""" Cisco_IOS_XE_native 

NED YANG module for IOS\-XE
Copyright (c) 2016\-2018 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class LoggingLevelType(Enum):
    """
    LoggingLevelType (Enum Class)

    .. data:: emergencies = 0

    .. data:: alerts = 1

    .. data:: critical = 2

    .. data:: errors = 3

    .. data:: warnings = 4

    .. data:: notifications = 5

    .. data:: informational = 6

    .. data:: debugging = 7

    .. data:: bogus = 8

    """

    emergencies = Enum.YLeaf(0, "emergencies")

    alerts = Enum.YLeaf(1, "alerts")

    critical = Enum.YLeaf(2, "critical")

    errors = Enum.YLeaf(3, "errors")

    warnings = Enum.YLeaf(4, "warnings")

    notifications = Enum.YLeaf(5, "notifications")

    informational = Enum.YLeaf(6, "informational")

    debugging = Enum.YLeaf(7, "debugging")

    bogus = Enum.YLeaf(8, "bogus")


class MonitorEventType(Enum):
    """
    MonitorEventType (Enum Class)

    .. data:: error = 0

    .. data:: detail = 1

    .. data:: major = 2

    """

    error = Enum.YLeaf(0, "error")

    detail = Enum.YLeaf(1, "detail")

    major = Enum.YLeaf(2, "major")



class Native(Entity):
    """
    
    
    .. attribute:: default
    
    	Set a command to its defaults
    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Default>`
    
    .. attribute:: bfd
    
    	BFD configuration commands
    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd>`
    
    .. attribute:: version
    
    	Version
    	**type**\: str
    
    .. attribute:: stackwise_virtual
    
    	Enter stackwise\-virtual configuration mode
    	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.StackwiseVirtual>`
    
    	**presence node**\: True
    
    .. attribute:: boot_start_marker
    
    	
    	**type**\: :py:class:`Empty<ydk.types.Empty>`
    
    .. attribute:: boot
    
    	Modify boot system parameters
    	**type**\:  :py:class:`Boot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Boot>`
    
    .. attribute:: boot_end_marker
    
    	
    	**type**\: :py:class:`Empty<ydk.types.Empty>`
    
    .. attribute:: banner
    
    	Define a login banner
    	**type**\:  :py:class:`Banner <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Banner>`
    
    .. attribute:: captive_portal_bypass
    
    	Enable Captive portal bypass for apple devices
    	**type**\: :py:class:`Empty<ydk.types.Empty>`
    
    .. attribute:: memory
    
    	Configure memory management
    	**type**\:  :py:class:`Memory <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Memory>`
    
    .. attribute:: location
    
    	Global location configuration commands
    	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Location>`
    
    .. attribute:: call_home
    
    	Enter call\-home configuration mode
    	**type**\:  :py:class:`CallHome <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome>`
    
    	**presence node**\: True
    
    .. attribute:: hw_module
    
    	Control of individual components in the system
    	**type**\:  :py:class:`HwModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwModule>`
    
    .. attribute:: cisp
    
    	Set CISP parameters
    	**type**\:  :py:class:`Cisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cisp>`
    
    .. attribute:: module
    
    	Module
    	**type**\:  :py:class:`Module <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Module>`
    
    .. attribute:: domain
    
    	Domain Configuration Commands
    	**type**\: list of  		 :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain>`
    
    .. attribute:: parser
    
    	Configure parser
    	**type**\:  :py:class:`Parser <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser>`
    
    .. attribute:: service
    
    	Modify use of network based services
    	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service>`
    
    .. attribute:: platform
    
    	platform specific configuration
    	**type**\:  :py:class:`Platform <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform>`
    
    .. attribute:: hostname
    
    	Set system's network name
    	**type**\: str
    
    .. attribute:: enable
    
    	Modify enable password parameters
    	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Enable>`
    
    .. attribute:: password
    
    	Configure encryption password (key)
    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Password>`
    
    .. attribute:: eap
    
    	Configure EAP authenticator parameters
    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Eap>`
    
    .. attribute:: archive
    
    	Archive the configuration
    	**type**\:  :py:class:`Archive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Archive>`
    
    .. attribute:: username
    
    	Establish User Name Authentication
    	**type**\: list of  		 :py:class:`Username <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Username>`
    
    .. attribute:: card
    
    	Configure T1/E1 SPA
    	**type**\:  :py:class:`Card <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Card>`
    
    .. attribute:: controller
    
    	Configure controller
    	**type**\:  :py:class:`Controller <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller>`
    
    .. attribute:: aqm_register_fnf
    
    	Export audio/video stats to flow record
    	**type**\: :py:class:`Empty<ydk.types.Empty>`
    
    .. attribute:: vrf
    
    	VRF commands
    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf>`
    
    .. attribute:: rmon
    
    	Remote Monitoring
    	**type**\:  :py:class:`Rmon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Rmon>`
    
    .. attribute:: sampler
    
    	Define a Sampler
    	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Sampler>`
    
    .. attribute:: flow
    
    	Global Flow configuration subcommands
    	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow>`
    
    .. attribute:: ip
    
    	Global IP configuration subcommands
    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip>`
    
    .. attribute:: mka
    
    	MACsec Key Agreement (MKA) configuration
    	**type**\:  :py:class:`Mka <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mka>`
    
    .. attribute:: macro
    
    	Macro configuration
    	**type**\:  :py:class:`Macro <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Macro>`
    
    .. attribute:: ipv6
    
    	Global IPv6 configuration commands
    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6>`
    
    .. attribute:: vlan
    
    	Global vlan configuration
    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan>`
    
    .. attribute:: mvrp
    
    	Global MVRP
    	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mvrp>`
    
    .. attribute:: avb
    
    	Global AVB
    	**type**\:  :py:class:`Avb <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avb>`
    
    	**presence node**\: True
    
    .. attribute:: ptp
    
    	Global PTP
    	**type**\:  :py:class:`Ptp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ptp>`
    
    .. attribute:: cdp
    
    	Global CDP configuration subcommands
    	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cdp>`
    
    .. attribute:: avc
    
    	Application visibility and control
    	**type**\:  :py:class:`Avc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avc>`
    
    .. attribute:: policy
    
    	
    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy>`
    
    .. attribute:: interface
    
    	Configure Interfaces
    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface>`
    
    .. attribute:: route_map
    
    	Route map tag
    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap>`
    
    .. attribute:: route_tag
    
    	
    	**type**\:  :py:class:`RouteTag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag>`
    
    .. attribute:: table_map
    
    	Configure Table Map
    	**type**\: list of  		 :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
    
    .. attribute:: sdm
    
    	Switch database management
    	**type**\:  :py:class:`Sdm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Sdm>`
    
    .. attribute:: mls
    
    	mls global commands
    	**type**\:  :py:class:`Mls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mls>`
    
    .. attribute:: object_group
    
    	Configure Object group
    	**type**\:  :py:class:`ObjectGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup>`
    
    .. attribute:: pseudowire_class
    
    	Pseudowire\-class configuration
    	**type**\: list of  		 :py:class:`PseudowireClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass>`
    
    .. attribute:: control_plane
    
    	Configure control plane services
    	**type**\:  :py:class:`ControlPlane <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ControlPlane>`
    
    	**presence node**\: True
    
    .. attribute:: control_plane_host
    
    	
    	**type**\:  :py:class:`ControlPlaneHost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ControlPlaneHost>`
    
    .. attribute:: config_register
    
    	Define the configuration register
    	**type**\: str
    
    	**pattern:** [0\-9xXa\-fA\-F].\*
    
    .. attribute:: clock
    
    	Configure time\-of\-day clock
    	**type**\:  :py:class:`Clock <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Clock>`
    
    .. attribute:: logging
    
    	Modify message logging facilities
    	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging>`
    
    .. attribute:: aaa
    
    	Authentication, Authorization and Accounting
    	**type**\:  :py:class:`Aaa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa>`
    
    .. attribute:: privilege
    
    	Command privilege parameters
    	**type**\:  :py:class:`Privilege <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Privilege>`
    
    .. attribute:: login
    
    	Enable secure login checking
    	**type**\:  :py:class:`Login <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Login>`
    
    .. attribute:: multilink
    
    	PPP multilink global configuration
    	**type**\:  :py:class:`Multilink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Multilink>`
    
    .. attribute:: mac_address_table
    
    	Configure the MAC address table
    	**type**\:  :py:class:`MacAddressTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MacAddressTable>`
    
    .. attribute:: redundancy
    
    	Enter redundancy mode
    	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy>`
    
    	**presence node**\: True
    
    .. attribute:: scheduler
    
    	Scheduler parameters
    	**type**\:  :py:class:`Scheduler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Scheduler>`
    
    .. attribute:: epm
    
    	EPM Global Configuration Commands
    	**type**\:  :py:class:`Epm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Epm>`
    
    .. attribute:: spanning_tree
    
    	Spanning Tree Subsystem
    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree>`
    
    .. attribute:: subscriber
    
    	Subscriber configuration
    	**type**\:  :py:class:`Subscriber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Subscriber>`
    
    .. attribute:: track
    
    	Object tracking configuration commands
    	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track>`
    
    .. attribute:: dot1x
    
    	IEEE 802.1X Global Configuration Commands
    	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dot1x>`
    
    .. attribute:: mab
    
    	mab Configuration Commands
    	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mab>`
    
    .. attribute:: fallback
    
    	Fallback configuration commands
    	**type**\:  :py:class:`Fallback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fallback>`
    
    .. attribute:: parameter_map
    
    	parameter map
    	**type**\:  :py:class:`ParameterMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap>`
    
    .. attribute:: ppp
    
    	PPP global configuration
    	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ppp>`
    
    .. attribute:: mac
    
    	Global MAC configuration subcommands
    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac>`
    
    .. attribute:: tacacs
    
    	TACACS server configuration command
    	**type**\:  :py:class:`Tacacs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Tacacs>`
    
    .. attribute:: tacacs_server
    
    	Modify TACACS query parameters
    	**type**\:  :py:class:`TacacsServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TacacsServer>`
    
    .. attribute:: software
    
    	Configure software installation parameters
    	**type**\:  :py:class:`Software <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Software>`
    
    .. attribute:: upgrade
    
    	Global upgrade configuration subcommands
    	**type**\:  :py:class:`Upgrade <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Upgrade>`
    
    .. attribute:: vtp
    
    	Configure global VTP state
    	**type**\:  :py:class:`Vtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vtp>`
    
    .. attribute:: xconnect
    
    	
    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Xconnect>`
    
    .. attribute:: fabric
    
    	Catalyst 6000 crossbar fabric configuration commands
    	**type**\:  :py:class:`Fabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fabric>`
    
    .. attribute:: port_channel
    
    	EtherChannel configuration
    	**type**\:  :py:class:`PortChannel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PortChannel>`
    
    .. attribute:: key
    
    	Key management
    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Key>`
    
    .. attribute:: l2
    
    	Layer 2 configuration
    	**type**\:  :py:class:`L2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2>`
    
    .. attribute:: system
    
    	Set the system configuration
    	**type**\:  :py:class:`System <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System>`
    
    .. attribute:: errdisable
    
    	Error disable
    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable>`
    
    .. attribute:: identity
    
    	Identity Configuration Commands
    	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity>`
    
    .. attribute:: monitor
    
    	Monitoring different system events
    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor>`
    
    .. attribute:: tftp_server
    
    	Provide TFTP service for netload requests
    	**type**\: list of  		 :py:class:`TftpServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TftpServer>`
    
    .. attribute:: radius_server
    
    	Modify RADIUS query parameters
    	**type**\:  :py:class:`RadiusServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer>`
    
    .. attribute:: radius
    
    	RADIUS server configuration command
    	**type**\:  :py:class:`Radius <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius>`
    
    .. attribute:: zone
    
    	FW with zoning
    	**type**\:  :py:class:`Zone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Zone>`
    
    .. attribute:: zone_pair
    
    	Zone pair command
    	**type**\:  :py:class:`ZonePair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ZonePair>`
    
    .. attribute:: alarm_contact
    
    	
    	**type**\: list of  		 :py:class:`AlarmContact <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.AlarmContact>`
    
    .. attribute:: ethernet
    
    	Ethernet configuration
    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet>`
    
    .. attribute:: bridge_domain
    
    	Bridge\-domain global configuration commands
    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain>`
    
    .. attribute:: crypto
    
    	Encryption module
    	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto>`
    
    .. attribute:: cts
    
    	Configures Cisco TrustSec
    	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts>`
    
    .. attribute:: bfd_template
    
    	BFD\-template
    	**type**\:  :py:class:`BfdTemplate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BfdTemplate>`
    
    .. attribute:: pfr
    
    	Performance Routing configuration submodes
    	**type**\:  :py:class:`Pfr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr>`
    
    .. attribute:: pfr_map
    
    	Create pfr\-map and enter pfr\-map command mode
    	**type**\: list of  		 :py:class:`PfrMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap>`
    
    .. attribute:: facility_alarm
    
    	Configure facility alarms
    	**type**\:  :py:class:`FacilityAlarm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FacilityAlarm>`
    
    .. attribute:: setup
    
    	Configure setup options
    	**type**\:  :py:class:`Setup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Setup>`
    
    .. attribute:: tod_clock
    
    	Tod clock config commands
    	**type**\:  :py:class:`TodClock <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TodClock>`
    
    .. attribute:: network_clock
    
    	Network clock config commands
    	**type**\:  :py:class:`NetworkClock <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkClock>`
    
    .. attribute:: l2vpn
    
    	Layer2 VPN commands
    	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn>`
    
    .. attribute:: l2vpn_config
    
    	
    	**type**\:  :py:class:`L2vpnConfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpnConfig>`
    
    .. attribute:: l3vpn
    
    	l3vpn encapsulation ip commands
    	**type**\:  :py:class:`L3vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L3vpn>`
    
    .. attribute:: mpls
    
    	Configure MPLS parameters
    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls>`
    
    .. attribute:: router
    
    	
    	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router>`
    
    .. attribute:: service_chain
    
    	Service Chain mode
    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain>`
    
    .. attribute:: performance
    
    	Global Performance monitor configuration
    	**type**\:  :py:class:`Performance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance>`
    
    .. attribute:: otv
    
    	Configure OTV information
    	**type**\:  :py:class:`Otv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv>`
    
    .. attribute:: remote_management
    
    	Enable the remote managment
    	**type**\:  :py:class:`RemoteManagement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RemoteManagement>`
    
    .. attribute:: virtual_service
    
    	Configure virtual service
    	**type**\: list of  		 :py:class:`VirtualService <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService>`
    
    .. attribute:: snmp
    
    	Modify SNMP interface parameters
    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Snmp>`
    
    .. attribute:: snmp_server
    
    	Modify SNMP engine parameters
    	**type**\:  :py:class:`SnmpServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer>`
    
    .. attribute:: segment_routing
    
    	Enter Segment Routing Mode
    	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting>`
    
    .. attribute:: license
    
    	Configure license features
    	**type**\:  :py:class:`License <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License>`
    
    .. attribute:: disable_eadi
    
    	
    	**type**\: :py:class:`Empty<ydk.types.Empty>`
    
    .. attribute:: memory_size
    
    	Adjust memory size by percentage
    	**type**\:  :py:class:`MemorySize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MemorySize>`
    
    .. attribute:: transceiver
    
    	Select from transceiver configuration commands
    	**type**\:  :py:class:`Transceiver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Transceiver>`
    
    .. attribute:: service_insertion
    
    	Service Insertion mode
    	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceInsertion>`
    
    .. attribute:: udld
    
    	Configure global UDLD setting
    	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Udld>`
    
    .. attribute:: qos
    
    	Global QoS configuration commands
    	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos>`
    
    	**presence node**\: True
    
    .. attribute:: time_range
    
    	Define time range entries
    	**type**\: list of  		 :py:class:`TimeRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TimeRange>`
    
    .. attribute:: device_tracking
    
    	Device tracking configuration commands
    	**type**\:  :py:class:`DeviceTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking>`
    
    .. attribute:: fhrp
    
    	Configure First Hop Redundancy Protocols
    	**type**\:  :py:class:`Fhrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fhrp>`
    
    .. attribute:: metadata
    
    	Metadata Application
    	**type**\:  :py:class:`Metadata <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Metadata>`
    
    .. attribute:: profile
    
    	MSP Profile
    	**type**\:  :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Profile>`
    
    .. attribute:: alias
    
    	Create command alias
    	**type**\:  :py:class:`Alias <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Alias>`
    
    .. attribute:: line
    
    	Configure a terminal line
    	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line>`
    
    .. attribute:: ntp
    
    	Configure NTP
    	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp>`
    
    .. attribute:: wsma
    
    	Configure Web Services Management Agents
    	**type**\:  :py:class:`Wsma <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Wsma>`
    
    .. attribute:: event
    
    	Event related configuration commands
    	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event>`
    
    .. attribute:: template
    
    	template
    	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template>`
    
    .. attribute:: process
    
    	Configure process
    	**type**\:  :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process>`
    
    .. attribute:: exception
    
    	help
    	**type**\:  :py:class:`Exception <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Exception>`
    
    .. attribute:: iox
    
    	Configure IOx services
    	**type**\:  :py:class:`Iox <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Iox>`
    
    	**presence node**\: True
    
    .. attribute:: named_ordering_route_map
    
    	named ordering route\-map enable
    	**type**\:  :py:class:`NamedOrderingRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NamedOrderingRouteMap>`
    
    .. attribute:: esmc
    
    	Ethernet Synchronization Messaging Channel
    	**type**\:  :py:class:`Esmc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Esmc>`
    
    .. attribute:: cef
    
    	Cisco Express Forwarding
    	**type**\:  :py:class:`Cef <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef>`
    
    .. attribute:: arp
    
    	Set a static ARP entry
    	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp>`
    
    .. attribute:: network_policy
    
    	Network Policy
    	**type**\:  :py:class:`NetworkPolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkPolicy>`
    
    .. attribute:: energywise
    
    	EnergyWise Global Configuration Commands
    	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Energywise>`
    
    .. attribute:: service_template
    
    	Configure a service\-template/identity policy
    	**type**\: list of  		 :py:class:`ServiceTemplate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceTemplate>`
    
    .. attribute:: switch
    
    	Config commands for the switches in the stack
    	**type**\: list of  		 :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Switch>`
    
    .. attribute:: switch_virtual
    
    	
    	**type**\: list of  		 :py:class:`SwitchVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SwitchVirtual>`
    
    .. attribute:: device
    
    	device classifier configuration
    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Device>`
    
    .. attribute:: stack_mac
    
    	Global stack mac\-address feature configurations
    	**type**\:  :py:class:`StackMac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.StackMac>`
    
    .. attribute:: l2protocol_tunnel
    
    	Tunnel Layer2 protocols
    	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2protocolTunnel>`
    
    .. attribute:: rep
    
    	Resilient Ethernet Protocol characteristics
    	**type**\:  :py:class:`Rep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Rep>`
    
    .. attribute:: hw_switch
    
    	Hw\-switch
    	**type**\:  :py:class:`HwSwitch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwSwitch>`
    
    .. attribute:: feature
    
    	feature enable config
    	**type**\:  :py:class:`Feature <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Feature>`
    
    .. attribute:: openflow
    
    	OpenFlow configuration
    	**type**\:  :py:class:`Openflow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow>`
    
    .. attribute:: et_analytics
    
    	Encrypted Traffic Analytics
    	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.EtAnalytics>`
    
    	**presence node**\: True
    
    .. attribute:: dialer
    
    	Dialer commands
    	**type**\:  :py:class:`Dialer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dialer>`
    
    .. attribute:: dialer_list
    
    	Create a dialer list entry
    	**type**\: list of  		 :py:class:`DialerList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DialerList>`
    
    .. attribute:: utd
    
    	Global Unified Threat Defense
    	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Utd>`
    
    	**presence node**\: True
    
    .. attribute:: utd_st
    
    	
    	**type**\:  :py:class:`UtdSt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt>`
    
    .. attribute:: utd_mt
    
    	
    	**type**\:  :py:class:`UtdMt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt>`
    
    .. attribute:: fabric_group
    
    	
    	**type**\:  :py:class:`FabricGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup>`
    
    .. attribute:: coap
    
    	CoAP Global Configuration Commands
    	**type**\:  :py:class:`Coap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Coap>`
    
    .. attribute:: voice
    
    	Global voice configuration
    	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Voice>`
    
    .. attribute:: voice_card
    
    	Configure a specific voice\-card
    	**type**\: list of  		 :py:class:`VoiceCard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VoiceCard>`
    
    .. attribute:: power
    
    	Power configure
    	**type**\:  :py:class:`Power <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Power>`
    
    .. attribute:: device_sensor
    
    	IOS Sensor Commands
    	**type**\:  :py:class:`DeviceSensor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceSensor>`
    
    .. attribute:: service_list
    
    	Enter the service list
    	**type**\:  :py:class:`ServiceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceList>`
    
    .. attribute:: access_session
    
    	Access Sesion Global Configuration Commands
    	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.AccessSession>`
    
    .. attribute:: authentication
    
    	Auth Manager Global Configuration Commands
    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Authentication>`
    
    .. attribute:: service_routing
    
    	Configure service\-routing
    	**type**\:  :py:class:`ServiceRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceRouting>`
    
    .. attribute:: maintenance_template
    
    	maintenance\-template configuration
    	**type**\: list of  		 :py:class:`MaintenanceTemplate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MaintenanceTemplate>`
    
    .. attribute:: lldp
    
    	Enables LLDP globally
    	**type**\:  :py:class:`Lldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Lldp>`
    
    .. attribute:: diagnostic
    
    	Configure diagnostic information
    	**type**\:  :py:class:`Diagnostic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic>`
    
    .. attribute:: nat66
    
    	NAT66 configuration commands
    	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Nat66>`
    
    .. attribute:: bba_group
    
    	Configure BBA Group
    	**type**\:  :py:class:`BbaGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BbaGroup>`
    
    .. attribute:: shell
    
    	Configure shell command
    	**type**\:  :py:class:`Shell <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Shell>`
    
    .. attribute:: vstack
    
    	Configure vstack parameters and enable or disable SmartInstall
    	**type**\:  :py:class:`Vstack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vstack>`
    
    .. attribute:: pm_agent
    
    	pm\-agent Configuration Commands
    	**type**\:  :py:class:`PmAgent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent>`
    
    	**presence node**\: True
    
    .. attribute:: vpdn
    
    	Virtual Private Dialup Network
    	**type**\:  :py:class:`Vpdn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vpdn>`
    
    

    """

    _prefix = 'ios'
    _revision = '2018-05-22'

    def __init__(self):
        super(Native, self).__init__()
        self._top_entity = None

        self.yang_name = "native"
        self.yang_parent_name = "Cisco-IOS-XE-native"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("default", ("default", Native.Default)), ("bfd", ("bfd", Native.Bfd)), ("stackwise-virtual", ("stackwise_virtual", Native.StackwiseVirtual)), ("boot", ("boot", Native.Boot)), ("banner", ("banner", Native.Banner)), ("memory", ("memory", Native.Memory)), ("location", ("location", Native.Location)), ("call-home", ("call_home", Native.CallHome)), ("hw-module", ("hw_module", Native.HwModule)), ("cisp", ("cisp", Native.Cisp)), ("module", ("module", Native.Module)), ("domain", ("domain", Native.Domain)), ("parser", ("parser", Native.Parser)), ("service", ("service", Native.Service)), ("platform", ("platform", Native.Platform)), ("enable", ("enable", Native.Enable)), ("password", ("password", Native.Password)), ("eap", ("eap", Native.Eap)), ("archive", ("archive", Native.Archive)), ("username", ("username", Native.Username)), ("card", ("card", Native.Card)), ("controller", ("controller", Native.Controller)), ("vrf", ("vrf", Native.Vrf)), ("rmon", ("rmon", Native.Rmon)), ("sampler", ("sampler", Native.Sampler)), ("flow", ("flow", Native.Flow)), ("ip", ("ip", Native.Ip)), ("mka", ("mka", Native.Mka)), ("macro", ("macro", Native.Macro)), ("ipv6", ("ipv6", Native.Ipv6)), ("vlan", ("vlan", Native.Vlan)), ("mvrp", ("mvrp", Native.Mvrp)), ("avb", ("avb", Native.Avb)), ("ptp", ("ptp", Native.Ptp)), ("cdp", ("cdp", Native.Cdp)), ("avc", ("avc", Native.Avc)), ("policy", ("policy", Native.Policy)), ("interface", ("interface", Native.Interface)), ("route-map", ("route_map", Native.RouteMap)), ("route-tag", ("route_tag", Native.RouteTag)), ("table-map", ("table_map", Native.TableMap)), ("sdm", ("sdm", Native.Sdm)), ("mls", ("mls", Native.Mls)), ("object-group", ("object_group", Native.ObjectGroup)), ("pseudowire-class", ("pseudowire_class", Native.PseudowireClass)), ("control-plane", ("control_plane", Native.ControlPlane)), ("control-plane-host", ("control_plane_host", Native.ControlPlaneHost)), ("clock", ("clock", Native.Clock)), ("logging", ("logging", Native.Logging)), ("aaa", ("aaa", Native.Aaa)), ("privilege", ("privilege", Native.Privilege)), ("login", ("login", Native.Login)), ("multilink", ("multilink", Native.Multilink)), ("mac-address-table", ("mac_address_table", Native.MacAddressTable)), ("redundancy", ("redundancy", Native.Redundancy)), ("scheduler", ("scheduler", Native.Scheduler)), ("epm", ("epm", Native.Epm)), ("spanning-tree", ("spanning_tree", Native.SpanningTree)), ("subscriber", ("subscriber", Native.Subscriber)), ("track", ("track", Native.Track)), ("dot1x", ("dot1x", Native.Dot1x)), ("mab", ("mab", Native.Mab)), ("fallback", ("fallback", Native.Fallback)), ("parameter-map", ("parameter_map", Native.ParameterMap)), ("ppp", ("ppp", Native.Ppp)), ("mac", ("mac", Native.Mac)), ("tacacs", ("tacacs", Native.Tacacs)), ("tacacs-server", ("tacacs_server", Native.TacacsServer)), ("software", ("software", Native.Software)), ("upgrade", ("upgrade", Native.Upgrade)), ("vtp", ("vtp", Native.Vtp)), ("xconnect", ("xconnect", Native.Xconnect)), ("fabric", ("fabric", Native.Fabric)), ("port-channel", ("port_channel", Native.PortChannel)), ("key", ("key", Native.Key)), ("l2", ("l2", Native.L2)), ("system", ("system", Native.System)), ("errdisable", ("errdisable", Native.Errdisable)), ("identity", ("identity", Native.Identity)), ("monitor", ("monitor", Native.Monitor)), ("tftp-server", ("tftp_server", Native.TftpServer)), ("radius-server", ("radius_server", Native.RadiusServer)), ("radius", ("radius", Native.Radius)), ("zone", ("zone", Native.Zone)), ("zone-pair", ("zone_pair", Native.ZonePair)), ("alarm-contact", ("alarm_contact", Native.AlarmContact)), ("ethernet", ("ethernet", Native.Ethernet)), ("bridge-domain", ("bridge_domain", Native.BridgeDomain)), ("crypto", ("crypto", Native.Crypto)), ("cts", ("cts", Native.Cts)), ("bfd-template", ("bfd_template", Native.BfdTemplate)), ("pfr", ("pfr", Native.Pfr)), ("pfr-map", ("pfr_map", Native.PfrMap)), ("facility-alarm", ("facility_alarm", Native.FacilityAlarm)), ("setup", ("setup", Native.Setup)), ("tod-clock", ("tod_clock", Native.TodClock)), ("network-clock", ("network_clock", Native.NetworkClock)), ("l2vpn", ("l2vpn", Native.L2vpn)), ("l2vpn-config", ("l2vpn_config", Native.L2vpnConfig)), ("l3vpn", ("l3vpn", Native.L3vpn)), ("mpls", ("mpls", Native.Mpls)), ("router", ("router", Native.Router)), ("service-chain", ("service_chain", Native.ServiceChain)), ("performance", ("performance", Native.Performance)), ("otv", ("otv", Native.Otv)), ("remote-management", ("remote_management", Native.RemoteManagement)), ("virtual-service", ("virtual_service", Native.VirtualService)), ("snmp", ("snmp", Native.Snmp)), ("snmp-server", ("snmp_server", Native.SnmpServer)), ("segment-routing", ("segment_routing", Native.SegmentRouting)), ("license", ("license", Native.License)), ("memory-size", ("memory_size", Native.MemorySize)), ("transceiver", ("transceiver", Native.Transceiver)), ("service-insertion", ("service_insertion", Native.ServiceInsertion)), ("udld", ("udld", Native.Udld)), ("qos", ("qos", Native.Qos)), ("time-range", ("time_range", Native.TimeRange)), ("device-tracking", ("device_tracking", Native.DeviceTracking)), ("fhrp", ("fhrp", Native.Fhrp)), ("metadata", ("metadata", Native.Metadata)), ("profile", ("profile", Native.Profile)), ("alias", ("alias", Native.Alias)), ("line", ("line", Native.Line)), ("ntp", ("ntp", Native.Ntp)), ("wsma", ("wsma", Native.Wsma)), ("event", ("event", Native.Event)), ("template", ("template", Native.Template)), ("process", ("process", Native.Process)), ("exception", ("exception", Native.Exception)), ("iox", ("iox", Native.Iox)), ("Cisco-IOS-XE-route-map:named-ordering-route-map", ("named_ordering_route_map", Native.NamedOrderingRouteMap)), ("Cisco-IOS-XE-ethernet:esmc", ("esmc", Native.Esmc)), ("Cisco-IOS-XE-cef:cef", ("cef", Native.Cef)), ("Cisco-IOS-XE-arp:arp", ("arp", Native.Arp)), ("Cisco-IOS-XE-switch:network-policy", ("network_policy", Native.NetworkPolicy)), ("Cisco-IOS-XE-switch:energywise", ("energywise", Native.Energywise)), ("Cisco-IOS-XE-switch:service-template", ("service_template", Native.ServiceTemplate)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Switch)), ("Cisco-IOS-XE-switch:switch-virtual", ("switch_virtual", Native.SwitchVirtual)), ("Cisco-IOS-XE-switch:device", ("device", Native.Device)), ("Cisco-IOS-XE-switch:stack-mac", ("stack_mac", Native.StackMac)), ("Cisco-IOS-XE-switch:l2protocol-tunnel", ("l2protocol_tunnel", Native.L2protocolTunnel)), ("Cisco-IOS-XE-switch:rep", ("rep", Native.Rep)), ("Cisco-IOS-XE-switch:hw-switch", ("hw_switch", Native.HwSwitch)), ("Cisco-IOS-XE-switch:feature", ("feature", Native.Feature)), ("Cisco-IOS-XE-switch:openflow", ("openflow", Native.Openflow)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.EtAnalytics)), ("Cisco-IOS-XE-cellular:dialer", ("dialer", Native.Dialer)), ("Cisco-IOS-XE-cellular:dialer-list", ("dialer_list", Native.DialerList)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Utd)), ("Cisco-IOS-XE-utd:utd-st", ("utd_st", Native.UtdSt)), ("Cisco-IOS-XE-utd:utd-mt", ("utd_mt", Native.UtdMt)), ("Cisco-IOS-XE-iwanfabric:fabric-group", ("fabric_group", Native.FabricGroup)), ("Cisco-IOS-XE-coap:coap", ("coap", Native.Coap)), ("Cisco-IOS-XE-voice:voice", ("voice", Native.Voice)), ("Cisco-IOS-XE-voice:voice-card", ("voice_card", Native.VoiceCard)), ("Cisco-IOS-XE-power:power", ("power", Native.Power)), ("Cisco-IOS-XE-device-sensor:device-sensor", ("device_sensor", Native.DeviceSensor)), ("Cisco-IOS-XE-service-discovery:service-list", ("service_list", Native.ServiceList)), ("Cisco-IOS-XE-sanet:access-session", ("access_session", Native.AccessSession)), ("Cisco-IOS-XE-sanet:authentication", ("authentication", Native.Authentication)), ("Cisco-IOS-XE-service-routing:service-routing", ("service_routing", Native.ServiceRouting)), ("Cisco-IOS-XE-mmode:maintenance-template", ("maintenance_template", Native.MaintenanceTemplate)), ("Cisco-IOS-XE-lldp:lldp", ("lldp", Native.Lldp)), ("Cisco-IOS-XE-diagnostics:diagnostic", ("diagnostic", Native.Diagnostic)), ("Cisco-IOS-XE-nat:nat66", ("nat66", Native.Nat66)), ("Cisco-IOS-XE-bba-group:bba-group", ("bba_group", Native.BbaGroup)), ("Cisco-IOS-XE-platform:shell", ("shell", Native.Shell)), ("Cisco-IOS-XE-vstack:vstack", ("vstack", Native.Vstack)), ("Cisco-IOS-XE-pathmgr:pm-agent", ("pm_agent", Native.PmAgent)), ("Cisco-IOS-XE-vpdn:vpdn", ("vpdn", Native.Vpdn))])
        self._leafs = OrderedDict([
            ('version', (YLeaf(YType.str, 'version'), ['str'])),
            ('boot_start_marker', (YLeaf(YType.empty, 'boot-start-marker'), ['Empty'])),
            ('boot_end_marker', (YLeaf(YType.empty, 'boot-end-marker'), ['Empty'])),
            ('captive_portal_bypass', (YLeaf(YType.empty, 'captive-portal-bypass'), ['Empty'])),
            ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
            ('aqm_register_fnf', (YLeaf(YType.empty, 'aqm-register-fnf'), ['Empty'])),
            ('config_register', (YLeaf(YType.str, 'config-register'), ['str'])),
            ('disable_eadi', (YLeaf(YType.empty, 'disable-eadi'), ['Empty'])),
        ])
        self.version = None
        self.boot_start_marker = None
        self.boot_end_marker = None
        self.captive_portal_bypass = None
        self.hostname = None
        self.aqm_register_fnf = None
        self.config_register = None
        self.disable_eadi = None

        self.default = Native.Default()
        self.default.parent = self
        self._children_name_map["default"] = "default"

        self.bfd = Native.Bfd()
        self.bfd.parent = self
        self._children_name_map["bfd"] = "bfd"

        self.stackwise_virtual = None
        self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

        self.boot = Native.Boot()
        self.boot.parent = self
        self._children_name_map["boot"] = "boot"

        self.banner = Native.Banner()
        self.banner.parent = self
        self._children_name_map["banner"] = "banner"

        self.memory = Native.Memory()
        self.memory.parent = self
        self._children_name_map["memory"] = "memory"

        self.location = Native.Location()
        self.location.parent = self
        self._children_name_map["location"] = "location"

        self.call_home = None
        self._children_name_map["call_home"] = "call-home"

        self.hw_module = Native.HwModule()
        self.hw_module.parent = self
        self._children_name_map["hw_module"] = "hw-module"

        self.cisp = Native.Cisp()
        self.cisp.parent = self
        self._children_name_map["cisp"] = "cisp"

        self.module = Native.Module()
        self.module.parent = self
        self._children_name_map["module"] = "module"

        self.parser = Native.Parser()
        self.parser.parent = self
        self._children_name_map["parser"] = "parser"

        self.service = Native.Service()
        self.service.parent = self
        self._children_name_map["service"] = "service"

        self.platform = Native.Platform()
        self.platform.parent = self
        self._children_name_map["platform"] = "platform"

        self.enable = Native.Enable()
        self.enable.parent = self
        self._children_name_map["enable"] = "enable"

        self.password = Native.Password()
        self.password.parent = self
        self._children_name_map["password"] = "password"

        self.eap = Native.Eap()
        self.eap.parent = self
        self._children_name_map["eap"] = "eap"

        self.archive = Native.Archive()
        self.archive.parent = self
        self._children_name_map["archive"] = "archive"

        self.card = Native.Card()
        self.card.parent = self
        self._children_name_map["card"] = "card"

        self.controller = Native.Controller()
        self.controller.parent = self
        self._children_name_map["controller"] = "controller"

        self.vrf = Native.Vrf()
        self.vrf.parent = self
        self._children_name_map["vrf"] = "vrf"

        self.rmon = Native.Rmon()
        self.rmon.parent = self
        self._children_name_map["rmon"] = "rmon"

        self.flow = Native.Flow()
        self.flow.parent = self
        self._children_name_map["flow"] = "flow"

        self.ip = Native.Ip()
        self.ip.parent = self
        self._children_name_map["ip"] = "ip"

        self.mka = Native.Mka()
        self.mka.parent = self
        self._children_name_map["mka"] = "mka"

        self.macro = Native.Macro()
        self.macro.parent = self
        self._children_name_map["macro"] = "macro"

        self.ipv6 = Native.Ipv6()
        self.ipv6.parent = self
        self._children_name_map["ipv6"] = "ipv6"

        self.vlan = Native.Vlan()
        self.vlan.parent = self
        self._children_name_map["vlan"] = "vlan"

        self.mvrp = Native.Mvrp()
        self.mvrp.parent = self
        self._children_name_map["mvrp"] = "mvrp"

        self.avb = None
        self._children_name_map["avb"] = "avb"

        self.ptp = Native.Ptp()
        self.ptp.parent = self
        self._children_name_map["ptp"] = "ptp"

        self.cdp = Native.Cdp()
        self.cdp.parent = self
        self._children_name_map["cdp"] = "cdp"

        self.avc = Native.Avc()
        self.avc.parent = self
        self._children_name_map["avc"] = "avc"

        self.policy = Native.Policy()
        self.policy.parent = self
        self._children_name_map["policy"] = "policy"

        self.interface = Native.Interface()
        self.interface.parent = self
        self._children_name_map["interface"] = "interface"

        self.route_tag = Native.RouteTag()
        self.route_tag.parent = self
        self._children_name_map["route_tag"] = "route-tag"

        self.sdm = Native.Sdm()
        self.sdm.parent = self
        self._children_name_map["sdm"] = "sdm"

        self.mls = Native.Mls()
        self.mls.parent = self
        self._children_name_map["mls"] = "mls"

        self.object_group = Native.ObjectGroup()
        self.object_group.parent = self
        self._children_name_map["object_group"] = "object-group"

        self.control_plane = None
        self._children_name_map["control_plane"] = "control-plane"

        self.control_plane_host = Native.ControlPlaneHost()
        self.control_plane_host.parent = self
        self._children_name_map["control_plane_host"] = "control-plane-host"

        self.clock = Native.Clock()
        self.clock.parent = self
        self._children_name_map["clock"] = "clock"

        self.logging = Native.Logging()
        self.logging.parent = self
        self._children_name_map["logging"] = "logging"

        self.aaa = Native.Aaa()
        self.aaa.parent = self
        self._children_name_map["aaa"] = "aaa"

        self.privilege = Native.Privilege()
        self.privilege.parent = self
        self._children_name_map["privilege"] = "privilege"

        self.login = Native.Login()
        self.login.parent = self
        self._children_name_map["login"] = "login"

        self.multilink = Native.Multilink()
        self.multilink.parent = self
        self._children_name_map["multilink"] = "multilink"

        self.mac_address_table = Native.MacAddressTable()
        self.mac_address_table.parent = self
        self._children_name_map["mac_address_table"] = "mac-address-table"

        self.redundancy = None
        self._children_name_map["redundancy"] = "redundancy"

        self.scheduler = Native.Scheduler()
        self.scheduler.parent = self
        self._children_name_map["scheduler"] = "scheduler"

        self.epm = Native.Epm()
        self.epm.parent = self
        self._children_name_map["epm"] = "epm"

        self.spanning_tree = Native.SpanningTree()
        self.spanning_tree.parent = self
        self._children_name_map["spanning_tree"] = "spanning-tree"

        self.subscriber = Native.Subscriber()
        self.subscriber.parent = self
        self._children_name_map["subscriber"] = "subscriber"

        self.track = Native.Track()
        self.track.parent = self
        self._children_name_map["track"] = "track"

        self.dot1x = Native.Dot1x()
        self.dot1x.parent = self
        self._children_name_map["dot1x"] = "dot1x"

        self.mab = Native.Mab()
        self.mab.parent = self
        self._children_name_map["mab"] = "mab"

        self.fallback = Native.Fallback()
        self.fallback.parent = self
        self._children_name_map["fallback"] = "fallback"

        self.parameter_map = Native.ParameterMap()
        self.parameter_map.parent = self
        self._children_name_map["parameter_map"] = "parameter-map"

        self.ppp = Native.Ppp()
        self.ppp.parent = self
        self._children_name_map["ppp"] = "ppp"

        self.mac = Native.Mac()
        self.mac.parent = self
        self._children_name_map["mac"] = "mac"

        self.tacacs = Native.Tacacs()
        self.tacacs.parent = self
        self._children_name_map["tacacs"] = "tacacs"

        self.tacacs_server = Native.TacacsServer()
        self.tacacs_server.parent = self
        self._children_name_map["tacacs_server"] = "tacacs-server"

        self.software = Native.Software()
        self.software.parent = self
        self._children_name_map["software"] = "software"

        self.upgrade = Native.Upgrade()
        self.upgrade.parent = self
        self._children_name_map["upgrade"] = "upgrade"

        self.vtp = Native.Vtp()
        self.vtp.parent = self
        self._children_name_map["vtp"] = "vtp"

        self.xconnect = Native.Xconnect()
        self.xconnect.parent = self
        self._children_name_map["xconnect"] = "xconnect"

        self.fabric = Native.Fabric()
        self.fabric.parent = self
        self._children_name_map["fabric"] = "fabric"

        self.port_channel = Native.PortChannel()
        self.port_channel.parent = self
        self._children_name_map["port_channel"] = "port-channel"

        self.key = Native.Key()
        self.key.parent = self
        self._children_name_map["key"] = "key"

        self.l2 = Native.L2()
        self.l2.parent = self
        self._children_name_map["l2"] = "l2"

        self.system = Native.System()
        self.system.parent = self
        self._children_name_map["system"] = "system"

        self.errdisable = Native.Errdisable()
        self.errdisable.parent = self
        self._children_name_map["errdisable"] = "errdisable"

        self.identity = Native.Identity()
        self.identity.parent = self
        self._children_name_map["identity"] = "identity"

        self.monitor = Native.Monitor()
        self.monitor.parent = self
        self._children_name_map["monitor"] = "monitor"

        self.radius_server = Native.RadiusServer()
        self.radius_server.parent = self
        self._children_name_map["radius_server"] = "radius-server"

        self.radius = Native.Radius()
        self.radius.parent = self
        self._children_name_map["radius"] = "radius"

        self.zone = Native.Zone()
        self.zone.parent = self
        self._children_name_map["zone"] = "zone"

        self.zone_pair = Native.ZonePair()
        self.zone_pair.parent = self
        self._children_name_map["zone_pair"] = "zone-pair"

        self.ethernet = Native.Ethernet()
        self.ethernet.parent = self
        self._children_name_map["ethernet"] = "ethernet"

        self.bridge_domain = Native.BridgeDomain()
        self.bridge_domain.parent = self
        self._children_name_map["bridge_domain"] = "bridge-domain"

        self.crypto = Native.Crypto()
        self.crypto.parent = self
        self._children_name_map["crypto"] = "crypto"

        self.cts = Native.Cts()
        self.cts.parent = self
        self._children_name_map["cts"] = "cts"

        self.bfd_template = Native.BfdTemplate()
        self.bfd_template.parent = self
        self._children_name_map["bfd_template"] = "bfd-template"

        self.pfr = Native.Pfr()
        self.pfr.parent = self
        self._children_name_map["pfr"] = "pfr"

        self.facility_alarm = Native.FacilityAlarm()
        self.facility_alarm.parent = self
        self._children_name_map["facility_alarm"] = "facility-alarm"

        self.setup = Native.Setup()
        self.setup.parent = self
        self._children_name_map["setup"] = "setup"

        self.tod_clock = Native.TodClock()
        self.tod_clock.parent = self
        self._children_name_map["tod_clock"] = "tod-clock"

        self.network_clock = Native.NetworkClock()
        self.network_clock.parent = self
        self._children_name_map["network_clock"] = "network-clock"

        self.l2vpn = Native.L2vpn()
        self.l2vpn.parent = self
        self._children_name_map["l2vpn"] = "l2vpn"

        self.l2vpn_config = Native.L2vpnConfig()
        self.l2vpn_config.parent = self
        self._children_name_map["l2vpn_config"] = "l2vpn-config"

        self.l3vpn = Native.L3vpn()
        self.l3vpn.parent = self
        self._children_name_map["l3vpn"] = "l3vpn"

        self.mpls = Native.Mpls()
        self.mpls.parent = self
        self._children_name_map["mpls"] = "mpls"

        self.router = Native.Router()
        self.router.parent = self
        self._children_name_map["router"] = "router"

        self.service_chain = Native.ServiceChain()
        self.service_chain.parent = self
        self._children_name_map["service_chain"] = "service-chain"

        self.performance = Native.Performance()
        self.performance.parent = self
        self._children_name_map["performance"] = "performance"

        self.otv = Native.Otv()
        self.otv.parent = self
        self._children_name_map["otv"] = "otv"

        self.remote_management = Native.RemoteManagement()
        self.remote_management.parent = self
        self._children_name_map["remote_management"] = "remote-management"

        self.snmp = Native.Snmp()
        self.snmp.parent = self
        self._children_name_map["snmp"] = "snmp"

        self.snmp_server = Native.SnmpServer()
        self.snmp_server.parent = self
        self._children_name_map["snmp_server"] = "snmp-server"

        self.segment_routing = Native.SegmentRouting()
        self.segment_routing.parent = self
        self._children_name_map["segment_routing"] = "segment-routing"

        self.license = Native.License()
        self.license.parent = self
        self._children_name_map["license"] = "license"

        self.memory_size = Native.MemorySize()
        self.memory_size.parent = self
        self._children_name_map["memory_size"] = "memory-size"

        self.transceiver = Native.Transceiver()
        self.transceiver.parent = self
        self._children_name_map["transceiver"] = "transceiver"

        self.service_insertion = Native.ServiceInsertion()
        self.service_insertion.parent = self
        self._children_name_map["service_insertion"] = "service-insertion"

        self.udld = Native.Udld()
        self.udld.parent = self
        self._children_name_map["udld"] = "udld"

        self.qos = None
        self._children_name_map["qos"] = "qos"

        self.device_tracking = Native.DeviceTracking()
        self.device_tracking.parent = self
        self._children_name_map["device_tracking"] = "device-tracking"

        self.fhrp = Native.Fhrp()
        self.fhrp.parent = self
        self._children_name_map["fhrp"] = "fhrp"

        self.metadata = Native.Metadata()
        self.metadata.parent = self
        self._children_name_map["metadata"] = "metadata"

        self.profile = Native.Profile()
        self.profile.parent = self
        self._children_name_map["profile"] = "profile"

        self.alias = Native.Alias()
        self.alias.parent = self
        self._children_name_map["alias"] = "alias"

        self.line = Native.Line()
        self.line.parent = self
        self._children_name_map["line"] = "line"

        self.ntp = Native.Ntp()
        self.ntp.parent = self
        self._children_name_map["ntp"] = "ntp"

        self.wsma = Native.Wsma()
        self.wsma.parent = self
        self._children_name_map["wsma"] = "wsma"

        self.event = Native.Event()
        self.event.parent = self
        self._children_name_map["event"] = "event"

        self.template = Native.Template()
        self.template.parent = self
        self._children_name_map["template"] = "template"

        self.process = Native.Process()
        self.process.parent = self
        self._children_name_map["process"] = "process"

        self.exception = Native.Exception()
        self.exception.parent = self
        self._children_name_map["exception"] = "exception"

        self.iox = None
        self._children_name_map["iox"] = "iox"

        self.named_ordering_route_map = Native.NamedOrderingRouteMap()
        self.named_ordering_route_map.parent = self
        self._children_name_map["named_ordering_route_map"] = "Cisco-IOS-XE-route-map:named-ordering-route-map"

        self.esmc = Native.Esmc()
        self.esmc.parent = self
        self._children_name_map["esmc"] = "Cisco-IOS-XE-ethernet:esmc"

        self.cef = Native.Cef()
        self.cef.parent = self
        self._children_name_map["cef"] = "Cisco-IOS-XE-cef:cef"

        self.arp = Native.Arp()
        self.arp.parent = self
        self._children_name_map["arp"] = "Cisco-IOS-XE-arp:arp"

        self.network_policy = Native.NetworkPolicy()
        self.network_policy.parent = self
        self._children_name_map["network_policy"] = "Cisco-IOS-XE-switch:network-policy"

        self.energywise = Native.Energywise()
        self.energywise.parent = self
        self._children_name_map["energywise"] = "Cisco-IOS-XE-switch:energywise"

        self.device = Native.Device()
        self.device.parent = self
        self._children_name_map["device"] = "Cisco-IOS-XE-switch:device"

        self.stack_mac = Native.StackMac()
        self.stack_mac.parent = self
        self._children_name_map["stack_mac"] = "Cisco-IOS-XE-switch:stack-mac"

        self.l2protocol_tunnel = Native.L2protocolTunnel()
        self.l2protocol_tunnel.parent = self
        self._children_name_map["l2protocol_tunnel"] = "Cisco-IOS-XE-switch:l2protocol-tunnel"

        self.rep = Native.Rep()
        self.rep.parent = self
        self._children_name_map["rep"] = "Cisco-IOS-XE-switch:rep"

        self.hw_switch = Native.HwSwitch()
        self.hw_switch.parent = self
        self._children_name_map["hw_switch"] = "Cisco-IOS-XE-switch:hw-switch"

        self.feature = Native.Feature()
        self.feature.parent = self
        self._children_name_map["feature"] = "Cisco-IOS-XE-switch:feature"

        self.openflow = Native.Openflow()
        self.openflow.parent = self
        self._children_name_map["openflow"] = "Cisco-IOS-XE-switch:openflow"

        self.et_analytics = None
        self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

        self.dialer = Native.Dialer()
        self.dialer.parent = self
        self._children_name_map["dialer"] = "Cisco-IOS-XE-cellular:dialer"

        self.utd = None
        self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

        self.utd_st = Native.UtdSt()
        self.utd_st.parent = self
        self._children_name_map["utd_st"] = "Cisco-IOS-XE-utd:utd-st"

        self.utd_mt = Native.UtdMt()
        self.utd_mt.parent = self
        self._children_name_map["utd_mt"] = "Cisco-IOS-XE-utd:utd-mt"

        self.fabric_group = Native.FabricGroup()
        self.fabric_group.parent = self
        self._children_name_map["fabric_group"] = "Cisco-IOS-XE-iwanfabric:fabric-group"

        self.coap = Native.Coap()
        self.coap.parent = self
        self._children_name_map["coap"] = "Cisco-IOS-XE-coap:coap"

        self.voice = Native.Voice()
        self.voice.parent = self
        self._children_name_map["voice"] = "Cisco-IOS-XE-voice:voice"

        self.power = Native.Power()
        self.power.parent = self
        self._children_name_map["power"] = "Cisco-IOS-XE-power:power"

        self.device_sensor = Native.DeviceSensor()
        self.device_sensor.parent = self
        self._children_name_map["device_sensor"] = "Cisco-IOS-XE-device-sensor:device-sensor"

        self.service_list = Native.ServiceList()
        self.service_list.parent = self
        self._children_name_map["service_list"] = "Cisco-IOS-XE-service-discovery:service-list"

        self.access_session = Native.AccessSession()
        self.access_session.parent = self
        self._children_name_map["access_session"] = "Cisco-IOS-XE-sanet:access-session"

        self.authentication = Native.Authentication()
        self.authentication.parent = self
        self._children_name_map["authentication"] = "Cisco-IOS-XE-sanet:authentication"

        self.service_routing = Native.ServiceRouting()
        self.service_routing.parent = self
        self._children_name_map["service_routing"] = "Cisco-IOS-XE-service-routing:service-routing"

        self.lldp = Native.Lldp()
        self.lldp.parent = self
        self._children_name_map["lldp"] = "Cisco-IOS-XE-lldp:lldp"

        self.diagnostic = Native.Diagnostic()
        self.diagnostic.parent = self
        self._children_name_map["diagnostic"] = "Cisco-IOS-XE-diagnostics:diagnostic"

        self.nat66 = Native.Nat66()
        self.nat66.parent = self
        self._children_name_map["nat66"] = "Cisco-IOS-XE-nat:nat66"

        self.bba_group = Native.BbaGroup()
        self.bba_group.parent = self
        self._children_name_map["bba_group"] = "Cisco-IOS-XE-bba-group:bba-group"

        self.shell = Native.Shell()
        self.shell.parent = self
        self._children_name_map["shell"] = "Cisco-IOS-XE-platform:shell"

        self.vstack = Native.Vstack()
        self.vstack.parent = self
        self._children_name_map["vstack"] = "Cisco-IOS-XE-vstack:vstack"

        self.pm_agent = None
        self._children_name_map["pm_agent"] = "Cisco-IOS-XE-pathmgr:pm-agent"

        self.vpdn = Native.Vpdn()
        self.vpdn.parent = self
        self._children_name_map["vpdn"] = "Cisco-IOS-XE-vpdn:vpdn"

        self.domain = YList(self)
        self.username = YList(self)
        self.sampler = YList(self)
        self.route_map = YList(self)
        self.table_map = YList(self)
        self.pseudowire_class = YList(self)
        self.tftp_server = YList(self)
        self.alarm_contact = YList(self)
        self.pfr_map = YList(self)
        self.virtual_service = YList(self)
        self.time_range = YList(self)
        self.service_template = YList(self)
        self.switch = YList(self)
        self.switch_virtual = YList(self)
        self.dialer_list = YList(self)
        self.voice_card = YList(self)
        self.maintenance_template = YList(self)
        self._segment_path = lambda: "Cisco-IOS-XE-native:native"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Native, [u'version', u'boot_start_marker', u'boot_end_marker', u'captive_portal_bypass', u'hostname', u'aqm_register_fnf', u'config_register', u'disable_eadi'], name, value)


    class Default(Entity):
        """
        Set a command to its defaults
        
        .. attribute:: crypto
        
        	Encryption module
        	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Default.Crypto>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Default, self).__init__()

            self.yang_name = "default"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("crypto", ("crypto", Native.Default.Crypto))])
            self._leafs = OrderedDict()

            self.crypto = Native.Default.Crypto()
            self.crypto.parent = self
            self._children_name_map["crypto"] = "crypto"
            self._segment_path = lambda: "default"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Default, [], name, value)


        class Crypto(Entity):
            """
            Encryption module
            
            .. attribute:: ikev2
            
            	Configure IKEv2 Options
            	**type**\:  :py:class:`Ikev2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Default.Crypto.Ikev2>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Default.Crypto, self).__init__()

                self.yang_name = "crypto"
                self.yang_parent_name = "default"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ikev2", ("ikev2", Native.Default.Crypto.Ikev2))])
                self._leafs = OrderedDict()

                self.ikev2 = Native.Default.Crypto.Ikev2()
                self.ikev2.parent = self
                self._children_name_map["ikev2"] = "ikev2"
                self._segment_path = lambda: "crypto"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/default/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Default.Crypto, [], name, value)


            class Ikev2(Entity):
                """
                Configure IKEv2 Options
                
                .. attribute:: proposal
                
                	Define IKEV2 proposals
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: policy
                
                	Define IKEV2 policies
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Default.Crypto.Ikev2, self).__init__()

                    self.yang_name = "ikev2"
                    self.yang_parent_name = "crypto"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('proposal', (YLeaf(YType.empty, 'proposal'), ['Empty'])),
                        ('policy', (YLeaf(YType.empty, 'policy'), ['Empty'])),
                    ])
                    self.proposal = None
                    self.policy = None
                    self._segment_path = lambda: "ikev2"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/default/crypto/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Default.Crypto.Ikev2, [u'proposal', u'policy'], name, value)


    class Bfd(Entity):
        """
        BFD configuration commands
        
        .. attribute:: l2cos
        
        	Value of L2 COS for BFD Pkts over VLAN interfaces
        	**type**\: int
        
        	**range:** 0..6
        
        .. attribute:: map
        
        	configure bfd map entry for multi\-hop sessions
        	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map>`
        
        .. attribute:: slow_timers
        
        	Value in ms to use for slow timers
        	**type**\: int
        
        	**range:** 1000..30000
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Bfd, self).__init__()

            self.yang_name = "bfd"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:map", ("map", Native.Bfd.Map))])
            self._leafs = OrderedDict([
                ('l2cos', (YLeaf(YType.uint8, 'Cisco-IOS-XE-bfd:l2cos'), ['int'])),
                ('slow_timers', (YLeaf(YType.uint16, 'Cisco-IOS-XE-bfd:slow-timers'), ['int'])),
            ])
            self.l2cos = None
            self.slow_timers = None

            self.map = Native.Bfd.Map()
            self.map.parent = self
            self._children_name_map["map"] = "Cisco-IOS-XE-bfd:map"
            self._segment_path = lambda: "bfd"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Bfd, ['l2cos', 'slow_timers'], name, value)


        class Map(Entity):
            """
            configure bfd map entry for multi\-hop sessions
            
            .. attribute:: ipv4
            
            	IPv4 Address Family
            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map.Ipv4>`
            
            .. attribute:: ipv6
            
            	IPv6 Address Family
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map.Ipv6>`
            
            

            """

            _prefix = 'ios-bfd'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Bfd.Map, self).__init__()

                self.yang_name = "map"
                self.yang_parent_name = "bfd"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Bfd.Map.Ipv4)), ("ipv6", ("ipv6", Native.Bfd.Map.Ipv6))])
                self._leafs = OrderedDict()

                self.ipv4 = Native.Bfd.Map.Ipv4()
                self.ipv4.parent = self
                self._children_name_map["ipv4"] = "ipv4"

                self.ipv6 = Native.Bfd.Map.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"
                self._segment_path = lambda: "Cisco-IOS-XE-bfd:map"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bfd/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Bfd.Map, [], name, value)


            class Ipv4(Entity):
                """
                IPv4 Address Family
                
                .. attribute:: no_vrf
                
                	
                	**type**\:  :py:class:`NoVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map.Ipv4.NoVrf>`
                
                .. attribute:: vrf
                
                	Destination VRF name
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map.Ipv4.Vrf>`
                
                

                """

                _prefix = 'ios-bfd'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Bfd.Map.Ipv4, self).__init__()

                    self.yang_name = "ipv4"
                    self.yang_parent_name = "map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("no-vrf", ("no_vrf", Native.Bfd.Map.Ipv4.NoVrf)), ("vrf", ("vrf", Native.Bfd.Map.Ipv4.Vrf))])
                    self._leafs = OrderedDict()

                    self.no_vrf = Native.Bfd.Map.Ipv4.NoVrf()
                    self.no_vrf.parent = self
                    self._children_name_map["no_vrf"] = "no-vrf"

                    self.vrf = Native.Bfd.Map.Ipv4.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._segment_path = lambda: "ipv4"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bfd/Cisco-IOS-XE-bfd:map/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Bfd.Map.Ipv4, [], name, value)


                class NoVrf(Entity):
                    """
                    
                    
                    .. attribute:: dest_ip
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                    
                    .. attribute:: src_ip
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Bfd.Map.Ipv4.NoVrf, self).__init__()

                        self.yang_name = "no-vrf"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dest_ip', (YLeaf(YType.str, 'dest-ip'), ['str'])),
                            ('src_ip', (YLeaf(YType.str, 'src-ip'), ['str'])),
                            ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                        ])
                        self.dest_ip = None
                        self.src_ip = None
                        self.template_name = None
                        self._segment_path = lambda: "no-vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bfd/Cisco-IOS-XE-bfd:map/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Bfd.Map.Ipv4.NoVrf, ['dest_ip', 'src_ip', 'template_name'], name, value)


                class Vrf(Entity):
                    """
                    Destination VRF name
                    
                    .. attribute:: dst_vrf
                    
                    	
                    	**type**\: list of  		 :py:class:`DstVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map.Ipv4.Vrf.DstVrf>`
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Bfd.Map.Ipv4.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dst-vrf", ("dst_vrf", Native.Bfd.Map.Ipv4.Vrf.DstVrf))])
                        self._leafs = OrderedDict()

                        self.dst_vrf = YList(self)
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bfd/Cisco-IOS-XE-bfd:map/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Bfd.Map.Ipv4.Vrf, [], name, value)


                    class DstVrf(Entity):
                        """
                        
                        
                        .. attribute:: dst_vrf  (key)
                        
                        	Destination VRF instance name
                        	**type**\: str
                        
                        .. attribute:: a_period_b_period_c_period_d_slash_nn
                        
                        	Destination IP prefix/len
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-bfd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Bfd.Map.Ipv4.Vrf.DstVrf, self).__init__()

                            self.yang_name = "dst-vrf"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['dst_vrf']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dst_vrf', (YLeaf(YType.str, 'dst-vrf'), ['str'])),
                                ('a_period_b_period_c_period_d_slash_nn', (YLeaf(YType.empty, 'A_PERIOD_B_PERIOD_C_PERIOD_D_SLASH_nn'), ['Empty'])),
                            ])
                            self.dst_vrf = None
                            self.a_period_b_period_c_period_d_slash_nn = None
                            self._segment_path = lambda: "dst-vrf" + "[dst-vrf='" + str(self.dst_vrf) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bfd/Cisco-IOS-XE-bfd:map/ipv4/vrf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Bfd.Map.Ipv4.Vrf.DstVrf, ['dst_vrf', 'a_period_b_period_c_period_d_slash_nn'], name, value)


            class Ipv6(Entity):
                """
                IPv6 Address Family
                
                .. attribute:: dp_ipv6_prefix
                
                	
                	**type**\: list of  		 :py:class:`DpIpv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map.Ipv6.DpIpv6Prefix>`
                
                .. attribute:: vrf
                
                	Destination VRF name
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map.Ipv6.Vrf>`
                
                

                """

                _prefix = 'ios-bfd'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Bfd.Map.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dp-ipv6_prefix", ("dp_ipv6_prefix", Native.Bfd.Map.Ipv6.DpIpv6Prefix)), ("vrf", ("vrf", Native.Bfd.Map.Ipv6.Vrf))])
                    self._leafs = OrderedDict()

                    self.vrf = Native.Bfd.Map.Ipv6.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.dp_ipv6_prefix = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bfd/Cisco-IOS-XE-bfd:map/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Bfd.Map.Ipv6, [], name, value)


                class DpIpv6Prefix(Entity):
                    """
                    
                    
                    .. attribute:: dp_ipv6_prefix  (key)
                    
                    	Destination IPv6 prefix/len
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    .. attribute:: bfd_nm
                    
                    	bfd template name
                    	**type**\: str
                    
                    .. attribute:: src_ipv6_prefix0
                    
                    	
                    	**type**\: list of  		 :py:class:`SrcIpv6Prefix0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map.Ipv6.DpIpv6Prefix.SrcIpv6Prefix0>`
                    
                    .. attribute:: vrf
                    
                    	Source VRF name
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map.Ipv6.DpIpv6Prefix.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Bfd.Map.Ipv6.DpIpv6Prefix, self).__init__()

                        self.yang_name = "dp-ipv6_prefix"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['dp_ipv6_prefix']
                        self._child_classes = OrderedDict([("src-ipv6_prefix0", ("src_ipv6_prefix0", Native.Bfd.Map.Ipv6.DpIpv6Prefix.SrcIpv6Prefix0)), ("vrf", ("vrf", Native.Bfd.Map.Ipv6.DpIpv6Prefix.Vrf))])
                        self._leafs = OrderedDict([
                            ('dp_ipv6_prefix', (YLeaf(YType.str, 'dp-ipv6_prefix'), ['str'])),
                            ('bfd_nm', (YLeaf(YType.str, 'bfd-nm'), ['str'])),
                        ])
                        self.dp_ipv6_prefix = None
                        self.bfd_nm = None

                        self.vrf = Native.Bfd.Map.Ipv6.DpIpv6Prefix.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.src_ipv6_prefix0 = YList(self)
                        self._segment_path = lambda: "dp-ipv6_prefix" + "[dp-ipv6_prefix='" + str(self.dp_ipv6_prefix) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bfd/Cisco-IOS-XE-bfd:map/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Bfd.Map.Ipv6.DpIpv6Prefix, ['dp_ipv6_prefix', 'bfd_nm'], name, value)


                    class SrcIpv6Prefix0(Entity):
                        """
                        
                        
                        .. attribute:: src_ipv6_prefix0  (key)
                        
                        	Source IPv6 prefix/len
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: bfd_name
                        
                        	bfd template name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bfd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Bfd.Map.Ipv6.DpIpv6Prefix.SrcIpv6Prefix0, self).__init__()

                            self.yang_name = "src-ipv6_prefix0"
                            self.yang_parent_name = "dp-ipv6_prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['src_ipv6_prefix0']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('src_ipv6_prefix0', (YLeaf(YType.str, 'src-ipv6_prefix0'), ['str'])),
                                ('bfd_name', (YLeaf(YType.str, 'bfd-name'), ['str'])),
                            ])
                            self.src_ipv6_prefix0 = None
                            self.bfd_name = None
                            self._segment_path = lambda: "src-ipv6_prefix0" + "[src-ipv6_prefix0='" + str(self.src_ipv6_prefix0) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Bfd.Map.Ipv6.DpIpv6Prefix.SrcIpv6Prefix0, ['src_ipv6_prefix0', 'bfd_name'], name, value)


                    class Vrf(Entity):
                        """
                        Source VRF name
                        
                        .. attribute:: src_vrf
                        
                        	
                        	**type**\: list of  		 :py:class:`SrcVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map.Ipv6.DpIpv6Prefix.Vrf.SrcVrf>`
                        
                        

                        """

                        _prefix = 'ios-bfd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Bfd.Map.Ipv6.DpIpv6Prefix.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "dp-ipv6_prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("src-vrf", ("src_vrf", Native.Bfd.Map.Ipv6.DpIpv6Prefix.Vrf.SrcVrf))])
                            self._leafs = OrderedDict()

                            self.src_vrf = YList(self)
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Bfd.Map.Ipv6.DpIpv6Prefix.Vrf, [], name, value)


                        class SrcVrf(Entity):
                            """
                            
                            
                            .. attribute:: src_vrf  (key)
                            
                            	Source VRF instance name
                            	**type**\: str
                            
                            .. attribute:: src_ipv6_prefix
                            
                            	Source IPv6 prefix/len
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            

                            """

                            _prefix = 'ios-bfd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Bfd.Map.Ipv6.DpIpv6Prefix.Vrf.SrcVrf, self).__init__()

                                self.yang_name = "src-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['src_vrf']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('src_vrf', (YLeaf(YType.str, 'src-vrf'), ['str'])),
                                    ('src_ipv6_prefix', (YLeaf(YType.str, 'src-ipv6_prefix'), ['str'])),
                                ])
                                self.src_vrf = None
                                self.src_ipv6_prefix = None
                                self._segment_path = lambda: "src-vrf" + "[src-vrf='" + str(self.src_vrf) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Bfd.Map.Ipv6.DpIpv6Prefix.Vrf.SrcVrf, ['src_vrf', 'src_ipv6_prefix'], name, value)


                class Vrf(Entity):
                    """
                    Destination VRF name
                    
                    .. attribute:: dst_vrf
                    
                    	
                    	**type**\: list of  		 :py:class:`DstVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Bfd.Map.Ipv6.Vrf.DstVrf>`
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Bfd.Map.Ipv6.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dst-vrf", ("dst_vrf", Native.Bfd.Map.Ipv6.Vrf.DstVrf))])
                        self._leafs = OrderedDict()

                        self.dst_vrf = YList(self)
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bfd/Cisco-IOS-XE-bfd:map/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Bfd.Map.Ipv6.Vrf, [], name, value)


                    class DstVrf(Entity):
                        """
                        
                        
                        .. attribute:: dst_vrf  (key)
                        
                        	Destination VRF instance name
                        	**type**\: str
                        
                        .. attribute:: dst_ipv6_prefix
                        
                        	Destination IPv6 prefix/len
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        

                        """

                        _prefix = 'ios-bfd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Bfd.Map.Ipv6.Vrf.DstVrf, self).__init__()

                            self.yang_name = "dst-vrf"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['dst_vrf']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dst_vrf', (YLeaf(YType.str, 'dst-vrf'), ['str'])),
                                ('dst_ipv6_prefix', (YLeaf(YType.str, 'dst-ipv6_prefix'), ['str'])),
                            ])
                            self.dst_vrf = None
                            self.dst_ipv6_prefix = None
                            self._segment_path = lambda: "dst-vrf" + "[dst-vrf='" + str(self.dst_vrf) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bfd/Cisco-IOS-XE-bfd:map/ipv6/vrf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Bfd.Map.Ipv6.Vrf.DstVrf, ['dst_vrf', 'dst_ipv6_prefix'], name, value)


    class StackwiseVirtual(Entity):
        """
        Enter stackwise\-virtual configuration mode
        
        .. attribute:: domain
        
        	Set the Stackwise Virtual switch domain number
        	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.StackwiseVirtual.Domain>`
        
        .. attribute:: dual_active
        
        	Stackwise Virtual dual active detection
        	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.StackwiseVirtual.DualActive>`
        
        

        This class is a :ref:`presence class<presence-class>`

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.StackwiseVirtual, self).__init__()

            self.yang_name = "stackwise-virtual"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-stackwise-virtual:domain", ("domain", Native.StackwiseVirtual.Domain)), ("Cisco-IOS-XE-stackwise-virtual:dual-active", ("dual_active", Native.StackwiseVirtual.DualActive))])
            self.is_presence_container = True
            self._leafs = OrderedDict()

            self.domain = Native.StackwiseVirtual.Domain()
            self.domain.parent = self
            self._children_name_map["domain"] = "Cisco-IOS-XE-stackwise-virtual:domain"

            self.dual_active = Native.StackwiseVirtual.DualActive()
            self.dual_active.parent = self
            self._children_name_map["dual_active"] = "Cisco-IOS-XE-stackwise-virtual:dual-active"
            self._segment_path = lambda: "stackwise-virtual"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.StackwiseVirtual, [], name, value)


        class Domain(Entity):
            """
            Set the Stackwise Virtual switch domain number
            
            .. attribute:: domain
            
            	
            	**type**\: int
            
            	**range:** 1..255
            
            

            """

            _prefix = 'ios-stackwise-virtual'
            _revision = '2017-06-05'

            def __init__(self):
                super(Native.StackwiseVirtual.Domain, self).__init__()

                self.yang_name = "domain"
                self.yang_parent_name = "stackwise-virtual"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('domain', (YLeaf(YType.uint16, 'domain'), ['int'])),
                ])
                self.domain = None
                self._segment_path = lambda: "Cisco-IOS-XE-stackwise-virtual:domain"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/stackwise-virtual/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.StackwiseVirtual.Domain, ['domain'], name, value)


        class DualActive(Entity):
            """
            Stackwise Virtual dual active detection
            
            .. attribute:: detection
            
            	Stackwise Virtual dual active detection configuration
            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.StackwiseVirtual.DualActive.Detection>`
            
            

            """

            _prefix = 'ios-stackwise-virtual'
            _revision = '2017-06-05'

            def __init__(self):
                super(Native.StackwiseVirtual.DualActive, self).__init__()

                self.yang_name = "dual-active"
                self.yang_parent_name = "stackwise-virtual"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("detection", ("detection", Native.StackwiseVirtual.DualActive.Detection))])
                self._leafs = OrderedDict()

                self.detection = Native.StackwiseVirtual.DualActive.Detection()
                self.detection.parent = self
                self._children_name_map["detection"] = "detection"
                self._segment_path = lambda: "Cisco-IOS-XE-stackwise-virtual:dual-active"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/stackwise-virtual/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.StackwiseVirtual.DualActive, [], name, value)


            class Detection(Entity):
                """
                Stackwise Virtual dual active detection configuration
                
                .. attribute:: pagp
                
                	Dual\-active detection using PAgP
                	**type**\:  :py:class:`Pagp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.StackwiseVirtual.DualActive.Detection.Pagp>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-stackwise-virtual'
                _revision = '2017-06-05'

                def __init__(self):
                    super(Native.StackwiseVirtual.DualActive.Detection, self).__init__()

                    self.yang_name = "detection"
                    self.yang_parent_name = "dual-active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("pagp", ("pagp", Native.StackwiseVirtual.DualActive.Detection.Pagp))])
                    self._leafs = OrderedDict()

                    self.pagp = None
                    self._children_name_map["pagp"] = "pagp"
                    self._segment_path = lambda: "detection"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/stackwise-virtual/Cisco-IOS-XE-stackwise-virtual:dual-active/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.StackwiseVirtual.DualActive.Detection, [], name, value)


                class Pagp(Entity):
                    """
                    Dual\-active detection using PAgP
                    
                    .. attribute:: trust
                    
                    	Trusted channels for PAgP dual\-active detection
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.StackwiseVirtual.DualActive.Detection.Pagp.Trust>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-stackwise-virtual'
                    _revision = '2017-06-05'

                    def __init__(self):
                        super(Native.StackwiseVirtual.DualActive.Detection.Pagp, self).__init__()

                        self.yang_name = "pagp"
                        self.yang_parent_name = "detection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("trust", ("trust", Native.StackwiseVirtual.DualActive.Detection.Pagp.Trust))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.trust = Native.StackwiseVirtual.DualActive.Detection.Pagp.Trust()
                        self.trust.parent = self
                        self._children_name_map["trust"] = "trust"
                        self._segment_path = lambda: "pagp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/stackwise-virtual/Cisco-IOS-XE-stackwise-virtual:dual-active/detection/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.StackwiseVirtual.DualActive.Detection.Pagp, [], name, value)


                    class Trust(Entity):
                        """
                        Trusted channels for PAgP dual\-active detection
                        
                        .. attribute:: channel_group
                        
                        	Etherchannel/port bundle to be used for pagp dual\-active detection
                        	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.StackwiseVirtual.DualActive.Detection.Pagp.Trust.ChannelGroup>`
                        
                        

                        """

                        _prefix = 'ios-stackwise-virtual'
                        _revision = '2017-06-05'

                        def __init__(self):
                            super(Native.StackwiseVirtual.DualActive.Detection.Pagp.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "pagp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("channel-group", ("channel_group", Native.StackwiseVirtual.DualActive.Detection.Pagp.Trust.ChannelGroup))])
                            self._leafs = OrderedDict()

                            self.channel_group = Native.StackwiseVirtual.DualActive.Detection.Pagp.Trust.ChannelGroup()
                            self.channel_group.parent = self
                            self._children_name_map["channel_group"] = "channel-group"
                            self._segment_path = lambda: "trust"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/stackwise-virtual/Cisco-IOS-XE-stackwise-virtual:dual-active/detection/pagp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.StackwiseVirtual.DualActive.Detection.Pagp.Trust, [], name, value)


                        class ChannelGroup(Entity):
                            """
                            Etherchannel/port bundle to be used for pagp dual\-active detection
                            
                            .. attribute:: channel_group_number
                            
                            	Percent range from 1 to 128
                            	**type**\: int
                            
                            	**range:** 1..128
                            
                            

                            """

                            _prefix = 'ios-stackwise-virtual'
                            _revision = '2017-06-05'

                            def __init__(self):
                                super(Native.StackwiseVirtual.DualActive.Detection.Pagp.Trust.ChannelGroup, self).__init__()

                                self.yang_name = "channel-group"
                                self.yang_parent_name = "trust"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('channel_group_number', (YLeaf(YType.uint16, 'channel-group-number'), ['int'])),
                                ])
                                self.channel_group_number = None
                                self._segment_path = lambda: "channel-group"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/stackwise-virtual/Cisco-IOS-XE-stackwise-virtual:dual-active/detection/pagp/trust/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.StackwiseVirtual.DualActive.Detection.Pagp.Trust.ChannelGroup, ['channel_group_number'], name, value)


    class Boot(Entity):
        """
        Modify boot system parameters
        
        .. attribute:: system
        
        	System Image
        	**type**\:  :py:class:`System <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Boot.System>`
        
        .. attribute:: enable_break
        
        	Enable break
        	**type**\:  :py:class:`EnableBreak <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Boot.EnableBreak>`
        
        	**presence node**\: True
        
        .. attribute:: manual
        
        	Manual boot
        	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Boot.Manual>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Boot, self).__init__()

            self.yang_name = "boot"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("system", ("system", Native.Boot.System)), ("Cisco-IOS-XE-switch:enable-break", ("enable_break", Native.Boot.EnableBreak)), ("Cisco-IOS-XE-switch:manual", ("manual", Native.Boot.Manual))])
            self._leafs = OrderedDict()

            self.system = Native.Boot.System()
            self.system.parent = self
            self._children_name_map["system"] = "system"

            self.enable_break = None
            self._children_name_map["enable_break"] = "Cisco-IOS-XE-switch:enable-break"

            self.manual = None
            self._children_name_map["manual"] = "Cisco-IOS-XE-switch:manual"
            self._segment_path = lambda: "boot"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Boot, [], name, value)


        class System(Entity):
            """
            System Image
            
            .. attribute:: tftp_path
            
            	Example\: 192.x.x.x/<path to image>
            	**type**\: str
            
            .. attribute:: tftp
            
            	Example 192.168.x.x/<image\-path>
            	**type**\: str
            
            .. attribute:: bootfile
            
            	WORD \- boot filename
            	**type**\:  :py:class:`Bootfile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Boot.System.Bootfile>`
            
            .. attribute:: flash
            
            	flash \- Boot from flash memory
            	**type**\:  :py:class:`Flash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Boot.System.Flash>`
            
            .. attribute:: switch
            
            	Set system image for switches in the stack
            	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Boot.System.Switch>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Boot.System, self).__init__()

                self.yang_name = "system"
                self.yang_parent_name = "boot"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("bootfile", ("bootfile", Native.Boot.System.Bootfile)), ("flash", ("flash", Native.Boot.System.Flash)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Boot.System.Switch))])
                self._leafs = OrderedDict([
                    ('tftp_path', (YLeaf(YType.str, 'tftp-path'), ['str'])),
                    ('tftp', (YLeaf(YType.str, 'tftp'), ['str'])),
                ])
                self.tftp_path = None
                self.tftp = None

                self.bootfile = Native.Boot.System.Bootfile()
                self.bootfile.parent = self
                self._children_name_map["bootfile"] = "bootfile"

                self.flash = Native.Boot.System.Flash()
                self.flash.parent = self
                self._children_name_map["flash"] = "flash"

                self.switch = Native.Boot.System.Switch()
                self.switch.parent = self
                self._children_name_map["switch"] = "Cisco-IOS-XE-switch:switch"
                self._segment_path = lambda: "system"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/boot/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Boot.System, [u'tftp_path', u'tftp'], name, value)


            class Bootfile(Entity):
                """
                WORD \- boot filename
                
                .. attribute:: filename_list
                
                	
                	**type**\: list of  		 :py:class:`FilenameList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Boot.System.Bootfile.FilenameList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Boot.System.Bootfile, self).__init__()

                    self.yang_name = "bootfile"
                    self.yang_parent_name = "system"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("filename-list", ("filename_list", Native.Boot.System.Bootfile.FilenameList))])
                    self._leafs = OrderedDict()

                    self.filename_list = YList(self)
                    self._segment_path = lambda: "bootfile"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/boot/system/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Boot.System.Bootfile, [], name, value)


                class FilenameList(Entity):
                    """
                    
                    
                    .. attribute:: filename  (key)
                    
                    	WORD \- TFTP filename or URL
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Boot.System.Bootfile.FilenameList, self).__init__()

                        self.yang_name = "filename-list"
                        self.yang_parent_name = "bootfile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['filename']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('filename', (YLeaf(YType.str, 'filename'), ['str'])),
                        ])
                        self.filename = None
                        self._segment_path = lambda: "filename-list" + "[filename='" + str(self.filename) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/boot/system/bootfile/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Boot.System.Bootfile.FilenameList, [u'filename'], name, value)


            class Flash(Entity):
                """
                flash \- Boot from flash memory
                
                .. attribute:: flash_list
                
                	
                	**type**\: list of  		 :py:class:`FlashList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Boot.System.Flash.FlashList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Boot.System.Flash, self).__init__()

                    self.yang_name = "flash"
                    self.yang_parent_name = "system"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flash-list", ("flash_list", Native.Boot.System.Flash.FlashList))])
                    self._leafs = OrderedDict()

                    self.flash_list = YList(self)
                    self._segment_path = lambda: "flash"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/boot/system/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Boot.System.Flash, [], name, value)


                class FlashList(Entity):
                    """
                    
                    
                    .. attribute:: flash_leaf  (key)
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Boot.System.Flash.FlashList, self).__init__()

                        self.yang_name = "flash-list"
                        self.yang_parent_name = "flash"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['flash_leaf']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('flash_leaf', (YLeaf(YType.str, 'flash-leaf'), ['str'])),
                        ])
                        self.flash_leaf = None
                        self._segment_path = lambda: "flash-list" + "[flash-leaf='" + str(self.flash_leaf) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/boot/system/flash/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Boot.System.Flash.FlashList, [u'flash_leaf'], name, value)


            class Switch(Entity):
                """
                Set system image for switches in the stack
                
                .. attribute:: switch_number
                
                	
                	**type**\: list of  		 :py:class:`SwitchNumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Boot.System.Switch.SwitchNumber>`
                
                .. attribute:: all
                
                	Set system image for all switches in the stack
                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Boot.System.Switch.All>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Boot.System.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "system"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("switch-number", ("switch_number", Native.Boot.System.Switch.SwitchNumber)), ("all", ("all", Native.Boot.System.Switch.All))])
                    self._leafs = OrderedDict()

                    self.all = Native.Boot.System.Switch.All()
                    self.all.parent = self
                    self._children_name_map["all"] = "all"

                    self.switch_number = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:switch"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/boot/system/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Boot.System.Switch, [], name, value)


                class SwitchNumber(Entity):
                    """
                    
                    
                    .. attribute:: range  (key)
                    
                    	Switch number
                    	**type**\: int
                    
                    	**range:** 1..9
                    
                    .. attribute:: flash_1_path
                    
                    	Example edison.bin
                    	**type**\: str
                    
                    .. attribute:: flash_path
                    
                    	Example edison.bin
                    	**type**\: str
                    
                    .. attribute:: tftp_path
                    
                    	Example 192.x.x.x/<path>
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Boot.System.Switch.SwitchNumber, self).__init__()

                        self.yang_name = "switch-number"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                            ('flash_1_path', (YLeaf(YType.str, 'flash-1-path'), ['str'])),
                            ('flash_path', (YLeaf(YType.str, 'flash-path'), ['str'])),
                            ('tftp_path', (YLeaf(YType.str, 'tftp-path'), ['str'])),
                        ])
                        self.range = None
                        self.flash_1_path = None
                        self.flash_path = None
                        self.tftp_path = None
                        self._segment_path = lambda: "switch-number" + "[range='" + str(self.range) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/boot/system/Cisco-IOS-XE-switch:switch/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Boot.System.Switch.SwitchNumber, [u'range', u'flash_1_path', u'flash_path', u'tftp_path'], name, value)


                class All(Entity):
                    """
                    Set system image for all switches in the stack
                    
                    .. attribute:: flash_1
                    
                    	Example edison.bin
                    	**type**\: str
                    
                    .. attribute:: flash
                    
                    	Example edison.bin
                    	**type**\: str
                    
                    .. attribute:: tftp
                    
                    	Example 192.x.x.x/<image\-path>
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Boot.System.Switch.All, self).__init__()

                        self.yang_name = "all"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('flash_1', (YLeaf(YType.str, 'flash-1'), ['str'])),
                            ('flash', (YLeaf(YType.str, 'flash'), ['str'])),
                            ('tftp', (YLeaf(YType.str, 'tftp'), ['str'])),
                        ])
                        self.flash_1 = None
                        self.flash = None
                        self.tftp = None
                        self._segment_path = lambda: "all"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/boot/system/Cisco-IOS-XE-switch:switch/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Boot.System.Switch.All, [u'flash_1', u'flash', u'tftp'], name, value)


        class EnableBreak(Entity):
            """
            Enable break
            
            .. attribute:: switch
            
            	Set enable break for switches in the stack
            	**type**\: int
            
            	**range:** 1..9
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.Boot.EnableBreak, self).__init__()

                self.yang_name = "enable-break"
                self.yang_parent_name = "boot"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('switch', (YLeaf(YType.uint8, 'switch'), ['int'])),
                ])
                self.switch = None
                self._segment_path = lambda: "Cisco-IOS-XE-switch:enable-break"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/boot/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Boot.EnableBreak, [u'switch'], name, value)


        class Manual(Entity):
            """
            Manual boot
            
            .. attribute:: switch
            
            	Set manual boot for switches in the stack\:Switch number(s)
            	**type**\: int
            
            	**range:** 1..9
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.Boot.Manual, self).__init__()

                self.yang_name = "manual"
                self.yang_parent_name = "boot"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('switch', (YLeaf(YType.uint8, 'switch'), ['int'])),
                ])
                self.switch = None
                self._segment_path = lambda: "Cisco-IOS-XE-switch:manual"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/boot/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Boot.Manual, [u'switch'], name, value)


    class Banner(Entity):
        """
        Define a login banner
        
        .. attribute:: exec_
        
        	Set EXEC process creation banner
        	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Banner.Exec>`
        
        .. attribute:: login
        
        	Set login banner
        	**type**\:  :py:class:`Login <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Banner.Login>`
        
        .. attribute:: prompt_timeout
        
        	Set Message for login authentication timeout
        	**type**\:  :py:class:`PromptTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Banner.PromptTimeout>`
        
        .. attribute:: motd
        
        	Set Message of the Day banner
        	**type**\:  :py:class:`Motd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Banner.Motd>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Banner, self).__init__()

            self.yang_name = "banner"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("exec", ("exec_", Native.Banner.Exec)), ("login", ("login", Native.Banner.Login)), ("prompt-timeout", ("prompt_timeout", Native.Banner.PromptTimeout)), ("motd", ("motd", Native.Banner.Motd))])
            self._leafs = OrderedDict()

            self.exec_ = Native.Banner.Exec()
            self.exec_.parent = self
            self._children_name_map["exec_"] = "exec"

            self.login = Native.Banner.Login()
            self.login.parent = self
            self._children_name_map["login"] = "login"

            self.prompt_timeout = Native.Banner.PromptTimeout()
            self.prompt_timeout.parent = self
            self._children_name_map["prompt_timeout"] = "prompt-timeout"

            self.motd = Native.Banner.Motd()
            self.motd.parent = self
            self._children_name_map["motd"] = "motd"
            self._segment_path = lambda: "banner"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Banner, [], name, value)


        class Exec(Entity):
            """
            Set EXEC process creation banner
            
            .. attribute:: banner
            
            	Banner message format, c banner\-text c, where 'c' is a delimiting character
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Banner.Exec, self).__init__()

                self.yang_name = "exec"
                self.yang_parent_name = "banner"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('banner', (YLeaf(YType.str, 'banner'), ['str'])),
                ])
                self.banner = None
                self._segment_path = lambda: "exec"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/banner/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Banner.Exec, [u'banner'], name, value)


        class Login(Entity):
            """
            Set login banner
            
            .. attribute:: banner
            
            	Banner message format, c banner\-text c, where 'c' is a delimiting character
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Banner.Login, self).__init__()

                self.yang_name = "login"
                self.yang_parent_name = "banner"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('banner', (YLeaf(YType.str, 'banner'), ['str'])),
                ])
                self.banner = None
                self._segment_path = lambda: "login"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/banner/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Banner.Login, [u'banner'], name, value)


        class PromptTimeout(Entity):
            """
            Set Message for login authentication timeout
            
            .. attribute:: banner
            
            	Banner message format, c banner\-text c, where 'c' is a delimiting character
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Banner.PromptTimeout, self).__init__()

                self.yang_name = "prompt-timeout"
                self.yang_parent_name = "banner"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('banner', (YLeaf(YType.str, 'banner'), ['str'])),
                ])
                self.banner = None
                self._segment_path = lambda: "prompt-timeout"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/banner/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Banner.PromptTimeout, [u'banner'], name, value)


        class Motd(Entity):
            """
            Set Message of the Day banner
            
            .. attribute:: banner
            
            	Banner message format, c banner\-text c, where 'c' is a delimiting character
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Banner.Motd, self).__init__()

                self.yang_name = "motd"
                self.yang_parent_name = "banner"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('banner', (YLeaf(YType.str, 'banner'), ['str'])),
                ])
                self.banner = None
                self._segment_path = lambda: "motd"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/banner/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Banner.Motd, [u'banner'], name, value)


    class Memory(Entity):
        """
        Configure memory management
        
        .. attribute:: statistics
        
        	Configure statistics history table
        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Memory.Statistics>`
        
        .. attribute:: chunk
        
        	chunk related configuration
        	**type**\:  :py:class:`Chunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Memory.Chunk>`
        
        .. attribute:: free
        
        	free memory low water mark
        	**type**\:  :py:class:`Free <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Memory.Free>`
        
        .. attribute:: lite
        
        	Enable/disable memory lite
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: reserve
        
        	reserve memory
        	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Memory.Reserve>`
        
        .. attribute:: sanity
        
        	Enable memory sanity
        	**type**\:  :py:class:`Sanity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Memory.Sanity>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Memory, self).__init__()

            self.yang_name = "memory"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("statistics", ("statistics", Native.Memory.Statistics)), ("chunk", ("chunk", Native.Memory.Chunk)), ("free", ("free", Native.Memory.Free)), ("reserve", ("reserve", Native.Memory.Reserve)), ("sanity", ("sanity", Native.Memory.Sanity))])
            self._leafs = OrderedDict([
                ('lite', (YLeaf(YType.empty, 'lite'), ['Empty'])),
            ])
            self.lite = None

            self.statistics = Native.Memory.Statistics()
            self.statistics.parent = self
            self._children_name_map["statistics"] = "statistics"

            self.chunk = Native.Memory.Chunk()
            self.chunk.parent = self
            self._children_name_map["chunk"] = "chunk"

            self.free = Native.Memory.Free()
            self.free.parent = self
            self._children_name_map["free"] = "free"

            self.reserve = Native.Memory.Reserve()
            self.reserve.parent = self
            self._children_name_map["reserve"] = "reserve"

            self.sanity = None
            self._children_name_map["sanity"] = "sanity"
            self._segment_path = lambda: "memory"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Memory, [u'lite'], name, value)


        class Statistics(Entity):
            """
            Configure statistics history table
            
            .. attribute:: history
            
            	Configure statistics history table
            	**type**\:  :py:class:`History <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Memory.Statistics.History>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Memory.Statistics, self).__init__()

                self.yang_name = "statistics"
                self.yang_parent_name = "memory"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("history", ("history", Native.Memory.Statistics.History))])
                self._leafs = OrderedDict()

                self.history = Native.Memory.Statistics.History()
                self.history.parent = self
                self._children_name_map["history"] = "history"
                self._segment_path = lambda: "statistics"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/memory/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Memory.Statistics, [], name, value)


            class History(Entity):
                """
                Configure statistics history table
                
                .. attribute:: table
                
                	Configure statistics history table
                	**type**\: int
                
                	**range:** 12..72
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Memory.Statistics.History, self).__init__()

                    self.yang_name = "history"
                    self.yang_parent_name = "statistics"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('table', (YLeaf(YType.uint8, 'table'), ['int'])),
                    ])
                    self.table = None
                    self._segment_path = lambda: "history"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/memory/statistics/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Memory.Statistics.History, [u'table'], name, value)


        class Chunk(Entity):
            """
            chunk related configuration
            
            .. attribute:: siblings
            
            	chunk siblings related configuration
            	**type**\:  :py:class:`Siblings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Memory.Chunk.Siblings>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Memory.Chunk, self).__init__()

                self.yang_name = "chunk"
                self.yang_parent_name = "memory"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("siblings", ("siblings", Native.Memory.Chunk.Siblings))])
                self._leafs = OrderedDict()

                self.siblings = Native.Memory.Chunk.Siblings()
                self.siblings.parent = self
                self._children_name_map["siblings"] = "siblings"
                self._segment_path = lambda: "chunk"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/memory/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Memory.Chunk, [], name, value)


            class Siblings(Entity):
                """
                chunk siblings related configuration
                
                .. attribute:: threshold
                
                	Default is platform dependent
                	**type**\: int
                
                	**range:** 2..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Memory.Chunk.Siblings, self).__init__()

                    self.yang_name = "siblings"
                    self.yang_parent_name = "chunk"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                    ])
                    self.threshold = None
                    self._segment_path = lambda: "siblings"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/memory/chunk/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Memory.Chunk.Siblings, [u'threshold'], name, value)


        class Free(Entity):
            """
            free memory low water mark
            
            .. attribute:: low_watermark
            
            	low water mark for notifications
            	**type**\:  :py:class:`LowWatermark <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Memory.Free.LowWatermark>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Memory.Free, self).__init__()

                self.yang_name = "free"
                self.yang_parent_name = "memory"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("low-watermark", ("low_watermark", Native.Memory.Free.LowWatermark))])
                self._leafs = OrderedDict()

                self.low_watermark = Native.Memory.Free.LowWatermark()
                self.low_watermark.parent = self
                self._children_name_map["low_watermark"] = "low-watermark"
                self._segment_path = lambda: "free"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/memory/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Memory.Free, [], name, value)


            class LowWatermark(Entity):
                """
                low water mark for notifications
                
                .. attribute:: io
                
                	low water mark of memory in KB
                	**type**\: int
                
                	**range:** 1..3994575
                
                .. attribute:: processor
                
                	low water mark of memory in KB
                	**type**\: int
                
                	**range:** 1..3994575
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Memory.Free.LowWatermark, self).__init__()

                    self.yang_name = "low-watermark"
                    self.yang_parent_name = "free"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('io', (YLeaf(YType.uint32, 'IO'), ['int'])),
                        ('processor', (YLeaf(YType.uint32, 'processor'), ['int'])),
                    ])
                    self.io = None
                    self.processor = None
                    self._segment_path = lambda: "low-watermark"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/memory/free/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Memory.Free.LowWatermark, [u'io', u'processor'], name, value)


        class Reserve(Entity):
            """
            reserve memory
            
            .. attribute:: critical
            
            	Reserve Critical Memory
            	**type**\:  :py:class:`Critical <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Memory.Reserve.Critical>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Memory.Reserve, self).__init__()

                self.yang_name = "reserve"
                self.yang_parent_name = "memory"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("critical", ("critical", Native.Memory.Reserve.Critical))])
                self._leafs = OrderedDict()

                self.critical = None
                self._children_name_map["critical"] = "critical"
                self._segment_path = lambda: "reserve"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/memory/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Memory.Reserve, [], name, value)


            class Critical(Entity):
                """
                Reserve Critical Memory
                
                .. attribute:: memory_range
                
                	total amount of memory to be reserved in kilobytes
                	**type**\: int
                
                	**range:** 1..4294967295
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Memory.Reserve.Critical, self).__init__()

                    self.yang_name = "critical"
                    self.yang_parent_name = "reserve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('memory_range', (YLeaf(YType.uint32, 'memory-range'), ['int'])),
                    ])
                    self.memory_range = None
                    self._segment_path = lambda: "critical"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/memory/reserve/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Memory.Reserve.Critical, [u'memory_range'], name, value)


        class Sanity(Entity):
            """
            Enable memory sanity
            
            .. attribute:: all
            
            	Enable memory sanity all
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: buffer
            
            	Enable memory sanity buffer
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: queue
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Memory.Sanity, self).__init__()

                self.yang_name = "sanity"
                self.yang_parent_name = "memory"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                    ('buffer', (YLeaf(YType.empty, 'buffer'), ['Empty'])),
                    ('queue', (YLeaf(YType.empty, 'queue'), ['Empty'])),
                ])
                self.all = None
                self.buffer = None
                self.queue = None
                self._segment_path = lambda: "sanity"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/memory/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Memory.Sanity, [u'all', u'buffer', u'queue'], name, value)


    class Location(Entity):
        """
        Global location configuration commands
        
        .. attribute:: civic_location
        
        	Civic location information
        	**type**\:  :py:class:`CivicLocation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Location.CivicLocation>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Location, self).__init__()

            self.yang_name = "location"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("civic-location", ("civic_location", Native.Location.CivicLocation))])
            self._leafs = OrderedDict()

            self.civic_location = Native.Location.CivicLocation()
            self.civic_location.parent = self
            self._children_name_map["civic_location"] = "civic-location"
            self._segment_path = lambda: "location"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Location, [], name, value)


        class CivicLocation(Entity):
            """
            Civic location information
            
            .. attribute:: identifier
            
            	Set the identifier
            	**type**\: list of  		 :py:class:`Identifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Location.CivicLocation.Identifier>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Location.CivicLocation, self).__init__()

                self.yang_name = "civic-location"
                self.yang_parent_name = "location"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("identifier", ("identifier", Native.Location.CivicLocation.Identifier))])
                self._leafs = OrderedDict()

                self.identifier = YList(self)
                self._segment_path = lambda: "civic-location"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/location/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Location.CivicLocation, [], name, value)


            class Identifier(Entity):
                """
                Set the identifier
                
                .. attribute:: identifier  (key)
                
                	
                	**type**\: str
                
                .. attribute:: building
                
                	Building information
                	**type**\: str
                
                .. attribute:: floor
                
                	Floor number
                	**type**\: str
                
                .. attribute:: landmark
                
                	Landmark
                	**type**\: str
                
                .. attribute:: name
                
                	Resident name
                	**type**\: str
                
                .. attribute:: number
                
                	Street number
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Location.CivicLocation.Identifier, self).__init__()

                    self.yang_name = "identifier"
                    self.yang_parent_name = "civic-location"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['identifier']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('identifier', (YLeaf(YType.str, 'identifier'), ['str'])),
                        ('building', (YLeaf(YType.str, 'building'), ['str'])),
                        ('floor', (YLeaf(YType.str, 'floor'), ['str'])),
                        ('landmark', (YLeaf(YType.str, 'landmark'), ['str'])),
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('number', (YLeaf(YType.str, 'number'), ['str'])),
                    ])
                    self.identifier = None
                    self.building = None
                    self.floor = None
                    self.landmark = None
                    self.name = None
                    self.number = None
                    self._segment_path = lambda: "identifier" + "[identifier='" + str(self.identifier) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/location/civic-location/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Location.CivicLocation.Identifier, [u'identifier', u'building', u'floor', u'landmark', u'name', u'number'], name, value)


    class CallHome(Entity):
        """
        Enter call\-home configuration mode
        
        .. attribute:: contact_email_addr
        
        	Use email address
        	**type**\: str
        
        .. attribute:: source_interface
        
        	Source interface name to send call\-home messages using email
        	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.SourceInterface>`
        
        .. attribute:: http_proxy
        
        	Specify proxy server for http request
        	**type**\:  :py:class:`HttpProxy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.HttpProxy>`
        
        .. attribute:: profile
        
        	Enter call\-home profile configuration mode
        	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile>`
        
        

        This class is a :ref:`presence class<presence-class>`

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.CallHome, self).__init__()

            self.yang_name = "call-home"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-call-home:source-interface", ("source_interface", Native.CallHome.SourceInterface)), ("Cisco-IOS-XE-call-home:http-proxy", ("http_proxy", Native.CallHome.HttpProxy)), ("Cisco-IOS-XE-call-home:profile", ("profile", Native.CallHome.Profile))])
            self.is_presence_container = True
            self._leafs = OrderedDict([
                ('contact_email_addr', (YLeaf(YType.str, 'Cisco-IOS-XE-call-home:contact-email-addr'), ['str'])),
            ])
            self.contact_email_addr = None

            self.source_interface = Native.CallHome.SourceInterface()
            self.source_interface.parent = self
            self._children_name_map["source_interface"] = "Cisco-IOS-XE-call-home:source-interface"

            self.http_proxy = Native.CallHome.HttpProxy()
            self.http_proxy.parent = self
            self._children_name_map["http_proxy"] = "Cisco-IOS-XE-call-home:http-proxy"

            self.profile = YList(self)
            self._segment_path = lambda: "call-home"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.CallHome, ['contact_email_addr'], name, value)


        class SourceInterface(Entity):
            """
            Source interface name to send call\-home messages using email
            
            .. attribute:: appnav_compress
            
            	Service\-Context Virtual Interface Compress
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: appnav_uncompress
            
            	Service\-Context Virtual Interface UnCompress
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: atm
            
            	ATM interface
            	**type**\: str
            
            .. attribute:: atm_subinterface
            
            	
            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.SourceInterface.ATMSubinterface>`
            
            .. attribute:: atm_acr
            
            	ATM\-ACR interface
            	**type**\: str
            
            	**pattern:** [0\-9]
            
            .. attribute:: atm_acrsubinterface
            
            	
            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.SourceInterface.ATMACRsubinterface>`
            
            .. attribute:: bdi
            
            	Bridge\-Domain interface
            	**type**\: str
            
            .. attribute:: cem
            
            	CEM interface
            	**type**\: str
            
            	**pattern:** ([0\-9]/){2}[0\-9]
            
            .. attribute:: cem_acr
            
            	CEM\-ACR interface
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: embedded_service_engine
            
            	cisco embedded service engine module
            	**type**\: str
            
            .. attribute:: ethernet
            
            	IEEE 802.3
            	**type**\: str
            
            .. attribute:: fastethernet
            
            	FastEthernet IEEE 802.3
            	**type**\: str
            
            .. attribute:: gigabitethernet
            
            	GigabitEthernet IEEE 802.3z
            	**type**\: str
            
            .. attribute:: fivegigabitethernet
            
            	Five GigabitEthernet 
            	**type**\: str
            
            .. attribute:: twentyfivegige
            
            	Twenty Five GigabitEthernet 
            	**type**\: str
            
            .. attribute:: twogigabitethernet
            
            	Two GigabitEthernet 
            	**type**\: str
            
            .. attribute:: fortygigabitethernet
            
            	Forty GigabitEthernet 
            	**type**\: str
            
            .. attribute:: hundredgige
            
            	Hundred GigabitEthernet
            	**type**\: str
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol Virtual Interface
            	**type**\: str
            
            .. attribute:: lisp_subinterface
            
            	Locator/ID Separation Protocol Virtual Interface
            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.SourceInterface.LISPSubinterface>`
            
            .. attribute:: loopback
            
            	Loopback interface
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: multilink
            
            	Multilink\-group interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: nve
            
            	Network virtualization endpoint interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: overlay
            
            	Overlay interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: port_channel
            
            	Ethernet Channel of interfaces
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: port_channel_subinterface
            
            	
            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.SourceInterface.PortChannelSubinterface>`
            
            .. attribute:: pseudowire
            
            	Pseudowire Interface
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: sm
            
            	SM Interface
            	**type**\: str
            
            .. attribute:: cellular
            
            	Cellular Interface
            	**type**\: str
            
            .. attribute:: serial
            
            	Serial interface
            	**type**\: str
            
            .. attribute:: tengigabitethernet
            
            	Ten Gigabit Ethernet
            	**type**\: str
            
            .. attribute:: tunnel
            
            	Tunnel interface
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: virtual_template
            
            	Virtual Template interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: vlan
            
            	Iosxr Vlans
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: virtualportgroup
            
            	Virtual Port Group
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: vasileft
            
            	vasileft
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: vasiright
            
            	vasiright
            	**type**\: int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'ios-ch'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.CallHome.SourceInterface, self).__init__()

                self.yang_name = "source-interface"
                self.yang_parent_name = "call-home"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.CallHome.SourceInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.CallHome.SourceInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.CallHome.SourceInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.CallHome.SourceInterface.PortChannelSubinterface))])
                self._leafs = OrderedDict([
                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                ])
                self.appnav_compress = None
                self.appnav_uncompress = None
                self.atm = None
                self.atm_acr = None
                self.bdi = None
                self.cem = None
                self.cem_acr = None
                self.embedded_service_engine = None
                self.ethernet = None
                self.fastethernet = None
                self.gigabitethernet = None
                self.fivegigabitethernet = None
                self.twentyfivegige = None
                self.twogigabitethernet = None
                self.fortygigabitethernet = None
                self.hundredgige = None
                self.lisp = None
                self.loopback = None
                self.multilink = None
                self.nve = None
                self.overlay = None
                self.port_channel = None
                self.pseudowire = None
                self.sm = None
                self.cellular = None
                self.serial = None
                self.tengigabitethernet = None
                self.tunnel = None
                self.virtual_template = None
                self.vlan = None
                self.virtualportgroup = None
                self.vasileft = None
                self.vasiright = None

                self.atm_subinterface = Native.CallHome.SourceInterface.ATMSubinterface()
                self.atm_subinterface.parent = self
                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                self.atm_acrsubinterface = Native.CallHome.SourceInterface.ATMACRsubinterface()
                self.atm_acrsubinterface.parent = self
                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                self.lisp_subinterface = Native.CallHome.SourceInterface.LISPSubinterface()
                self.lisp_subinterface.parent = self
                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                self.port_channel_subinterface = Native.CallHome.SourceInterface.PortChannelSubinterface()
                self.port_channel_subinterface.parent = self
                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                self._segment_path = lambda: "Cisco-IOS-XE-call-home:source-interface"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/call-home/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.CallHome.SourceInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


            class ATMSubinterface(Entity):
                """
                
                
                .. attribute:: atm
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-ch'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.CallHome.SourceInterface.ATMSubinterface, self).__init__()

                    self.yang_name = "ATM-subinterface"
                    self.yang_parent_name = "source-interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                    ])
                    self.atm = None
                    self._segment_path = lambda: "ATM-subinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/call-home/Cisco-IOS-XE-call-home:source-interface/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.CallHome.SourceInterface.ATMSubinterface, [u'atm'], name, value)


            class ATMACRsubinterface(Entity):
                """
                
                
                .. attribute:: atm_acr
                
                	
                	**type**\: str
                
                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                
                

                """

                _prefix = 'ios-ch'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.CallHome.SourceInterface.ATMACRsubinterface, self).__init__()

                    self.yang_name = "ATM-ACRsubinterface"
                    self.yang_parent_name = "source-interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                    ])
                    self.atm_acr = None
                    self._segment_path = lambda: "ATM-ACRsubinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/call-home/Cisco-IOS-XE-call-home:source-interface/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.CallHome.SourceInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


            class LISPSubinterface(Entity):
                """
                Locator/ID Separation Protocol Virtual Interface
                
                .. attribute:: lisp
                
                	
                	**type**\: str
                
                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                
                

                """

                _prefix = 'ios-ch'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.CallHome.SourceInterface.LISPSubinterface, self).__init__()

                    self.yang_name = "LISP-subinterface"
                    self.yang_parent_name = "source-interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                    ])
                    self.lisp = None
                    self._segment_path = lambda: "LISP-subinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/call-home/Cisco-IOS-XE-call-home:source-interface/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.CallHome.SourceInterface.LISPSubinterface, [u'lisp'], name, value)


            class PortChannelSubinterface(Entity):
                """
                
                
                .. attribute:: port_channel
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-ch'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.CallHome.SourceInterface.PortChannelSubinterface, self).__init__()

                    self.yang_name = "Port-channel-subinterface"
                    self.yang_parent_name = "source-interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                    ])
                    self.port_channel = None
                    self._segment_path = lambda: "Port-channel-subinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/call-home/Cisco-IOS-XE-call-home:source-interface/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.CallHome.SourceInterface.PortChannelSubinterface, [u'port_channel'], name, value)


        class HttpProxy(Entity):
            """
            Specify proxy server for http request
            
            .. attribute:: proxy_servers
            
            	
            	**type**\: list of  		 :py:class:`ProxyServers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.HttpProxy.ProxyServers>`
            
            

            """

            _prefix = 'ios-ch'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.CallHome.HttpProxy, self).__init__()

                self.yang_name = "http-proxy"
                self.yang_parent_name = "call-home"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("proxy-servers", ("proxy_servers", Native.CallHome.HttpProxy.ProxyServers))])
                self._leafs = OrderedDict()

                self.proxy_servers = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-call-home:http-proxy"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/call-home/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.CallHome.HttpProxy, [], name, value)


            class ProxyServers(Entity):
                """
                
                
                .. attribute:: proxy_server  (key)
                
                	Http proxy server
                	**type**\: str
                
                .. attribute:: port
                
                	http proxy server port number
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ch'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.CallHome.HttpProxy.ProxyServers, self).__init__()

                    self.yang_name = "proxy-servers"
                    self.yang_parent_name = "http-proxy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['proxy_server']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('proxy_server', (YLeaf(YType.str, 'proxy-server'), ['str'])),
                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                    ])
                    self.proxy_server = None
                    self.port = None
                    self._segment_path = lambda: "proxy-servers" + "[proxy-server='" + str(self.proxy_server) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/call-home/Cisco-IOS-XE-call-home:http-proxy/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.CallHome.HttpProxy.ProxyServers, ['proxy_server', 'port'], name, value)


        class Profile(Entity):
            """
            Enter call\-home profile configuration mode
            
            .. attribute:: profile_name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: active
            
            	Activate the current profile
            	**type**\: bool
            
            .. attribute:: destination
            
            	Message destination related configuration
            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.Destination>`
            
            .. attribute:: subscribe_to_alert_group
            
            	Subscribe to alert\-group
            	**type**\:  :py:class:`SubscribeToAlertGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup>`
            
            

            """

            _prefix = 'ios-ch'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.CallHome.Profile, self).__init__()

                self.yang_name = "profile"
                self.yang_parent_name = "call-home"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['profile_name']
                self._child_classes = OrderedDict([("destination", ("destination", Native.CallHome.Profile.Destination)), ("subscribe-to-alert-group", ("subscribe_to_alert_group", Native.CallHome.Profile.SubscribeToAlertGroup))])
                self._leafs = OrderedDict([
                    ('profile_name', (YLeaf(YType.str, 'profile-name'), ['str'])),
                    ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                ])
                self.profile_name = None
                self.active = None

                self.destination = Native.CallHome.Profile.Destination()
                self.destination.parent = self
                self._children_name_map["destination"] = "destination"

                self.subscribe_to_alert_group = Native.CallHome.Profile.SubscribeToAlertGroup()
                self.subscribe_to_alert_group.parent = self
                self._children_name_map["subscribe_to_alert_group"] = "subscribe-to-alert-group"
                self._segment_path = lambda: "Cisco-IOS-XE-call-home:profile" + "[profile-name='" + str(self.profile_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/call-home/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.CallHome.Profile, ['profile_name', 'active'], name, value)


            class Destination(Entity):
                """
                Message destination related configuration
                
                .. attribute:: transport_method
                
                	To specify transport method for this profile
                	**type**\:  :py:class:`TransportMethod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.Destination.TransportMethod>`
                
                .. attribute:: address
                
                	To add destination address to this profile
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.Destination.Address>`
                
                

                """

                _prefix = 'ios-ch'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.CallHome.Profile.Destination, self).__init__()

                    self.yang_name = "destination"
                    self.yang_parent_name = "profile"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("address", ("address", Native.CallHome.Profile.Destination.Address))])
                    self._leafs = OrderedDict([
                        ('transport_method', (YLeaf(YType.enumeration, 'transport-method'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'CallHome.Profile.Destination.TransportMethod')])),
                    ])
                    self.transport_method = None

                    self.address = Native.CallHome.Profile.Destination.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"
                    self._segment_path = lambda: "destination"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.CallHome.Profile.Destination, ['transport_method'], name, value)

                class TransportMethod(Enum):
                    """
                    TransportMethod (Enum Class)

                    To specify transport method for this profile

                    .. data:: http = 0

                    .. data:: email = 1

                    """

                    http = Enum.YLeaf(0, "http")

                    email = Enum.YLeaf(1, "email")



                class Address(Entity):
                    """
                    To add destination address to this profile
                    
                    .. attribute:: email
                    
                    	Use email address
                    	**type**\: str
                    
                    .. attribute:: http
                    
                    	To add http address to this profile
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-ch'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.CallHome.Profile.Destination.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "destination"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('email', (YLeaf(YType.str, 'email'), ['str'])),
                            ('http', (YLeaf(YType.str, 'http'), ['str'])),
                        ])
                        self.email = None
                        self.http = None
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.CallHome.Profile.Destination.Address, ['email', 'http'], name, value)


            class SubscribeToAlertGroup(Entity):
                """
                Subscribe to alert\-group
                
                .. attribute:: diagnostic
                
                	diagnostic info
                	**type**\:  :py:class:`Diagnostic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Diagnostic>`
                
                	**presence node**\: True
                
                .. attribute:: environment
                
                	environmental info
                	**type**\:  :py:class:`Environment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Environment>`
                
                	**presence node**\: True
                
                .. attribute:: inventory
                
                	inventory info
                	**type**\:  :py:class:`Inventory <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Inventory>`
                
                	**presence node**\: True
                
                .. attribute:: syslog
                
                	syslog info
                	**type**\:  :py:class:`Syslog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Syslog>`
                
                	**presence node**\: True
                
                .. attribute:: configuration
                
                	configuration info
                	**type**\:  :py:class:`Configuration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Configuration>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-ch'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.CallHome.Profile.SubscribeToAlertGroup, self).__init__()

                    self.yang_name = "subscribe-to-alert-group"
                    self.yang_parent_name = "profile"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("diagnostic", ("diagnostic", Native.CallHome.Profile.SubscribeToAlertGroup.Diagnostic)), ("environment", ("environment", Native.CallHome.Profile.SubscribeToAlertGroup.Environment)), ("inventory", ("inventory", Native.CallHome.Profile.SubscribeToAlertGroup.Inventory)), ("syslog", ("syslog", Native.CallHome.Profile.SubscribeToAlertGroup.Syslog)), ("configuration", ("configuration", Native.CallHome.Profile.SubscribeToAlertGroup.Configuration))])
                    self._leafs = OrderedDict()

                    self.diagnostic = None
                    self._children_name_map["diagnostic"] = "diagnostic"

                    self.environment = None
                    self._children_name_map["environment"] = "environment"

                    self.inventory = None
                    self._children_name_map["inventory"] = "inventory"

                    self.syslog = None
                    self._children_name_map["syslog"] = "syslog"

                    self.configuration = None
                    self._children_name_map["configuration"] = "configuration"
                    self._segment_path = lambda: "subscribe-to-alert-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup, [], name, value)


                class Diagnostic(Entity):
                    """
                    diagnostic info
                    
                    .. attribute:: severity
                    
                    	Severity
                    	**type**\:  :py:class:`Severity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Diagnostic.Severity>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ch'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.CallHome.Profile.SubscribeToAlertGroup.Diagnostic, self).__init__()

                        self.yang_name = "diagnostic"
                        self.yang_parent_name = "subscribe-to-alert-group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('severity', (YLeaf(YType.enumeration, 'severity'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'CallHome.Profile.SubscribeToAlertGroup.Diagnostic.Severity')])),
                        ])
                        self.severity = None
                        self._segment_path = lambda: "diagnostic"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Diagnostic, ['severity'], name, value)

                    class Severity(Enum):
                        """
                        Severity (Enum Class)

                        Severity

                        .. data:: catastrophic = 0

                        .. data:: critical = 1

                        .. data:: debugging = 2

                        .. data:: disaster = 3

                        .. data:: fatal = 4

                        .. data:: major = 5

                        .. data:: minor = 6

                        .. data:: normal = 7

                        .. data:: notification = 8

                        .. data:: warning = 9

                        """

                        catastrophic = Enum.YLeaf(0, "catastrophic")

                        critical = Enum.YLeaf(1, "critical")

                        debugging = Enum.YLeaf(2, "debugging")

                        disaster = Enum.YLeaf(3, "disaster")

                        fatal = Enum.YLeaf(4, "fatal")

                        major = Enum.YLeaf(5, "major")

                        minor = Enum.YLeaf(6, "minor")

                        normal = Enum.YLeaf(7, "normal")

                        notification = Enum.YLeaf(8, "notification")

                        warning = Enum.YLeaf(9, "warning")



                class Environment(Entity):
                    """
                    environmental info
                    
                    .. attribute:: severity
                    
                    	Severity
                    	**type**\:  :py:class:`Severity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Environment.Severity>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ch'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.CallHome.Profile.SubscribeToAlertGroup.Environment, self).__init__()

                        self.yang_name = "environment"
                        self.yang_parent_name = "subscribe-to-alert-group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('severity', (YLeaf(YType.enumeration, 'severity'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'CallHome.Profile.SubscribeToAlertGroup.Environment.Severity')])),
                        ])
                        self.severity = None
                        self._segment_path = lambda: "environment"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Environment, ['severity'], name, value)

                    class Severity(Enum):
                        """
                        Severity (Enum Class)

                        Severity

                        .. data:: catastrophic = 0

                        .. data:: critical = 1

                        .. data:: debugging = 2

                        .. data:: disaster = 3

                        .. data:: fatal = 4

                        .. data:: major = 5

                        .. data:: minor = 6

                        .. data:: normal = 7

                        .. data:: notification = 8

                        .. data:: warning = 9

                        """

                        catastrophic = Enum.YLeaf(0, "catastrophic")

                        critical = Enum.YLeaf(1, "critical")

                        debugging = Enum.YLeaf(2, "debugging")

                        disaster = Enum.YLeaf(3, "disaster")

                        fatal = Enum.YLeaf(4, "fatal")

                        major = Enum.YLeaf(5, "major")

                        minor = Enum.YLeaf(6, "minor")

                        normal = Enum.YLeaf(7, "normal")

                        notification = Enum.YLeaf(8, "notification")

                        warning = Enum.YLeaf(9, "warning")



                class Inventory(Entity):
                    """
                    inventory info
                    
                    .. attribute:: periodic
                    
                    	
                    	**type**\:  :py:class:`Periodic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ch'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.CallHome.Profile.SubscribeToAlertGroup.Inventory, self).__init__()

                        self.yang_name = "inventory"
                        self.yang_parent_name = "subscribe-to-alert-group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("periodic", ("periodic", Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.periodic = Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic()
                        self.periodic.parent = self
                        self._children_name_map["periodic"] = "periodic"
                        self._segment_path = lambda: "inventory"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Inventory, [], name, value)


                    class Periodic(Entity):
                        """
                        
                        
                        .. attribute:: daily
                        
                        	Daily call\-home message
                        	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Daily>`
                        
                        .. attribute:: monthly
                        
                        	Monthly call\-home message
                        	**type**\:  :py:class:`Monthly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Monthly>`
                        
                        .. attribute:: weekly
                        
                        	Weekly call\-home message
                        	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Weekly>`
                        
                        

                        """

                        _prefix = 'ios-ch'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic, self).__init__()

                            self.yang_name = "periodic"
                            self.yang_parent_name = "inventory"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("daily", ("daily", Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Daily)), ("monthly", ("monthly", Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Monthly)), ("weekly", ("weekly", Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Weekly))])
                            self._leafs = OrderedDict()

                            self.daily = Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Daily()
                            self.daily.parent = self
                            self._children_name_map["daily"] = "daily"

                            self.monthly = Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Monthly()
                            self.monthly.parent = self
                            self._children_name_map["monthly"] = "monthly"

                            self.weekly = Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Weekly()
                            self.weekly.parent = self
                            self._children_name_map["weekly"] = "weekly"
                            self._segment_path = lambda: "periodic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic, [], name, value)


                        class Daily(Entity):
                            """
                            Daily call\-home message
                            
                            .. attribute:: begin_time
                            
                            	Begin time
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-ch'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Daily, self).__init__()

                                self.yang_name = "daily"
                                self.yang_parent_name = "periodic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('begin_time', (YLeaf(YType.str, 'begin-time'), ['str'])),
                                ])
                                self.begin_time = None
                                self._segment_path = lambda: "daily"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Daily, ['begin_time'], name, value)


                        class Monthly(Entity):
                            """
                            Monthly call\-home message
                            
                            .. attribute:: date
                            
                            	Day of month
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: begin_time
                            
                            	Begin time
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-ch'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Monthly, self).__init__()

                                self.yang_name = "monthly"
                                self.yang_parent_name = "periodic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('date', (YLeaf(YType.uint8, 'date'), ['int'])),
                                    ('begin_time', (YLeaf(YType.str, 'begin-time'), ['str'])),
                                ])
                                self.date = None
                                self.begin_time = None
                                self._segment_path = lambda: "monthly"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Monthly, ['date', 'begin_time'], name, value)


                        class Weekly(Entity):
                            """
                            Weekly call\-home message
                            
                            .. attribute:: day
                            
                            	Day of the week
                            	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                            
                            .. attribute:: begin_time
                            
                            	Begin time
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-ch'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Weekly, self).__init__()

                                self.yang_name = "weekly"
                                self.yang_parent_name = "periodic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                    ('begin_time', (YLeaf(YType.str, 'begin-time'), ['str'])),
                                ])
                                self.day = None
                                self.begin_time = None
                                self._segment_path = lambda: "weekly"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Inventory.Periodic.Weekly, ['day', 'begin_time'], name, value)


                class Syslog(Entity):
                    """
                    syslog info
                    
                    .. attribute:: severity
                    
                    	severity
                    	**type**\: list of  		 :py:class:`Severity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Syslog.Severity>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ch'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.CallHome.Profile.SubscribeToAlertGroup.Syslog, self).__init__()

                        self.yang_name = "syslog"
                        self.yang_parent_name = "subscribe-to-alert-group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("severity", ("severity", Native.CallHome.Profile.SubscribeToAlertGroup.Syslog.Severity))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.severity = YList(self)
                        self._segment_path = lambda: "syslog"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Syslog, [], name, value)


                    class Severity(Entity):
                        """
                        severity
                        
                        .. attribute:: value  (key)
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Syslog.Severity.Value>`
                        
                        .. attribute:: pattern
                        
                        	Syslog message pattern
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ch'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.CallHome.Profile.SubscribeToAlertGroup.Syslog.Severity, self).__init__()

                            self.yang_name = "severity"
                            self.yang_parent_name = "syslog"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['value']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.enumeration, 'value'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'CallHome.Profile.SubscribeToAlertGroup.Syslog.Severity.Value')])),
                                ('pattern', (YLeaf(YType.str, 'pattern'), ['str'])),
                            ])
                            self.value = None
                            self.pattern = None
                            self._segment_path = lambda: "severity" + "[value='" + str(self.value) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Syslog.Severity, ['value', 'pattern'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: catastrophic = 0

                            .. data:: critical = 1

                            .. data:: debugging = 2

                            .. data:: disaster = 3

                            .. data:: fatal = 4

                            .. data:: major = 5

                            .. data:: minor = 6

                            .. data:: normal = 7

                            .. data:: notification = 8

                            .. data:: warning = 9

                            """

                            catastrophic = Enum.YLeaf(0, "catastrophic")

                            critical = Enum.YLeaf(1, "critical")

                            debugging = Enum.YLeaf(2, "debugging")

                            disaster = Enum.YLeaf(3, "disaster")

                            fatal = Enum.YLeaf(4, "fatal")

                            major = Enum.YLeaf(5, "major")

                            minor = Enum.YLeaf(6, "minor")

                            normal = Enum.YLeaf(7, "normal")

                            notification = Enum.YLeaf(8, "notification")

                            warning = Enum.YLeaf(9, "warning")



                class Configuration(Entity):
                    """
                    configuration info
                    
                    .. attribute:: periodic
                    
                    	
                    	**type**\:  :py:class:`Periodic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ch'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.CallHome.Profile.SubscribeToAlertGroup.Configuration, self).__init__()

                        self.yang_name = "configuration"
                        self.yang_parent_name = "subscribe-to-alert-group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("periodic", ("periodic", Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.periodic = Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic()
                        self.periodic.parent = self
                        self._children_name_map["periodic"] = "periodic"
                        self._segment_path = lambda: "configuration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Configuration, [], name, value)


                    class Periodic(Entity):
                        """
                        
                        
                        .. attribute:: daily
                        
                        	Daily call\-home message
                        	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Daily>`
                        
                        .. attribute:: monthly
                        
                        	Monthly call\-home message
                        	**type**\:  :py:class:`Monthly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Monthly>`
                        
                        .. attribute:: weekly
                        
                        	Weekly call\-home message
                        	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Weekly>`
                        
                        

                        """

                        _prefix = 'ios-ch'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic, self).__init__()

                            self.yang_name = "periodic"
                            self.yang_parent_name = "configuration"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("daily", ("daily", Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Daily)), ("monthly", ("monthly", Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Monthly)), ("weekly", ("weekly", Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Weekly))])
                            self._leafs = OrderedDict()

                            self.daily = Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Daily()
                            self.daily.parent = self
                            self._children_name_map["daily"] = "daily"

                            self.monthly = Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Monthly()
                            self.monthly.parent = self
                            self._children_name_map["monthly"] = "monthly"

                            self.weekly = Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Weekly()
                            self.weekly.parent = self
                            self._children_name_map["weekly"] = "weekly"
                            self._segment_path = lambda: "periodic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic, [], name, value)


                        class Daily(Entity):
                            """
                            Daily call\-home message
                            
                            .. attribute:: begin_time
                            
                            	Begin time
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-ch'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Daily, self).__init__()

                                self.yang_name = "daily"
                                self.yang_parent_name = "periodic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('begin_time', (YLeaf(YType.str, 'begin-time'), ['str'])),
                                ])
                                self.begin_time = None
                                self._segment_path = lambda: "daily"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Daily, ['begin_time'], name, value)


                        class Monthly(Entity):
                            """
                            Monthly call\-home message
                            
                            .. attribute:: date
                            
                            	Day of month
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: begin_time
                            
                            	Begin time
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-ch'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Monthly, self).__init__()

                                self.yang_name = "monthly"
                                self.yang_parent_name = "periodic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('date', (YLeaf(YType.uint8, 'date'), ['int'])),
                                    ('begin_time', (YLeaf(YType.str, 'begin-time'), ['str'])),
                                ])
                                self.date = None
                                self.begin_time = None
                                self._segment_path = lambda: "monthly"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Monthly, ['date', 'begin_time'], name, value)


                        class Weekly(Entity):
                            """
                            Weekly call\-home message
                            
                            .. attribute:: day
                            
                            	Day of the week
                            	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                            
                            .. attribute:: begin_time
                            
                            	Begin time
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-ch'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Weekly, self).__init__()

                                self.yang_name = "weekly"
                                self.yang_parent_name = "periodic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                    ('begin_time', (YLeaf(YType.str, 'begin-time'), ['str'])),
                                ])
                                self.day = None
                                self.begin_time = None
                                self._segment_path = lambda: "weekly"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.CallHome.Profile.SubscribeToAlertGroup.Configuration.Periodic.Weekly, ['day', 'begin_time'], name, value)


    class HwModule(Entity):
        """
        Control of individual components in the system
        
        .. attribute:: uplink
        
        	Uplink control
        	**type**\:  :py:class:`Uplink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwModule.Uplink>`
        
        .. attribute:: switch
        
        	Switch in the system
        	**type**\: list of  		 :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwModule.Switch>`
        
        .. attribute:: slot
        
        	Control a component in a slot
        	**type**\: list of  		 :py:class:`Slot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwModule.Slot>`
        
        .. attribute:: sm
        
        	
        	**type**\: int
        
        	**range:** 0..255
        
        .. attribute:: pvdm
        
        	
        	**type**\: str
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.HwModule, self).__init__()

            self.yang_name = "hw-module"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("uplink", ("uplink", Native.HwModule.Uplink)), ("switch", ("switch", Native.HwModule.Switch)), ("slot", ("slot", Native.HwModule.Slot))])
            self._leafs = OrderedDict([
                ('sm', (YLeaf(YType.uint8, 'sm'), ['int'])),
                ('pvdm', (YLeaf(YType.str, 'pvdm'), ['str'])),
            ])
            self.sm = None
            self.pvdm = None

            self.uplink = Native.HwModule.Uplink()
            self.uplink.parent = self
            self._children_name_map["uplink"] = "uplink"

            self.switch = YList(self)
            self.slot = YList(self)
            self._segment_path = lambda: "hw-module"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.HwModule, [u'sm', u'pvdm'], name, value)


        class Uplink(Entity):
            """
            Uplink control
            
            .. attribute:: select
            
            	Select uplink interface
            	**type**\: str
            
            .. attribute:: mode
            
            	Uplink mode
            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwModule.Uplink.Mode>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.HwModule.Uplink, self).__init__()

                self.yang_name = "uplink"
                self.yang_parent_name = "hw-module"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('select', (YLeaf(YType.str, 'select'), ['str'])),
                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'HwModule.Uplink.Mode')])),
                ])
                self.select = None
                self.mode = None
                self._segment_path = lambda: "uplink"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/hw-module/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.HwModule.Uplink, [u'select', u'mode'], name, value)

            class Mode(Enum):
                """
                Mode (Enum Class)

                Uplink mode

                .. data:: shared_backplane = 0

                """

                shared_backplane = Enum.YLeaf(0, "shared-backplane")



        class Switch(Entity):
            """
            Switch in the system
            
            .. attribute:: switch_number  (key)
            
            	Switch number in the Stack (Refer to show switch CLI)
            	**type**\: int
            
            	**range:** 1..8
            
            .. attribute:: usbflash1
            
            	USB SSD
            	**type**\:  :py:class:`Usbflash1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwModule.Switch.Usbflash1>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.HwModule.Switch, self).__init__()

                self.yang_name = "switch"
                self.yang_parent_name = "hw-module"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['switch_number']
                self._child_classes = OrderedDict([("usbflash1", ("usbflash1", Native.HwModule.Switch.Usbflash1))])
                self._leafs = OrderedDict([
                    ('switch_number', (YLeaf(YType.uint8, 'switch-number'), ['int'])),
                ])
                self.switch_number = None

                self.usbflash1 = Native.HwModule.Switch.Usbflash1()
                self.usbflash1.parent = self
                self._children_name_map["usbflash1"] = "usbflash1"
                self._segment_path = lambda: "switch" + "[switch-number='" + str(self.switch_number) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/hw-module/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.HwModule.Switch, [u'switch_number'], name, value)


            class Usbflash1(Entity):
                """
                USB SSD
                
                .. attribute:: security
                
                	Security on usbflash1
                	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwModule.Switch.Usbflash1.Security>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.HwModule.Switch.Usbflash1, self).__init__()

                    self.yang_name = "usbflash1"
                    self.yang_parent_name = "switch"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("security", ("security", Native.HwModule.Switch.Usbflash1.Security))])
                    self._leafs = OrderedDict()

                    self.security = Native.HwModule.Switch.Usbflash1.Security()
                    self.security.parent = self
                    self._children_name_map["security"] = "security"
                    self._segment_path = lambda: "usbflash1"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.HwModule.Switch.Usbflash1, [], name, value)


                class Security(Entity):
                    """
                    Security on usbflash1
                    
                    .. attribute:: enable
                    
                    	Enable security on usbflash1
                    	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwModule.Switch.Usbflash1.Security.Enable>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.HwModule.Switch.Usbflash1.Security, self).__init__()

                        self.yang_name = "security"
                        self.yang_parent_name = "usbflash1"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("enable", ("enable", Native.HwModule.Switch.Usbflash1.Security.Enable))])
                        self._leafs = OrderedDict()

                        self.enable = None
                        self._children_name_map["enable"] = "enable"
                        self._segment_path = lambda: "security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.HwModule.Switch.Usbflash1.Security, [], name, value)


                    class Enable(Entity):
                        """
                        Enable security on usbflash1
                        
                        .. attribute:: password
                        
                        	Enter password for enabling security on usbflash1
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.HwModule.Switch.Usbflash1.Security.Enable, self).__init__()

                            self.yang_name = "enable"
                            self.yang_parent_name = "security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.password = None
                            self._segment_path = lambda: "enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.HwModule.Switch.Usbflash1.Security.Enable, [u'password'], name, value)


        class Slot(Entity):
            """
            Control a component in a slot
            
            .. attribute:: name  (key)
            
            	Slot of LC
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown a fru
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.HwModule.Slot, self).__init__()

                self.yang_name = "slot"
                self.yang_parent_name = "hw-module"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                ])
                self.name = None
                self.shutdown = None
                self._segment_path = lambda: "slot" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/hw-module/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.HwModule.Slot, [u'name', u'shutdown'], name, value)


    class Cisp(Entity):
        """
        Set CISP parameters
        
        .. attribute:: enable
        
        	Enable CISP
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Cisp, self).__init__()

            self.yang_name = "cisp"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
            ])
            self.enable = None
            self._segment_path = lambda: "cisp"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Cisp, [u'enable'], name, value)


    class Module(Entity):
        """
        Module
        
        .. attribute:: provision
        
        	Configure module provision status
        	**type**\:  :py:class:`Provision <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Module.Provision>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Module, self).__init__()

            self.yang_name = "module"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:provision", ("provision", Native.Module.Provision))])
            self._leafs = OrderedDict()

            self.provision = Native.Module.Provision()
            self.provision.parent = self
            self._children_name_map["provision"] = "Cisco-IOS-XE-switch:provision"
            self._segment_path = lambda: "module"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Module, [], name, value)


        class Provision(Entity):
            """
            Configure module provision status
            
            .. attribute:: switch
            
            	
            	**type**\: list of  		 :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Module.Provision.Switch>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.Module.Provision, self).__init__()

                self.yang_name = "provision"
                self.yang_parent_name = "module"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("switch", ("switch", Native.Module.Provision.Switch))])
                self._leafs = OrderedDict()

                self.switch = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-switch:provision"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/module/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Module.Provision, [], name, value)


            class Switch(Entity):
                """
                
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: chassis
                
                	
                	**type**\:  :py:class:`Chassis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Module.Provision.Switch.Chassis>`
                
                .. attribute:: slot
                
                	
                	**type**\: list of  		 :py:class:`Slot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Module.Provision.Switch.Slot>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Module.Provision.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "provision"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("chassis", ("chassis", Native.Module.Provision.Switch.Chassis)), ("slot", ("slot", Native.Module.Provision.Switch.Slot))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                    ])
                    self.number = None

                    self.chassis = Native.Module.Provision.Switch.Chassis()
                    self.chassis.parent = self
                    self._children_name_map["chassis"] = "chassis"

                    self.slot = YList(self)
                    self._segment_path = lambda: "switch" + "[number='" + str(self.number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/module/Cisco-IOS-XE-switch:provision/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Module.Provision.Switch, [u'number'], name, value)


                class Chassis(Entity):
                    """
                    
                    
                    .. attribute:: chassis_type
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: base_mac
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Module.Provision.Switch.Chassis, self).__init__()

                        self.yang_name = "chassis"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('chassis_type', (YLeaf(YType.uint32, 'chassis-type'), ['int'])),
                            ('base_mac', (YLeaf(YType.str, 'base-mac'), ['str'])),
                        ])
                        self.chassis_type = None
                        self.base_mac = None
                        self._segment_path = lambda: "chassis"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Module.Provision.Switch.Chassis, [u'chassis_type', u'base_mac'], name, value)


                class Slot(Entity):
                    """
                    
                    
                    .. attribute:: number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: slot_type
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: base_mac
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Module.Provision.Switch.Slot, self).__init__()

                        self.yang_name = "slot"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['number']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                            ('slot_type', (YLeaf(YType.uint32, 'slot-type'), ['int'])),
                            ('base_mac', (YLeaf(YType.str, 'base-mac'), ['str'])),
                        ])
                        self.number = None
                        self.slot_type = None
                        self.base_mac = None
                        self._segment_path = lambda: "slot" + "[number='" + str(self.number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Module.Provision.Switch.Slot, [u'number', u'slot_type', u'base_mac'], name, value)


    class Domain(Entity):
        """
        Domain Configuration Commands
        
        .. attribute:: name  (key)
        
        	
        	**type**\: str
        
        .. attribute:: vrf
        
        	Specify vrf for domain
        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Domain, self).__init__()

            self.yang_name = "domain"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['name']
            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Domain.Vrf))])
            self._leafs = OrderedDict([
                ('name', (YLeaf(YType.str, 'name'), ['str'])),
            ])
            self.name = None

            self.vrf = YList(self)
            self._segment_path = lambda: "domain" + "[name='" + str(self.name) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Domain, [u'name'], name, value)


        class Vrf(Entity):
            """
            Specify vrf for domain
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: border
            
            	Enter border router configuration submode
            	**type**\:  :py:class:`Border <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Border>`
            
            .. attribute:: master
            
            	Enter master controller configuration submode
            	**type**\:  :py:class:`Master <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Domain.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "domain"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("border", ("border", Native.Domain.Vrf.Border)), ("master", ("master", Native.Domain.Vrf.Master))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.border = Native.Domain.Vrf.Border()
                self.border.parent = self
                self._children_name_map["border"] = "border"

                self.master = Native.Domain.Vrf.Master()
                self.master.parent = self
                self._children_name_map["master"] = "master"
                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Domain.Vrf, [u'name'], name, value)


            class Border(Entity):
                """
                Enter border router configuration submode
                
                .. attribute:: advanced
                
                	Enter border router advanced configuration submode
                	**type**\:  :py:class:`Advanced <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Border.Advanced>`
                
                .. attribute:: source_interface
                
                	Source Interface for border
                	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Border.SourceInterface>`
                
                .. attribute:: master
                
                	Specify IP address of Domain master controller
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\:  :py:class:`Master <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Border.Master>`
                
                .. attribute:: password
                
                	MD5 password to be used with MC
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Border.Password>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Domain.Vrf.Border, self).__init__()

                    self.yang_name = "border"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("advanced", ("advanced", Native.Domain.Vrf.Border.Advanced)), ("source-interface", ("source_interface", Native.Domain.Vrf.Border.SourceInterface)), ("password", ("password", Native.Domain.Vrf.Border.Password))])
                    self._leafs = OrderedDict([
                        ('master', (YLeaf(YType.str, 'master'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Domain.Vrf.Border.Master')])),
                    ])
                    self.master = None

                    self.advanced = Native.Domain.Vrf.Border.Advanced()
                    self.advanced.parent = self
                    self._children_name_map["advanced"] = "advanced"

                    self.source_interface = Native.Domain.Vrf.Border.SourceInterface()
                    self.source_interface.parent = self
                    self._children_name_map["source_interface"] = "source-interface"

                    self.password = Native.Domain.Vrf.Border.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "password"
                    self._segment_path = lambda: "border"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Domain.Vrf.Border, [u'master'], name, value)

                class Master(Enum):
                    """
                    Master (Enum Class)

                    Specify IP address of Domain master controller

                    .. data:: local = 0

                    """

                    local = Enum.YLeaf(0, "local")



                class Advanced(Entity):
                    """
                    Enter border router advanced configuration submode
                    
                    .. attribute:: monitor_cache_percent
                    
                    	cache usage (%), border instance will AUTOMATICALLY go through SHUT/NO SHUT any ACTIVE traffic on this border will be affected
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Domain.Vrf.Border.Advanced, self).__init__()

                        self.yang_name = "advanced"
                        self.yang_parent_name = "border"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('monitor_cache_percent', (YLeaf(YType.uint8, 'monitor-cache-percent'), ['int'])),
                        ])
                        self.monitor_cache_percent = None
                        self._segment_path = lambda: "advanced"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Domain.Vrf.Border.Advanced, [u'monitor_cache_percent'], name, value)


                class SourceInterface(Entity):
                    """
                    Source Interface for border
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Domain.Vrf.Border.SourceInterface, self).__init__()

                        self.yang_name = "source-interface"
                        self.yang_parent_name = "border"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ])
                        self.loopback = None
                        self._segment_path = lambda: "source-interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Domain.Vrf.Border.SourceInterface, [u'loopback'], name, value)


                class Password(Entity):
                    """
                    MD5 password to be used with MC
                    
                    .. attribute:: encryption
                    
                    	
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Border.Password.Encryption>`
                    
                    .. attribute:: clear_key
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Domain.Vrf.Border.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "border"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Domain.Vrf.Border.Password.Encryption')])),
                            ('clear_key', (YLeaf(YType.str, 'clear-key'), ['str'])),
                        ])
                        self.encryption = None
                        self.clear_key = None
                        self._segment_path = lambda: "password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Domain.Vrf.Border.Password, [u'encryption', u'clear_key'], name, value)

                    class Encryption(Enum):
                        """
                        Encryption (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_7 = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_7 = Enum.YLeaf(1, "7")



            class Master(Entity):
                """
                Enter master controller configuration submode
                
                .. attribute:: branch
                
                	Set master type as branch hub
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hub
                
                	Set master type as hub
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transit
                
                	Set master type as transit
                	**type**\: int
                
                	**range:** 1..64
                
                .. attribute:: advanced
                
                	Advanced configuration submode
                	**type**\:  :py:class:`Advanced <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Advanced>`
                
                .. attribute:: collector
                
                	NMS/v9 collector configuration
                	**type**\:  :py:class:`Collector <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Collector>`
                
                .. attribute:: enterprise_prefix
                
                	Enterprise prefix configuration
                	**type**\:  :py:class:`EnterprisePrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.EnterprisePrefix>`
                
                .. attribute:: load_balance
                
                	load balance non\-policy traffic
                	**type**\:  :py:class:`LoadBalance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.LoadBalance>`
                
                	**presence node**\: True
                
                .. attribute:: password
                
                	MD5 password to be used with BRs
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Password>`
                
                .. attribute:: site_prefixes
                
                	site\-prefixes configuration
                	**type**\:  :py:class:`SitePrefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.SitePrefixes>`
                
                .. attribute:: source_interface
                
                	Source Interface for master controller
                	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.SourceInterface>`
                
                .. attribute:: class_
                
                	Create domain class and enter domain class command mode
                	**type**\: list of  		 :py:class:`Class <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Class>`
                
                .. attribute:: hub_ip
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Domain.Vrf.Master, self).__init__()

                    self.yang_name = "master"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("advanced", ("advanced", Native.Domain.Vrf.Master.Advanced)), ("collector", ("collector", Native.Domain.Vrf.Master.Collector)), ("enterprise-prefix", ("enterprise_prefix", Native.Domain.Vrf.Master.EnterprisePrefix)), ("load-balance", ("load_balance", Native.Domain.Vrf.Master.LoadBalance)), ("password", ("password", Native.Domain.Vrf.Master.Password)), ("site-prefixes", ("site_prefixes", Native.Domain.Vrf.Master.SitePrefixes)), ("source-interface", ("source_interface", Native.Domain.Vrf.Master.SourceInterface)), ("class", ("class_", Native.Domain.Vrf.Master.Class))])
                    self._leafs = OrderedDict([
                        ('branch', (YLeaf(YType.empty, 'branch'), ['Empty'])),
                        ('hub', (YLeaf(YType.empty, 'hub'), ['Empty'])),
                        ('transit', (YLeaf(YType.uint8, 'transit'), ['int'])),
                        ('hub_ip', (YLeaf(YType.str, 'hub-ip'), ['str'])),
                    ])
                    self.branch = None
                    self.hub = None
                    self.transit = None
                    self.hub_ip = None

                    self.advanced = Native.Domain.Vrf.Master.Advanced()
                    self.advanced.parent = self
                    self._children_name_map["advanced"] = "advanced"

                    self.collector = Native.Domain.Vrf.Master.Collector()
                    self.collector.parent = self
                    self._children_name_map["collector"] = "collector"

                    self.enterprise_prefix = Native.Domain.Vrf.Master.EnterprisePrefix()
                    self.enterprise_prefix.parent = self
                    self._children_name_map["enterprise_prefix"] = "enterprise-prefix"

                    self.load_balance = None
                    self._children_name_map["load_balance"] = "load-balance"

                    self.password = Native.Domain.Vrf.Master.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "password"

                    self.site_prefixes = Native.Domain.Vrf.Master.SitePrefixes()
                    self.site_prefixes.parent = self
                    self._children_name_map["site_prefixes"] = "site-prefixes"

                    self.source_interface = Native.Domain.Vrf.Master.SourceInterface()
                    self.source_interface.parent = self
                    self._children_name_map["source_interface"] = "source-interface"

                    self.class_ = YList(self)
                    self._segment_path = lambda: "master"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Domain.Vrf.Master, [u'branch', u'hub', u'transit', u'hub_ip'], name, value)


                class Advanced(Entity):
                    """
                    Advanced configuration submode
                    
                    .. attribute:: byte_loss_threshold
                    
                    	Specify minimum byte loss calculation threshold
                    	**type**\: int
                    
                    	**range:** 0..5600
                    
                    .. attribute:: channel_unreachable_timer
                    
                    	Unreach interval detection
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: load_sharing
                    
                    	Enable load\-sharing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: minimum_mask_length
                    
                    	Specify minimum mask length
                    	**type**\: int
                    
                    	**range:** 1..32
                    
                    .. attribute:: mitigation_mode
                    
                    	Enable brownout detection in domain
                    	**type**\:  :py:class:`MitigationMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Advanced.MitigationMode>`
                    
                    .. attribute:: packet_loss_threshold
                    
                    	Specify minimum packet loss calculation threshold
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    .. attribute:: smart_probes
                    
                    	Smart probes configuration
                    	**type**\:  :py:class:`SmartProbes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Advanced.SmartProbes>`
                    
                    .. attribute:: syslog
                    
                    	Specify syslog minimim time between tca
                    	**type**\:  :py:class:`Syslog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Advanced.Syslog>`
                    
                    .. attribute:: tcp
                    
                    	Specify tcp port numbers for mc\-br communication
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Advanced.Tcp>`
                    
                    .. attribute:: threshold_variance
                    
                    	Policy decision Threshold variance
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    .. attribute:: traffic_class_ageout_timer
                    
                    	Traffic\-class DB age timer
                    	**type**\:  :py:class:`TrafficClassAgeoutTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Advanced.TrafficClassAgeoutTimer>`
                    
                    .. attribute:: transit_site_affinity
                    
                    	Enable Transit Site Affinity
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Domain.Vrf.Master.Advanced, self).__init__()

                        self.yang_name = "advanced"
                        self.yang_parent_name = "master"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("smart-probes", ("smart_probes", Native.Domain.Vrf.Master.Advanced.SmartProbes)), ("syslog", ("syslog", Native.Domain.Vrf.Master.Advanced.Syslog)), ("tcp", ("tcp", Native.Domain.Vrf.Master.Advanced.Tcp)), ("traffic-class-ageout-timer", ("traffic_class_ageout_timer", Native.Domain.Vrf.Master.Advanced.TrafficClassAgeoutTimer))])
                        self._leafs = OrderedDict([
                            ('byte_loss_threshold', (YLeaf(YType.uint16, 'byte-loss-threshold'), ['int'])),
                            ('channel_unreachable_timer', (YLeaf(YType.uint16, 'channel-unreachable-timer'), ['int'])),
                            ('load_sharing', (YLeaf(YType.empty, 'load-sharing'), ['Empty'])),
                            ('minimum_mask_length', (YLeaf(YType.uint8, 'minimum-mask-length'), ['int'])),
                            ('mitigation_mode', (YLeaf(YType.enumeration, 'mitigation-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Domain.Vrf.Master.Advanced.MitigationMode')])),
                            ('packet_loss_threshold', (YLeaf(YType.uint8, 'packet-loss-threshold'), ['int'])),
                            ('threshold_variance', (YLeaf(YType.uint8, 'threshold-variance'), ['int'])),
                            ('transit_site_affinity', (YLeaf(YType.empty, 'transit-site-affinity'), ['Empty'])),
                        ])
                        self.byte_loss_threshold = None
                        self.channel_unreachable_timer = None
                        self.load_sharing = None
                        self.minimum_mask_length = None
                        self.mitigation_mode = None
                        self.packet_loss_threshold = None
                        self.threshold_variance = None
                        self.transit_site_affinity = None

                        self.smart_probes = Native.Domain.Vrf.Master.Advanced.SmartProbes()
                        self.smart_probes.parent = self
                        self._children_name_map["smart_probes"] = "smart-probes"

                        self.syslog = Native.Domain.Vrf.Master.Advanced.Syslog()
                        self.syslog.parent = self
                        self._children_name_map["syslog"] = "syslog"

                        self.tcp = Native.Domain.Vrf.Master.Advanced.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"

                        self.traffic_class_ageout_timer = Native.Domain.Vrf.Master.Advanced.TrafficClassAgeoutTimer()
                        self.traffic_class_ageout_timer.parent = self
                        self._children_name_map["traffic_class_ageout_timer"] = "traffic-class-ageout-timer"
                        self._segment_path = lambda: "advanced"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Domain.Vrf.Master.Advanced, [u'byte_loss_threshold', u'channel_unreachable_timer', u'load_sharing', u'minimum_mask_length', u'mitigation_mode', u'packet_loss_threshold', u'threshold_variance', u'transit_site_affinity'], name, value)

                    class MitigationMode(Enum):
                        """
                        MitigationMode (Enum Class)

                        Enable brownout detection in domain

                        .. data:: aggressive = 0

                        """

                        aggressive = Enum.YLeaf(0, "aggressive")



                    class SmartProbes(Entity):
                        """
                        Smart probes configuration
                        
                        .. attribute:: destination_port
                        
                        	Specify smart probes destination port number
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: source_port
                        
                        	Specify smart probes source port number
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Domain.Vrf.Master.Advanced.SmartProbes, self).__init__()

                            self.yang_name = "smart-probes"
                            self.yang_parent_name = "advanced"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('destination_port', (YLeaf(YType.uint16, 'destination-port'), ['int'])),
                                ('source_port', (YLeaf(YType.uint16, 'source-port'), ['int'])),
                            ])
                            self.destination_port = None
                            self.source_port = None
                            self._segment_path = lambda: "smart-probes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Domain.Vrf.Master.Advanced.SmartProbes, [u'destination_port', u'source_port'], name, value)


                    class Syslog(Entity):
                        """
                        Specify syslog minimim time between tca
                        
                        .. attribute:: tca_time_min
                        
                        	Specify time between syslog tcas in seconds
                        	**type**\: int
                        
                        	**range:** 30..36000
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Domain.Vrf.Master.Advanced.Syslog, self).__init__()

                            self.yang_name = "syslog"
                            self.yang_parent_name = "advanced"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tca_time_min', (YLeaf(YType.uint32, 'tca-time-min'), ['int'])),
                            ])
                            self.tca_time_min = None
                            self._segment_path = lambda: "syslog"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Domain.Vrf.Master.Advanced.Syslog, [u'tca_time_min'], name, value)


                    class Tcp(Entity):
                        """
                        Specify tcp port numbers for mc\-br communication
                        
                        .. attribute:: mc_port
                        
                        	Specify tcp MC self port for mc\-br communication
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Domain.Vrf.Master.Advanced.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "advanced"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mc_port', (YLeaf(YType.uint16, 'mc-port'), ['int'])),
                            ])
                            self.mc_port = None
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Domain.Vrf.Master.Advanced.Tcp, [u'mc_port'], name, value)


                    class TrafficClassAgeoutTimer(Entity):
                        """
                        Traffic\-class DB age timer
                        
                        .. attribute:: interval
                        
                        	Specify new timer interval value mins/hours
                        	**type**\: int
                        
                        	**range:** 5..65535
                        
                        .. attribute:: interval_unit
                        
                        	
                        	**type**\:  :py:class:`IntervalUnit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Advanced.TrafficClassAgeoutTimer.IntervalUnit>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Domain.Vrf.Master.Advanced.TrafficClassAgeoutTimer, self).__init__()

                            self.yang_name = "traffic-class-ageout-timer"
                            self.yang_parent_name = "advanced"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ('interval_unit', (YLeaf(YType.enumeration, 'interval-unit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Domain.Vrf.Master.Advanced.TrafficClassAgeoutTimer.IntervalUnit')])),
                            ])
                            self.interval = None
                            self.interval_unit = None
                            self._segment_path = lambda: "traffic-class-ageout-timer"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Domain.Vrf.Master.Advanced.TrafficClassAgeoutTimer, [u'interval', u'interval_unit'], name, value)

                        class IntervalUnit(Enum):
                            """
                            IntervalUnit (Enum Class)

                            .. data:: hours = 0

                            .. data:: minutes = 1

                            """

                            hours = Enum.YLeaf(0, "hours")

                            minutes = Enum.YLeaf(1, "minutes")



                class Collector(Entity):
                    """
                    NMS/v9 collector configuration
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: port
                    
                    	Specify collector port number
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Domain.Vrf.Master.Collector, self).__init__()

                        self.yang_name = "collector"
                        self.yang_parent_name = "master"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                            ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                        ])
                        self.ip = None
                        self.port = None
                        self._segment_path = lambda: "collector"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Domain.Vrf.Master.Collector, [u'ip', u'port'], name, value)


                class EnterprisePrefix(Entity):
                    """
                    Enterprise prefix configuration
                    
                    .. attribute:: prefix_list
                    
                    	Specify prefix\-list with static site targets
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Domain.Vrf.Master.EnterprisePrefix, self).__init__()

                        self.yang_name = "enterprise-prefix"
                        self.yang_parent_name = "master"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                        ])
                        self.prefix_list = None
                        self._segment_path = lambda: "enterprise-prefix"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Domain.Vrf.Master.EnterprisePrefix, [u'prefix_list'], name, value)


                class LoadBalance(Entity):
                    """
                    load balance non\-policy traffic
                    
                    .. attribute:: advanced
                    
                    	Load balancing configuration mode
                    	**type**\:  :py:class:`Advanced <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.LoadBalance.Advanced>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Domain.Vrf.Master.LoadBalance, self).__init__()

                        self.yang_name = "load-balance"
                        self.yang_parent_name = "master"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("advanced", ("advanced", Native.Domain.Vrf.Master.LoadBalance.Advanced))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.advanced = Native.Domain.Vrf.Master.LoadBalance.Advanced()
                        self.advanced.parent = self
                        self._children_name_map["advanced"] = "advanced"
                        self._segment_path = lambda: "load-balance"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Domain.Vrf.Master.LoadBalance, [], name, value)


                    class Advanced(Entity):
                        """
                        Load balancing configuration mode
                        
                        .. attribute:: match
                        
                        	Specify the applications the policy applies to
                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.LoadBalance.Advanced.Match>`
                        
                        .. attribute:: path_preference
                        
                        	Specify the preferred provider
                        	**type**\:  :py:class:`PathPreference <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.LoadBalance.Advanced.PathPreference>`
                        
                        .. attribute:: path_last_resort
                        
                        	Specify path of last resort provider
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Domain.Vrf.Master.LoadBalance.Advanced, self).__init__()

                            self.yang_name = "advanced"
                            self.yang_parent_name = "load-balance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("match", ("match", Native.Domain.Vrf.Master.LoadBalance.Advanced.Match)), ("path-preference", ("path_preference", Native.Domain.Vrf.Master.LoadBalance.Advanced.PathPreference))])
                            self._leafs = OrderedDict([
                                ('path_last_resort', (YLeaf(YType.str, 'path-last-resort'), ['str'])),
                            ])
                            self.path_last_resort = None

                            self.match = Native.Domain.Vrf.Master.LoadBalance.Advanced.Match()
                            self.match.parent = self
                            self._children_name_map["match"] = "match"

                            self.path_preference = Native.Domain.Vrf.Master.LoadBalance.Advanced.PathPreference()
                            self.path_preference.parent = self
                            self._children_name_map["path_preference"] = "path-preference"
                            self._segment_path = lambda: "advanced"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Domain.Vrf.Master.LoadBalance.Advanced, [u'path_last_resort'], name, value)


                        class Match(Entity):
                            """
                            Specify the applications the policy applies to
                            
                            .. attribute:: dscp
                            
                            	specify DSCP
                            	**type**\: list of  		 :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.LoadBalance.Advanced.Match.Dscp>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Domain.Vrf.Master.LoadBalance.Advanced.Match, self).__init__()

                                self.yang_name = "match"
                                self.yang_parent_name = "advanced"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dscp", ("dscp", Native.Domain.Vrf.Master.LoadBalance.Advanced.Match.Dscp))])
                                self._leafs = OrderedDict()

                                self.dscp = YList(self)
                                self._segment_path = lambda: "match"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Domain.Vrf.Master.LoadBalance.Advanced.Match, [], name, value)


                            class Dscp(Entity):
                                """
                                specify DSCP
                                
                                .. attribute:: value  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..63
                                
                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                
                                .. attribute:: policy
                                
                                	Specify the policy (user defined/predefined)
                                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.LoadBalance.Advanced.Match.Dscp.Policy>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Domain.Vrf.Master.LoadBalance.Advanced.Match.Dscp, self).__init__()

                                    self.yang_name = "dscp"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['value']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                        ('policy', (YLeaf(YType.enumeration, 'policy'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Domain.Vrf.Master.LoadBalance.Advanced.Match.Dscp.Policy')])),
                                    ])
                                    self.value = None
                                    self.policy = None
                                    self._segment_path = lambda: "dscp" + "[value='" + str(self.value) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Domain.Vrf.Master.LoadBalance.Advanced.Match.Dscp, [u'value', u'policy'], name, value)

                                class Policy(Enum):
                                    """
                                    Policy (Enum Class)

                                    Specify the policy (user defined/predefined)

                                    .. data:: best_effort = 0

                                    .. data:: bulk_data = 1

                                    .. data:: custom = 2

                                    .. data:: low_latency_data = 3

                                    .. data:: real_time_video = 4

                                    .. data:: scavenger = 5

                                    .. data:: voice = 6

                                    """

                                    best_effort = Enum.YLeaf(0, "best-effort")

                                    bulk_data = Enum.YLeaf(1, "bulk-data")

                                    custom = Enum.YLeaf(2, "custom")

                                    low_latency_data = Enum.YLeaf(3, "low-latency-data")

                                    real_time_video = Enum.YLeaf(4, "real-time-video")

                                    scavenger = Enum.YLeaf(5, "scavenger")

                                    voice = Enum.YLeaf(6, "voice")



                        class PathPreference(Entity):
                            """
                            Specify the preferred provider
                            
                            .. attribute:: primary
                            
                            	Primary service provider
                            	**type**\: str
                            
                            .. attribute:: primary2
                            
                            	Primary service provider
                            	**type**\: str
                            
                            .. attribute:: primary3
                            
                            	Primary service provider
                            	**type**\: str
                            
                            .. attribute:: fallback
                            
                            	Specify the fallback provider
                            	**type**\: union of the below types:
                            
                            		**type**\:  :py:class:`Fallback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Class.PathPreference.Fallback>`
                            
                            		**type**\: str
                            
                            .. attribute:: fallback2
                            
                            	Fallback service provider
                            	**type**\: str
                            
                            .. attribute:: fallback3
                            
                            	Fallback service provider
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Domain.Vrf.Master.LoadBalance.Advanced.PathPreference, self).__init__()

                                self.yang_name = "path-preference"
                                self.yang_parent_name = "advanced"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary', (YLeaf(YType.str, 'primary'), ['str'])),
                                    ('primary2', (YLeaf(YType.str, 'primary2'), ['str'])),
                                    ('primary3', (YLeaf(YType.str, 'primary3'), ['str'])),
                                    ('fallback', (YLeaf(YType.str, 'fallback'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Domain.Vrf.Master.Class.PathPreference.Fallback'),'str'])),
                                    ('fallback2', (YLeaf(YType.str, 'fallback2'), ['str'])),
                                    ('fallback3', (YLeaf(YType.str, 'fallback3'), ['str'])),
                                ])
                                self.primary = None
                                self.primary2 = None
                                self.primary3 = None
                                self.fallback = None
                                self.fallback2 = None
                                self.fallback3 = None
                                self._segment_path = lambda: "path-preference"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Domain.Vrf.Master.LoadBalance.Advanced.PathPreference, [u'primary', u'primary2', u'primary3', u'fallback', u'fallback2', u'fallback3'], name, value)

                            class Fallback(Enum):
                                """
                                Fallback (Enum Class)

                                Specify the fallback provider

                                .. data:: routing = 0

                                .. data:: blackhole = 1

                                """

                                routing = Enum.YLeaf(0, "routing")

                                blackhole = Enum.YLeaf(1, "blackhole")



                class Password(Entity):
                    """
                    MD5 password to be used with BRs
                    
                    .. attribute:: encryption
                    
                    	
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Password.Encryption>`
                    
                    .. attribute:: clear_key
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Domain.Vrf.Master.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "master"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Domain.Vrf.Master.Password.Encryption')])),
                            ('clear_key', (YLeaf(YType.str, 'clear-key'), ['str'])),
                        ])
                        self.encryption = None
                        self.clear_key = None
                        self._segment_path = lambda: "password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Domain.Vrf.Master.Password, [u'encryption', u'clear_key'], name, value)

                    class Encryption(Enum):
                        """
                        Encryption (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_7 = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_7 = Enum.YLeaf(1, "7")



                class SitePrefixes(Entity):
                    """
                    site\-prefixes configuration
                    
                    .. attribute:: prefix_list
                    
                    	Specify prefix\-list with static site targets
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Domain.Vrf.Master.SitePrefixes, self).__init__()

                        self.yang_name = "site-prefixes"
                        self.yang_parent_name = "master"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                        ])
                        self.prefix_list = None
                        self._segment_path = lambda: "site-prefixes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Domain.Vrf.Master.SitePrefixes, [u'prefix_list'], name, value)


                class SourceInterface(Entity):
                    """
                    Source Interface for master controller
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Domain.Vrf.Master.SourceInterface, self).__init__()

                        self.yang_name = "source-interface"
                        self.yang_parent_name = "master"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ])
                        self.loopback = None
                        self._segment_path = lambda: "source-interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Domain.Vrf.Master.SourceInterface, [u'loopback'], name, value)


                class Class(Entity):
                    """
                    Create domain class and enter domain class command mode
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: sequence  (key)
                    
                    	Set the Sequence for the class
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: match
                    
                    	Specify the applications the policy applies to
                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Class.Match>`
                    
                    .. attribute:: path_preference
                    
                    	Specify the preferred provider
                    	**type**\:  :py:class:`PathPreference <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Class.PathPreference>`
                    
                    .. attribute:: path_last_resort
                    
                    	Specify path of last resort provider
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Domain.Vrf.Master.Class, self).__init__()

                        self.yang_name = "class"
                        self.yang_parent_name = "master"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name','sequence']
                        self._child_classes = OrderedDict([("match", ("match", Native.Domain.Vrf.Master.Class.Match)), ("path-preference", ("path_preference", Native.Domain.Vrf.Master.Class.PathPreference))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('sequence', (YLeaf(YType.uint16, 'sequence'), ['int'])),
                            ('path_last_resort', (YLeaf(YType.str, 'path-last-resort'), ['str'])),
                        ])
                        self.name = None
                        self.sequence = None
                        self.path_last_resort = None

                        self.match = Native.Domain.Vrf.Master.Class.Match()
                        self.match.parent = self
                        self._children_name_map["match"] = "match"

                        self.path_preference = Native.Domain.Vrf.Master.Class.PathPreference()
                        self.path_preference.parent = self
                        self._children_name_map["path_preference"] = "path-preference"
                        self._segment_path = lambda: "class" + "[name='" + str(self.name) + "']" + "[sequence='" + str(self.sequence) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Domain.Vrf.Master.Class, [u'name', u'sequence', u'path_last_resort'], name, value)


                    class Match(Entity):
                        """
                        Specify the applications the policy applies to
                        
                        .. attribute:: dscp
                        
                        	specify DSCP
                        	**type**\: list of  		 :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Class.Match.Dscp>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Domain.Vrf.Master.Class.Match, self).__init__()

                            self.yang_name = "match"
                            self.yang_parent_name = "class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dscp", ("dscp", Native.Domain.Vrf.Master.Class.Match.Dscp))])
                            self._leafs = OrderedDict()

                            self.dscp = YList(self)
                            self._segment_path = lambda: "match"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Domain.Vrf.Master.Class.Match, [], name, value)


                        class Dscp(Entity):
                            """
                            specify DSCP
                            
                            .. attribute:: value  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..63
                            
                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                            
                            .. attribute:: policy
                            
                            	Specify the policy (user defined/predefined)
                            	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Class.Match.Dscp.Policy>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Domain.Vrf.Master.Class.Match.Dscp, self).__init__()

                                self.yang_name = "dscp"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['value']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                    ('policy', (YLeaf(YType.enumeration, 'policy'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Domain.Vrf.Master.Class.Match.Dscp.Policy')])),
                                ])
                                self.value = None
                                self.policy = None
                                self._segment_path = lambda: "dscp" + "[value='" + str(self.value) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Domain.Vrf.Master.Class.Match.Dscp, [u'value', u'policy'], name, value)

                            class Policy(Enum):
                                """
                                Policy (Enum Class)

                                Specify the policy (user defined/predefined)

                                .. data:: best_effort = 0

                                .. data:: bulk_data = 1

                                .. data:: custom = 2

                                .. data:: low_latency_data = 3

                                .. data:: real_time_video = 4

                                .. data:: scavenger = 5

                                .. data:: voice = 6

                                """

                                best_effort = Enum.YLeaf(0, "best-effort")

                                bulk_data = Enum.YLeaf(1, "bulk-data")

                                custom = Enum.YLeaf(2, "custom")

                                low_latency_data = Enum.YLeaf(3, "low-latency-data")

                                real_time_video = Enum.YLeaf(4, "real-time-video")

                                scavenger = Enum.YLeaf(5, "scavenger")

                                voice = Enum.YLeaf(6, "voice")



                    class PathPreference(Entity):
                        """
                        Specify the preferred provider
                        
                        .. attribute:: primary
                        
                        	Primary service provider
                        	**type**\: str
                        
                        .. attribute:: primary2
                        
                        	Primary service provider
                        	**type**\: str
                        
                        .. attribute:: primary3
                        
                        	Primary service provider
                        	**type**\: str
                        
                        .. attribute:: fallback
                        
                        	Specify the fallback provider
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Fallback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Domain.Vrf.Master.Class.PathPreference.Fallback>`
                        
                        		**type**\: str
                        
                        .. attribute:: fallback2
                        
                        	Fallback service provider
                        	**type**\: str
                        
                        .. attribute:: fallback3
                        
                        	Fallback service provider
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Domain.Vrf.Master.Class.PathPreference, self).__init__()

                            self.yang_name = "path-preference"
                            self.yang_parent_name = "class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary', (YLeaf(YType.str, 'primary'), ['str'])),
                                ('primary2', (YLeaf(YType.str, 'primary2'), ['str'])),
                                ('primary3', (YLeaf(YType.str, 'primary3'), ['str'])),
                                ('fallback', (YLeaf(YType.str, 'fallback'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Domain.Vrf.Master.Class.PathPreference.Fallback'),'str'])),
                                ('fallback2', (YLeaf(YType.str, 'fallback2'), ['str'])),
                                ('fallback3', (YLeaf(YType.str, 'fallback3'), ['str'])),
                            ])
                            self.primary = None
                            self.primary2 = None
                            self.primary3 = None
                            self.fallback = None
                            self.fallback2 = None
                            self.fallback3 = None
                            self._segment_path = lambda: "path-preference"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Domain.Vrf.Master.Class.PathPreference, [u'primary', u'primary2', u'primary3', u'fallback', u'fallback2', u'fallback3'], name, value)

                        class Fallback(Enum):
                            """
                            Fallback (Enum Class)

                            Specify the fallback provider

                            .. data:: routing = 0

                            .. data:: blackhole = 1

                            """

                            routing = Enum.YLeaf(0, "routing")

                            blackhole = Enum.YLeaf(1, "blackhole")



    class Parser(Entity):
        """
        Configure parser
        
        .. attribute:: config
        
        	Configure config generation
        	**type**\:  :py:class:`Config <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.Config>`
        
        .. attribute:: view
        
        	View Commands
        	**type**\:  :py:class:`View <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Parser, self).__init__()

            self.yang_name = "parser"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("config", ("config", Native.Parser.Config)), ("view", ("view", Native.Parser.View))])
            self._leafs = OrderedDict()

            self.config = Native.Parser.Config()
            self.config.parent = self
            self._children_name_map["config"] = "config"

            self.view = Native.Parser.View()
            self.view.parent = self
            self._children_name_map["view"] = "view"
            self._segment_path = lambda: "parser"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Parser, [], name, value)


        class Config(Entity):
            """
            Configure config generation
            
            .. attribute:: cache
            
            	Cache the configuration
            	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.Config.Cache>`
            
            .. attribute:: partition
            
            	Enable configuration Partitioning
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Parser.Config, self).__init__()

                self.yang_name = "config"
                self.yang_parent_name = "parser"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('cache', (YLeaf(YType.enumeration, 'cache'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Parser.Config.Cache')])),
                    ('partition', (YLeaf(YType.empty, 'partition'), ['Empty'])),
                ])
                self.cache = None
                self.partition = None
                self._segment_path = lambda: "config"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parser/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Parser.Config, [u'cache', u'partition'], name, value)

            class Cache(Enum):
                """
                Cache (Enum Class)

                Cache the configuration

                .. data:: interface = 0

                """

                interface = Enum.YLeaf(0, "interface")



        class View(Entity):
            """
            View Commands
            
            .. attribute:: view_name_list
            
            	
            	**type**\: list of  		 :py:class:`ViewNameList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList>`
            
            .. attribute:: view_name_superview_list
            
            	
            	**type**\: list of  		 :py:class:`ViewNameSuperviewList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameSuperviewList>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Parser.View, self).__init__()

                self.yang_name = "view"
                self.yang_parent_name = "parser"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("view-name-list", ("view_name_list", Native.Parser.View.ViewNameList)), ("view-name-superview-list", ("view_name_superview_list", Native.Parser.View.ViewNameSuperviewList))])
                self._leafs = OrderedDict()

                self.view_name_list = YList(self)
                self.view_name_superview_list = YList(self)
                self._segment_path = lambda: "view"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parser/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Parser.View, [], name, value)


            class ViewNameList(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	View Name
                	**type**\: str
                
                .. attribute:: inclusive
                
                	SuperView Commands
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: secret
                
                	Set a secret for the current view
                	**type**\:  :py:class:`Secret <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Secret>`
                
                .. attribute:: commands
                
                	Configure commands for a view
                	**type**\:  :py:class:`Commands <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Parser.View.ViewNameList, self).__init__()

                    self.yang_name = "view-name-list"
                    self.yang_parent_name = "view"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("secret", ("secret", Native.Parser.View.ViewNameList.Secret)), ("commands", ("commands", Native.Parser.View.ViewNameList.Commands))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('inclusive', (YLeaf(YType.empty, 'inclusive'), ['Empty'])),
                    ])
                    self.name = None
                    self.inclusive = None

                    self.secret = Native.Parser.View.ViewNameList.Secret()
                    self.secret.parent = self
                    self._children_name_map["secret"] = "secret"

                    self.commands = Native.Parser.View.ViewNameList.Commands()
                    self.commands.parent = self
                    self._children_name_map["commands"] = "commands"
                    self._segment_path = lambda: "view-name-list" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parser/view/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Parser.View.ViewNameList, [u'name', u'inclusive'], name, value)


                class Secret(Entity):
                    """
                    Set a secret for the current view
                    
                    .. attribute:: type
                    
                    	
                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Secret.Type>`
                    
                    .. attribute:: secret
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Parser.View.ViewNameList.Secret, self).__init__()

                        self.yang_name = "secret"
                        self.yang_parent_name = "view-name-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Parser.View.ViewNameList.Secret.Type')])),
                            ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                        ])
                        self.type = None
                        self.secret = None
                        self._segment_path = lambda: "secret"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Parser.View.ViewNameList.Secret, [u'type', u'secret'], name, value)

                    class Type(Enum):
                        """
                        Type (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_5 = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_5 = Enum.YLeaf(1, "5")



                class Commands(Entity):
                    """
                    Configure commands for a view
                    
                    .. attribute:: exec_
                    
                    	Exec mode
                    	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Exec>`
                    
                    .. attribute:: configure
                    
                    	Global configuration mode
                    	**type**\:  :py:class:`Configure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Configure>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Parser.View.ViewNameList.Commands, self).__init__()

                        self.yang_name = "commands"
                        self.yang_parent_name = "view-name-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("exec", ("exec_", Native.Parser.View.ViewNameList.Commands.Exec)), ("configure", ("configure", Native.Parser.View.ViewNameList.Commands.Configure))])
                        self._leafs = OrderedDict()

                        self.exec_ = Native.Parser.View.ViewNameList.Commands.Exec()
                        self.exec_.parent = self
                        self._children_name_map["exec_"] = "exec"

                        self.configure = Native.Parser.View.ViewNameList.Commands.Configure()
                        self.configure.parent = self
                        self._children_name_map["configure"] = "configure"
                        self._segment_path = lambda: "commands"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Parser.View.ViewNameList.Commands, [], name, value)


                    class Exec(Entity):
                        """
                        Exec mode
                        
                        .. attribute:: exclude
                        
                        	Exclude the command from the view
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Exec.Exclude>`
                        
                        .. attribute:: include
                        
                        	Add command to the view
                        	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Exec.Include>`
                        
                        .. attribute:: include_exclusive
                        
                        	Include in this view but exclude from others
                        	**type**\:  :py:class:`IncludeExclusive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Exec.IncludeExclusive>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Parser.View.ViewNameList.Commands.Exec, self).__init__()

                            self.yang_name = "exec"
                            self.yang_parent_name = "commands"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Parser.View.ViewNameList.Commands.Exec.Exclude)), ("include", ("include", Native.Parser.View.ViewNameList.Commands.Exec.Include)), ("include-exclusive", ("include_exclusive", Native.Parser.View.ViewNameList.Commands.Exec.IncludeExclusive))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Parser.View.ViewNameList.Commands.Exec.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"

                            self.include = Native.Parser.View.ViewNameList.Commands.Exec.Include()
                            self.include.parent = self
                            self._children_name_map["include"] = "include"

                            self.include_exclusive = Native.Parser.View.ViewNameList.Commands.Exec.IncludeExclusive()
                            self.include_exclusive.parent = self
                            self._children_name_map["include_exclusive"] = "include-exclusive"
                            self._segment_path = lambda: "exec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Exec, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude the command from the view
                            
                            .. attribute:: command_list
                            
                            	
                            	**type**\: list of  		 :py:class:`CommandList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Exec.Exclude.CommandList>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Parser.View.ViewNameList.Commands.Exec.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "exec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("command-list", ("command_list", Native.Parser.View.ViewNameList.Commands.Exec.Exclude.CommandList))])
                                self._leafs = OrderedDict()

                                self.command_list = YList(self)
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Exec.Exclude, [], name, value)


                            class CommandList(Entity):
                                """
                                
                                
                                .. attribute:: command  (key)
                                
                                	Keywords of the command
                                	**type**\: str
                                
                                .. attribute:: all
                                
                                	wild card support
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Parser.View.ViewNameList.Commands.Exec.Exclude.CommandList, self).__init__()

                                    self.yang_name = "command-list"
                                    self.yang_parent_name = "exclude"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['command']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ])
                                    self.command = None
                                    self.all = None
                                    self._segment_path = lambda: "command-list" + "[command='" + str(self.command) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Exec.Exclude.CommandList, [u'command', u'all'], name, value)


                        class Include(Entity):
                            """
                            Add command to the view
                            
                            .. attribute:: command_list
                            
                            	
                            	**type**\: list of  		 :py:class:`CommandList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Exec.Include.CommandList>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Parser.View.ViewNameList.Commands.Exec.Include, self).__init__()

                                self.yang_name = "include"
                                self.yang_parent_name = "exec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("command-list", ("command_list", Native.Parser.View.ViewNameList.Commands.Exec.Include.CommandList))])
                                self._leafs = OrderedDict()

                                self.command_list = YList(self)
                                self._segment_path = lambda: "include"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Exec.Include, [], name, value)


                            class CommandList(Entity):
                                """
                                
                                
                                .. attribute:: command  (key)
                                
                                	Keywords of the command
                                	**type**\: str
                                
                                .. attribute:: all
                                
                                	wild card support
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Parser.View.ViewNameList.Commands.Exec.Include.CommandList, self).__init__()

                                    self.yang_name = "command-list"
                                    self.yang_parent_name = "include"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['command']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ])
                                    self.command = None
                                    self.all = None
                                    self._segment_path = lambda: "command-list" + "[command='" + str(self.command) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Exec.Include.CommandList, [u'command', u'all'], name, value)


                        class IncludeExclusive(Entity):
                            """
                            Include in this view but exclude from others
                            
                            .. attribute:: command_list
                            
                            	
                            	**type**\: list of  		 :py:class:`CommandList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Exec.IncludeExclusive.CommandList>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Parser.View.ViewNameList.Commands.Exec.IncludeExclusive, self).__init__()

                                self.yang_name = "include-exclusive"
                                self.yang_parent_name = "exec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("command-list", ("command_list", Native.Parser.View.ViewNameList.Commands.Exec.IncludeExclusive.CommandList))])
                                self._leafs = OrderedDict()

                                self.command_list = YList(self)
                                self._segment_path = lambda: "include-exclusive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Exec.IncludeExclusive, [], name, value)


                            class CommandList(Entity):
                                """
                                
                                
                                .. attribute:: command  (key)
                                
                                	Keywords of the command
                                	**type**\: str
                                
                                .. attribute:: all
                                
                                	wild card support
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Parser.View.ViewNameList.Commands.Exec.IncludeExclusive.CommandList, self).__init__()

                                    self.yang_name = "command-list"
                                    self.yang_parent_name = "include-exclusive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['command']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ])
                                    self.command = None
                                    self.all = None
                                    self._segment_path = lambda: "command-list" + "[command='" + str(self.command) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Exec.IncludeExclusive.CommandList, [u'command', u'all'], name, value)


                    class Configure(Entity):
                        """
                        Global configuration mode
                        
                        .. attribute:: exclude
                        
                        	Exclude the command from the view
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Configure.Exclude>`
                        
                        .. attribute:: include
                        
                        	Add command to the view
                        	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Configure.Include>`
                        
                        .. attribute:: include_exclusive
                        
                        	Include in this view but exclude from others
                        	**type**\:  :py:class:`IncludeExclusive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Configure.IncludeExclusive>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Parser.View.ViewNameList.Commands.Configure, self).__init__()

                            self.yang_name = "configure"
                            self.yang_parent_name = "commands"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Parser.View.ViewNameList.Commands.Configure.Exclude)), ("include", ("include", Native.Parser.View.ViewNameList.Commands.Configure.Include)), ("include-exclusive", ("include_exclusive", Native.Parser.View.ViewNameList.Commands.Configure.IncludeExclusive))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Parser.View.ViewNameList.Commands.Configure.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"

                            self.include = Native.Parser.View.ViewNameList.Commands.Configure.Include()
                            self.include.parent = self
                            self._children_name_map["include"] = "include"

                            self.include_exclusive = Native.Parser.View.ViewNameList.Commands.Configure.IncludeExclusive()
                            self.include_exclusive.parent = self
                            self._children_name_map["include_exclusive"] = "include-exclusive"
                            self._segment_path = lambda: "configure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Configure, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude the command from the view
                            
                            .. attribute:: command_list
                            
                            	
                            	**type**\: list of  		 :py:class:`CommandList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Configure.Exclude.CommandList>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Parser.View.ViewNameList.Commands.Configure.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "configure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("command-list", ("command_list", Native.Parser.View.ViewNameList.Commands.Configure.Exclude.CommandList))])
                                self._leafs = OrderedDict()

                                self.command_list = YList(self)
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Configure.Exclude, [], name, value)


                            class CommandList(Entity):
                                """
                                
                                
                                .. attribute:: command  (key)
                                
                                	Keywords of the command
                                	**type**\: str
                                
                                .. attribute:: all
                                
                                	wild card support
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Parser.View.ViewNameList.Commands.Configure.Exclude.CommandList, self).__init__()

                                    self.yang_name = "command-list"
                                    self.yang_parent_name = "exclude"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['command']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ])
                                    self.command = None
                                    self.all = None
                                    self._segment_path = lambda: "command-list" + "[command='" + str(self.command) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Configure.Exclude.CommandList, [u'command', u'all'], name, value)


                        class Include(Entity):
                            """
                            Add command to the view
                            
                            .. attribute:: command_list
                            
                            	
                            	**type**\: list of  		 :py:class:`CommandList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Configure.Include.CommandList>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Parser.View.ViewNameList.Commands.Configure.Include, self).__init__()

                                self.yang_name = "include"
                                self.yang_parent_name = "configure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("command-list", ("command_list", Native.Parser.View.ViewNameList.Commands.Configure.Include.CommandList))])
                                self._leafs = OrderedDict()

                                self.command_list = YList(self)
                                self._segment_path = lambda: "include"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Configure.Include, [], name, value)


                            class CommandList(Entity):
                                """
                                
                                
                                .. attribute:: command  (key)
                                
                                	Keywords of the command
                                	**type**\: str
                                
                                .. attribute:: all
                                
                                	wild card support
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Parser.View.ViewNameList.Commands.Configure.Include.CommandList, self).__init__()

                                    self.yang_name = "command-list"
                                    self.yang_parent_name = "include"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['command']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ])
                                    self.command = None
                                    self.all = None
                                    self._segment_path = lambda: "command-list" + "[command='" + str(self.command) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Configure.Include.CommandList, [u'command', u'all'], name, value)


                        class IncludeExclusive(Entity):
                            """
                            Include in this view but exclude from others
                            
                            .. attribute:: command_list
                            
                            	
                            	**type**\: list of  		 :py:class:`CommandList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList.Commands.Configure.IncludeExclusive.CommandList>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Parser.View.ViewNameList.Commands.Configure.IncludeExclusive, self).__init__()

                                self.yang_name = "include-exclusive"
                                self.yang_parent_name = "configure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("command-list", ("command_list", Native.Parser.View.ViewNameList.Commands.Configure.IncludeExclusive.CommandList))])
                                self._leafs = OrderedDict()

                                self.command_list = YList(self)
                                self._segment_path = lambda: "include-exclusive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Configure.IncludeExclusive, [], name, value)


                            class CommandList(Entity):
                                """
                                
                                
                                .. attribute:: command  (key)
                                
                                	Keywords of the command
                                	**type**\: str
                                
                                .. attribute:: all
                                
                                	wild card support
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Parser.View.ViewNameList.Commands.Configure.IncludeExclusive.CommandList, self).__init__()

                                    self.yang_name = "command-list"
                                    self.yang_parent_name = "include-exclusive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['command']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ])
                                    self.command = None
                                    self.all = None
                                    self._segment_path = lambda: "command-list" + "[command='" + str(self.command) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Parser.View.ViewNameList.Commands.Configure.IncludeExclusive.CommandList, [u'command', u'all'], name, value)


            class ViewNameSuperviewList(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	View Name
                	**type**\: str
                
                .. attribute:: superview
                
                	SuperView Commands
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: secret
                
                	Set a secret for the current view
                	**type**\:  :py:class:`Secret <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameSuperviewList.Secret>`
                
                .. attribute:: view
                
                	View Name
                	**type**\: list of  		 :py:class:`View_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameSuperviewList.View_>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Parser.View.ViewNameSuperviewList, self).__init__()

                    self.yang_name = "view-name-superview-list"
                    self.yang_parent_name = "view"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("secret", ("secret", Native.Parser.View.ViewNameSuperviewList.Secret)), ("view", ("view", Native.Parser.View.ViewNameSuperviewList.View_))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('superview', (YLeaf(YType.empty, 'superview'), ['Empty'])),
                    ])
                    self.name = None
                    self.superview = None

                    self.secret = Native.Parser.View.ViewNameSuperviewList.Secret()
                    self.secret.parent = self
                    self._children_name_map["secret"] = "secret"

                    self.view = YList(self)
                    self._segment_path = lambda: "view-name-superview-list" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parser/view/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Parser.View.ViewNameSuperviewList, [u'name', u'superview'], name, value)


                class Secret(Entity):
                    """
                    Set a secret for the current view
                    
                    .. attribute:: type
                    
                    	
                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameSuperviewList.Secret.Type>`
                    
                    .. attribute:: secret
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Parser.View.ViewNameSuperviewList.Secret, self).__init__()

                        self.yang_name = "secret"
                        self.yang_parent_name = "view-name-superview-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Parser.View.ViewNameSuperviewList.Secret.Type')])),
                            ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                        ])
                        self.type = None
                        self.secret = None
                        self._segment_path = lambda: "secret"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Parser.View.ViewNameSuperviewList.Secret, [u'type', u'secret'], name, value)

                    class Type(Enum):
                        """
                        Type (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_5 = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_5 = Enum.YLeaf(1, "5")



                class View_(Entity):
                    """
                    View Name
                    
                    .. attribute:: view_name  (key)
                    
                    	
                    	**type**\: str
                    
                    	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Parser.View.ViewNameList>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Parser.View.ViewNameSuperviewList.View_, self).__init__()

                        self.yang_name = "view"
                        self.yang_parent_name = "view-name-superview-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['view_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('view_name', (YLeaf(YType.str, 'view-name'), ['str'])),
                        ])
                        self.view_name = None
                        self._segment_path = lambda: "view" + "[view-name='" + str(self.view_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Parser.View.ViewNameSuperviewList.View_, [u'view_name'], name, value)


    class Service(Entity):
        """
        Modify use of network based services
        
        .. attribute:: internal
        
        	Enable/Disable Internal commands
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: pad_conf
        
        	
        	**type**\:  :py:class:`PadConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.PadConf>`
        
        .. attribute:: pad
        
        	Enable PAD commands
        	**type**\:  :py:class:`Pad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Pad>`
        
        	**presence node**\: True
        
        .. attribute:: password_encryption
        
        	Encrypt system passwords
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: password_recovery
        
        	Enable password recovery
        	**type**\: bool
        
        .. attribute:: timestamps
        
        	Timestamp debug/log messages
        	**type**\:  :py:class:`Timestamps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps>`
        
        	**presence node**\: True
        
        .. attribute:: alignment
        
        	Control alignment correction and logging
        	**type**\:  :py:class:`Alignment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Alignment>`
        
        .. attribute:: call_home
        
        	Enable call\-home service
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: compress_config
        
        	Compress the configuration file
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: config
        
        	TFTP load config files
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: counters
        
        	Control aging of interface counters
        	**type**\:  :py:class:`Counters <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Counters>`
        
        .. attribute:: dhcp
        
        	Enable DHCP server and relay agent
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: disable_ip_fast_frag
        
        	Disable IP particle\-based fast fragmentation
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: exec_callback
        
        	Enable exec callback
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: exec_wait
        
        	Delay EXEC startup on noisy lines
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: finger
        
        	Allow responses to finger requests
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: heartbeat
        
        	Enable heartbeat processing
        	**type**\:  :py:class:`Heartbeat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Heartbeat>`
        
        .. attribute:: hide_telnet_addresses
        
        	Hide destination addresses in telnet command
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: linenumber
        
        	enable line number banner for each exec
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: log_hidden
        
        	Enable syslog msgs for hidden/internal commands
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: nagle
        
        	Enable Nagle's congestion control algorithm
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: old_slip_prompts
        
        	Allow old scripts to operate with slip/ppp
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: prompt
        
        	Enable mode specific prompt
        	**type**\:  :py:class:`Prompt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Prompt>`
        
        .. attribute:: pt_vty_logging
        
        	Log significant VTY\-Async events
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: sequence_numbers
        
        	Stamp logger messages with a sequence number
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: slave_log
        
        	Enable log capability of slave IPs
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: tcp_keepalives_in
        
        	Generate keepalives on idle incoming network connections
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: tcp_keepalives_out
        
        	Generate keepalives on idle outgoing network connections
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: telnet_zeroidle
        
        	Set TCP window 0 when connection is idle
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: tcp_small_servers
        
        	Enable small TCP servers (e.g., ECHO)
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: udp_small_servers
        
        	Enable small UDP servers (e.g., ECHO)
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: unsupported_transceiver
        
        	Enable support for third\-party transceivers
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Service, self).__init__()

            self.yang_name = "service"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("pad-conf", ("pad_conf", Native.Service.PadConf)), ("pad", ("pad", Native.Service.Pad)), ("timestamps", ("timestamps", Native.Service.Timestamps)), ("alignment", ("alignment", Native.Service.Alignment)), ("counters", ("counters", Native.Service.Counters)), ("heartbeat", ("heartbeat", Native.Service.Heartbeat)), ("prompt", ("prompt", Native.Service.Prompt))])
            self._leafs = OrderedDict([
                ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                ('password_encryption', (YLeaf(YType.empty, 'password-encryption'), ['Empty'])),
                ('password_recovery', (YLeaf(YType.boolean, 'password-recovery'), ['bool'])),
                ('call_home', (YLeaf(YType.empty, 'call-home'), ['Empty'])),
                ('compress_config', (YLeaf(YType.empty, 'compress-config'), ['Empty'])),
                ('config', (YLeaf(YType.empty, 'config'), ['Empty'])),
                ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                ('disable_ip_fast_frag', (YLeaf(YType.empty, 'disable-ip-fast-frag'), ['Empty'])),
                ('exec_callback', (YLeaf(YType.empty, 'exec-callback'), ['Empty'])),
                ('exec_wait', (YLeaf(YType.empty, 'exec-wait'), ['Empty'])),
                ('finger', (YLeaf(YType.empty, 'finger'), ['Empty'])),
                ('hide_telnet_addresses', (YLeaf(YType.empty, 'hide-telnet-addresses'), ['Empty'])),
                ('linenumber', (YLeaf(YType.empty, 'linenumber'), ['Empty'])),
                ('log_hidden', (YLeaf(YType.empty, 'log-hidden'), ['Empty'])),
                ('nagle', (YLeaf(YType.empty, 'nagle'), ['Empty'])),
                ('old_slip_prompts', (YLeaf(YType.empty, 'old-slip-prompts'), ['Empty'])),
                ('pt_vty_logging', (YLeaf(YType.empty, 'pt-vty-logging'), ['Empty'])),
                ('sequence_numbers', (YLeaf(YType.empty, 'sequence-numbers'), ['Empty'])),
                ('slave_log', (YLeaf(YType.empty, 'slave-log'), ['Empty'])),
                ('tcp_keepalives_in', (YLeaf(YType.empty, 'tcp-keepalives-in'), ['Empty'])),
                ('tcp_keepalives_out', (YLeaf(YType.empty, 'tcp-keepalives-out'), ['Empty'])),
                ('telnet_zeroidle', (YLeaf(YType.empty, 'telnet-zeroidle'), ['Empty'])),
                ('tcp_small_servers', (YLeaf(YType.empty, 'tcp-small-servers'), ['Empty'])),
                ('udp_small_servers', (YLeaf(YType.empty, 'udp-small-servers'), ['Empty'])),
                ('unsupported_transceiver', (YLeaf(YType.empty, 'unsupported-transceiver'), ['Empty'])),
            ])
            self.internal = None
            self.password_encryption = None
            self.password_recovery = None
            self.call_home = None
            self.compress_config = None
            self.config = None
            self.dhcp = None
            self.disable_ip_fast_frag = None
            self.exec_callback = None
            self.exec_wait = None
            self.finger = None
            self.hide_telnet_addresses = None
            self.linenumber = None
            self.log_hidden = None
            self.nagle = None
            self.old_slip_prompts = None
            self.pt_vty_logging = None
            self.sequence_numbers = None
            self.slave_log = None
            self.tcp_keepalives_in = None
            self.tcp_keepalives_out = None
            self.telnet_zeroidle = None
            self.tcp_small_servers = None
            self.udp_small_servers = None
            self.unsupported_transceiver = None

            self.pad_conf = Native.Service.PadConf()
            self.pad_conf.parent = self
            self._children_name_map["pad_conf"] = "pad-conf"

            self.pad = None
            self._children_name_map["pad"] = "pad"

            self.timestamps = None
            self._children_name_map["timestamps"] = "timestamps"

            self.alignment = Native.Service.Alignment()
            self.alignment.parent = self
            self._children_name_map["alignment"] = "alignment"

            self.counters = Native.Service.Counters()
            self.counters.parent = self
            self._children_name_map["counters"] = "counters"

            self.heartbeat = Native.Service.Heartbeat()
            self.heartbeat.parent = self
            self._children_name_map["heartbeat"] = "heartbeat"

            self.prompt = Native.Service.Prompt()
            self.prompt.parent = self
            self._children_name_map["prompt"] = "prompt"
            self._segment_path = lambda: "service"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Service, [u'internal', u'password_encryption', u'password_recovery', u'call_home', u'compress_config', u'config', u'dhcp', u'disable_ip_fast_frag', u'exec_callback', u'exec_wait', u'finger', u'hide_telnet_addresses', u'linenumber', u'log_hidden', u'nagle', u'old_slip_prompts', u'pt_vty_logging', u'sequence_numbers', u'slave_log', u'tcp_keepalives_in', u'tcp_keepalives_out', u'telnet_zeroidle', u'tcp_small_servers', u'udp_small_servers', u'unsupported_transceiver'], name, value)


        class PadConf(Entity):
            """
            
            
            .. attribute:: pad
            
            	Enable PAD commands
            	**type**\: bool
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Service.PadConf, self).__init__()

                self.yang_name = "pad-conf"
                self.yang_parent_name = "service"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('pad', (YLeaf(YType.boolean, 'pad'), ['bool'])),
                ])
                self.pad = None
                self._segment_path = lambda: "pad-conf"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Service.PadConf, [u'pad'], name, value)


        class Pad(Entity):
            """
            Enable PAD commands
            
            .. attribute:: cmns
            
            	Enable PAD over CMNS connections
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: from_xot
            
            	Accept XOT to PAD connections
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: to_xot
            
            	Allow outgoing PAD over XOT connections
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Service.Pad, self).__init__()

                self.yang_name = "pad"
                self.yang_parent_name = "service"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('cmns', (YLeaf(YType.empty, 'cmns'), ['Empty'])),
                    ('from_xot', (YLeaf(YType.empty, 'from-xot'), ['Empty'])),
                    ('to_xot', (YLeaf(YType.empty, 'to-xot'), ['Empty'])),
                ])
                self.cmns = None
                self.from_xot = None
                self.to_xot = None
                self._segment_path = lambda: "pad"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Service.Pad, [u'cmns', u'from_xot', u'to_xot'], name, value)


        class Timestamps(Entity):
            """
            Timestamp debug/log messages
            
            .. attribute:: debug
            
            	Timestamp debug messages
            	**type**\:  :py:class:`Debug <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug>`
            
            .. attribute:: log
            
            	Timestamp log messages
            	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Log>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Service.Timestamps, self).__init__()

                self.yang_name = "timestamps"
                self.yang_parent_name = "service"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("debug", ("debug", Native.Service.Timestamps.Debug)), ("log", ("log", Native.Service.Timestamps.Log))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.debug = Native.Service.Timestamps.Debug()
                self.debug.parent = self
                self._children_name_map["debug"] = "debug"

                self.log = Native.Service.Timestamps.Log()
                self.log.parent = self
                self._children_name_map["log"] = "log"
                self._segment_path = lambda: "timestamps"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Service.Timestamps, [], name, value)


            class Debug(Entity):
                """
                Timestamp debug messages
                
                .. attribute:: datetime
                
                	Timestamp with date and time
                	**type**\:  :py:class:`Datetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime>`
                
                	**presence node**\: True
                
                .. attribute:: uptime
                
                	Timestamp with system uptime
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Service.Timestamps.Debug, self).__init__()

                    self.yang_name = "debug"
                    self.yang_parent_name = "timestamps"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("datetime", ("datetime", Native.Service.Timestamps.Debug.Datetime))])
                    self._leafs = OrderedDict([
                        ('uptime', (YLeaf(YType.empty, 'uptime'), ['Empty'])),
                    ])
                    self.uptime = None

                    self.datetime = None
                    self._children_name_map["datetime"] = "datetime"
                    self._segment_path = lambda: "debug"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Service.Timestamps.Debug, [u'uptime'], name, value)


                class Datetime(Entity):
                    """
                    Timestamp with date and time
                    
                    .. attribute:: localtime
                    
                    	Use local time zone for timestamps
                    	**type**\:  :py:class:`Localtime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Localtime>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: msec
                    
                    	Include milliseconds in timestamp
                    	**type**\:  :py:class:`Msec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Msec>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: show_timezone
                    
                    	Add time zone information to timestamp
                    	**type**\:  :py:class:`ShowTimezone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.ShowTimezone>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: year
                    
                    	Include year in timestamp
                    	**type**\:  :py:class:`Year <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Year>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Service.Timestamps.Debug.Datetime, self).__init__()

                        self.yang_name = "datetime"
                        self.yang_parent_name = "debug"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("localtime", ("localtime", Native.Service.Timestamps.Debug.Datetime.Localtime)), ("msec", ("msec", Native.Service.Timestamps.Debug.Datetime.Msec)), ("show-timezone", ("show_timezone", Native.Service.Timestamps.Debug.Datetime.ShowTimezone)), ("year", ("year", Native.Service.Timestamps.Debug.Datetime.Year))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.localtime = None
                        self._children_name_map["localtime"] = "localtime"

                        self.msec = None
                        self._children_name_map["msec"] = "msec"

                        self.show_timezone = None
                        self._children_name_map["show_timezone"] = "show-timezone"

                        self.year = None
                        self._children_name_map["year"] = "year"
                        self._segment_path = lambda: "datetime"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Service.Timestamps.Debug.Datetime, [], name, value)


                    class Localtime(Entity):
                        """
                        Use local time zone for timestamps
                        
                        .. attribute:: msec
                        
                        	Include milliseconds in timestamp
                        	**type**\:  :py:class:`Msec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Localtime.Msec>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: show_timezone
                        
                        	Add time zone information to timestamp
                        	**type**\:  :py:class:`ShowTimezone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Localtime.ShowTimezone>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: year
                        
                        	Include year in timestamp
                        	**type**\:  :py:class:`Year <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Localtime.Year>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Service.Timestamps.Debug.Datetime.Localtime, self).__init__()

                            self.yang_name = "localtime"
                            self.yang_parent_name = "datetime"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("msec", ("msec", Native.Service.Timestamps.Debug.Datetime.Localtime.Msec)), ("show-timezone", ("show_timezone", Native.Service.Timestamps.Debug.Datetime.Localtime.ShowTimezone)), ("year", ("year", Native.Service.Timestamps.Debug.Datetime.Localtime.Year))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.msec = None
                            self._children_name_map["msec"] = "msec"

                            self.show_timezone = None
                            self._children_name_map["show_timezone"] = "show-timezone"

                            self.year = None
                            self._children_name_map["year"] = "year"
                            self._segment_path = lambda: "localtime"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Localtime, [], name, value)


                        class Msec(Entity):
                            """
                            Include milliseconds in timestamp
                            
                            .. attribute:: show_timezone
                            
                            	Add time zone information to timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: year
                            
                            	Include year in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.Localtime.Msec, self).__init__()

                                self.yang_name = "msec"
                                self.yang_parent_name = "localtime"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('show_timezone', (YLeaf(YType.empty, 'show-timezone'), ['Empty'])),
                                    ('year', (YLeaf(YType.empty, 'year'), ['Empty'])),
                                ])
                                self.show_timezone = None
                                self.year = None
                                self._segment_path = lambda: "msec"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/localtime/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Localtime.Msec, [u'show_timezone', u'year'], name, value)


                        class ShowTimezone(Entity):
                            """
                            Add time zone information to timestamp
                            
                            .. attribute:: msec
                            
                            	Include milliseconds in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: year
                            
                            	Include year in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.Localtime.ShowTimezone, self).__init__()

                                self.yang_name = "show-timezone"
                                self.yang_parent_name = "localtime"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                                    ('year', (YLeaf(YType.empty, 'year'), ['Empty'])),
                                ])
                                self.msec = None
                                self.year = None
                                self._segment_path = lambda: "show-timezone"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/localtime/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Localtime.ShowTimezone, [u'msec', u'year'], name, value)


                        class Year(Entity):
                            """
                            Include year in timestamp
                            
                            .. attribute:: msec
                            
                            	Include milliseconds in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: show_timezone
                            
                            	Add time zone information to timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.Localtime.Year, self).__init__()

                                self.yang_name = "year"
                                self.yang_parent_name = "localtime"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                                    ('show_timezone', (YLeaf(YType.empty, 'show-timezone'), ['Empty'])),
                                ])
                                self.msec = None
                                self.show_timezone = None
                                self._segment_path = lambda: "year"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/localtime/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Localtime.Year, [u'msec', u'show_timezone'], name, value)


                    class Msec(Entity):
                        """
                        Include milliseconds in timestamp
                        
                        .. attribute:: localtime
                        
                        	Use local time zone for timestamps
                        	**type**\:  :py:class:`Localtime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Msec.Localtime>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: show_timezone
                        
                        	Add time zone information to timestamp
                        	**type**\:  :py:class:`ShowTimezone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Msec.ShowTimezone>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: year
                        
                        	Include year in timestamp
                        	**type**\:  :py:class:`Year <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Msec.Year>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Service.Timestamps.Debug.Datetime.Msec, self).__init__()

                            self.yang_name = "msec"
                            self.yang_parent_name = "datetime"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("localtime", ("localtime", Native.Service.Timestamps.Debug.Datetime.Msec.Localtime)), ("show-timezone", ("show_timezone", Native.Service.Timestamps.Debug.Datetime.Msec.ShowTimezone)), ("year", ("year", Native.Service.Timestamps.Debug.Datetime.Msec.Year))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.localtime = None
                            self._children_name_map["localtime"] = "localtime"

                            self.show_timezone = None
                            self._children_name_map["show_timezone"] = "show-timezone"

                            self.year = None
                            self._children_name_map["year"] = "year"
                            self._segment_path = lambda: "msec"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Msec, [], name, value)


                        class Localtime(Entity):
                            """
                            Use local time zone for timestamps
                            
                            .. attribute:: show_timezone
                            
                            	Add time zone information to timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: year
                            
                            	Include year in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.Msec.Localtime, self).__init__()

                                self.yang_name = "localtime"
                                self.yang_parent_name = "msec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('show_timezone', (YLeaf(YType.empty, 'show-timezone'), ['Empty'])),
                                    ('year', (YLeaf(YType.empty, 'year'), ['Empty'])),
                                ])
                                self.show_timezone = None
                                self.year = None
                                self._segment_path = lambda: "localtime"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/msec/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Msec.Localtime, [u'show_timezone', u'year'], name, value)


                        class ShowTimezone(Entity):
                            """
                            Add time zone information to timestamp
                            
                            .. attribute:: localtime
                            
                            	Use local time zone for timestamps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: year
                            
                            	Include year in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.Msec.ShowTimezone, self).__init__()

                                self.yang_name = "show-timezone"
                                self.yang_parent_name = "msec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('localtime', (YLeaf(YType.empty, 'localtime'), ['Empty'])),
                                    ('year', (YLeaf(YType.empty, 'year'), ['Empty'])),
                                ])
                                self.localtime = None
                                self.year = None
                                self._segment_path = lambda: "show-timezone"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/msec/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Msec.ShowTimezone, [u'localtime', u'year'], name, value)


                        class Year(Entity):
                            """
                            Include year in timestamp
                            
                            .. attribute:: localtime
                            
                            	Use local time zone for timestamps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: show_timezone
                            
                            	Add time zone information to timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.Msec.Year, self).__init__()

                                self.yang_name = "year"
                                self.yang_parent_name = "msec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('localtime', (YLeaf(YType.empty, 'localtime'), ['Empty'])),
                                    ('show_timezone', (YLeaf(YType.empty, 'show-timezone'), ['Empty'])),
                                ])
                                self.localtime = None
                                self.show_timezone = None
                                self._segment_path = lambda: "year"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/msec/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Msec.Year, [u'localtime', u'show_timezone'], name, value)


                    class ShowTimezone(Entity):
                        """
                        Add time zone information to timestamp
                        
                        .. attribute:: localtime
                        
                        	Use local time zone for timestamps
                        	**type**\:  :py:class:`Localtime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Localtime>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: msec
                        
                        	Include milliseconds in timestamp
                        	**type**\:  :py:class:`Msec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Msec>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: year
                        
                        	Include year in timestamp
                        	**type**\:  :py:class:`Year <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Year>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Service.Timestamps.Debug.Datetime.ShowTimezone, self).__init__()

                            self.yang_name = "show-timezone"
                            self.yang_parent_name = "datetime"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("localtime", ("localtime", Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Localtime)), ("msec", ("msec", Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Msec)), ("year", ("year", Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Year))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.localtime = None
                            self._children_name_map["localtime"] = "localtime"

                            self.msec = None
                            self._children_name_map["msec"] = "msec"

                            self.year = None
                            self._children_name_map["year"] = "year"
                            self._segment_path = lambda: "show-timezone"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.ShowTimezone, [], name, value)


                        class Localtime(Entity):
                            """
                            Use local time zone for timestamps
                            
                            .. attribute:: msec
                            
                            	Include milliseconds in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: year
                            
                            	Include year in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Localtime, self).__init__()

                                self.yang_name = "localtime"
                                self.yang_parent_name = "show-timezone"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                                    ('year', (YLeaf(YType.empty, 'year'), ['Empty'])),
                                ])
                                self.msec = None
                                self.year = None
                                self._segment_path = lambda: "localtime"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/show-timezone/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Localtime, [u'msec', u'year'], name, value)


                        class Msec(Entity):
                            """
                            Include milliseconds in timestamp
                            
                            .. attribute:: localtime
                            
                            	Use local time zone for timestamps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: year
                            
                            	Include year in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Msec, self).__init__()

                                self.yang_name = "msec"
                                self.yang_parent_name = "show-timezone"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('localtime', (YLeaf(YType.empty, 'localtime'), ['Empty'])),
                                    ('year', (YLeaf(YType.empty, 'year'), ['Empty'])),
                                ])
                                self.localtime = None
                                self.year = None
                                self._segment_path = lambda: "msec"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/show-timezone/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Msec, [u'localtime', u'year'], name, value)


                        class Year(Entity):
                            """
                            Include year in timestamp
                            
                            .. attribute:: localtime
                            
                            	Use local time zone for timestamps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: msec
                            
                            	Include milliseconds in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Year, self).__init__()

                                self.yang_name = "year"
                                self.yang_parent_name = "show-timezone"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('localtime', (YLeaf(YType.empty, 'localtime'), ['Empty'])),
                                    ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                                ])
                                self.localtime = None
                                self.msec = None
                                self._segment_path = lambda: "year"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/show-timezone/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.ShowTimezone.Year, [u'localtime', u'msec'], name, value)


                    class Year(Entity):
                        """
                        Include year in timestamp
                        
                        .. attribute:: localtime
                        
                        	Use local time zone for timestamps
                        	**type**\:  :py:class:`Localtime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Year.Localtime>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: msec
                        
                        	Include milliseconds in timestamp
                        	**type**\:  :py:class:`Msec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Year.Msec>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: show_timezone
                        
                        	Add time zone information to timestamp
                        	**type**\:  :py:class:`ShowTimezone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Debug.Datetime.Year.ShowTimezone>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Service.Timestamps.Debug.Datetime.Year, self).__init__()

                            self.yang_name = "year"
                            self.yang_parent_name = "datetime"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("localtime", ("localtime", Native.Service.Timestamps.Debug.Datetime.Year.Localtime)), ("msec", ("msec", Native.Service.Timestamps.Debug.Datetime.Year.Msec)), ("show-timezone", ("show_timezone", Native.Service.Timestamps.Debug.Datetime.Year.ShowTimezone))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.localtime = None
                            self._children_name_map["localtime"] = "localtime"

                            self.msec = None
                            self._children_name_map["msec"] = "msec"

                            self.show_timezone = None
                            self._children_name_map["show_timezone"] = "show-timezone"
                            self._segment_path = lambda: "year"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Year, [], name, value)


                        class Localtime(Entity):
                            """
                            Use local time zone for timestamps
                            
                            .. attribute:: msec
                            
                            	Include milliseconds in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: show_timezone
                            
                            	Add time zone information to timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.Year.Localtime, self).__init__()

                                self.yang_name = "localtime"
                                self.yang_parent_name = "year"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                                    ('show_timezone', (YLeaf(YType.empty, 'show-timezone'), ['Empty'])),
                                ])
                                self.msec = None
                                self.show_timezone = None
                                self._segment_path = lambda: "localtime"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/year/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Year.Localtime, [u'msec', u'show_timezone'], name, value)


                        class Msec(Entity):
                            """
                            Include milliseconds in timestamp
                            
                            .. attribute:: localtime
                            
                            	Use local time zone for timestamps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: show_timezone
                            
                            	Add time zone information to timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.Year.Msec, self).__init__()

                                self.yang_name = "msec"
                                self.yang_parent_name = "year"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('localtime', (YLeaf(YType.empty, 'localtime'), ['Empty'])),
                                    ('show_timezone', (YLeaf(YType.empty, 'show-timezone'), ['Empty'])),
                                ])
                                self.localtime = None
                                self.show_timezone = None
                                self._segment_path = lambda: "msec"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/year/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Year.Msec, [u'localtime', u'show_timezone'], name, value)


                        class ShowTimezone(Entity):
                            """
                            Add time zone information to timestamp
                            
                            .. attribute:: localtime
                            
                            	Use local time zone for timestamps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: msec
                            
                            	Include milliseconds in timestamp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Service.Timestamps.Debug.Datetime.Year.ShowTimezone, self).__init__()

                                self.yang_name = "show-timezone"
                                self.yang_parent_name = "year"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('localtime', (YLeaf(YType.empty, 'localtime'), ['Empty'])),
                                    ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                                ])
                                self.localtime = None
                                self.msec = None
                                self._segment_path = lambda: "show-timezone"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/debug/datetime/year/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Service.Timestamps.Debug.Datetime.Year.ShowTimezone, [u'localtime', u'msec'], name, value)


            class Log(Entity):
                """
                Timestamp log messages
                
                .. attribute:: datetime
                
                	Timestamp with date and time
                	**type**\:  :py:class:`Datetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Timestamps.Log.Datetime>`
                
                	**presence node**\: True
                
                .. attribute:: uptime
                
                	Timestamp with system uptime
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Service.Timestamps.Log, self).__init__()

                    self.yang_name = "log"
                    self.yang_parent_name = "timestamps"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("datetime", ("datetime", Native.Service.Timestamps.Log.Datetime))])
                    self._leafs = OrderedDict([
                        ('uptime', (YLeaf(YType.empty, 'uptime'), ['Empty'])),
                    ])
                    self.uptime = None

                    self.datetime = None
                    self._children_name_map["datetime"] = "datetime"
                    self._segment_path = lambda: "log"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Service.Timestamps.Log, [u'uptime'], name, value)


                class Datetime(Entity):
                    """
                    Timestamp with date and time
                    
                    .. attribute:: msec
                    
                    	Include milliseconds in timestamp
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: localtime
                    
                    	Use local time zone for timestamps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: show_timezone
                    
                    	Add time zone information to timestamp
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: year
                    
                    	Include year in timestamp
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Service.Timestamps.Log.Datetime, self).__init__()

                        self.yang_name = "datetime"
                        self.yang_parent_name = "log"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ('localtime', (YLeaf(YType.empty, 'localtime'), ['Empty'])),
                            ('show_timezone', (YLeaf(YType.empty, 'show-timezone'), ['Empty'])),
                            ('year', (YLeaf(YType.empty, 'year'), ['Empty'])),
                        ])
                        self.msec = None
                        self.localtime = None
                        self.show_timezone = None
                        self.year = None
                        self._segment_path = lambda: "datetime"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/timestamps/log/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Service.Timestamps.Log.Datetime, [u'msec', u'localtime', u'show_timezone', u'year'], name, value)


        class Alignment(Entity):
            """
            Control alignment correction and logging
            
            .. attribute:: detection
            
            	Enable detection of alignment issues
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: logging
            
            	Enable logging of alignment issues
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Service.Alignment, self).__init__()

                self.yang_name = "alignment"
                self.yang_parent_name = "service"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('detection', (YLeaf(YType.empty, 'detection'), ['Empty'])),
                    ('logging', (YLeaf(YType.empty, 'logging'), ['Empty'])),
                ])
                self.detection = None
                self.logging = None
                self._segment_path = lambda: "alignment"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Service.Alignment, [u'detection', u'logging'], name, value)


        class Counters(Entity):
            """
            Control aging of interface counters
            
            .. attribute:: max
            
            	Maximum counter aging threshold
            	**type**\:  :py:class:`Max <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Service.Counters.Max>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Service.Counters, self).__init__()

                self.yang_name = "counters"
                self.yang_parent_name = "service"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("max", ("max", Native.Service.Counters.Max))])
                self._leafs = OrderedDict()

                self.max = Native.Service.Counters.Max()
                self.max.parent = self
                self._children_name_map["max"] = "max"
                self._segment_path = lambda: "counters"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Service.Counters, [], name, value)


            class Max(Entity):
                """
                Maximum counter aging threshold
                
                .. attribute:: age
                
                	Aging threshold
                	**type**\: int
                
                	**range:** 0..60
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Service.Counters.Max, self).__init__()

                    self.yang_name = "max"
                    self.yang_parent_name = "counters"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('age', (YLeaf(YType.uint8, 'age'), ['int'])),
                    ])
                    self.age = None
                    self._segment_path = lambda: "max"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/counters/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Service.Counters.Max, [u'age'], name, value)


        class Heartbeat(Entity):
            """
            Enable heartbeat processing
            
            .. attribute:: fatal_count
            
            	Set heartbeat fatal count
            	**type**\: int
            
            	**range:** 1..60
            
            .. attribute:: interrupt_interval
            
            	Set heartbeat interrupt test interval
            	**type**\: int
            
            	**range:** 0..60
            
            .. attribute:: interrupt_max
            
            	Set maximum message count from interrupt test
            	**type**\: int
            
            	**range:** 0..60
            
            .. attribute:: transmit_interval
            
            	Set heartbeat transmit interval
            	**type**\: int
            
            	**range:** 1..30
            
            .. attribute:: warning_timeout
            
            	Set heartbeat warning timeout interval
            	**type**\: int
            
            	**range:** 5..60
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Service.Heartbeat, self).__init__()

                self.yang_name = "heartbeat"
                self.yang_parent_name = "service"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('fatal_count', (YLeaf(YType.uint8, 'fatal-count'), ['int'])),
                    ('interrupt_interval', (YLeaf(YType.uint8, 'interrupt-interval'), ['int'])),
                    ('interrupt_max', (YLeaf(YType.uint8, 'interrupt-max'), ['int'])),
                    ('transmit_interval', (YLeaf(YType.uint8, 'transmit-interval'), ['int'])),
                    ('warning_timeout', (YLeaf(YType.uint8, 'warning-timeout'), ['int'])),
                ])
                self.fatal_count = None
                self.interrupt_interval = None
                self.interrupt_max = None
                self.transmit_interval = None
                self.warning_timeout = None
                self._segment_path = lambda: "heartbeat"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Service.Heartbeat, [u'fatal_count', u'interrupt_interval', u'interrupt_max', u'transmit_interval', u'warning_timeout'], name, value)


        class Prompt(Entity):
            """
            Enable mode specific prompt
            
            .. attribute:: config
            
            	Enable configuration mode prompt
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Service.Prompt, self).__init__()

                self.yang_name = "prompt"
                self.yang_parent_name = "service"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('config', (YLeaf(YType.empty, 'config'), ['Empty'])),
                ])
                self.config = None
                self._segment_path = lambda: "prompt"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Service.Prompt, [u'config'], name, value)


    class Platform(Entity):
        """
        platform specific configuration
        
        .. attribute:: atm_cdvt
        
        	Configure platform atm cdvt
        	**type**\: bool
        
        .. attribute:: cfm
        
        	Configure Multi\-NNI CFM feature
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: icmp
        
        	Configure platform icmp
        	**type**\:  :py:class:`Icmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Icmp>`
        
        .. attribute:: ip_ports
        
        	Configure Kernel IP ephemeral ports
        	**type**\:  :py:class:`IpPorts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.IpPorts>`
        
        .. attribute:: bfd
        
        	Platform specific BFD commands
        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Bfd>`
        
        .. attribute:: bfd_debug_trace
        
        	
        	**type**\: int
        
        	**range:** 0..255
        
        .. attribute:: time_source
        
        	Configure time\-source
        	**type**\:  :py:class:`TimeSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.TimeSource>`
        
        .. attribute:: console
        
        	Direct IOS output to console
        	**type**\:  :py:class:`Console <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Console>`
        
        	**presence node**\: True
        
        .. attribute:: enable
        
        	
        	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Enable>`
        
        .. attribute:: external_alarm
        
        	
        	**type**\:  :py:class:`ExternalAlarm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.ExternalAlarm>`
        
        .. attribute:: hardware
        
        	Configure platform hardware
        	**type**\:  :py:class:`Hardware <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Hardware>`
        
        .. attribute:: ipsec
        
        	Platform specific ipsec command
        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Ipsec>`
        
        .. attribute:: l2vpn
        
        	Configure platform l2vpn global configuration
        	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.L2vpn>`
        
        .. attribute:: multicast
        
        	Configure multicast
        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Multicast>`
        
        .. attribute:: punt_keepalive
        
        	punt\-keepalive messages
        	**type**\:  :py:class:`PuntKeepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.PuntKeepalive>`
        
        	**presence node**\: True
        
        .. attribute:: punt_policer
        
        	Configures punt policers
        	**type**\:  :py:class:`PuntPolicer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.PuntPolicer>`
        
        .. attribute:: qos
        
        	Platform specific qos configuration
        	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Qos>`
        
        .. attribute:: reload
        
        	Platform specific reload command
        	**type**\:  :py:class:`Reload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Reload>`
        
        .. attribute:: shell
        
        	Control platform shell access command availability
        	**type**\: bool
        
        .. attribute:: tcam_parity_error
        
        	
        	**type**\:  :py:class:`TcamParityError <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.TcamParityError>`
        
        .. attribute:: urpf
        
        	Platform specific urpf commands
        	**type**\:  :py:class:`Urpf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Urpf>`
        
        .. attribute:: tcam_threshold
        
        	
        	**type**\:  :py:class:`TcamThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.TcamThreshold>`
        
        .. attribute:: trace
        
        	
        	**type**\:  :py:class:`Trace <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Trace>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Platform, self).__init__()

            self.yang_name = "platform"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-platform:icmp", ("icmp", Native.Platform.Icmp)), ("Cisco-IOS-XE-platform:ip-ports", ("ip_ports", Native.Platform.IpPorts)), ("Cisco-IOS-XE-platform:bfd", ("bfd", Native.Platform.Bfd)), ("Cisco-IOS-XE-platform:time-source", ("time_source", Native.Platform.TimeSource)), ("Cisco-IOS-XE-platform:console", ("console", Native.Platform.Console)), ("Cisco-IOS-XE-platform:enable", ("enable", Native.Platform.Enable)), ("Cisco-IOS-XE-platform:external-alarm", ("external_alarm", Native.Platform.ExternalAlarm)), ("Cisco-IOS-XE-platform:hardware", ("hardware", Native.Platform.Hardware)), ("Cisco-IOS-XE-platform:ipsec", ("ipsec", Native.Platform.Ipsec)), ("Cisco-IOS-XE-platform:l2vpn", ("l2vpn", Native.Platform.L2vpn)), ("Cisco-IOS-XE-platform:multicast", ("multicast", Native.Platform.Multicast)), ("Cisco-IOS-XE-platform:punt-keepalive", ("punt_keepalive", Native.Platform.PuntKeepalive)), ("Cisco-IOS-XE-platform:punt-policer", ("punt_policer", Native.Platform.PuntPolicer)), ("Cisco-IOS-XE-platform:qos", ("qos", Native.Platform.Qos)), ("Cisco-IOS-XE-platform:reload", ("reload", Native.Platform.Reload)), ("Cisco-IOS-XE-platform:urpf", ("urpf", Native.Platform.Urpf)), ("Cisco-IOS-XE-platform:tcam-threshold", ("tcam_threshold", Native.Platform.TcamThreshold)), ("Cisco-IOS-XE-platform:trace", ("trace", Native.Platform.Trace))])
            self._leafs = OrderedDict([
                ('atm_cdvt', (YLeaf(YType.boolean, 'Cisco-IOS-XE-platform:atm-cdvt'), ['bool'])),
                ('cfm', (YLeaf(YType.empty, 'Cisco-IOS-XE-platform:cfm'), ['Empty'])),
                ('bfd_debug_trace', (YLeaf(YType.uint8, 'Cisco-IOS-XE-platform:bfd-debug-trace'), ['int'])),
                ('shell', (YLeaf(YType.boolean, 'Cisco-IOS-XE-platform:shell'), ['bool'])),
                ('tcam_parity_error', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-platform:tcam-parity-error'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Platform.TcamParityError')])),
            ])
            self.atm_cdvt = None
            self.cfm = None
            self.bfd_debug_trace = None
            self.shell = None
            self.tcam_parity_error = None

            self.icmp = Native.Platform.Icmp()
            self.icmp.parent = self
            self._children_name_map["icmp"] = "Cisco-IOS-XE-platform:icmp"

            self.ip_ports = Native.Platform.IpPorts()
            self.ip_ports.parent = self
            self._children_name_map["ip_ports"] = "Cisco-IOS-XE-platform:ip-ports"

            self.bfd = Native.Platform.Bfd()
            self.bfd.parent = self
            self._children_name_map["bfd"] = "Cisco-IOS-XE-platform:bfd"

            self.time_source = Native.Platform.TimeSource()
            self.time_source.parent = self
            self._children_name_map["time_source"] = "Cisco-IOS-XE-platform:time-source"

            self.console = None
            self._children_name_map["console"] = "Cisco-IOS-XE-platform:console"

            self.enable = Native.Platform.Enable()
            self.enable.parent = self
            self._children_name_map["enable"] = "Cisco-IOS-XE-platform:enable"

            self.external_alarm = Native.Platform.ExternalAlarm()
            self.external_alarm.parent = self
            self._children_name_map["external_alarm"] = "Cisco-IOS-XE-platform:external-alarm"

            self.hardware = Native.Platform.Hardware()
            self.hardware.parent = self
            self._children_name_map["hardware"] = "Cisco-IOS-XE-platform:hardware"

            self.ipsec = Native.Platform.Ipsec()
            self.ipsec.parent = self
            self._children_name_map["ipsec"] = "Cisco-IOS-XE-platform:ipsec"

            self.l2vpn = Native.Platform.L2vpn()
            self.l2vpn.parent = self
            self._children_name_map["l2vpn"] = "Cisco-IOS-XE-platform:l2vpn"

            self.multicast = Native.Platform.Multicast()
            self.multicast.parent = self
            self._children_name_map["multicast"] = "Cisco-IOS-XE-platform:multicast"

            self.punt_keepalive = None
            self._children_name_map["punt_keepalive"] = "Cisco-IOS-XE-platform:punt-keepalive"

            self.punt_policer = Native.Platform.PuntPolicer()
            self.punt_policer.parent = self
            self._children_name_map["punt_policer"] = "Cisco-IOS-XE-platform:punt-policer"

            self.qos = Native.Platform.Qos()
            self.qos.parent = self
            self._children_name_map["qos"] = "Cisco-IOS-XE-platform:qos"

            self.reload = Native.Platform.Reload()
            self.reload.parent = self
            self._children_name_map["reload"] = "Cisco-IOS-XE-platform:reload"

            self.urpf = Native.Platform.Urpf()
            self.urpf.parent = self
            self._children_name_map["urpf"] = "Cisco-IOS-XE-platform:urpf"

            self.tcam_threshold = Native.Platform.TcamThreshold()
            self.tcam_threshold.parent = self
            self._children_name_map["tcam_threshold"] = "Cisco-IOS-XE-platform:tcam-threshold"

            self.trace = Native.Platform.Trace()
            self.trace.parent = self
            self._children_name_map["trace"] = "Cisco-IOS-XE-platform:trace"
            self._segment_path = lambda: "platform"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Platform, ['atm_cdvt', 'cfm', 'bfd_debug_trace', 'shell', 'tcam_parity_error'], name, value)

        class TcamParityError(Enum):
            """
            TcamParityError (Enum Class)

            .. data:: enable = 0

            .. data:: disable = 1

            """

            enable = Enum.YLeaf(0, "enable")

            disable = Enum.YLeaf(1, "disable")



        class Icmp(Entity):
            """
            Configure platform icmp
            
            .. attribute:: rate_limit
            
            	Rate limit of each ICMP types which are generated by data path
            	**type**\:  :py:class:`RateLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Icmp.RateLimit>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.Icmp, self).__init__()

                self.yang_name = "icmp"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("rate-limit", ("rate_limit", Native.Platform.Icmp.RateLimit))])
                self._leafs = OrderedDict()

                self.rate_limit = Native.Platform.Icmp.RateLimit()
                self.rate_limit.parent = self
                self._children_name_map["rate_limit"] = "rate-limit"
                self._segment_path = lambda: "Cisco-IOS-XE-platform:icmp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.Icmp, [], name, value)


            class RateLimit(Entity):
                """
                Rate limit of each ICMP types which are generated by data path
                
                .. attribute:: packet
                
                	Maximum # of packets allowed given a duration
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: duration
                
                	Duration in seconds (default value is 1 second)
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Icmp.RateLimit, self).__init__()

                    self.yang_name = "rate-limit"
                    self.yang_parent_name = "icmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('packet', (YLeaf(YType.uint32, 'packet'), ['int'])),
                        ('duration', (YLeaf(YType.uint32, 'duration'), ['int'])),
                    ])
                    self.packet = None
                    self.duration = None
                    self._segment_path = lambda: "rate-limit"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:icmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Icmp.RateLimit, ['packet', 'duration'], name, value)


        class IpPorts(Entity):
            """
            Configure Kernel IP ephemeral ports
            
            .. attribute:: ephemeral_max
            
            	Maximum value for ephemeral ports for IOS
            	**type**\: int
            
            	**range:** 49152..65534
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.IpPorts, self).__init__()

                self.yang_name = "ip-ports"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('ephemeral_max', (YLeaf(YType.uint16, 'ephemeral-max'), ['int'])),
                ])
                self.ephemeral_max = None
                self._segment_path = lambda: "Cisco-IOS-XE-platform:ip-ports"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.IpPorts, ['ephemeral_max'], name, value)


        class Bfd(Entity):
            """
            Platform specific BFD commands
            
            .. attribute:: disable_offload
            
            	Disable bfd hw offload
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: allow_svi
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: enable_offload
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.Bfd, self).__init__()

                self.yang_name = "bfd"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('disable_offload', (YLeaf(YType.empty, 'disable-offload'), ['Empty'])),
                    ('allow_svi', (YLeaf(YType.empty, 'allow-svi'), ['Empty'])),
                    ('enable_offload', (YLeaf(YType.empty, 'enable-offload'), ['Empty'])),
                ])
                self.disable_offload = None
                self.allow_svi = None
                self.enable_offload = None
                self._segment_path = lambda: "Cisco-IOS-XE-platform:bfd"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.Bfd, ['disable_offload', 'allow_svi', 'enable_offload'], name, value)


        class TimeSource(Entity):
            """
            Configure time\-source
            
            .. attribute:: ntp
            
            	Configure ntp
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.TimeSource.Ntp>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.TimeSource, self).__init__()

                self.yang_name = "time-source"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ntp", ("ntp", Native.Platform.TimeSource.Ntp))])
                self._leafs = OrderedDict()

                self.ntp = None
                self._children_name_map["ntp"] = "ntp"
                self._segment_path = lambda: "Cisco-IOS-XE-platform:time-source"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.TimeSource, [], name, value)


            class Ntp(Entity):
                """
                Configure ntp
                
                .. attribute:: time_scale
                
                	Configure ntp
                	**type**\:  :py:class:`TimeScale <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.TimeSource.Ntp.TimeScale>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.TimeSource.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "time-source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('time_scale', (YLeaf(YType.enumeration, 'time-scale'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Platform.TimeSource.Ntp.TimeScale')])),
                    ])
                    self.time_scale = None
                    self._segment_path = lambda: "ntp"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:time-source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.TimeSource.Ntp, ['time_scale'], name, value)

                class TimeScale(Enum):
                    """
                    TimeScale (Enum Class)

                    Configure ntp

                    .. data:: epoch_1900 = 0

                    .. data:: epoch_1970 = 1

                    """

                    epoch_1900 = Enum.YLeaf(0, "epoch-1900")

                    epoch_1970 = Enum.YLeaf(1, "epoch-1970")



        class Console(Entity):
            """
            Direct IOS output to console
            
            .. attribute:: output
            
            	
            	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Console.Output>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.Console, self).__init__()

                self.yang_name = "console"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('output', (YLeaf(YType.enumeration, 'output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Platform.Console.Output')])),
                ])
                self.output = None
                self._segment_path = lambda: "Cisco-IOS-XE-platform:console"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.Console, ['output'], name, value)

            class Output(Enum):
                """
                Output (Enum Class)

                .. data:: auto = 0

                .. data:: serial = 1

                .. data:: virtual = 2

                """

                auto = Enum.YLeaf(0, "auto")

                serial = Enum.YLeaf(1, "serial")

                virtual = Enum.YLeaf(2, "virtual")



        class Enable(Entity):
            """
            
            
            .. attribute:: controller
            
            	
            	**type**\: list of  		 :py:class:`Controller <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Enable.Controller>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.Enable, self).__init__()

                self.yang_name = "enable"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("controller", ("controller", Native.Platform.Enable.Controller))])
                self._leafs = OrderedDict()

                self.controller = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-platform:enable"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.Enable, [], name, value)


            class Controller(Entity):
                """
                
                
                .. attribute:: sonet  (key)
                
                	SONET
                	**type**\: str
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Enable.Controller, self).__init__()

                    self.yang_name = "controller"
                    self.yang_parent_name = "enable"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['sonet']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('sonet', (YLeaf(YType.str, 'SONET'), ['str'])),
                    ])
                    self.sonet = None
                    self._segment_path = lambda: "controller" + "[SONET='" + str(self.sonet) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:enable/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Enable.Controller, ['sonet'], name, value)


        class ExternalAlarm(Entity):
            """
            
            
            .. attribute:: line
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: alarm
            
            	
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..7
            
            		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.ExternalAlarm, self).__init__()

                self.yang_name = "external-alarm"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('line', (YLeaf(YType.uint32, 'line'), ['int'])),
                    ('alarm', (YLeaf(YType.str, 'alarm'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                ])
                self.line = None
                self.alarm = None
                self._segment_path = lambda: "Cisco-IOS-XE-platform:external-alarm"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.ExternalAlarm, ['line', 'alarm'], name, value)


        class Hardware(Entity):
            """
            Configure platform hardware
            
            .. attribute:: lite
            
            	
            	**type**\:  :py:class:`Lite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Hardware.Lite>`
            
            .. attribute:: throughput
            
            	Configure throughput
            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Hardware.Throughput>`
            
            .. attribute:: crypto_offload
            
            	Configure crypto offload
            	**type**\:  :py:class:`CryptoOffload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Hardware.CryptoOffload>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.Hardware, self).__init__()

                self.yang_name = "hardware"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("lite", ("lite", Native.Platform.Hardware.Lite)), ("throughput", ("throughput", Native.Platform.Hardware.Throughput)), ("crypto-offload", ("crypto_offload", Native.Platform.Hardware.CryptoOffload))])
                self._leafs = OrderedDict()

                self.lite = Native.Platform.Hardware.Lite()
                self.lite.parent = self
                self._children_name_map["lite"] = "lite"

                self.throughput = Native.Platform.Hardware.Throughput()
                self.throughput.parent = self
                self._children_name_map["throughput"] = "throughput"

                self.crypto_offload = Native.Platform.Hardware.CryptoOffload()
                self.crypto_offload.parent = self
                self._children_name_map["crypto_offload"] = "crypto-offload"
                self._segment_path = lambda: "Cisco-IOS-XE-platform:hardware"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.Hardware, [], name, value)


            class Lite(Entity):
                """
                
                
                .. attribute:: license
                
                	
                	**type**\:  :py:class:`License <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Hardware.Lite.License>`
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Hardware.Lite, self).__init__()

                    self.yang_name = "lite"
                    self.yang_parent_name = "hardware"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('license', (YLeaf(YType.enumeration, 'license'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Platform.Hardware.Lite.License')])),
                    ])
                    self.license = None
                    self._segment_path = lambda: "lite"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:hardware/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Hardware.Lite, ['license'], name, value)

                class License(Enum):
                    """
                    License (Enum Class)

                    .. data:: enable = 0

                    """

                    enable = Enum.YLeaf(0, "enable")



            class Throughput(Entity):
                """
                Configure throughput
                
                .. attribute:: disable
                
                	Disable throughput upgrade licenses
                	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Hardware.Throughput.Disable>`
                
                .. attribute:: level
                
                	Configure the current traffic throughput level
                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Hardware.Throughput.Level>`
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Hardware.Throughput, self).__init__()

                    self.yang_name = "throughput"
                    self.yang_parent_name = "hardware"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Platform.Hardware.Throughput.Level))])
                    self._leafs = OrderedDict([
                        ('disable', (YLeaf(YType.enumeration, 'disable'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Platform.Hardware.Throughput.Disable')])),
                    ])
                    self.disable = None

                    self.level = Native.Platform.Hardware.Throughput.Level()
                    self.level.parent = self
                    self._children_name_map["level"] = "level"
                    self._segment_path = lambda: "throughput"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:hardware/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Hardware.Throughput, ['disable'], name, value)

                class Disable(Enum):
                    """
                    Disable (Enum Class)

                    Disable throughput upgrade licenses

                    .. data:: internal_license = 0

                    """

                    internal_license = Enum.YLeaf(0, "internal-license")



                class Level(Entity):
                    """
                    Configure the current traffic throughput level
                    
                    .. attribute:: kbps
                    
                    	
                    	**type**\:  :py:class:`Kbps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Hardware.Throughput.Level.Kbps>`
                    
                    .. attribute:: eval_only
                    
                    	Use only evaluation license
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-plt'
                    _revision = '2018-05-17'

                    def __init__(self):
                        super(Native.Platform.Hardware.Throughput.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "throughput"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kbps', (YLeaf(YType.enumeration, 'kbps'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Platform.Hardware.Throughput.Level.Kbps')])),
                            ('eval_only', (YLeaf(YType.empty, 'eval-only'), ['Empty'])),
                        ])
                        self.kbps = None
                        self.eval_only = None
                        self._segment_path = lambda: "level"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:hardware/throughput/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Platform.Hardware.Throughput.Level, ['kbps', 'eval_only'], name, value)

                    class Kbps(Enum):
                        """
                        Kbps (Enum Class)

                        .. data:: Y_10000 = 0

                        .. data:: Y_25000 = 1

                        .. data:: Y_50000 = 2

                        """

                        Y_10000 = Enum.YLeaf(0, "10000")

                        Y_25000 = Enum.YLeaf(1, "25000")

                        Y_50000 = Enum.YLeaf(2, "50000")



            class CryptoOffload(Entity):
                """
                Configure crypto offload
                
                .. attribute:: enable
                
                	Enable crypto offload
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Hardware.CryptoOffload, self).__init__()

                    self.yang_name = "crypto-offload"
                    self.yang_parent_name = "hardware"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "crypto-offload"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:hardware/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Hardware.CryptoOffload, ['enable'], name, value)


        class Ipsec(Entity):
            """
            Platform specific ipsec command
            
            .. attribute:: arlog_supress
            
            	supress anti\-replay error log
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: fips_mode
            
            	enable FIPS mode
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: gdoi
            
            	gdoi
            	**type**\:  :py:class:`Gdoi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Ipsec.Gdoi>`
            
            .. attribute:: llq
            
            	config LLQ
            	**type**\:  :py:class:`Llq <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Ipsec.Llq>`
            
            .. attribute:: reassemble
            
            	reassemble packets
            	**type**\:  :py:class:`Reassemble <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Ipsec.Reassemble>`
            
            .. attribute:: flexvpn_bypass_tcam
            
            	 bypass TCAM for FlexVPN
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: modexp_throttle_window
            
            	 set modexp throttle window
            	**type**\: int
            
            	**range:** 0..32
            
            .. attribute:: control_plane
            
            	allocate extra crypto cores for control plane
            	**type**\:  :py:class:`ControlPlane <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Ipsec.ControlPlane>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.Ipsec, self).__init__()

                self.yang_name = "ipsec"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("llq", ("llq", Native.Platform.Ipsec.Llq)), ("reassemble", ("reassemble", Native.Platform.Ipsec.Reassemble))])
                self._leafs = OrderedDict([
                    ('arlog_supress', (YLeaf(YType.empty, 'arlog-supress'), ['Empty'])),
                    ('fips_mode', (YLeaf(YType.empty, 'fips-mode'), ['Empty'])),
                    ('gdoi', (YLeaf(YType.enumeration, 'gdoi'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Platform.Ipsec.Gdoi')])),
                    ('flexvpn_bypass_tcam', (YLeaf(YType.empty, 'flexvpn-bypass-tcam'), ['Empty'])),
                    ('modexp_throttle_window', (YLeaf(YType.uint8, 'modexp-throttle-window'), ['int'])),
                    ('control_plane', (YLeaf(YType.enumeration, 'control-plane'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Platform.Ipsec.ControlPlane')])),
                ])
                self.arlog_supress = None
                self.fips_mode = None
                self.gdoi = None
                self.flexvpn_bypass_tcam = None
                self.modexp_throttle_window = None
                self.control_plane = None

                self.llq = Native.Platform.Ipsec.Llq()
                self.llq.parent = self
                self._children_name_map["llq"] = "llq"

                self.reassemble = Native.Platform.Ipsec.Reassemble()
                self.reassemble.parent = self
                self._children_name_map["reassemble"] = "reassemble"
                self._segment_path = lambda: "Cisco-IOS-XE-platform:ipsec"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.Ipsec, ['arlog_supress', 'fips_mode', 'gdoi', 'flexvpn_bypass_tcam', 'modexp_throttle_window', 'control_plane'], name, value)

            class ControlPlane(Enum):
                """
                ControlPlane (Enum Class)

                allocate extra crypto cores for control plane

                .. data:: heavy = 0

                .. data:: medium = 1

                """

                heavy = Enum.YLeaf(0, "heavy")

                medium = Enum.YLeaf(1, "medium")


            class Gdoi(Enum):
                """
                Gdoi (Enum Class)

                gdoi

                .. data:: accept_both = 0

                """

                accept_both = Enum.YLeaf(0, "accept-both")



            class Llq(Entity):
                """
                config LLQ
                
                .. attribute:: qos_group
                
                	config LLQ QoS Group
                	**type**\: int
                
                	**range:** 1..99
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Ipsec.Llq, self).__init__()

                    self.yang_name = "llq"
                    self.yang_parent_name = "ipsec"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                    ])
                    self.qos_group = None
                    self._segment_path = lambda: "llq"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:ipsec/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Ipsec.Llq, ['qos_group'], name, value)


            class Reassemble(Entity):
                """
                reassemble packets
                
                .. attribute:: transit
                
                	transit IPSEC packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Ipsec.Reassemble, self).__init__()

                    self.yang_name = "reassemble"
                    self.yang_parent_name = "ipsec"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('transit', (YLeaf(YType.empty, 'transit'), ['Empty'])),
                    ])
                    self.transit = None
                    self._segment_path = lambda: "reassemble"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:ipsec/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Ipsec.Reassemble, ['transit'], name, value)


        class L2vpn(Entity):
            """
            Configure platform l2vpn global configuration
            
            .. attribute:: hdlc_pass_through
            
            	l2vpn HDLC force pass through
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: statistics
            
            	l2vpn statistics
            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.L2vpn.Statistics>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.L2vpn, self).__init__()

                self.yang_name = "l2vpn"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("statistics", ("statistics", Native.Platform.L2vpn.Statistics))])
                self._leafs = OrderedDict([
                    ('hdlc_pass_through', (YLeaf(YType.empty, 'hdlc-pass-through'), ['Empty'])),
                ])
                self.hdlc_pass_through = None

                self.statistics = Native.Platform.L2vpn.Statistics()
                self.statistics.parent = self
                self._children_name_map["statistics"] = "statistics"
                self._segment_path = lambda: "Cisco-IOS-XE-platform:l2vpn"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.L2vpn, ['hdlc_pass_through'], name, value)


            class Statistics(Entity):
                """
                l2vpn statistics
                
                .. attribute:: enable
                
                	enable the stats
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.L2vpn.Statistics, self).__init__()

                    self.yang_name = "statistics"
                    self.yang_parent_name = "l2vpn"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:l2vpn/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.L2vpn.Statistics, ['enable'], name, value)


        class Multicast(Entity):
            """
            Configure multicast
            
            .. attribute:: mgre
            
            	Multi\-point GRE tunnel
            	**type**\:  :py:class:`Mgre <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Multicast.Mgre>`
            
            .. attribute:: oce
            
            	multicast oce
            	**type**\:  :py:class:`Oce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Multicast.Oce>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.Multicast, self).__init__()

                self.yang_name = "multicast"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("mgre", ("mgre", Native.Platform.Multicast.Mgre)), ("oce", ("oce", Native.Platform.Multicast.Oce))])
                self._leafs = OrderedDict()

                self.mgre = Native.Platform.Multicast.Mgre()
                self.mgre.parent = self
                self._children_name_map["mgre"] = "mgre"

                self.oce = Native.Platform.Multicast.Oce()
                self.oce.parent = self
                self._children_name_map["oce"] = "oce"
                self._segment_path = lambda: "Cisco-IOS-XE-platform:multicast"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.Multicast, [], name, value)


            class Mgre(Entity):
                """
                Multi\-point GRE tunnel
                
                .. attribute:: injection
                
                	Enable packet injection
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Multicast.Mgre, self).__init__()

                    self.yang_name = "mgre"
                    self.yang_parent_name = "multicast"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('injection', (YLeaf(YType.empty, 'injection'), ['Empty'])),
                    ])
                    self.injection = None
                    self._segment_path = lambda: "mgre"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:multicast/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Multicast.Mgre, ['injection'], name, value)


            class Oce(Entity):
                """
                multicast oce
                
                .. attribute:: flag
                
                	multicast oce flag
                	**type**\:  :py:class:`Flag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Multicast.Oce.Flag>`
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Multicast.Oce, self).__init__()

                    self.yang_name = "oce"
                    self.yang_parent_name = "multicast"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flag", ("flag", Native.Platform.Multicast.Oce.Flag))])
                    self._leafs = OrderedDict()

                    self.flag = Native.Platform.Multicast.Oce.Flag()
                    self.flag.parent = self
                    self._children_name_map["flag"] = "flag"
                    self._segment_path = lambda: "oce"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:multicast/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Multicast.Oce, [], name, value)


                class Flag(Entity):
                    """
                    multicast oce flag
                    
                    .. attribute:: suppress
                    
                    	Enable oce flag suppress
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-plt'
                    _revision = '2018-05-17'

                    def __init__(self):
                        super(Native.Platform.Multicast.Oce.Flag, self).__init__()

                        self.yang_name = "flag"
                        self.yang_parent_name = "oce"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('suppress', (YLeaf(YType.empty, 'suppress'), ['Empty'])),
                        ])
                        self.suppress = None
                        self._segment_path = lambda: "flag"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:multicast/oce/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Platform.Multicast.Oce.Flag, ['suppress'], name, value)


        class PuntKeepalive(Entity):
            """
            punt\-keepalive messages
            
            .. attribute:: disable_kernel_core
            
            	Disable IOSXE kernel core generation for keepalive fault
            	**type**\: bool
            
            .. attribute:: settings
            
            	Set the keepalive parameters
            	**type**\:  :py:class:`Settings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.PuntKeepalive.Settings>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.PuntKeepalive, self).__init__()

                self.yang_name = "punt-keepalive"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("settings", ("settings", Native.Platform.PuntKeepalive.Settings))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('disable_kernel_core', (YLeaf(YType.boolean, 'disable-kernel-core'), ['bool'])),
                ])
                self.disable_kernel_core = None

                self.settings = Native.Platform.PuntKeepalive.Settings()
                self.settings.parent = self
                self._children_name_map["settings"] = "settings"
                self._segment_path = lambda: "Cisco-IOS-XE-platform:punt-keepalive"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.PuntKeepalive, ['disable_kernel_core'], name, value)


            class Settings(Entity):
                """
                Set the keepalive parameters
                
                .. attribute:: fatal_count
                
                	Set punt\-inject keepalive fatal count
                	**type**\: int
                
                	**range:** 15..60
                
                .. attribute:: transmit_interval
                
                	Set punt\-inject keepalive transmit interval
                	**type**\: int
                
                	**range:** 2..30
                
                .. attribute:: warning_count
                
                	Set punt\-inject keepalive warning count
                	**type**\: int
                
                	**range:** 10..60
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.PuntKeepalive.Settings, self).__init__()

                    self.yang_name = "settings"
                    self.yang_parent_name = "punt-keepalive"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fatal_count', (YLeaf(YType.uint16, 'fatal-count'), ['int'])),
                        ('transmit_interval', (YLeaf(YType.uint16, 'transmit-interval'), ['int'])),
                        ('warning_count', (YLeaf(YType.uint16, 'warning-count'), ['int'])),
                    ])
                    self.fatal_count = None
                    self.transmit_interval = None
                    self.warning_count = None
                    self._segment_path = lambda: "settings"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:punt-keepalive/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.PuntKeepalive.Settings, ['fatal_count', 'transmit_interval', 'warning_count'], name, value)


        class PuntPolicer(Entity):
            """
            Configures punt policers
            
            .. attribute:: punt_num
            
            	Configure punt cause to be policed
            	**type**\: list of  		 :py:class:`PuntNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.PuntPolicer.PuntNum>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.PuntPolicer, self).__init__()

                self.yang_name = "punt-policer"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("punt-num", ("punt_num", Native.Platform.PuntPolicer.PuntNum))])
                self._leafs = OrderedDict()

                self.punt_num = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-platform:punt-policer"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.PuntPolicer, [], name, value)


            class PuntNum(Entity):
                """
                Configure punt cause to be policed
                
                .. attribute:: cause  (key)
                
                	
                	**type**\: int
                
                	**range:** 1..89
                
                .. attribute:: max_rate
                
                	
                	**type**\: int
                
                	**range:** 10..32000
                
                .. attribute:: high
                
                	High priority traffic only
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.PuntPolicer.PuntNum, self).__init__()

                    self.yang_name = "punt-num"
                    self.yang_parent_name = "punt-policer"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['cause']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('cause', (YLeaf(YType.uint8, 'cause'), ['int'])),
                        ('max_rate', (YLeaf(YType.uint16, 'max-rate'), ['int'])),
                        ('high', (YLeaf(YType.empty, 'high'), ['Empty'])),
                    ])
                    self.cause = None
                    self.max_rate = None
                    self.high = None
                    self._segment_path = lambda: "punt-num" + "[cause='" + str(self.cause) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:punt-policer/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.PuntPolicer.PuntNum, ['cause', 'max_rate', 'high'], name, value)


        class Qos(Entity):
            """
            Platform specific qos configuration
            
            .. attribute:: cac_policer
            
            	packet per second
            	**type**\: int
            
            	**range:** 1..10000
            
            .. attribute:: marker_statistics
            
            	Configure marking statistics
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: match_statistics
            
            	Configure match stats
            	**type**\:  :py:class:`MatchStatistics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Qos.MatchStatistics>`
            
            .. attribute:: performance_monitor
            
            	Configure performance\-monitor statistics
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: punt_path_matching
            
            	Configure punt\-path matching on input interface (PPPoE\-Discovery, PPPoE\-PPP\-LCP)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.Qos, self).__init__()

                self.yang_name = "qos"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("match-statistics", ("match_statistics", Native.Platform.Qos.MatchStatistics))])
                self._leafs = OrderedDict([
                    ('cac_policer', (YLeaf(YType.uint16, 'cac-policer'), ['int'])),
                    ('marker_statistics', (YLeaf(YType.empty, 'marker-statistics'), ['Empty'])),
                    ('performance_monitor', (YLeaf(YType.empty, 'performance-monitor'), ['Empty'])),
                    ('punt_path_matching', (YLeaf(YType.empty, 'punt-path-matching'), ['Empty'])),
                ])
                self.cac_policer = None
                self.marker_statistics = None
                self.performance_monitor = None
                self.punt_path_matching = None

                self.match_statistics = Native.Platform.Qos.MatchStatistics()
                self.match_statistics.parent = self
                self._children_name_map["match_statistics"] = "match-statistics"
                self._segment_path = lambda: "Cisco-IOS-XE-platform:qos"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.Qos, ['cac_policer', 'marker_statistics', 'performance_monitor', 'punt_path_matching'], name, value)


            class MatchStatistics(Entity):
                """
                Configure match stats
                
                .. attribute:: per_filter
                
                	Configure per\-filter match statistics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: per_ace
                
                	Configure per\-ace match statistics (per\-filter must be enabled first)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Qos.MatchStatistics, self).__init__()

                    self.yang_name = "match-statistics"
                    self.yang_parent_name = "qos"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('per_filter', (YLeaf(YType.empty, 'per-filter'), ['Empty'])),
                        ('per_ace', (YLeaf(YType.empty, 'per-ace'), ['Empty'])),
                    ])
                    self.per_filter = None
                    self.per_ace = None
                    self._segment_path = lambda: "match-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:qos/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Qos.MatchStatistics, ['per_filter', 'per_ace'], name, value)


        class Reload(Entity):
            """
            Platform specific reload command
            
            .. attribute:: immediate
            
            	Immediately stop forwarding traffic
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.Reload, self).__init__()

                self.yang_name = "reload"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('immediate', (YLeaf(YType.empty, 'immediate'), ['Empty'])),
                ])
                self.immediate = None
                self._segment_path = lambda: "Cisco-IOS-XE-platform:reload"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.Reload, ['immediate'], name, value)


        class Urpf(Entity):
            """
            Platform specific urpf commands
            
            .. attribute:: loose
            
            	uRPF loose mode
            	**type**\:  :py:class:`Loose <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Urpf.Loose>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.Urpf, self).__init__()

                self.yang_name = "urpf"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("loose", ("loose", Native.Platform.Urpf.Loose))])
                self._leafs = OrderedDict()

                self.loose = Native.Platform.Urpf.Loose()
                self.loose.parent = self
                self._children_name_map["loose"] = "loose"
                self._segment_path = lambda: "Cisco-IOS-XE-platform:urpf"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.Urpf, [], name, value)


            class Loose(Entity):
                """
                uRPF loose mode
                
                .. attribute:: counter
                
                	drop counter
                	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Urpf.Loose.Counter>`
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Urpf.Loose, self).__init__()

                    self.yang_name = "loose"
                    self.yang_parent_name = "urpf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("counter", ("counter", Native.Platform.Urpf.Loose.Counter))])
                    self._leafs = OrderedDict()

                    self.counter = Native.Platform.Urpf.Loose.Counter()
                    self.counter.parent = self
                    self._children_name_map["counter"] = "counter"
                    self._segment_path = lambda: "loose"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:urpf/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Urpf.Loose, [], name, value)


                class Counter(Entity):
                    """
                    drop counter
                    
                    .. attribute:: ipv4
                    
                    	ipv4 protocol
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Urpf.Loose.Counter.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	ipv6 protocol
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Urpf.Loose.Counter.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-plt'
                    _revision = '2018-05-17'

                    def __init__(self):
                        super(Native.Platform.Urpf.Loose.Counter, self).__init__()

                        self.yang_name = "counter"
                        self.yang_parent_name = "loose"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Platform.Urpf.Loose.Counter.Ipv4)), ("ipv6", ("ipv6", Native.Platform.Urpf.Loose.Counter.Ipv6))])
                        self._leafs = OrderedDict()

                        self.ipv4 = Native.Platform.Urpf.Loose.Counter.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Platform.Urpf.Loose.Counter.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"
                        self._segment_path = lambda: "counter"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:urpf/loose/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Platform.Urpf.Loose.Counter, [], name, value)


                    class Ipv4(Entity):
                        """
                        ipv4 protocol
                        
                        .. attribute:: supress
                        
                        	supress drop
                        	**type**\:  :py:class:`Supress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Urpf.Loose.Counter.Ipv4.Supress>`
                        
                        

                        """

                        _prefix = 'ios-plt'
                        _revision = '2018-05-17'

                        def __init__(self):
                            super(Native.Platform.Urpf.Loose.Counter.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "counter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("supress", ("supress", Native.Platform.Urpf.Loose.Counter.Ipv4.Supress))])
                            self._leafs = OrderedDict()

                            self.supress = Native.Platform.Urpf.Loose.Counter.Ipv4.Supress()
                            self.supress.parent = self
                            self._children_name_map["supress"] = "supress"
                            self._segment_path = lambda: "ipv4"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:urpf/loose/counter/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Platform.Urpf.Loose.Counter.Ipv4, [], name, value)


                        class Supress(Entity):
                            """
                            supress drop
                            
                            .. attribute:: asymmetric_only
                            
                            	it works only for asymmetric traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-plt'
                            _revision = '2018-05-17'

                            def __init__(self):
                                super(Native.Platform.Urpf.Loose.Counter.Ipv4.Supress, self).__init__()

                                self.yang_name = "supress"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('asymmetric_only', (YLeaf(YType.empty, 'asymmetric_only'), ['Empty'])),
                                ])
                                self.asymmetric_only = None
                                self._segment_path = lambda: "supress"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:urpf/loose/counter/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Platform.Urpf.Loose.Counter.Ipv4.Supress, ['asymmetric_only'], name, value)


                    class Ipv6(Entity):
                        """
                        ipv6 protocol
                        
                        .. attribute:: supress
                        
                        	supress drop
                        	**type**\:  :py:class:`Supress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Urpf.Loose.Counter.Ipv6.Supress>`
                        
                        

                        """

                        _prefix = 'ios-plt'
                        _revision = '2018-05-17'

                        def __init__(self):
                            super(Native.Platform.Urpf.Loose.Counter.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "counter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("supress", ("supress", Native.Platform.Urpf.Loose.Counter.Ipv6.Supress))])
                            self._leafs = OrderedDict()

                            self.supress = Native.Platform.Urpf.Loose.Counter.Ipv6.Supress()
                            self.supress.parent = self
                            self._children_name_map["supress"] = "supress"
                            self._segment_path = lambda: "ipv6"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:urpf/loose/counter/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Platform.Urpf.Loose.Counter.Ipv6, [], name, value)


                        class Supress(Entity):
                            """
                            supress drop
                            
                            .. attribute:: asymmetric_only
                            
                            	it works only for asymmetric traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-plt'
                            _revision = '2018-05-17'

                            def __init__(self):
                                super(Native.Platform.Urpf.Loose.Counter.Ipv6.Supress, self).__init__()

                                self.yang_name = "supress"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('asymmetric_only', (YLeaf(YType.empty, 'asymmetric_only'), ['Empty'])),
                                ])
                                self.asymmetric_only = None
                                self._segment_path = lambda: "supress"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:urpf/loose/counter/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Platform.Urpf.Loose.Counter.Ipv6.Supress, ['asymmetric_only'], name, value)


        class TcamThreshold(Entity):
            """
            
            
            .. attribute:: alarm_frequency
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.TcamThreshold, self).__init__()

                self.yang_name = "tcam-threshold"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('alarm_frequency', (YLeaf(YType.uint32, 'alarm-frequency'), ['int'])),
                ])
                self.alarm_frequency = None
                self._segment_path = lambda: "Cisco-IOS-XE-platform:tcam-threshold"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.TcamThreshold, ['alarm_frequency'], name, value)


        class Trace(Entity):
            """
            
            
            .. attribute:: runtime
            
            	
            	**type**\: list of  		 :py:class:`Runtime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Trace.Runtime>`
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Platform.Trace, self).__init__()

                self.yang_name = "trace"
                self.yang_parent_name = "platform"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("runtime", ("runtime", Native.Platform.Trace.Runtime))])
                self._leafs = OrderedDict()

                self.runtime = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-platform:trace"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Platform.Trace, [], name, value)


            class Runtime(Entity):
                """
                
                
                .. attribute:: slot  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: bay  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: process
                
                	
                	**type**\:  :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Trace.Runtime.Process>`
                
                .. attribute:: module
                
                	
                	**type**\:  :py:class:`Module <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Trace.Runtime.Module>`
                
                .. attribute:: level
                
                	
                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Platform.Trace.Runtime.Level>`
                
                

                """

                _prefix = 'ios-plt'
                _revision = '2018-05-17'

                def __init__(self):
                    super(Native.Platform.Trace.Runtime, self).__init__()

                    self.yang_name = "runtime"
                    self.yang_parent_name = "trace"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['slot','bay']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('slot', (YLeaf(YType.uint8, 'slot'), ['int'])),
                        ('bay', (YLeaf(YType.uint8, 'bay'), ['int'])),
                        ('process', (YLeaf(YType.enumeration, 'process'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Platform.Trace.Runtime.Process')])),
                        ('module', (YLeaf(YType.enumeration, 'module'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Platform.Trace.Runtime.Module')])),
                        ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Platform.Trace.Runtime.Level')])),
                    ])
                    self.slot = None
                    self.bay = None
                    self.process = None
                    self.module = None
                    self.level = None
                    self._segment_path = lambda: "runtime" + "[slot='" + str(self.slot) + "']" + "[bay='" + str(self.bay) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/platform/Cisco-IOS-XE-platform:trace/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Platform.Trace.Runtime, ['slot', 'bay', 'process', 'module', 'level'], name, value)

                class Level(Enum):
                    """
                    Level (Enum Class)

                    .. data:: info = 0

                    """

                    info = Enum.YLeaf(0, "info")


                class Module(Enum):
                    """
                    Module (Enum Class)

                    .. data:: all_modules = 0

                    """

                    all_modules = Enum.YLeaf(0, "all-modules")


                class Process(Enum):
                    """
                    Process (Enum Class)

                    .. data:: iomd = 0

                    """

                    iomd = Enum.YLeaf(0, "iomd")



    class Enable(Entity):
        """
        Modify enable password parameters
        
        .. attribute:: password
        
        	Assign the privileged level password (MAX of 25 characters)
        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Enable.Password>`
        
        .. attribute:: last_resort
        
        	Define enable action if no TACACS servers respond
        	**type**\:  :py:class:`LastResort <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Enable.LastResort>`
        
        .. attribute:: secret
        
        	Assign the privileged level secret
        	**type**\:  :py:class:`Secret <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Enable.Secret>`
        
        .. attribute:: use_tacacs
        
        	Use TACACS to check enable passwords
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Enable, self).__init__()

            self.yang_name = "enable"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("password", ("password", Native.Enable.Password)), ("secret", ("secret", Native.Enable.Secret))])
            self._leafs = OrderedDict([
                ('last_resort', (YLeaf(YType.enumeration, 'last-resort'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Enable.LastResort')])),
                ('use_tacacs', (YLeaf(YType.empty, 'use-tacacs'), ['Empty'])),
            ])
            self.last_resort = None
            self.use_tacacs = None

            self.password = Native.Enable.Password()
            self.password.parent = self
            self._children_name_map["password"] = "password"

            self.secret = Native.Enable.Secret()
            self.secret.parent = self
            self._children_name_map["secret"] = "secret"
            self._segment_path = lambda: "enable"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Enable, [u'last_resort', u'use_tacacs'], name, value)

        class LastResort(Enum):
            """
            LastResort (Enum Class)

            Define enable action if no TACACS servers respond

            .. data:: password = 0

            .. data:: succeed = 1

            """

            password = Enum.YLeaf(0, "password")

            succeed = Enum.YLeaf(1, "succeed")



        class Password(Entity):
            """
            Assign the privileged level password (MAX of 25 characters)
            
            .. attribute:: level
            
            	Set exec level password
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: type
            
            	
            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Enable.Password.Type>`
            
            .. attribute:: secret
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Enable.Password, self).__init__()

                self.yang_name = "password"
                self.yang_parent_name = "enable"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Enable.Password.Type')])),
                    ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                ])
                self.level = None
                self.type = None
                self.secret = None
                self._segment_path = lambda: "password"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/enable/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Enable.Password, [u'level', u'type', u'secret'], name, value)

            class Type(Enum):
                """
                Type (Enum Class)

                .. data:: Y_0 = 0

                .. data:: Y_7 = 1

                """

                Y_0 = Enum.YLeaf(0, "0")

                Y_7 = Enum.YLeaf(1, "7")



        class Secret(Entity):
            """
            Assign the privileged level secret
            
            .. attribute:: level
            
            	Set exec level password
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: type
            
            	
            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Enable.Secret.Type>`
            
            .. attribute:: secret
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Enable.Secret, self).__init__()

                self.yang_name = "secret"
                self.yang_parent_name = "enable"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Enable.Secret.Type')])),
                    ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                ])
                self.level = None
                self.type = None
                self.secret = None
                self._segment_path = lambda: "secret"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/enable/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Enable.Secret, [u'level', u'type', u'secret'], name, value)

            class Type(Enum):
                """
                Type (Enum Class)

                .. data:: Y_0 = 0

                .. data:: Y_4 = 1

                .. data:: Y_5 = 2

                """

                Y_0 = Enum.YLeaf(0, "0")

                Y_4 = Enum.YLeaf(1, "4")

                Y_5 = Enum.YLeaf(2, "5")



    class Password(Entity):
        """
        Configure encryption password (key)
        
        .. attribute:: encryption
        
        	Encrypt system passwords
        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Password.Encryption>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Password, self).__init__()

            self.yang_name = "password"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("encryption", ("encryption", Native.Password.Encryption))])
            self._leafs = OrderedDict()

            self.encryption = Native.Password.Encryption()
            self.encryption.parent = self
            self._children_name_map["encryption"] = "encryption"
            self._segment_path = lambda: "password"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Password, [], name, value)


        class Encryption(Entity):
            """
            Encrypt system passwords
            
            .. attribute:: aes
            
            	Enable stronger (AES) password encryption
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Password.Encryption, self).__init__()

                self.yang_name = "encryption"
                self.yang_parent_name = "password"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('aes', (YLeaf(YType.empty, 'aes'), ['Empty'])),
                ])
                self.aes = None
                self._segment_path = lambda: "encryption"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/password/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Password.Encryption, [u'aes'], name, value)


    class Eap(Entity):
        """
        Configure EAP authenticator parameters
        
        .. attribute:: profile
        
        	EAP authenticator profile configuration
        	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Eap.Profile>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Eap, self).__init__()

            self.yang_name = "eap"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("profile", ("profile", Native.Eap.Profile))])
            self._leafs = OrderedDict()

            self.profile = YList(self)
            self._segment_path = lambda: "eap"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Eap, [], name, value)


        class Profile(Entity):
            """
            EAP authenticator profile configuration
            
            .. attribute:: name  (key)
            
            	WORD;;EAP authenticator profile name
            	**type**\: str
            
            .. attribute:: method
            
            	Add an allowed method
            	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Eap.Profile.Method>`
            
            .. attribute:: pki_trustpoint
            
            	Set the default pki trustpoint
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Eap.Profile, self).__init__()

                self.yang_name = "profile"
                self.yang_parent_name = "eap"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("method", ("method", Native.Eap.Profile.Method))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('pki_trustpoint', (YLeaf(YType.str, 'pki-trustpoint'), ['str'])),
                ])
                self.name = None
                self.pki_trustpoint = None

                self.method = Native.Eap.Profile.Method()
                self.method.parent = self
                self._children_name_map["method"] = "method"
                self._segment_path = lambda: "profile" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/eap/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Eap.Profile, [u'name', u'pki_trustpoint'], name, value)


            class Method(Entity):
                """
                Add an allowed method
                
                .. attribute:: fast
                
                	EAP\-FAST method allowed
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: gtc
                
                	EAP\-GTC method allowed
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: leap
                
                	EAP\-LEAP method allowed
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mschapv2
                
                	EAP\-MSCHAPV2 method allowed
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: peap
                
                	EAP\-PEAP method allowed
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: md5
                
                	EAP\-MD5 method allowed
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: tls
                
                	EAP\-TLS method allowed
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Eap.Profile.Method, self).__init__()

                    self.yang_name = "method"
                    self.yang_parent_name = "profile"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fast', (YLeaf(YType.empty, 'fast'), ['Empty'])),
                        ('gtc', (YLeaf(YType.empty, 'gtc'), ['Empty'])),
                        ('leap', (YLeaf(YType.empty, 'leap'), ['Empty'])),
                        ('mschapv2', (YLeaf(YType.empty, 'mschapv2'), ['Empty'])),
                        ('peap', (YLeaf(YType.empty, 'peap'), ['Empty'])),
                        ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                        ('tls', (YLeaf(YType.empty, 'tls'), ['Empty'])),
                    ])
                    self.fast = None
                    self.gtc = None
                    self.leap = None
                    self.mschapv2 = None
                    self.peap = None
                    self.md5 = None
                    self.tls = None
                    self._segment_path = lambda: "method"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Eap.Profile.Method, [u'fast', u'gtc', u'leap', u'mschapv2', u'peap', u'md5', u'tls'], name, value)


    class Archive(Entity):
        """
        Archive the configuration
        
        .. attribute:: log
        
        	Logging commands
        	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Archive.Log>`
        
        .. attribute:: path
        
        	path for backups
        	**type**\: union of the below types:
        
        		**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Archive.Path>`
        
        		**type**\: str
        
        .. attribute:: maximum
        
        	maximum number of backup copies
        	**type**\: int
        
        	**range:** 1..14
        
        .. attribute:: write_memory
        
        	Enable automatic backup generation during write memory
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: time_period
        
        	Period of time in minutes to automatically archive the running\-config
        	**type**\: int
        
        	**range:** 1..525600
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Archive, self).__init__()

            self.yang_name = "archive"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("log", ("log", Native.Archive.Log))])
            self._leafs = OrderedDict([
                ('path', (YLeaf(YType.str, 'path'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Archive.Path'),'str'])),
                ('maximum', (YLeaf(YType.uint8, 'maximum'), ['int'])),
                ('write_memory', (YLeaf(YType.empty, 'write-memory'), ['Empty'])),
                ('time_period', (YLeaf(YType.uint32, 'time-period'), ['int'])),
            ])
            self.path = None
            self.maximum = None
            self.write_memory = None
            self.time_period = None

            self.log = Native.Archive.Log()
            self.log.parent = self
            self._children_name_map["log"] = "log"
            self._segment_path = lambda: "archive"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Archive, [u'path', u'maximum', u'write_memory', u'time_period'], name, value)

        class Path(Enum):
            """
            Path (Enum Class)

            path for backups

            .. data:: bootflash__COLON__ = 0

            .. data:: flash__COLON__ = 1

            .. data:: ftp__COLON__ = 2

            .. data:: harddisk__COLON__ = 3

            .. data:: http__COLON__ = 4

            .. data:: https__COLON__ = 5

            .. data:: pram__COLON__ = 6

            .. data:: rcp__COLON__ = 7

            .. data:: scp__COLON__ = 8

            .. data:: tftp__COLON__ = 9

            """

            bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

            flash__COLON__ = Enum.YLeaf(1, "flash:")

            ftp__COLON__ = Enum.YLeaf(2, "ftp:")

            harddisk__COLON__ = Enum.YLeaf(3, "harddisk:")

            http__COLON__ = Enum.YLeaf(4, "http:")

            https__COLON__ = Enum.YLeaf(5, "https:")

            pram__COLON__ = Enum.YLeaf(6, "pram:")

            rcp__COLON__ = Enum.YLeaf(7, "rcp:")

            scp__COLON__ = Enum.YLeaf(8, "scp:")

            tftp__COLON__ = Enum.YLeaf(9, "tftp:")



        class Log(Entity):
            """
            Logging commands
            
            .. attribute:: config
            
            	Logging changes to the running configuration
            	**type**\:  :py:class:`Config <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Archive.Log.Config>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Archive.Log, self).__init__()

                self.yang_name = "log"
                self.yang_parent_name = "archive"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("config", ("config", Native.Archive.Log.Config))])
                self._leafs = OrderedDict()

                self.config = Native.Archive.Log.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"
                self._segment_path = lambda: "log"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/archive/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Archive.Log, [], name, value)


            class Config(Entity):
                """
                Logging changes to the running configuration
                
                .. attribute:: hidekeys
                
                	suppress output (e.g. passwords) when displaying logged commands
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: logging
                
                	Modify config logging parameters
                	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Archive.Log.Config.Logging>`
                
                .. attribute:: notify
                
                	Send logged commands to target applications
                	**type**\:  :py:class:`Notify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Archive.Log.Config.Notify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Archive.Log.Config, self).__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "log"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("logging", ("logging", Native.Archive.Log.Config.Logging)), ("notify", ("notify", Native.Archive.Log.Config.Notify))])
                    self._leafs = OrderedDict([
                        ('hidekeys', (YLeaf(YType.empty, 'hidekeys'), ['Empty'])),
                    ])
                    self.hidekeys = None

                    self.logging = Native.Archive.Log.Config.Logging()
                    self.logging.parent = self
                    self._children_name_map["logging"] = "logging"

                    self.notify = Native.Archive.Log.Config.Notify()
                    self.notify.parent = self
                    self._children_name_map["notify"] = "notify"
                    self._segment_path = lambda: "config"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/archive/log/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Archive.Log.Config, [u'hidekeys'], name, value)


                class Logging(Entity):
                    """
                    Modify config logging parameters
                    
                    .. attribute:: enable
                    
                    	Enable the config logger
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: size
                    
                    	Maximum number of logged commands that will be kept by the config log
                    	**type**\: int
                    
                    	**range:** 1..1000
                    
                    .. attribute:: persistent
                    
                    	Log configuration persistent
                    	**type**\:  :py:class:`Persistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Archive.Log.Config.Logging.Persistent>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Archive.Log.Config.Logging, self).__init__()

                        self.yang_name = "logging"
                        self.yang_parent_name = "config"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("persistent", ("persistent", Native.Archive.Log.Config.Logging.Persistent))])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                        ])
                        self.enable = None
                        self.size = None

                        self.persistent = None
                        self._children_name_map["persistent"] = "persistent"
                        self._segment_path = lambda: "logging"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/archive/log/config/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Archive.Log.Config.Logging, [u'enable', u'size'], name, value)


                    class Persistent(Entity):
                        """
                        Log configuration persistent
                        
                        .. attribute:: auto
                        
                        	Log configuration commands automatically
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: reload
                        
                        	Apply persisted commands on reload
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Archive.Log.Config.Logging.Persistent, self).__init__()

                            self.yang_name = "persistent"
                            self.yang_parent_name = "logging"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                                ('reload', (YLeaf(YType.empty, 'reload'), ['Empty'])),
                            ])
                            self.auto = None
                            self.reload = None
                            self._segment_path = lambda: "persistent"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/archive/log/config/logging/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Archive.Log.Config.Logging.Persistent, [u'auto', u'reload'], name, value)


                class Notify(Entity):
                    """
                    Send logged commands to target applications
                    
                    .. attribute:: syslog
                    
                    	Send logged commands as syslog messages
                    	**type**\:  :py:class:`Syslog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Archive.Log.Config.Notify.Syslog>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Archive.Log.Config.Notify, self).__init__()

                        self.yang_name = "notify"
                        self.yang_parent_name = "config"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("syslog", ("syslog", Native.Archive.Log.Config.Notify.Syslog))])
                        self._leafs = OrderedDict()

                        self.syslog = None
                        self._children_name_map["syslog"] = "syslog"
                        self._segment_path = lambda: "notify"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/archive/log/config/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Archive.Log.Config.Notify, [], name, value)


                    class Syslog(Entity):
                        """
                        Send logged commands as syslog messages
                        
                        .. attribute:: contenttype
                        
                        	Type of the syslog message content
                        	**type**\:  :py:class:`Contenttype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Archive.Log.Config.Notify.Syslog.Contenttype>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Archive.Log.Config.Notify.Syslog, self).__init__()

                            self.yang_name = "syslog"
                            self.yang_parent_name = "notify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('contenttype', (YLeaf(YType.enumeration, 'contenttype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Archive.Log.Config.Notify.Syslog.Contenttype')])),
                            ])
                            self.contenttype = None
                            self._segment_path = lambda: "syslog"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/archive/log/config/notify/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Archive.Log.Config.Notify.Syslog, [u'contenttype'], name, value)

                        class Contenttype(Enum):
                            """
                            Contenttype (Enum Class)

                            Type of the syslog message content

                            .. data:: plaintext = 0

                            .. data:: xml = 1

                            """

                            plaintext = Enum.YLeaf(0, "plaintext")

                            xml = Enum.YLeaf(1, "xml")



    class Username(Entity):
        """
        Establish User Name Authentication
        
        .. attribute:: name  (key)
        
        	
        	**type**\: str
        
        .. attribute:: privilege
        
        	Set user privilege level
        	**type**\: int
        
        	**range:** 0..15
        
        .. attribute:: view
        
        	Set view name
        	**type**\: str
        
        .. attribute:: one_time
        
        	Specify that the username/password is valid for only one time
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: password
        
        	Specify the password for the user
        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Username.Password>`
        
        .. attribute:: secret
        
        	Specify the secret for the user
        	**type**\:  :py:class:`Secret <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Username.Secret>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Username, self).__init__()

            self.yang_name = "username"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['name']
            self._child_classes = OrderedDict([("password", ("password", Native.Username.Password)), ("secret", ("secret", Native.Username.Secret))])
            self._leafs = OrderedDict([
                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ('privilege', (YLeaf(YType.uint8, 'privilege'), ['int'])),
                ('view', (YLeaf(YType.str, 'view'), ['str'])),
                ('one_time', (YLeaf(YType.empty, 'one-time'), ['Empty'])),
            ])
            self.name = None
            self.privilege = None
            self.view = None
            self.one_time = None

            self.password = Native.Username.Password()
            self.password.parent = self
            self._children_name_map["password"] = "password"

            self.secret = Native.Username.Secret()
            self.secret.parent = self
            self._children_name_map["secret"] = "secret"
            self._segment_path = lambda: "username" + "[name='" + str(self.name) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Username, [u'name', u'privilege', u'view', u'one_time'], name, value)


        class Password(Entity):
            """
            Specify the password for the user
            
            .. attribute:: encryption
            
            	
            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Username.Password.Encryption>`
            
            .. attribute:: password
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Username.Password, self).__init__()

                self.yang_name = "password"
                self.yang_parent_name = "username"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Username.Password.Encryption')])),
                    ('password', (YLeaf(YType.str, 'password'), ['str'])),
                ])
                self.encryption = None
                self.password = None
                self._segment_path = lambda: "password"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Username.Password, [u'encryption', u'password'], name, value)

            class Encryption(Enum):
                """
                Encryption (Enum Class)

                .. data:: Y_0 = 0

                .. data:: Y_7 = 1

                """

                Y_0 = Enum.YLeaf(0, "0")

                Y_7 = Enum.YLeaf(1, "7")



        class Secret(Entity):
            """
            Specify the secret for the user
            
            .. attribute:: encryption
            
            	
            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Username.Secret.Encryption>`
            
            .. attribute:: secret
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Username.Secret, self).__init__()

                self.yang_name = "secret"
                self.yang_parent_name = "username"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Username.Secret.Encryption')])),
                    ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                ])
                self.encryption = None
                self.secret = None
                self._segment_path = lambda: "secret"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Username.Secret, [u'encryption', u'secret'], name, value)

            class Encryption(Enum):
                """
                Encryption (Enum Class)

                .. data:: Y_0 = 0

                .. data:: Y_5 = 1

                .. data:: Y_9 = 2

                """

                Y_0 = Enum.YLeaf(0, "0")

                Y_5 = Enum.YLeaf(1, "5")

                Y_9 = Enum.YLeaf(2, "9")



    class Card(Entity):
        """
        Configure T1/E1 SPA
        
        .. attribute:: type
        
        	
        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Card.Type>`
        
        .. attribute:: slot
        
        	
        	**type**\: int
        
        	**range:** 0..4294967295
        
        .. attribute:: bay
        
        	
        	**type**\: int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Card, self).__init__()

            self.yang_name = "card"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('type', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-card:type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Card.Type')])),
                ('slot', (YLeaf(YType.uint32, 'Cisco-IOS-XE-card:slot'), ['int'])),
                ('bay', (YLeaf(YType.uint32, 'Cisco-IOS-XE-card:bay'), ['int'])),
            ])
            self.type = None
            self.slot = None
            self.bay = None
            self._segment_path = lambda: "card"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Card, ['type', 'slot', 'bay'], name, value)

        class Type(Enum):
            """
            Type (Enum Class)

            .. data:: t1 = 0

            .. data:: e1 = 1

            """

            t1 = Enum.YLeaf(0, "t1")

            e1 = Enum.YLeaf(1, "e1")



    class Controller(Entity):
        """
        Configure controller
        
        .. attribute:: controller_tx_ex_list
        
        	
        	**type**\: list of  		 :py:class:`ControllerTxExList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.ControllerTxExList>`
        
        .. attribute:: cellular
        
        	
        	**type**\: list of  		 :py:class:`Cellular <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular>`
        
        .. attribute:: sonet
        
        	SONET
        	**type**\: list of  		 :py:class:`SONET <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET>`
        
        .. attribute:: sonet_acr
        
        	SONET\-ACR
        	**type**\: list of  		 :py:class:`SONETACR <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR>`
        
        .. attribute:: wanphy
        
        	wanphy
        	**type**\: list of  		 :py:class:`Wanphy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Wanphy>`
        
        .. attribute:: vdsl
        
        	VDSL2 controller
        	**type**\: list of  		 :py:class:`Vdsl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Controller, self).__init__()

            self.yang_name = "controller"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-controller:controller-tx-ex-list", ("controller_tx_ex_list", Native.Controller.ControllerTxExList)), ("Cisco-IOS-XE-controller:Cellular", ("cellular", Native.Controller.Cellular)), ("Cisco-IOS-XE-controller:SONET", ("sonet", Native.Controller.SONET)), ("Cisco-IOS-XE-controller:SONET-ACR", ("sonet_acr", Native.Controller.SONETACR)), ("Cisco-IOS-XE-controller:wanphy", ("wanphy", Native.Controller.Wanphy)), ("Cisco-IOS-XE-controller:vdsl", ("vdsl", Native.Controller.Vdsl))])
            self._leafs = OrderedDict()

            self.controller_tx_ex_list = YList(self)
            self.cellular = YList(self)
            self.sonet = YList(self)
            self.sonet_acr = YList(self)
            self.wanphy = YList(self)
            self.vdsl = YList(self)
            self._segment_path = lambda: "controller"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Controller, [], name, value)


        class ControllerTxExList(Entity):
            """
            
            
            .. attribute:: name  (key)
            
            	
            	**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.ControllerTxExList.Name>`
            
            .. attribute:: number  (key)
            
            	
            	**type**\: str
            
            .. attribute:: atm
            
            	Specify atm
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: framing
            
            	
            	**type**\: str
            
            .. attribute:: clock
            
            	
            	**type**\:  :py:class:`Clock <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.ControllerTxExList.Clock>`
            
            .. attribute:: description
            
            	Controller specific description
            	**type**\: str
            
            	**length:** 1..240
            
            .. attribute:: linecode
            
            	
            	**type**\:  :py:class:`Linecode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.ControllerTxExList.Linecode>`
            
            .. attribute:: cablelength
            
            	
            	**type**\:  :py:class:`Cablelength <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.ControllerTxExList.Cablelength>`
            
            .. attribute:: channel_group
            
            	
            	**type**\: list of  		 :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.ControllerTxExList.ChannelGroup>`
            
            

            """

            _prefix = 'ios-ctrl'
            _revision = '2018-04-02'

            def __init__(self):
                super(Native.Controller.ControllerTxExList, self).__init__()

                self.yang_name = "controller-tx-ex-list"
                self.yang_parent_name = "controller"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name','number']
                self._child_classes = OrderedDict([("clock", ("clock", Native.Controller.ControllerTxExList.Clock)), ("cablelength", ("cablelength", Native.Controller.ControllerTxExList.Cablelength)), ("channel-group", ("channel_group", Native.Controller.ControllerTxExList.ChannelGroup))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.enumeration, 'name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.ControllerTxExList.Name')])),
                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                    ('atm', (YLeaf(YType.empty, 'atm'), ['Empty'])),
                    ('framing', (YLeaf(YType.str, 'framing'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('linecode', (YLeaf(YType.enumeration, 'linecode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.ControllerTxExList.Linecode')])),
                ])
                self.name = None
                self.number = None
                self.atm = None
                self.framing = None
                self.description = None
                self.linecode = None

                self.clock = Native.Controller.ControllerTxExList.Clock()
                self.clock.parent = self
                self._children_name_map["clock"] = "clock"

                self.cablelength = Native.Controller.ControllerTxExList.Cablelength()
                self.cablelength.parent = self
                self._children_name_map["cablelength"] = "cablelength"

                self.channel_group = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-controller:controller-tx-ex-list" + "[name='" + str(self.name) + "']" + "[number='" + str(self.number) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/controller/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Controller.ControllerTxExList, ['name', 'number', 'atm', 'framing', 'description', 'linecode'], name, value)

            class Linecode(Enum):
                """
                Linecode (Enum Class)

                .. data:: ami = 0

                .. data:: b8zs = 1

                .. data:: hdb3 = 2

                """

                ami = Enum.YLeaf(0, "ami")

                b8zs = Enum.YLeaf(1, "b8zs")

                hdb3 = Enum.YLeaf(2, "hdb3")


            class Name(Enum):
                """
                Name (Enum Class)

                .. data:: T1 = 0

                .. data:: E1 = 1

                .. data:: T3 = 2

                """

                T1 = Enum.YLeaf(0, "T1")

                E1 = Enum.YLeaf(1, "E1")

                T3 = Enum.YLeaf(2, "T3")



            class Clock(Entity):
                """
                
                
                .. attribute:: source
                
                	
                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.ControllerTxExList.Clock.Source>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.ControllerTxExList.Clock, self).__init__()

                    self.yang_name = "clock"
                    self.yang_parent_name = "controller-tx-ex-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("source", ("source", Native.Controller.ControllerTxExList.Clock.Source))])
                    self._leafs = OrderedDict()

                    self.source = Native.Controller.ControllerTxExList.Clock.Source()
                    self.source.parent = self
                    self._children_name_map["source"] = "source"
                    self._segment_path = lambda: "clock"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.ControllerTxExList.Clock, [], name, value)


                class Source(Entity):
                    """
                    
                    
                    .. attribute:: line
                    
                    	
                    	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.ControllerTxExList.Clock.Source.Line>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: internal
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: loop_timed
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.ControllerTxExList.Clock.Source, self).__init__()

                        self.yang_name = "source"
                        self.yang_parent_name = "clock"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("line", ("line", Native.Controller.ControllerTxExList.Clock.Source.Line))])
                        self._leafs = OrderedDict([
                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                            ('loop_timed', (YLeaf(YType.empty, 'loop-timed'), ['Empty'])),
                        ])
                        self.internal = None
                        self.loop_timed = None

                        self.line = None
                        self._children_name_map["line"] = "line"
                        self._segment_path = lambda: "source"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.ControllerTxExList.Clock.Source, ['internal', 'loop_timed'], name, value)


                    class Line(Entity):
                        """
                        
                        
                        .. attribute:: line_mode
                        
                        	
                        	**type**\:  :py:class:`LineMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.ControllerTxExList.Clock.Source.Line.LineMode>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.ControllerTxExList.Clock.Source.Line, self).__init__()

                            self.yang_name = "line"
                            self.yang_parent_name = "source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('line_mode', (YLeaf(YType.enumeration, 'line-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.ControllerTxExList.Clock.Source.Line.LineMode')])),
                            ])
                            self.line_mode = None
                            self._segment_path = lambda: "line"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.ControllerTxExList.Clock.Source.Line, ['line_mode'], name, value)

                        class LineMode(Enum):
                            """
                            LineMode (Enum Class)

                            .. data:: primary = 0

                            .. data:: secondary = 1

                            """

                            primary = Enum.YLeaf(0, "primary")

                            secondary = Enum.YLeaf(1, "secondary")



            class Cablelength(Entity):
                """
                
                
                .. attribute:: long
                
                	
                	**type**\: str
                
                .. attribute:: short
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.ControllerTxExList.Cablelength, self).__init__()

                    self.yang_name = "cablelength"
                    self.yang_parent_name = "controller-tx-ex-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('long', (YLeaf(YType.str, 'long'), ['str'])),
                        ('short', (YLeaf(YType.str, 'short'), ['str'])),
                    ])
                    self.long = None
                    self.short = None
                    self._segment_path = lambda: "cablelength"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.ControllerTxExList.Cablelength, ['long', 'short'], name, value)


            class ChannelGroup(Entity):
                """
                
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..30
                
                .. attribute:: timeslots
                
                	
                	**type**\: union of the below types:
                
                		**type**\: list of int
                
                			**range:** 0..65535
                
                		**type**\: list of str
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.ControllerTxExList.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "controller-tx-ex-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                        ('timeslots', (YLeafList(YType.str, 'timeslots'), ['int','str'])),
                    ])
                    self.number = None
                    self.timeslots = []
                    self._segment_path = lambda: "channel-group" + "[number='" + str(self.number) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.ControllerTxExList.ChannelGroup, ['number', 'timeslots'], name, value)


        class Cellular(Entity):
            """
            
            
            .. attribute:: id  (key)
            
            	
            	**type**\: str
            
            .. attribute:: lte
            
            	LTE type carrier
            	**type**\:  :py:class:`Lte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte>`
            
            

            """

            _prefix = 'ios-ctrl'
            _revision = '2018-04-02'

            def __init__(self):
                super(Native.Controller.Cellular, self).__init__()

                self.yang_name = "Cellular"
                self.yang_parent_name = "controller"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("lte", ("lte", Native.Controller.Cellular.Lte))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                ])
                self.id = None

                self.lte = Native.Controller.Cellular.Lte()
                self.lte.parent = self
                self._children_name_map["lte"] = "lte"
                self._segment_path = lambda: "Cisco-IOS-XE-controller:Cellular" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/controller/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Controller.Cellular, ['id'], name, value)


            class Lte(Entity):
                """
                LTE type carrier
                
                .. attribute:: sim
                
                	Subscriber Identity Module
                	**type**\:  :py:class:`Sim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Sim>`
                
                .. attribute:: sms
                
                	SMS configuration
                	**type**\:  :py:class:`Sms <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Sms>`
                
                .. attribute:: gps
                
                	GPS configuration
                	**type**\:  :py:class:`Gps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Gps>`
                
                .. attribute:: failovertimer
                
                	Failover timeout value in mins
                	**type**\: int
                
                	**range:** 3..7
                
                .. attribute:: firmware
                
                	Select firmware option
                	**type**\:  :py:class:`Firmware <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Firmware>`
                
                	**presence node**\: True
                
                .. attribute:: radio
                
                	Controller's radio
                	**type**\:  :py:class:`Radio <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Radio>`
                
                .. attribute:: modem
                
                	
                	**type**\:  :py:class:`Modem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem>`
                
                .. attribute:: event
                
                	cellular snmp event persistence
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event>`
                
                .. attribute:: dyinggasp
                
                	Dying Gasp Configuration
                	**type**\:  :py:class:`Dyinggasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Dyinggasp>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.Cellular.Lte, self).__init__()

                    self.yang_name = "lte"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("sim", ("sim", Native.Controller.Cellular.Lte.Sim)), ("sms", ("sms", Native.Controller.Cellular.Lte.Sms)), ("gps", ("gps", Native.Controller.Cellular.Lte.Gps)), ("firmware", ("firmware", Native.Controller.Cellular.Lte.Firmware)), ("radio", ("radio", Native.Controller.Cellular.Lte.Radio)), ("modem", ("modem", Native.Controller.Cellular.Lte.Modem)), ("event", ("event", Native.Controller.Cellular.Lte.Event)), ("dyinggasp", ("dyinggasp", Native.Controller.Cellular.Lte.Dyinggasp))])
                    self._leafs = OrderedDict([
                        ('failovertimer', (YLeaf(YType.uint8, 'failovertimer'), ['int'])),
                    ])
                    self.failovertimer = None

                    self.sim = Native.Controller.Cellular.Lte.Sim()
                    self.sim.parent = self
                    self._children_name_map["sim"] = "sim"

                    self.sms = Native.Controller.Cellular.Lte.Sms()
                    self.sms.parent = self
                    self._children_name_map["sms"] = "sms"

                    self.gps = Native.Controller.Cellular.Lte.Gps()
                    self.gps.parent = self
                    self._children_name_map["gps"] = "gps"

                    self.firmware = None
                    self._children_name_map["firmware"] = "firmware"

                    self.radio = Native.Controller.Cellular.Lte.Radio()
                    self.radio.parent = self
                    self._children_name_map["radio"] = "radio"

                    self.modem = Native.Controller.Cellular.Lte.Modem()
                    self.modem.parent = self
                    self._children_name_map["modem"] = "modem"

                    self.event = Native.Controller.Cellular.Lte.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.dyinggasp = Native.Controller.Cellular.Lte.Dyinggasp()
                    self.dyinggasp.parent = self
                    self._children_name_map["dyinggasp"] = "dyinggasp"
                    self._segment_path = lambda: "lte"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.Cellular.Lte, ['failovertimer'], name, value)


                class Sim(Entity):
                    """
                    Subscriber Identity Module
                    
                    .. attribute:: authenticate
                    
                    	CHV1 authentication
                    	**type**\:  :py:class:`Authenticate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Sim.Authenticate>`
                    
                    .. attribute:: data_profile_list
                    
                    	Data Profile number
                    	**type**\: list of  		 :py:class:`DataProfileList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Sim.DataProfileList>`
                    
                    .. attribute:: max_retry
                    
                    	Maximum number of SIM switchover retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: primary
                    
                    	Controller's primary SIM
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Sim.Primary>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Cellular.Lte.Sim, self).__init__()

                        self.yang_name = "sim"
                        self.yang_parent_name = "lte"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authenticate", ("authenticate", Native.Controller.Cellular.Lte.Sim.Authenticate)), ("data-profile-list", ("data_profile_list", Native.Controller.Cellular.Lte.Sim.DataProfileList)), ("primary", ("primary", Native.Controller.Cellular.Lte.Sim.Primary))])
                        self._leafs = OrderedDict([
                            ('max_retry', (YLeaf(YType.uint16, 'max-retry'), ['int'])),
                        ])
                        self.max_retry = None

                        self.authenticate = Native.Controller.Cellular.Lte.Sim.Authenticate()
                        self.authenticate.parent = self
                        self._children_name_map["authenticate"] = "authenticate"

                        self.primary = Native.Controller.Cellular.Lte.Sim.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.data_profile_list = YList(self)
                        self._segment_path = lambda: "sim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Cellular.Lte.Sim, ['max_retry'], name, value)


                    class Authenticate(Entity):
                        """
                        CHV1 authentication
                        
                        .. attribute:: pin_type
                        
                        	0 Specifies an UNENCRYPTED (cleartext) PIN will follow 7 Specifies a HIDDEN PIN will follow
                        	**type**\:  :py:class:`PinType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Sim.Authenticate.PinType>`
                        
                        .. attribute:: pin
                        
                        	Unecrypted PIN (Length 4 to 8 characters)Encrypted PIN
                        	**type**\: str
                        
                        .. attribute:: slot
                        
                        	Slot number
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Sim.Authenticate, self).__init__()

                            self.yang_name = "authenticate"
                            self.yang_parent_name = "sim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('pin_type', (YLeaf(YType.enumeration, 'pin-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Sim.Authenticate.PinType')])),
                                ('pin', (YLeaf(YType.str, 'pin'), ['str'])),
                                ('slot', (YLeaf(YType.uint8, 'slot'), ['int'])),
                            ])
                            self.pin_type = None
                            self.pin = None
                            self.slot = None
                            self._segment_path = lambda: "authenticate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Sim.Authenticate, ['pin_type', 'pin', 'slot'], name, value)

                        class PinType(Enum):
                            """
                            PinType (Enum Class)

                            0 Specifies an UNENCRYPTED (cleartext) PIN will follow 7 Specifies a HIDDEN PIN will follow

                            .. data:: Y_0 = 0

                            .. data:: Y_7 = 1

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_7 = Enum.YLeaf(1, "7")



                    class DataProfileList(Entity):
                        """
                        Data Profile number
                        
                        .. attribute:: slot  (key)
                        
                        	Slot number
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: data_profile
                        
                        	Profile Number corresponding to the data bearer APN
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: attach_profile
                        
                        	Profile Number corresponding to initial attach APN
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Sim.DataProfileList, self).__init__()

                            self.yang_name = "data-profile-list"
                            self.yang_parent_name = "sim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['slot']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('slot', (YLeaf(YType.uint8, 'slot'), ['int'])),
                                ('data_profile', (YLeaf(YType.uint8, 'data-profile'), ['int'])),
                                ('attach_profile', (YLeaf(YType.uint8, 'attach-profile'), ['int'])),
                            ])
                            self.slot = None
                            self.data_profile = None
                            self.attach_profile = None
                            self._segment_path = lambda: "data-profile-list" + "[slot='" + str(self.slot) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Sim.DataProfileList, ['slot', 'data_profile', 'attach_profile'], name, value)


                    class Primary(Entity):
                        """
                        Controller's primary SIM
                        
                        .. attribute:: slot
                        
                        	Slot number
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Sim.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "sim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('slot', (YLeaf(YType.uint8, 'slot'), ['int'])),
                            ])
                            self.slot = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Sim.Primary, ['slot'], name, value)


                class Sms(Entity):
                    """
                    SMS configuration
                    
                    .. attribute:: archive
                    
                    	SMS archive configuration
                    	**type**\:  :py:class:`Archive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Sms.Archive>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Cellular.Lte.Sms, self).__init__()

                        self.yang_name = "sms"
                        self.yang_parent_name = "lte"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("archive", ("archive", Native.Controller.Cellular.Lte.Sms.Archive))])
                        self._leafs = OrderedDict()

                        self.archive = Native.Controller.Cellular.Lte.Sms.Archive()
                        self.archive.parent = self
                        self._children_name_map["archive"] = "archive"
                        self._segment_path = lambda: "sms"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Cellular.Lte.Sms, [], name, value)


                    class Archive(Entity):
                        """
                        SMS archive configuration
                        
                        .. attribute:: path
                        
                        	path in URL to archive SMS
                        	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Sms.Archive.Path>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Sms.Archive, self).__init__()

                            self.yang_name = "archive"
                            self.yang_parent_name = "sms"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('path', (YLeaf(YType.enumeration, 'path'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Sms.Archive.Path')])),
                            ])
                            self.path = None
                            self._segment_path = lambda: "archive"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Sms.Archive, ['path'], name, value)

                        class Path(Enum):
                            """
                            Path (Enum Class)

                            path in URL to archive SMS

                            .. data:: ftp__COLON__ = 0

                            .. data:: http__COLON__ = 1

                            .. data:: https__COLON__ = 2

                            .. data:: pram__COLON__ = 3

                            .. data:: rcp__COLON__ = 4

                            .. data:: scp__COLON__ = 5

                            .. data:: tftp__COLON__ = 6

                            """

                            ftp__COLON__ = Enum.YLeaf(0, "ftp:")

                            http__COLON__ = Enum.YLeaf(1, "http:")

                            https__COLON__ = Enum.YLeaf(2, "https:")

                            pram__COLON__ = Enum.YLeaf(3, "pram:")

                            rcp__COLON__ = Enum.YLeaf(4, "rcp:")

                            scp__COLON__ = Enum.YLeaf(5, "scp:")

                            tftp__COLON__ = Enum.YLeaf(6, "tftp:")



                class Gps(Entity):
                    """
                    GPS configuration
                    
                    .. attribute:: nmea_conf
                    
                    	
                    	**type**\:  :py:class:`NmeaConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Gps.NmeaConf>`
                    
                    .. attribute:: nmea
                    
                    	
                    	**type**\:  :py:class:`Nmea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Gps.Nmea>`
                    
                    .. attribute:: enable
                    
                    	enable GPS feature
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mode
                    
                    	select GPS mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Gps.Mode>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Cellular.Lte.Gps, self).__init__()

                        self.yang_name = "gps"
                        self.yang_parent_name = "lte"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("nmea-conf", ("nmea_conf", Native.Controller.Cellular.Lte.Gps.NmeaConf)), ("nmea", ("nmea", Native.Controller.Cellular.Lte.Gps.Nmea))])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Gps.Mode')])),
                        ])
                        self.enable = None
                        self.mode = None

                        self.nmea_conf = Native.Controller.Cellular.Lte.Gps.NmeaConf()
                        self.nmea_conf.parent = self
                        self._children_name_map["nmea_conf"] = "nmea-conf"

                        self.nmea = Native.Controller.Cellular.Lte.Gps.Nmea()
                        self.nmea.parent = self
                        self._children_name_map["nmea"] = "nmea"
                        self._segment_path = lambda: "gps"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Cellular.Lte.Gps, ['enable', 'mode'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        select GPS mode

                        .. data:: ms_based = 0

                        .. data:: standalone = 1

                        """

                        ms_based = Enum.YLeaf(0, "ms-based")

                        standalone = Enum.YLeaf(1, "standalone")



                    class NmeaConf(Entity):
                        """
                        
                        
                        .. attribute:: nmea
                        
                        	enable NMEA data
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Gps.NmeaConf, self).__init__()

                            self.yang_name = "nmea-conf"
                            self.yang_parent_name = "gps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('nmea', (YLeaf(YType.empty, 'nmea'), ['Empty'])),
                            ])
                            self.nmea = None
                            self._segment_path = lambda: "nmea-conf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Gps.NmeaConf, ['nmea'], name, value)


                    class Nmea(Entity):
                        """
                        
                        
                        .. attribute:: ip
                        
                        	enable NMEA stream over IP UDP interface
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Gps.Nmea.Ip>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Gps.Nmea, self).__init__()

                            self.yang_name = "nmea"
                            self.yang_parent_name = "gps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Controller.Cellular.Lte.Gps.Nmea.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Controller.Cellular.Lte.Gps.Nmea.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "nmea"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Gps.Nmea, [], name, value)


                        class Ip(Entity):
                            """
                            enable NMEA stream over IP UDP interface
                            
                            .. attribute:: udp
                            
                            	UDP Transport
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Gps.Nmea.Ip.Udp>`
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Gps.Nmea.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "nmea"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Controller.Cellular.Lte.Gps.Nmea.Ip.Udp))])
                                self._leafs = OrderedDict()

                                self.udp = Native.Controller.Cellular.Lte.Gps.Nmea.Ip.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Gps.Nmea.Ip, [], name, value)


                            class Udp(Entity):
                                """
                                UDP Transport
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: destination_address
                                
                                	Destination address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: destination_port
                                
                                	Destination port
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ctrl'
                                _revision = '2018-04-02'

                                def __init__(self):
                                    super(Native.Controller.Cellular.Lte.Gps.Nmea.Ip.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                        ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str'])),
                                        ('destination_port', (YLeaf(YType.uint16, 'destination-port'), ['int'])),
                                    ])
                                    self.source_address = None
                                    self.destination_address = None
                                    self.destination_port = None
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Controller.Cellular.Lte.Gps.Nmea.Ip.Udp, ['source_address', 'destination_address', 'destination_port'], name, value)


                class Firmware(Entity):
                    """
                    Select firmware option
                    
                    .. attribute:: auto_sim
                    
                    	Select firmware auto\-sim
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Cellular.Lte.Firmware, self).__init__()

                        self.yang_name = "firmware"
                        self.yang_parent_name = "lte"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('auto_sim', (YLeaf(YType.empty, 'auto-sim'), ['Empty'])),
                        ])
                        self.auto_sim = None
                        self._segment_path = lambda: "firmware"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Cellular.Lte.Firmware, ['auto_sim'], name, value)


                class Radio(Entity):
                    """
                    Controller's radio
                    
                    .. attribute:: off
                    
                    	Power down radio
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Cellular.Lte.Radio, self).__init__()

                        self.yang_name = "radio"
                        self.yang_parent_name = "lte"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('off', (YLeaf(YType.empty, 'off'), ['Empty'])),
                        ])
                        self.off = None
                        self._segment_path = lambda: "radio"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Cellular.Lte.Radio, ['off'], name, value)


                class Modem(Entity):
                    """
                    
                    
                    .. attribute:: dm_log
                    
                    	Modem DM logging configuration
                    	**type**\:  :py:class:`DmLog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem.DmLog>`
                    
                    .. attribute:: fota
                    
                    	Firmware upgrade over the air
                    	**type**\:  :py:class:`Fota <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem.Fota>`
                    
                    .. attribute:: link_recovery
                    
                    	
                    	**type**\:  :py:class:`LinkRecovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem.LinkRecovery>`
                    
                    .. attribute:: nas_log
                    
                    	Modem NAS logging configuration
                    	**type**\:  :py:class:`NasLog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem.NasLog>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Cellular.Lte.Modem, self).__init__()

                        self.yang_name = "modem"
                        self.yang_parent_name = "lte"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dm-log", ("dm_log", Native.Controller.Cellular.Lte.Modem.DmLog)), ("fota", ("fota", Native.Controller.Cellular.Lte.Modem.Fota)), ("link-recovery", ("link_recovery", Native.Controller.Cellular.Lte.Modem.LinkRecovery)), ("nas-log", ("nas_log", Native.Controller.Cellular.Lte.Modem.NasLog))])
                        self._leafs = OrderedDict()

                        self.dm_log = Native.Controller.Cellular.Lte.Modem.DmLog()
                        self.dm_log.parent = self
                        self._children_name_map["dm_log"] = "dm-log"

                        self.fota = Native.Controller.Cellular.Lte.Modem.Fota()
                        self.fota.parent = self
                        self._children_name_map["fota"] = "fota"

                        self.link_recovery = Native.Controller.Cellular.Lte.Modem.LinkRecovery()
                        self.link_recovery.parent = self
                        self._children_name_map["link_recovery"] = "link-recovery"

                        self.nas_log = Native.Controller.Cellular.Lte.Modem.NasLog()
                        self.nas_log.parent = self
                        self._children_name_map["nas_log"] = "nas-log"
                        self._segment_path = lambda: "modem"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Cellular.Lte.Modem, [], name, value)


                    class DmLog(Entity):
                        """
                        Modem DM logging configuration
                        
                        .. attribute:: output
                        
                        	DM logging output files
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem.DmLog.Output>`
                        
                        .. attribute:: filter
                        
                        	DM log filter file. Specify DM log filter location (in .sqf format)
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem.DmLog.Filter>`
                        
                        .. attribute:: size
                        
                        	Specify maximum log size. Maximum log size in MB (default is 64MB, 0 means no upper limit)
                        	**type**\: int
                        
                        	**range:** 0..1024
                        
                        .. attribute:: filesize
                        
                        	Specify maximum log file size. Maximum file size in MB (default is 20MB)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        .. attribute:: rotation
                        
                        	DM log rotation (only supported on flash\:)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: enable
                        
                        	Enable DM logging
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: autostop
                        
                        	Auto stop trigger event
                        	**type**\:  :py:class:`Autostop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem.DmLog.Autostop>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Modem.DmLog, self).__init__()

                            self.yang_name = "dm-log"
                            self.yang_parent_name = "modem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("output", ("output", Native.Controller.Cellular.Lte.Modem.DmLog.Output)), ("autostop", ("autostop", Native.Controller.Cellular.Lte.Modem.DmLog.Autostop))])
                            self._leafs = OrderedDict([
                                ('filter', (YLeaf(YType.enumeration, 'filter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Modem.DmLog.Filter')])),
                                ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                ('filesize', (YLeaf(YType.int8, 'filesize'), ['int'])),
                                ('rotation', (YLeaf(YType.empty, 'rotation'), ['Empty'])),
                                ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ])
                            self.filter = None
                            self.size = None
                            self.filesize = None
                            self.rotation = None
                            self.enable = None

                            self.output = Native.Controller.Cellular.Lte.Modem.DmLog.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"

                            self.autostop = Native.Controller.Cellular.Lte.Modem.DmLog.Autostop()
                            self.autostop.parent = self
                            self._children_name_map["autostop"] = "autostop"
                            self._segment_path = lambda: "dm-log"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Modem.DmLog, ['filter', 'size', 'filesize', 'rotation', 'enable'], name, value)

                        class Filter(Enum):
                            """
                            Filter (Enum Class)

                            DM log filter file. Specify DM log filter location (in .sqf format)

                            .. data:: bootflash__COLON__ = 0

                            .. data:: flash__COLON__ = 1

                            .. data:: webui__COLON__ = 2

                            """

                            bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                            flash__COLON__ = Enum.YLeaf(1, "flash:")

                            webui__COLON__ = Enum.YLeaf(2, "webui:")



                        class Output(Entity):
                            """
                            DM logging output files
                            
                            .. attribute:: local_uf
                            
                            	Use Module Utility flash to store DM logs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: path
                            
                            	URL to store DM log files
                            	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem.DmLog.Output.Path>`
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Modem.DmLog.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "dm-log"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_uf', (YLeaf(YType.empty, 'local-uf'), ['Empty'])),
                                    ('path', (YLeaf(YType.enumeration, 'path'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Modem.DmLog.Output.Path')])),
                                ])
                                self.local_uf = None
                                self.path = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Modem.DmLog.Output, ['local_uf', 'path'], name, value)

                            class Path(Enum):
                                """
                                Path (Enum Class)

                                URL to store DM log files

                                .. data:: bootflash__COLON__ = 0

                                .. data:: flash__COLON__ = 1

                                .. data:: ftp__COLON__ = 2

                                .. data:: http__COLON__ = 3

                                .. data:: https__COLON__ = 4

                                .. data:: pram__COLON__ = 5

                                .. data:: rcp__COLON__ = 6

                                .. data:: scp__COLON__ = 7

                                .. data:: tftp__COLON__ = 8

                                """

                                bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                                flash__COLON__ = Enum.YLeaf(1, "flash:")

                                ftp__COLON__ = Enum.YLeaf(2, "ftp:")

                                http__COLON__ = Enum.YLeaf(3, "http:")

                                https__COLON__ = Enum.YLeaf(4, "https:")

                                pram__COLON__ = Enum.YLeaf(5, "pram:")

                                rcp__COLON__ = Enum.YLeaf(6, "rcp:")

                                scp__COLON__ = Enum.YLeaf(7, "scp:")

                                tftp__COLON__ = Enum.YLeaf(8, "tftp:")



                        class Autostop(Entity):
                            """
                            Auto stop trigger event
                            
                            .. attribute:: link_down
                            
                            	Cellular interface link down event
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timer
                            
                            	Timer interval in minutes
                            	**type**\: int
                            
                            	**range:** 12..120
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Modem.DmLog.Autostop, self).__init__()

                                self.yang_name = "autostop"
                                self.yang_parent_name = "dm-log"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_down', (YLeaf(YType.empty, 'link-down'), ['Empty'])),
                                    ('timer', (YLeaf(YType.int8, 'timer'), ['int'])),
                                ])
                                self.link_down = None
                                self.timer = None
                                self._segment_path = lambda: "autostop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Modem.DmLog.Autostop, ['link_down', 'timer'], name, value)


                    class Fota(Entity):
                        """
                        Firmware upgrade over the air
                        
                        .. attribute:: enable
                        
                        	Enable FOTA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: poll_timer
                        
                        	Set poll timer for AVMS, Interval(in minutes) at which modem polls server for firmware
                        	**type**\: int
                        
                        	**range:** 15..525600
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Modem.Fota, self).__init__()

                            self.yang_name = "fota"
                            self.yang_parent_name = "modem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                                ('poll_timer', (YLeaf(YType.uint32, 'poll-timer'), ['int'])),
                            ])
                            self.enable = None
                            self.poll_timer = None
                            self._segment_path = lambda: "fota"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Modem.Fota, ['enable', 'poll_timer'], name, value)


                    class LinkRecovery(Entity):
                        """
                        
                        
                        .. attribute:: rssi
                        
                        	
                        	**type**\:  :py:class:`Rssi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem.LinkRecovery.Rssi>`
                        
                        .. attribute:: monitor_timer
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wait_timer
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: debounce_count
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Modem.LinkRecovery, self).__init__()

                            self.yang_name = "link-recovery"
                            self.yang_parent_name = "modem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rssi", ("rssi", Native.Controller.Cellular.Lte.Modem.LinkRecovery.Rssi))])
                            self._leafs = OrderedDict([
                                ('monitor_timer', (YLeaf(YType.uint32, 'monitor-timer'), ['int'])),
                                ('wait_timer', (YLeaf(YType.uint32, 'wait-timer'), ['int'])),
                                ('debounce_count', (YLeaf(YType.uint32, 'debounce-count'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.monitor_timer = None
                            self.wait_timer = None
                            self.debounce_count = None
                            self.disable = None

                            self.rssi = Native.Controller.Cellular.Lte.Modem.LinkRecovery.Rssi()
                            self.rssi.parent = self
                            self._children_name_map["rssi"] = "rssi"
                            self._segment_path = lambda: "link-recovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Modem.LinkRecovery, ['monitor_timer', 'wait_timer', 'debounce_count', 'disable'], name, value)


                        class Rssi(Entity):
                            """
                            
                            
                            .. attribute:: onset_threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Modem.LinkRecovery.Rssi, self).__init__()

                                self.yang_name = "rssi"
                                self.yang_parent_name = "link-recovery"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('onset_threshold', (YLeaf(YType.int32, 'onset-threshold'), ['int'])),
                                ])
                                self.onset_threshold = None
                                self._segment_path = lambda: "rssi"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Modem.LinkRecovery.Rssi, ['onset_threshold'], name, value)


                    class NasLog(Entity):
                        """
                        Modem NAS logging configuration
                        
                        .. attribute:: output
                        
                        	DM logging output files
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem.NasLog.Output>`
                        
                        .. attribute:: size
                        
                        	Specify maximum log size. Maximum log size in MB (default is 64MB, 0 means no upper limit)
                        	**type**\: int
                        
                        	**range:** 0..1024
                        
                        .. attribute:: filesize
                        
                        	Specify maximum log file size. Maximum file size in MB (default is 20MB)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        .. attribute:: enable
                        
                        	Enable NAS logging
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Modem.NasLog, self).__init__()

                            self.yang_name = "nas-log"
                            self.yang_parent_name = "modem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("output", ("output", Native.Controller.Cellular.Lte.Modem.NasLog.Output))])
                            self._leafs = OrderedDict([
                                ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                ('filesize', (YLeaf(YType.int8, 'filesize'), ['int'])),
                                ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ])
                            self.size = None
                            self.filesize = None
                            self.enable = None

                            self.output = Native.Controller.Cellular.Lte.Modem.NasLog.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "nas-log"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Modem.NasLog, ['size', 'filesize', 'enable'], name, value)


                        class Output(Entity):
                            """
                            DM logging output files
                            
                            .. attribute:: path
                            
                            	URL to store DM log files
                            	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Modem.NasLog.Output.Path>`
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Modem.NasLog.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "nas-log"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('path', (YLeaf(YType.enumeration, 'path'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Modem.NasLog.Output.Path')])),
                                ])
                                self.path = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Modem.NasLog.Output, ['path'], name, value)

                            class Path(Enum):
                                """
                                Path (Enum Class)

                                URL to store DM log files

                                .. data:: bootflash__COLON__ = 0

                                .. data:: flash__COLON__ = 1

                                """

                                bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                                flash__COLON__ = Enum.YLeaf(1, "flash:")



                class Event(Entity):
                    """
                    cellular snmp event persistence
                    
                    .. attribute:: connection_status
                    
                    	connection status
                    	**type**\:  :py:class:`ConnectionStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.ConnectionStatus>`
                    
                    .. attribute:: ecio
                    
                    	ecio
                    	**type**\:  :py:class:`Ecio <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Ecio>`
                    
                    .. attribute:: modem_state
                    
                    	modem state
                    	**type**\:  :py:class:`ModemState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.ModemState>`
                    
                    .. attribute:: network
                    
                    	enable trap for network
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Network>`
                    
                    .. attribute:: rsrp
                    
                    	Reference Signal Received Power
                    	**type**\:  :py:class:`Rsrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rsrp>`
                    
                    .. attribute:: rsrq
                    
                    	Reference Signal Received Quality
                    	**type**\:  :py:class:`Rsrq <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rsrq>`
                    
                    .. attribute:: rssi
                    
                    	rssi
                    	**type**\:  :py:class:`Rssi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rssi>`
                    
                    .. attribute:: service
                    
                    	enable trap for service
                    	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Service>`
                    
                    .. attribute:: temperature
                    
                    	modem temperature
                    	**type**\:  :py:class:`Temperature <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Temperature>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Cellular.Lte.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "lte"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("connection-status", ("connection_status", Native.Controller.Cellular.Lte.Event.ConnectionStatus)), ("ecio", ("ecio", Native.Controller.Cellular.Lte.Event.Ecio)), ("modem-state", ("modem_state", Native.Controller.Cellular.Lte.Event.ModemState)), ("network", ("network", Native.Controller.Cellular.Lte.Event.Network)), ("rsrp", ("rsrp", Native.Controller.Cellular.Lte.Event.Rsrp)), ("rsrq", ("rsrq", Native.Controller.Cellular.Lte.Event.Rsrq)), ("rssi", ("rssi", Native.Controller.Cellular.Lte.Event.Rssi)), ("service", ("service", Native.Controller.Cellular.Lte.Event.Service)), ("temperature", ("temperature", Native.Controller.Cellular.Lte.Event.Temperature))])
                        self._leafs = OrderedDict()

                        self.connection_status = Native.Controller.Cellular.Lte.Event.ConnectionStatus()
                        self.connection_status.parent = self
                        self._children_name_map["connection_status"] = "connection-status"

                        self.ecio = Native.Controller.Cellular.Lte.Event.Ecio()
                        self.ecio.parent = self
                        self._children_name_map["ecio"] = "ecio"

                        self.modem_state = Native.Controller.Cellular.Lte.Event.ModemState()
                        self.modem_state.parent = self
                        self._children_name_map["modem_state"] = "modem-state"

                        self.network = Native.Controller.Cellular.Lte.Event.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.rsrp = Native.Controller.Cellular.Lte.Event.Rsrp()
                        self.rsrp.parent = self
                        self._children_name_map["rsrp"] = "rsrp"

                        self.rsrq = Native.Controller.Cellular.Lte.Event.Rsrq()
                        self.rsrq.parent = self
                        self._children_name_map["rsrq"] = "rsrq"

                        self.rssi = Native.Controller.Cellular.Lte.Event.Rssi()
                        self.rssi.parent = self
                        self._children_name_map["rssi"] = "rssi"

                        self.service = Native.Controller.Cellular.Lte.Event.Service()
                        self.service.parent = self
                        self._children_name_map["service"] = "service"

                        self.temperature = Native.Controller.Cellular.Lte.Event.Temperature()
                        self.temperature.parent = self
                        self._children_name_map["temperature"] = "temperature"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Cellular.Lte.Event, [], name, value)


                    class ConnectionStatus(Entity):
                        """
                        connection status
                        
                        .. attribute:: mib_trap
                        
                        	mibtrap
                        	**type**\: list of   :py:class:`MibTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.ConnectionStatus.MibTrap>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Event.ConnectionStatus, self).__init__()

                            self.yang_name = "connection-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mib_trap', (YLeafList(YType.enumeration, 'mib-trap'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Event.ConnectionStatus.MibTrap')])),
                            ])
                            self.mib_trap = []
                            self._segment_path = lambda: "connection-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Event.ConnectionStatus, ['mib_trap'], name, value)

                        class MibTrap(Enum):
                            """
                            MibTrap (Enum Class)

                            mibtrap

                            .. data:: All_lte = 0

                            .. data:: active = 1

                            .. data:: inactive = 2

                            """

                            All_lte = Enum.YLeaf(0, "All-lte")

                            active = Enum.YLeaf(1, "active")

                            inactive = Enum.YLeaf(2, "inactive")



                    class Ecio(Entity):
                        """
                        ecio
                        
                        .. attribute:: abate
                        
                        	
                        	**type**\:  :py:class:`Abate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Ecio.Abate>`
                        
                        .. attribute:: onset
                        
                        	
                        	**type**\:  :py:class:`Onset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Ecio.Onset>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Event.Ecio, self).__init__()

                            self.yang_name = "ecio"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("abate", ("abate", Native.Controller.Cellular.Lte.Event.Ecio.Abate)), ("onset", ("onset", Native.Controller.Cellular.Lte.Event.Ecio.Onset))])
                            self._leafs = OrderedDict()

                            self.abate = Native.Controller.Cellular.Lte.Event.Ecio.Abate()
                            self.abate.parent = self
                            self._children_name_map["abate"] = "abate"

                            self.onset = Native.Controller.Cellular.Lte.Event.Ecio.Onset()
                            self.onset.parent = self
                            self._children_name_map["onset"] = "onset"
                            self._segment_path = lambda: "ecio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Event.Ecio, [], name, value)


                        class Abate(Entity):
                            """
                            
                            
                            .. attribute:: mib_trap
                            
                            	mibtrap
                            	**type**\: list of   :py:class:`MibTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Ecio.Abate.MibTrap>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-150..0
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Event.Ecio.Abate, self).__init__()

                                self.yang_name = "abate"
                                self.yang_parent_name = "ecio"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mib_trap', (YLeafList(YType.enumeration, 'mib-trap'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Event.Ecio.Abate.MibTrap')])),
                                    ('threshold', (YLeaf(YType.int16, 'threshold'), ['int'])),
                                ])
                                self.mib_trap = []
                                self.threshold = None
                                self._segment_path = lambda: "abate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Event.Ecio.Abate, ['mib_trap', 'threshold'], name, value)

                            class MibTrap(Enum):
                                """
                                MibTrap (Enum Class)

                                mibtrap

                                .. data:: Y_1xrtt = 0

                                .. data:: All_lte = 1

                                .. data:: edge = 2

                                .. data:: evdoRel0 = 3

                                .. data:: evdoRelA = 4

                                .. data:: evdoRelB = 5

                                .. data:: gprs = 6

                                .. data:: umts__FWD_SLASH__wcdma = 7

                                .. data:: hsdpa = 8

                                .. data:: hsupa = 9

                                .. data:: hspa = 10

                                .. data:: hspa_plus = 11

                                .. data:: lte_tdd = 12

                                .. data:: lte_fdd = 13

                                """

                                Y_1xrtt = Enum.YLeaf(0, "1xrtt")

                                All_lte = Enum.YLeaf(1, "All-lte")

                                edge = Enum.YLeaf(2, "edge")

                                evdoRel0 = Enum.YLeaf(3, "evdoRel0")

                                evdoRelA = Enum.YLeaf(4, "evdoRelA")

                                evdoRelB = Enum.YLeaf(5, "evdoRelB")

                                gprs = Enum.YLeaf(6, "gprs")

                                umts__FWD_SLASH__wcdma = Enum.YLeaf(7, "umts/wcdma")

                                hsdpa = Enum.YLeaf(8, "hsdpa")

                                hsupa = Enum.YLeaf(9, "hsupa")

                                hspa = Enum.YLeaf(10, "hspa")

                                hspa_plus = Enum.YLeaf(11, "hspa-plus")

                                lte_tdd = Enum.YLeaf(12, "lte-tdd")

                                lte_fdd = Enum.YLeaf(13, "lte-fdd")



                        class Onset(Entity):
                            """
                            
                            
                            .. attribute:: mib_trap
                            
                            	mibtrap
                            	**type**\: list of   :py:class:`MibTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Ecio.Onset.MibTrap>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-150..0
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Event.Ecio.Onset, self).__init__()

                                self.yang_name = "onset"
                                self.yang_parent_name = "ecio"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mib_trap', (YLeafList(YType.enumeration, 'mib-trap'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Event.Ecio.Onset.MibTrap')])),
                                    ('threshold', (YLeaf(YType.int16, 'threshold'), ['int'])),
                                ])
                                self.mib_trap = []
                                self.threshold = None
                                self._segment_path = lambda: "onset"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Event.Ecio.Onset, ['mib_trap', 'threshold'], name, value)

                            class MibTrap(Enum):
                                """
                                MibTrap (Enum Class)

                                mibtrap

                                .. data:: Y_1xrtt = 0

                                .. data:: All_lte = 1

                                .. data:: edge = 2

                                .. data:: evdoRel0 = 3

                                .. data:: evdoRelA = 4

                                .. data:: evdoRelB = 5

                                .. data:: gprs = 6

                                .. data:: umts__FWD_SLASH__wcdma = 7

                                .. data:: hsdpa = 8

                                .. data:: hsupa = 9

                                .. data:: hspa = 10

                                .. data:: hspa_plus = 11

                                .. data:: lte_tdd = 12

                                .. data:: lte_fdd = 13

                                """

                                Y_1xrtt = Enum.YLeaf(0, "1xrtt")

                                All_lte = Enum.YLeaf(1, "All-lte")

                                edge = Enum.YLeaf(2, "edge")

                                evdoRel0 = Enum.YLeaf(3, "evdoRel0")

                                evdoRelA = Enum.YLeaf(4, "evdoRelA")

                                evdoRelB = Enum.YLeaf(5, "evdoRelB")

                                gprs = Enum.YLeaf(6, "gprs")

                                umts__FWD_SLASH__wcdma = Enum.YLeaf(7, "umts/wcdma")

                                hsdpa = Enum.YLeaf(8, "hsdpa")

                                hsupa = Enum.YLeaf(9, "hsupa")

                                hspa = Enum.YLeaf(10, "hspa")

                                hspa_plus = Enum.YLeaf(11, "hspa-plus")

                                lte_tdd = Enum.YLeaf(12, "lte-tdd")

                                lte_fdd = Enum.YLeaf(13, "lte-fdd")



                    class ModemState(Entity):
                        """
                        modem state
                        
                        .. attribute:: mib_trap
                        
                        	mibtrap
                        	**type**\: list of   :py:class:`MibTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.ModemState.MibTrap>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Event.ModemState, self).__init__()

                            self.yang_name = "modem-state"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mib_trap', (YLeafList(YType.enumeration, 'mib-trap'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Event.ModemState.MibTrap')])),
                            ])
                            self.mib_trap = []
                            self._segment_path = lambda: "modem-state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Event.ModemState, ['mib_trap'], name, value)

                        class MibTrap(Enum):
                            """
                            MibTrap (Enum Class)

                            mibtrap

                            .. data:: all = 0

                            .. data:: down = 1

                            .. data:: up = 2

                            """

                            all = Enum.YLeaf(0, "all")

                            down = Enum.YLeaf(1, "down")

                            up = Enum.YLeaf(2, "up")



                    class Network(Entity):
                        """
                        enable trap for network
                        
                        .. attribute:: mib_trap
                        
                        	mibtrap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Event.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mib_trap', (YLeaf(YType.empty, 'mib-trap'), ['Empty'])),
                            ])
                            self.mib_trap = None
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Event.Network, ['mib_trap'], name, value)


                    class Rsrp(Entity):
                        """
                        Reference Signal Received Power
                        
                        .. attribute:: abate
                        
                        	
                        	**type**\:  :py:class:`Abate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rsrp.Abate>`
                        
                        .. attribute:: onset
                        
                        	
                        	**type**\:  :py:class:`Onset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rsrp.Onset>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Event.Rsrp, self).__init__()

                            self.yang_name = "rsrp"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("abate", ("abate", Native.Controller.Cellular.Lte.Event.Rsrp.Abate)), ("onset", ("onset", Native.Controller.Cellular.Lte.Event.Rsrp.Onset))])
                            self._leafs = OrderedDict()

                            self.abate = Native.Controller.Cellular.Lte.Event.Rsrp.Abate()
                            self.abate.parent = self
                            self._children_name_map["abate"] = "abate"

                            self.onset = Native.Controller.Cellular.Lte.Event.Rsrp.Onset()
                            self.onset.parent = self
                            self._children_name_map["onset"] = "onset"
                            self._segment_path = lambda: "rsrp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Event.Rsrp, [], name, value)


                        class Abate(Entity):
                            """
                            
                            
                            .. attribute:: mib_trap
                            
                            	mibtrap
                            	**type**\: list of   :py:class:`MibTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rsrp.Abate.MibTrap>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-150..0
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Event.Rsrp.Abate, self).__init__()

                                self.yang_name = "abate"
                                self.yang_parent_name = "rsrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mib_trap', (YLeafList(YType.enumeration, 'mib-trap'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Event.Rsrp.Abate.MibTrap')])),
                                    ('threshold', (YLeaf(YType.int16, 'threshold'), ['int'])),
                                ])
                                self.mib_trap = []
                                self.threshold = None
                                self._segment_path = lambda: "abate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Event.Rsrp.Abate, ['mib_trap', 'threshold'], name, value)

                            class MibTrap(Enum):
                                """
                                MibTrap (Enum Class)

                                mibtrap

                                .. data:: All_lte = 0

                                .. data:: lte_tdd = 1

                                .. data:: lte_fdd = 2

                                """

                                All_lte = Enum.YLeaf(0, "All-lte")

                                lte_tdd = Enum.YLeaf(1, "lte-tdd")

                                lte_fdd = Enum.YLeaf(2, "lte-fdd")



                        class Onset(Entity):
                            """
                            
                            
                            .. attribute:: mib_trap
                            
                            	mibtrap
                            	**type**\: list of   :py:class:`MibTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rsrp.Onset.MibTrap>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-150..0
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Event.Rsrp.Onset, self).__init__()

                                self.yang_name = "onset"
                                self.yang_parent_name = "rsrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mib_trap', (YLeafList(YType.enumeration, 'mib-trap'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Event.Rsrp.Onset.MibTrap')])),
                                    ('threshold', (YLeaf(YType.int16, 'threshold'), ['int'])),
                                ])
                                self.mib_trap = []
                                self.threshold = None
                                self._segment_path = lambda: "onset"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Event.Rsrp.Onset, ['mib_trap', 'threshold'], name, value)

                            class MibTrap(Enum):
                                """
                                MibTrap (Enum Class)

                                mibtrap

                                .. data:: All_lte = 0

                                .. data:: lte_tdd = 1

                                .. data:: lte_fdd = 2

                                """

                                All_lte = Enum.YLeaf(0, "All-lte")

                                lte_tdd = Enum.YLeaf(1, "lte-tdd")

                                lte_fdd = Enum.YLeaf(2, "lte-fdd")



                    class Rsrq(Entity):
                        """
                        Reference Signal Received Quality
                        
                        .. attribute:: abate
                        
                        	
                        	**type**\:  :py:class:`Abate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rsrq.Abate>`
                        
                        .. attribute:: onset
                        
                        	
                        	**type**\:  :py:class:`Onset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rsrq.Onset>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Event.Rsrq, self).__init__()

                            self.yang_name = "rsrq"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("abate", ("abate", Native.Controller.Cellular.Lte.Event.Rsrq.Abate)), ("onset", ("onset", Native.Controller.Cellular.Lte.Event.Rsrq.Onset))])
                            self._leafs = OrderedDict()

                            self.abate = Native.Controller.Cellular.Lte.Event.Rsrq.Abate()
                            self.abate.parent = self
                            self._children_name_map["abate"] = "abate"

                            self.onset = Native.Controller.Cellular.Lte.Event.Rsrq.Onset()
                            self.onset.parent = self
                            self._children_name_map["onset"] = "onset"
                            self._segment_path = lambda: "rsrq"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Event.Rsrq, [], name, value)


                        class Abate(Entity):
                            """
                            
                            
                            .. attribute:: mib_trap
                            
                            	mibtrap
                            	**type**\: list of   :py:class:`MibTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rsrq.Abate.MibTrap>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-20..0
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Event.Rsrq.Abate, self).__init__()

                                self.yang_name = "abate"
                                self.yang_parent_name = "rsrq"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mib_trap', (YLeafList(YType.enumeration, 'mib-trap'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Event.Rsrq.Abate.MibTrap')])),
                                    ('threshold', (YLeaf(YType.int8, 'threshold'), ['int'])),
                                ])
                                self.mib_trap = []
                                self.threshold = None
                                self._segment_path = lambda: "abate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Event.Rsrq.Abate, ['mib_trap', 'threshold'], name, value)

                            class MibTrap(Enum):
                                """
                                MibTrap (Enum Class)

                                mibtrap

                                .. data:: All_lte = 0

                                .. data:: lte_tdd = 1

                                .. data:: lte_fdd = 2

                                """

                                All_lte = Enum.YLeaf(0, "All-lte")

                                lte_tdd = Enum.YLeaf(1, "lte-tdd")

                                lte_fdd = Enum.YLeaf(2, "lte-fdd")



                        class Onset(Entity):
                            """
                            
                            
                            .. attribute:: mib_trap
                            
                            	mibtrap
                            	**type**\: list of   :py:class:`MibTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rsrq.Onset.MibTrap>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-20..0
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Event.Rsrq.Onset, self).__init__()

                                self.yang_name = "onset"
                                self.yang_parent_name = "rsrq"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mib_trap', (YLeafList(YType.enumeration, 'mib-trap'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Event.Rsrq.Onset.MibTrap')])),
                                    ('threshold', (YLeaf(YType.int8, 'threshold'), ['int'])),
                                ])
                                self.mib_trap = []
                                self.threshold = None
                                self._segment_path = lambda: "onset"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Event.Rsrq.Onset, ['mib_trap', 'threshold'], name, value)

                            class MibTrap(Enum):
                                """
                                MibTrap (Enum Class)

                                mibtrap

                                .. data:: All_lte = 0

                                .. data:: lte_tdd = 1

                                .. data:: lte_fdd = 2

                                """

                                All_lte = Enum.YLeaf(0, "All-lte")

                                lte_tdd = Enum.YLeaf(1, "lte-tdd")

                                lte_fdd = Enum.YLeaf(2, "lte-fdd")



                    class Rssi(Entity):
                        """
                        rssi
                        
                        .. attribute:: abate
                        
                        	
                        	**type**\:  :py:class:`Abate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rssi.Abate>`
                        
                        .. attribute:: onset
                        
                        	
                        	**type**\:  :py:class:`Onset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rssi.Onset>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Event.Rssi, self).__init__()

                            self.yang_name = "rssi"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("abate", ("abate", Native.Controller.Cellular.Lte.Event.Rssi.Abate)), ("onset", ("onset", Native.Controller.Cellular.Lte.Event.Rssi.Onset))])
                            self._leafs = OrderedDict()

                            self.abate = Native.Controller.Cellular.Lte.Event.Rssi.Abate()
                            self.abate.parent = self
                            self._children_name_map["abate"] = "abate"

                            self.onset = Native.Controller.Cellular.Lte.Event.Rssi.Onset()
                            self.onset.parent = self
                            self._children_name_map["onset"] = "onset"
                            self._segment_path = lambda: "rssi"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Event.Rssi, [], name, value)


                        class Abate(Entity):
                            """
                            
                            
                            .. attribute:: mib_trap
                            
                            	mibtrap
                            	**type**\: list of   :py:class:`MibTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rssi.Abate.MibTrap>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-150..0
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Event.Rssi.Abate, self).__init__()

                                self.yang_name = "abate"
                                self.yang_parent_name = "rssi"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mib_trap', (YLeafList(YType.enumeration, 'mib-trap'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Event.Rssi.Abate.MibTrap')])),
                                    ('threshold', (YLeaf(YType.int16, 'threshold'), ['int'])),
                                ])
                                self.mib_trap = []
                                self.threshold = None
                                self._segment_path = lambda: "abate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Event.Rssi.Abate, ['mib_trap', 'threshold'], name, value)

                            class MibTrap(Enum):
                                """
                                MibTrap (Enum Class)

                                mibtrap

                                .. data:: All_lte = 0

                                .. data:: lte_tdd = 1

                                .. data:: lte_fdd = 2

                                """

                                All_lte = Enum.YLeaf(0, "All-lte")

                                lte_tdd = Enum.YLeaf(1, "lte-tdd")

                                lte_fdd = Enum.YLeaf(2, "lte-fdd")



                        class Onset(Entity):
                            """
                            
                            
                            .. attribute:: mib_trap
                            
                            	mibtrap
                            	**type**\: list of   :py:class:`MibTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Rssi.Onset.MibTrap>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-150..0
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Event.Rssi.Onset, self).__init__()

                                self.yang_name = "onset"
                                self.yang_parent_name = "rssi"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mib_trap', (YLeafList(YType.enumeration, 'mib-trap'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Cellular.Lte.Event.Rssi.Onset.MibTrap')])),
                                    ('threshold', (YLeaf(YType.int16, 'threshold'), ['int'])),
                                ])
                                self.mib_trap = []
                                self.threshold = None
                                self._segment_path = lambda: "onset"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Event.Rssi.Onset, ['mib_trap', 'threshold'], name, value)

                            class MibTrap(Enum):
                                """
                                MibTrap (Enum Class)

                                mibtrap

                                .. data:: All_lte = 0

                                .. data:: lte_tdd = 1

                                .. data:: lte_fdd = 2

                                """

                                All_lte = Enum.YLeaf(0, "All-lte")

                                lte_tdd = Enum.YLeaf(1, "lte-tdd")

                                lte_fdd = Enum.YLeaf(2, "lte-fdd")



                    class Service(Entity):
                        """
                        enable trap for service
                        
                        .. attribute:: mib_trap
                        
                        	mibtrap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Event.Service, self).__init__()

                            self.yang_name = "service"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mib_trap', (YLeaf(YType.empty, 'mib-trap'), ['Empty'])),
                            ])
                            self.mib_trap = None
                            self._segment_path = lambda: "service"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Event.Service, ['mib_trap'], name, value)


                    class Temperature(Entity):
                        """
                        modem temperature
                        
                        .. attribute:: abate
                        
                        	
                        	**type**\:  :py:class:`Abate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Temperature.Abate>`
                        
                        .. attribute:: onset
                        
                        	
                        	**type**\:  :py:class:`Onset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Event.Temperature.Onset>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Event.Temperature, self).__init__()

                            self.yang_name = "temperature"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("abate", ("abate", Native.Controller.Cellular.Lte.Event.Temperature.Abate)), ("onset", ("onset", Native.Controller.Cellular.Lte.Event.Temperature.Onset))])
                            self._leafs = OrderedDict()

                            self.abate = Native.Controller.Cellular.Lte.Event.Temperature.Abate()
                            self.abate.parent = self
                            self._children_name_map["abate"] = "abate"

                            self.onset = Native.Controller.Cellular.Lte.Event.Temperature.Onset()
                            self.onset.parent = self
                            self._children_name_map["onset"] = "onset"
                            self._segment_path = lambda: "temperature"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Event.Temperature, [], name, value)


                        class Abate(Entity):
                            """
                            
                            
                            .. attribute:: mib_trap
                            
                            	mibtrap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-150..0
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Event.Temperature.Abate, self).__init__()

                                self.yang_name = "abate"
                                self.yang_parent_name = "temperature"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mib_trap', (YLeaf(YType.empty, 'mib-trap'), ['Empty'])),
                                    ('threshold', (YLeaf(YType.int16, 'threshold'), ['int'])),
                                ])
                                self.mib_trap = None
                                self.threshold = None
                                self._segment_path = lambda: "abate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Event.Temperature.Abate, ['mib_trap', 'threshold'], name, value)


                        class Onset(Entity):
                            """
                            
                            
                            .. attribute:: mib_trap
                            
                            	mibtrap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-150..0
                            
                            

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Cellular.Lte.Event.Temperature.Onset, self).__init__()

                                self.yang_name = "onset"
                                self.yang_parent_name = "temperature"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mib_trap', (YLeaf(YType.empty, 'mib-trap'), ['Empty'])),
                                    ('threshold', (YLeaf(YType.int16, 'threshold'), ['int'])),
                                ])
                                self.mib_trap = None
                                self.threshold = None
                                self._segment_path = lambda: "onset"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Cellular.Lte.Event.Temperature.Onset, ['mib_trap', 'threshold'], name, value)


                class Dyinggasp(Entity):
                    """
                    Dying Gasp Configuration
                    
                    .. attribute:: detach
                    
                    	Send Detach Request
                    	**type**\:  :py:class:`Detach <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Dyinggasp.Detach>`
                    
                    .. attribute:: sms
                    
                    	SMS Commands
                    	**type**\:  :py:class:`Sms <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Cellular.Lte.Dyinggasp.Sms>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Cellular.Lte.Dyinggasp, self).__init__()

                        self.yang_name = "dyinggasp"
                        self.yang_parent_name = "lte"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("detach", ("detach", Native.Controller.Cellular.Lte.Dyinggasp.Detach)), ("sms", ("sms", Native.Controller.Cellular.Lte.Dyinggasp.Sms))])
                        self._leafs = OrderedDict()

                        self.detach = Native.Controller.Cellular.Lte.Dyinggasp.Detach()
                        self.detach.parent = self
                        self._children_name_map["detach"] = "detach"

                        self.sms = Native.Controller.Cellular.Lte.Dyinggasp.Sms()
                        self.sms.parent = self
                        self._children_name_map["sms"] = "sms"
                        self._segment_path = lambda: "dyinggasp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Cellular.Lte.Dyinggasp, [], name, value)


                    class Detach(Entity):
                        """
                        Send Detach Request
                        
                        .. attribute:: enable
                        
                        	Enable Dying Gasp Detach Request
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Dyinggasp.Detach, self).__init__()

                            self.yang_name = "detach"
                            self.yang_parent_name = "dyinggasp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ])
                            self.enable = None
                            self._segment_path = lambda: "detach"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Dyinggasp.Detach, ['enable'], name, value)


                    class Sms(Entity):
                        """
                        SMS Commands
                        
                        .. attribute:: send
                        
                        	Send SMS
                        	**type**\: str
                        
                        .. attribute:: sms_text
                        
                        	SMS text until the end of line (EOL) up to 160 characters
                        	**type**\: str
                        
                        	**length:** 1..160
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Cellular.Lte.Dyinggasp.Sms, self).__init__()

                            self.yang_name = "sms"
                            self.yang_parent_name = "dyinggasp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('send', (YLeaf(YType.str, 'send'), ['str'])),
                                ('sms_text', (YLeaf(YType.str, 'sms-text'), ['str'])),
                            ])
                            self.send = None
                            self.sms_text = None
                            self._segment_path = lambda: "sms"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Cellular.Lte.Dyinggasp.Sms, ['send', 'sms_text'], name, value)


        class SONET(Entity):
            """
            SONET
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: framing
            
            	SONET framing
            	**type**\:  :py:class:`Framing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Framing>`
            
            .. attribute:: shutdown
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: clock
            
            	SONET clock
            	**type**\:  :py:class:`Clock <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Clock>`
            
            .. attribute:: aug
            
            	AUG
            	**type**\:  :py:class:`Aug <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Aug>`
            
            .. attribute:: au_3
            
            	AU\-3
            	**type**\: list of  		 :py:class:`Au3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au3>`
            
            .. attribute:: au_4_atm
            
            	
            	**type**\:  :py:class:`Au4Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4Atm>`
            
            .. attribute:: au_4
            
            	AU\-4
            	**type**\: list of  		 :py:class:`Au4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4>`
            
            .. attribute:: aps
            
            	SONET APS
            	**type**\:  :py:class:`Aps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Aps>`
            
            

            """

            _prefix = 'ios-ctrl'
            _revision = '2018-04-02'

            def __init__(self):
                super(Native.Controller.SONET, self).__init__()

                self.yang_name = "SONET"
                self.yang_parent_name = "controller"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("clock", ("clock", Native.Controller.SONET.Clock)), ("aug", ("aug", Native.Controller.SONET.Aug)), ("au-3", ("au_3", Native.Controller.SONET.Au3)), ("au-4-atm", ("au_4_atm", Native.Controller.SONET.Au4Atm)), ("au-4", ("au_4", Native.Controller.SONET.Au4)), ("aps", ("aps", Native.Controller.SONET.Aps))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('framing', (YLeaf(YType.enumeration, 'framing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONET.Framing')])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                ])
                self.name = None
                self.framing = None
                self.shutdown = None

                self.clock = Native.Controller.SONET.Clock()
                self.clock.parent = self
                self._children_name_map["clock"] = "clock"

                self.aug = Native.Controller.SONET.Aug()
                self.aug.parent = self
                self._children_name_map["aug"] = "aug"

                self.au_4_atm = Native.Controller.SONET.Au4Atm()
                self.au_4_atm.parent = self
                self._children_name_map["au_4_atm"] = "au-4-atm"

                self.aps = Native.Controller.SONET.Aps()
                self.aps.parent = self
                self._children_name_map["aps"] = "aps"

                self.au_3 = YList(self)
                self.au_4 = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-controller:SONET" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/controller/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Controller.SONET, ['name', 'framing', 'shutdown'], name, value)

            class Framing(Enum):
                """
                Framing (Enum Class)

                SONET framing

                .. data:: sonet = 0

                .. data:: sdh = 1

                """

                sonet = Enum.YLeaf(0, "sonet")

                sdh = Enum.YLeaf(1, "sdh")



            class Clock(Entity):
                """
                SONET clock
                
                .. attribute:: source
                
                	SONET clock source
                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Clock.Source>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONET.Clock, self).__init__()

                    self.yang_name = "clock"
                    self.yang_parent_name = "SONET"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('source', (YLeaf(YType.enumeration, 'source'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONET.Clock.Source')])),
                    ])
                    self.source = None
                    self._segment_path = lambda: "clock"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONET.Clock, ['source'], name, value)

                class Source(Enum):
                    """
                    Source (Enum Class)

                    SONET clock source

                    .. data:: internal = 0

                    .. data:: line = 1

                    """

                    internal = Enum.YLeaf(0, "internal")

                    line = Enum.YLeaf(1, "line")



            class Aug(Entity):
                """
                AUG
                
                .. attribute:: mapping
                
                	
                	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Aug.Mapping>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONET.Aug, self).__init__()

                    self.yang_name = "aug"
                    self.yang_parent_name = "SONET"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mapping', (YLeaf(YType.enumeration, 'mapping'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONET.Aug.Mapping')])),
                    ])
                    self.mapping = None
                    self._segment_path = lambda: "aug"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONET.Aug, ['mapping'], name, value)

                class Mapping(Enum):
                    """
                    Mapping (Enum Class)

                    .. data:: au_3 = 0

                    .. data:: au_4 = 1

                    """

                    au_3 = Enum.YLeaf(0, "au-3")

                    au_4 = Enum.YLeaf(1, "au-4")



            class Au3(Entity):
                """
                AU\-3
                
                .. attribute:: number  (key)
                
                	AU\-3 number
                	**type**\: int
                
                	**range:** 1..3
                
                .. attribute:: overhead
                
                	overhead
                	**type**\:  :py:class:`Overhead <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au3.Overhead>`
                
                .. attribute:: mode
                
                	mode
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au3.Mode>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONET.Au3, self).__init__()

                    self.yang_name = "au-3"
                    self.yang_parent_name = "SONET"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("overhead", ("overhead", Native.Controller.SONET.Au3.Overhead)), ("mode", ("mode", Native.Controller.SONET.Au3.Mode))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                    ])
                    self.number = None

                    self.overhead = Native.Controller.SONET.Au3.Overhead()
                    self.overhead.parent = self
                    self._children_name_map["overhead"] = "overhead"

                    self.mode = Native.Controller.SONET.Au3.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"
                    self._segment_path = lambda: "au-3" + "[number='" + str(self.number) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONET.Au3, ['number'], name, value)


                class Overhead(Entity):
                    """
                    overhead
                    
                    .. attribute:: byte
                    
                    	
                    	**type**\:  :py:class:`Byte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au3.Overhead.Byte>`
                    
                    .. attribute:: length
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Au3.Overhead, self).__init__()

                        self.yang_name = "overhead"
                        self.yang_parent_name = "au-3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('byte', (YLeaf(YType.enumeration, 'byte'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONET.Au3.Overhead.Byte')])),
                            ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                        ])
                        self.byte = None
                        self.length = None
                        self._segment_path = lambda: "overhead"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Au3.Overhead, ['byte', 'length'], name, value)

                    class Byte(Enum):
                        """
                        Byte (Enum Class)

                        .. data:: j1 = 0

                        """

                        j1 = Enum.YLeaf(0, "j1")



                class Mode(Entity):
                    """
                    mode
                    
                    .. attribute:: mapping
                    
                    	
                    	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au3.Mode.Mapping>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Au3.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "au-3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mapping', (YLeaf(YType.enumeration, 'mapping'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONET.Au3.Mode.Mapping')])),
                        ])
                        self.mapping = None
                        self._segment_path = lambda: "mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Au3.Mode, ['mapping'], name, value)

                    class Mapping(Enum):
                        """
                        Mapping (Enum Class)

                        .. data:: c_11 = 0

                        .. data:: c_12 = 1

                        .. data:: c_2 = 2

                        """

                        c_11 = Enum.YLeaf(0, "c-11")

                        c_12 = Enum.YLeaf(1, "c-12")

                        c_2 = Enum.YLeaf(2, "c-2")



            class Au4Atm(Entity):
                """
                
                
                .. attribute:: au_4
                
                	AU\-4
                	**type**\:  :py:class:`Au4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4Atm.Au4>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONET.Au4Atm, self).__init__()

                    self.yang_name = "au-4-atm"
                    self.yang_parent_name = "SONET"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("au-4", ("au_4", Native.Controller.SONET.Au4Atm.Au4))])
                    self._leafs = OrderedDict()

                    self.au_4 = Native.Controller.SONET.Au4Atm.Au4()
                    self.au_4.parent = self
                    self._children_name_map["au_4"] = "au-4"
                    self._segment_path = lambda: "au-4-atm"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONET.Au4Atm, [], name, value)


                class Au4(Entity):
                    """
                    AU\-4
                    
                    .. attribute:: number
                    
                    	AU\-4 number
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Au4Atm.Au4, self).__init__()

                        self.yang_name = "au-4"
                        self.yang_parent_name = "au-4-atm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                            ('atm', (YLeaf(YType.empty, 'atm'), ['Empty'])),
                        ])
                        self.number = None
                        self.atm = None
                        self._segment_path = lambda: "au-4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Au4Atm.Au4, ['number', 'atm'], name, value)


            class Au4(Entity):
                """
                AU\-4
                
                .. attribute:: number  (key)
                
                	AU\-4 number
                	**type**\: int
                
                	**range:** 1..3
                
                .. attribute:: tug_3  (key)
                
                	TUG\-3
                	**type**\: int
                
                	**range:** 1..3
                
                .. attribute:: mode
                
                	mode
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.Mode>`
                
                .. attribute:: cem_group
                
                	CEM group
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: unframed
                
                	Unframed
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: framing
                
                	
                	**type**\:  :py:class:`Framing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.Framing>`
                
                .. attribute:: cem_group_timeslots
                
                	
                	**type**\:  :py:class:`CemGroupTimeslots <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.CemGroupTimeslots>`
                
                .. attribute:: channel_group_timeslots
                
                	
                	**type**\:  :py:class:`ChannelGroupTimeslots <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.ChannelGroupTimeslots>`
                
                .. attribute:: cem_group_unframed
                
                	
                	**type**\:  :py:class:`CemGroupUnframed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.CemGroupUnframed>`
                
                .. attribute:: framing_unframed
                
                	
                	**type**\:  :py:class:`FramingUnframed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.FramingUnframed>`
                
                .. attribute:: cem_group_atm
                
                	
                	**type**\:  :py:class:`CemGroupAtm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.CemGroupAtm>`
                
                .. attribute:: ima_group
                
                	
                	**type**\:  :py:class:`ImaGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.ImaGroup>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONET.Au4, self).__init__()

                    self.yang_name = "au-4"
                    self.yang_parent_name = "SONET"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['number','tug_3']
                    self._child_classes = OrderedDict([("cem-group-timeslots", ("cem_group_timeslots", Native.Controller.SONET.Au4.CemGroupTimeslots)), ("channel-group-timeslots", ("channel_group_timeslots", Native.Controller.SONET.Au4.ChannelGroupTimeslots)), ("cem-group-unframed", ("cem_group_unframed", Native.Controller.SONET.Au4.CemGroupUnframed)), ("framing-unframed", ("framing_unframed", Native.Controller.SONET.Au4.FramingUnframed)), ("cem-group-atm", ("cem_group_atm", Native.Controller.SONET.Au4.CemGroupAtm)), ("ima-group", ("ima_group", Native.Controller.SONET.Au4.ImaGroup))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                        ('tug_3', (YLeaf(YType.int8, 'tug-3'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONET.Au4.Mode')])),
                        ('cem_group', (YLeaf(YType.int32, 'cem-group'), ['int'])),
                        ('unframed', (YLeaf(YType.empty, 'unframed'), ['Empty'])),
                        ('framing', (YLeaf(YType.enumeration, 'framing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONET.Au4.Framing')])),
                    ])
                    self.number = None
                    self.tug_3 = None
                    self.mode = None
                    self.cem_group = None
                    self.unframed = None
                    self.framing = None

                    self.cem_group_timeslots = Native.Controller.SONET.Au4.CemGroupTimeslots()
                    self.cem_group_timeslots.parent = self
                    self._children_name_map["cem_group_timeslots"] = "cem-group-timeslots"

                    self.channel_group_timeslots = Native.Controller.SONET.Au4.ChannelGroupTimeslots()
                    self.channel_group_timeslots.parent = self
                    self._children_name_map["channel_group_timeslots"] = "channel-group-timeslots"

                    self.cem_group_unframed = Native.Controller.SONET.Au4.CemGroupUnframed()
                    self.cem_group_unframed.parent = self
                    self._children_name_map["cem_group_unframed"] = "cem-group-unframed"

                    self.framing_unframed = Native.Controller.SONET.Au4.FramingUnframed()
                    self.framing_unframed.parent = self
                    self._children_name_map["framing_unframed"] = "framing-unframed"

                    self.cem_group_atm = Native.Controller.SONET.Au4.CemGroupAtm()
                    self.cem_group_atm.parent = self
                    self._children_name_map["cem_group_atm"] = "cem-group-atm"

                    self.ima_group = Native.Controller.SONET.Au4.ImaGroup()
                    self.ima_group.parent = self
                    self._children_name_map["ima_group"] = "ima-group"
                    self._segment_path = lambda: "au-4" + "[number='" + str(self.number) + "']" + "[tug-3='" + str(self.tug_3) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONET.Au4, ['number', 'tug_3', 'mode', 'cem_group', 'unframed', 'framing'], name, value)

                class Framing(Enum):
                    """
                    Framing (Enum Class)

                    .. data:: unframed = 0

                    """

                    unframed = Enum.YLeaf(0, "unframed")


                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    mode

                    .. data:: c_11 = 0

                    .. data:: c_12 = 1

                    .. data:: c_2 = 2

                    .. data:: c_3 = 3

                    .. data:: c_4 = 4

                    .. data:: e3 = 5

                    """

                    c_11 = Enum.YLeaf(0, "c-11")

                    c_12 = Enum.YLeaf(1, "c-12")

                    c_2 = Enum.YLeaf(2, "c-2")

                    c_3 = Enum.YLeaf(3, "c-3")

                    c_4 = Enum.YLeaf(4, "c-4")

                    e3 = Enum.YLeaf(5, "e3")



                class CemGroupTimeslots(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.CemGroupTimeslots.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Au4.CemGroupTimeslots, self).__init__()

                        self.yang_name = "cem-group-timeslots"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONET.Au4.CemGroupTimeslots.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "cem-group-timeslots"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Au4.CemGroupTimeslots, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: cem_group  (key)
                        
                        	CEM group
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: timeslots
                        
                        	Time slots
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONET.Au4.CemGroupTimeslots.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "cem-group-timeslots"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1','cem_group']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('cem_group', (YLeaf(YType.int32, 'cem-group'), ['int'])),
                                ('timeslots', (YLeaf(YType.str, 'timeslots'), ['str'])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.cem_group = None
                            self.timeslots = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']" + "[cem-group='" + str(self.cem_group) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONET.Au4.CemGroupTimeslots.Tug2, ['number', 'e1', 'cem_group', 'timeslots'], name, value)


                class ChannelGroupTimeslots(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.ChannelGroupTimeslots.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Au4.ChannelGroupTimeslots, self).__init__()

                        self.yang_name = "channel-group-timeslots"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONET.Au4.ChannelGroupTimeslots.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "channel-group-timeslots"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Au4.ChannelGroupTimeslots, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: channel_group  (key)
                        
                        	Channel group
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: timeslots
                        
                        	Time slots
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONET.Au4.ChannelGroupTimeslots.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "channel-group-timeslots"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1','channel_group']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('channel_group', (YLeaf(YType.int32, 'channel-group'), ['int'])),
                                ('timeslots', (YLeaf(YType.str, 'timeslots'), ['str'])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.channel_group = None
                            self.timeslots = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']" + "[channel-group='" + str(self.channel_group) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONET.Au4.ChannelGroupTimeslots.Tug2, ['number', 'e1', 'channel_group', 'timeslots'], name, value)


                class CemGroupUnframed(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.CemGroupUnframed.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Au4.CemGroupUnframed, self).__init__()

                        self.yang_name = "cem-group-unframed"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONET.Au4.CemGroupUnframed.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "cem-group-unframed"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Au4.CemGroupUnframed, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: cem_group  (key)
                        
                        	CEM group
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: unframed
                        
                        	Unframed
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONET.Au4.CemGroupUnframed.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "cem-group-unframed"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1','cem_group']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('cem_group', (YLeaf(YType.int32, 'cem-group'), ['int'])),
                                ('unframed', (YLeaf(YType.empty, 'unframed'), ['Empty'])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.cem_group = None
                            self.unframed = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']" + "[cem-group='" + str(self.cem_group) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONET.Au4.CemGroupUnframed.Tug2, ['number', 'e1', 'cem_group', 'unframed'], name, value)


                class FramingUnframed(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.FramingUnframed.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Au4.FramingUnframed, self).__init__()

                        self.yang_name = "framing-unframed"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONET.Au4.FramingUnframed.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "framing-unframed"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Au4.FramingUnframed, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: framing
                        
                        	
                        	**type**\:  :py:class:`Framing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.FramingUnframed.Tug2.Framing>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONET.Au4.FramingUnframed.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "framing-unframed"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('framing', (YLeaf(YType.enumeration, 'framing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONET.Au4.FramingUnframed.Tug2.Framing')])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.framing = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONET.Au4.FramingUnframed.Tug2, ['number', 'e1', 'framing'], name, value)

                        class Framing(Enum):
                            """
                            Framing (Enum Class)

                            .. data:: unframed = 0

                            """

                            unframed = Enum.YLeaf(0, "unframed")



                class CemGroupAtm(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.CemGroupAtm.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Au4.CemGroupAtm, self).__init__()

                        self.yang_name = "cem-group-atm"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONET.Au4.CemGroupAtm.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "cem-group-atm"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Au4.CemGroupAtm, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONET.Au4.CemGroupAtm.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "cem-group-atm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('atm', (YLeaf(YType.empty, 'atm'), ['Empty'])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.atm = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONET.Au4.CemGroupAtm.Tug2, ['number', 'e1', 'atm'], name, value)


                class ImaGroup(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Au4.ImaGroup.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Au4.ImaGroup, self).__init__()

                        self.yang_name = "ima-group"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONET.Au4.ImaGroup.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "ima-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Au4.ImaGroup, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: ima_group  (key)
                        
                        	IMA group
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONET.Au4.ImaGroup.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "ima-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1','ima_group']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('ima_group', (YLeaf(YType.int32, 'ima-group'), ['int'])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.ima_group = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']" + "[ima-group='" + str(self.ima_group) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONET.Au4.ImaGroup.Tug2, ['number', 'e1', 'ima_group'], name, value)


            class Aps(Entity):
                """
                SONET APS
                
                .. attribute:: group
                
                	SONET APS group
                	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Aps.Group>`
                
                .. attribute:: working
                
                	Working line
                	**type**\: int
                
                	**range:** \-128..127
                
                .. attribute:: protect
                
                	Protect line
                	**type**\:  :py:class:`Protect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Aps.Protect>`
                
                .. attribute:: hspw_icrm_grp
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: interchassis
                
                	
                	**type**\:  :py:class:`Interchassis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONET.Aps.Interchassis>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONET.Aps, self).__init__()

                    self.yang_name = "aps"
                    self.yang_parent_name = "SONET"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("group", ("group", Native.Controller.SONET.Aps.Group)), ("protect", ("protect", Native.Controller.SONET.Aps.Protect)), ("interchassis", ("interchassis", Native.Controller.SONET.Aps.Interchassis))])
                    self._leafs = OrderedDict([
                        ('working', (YLeaf(YType.int8, 'working'), ['int'])),
                        ('hspw_icrm_grp', (YLeaf(YType.uint8, 'hspw-icrm-grp'), ['int'])),
                    ])
                    self.working = None
                    self.hspw_icrm_grp = None

                    self.group = Native.Controller.SONET.Aps.Group()
                    self.group.parent = self
                    self._children_name_map["group"] = "group"

                    self.protect = Native.Controller.SONET.Aps.Protect()
                    self.protect.parent = self
                    self._children_name_map["protect"] = "protect"

                    self.interchassis = Native.Controller.SONET.Aps.Interchassis()
                    self.interchassis.parent = self
                    self._children_name_map["interchassis"] = "interchassis"
                    self._segment_path = lambda: "aps"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONET.Aps, ['working', 'hspw_icrm_grp'], name, value)


                class Group(Entity):
                    """
                    SONET APS group
                    
                    .. attribute:: group_number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: acr
                    
                    	ACR
                    	**type**\: int
                    
                    	**range:** \-128..127
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Aps.Group, self).__init__()

                        self.yang_name = "group"
                        self.yang_parent_name = "aps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint8, 'group-number'), ['int'])),
                            ('acr', (YLeaf(YType.int8, 'acr'), ['int'])),
                        ])
                        self.group_number = None
                        self.acr = None
                        self._segment_path = lambda: "group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Aps.Group, ['group_number', 'acr'], name, value)


                class Protect(Entity):
                    """
                    Protect line
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** \-128..127
                    
                    .. attribute:: ip_addr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Aps.Protect, self).__init__()

                        self.yang_name = "protect"
                        self.yang_parent_name = "aps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str'])),
                        ])
                        self.number = None
                        self.ip_addr = None
                        self._segment_path = lambda: "protect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Aps.Protect, ['number', 'ip_addr'], name, value)


                class Interchassis(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONET.Aps.Interchassis, self).__init__()

                        self.yang_name = "interchassis"
                        self.yang_parent_name = "aps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "interchassis"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONET.Aps.Interchassis, ['group'], name, value)


        class SONETACR(Entity):
            """
            SONET\-ACR
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            	**pattern:** ([0\-9\\.])+
            
            .. attribute:: framing
            
            	SONET framing
            	**type**\:  :py:class:`Framing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Framing>`
            
            .. attribute:: shutdown
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: clock
            
            	SONET clock
            	**type**\:  :py:class:`Clock <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Clock>`
            
            .. attribute:: aug
            
            	AUG
            	**type**\:  :py:class:`Aug <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Aug>`
            
            .. attribute:: au_3
            
            	AU\-3
            	**type**\: list of  		 :py:class:`Au3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au3>`
            
            .. attribute:: au_4_atm
            
            	
            	**type**\:  :py:class:`Au4Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4Atm>`
            
            .. attribute:: au_4
            
            	AU\-4
            	**type**\: list of  		 :py:class:`Au4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4>`
            
            .. attribute:: aps
            
            	SONET APS
            	**type**\:  :py:class:`Aps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Aps>`
            
            

            """

            _prefix = 'ios-ctrl'
            _revision = '2018-04-02'

            def __init__(self):
                super(Native.Controller.SONETACR, self).__init__()

                self.yang_name = "SONET-ACR"
                self.yang_parent_name = "controller"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("clock", ("clock", Native.Controller.SONETACR.Clock)), ("aug", ("aug", Native.Controller.SONETACR.Aug)), ("au-3", ("au_3", Native.Controller.SONETACR.Au3)), ("au-4-atm", ("au_4_atm", Native.Controller.SONETACR.Au4Atm)), ("au-4", ("au_4", Native.Controller.SONETACR.Au4)), ("aps", ("aps", Native.Controller.SONETACR.Aps))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('framing', (YLeaf(YType.enumeration, 'framing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONETACR.Framing')])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                ])
                self.name = None
                self.framing = None
                self.shutdown = None

                self.clock = Native.Controller.SONETACR.Clock()
                self.clock.parent = self
                self._children_name_map["clock"] = "clock"

                self.aug = Native.Controller.SONETACR.Aug()
                self.aug.parent = self
                self._children_name_map["aug"] = "aug"

                self.au_4_atm = Native.Controller.SONETACR.Au4Atm()
                self.au_4_atm.parent = self
                self._children_name_map["au_4_atm"] = "au-4-atm"

                self.aps = Native.Controller.SONETACR.Aps()
                self.aps.parent = self
                self._children_name_map["aps"] = "aps"

                self.au_3 = YList(self)
                self.au_4 = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-controller:SONET-ACR" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/controller/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Controller.SONETACR, ['name', 'framing', 'shutdown'], name, value)

            class Framing(Enum):
                """
                Framing (Enum Class)

                SONET framing

                .. data:: sonet = 0

                .. data:: sdh = 1

                """

                sonet = Enum.YLeaf(0, "sonet")

                sdh = Enum.YLeaf(1, "sdh")



            class Clock(Entity):
                """
                SONET clock
                
                .. attribute:: source
                
                	SONET clock source
                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Clock.Source>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONETACR.Clock, self).__init__()

                    self.yang_name = "clock"
                    self.yang_parent_name = "SONET-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('source', (YLeaf(YType.enumeration, 'source'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONETACR.Clock.Source')])),
                    ])
                    self.source = None
                    self._segment_path = lambda: "clock"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONETACR.Clock, ['source'], name, value)

                class Source(Enum):
                    """
                    Source (Enum Class)

                    SONET clock source

                    .. data:: internal = 0

                    .. data:: line = 1

                    """

                    internal = Enum.YLeaf(0, "internal")

                    line = Enum.YLeaf(1, "line")



            class Aug(Entity):
                """
                AUG
                
                .. attribute:: mapping
                
                	
                	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Aug.Mapping>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONETACR.Aug, self).__init__()

                    self.yang_name = "aug"
                    self.yang_parent_name = "SONET-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mapping', (YLeaf(YType.enumeration, 'mapping'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONETACR.Aug.Mapping')])),
                    ])
                    self.mapping = None
                    self._segment_path = lambda: "aug"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONETACR.Aug, ['mapping'], name, value)

                class Mapping(Enum):
                    """
                    Mapping (Enum Class)

                    .. data:: au_3 = 0

                    .. data:: au_4 = 1

                    """

                    au_3 = Enum.YLeaf(0, "au-3")

                    au_4 = Enum.YLeaf(1, "au-4")



            class Au3(Entity):
                """
                AU\-3
                
                .. attribute:: number  (key)
                
                	AU\-3 number
                	**type**\: int
                
                	**range:** 1..3
                
                .. attribute:: overhead
                
                	overhead
                	**type**\:  :py:class:`Overhead <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au3.Overhead>`
                
                .. attribute:: mode
                
                	mode
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au3.Mode>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONETACR.Au3, self).__init__()

                    self.yang_name = "au-3"
                    self.yang_parent_name = "SONET-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("overhead", ("overhead", Native.Controller.SONETACR.Au3.Overhead)), ("mode", ("mode", Native.Controller.SONETACR.Au3.Mode))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                    ])
                    self.number = None

                    self.overhead = Native.Controller.SONETACR.Au3.Overhead()
                    self.overhead.parent = self
                    self._children_name_map["overhead"] = "overhead"

                    self.mode = Native.Controller.SONETACR.Au3.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"
                    self._segment_path = lambda: "au-3" + "[number='" + str(self.number) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONETACR.Au3, ['number'], name, value)


                class Overhead(Entity):
                    """
                    overhead
                    
                    .. attribute:: byte
                    
                    	
                    	**type**\:  :py:class:`Byte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au3.Overhead.Byte>`
                    
                    .. attribute:: length
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Au3.Overhead, self).__init__()

                        self.yang_name = "overhead"
                        self.yang_parent_name = "au-3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('byte', (YLeaf(YType.enumeration, 'byte'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONETACR.Au3.Overhead.Byte')])),
                            ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                        ])
                        self.byte = None
                        self.length = None
                        self._segment_path = lambda: "overhead"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Au3.Overhead, ['byte', 'length'], name, value)

                    class Byte(Enum):
                        """
                        Byte (Enum Class)

                        .. data:: j1 = 0

                        """

                        j1 = Enum.YLeaf(0, "j1")



                class Mode(Entity):
                    """
                    mode
                    
                    .. attribute:: mapping
                    
                    	
                    	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au3.Mode.Mapping>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Au3.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "au-3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mapping', (YLeaf(YType.enumeration, 'mapping'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONETACR.Au3.Mode.Mapping')])),
                        ])
                        self.mapping = None
                        self._segment_path = lambda: "mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Au3.Mode, ['mapping'], name, value)

                    class Mapping(Enum):
                        """
                        Mapping (Enum Class)

                        .. data:: c_11 = 0

                        .. data:: c_12 = 1

                        .. data:: c_2 = 2

                        """

                        c_11 = Enum.YLeaf(0, "c-11")

                        c_12 = Enum.YLeaf(1, "c-12")

                        c_2 = Enum.YLeaf(2, "c-2")



            class Au4Atm(Entity):
                """
                
                
                .. attribute:: au_4
                
                	AU\-4
                	**type**\:  :py:class:`Au4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4Atm.Au4>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONETACR.Au4Atm, self).__init__()

                    self.yang_name = "au-4-atm"
                    self.yang_parent_name = "SONET-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("au-4", ("au_4", Native.Controller.SONETACR.Au4Atm.Au4))])
                    self._leafs = OrderedDict()

                    self.au_4 = Native.Controller.SONETACR.Au4Atm.Au4()
                    self.au_4.parent = self
                    self._children_name_map["au_4"] = "au-4"
                    self._segment_path = lambda: "au-4-atm"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONETACR.Au4Atm, [], name, value)


                class Au4(Entity):
                    """
                    AU\-4
                    
                    .. attribute:: number
                    
                    	AU\-4 number
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Au4Atm.Au4, self).__init__()

                        self.yang_name = "au-4"
                        self.yang_parent_name = "au-4-atm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                            ('atm', (YLeaf(YType.empty, 'atm'), ['Empty'])),
                        ])
                        self.number = None
                        self.atm = None
                        self._segment_path = lambda: "au-4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Au4Atm.Au4, ['number', 'atm'], name, value)


            class Au4(Entity):
                """
                AU\-4
                
                .. attribute:: number  (key)
                
                	AU\-4 number
                	**type**\: int
                
                	**range:** 1..3
                
                .. attribute:: tug_3  (key)
                
                	TUG\-3
                	**type**\: int
                
                	**range:** 1..3
                
                .. attribute:: mode
                
                	mode
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.Mode>`
                
                .. attribute:: cem_group
                
                	CEM group
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: unframed
                
                	Unframed
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: framing
                
                	
                	**type**\:  :py:class:`Framing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.Framing>`
                
                .. attribute:: cem_group_timeslots
                
                	
                	**type**\:  :py:class:`CemGroupTimeslots <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.CemGroupTimeslots>`
                
                .. attribute:: channel_group_timeslots
                
                	
                	**type**\:  :py:class:`ChannelGroupTimeslots <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.ChannelGroupTimeslots>`
                
                .. attribute:: cem_group_unframed
                
                	
                	**type**\:  :py:class:`CemGroupUnframed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.CemGroupUnframed>`
                
                .. attribute:: framing_unframed
                
                	
                	**type**\:  :py:class:`FramingUnframed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.FramingUnframed>`
                
                .. attribute:: cem_group_atm
                
                	
                	**type**\:  :py:class:`CemGroupAtm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.CemGroupAtm>`
                
                .. attribute:: ima_group
                
                	
                	**type**\:  :py:class:`ImaGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.ImaGroup>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONETACR.Au4, self).__init__()

                    self.yang_name = "au-4"
                    self.yang_parent_name = "SONET-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['number','tug_3']
                    self._child_classes = OrderedDict([("cem-group-timeslots", ("cem_group_timeslots", Native.Controller.SONETACR.Au4.CemGroupTimeslots)), ("channel-group-timeslots", ("channel_group_timeslots", Native.Controller.SONETACR.Au4.ChannelGroupTimeslots)), ("cem-group-unframed", ("cem_group_unframed", Native.Controller.SONETACR.Au4.CemGroupUnframed)), ("framing-unframed", ("framing_unframed", Native.Controller.SONETACR.Au4.FramingUnframed)), ("cem-group-atm", ("cem_group_atm", Native.Controller.SONETACR.Au4.CemGroupAtm)), ("ima-group", ("ima_group", Native.Controller.SONETACR.Au4.ImaGroup))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                        ('tug_3', (YLeaf(YType.int8, 'tug-3'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONETACR.Au4.Mode')])),
                        ('cem_group', (YLeaf(YType.int32, 'cem-group'), ['int'])),
                        ('unframed', (YLeaf(YType.empty, 'unframed'), ['Empty'])),
                        ('framing', (YLeaf(YType.enumeration, 'framing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONETACR.Au4.Framing')])),
                    ])
                    self.number = None
                    self.tug_3 = None
                    self.mode = None
                    self.cem_group = None
                    self.unframed = None
                    self.framing = None

                    self.cem_group_timeslots = Native.Controller.SONETACR.Au4.CemGroupTimeslots()
                    self.cem_group_timeslots.parent = self
                    self._children_name_map["cem_group_timeslots"] = "cem-group-timeslots"

                    self.channel_group_timeslots = Native.Controller.SONETACR.Au4.ChannelGroupTimeslots()
                    self.channel_group_timeslots.parent = self
                    self._children_name_map["channel_group_timeslots"] = "channel-group-timeslots"

                    self.cem_group_unframed = Native.Controller.SONETACR.Au4.CemGroupUnframed()
                    self.cem_group_unframed.parent = self
                    self._children_name_map["cem_group_unframed"] = "cem-group-unframed"

                    self.framing_unframed = Native.Controller.SONETACR.Au4.FramingUnframed()
                    self.framing_unframed.parent = self
                    self._children_name_map["framing_unframed"] = "framing-unframed"

                    self.cem_group_atm = Native.Controller.SONETACR.Au4.CemGroupAtm()
                    self.cem_group_atm.parent = self
                    self._children_name_map["cem_group_atm"] = "cem-group-atm"

                    self.ima_group = Native.Controller.SONETACR.Au4.ImaGroup()
                    self.ima_group.parent = self
                    self._children_name_map["ima_group"] = "ima-group"
                    self._segment_path = lambda: "au-4" + "[number='" + str(self.number) + "']" + "[tug-3='" + str(self.tug_3) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONETACR.Au4, ['number', 'tug_3', 'mode', 'cem_group', 'unframed', 'framing'], name, value)

                class Framing(Enum):
                    """
                    Framing (Enum Class)

                    .. data:: unframed = 0

                    """

                    unframed = Enum.YLeaf(0, "unframed")


                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    mode

                    .. data:: c_11 = 0

                    .. data:: c_12 = 1

                    .. data:: c_2 = 2

                    .. data:: c_3 = 3

                    .. data:: c_4 = 4

                    .. data:: e3 = 5

                    """

                    c_11 = Enum.YLeaf(0, "c-11")

                    c_12 = Enum.YLeaf(1, "c-12")

                    c_2 = Enum.YLeaf(2, "c-2")

                    c_3 = Enum.YLeaf(3, "c-3")

                    c_4 = Enum.YLeaf(4, "c-4")

                    e3 = Enum.YLeaf(5, "e3")



                class CemGroupTimeslots(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.CemGroupTimeslots.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Au4.CemGroupTimeslots, self).__init__()

                        self.yang_name = "cem-group-timeslots"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONETACR.Au4.CemGroupTimeslots.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "cem-group-timeslots"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Au4.CemGroupTimeslots, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: cem_group  (key)
                        
                        	CEM group
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: timeslots
                        
                        	Time slots
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONETACR.Au4.CemGroupTimeslots.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "cem-group-timeslots"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1','cem_group']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('cem_group', (YLeaf(YType.int32, 'cem-group'), ['int'])),
                                ('timeslots', (YLeaf(YType.str, 'timeslots'), ['str'])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.cem_group = None
                            self.timeslots = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']" + "[cem-group='" + str(self.cem_group) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONETACR.Au4.CemGroupTimeslots.Tug2, ['number', 'e1', 'cem_group', 'timeslots'], name, value)


                class ChannelGroupTimeslots(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.ChannelGroupTimeslots.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Au4.ChannelGroupTimeslots, self).__init__()

                        self.yang_name = "channel-group-timeslots"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONETACR.Au4.ChannelGroupTimeslots.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "channel-group-timeslots"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Au4.ChannelGroupTimeslots, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: channel_group  (key)
                        
                        	Channel group
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: timeslots
                        
                        	Time slots
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONETACR.Au4.ChannelGroupTimeslots.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "channel-group-timeslots"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1','channel_group']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('channel_group', (YLeaf(YType.int32, 'channel-group'), ['int'])),
                                ('timeslots', (YLeaf(YType.str, 'timeslots'), ['str'])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.channel_group = None
                            self.timeslots = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']" + "[channel-group='" + str(self.channel_group) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONETACR.Au4.ChannelGroupTimeslots.Tug2, ['number', 'e1', 'channel_group', 'timeslots'], name, value)


                class CemGroupUnframed(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.CemGroupUnframed.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Au4.CemGroupUnframed, self).__init__()

                        self.yang_name = "cem-group-unframed"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONETACR.Au4.CemGroupUnframed.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "cem-group-unframed"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Au4.CemGroupUnframed, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: cem_group  (key)
                        
                        	CEM group
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: unframed
                        
                        	Unframed
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONETACR.Au4.CemGroupUnframed.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "cem-group-unframed"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1','cem_group']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('cem_group', (YLeaf(YType.int32, 'cem-group'), ['int'])),
                                ('unframed', (YLeaf(YType.empty, 'unframed'), ['Empty'])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.cem_group = None
                            self.unframed = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']" + "[cem-group='" + str(self.cem_group) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONETACR.Au4.CemGroupUnframed.Tug2, ['number', 'e1', 'cem_group', 'unframed'], name, value)


                class FramingUnframed(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.FramingUnframed.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Au4.FramingUnframed, self).__init__()

                        self.yang_name = "framing-unframed"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONETACR.Au4.FramingUnframed.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "framing-unframed"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Au4.FramingUnframed, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: framing
                        
                        	
                        	**type**\:  :py:class:`Framing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.FramingUnframed.Tug2.Framing>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONETACR.Au4.FramingUnframed.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "framing-unframed"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('framing', (YLeaf(YType.enumeration, 'framing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.SONETACR.Au4.FramingUnframed.Tug2.Framing')])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.framing = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONETACR.Au4.FramingUnframed.Tug2, ['number', 'e1', 'framing'], name, value)

                        class Framing(Enum):
                            """
                            Framing (Enum Class)

                            .. data:: unframed = 0

                            """

                            unframed = Enum.YLeaf(0, "unframed")



                class CemGroupAtm(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.CemGroupAtm.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Au4.CemGroupAtm, self).__init__()

                        self.yang_name = "cem-group-atm"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONETACR.Au4.CemGroupAtm.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "cem-group-atm"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Au4.CemGroupAtm, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONETACR.Au4.CemGroupAtm.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "cem-group-atm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('atm', (YLeaf(YType.empty, 'atm'), ['Empty'])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.atm = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONETACR.Au4.CemGroupAtm.Tug2, ['number', 'e1', 'atm'], name, value)


                class ImaGroup(Entity):
                    """
                    
                    
                    .. attribute:: tug_2
                    
                    	TUG\-2
                    	**type**\: list of  		 :py:class:`Tug2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Au4.ImaGroup.Tug2>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Au4.ImaGroup, self).__init__()

                        self.yang_name = "ima-group"
                        self.yang_parent_name = "au-4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tug-2", ("tug_2", Native.Controller.SONETACR.Au4.ImaGroup.Tug2))])
                        self._leafs = OrderedDict()

                        self.tug_2 = YList(self)
                        self._segment_path = lambda: "ima-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Au4.ImaGroup, [], name, value)


                    class Tug2(Entity):
                        """
                        TUG\-2
                        
                        .. attribute:: number  (key)
                        
                        	TUG\-2 number
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: e1  (key)
                        
                        	E1
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: ima_group  (key)
                        
                        	IMA group
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.SONETACR.Au4.ImaGroup.Tug2, self).__init__()

                            self.yang_name = "tug-2"
                            self.yang_parent_name = "ima-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number','e1','ima_group']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                                ('e1', (YLeaf(YType.int8, 'e1'), ['int'])),
                                ('ima_group', (YLeaf(YType.int32, 'ima-group'), ['int'])),
                            ])
                            self.number = None
                            self.e1 = None
                            self.ima_group = None
                            self._segment_path = lambda: "tug-2" + "[number='" + str(self.number) + "']" + "[e1='" + str(self.e1) + "']" + "[ima-group='" + str(self.ima_group) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.SONETACR.Au4.ImaGroup.Tug2, ['number', 'e1', 'ima_group'], name, value)


            class Aps(Entity):
                """
                SONET APS
                
                .. attribute:: group
                
                	SONET APS group
                	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Aps.Group>`
                
                .. attribute:: working
                
                	Working line
                	**type**\: int
                
                	**range:** \-128..127
                
                .. attribute:: protect
                
                	Protect line
                	**type**\:  :py:class:`Protect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Aps.Protect>`
                
                .. attribute:: hspw_icrm_grp
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: interchassis
                
                	
                	**type**\:  :py:class:`Interchassis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.SONETACR.Aps.Interchassis>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.SONETACR.Aps, self).__init__()

                    self.yang_name = "aps"
                    self.yang_parent_name = "SONET-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("group", ("group", Native.Controller.SONETACR.Aps.Group)), ("protect", ("protect", Native.Controller.SONETACR.Aps.Protect)), ("interchassis", ("interchassis", Native.Controller.SONETACR.Aps.Interchassis))])
                    self._leafs = OrderedDict([
                        ('working', (YLeaf(YType.int8, 'working'), ['int'])),
                        ('hspw_icrm_grp', (YLeaf(YType.uint8, 'hspw-icrm-grp'), ['int'])),
                    ])
                    self.working = None
                    self.hspw_icrm_grp = None

                    self.group = Native.Controller.SONETACR.Aps.Group()
                    self.group.parent = self
                    self._children_name_map["group"] = "group"

                    self.protect = Native.Controller.SONETACR.Aps.Protect()
                    self.protect.parent = self
                    self._children_name_map["protect"] = "protect"

                    self.interchassis = Native.Controller.SONETACR.Aps.Interchassis()
                    self.interchassis.parent = self
                    self._children_name_map["interchassis"] = "interchassis"
                    self._segment_path = lambda: "aps"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.SONETACR.Aps, ['working', 'hspw_icrm_grp'], name, value)


                class Group(Entity):
                    """
                    SONET APS group
                    
                    .. attribute:: group_number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: acr
                    
                    	ACR
                    	**type**\: int
                    
                    	**range:** \-128..127
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Aps.Group, self).__init__()

                        self.yang_name = "group"
                        self.yang_parent_name = "aps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint8, 'group-number'), ['int'])),
                            ('acr', (YLeaf(YType.int8, 'acr'), ['int'])),
                        ])
                        self.group_number = None
                        self.acr = None
                        self._segment_path = lambda: "group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Aps.Group, ['group_number', 'acr'], name, value)


                class Protect(Entity):
                    """
                    Protect line
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** \-128..127
                    
                    .. attribute:: ip_addr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Aps.Protect, self).__init__()

                        self.yang_name = "protect"
                        self.yang_parent_name = "aps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.int8, 'number'), ['int'])),
                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str'])),
                        ])
                        self.number = None
                        self.ip_addr = None
                        self._segment_path = lambda: "protect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Aps.Protect, ['number', 'ip_addr'], name, value)


                class Interchassis(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.SONETACR.Aps.Interchassis, self).__init__()

                        self.yang_name = "interchassis"
                        self.yang_parent_name = "aps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "interchassis"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.SONETACR.Aps.Interchassis, ['group'], name, value)


        class Wanphy(Entity):
            """
            wanphy
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios-ctrl'
            _revision = '2018-04-02'

            def __init__(self):
                super(Native.Controller.Wanphy, self).__init__()

                self.yang_name = "wanphy"
                self.yang_parent_name = "controller"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None
                self._segment_path = lambda: "Cisco-IOS-XE-controller:wanphy" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/controller/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Controller.Wanphy, ['name'], name, value)


        class Vdsl(Entity):
            """
            VDSL2 controller
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: shutdown
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: sra
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: bitswap
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: diagnostics
            
            	
            	**type**\:  :py:class:`Diagnostics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Diagnostics>`
            
            .. attribute:: description
            
            	
            	**type**\: str
            
            	**length:** 1..240
            
            .. attribute:: line_mode
            
            	
            	**type**\:  :py:class:`LineMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.LineMode>`
            
            .. attribute:: operating
            
            	
            	**type**\:  :py:class:`Operating <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Operating>`
            
            .. attribute:: training
            
            	
            	**type**\:  :py:class:`Training <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Training>`
            
            .. attribute:: sync
            
            	
            	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Sync>`
            
            .. attribute:: modem
            
            	
            	**type**\: str
            
            	**length:** 1..48
            
            

            """

            _prefix = 'ios-ctrl'
            _revision = '2018-04-02'

            def __init__(self):
                super(Native.Controller.Vdsl, self).__init__()

                self.yang_name = "vdsl"
                self.yang_parent_name = "controller"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("line-mode", ("line_mode", Native.Controller.Vdsl.LineMode)), ("operating", ("operating", Native.Controller.Vdsl.Operating)), ("training", ("training", Native.Controller.Vdsl.Training)), ("sync", ("sync", Native.Controller.Vdsl.Sync))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('sra', (YLeaf(YType.empty, 'sra'), ['Empty'])),
                    ('bitswap', (YLeaf(YType.empty, 'bitswap'), ['Empty'])),
                    ('diagnostics', (YLeaf(YType.enumeration, 'diagnostics'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Vdsl.Diagnostics')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('modem', (YLeaf(YType.str, 'modem'), ['str'])),
                ])
                self.name = None
                self.shutdown = None
                self.sra = None
                self.bitswap = None
                self.diagnostics = None
                self.description = None
                self.modem = None

                self.line_mode = Native.Controller.Vdsl.LineMode()
                self.line_mode.parent = self
                self._children_name_map["line_mode"] = "line-mode"

                self.operating = Native.Controller.Vdsl.Operating()
                self.operating.parent = self
                self._children_name_map["operating"] = "operating"

                self.training = Native.Controller.Vdsl.Training()
                self.training.parent = self
                self._children_name_map["training"] = "training"

                self.sync = Native.Controller.Vdsl.Sync()
                self.sync.parent = self
                self._children_name_map["sync"] = "sync"
                self._segment_path = lambda: "Cisco-IOS-XE-controller:vdsl" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/controller/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Controller.Vdsl, ['name', 'shutdown', 'sra', 'bitswap', 'diagnostics', 'description', 'modem'], name, value)

            class Diagnostics(Enum):
                """
                Diagnostics (Enum Class)

                .. data:: DELT = 0

                """

                DELT = Enum.YLeaf(0, "DELT")



            class LineMode(Entity):
                """
                
                
                .. attribute:: bonding
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: single_wire
                
                	
                	**type**\:  :py:class:`SingleWire <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.LineMode.SingleWire>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.Vdsl.LineMode, self).__init__()

                    self.yang_name = "line-mode"
                    self.yang_parent_name = "vdsl"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("single-wire", ("single_wire", Native.Controller.Vdsl.LineMode.SingleWire))])
                    self._leafs = OrderedDict([
                        ('bonding', (YLeaf(YType.empty, 'bonding'), ['Empty'])),
                    ])
                    self.bonding = None

                    self.single_wire = Native.Controller.Vdsl.LineMode.SingleWire()
                    self.single_wire.parent = self
                    self._children_name_map["single_wire"] = "single-wire"
                    self._segment_path = lambda: "line-mode"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.Vdsl.LineMode, ['bonding'], name, value)


                class SingleWire(Entity):
                    """
                    
                    
                    .. attribute:: line
                    
                    	
                    	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.LineMode.SingleWire.Line>`
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Vdsl.LineMode.SingleWire, self).__init__()

                        self.yang_name = "single-wire"
                        self.yang_parent_name = "line-mode"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("line", ("line", Native.Controller.Vdsl.LineMode.SingleWire.Line))])
                        self._leafs = OrderedDict()

                        self.line = Native.Controller.Vdsl.LineMode.SingleWire.Line()
                        self.line.parent = self
                        self._children_name_map["line"] = "line"
                        self._segment_path = lambda: "single-wire"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Vdsl.LineMode.SingleWire, [], name, value)


                    class Line(Entity):
                        """
                        
                        
                        .. attribute:: zero
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: one
                        
                        	
                        	**type**\:  :py:class:`One <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.LineMode.SingleWire.Line.One>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Vdsl.LineMode.SingleWire.Line, self).__init__()

                            self.yang_name = "line"
                            self.yang_parent_name = "single-wire"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("one", ("one", Native.Controller.Vdsl.LineMode.SingleWire.Line.One))])
                            self._leafs = OrderedDict([
                                ('zero', (YLeaf(YType.empty, 'zero'), ['Empty'])),
                            ])
                            self.zero = None

                            self.one = None
                            self._children_name_map["one"] = "one"
                            self._segment_path = lambda: "line"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Vdsl.LineMode.SingleWire.Line, ['zero'], name, value)


                        class One(Entity):
                            """
                            
                            
                            .. attribute:: profile
                            
                            	
                            	**type**\:  :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.LineMode.SingleWire.Line.One.Profile>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ctrl'
                            _revision = '2018-04-02'

                            def __init__(self):
                                super(Native.Controller.Vdsl.LineMode.SingleWire.Line.One, self).__init__()

                                self.yang_name = "one"
                                self.yang_parent_name = "line"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('profile', (YLeaf(YType.enumeration, 'profile'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Vdsl.LineMode.SingleWire.Line.One.Profile')])),
                                ])
                                self.profile = None
                                self._segment_path = lambda: "one"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Controller.Vdsl.LineMode.SingleWire.Line.One, ['profile'], name, value)

                            class Profile(Enum):
                                """
                                Profile (Enum Class)

                                .. data:: Y_30a = 0

                                """

                                Y_30a = Enum.YLeaf(0, "30a")



            class Operating(Entity):
                """
                
                
                .. attribute:: mode
                
                	
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Operating.Mode>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.Vdsl.Operating, self).__init__()

                    self.yang_name = "operating"
                    self.yang_parent_name = "vdsl"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Controller.Vdsl.Operating.Mode))])
                    self._leafs = OrderedDict()

                    self.mode = Native.Controller.Vdsl.Operating.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"
                    self._segment_path = lambda: "operating"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.Vdsl.Operating, [], name, value)


                class Mode(Entity):
                    """
                    
                    
                    .. attribute:: adsl1
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: adsl2
                    
                    	
                    	**type**\:  :py:class:`Adsl2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Operating.Mode.Adsl2>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: auto
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vdsl2
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ansi
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: adsl2plus
                    
                    	
                    	**type**\:  :py:class:`Adsl2plus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Operating.Mode.Adsl2plus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Vdsl.Operating.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "operating"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("adsl2", ("adsl2", Native.Controller.Vdsl.Operating.Mode.Adsl2)), ("adsl2plus", ("adsl2plus", Native.Controller.Vdsl.Operating.Mode.Adsl2plus))])
                        self._leafs = OrderedDict([
                            ('adsl1', (YLeaf(YType.empty, 'adsl1'), ['Empty'])),
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                            ('vdsl2', (YLeaf(YType.empty, 'vdsl2'), ['Empty'])),
                            ('ansi', (YLeaf(YType.empty, 'ansi'), ['Empty'])),
                        ])
                        self.adsl1 = None
                        self.auto = None
                        self.vdsl2 = None
                        self.ansi = None

                        self.adsl2 = None
                        self._children_name_map["adsl2"] = "adsl2"

                        self.adsl2plus = None
                        self._children_name_map["adsl2plus"] = "adsl2plus"
                        self._segment_path = lambda: "mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Vdsl.Operating.Mode, ['adsl1', 'auto', 'vdsl2', 'ansi'], name, value)


                    class Adsl2(Entity):
                        """
                        
                        
                        .. attribute:: annex
                        
                        	
                        	**type**\:  :py:class:`Annex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Operating.Mode.Adsl2.Annex>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Vdsl.Operating.Mode.Adsl2, self).__init__()

                            self.yang_name = "adsl2"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('annex', (YLeaf(YType.enumeration, 'annex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Vdsl.Operating.Mode.Adsl2.Annex')])),
                            ])
                            self.annex = None
                            self._segment_path = lambda: "adsl2"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Vdsl.Operating.Mode.Adsl2, ['annex'], name, value)

                        class Annex(Enum):
                            """
                            Annex (Enum Class)

                            .. data:: A = 0

                            .. data:: M = 1

                            """

                            A = Enum.YLeaf(0, "A")

                            M = Enum.YLeaf(1, "M")



                    class Adsl2plus(Entity):
                        """
                        
                        
                        .. attribute:: annex
                        
                        	
                        	**type**\:  :py:class:`Annex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Operating.Mode.Adsl2plus.Annex>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Vdsl.Operating.Mode.Adsl2plus, self).__init__()

                            self.yang_name = "adsl2plus"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('annex', (YLeaf(YType.enumeration, 'annex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Controller.Vdsl.Operating.Mode.Adsl2plus.Annex')])),
                            ])
                            self.annex = None
                            self._segment_path = lambda: "adsl2plus"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Vdsl.Operating.Mode.Adsl2plus, ['annex'], name, value)

                        class Annex(Enum):
                            """
                            Annex (Enum Class)

                            .. data:: A = 0

                            .. data:: M = 1

                            """

                            A = Enum.YLeaf(0, "A")

                            M = Enum.YLeaf(1, "M")



            class Training(Entity):
                """
                
                
                .. attribute:: log
                
                	
                	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Training.Log>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.Vdsl.Training, self).__init__()

                    self.yang_name = "training"
                    self.yang_parent_name = "vdsl"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("log", ("log", Native.Controller.Vdsl.Training.Log))])
                    self._leafs = OrderedDict()

                    self.log = Native.Controller.Vdsl.Training.Log()
                    self.log.parent = self
                    self._children_name_map["log"] = "log"
                    self._segment_path = lambda: "training"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.Vdsl.Training, [], name, value)


                class Log(Entity):
                    """
                    
                    
                    .. attribute:: filename
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Vdsl.Training.Log, self).__init__()

                        self.yang_name = "log"
                        self.yang_parent_name = "training"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('filename', (YLeaf(YType.str, 'filename'), ['str'])),
                        ])
                        self.filename = None
                        self._segment_path = lambda: "log"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Vdsl.Training.Log, ['filename'], name, value)


            class Sync(Entity):
                """
                
                
                .. attribute:: interval
                
                	
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Sync.Interval>`
                
                .. attribute:: mode
                
                	
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Sync.Mode>`
                
                

                """

                _prefix = 'ios-ctrl'
                _revision = '2018-04-02'

                def __init__(self):
                    super(Native.Controller.Vdsl.Sync, self).__init__()

                    self.yang_name = "sync"
                    self.yang_parent_name = "vdsl"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interval", ("interval", Native.Controller.Vdsl.Sync.Interval)), ("mode", ("mode", Native.Controller.Vdsl.Sync.Mode))])
                    self._leafs = OrderedDict()

                    self.interval = Native.Controller.Vdsl.Sync.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "interval"

                    self.mode = Native.Controller.Vdsl.Sync.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"
                    self._segment_path = lambda: "sync"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Controller.Vdsl.Sync, [], name, value)


                class Interval(Entity):
                    """
                    
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Vdsl.Sync.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "sync"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                        ])
                        self.seconds = None
                        self._segment_path = lambda: "interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Vdsl.Sync.Interval, ['seconds'], name, value)


                class Mode(Entity):
                    """
                    
                    
                    .. attribute:: itu
                    
                    	
                    	**type**\:  :py:class:`Itu <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Sync.Mode.Itu>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: none
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ansi
                    
                    	
                    	**type**\:  :py:class:`Ansi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Controller.Vdsl.Sync.Mode.Ansi>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ctrl'
                    _revision = '2018-04-02'

                    def __init__(self):
                        super(Native.Controller.Vdsl.Sync.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "sync"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("itu", ("itu", Native.Controller.Vdsl.Sync.Mode.Itu)), ("ansi", ("ansi", Native.Controller.Vdsl.Sync.Mode.Ansi))])
                        self._leafs = OrderedDict([
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ])
                        self.none = None

                        self.itu = None
                        self._children_name_map["itu"] = "itu"

                        self.ansi = None
                        self._children_name_map["ansi"] = "ansi"
                        self._segment_path = lambda: "mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Controller.Vdsl.Sync.Mode, ['none'], name, value)


                    class Itu(Entity):
                        """
                        
                        
                        .. attribute:: previous
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Vdsl.Sync.Mode.Itu, self).__init__()

                            self.yang_name = "itu"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('previous', (YLeaf(YType.empty, 'previous'), ['Empty'])),
                            ])
                            self.previous = None
                            self._segment_path = lambda: "itu"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Vdsl.Sync.Mode.Itu, ['previous'], name, value)


                    class Ansi(Entity):
                        """
                        
                        
                        .. attribute:: previous
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ctrl'
                        _revision = '2018-04-02'

                        def __init__(self):
                            super(Native.Controller.Vdsl.Sync.Mode.Ansi, self).__init__()

                            self.yang_name = "ansi"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('previous', (YLeaf(YType.empty, 'previous'), ['Empty'])),
                            ])
                            self.previous = None
                            self._segment_path = lambda: "ansi"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Controller.Vdsl.Sync.Mode.Ansi, ['previous'], name, value)


    class Vrf(Entity):
        """
        VRF commands
        
        .. attribute:: definition
        
        	VRF definition mode
        	**type**\: list of  		 :py:class:`Definition <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Vrf, self).__init__()

            self.yang_name = "vrf"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("definition", ("definition", Native.Vrf.Definition))])
            self._leafs = OrderedDict()

            self.definition = YList(self)
            self._segment_path = lambda: "vrf"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Vrf, [], name, value)


        class Definition(Entity):
            """
            VRF definition mode
            
            .. attribute:: name  (key)
            
            	WORD;;VRF name
            	**type**\: str
            
            .. attribute:: description
            
            	VRF specific description
            	**type**\: str
            
            	**length:** 1..244
            
            .. attribute:: rd
            
            	Specify Route Distinguisher
            	**type**\: union of the below types:
            
            		**type**\: str
            
            			**pattern:** [0\-9]+\:[0\-9]+
            
            		**type**\: str
            
            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            		**type**\: str
            
            			**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
            
            .. attribute:: address_family
            
            	Enter Address Family command mode
            	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily>`
            
            .. attribute:: route_target
            
            	Specify Target VPN Extended Communities
            	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.RouteTarget>`
            
            .. attribute:: vpn
            
            	Configure VPN ID as specified in rfc2685
            	**type**\:  :py:class:`Vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.Vpn>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Vrf.Definition, self).__init__()

                self.yang_name = "definition"
                self.yang_parent_name = "vrf"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("address-family", ("address_family", Native.Vrf.Definition.AddressFamily)), ("route-target", ("route_target", Native.Vrf.Definition.RouteTarget)), ("vpn", ("vpn", Native.Vrf.Definition.Vpn))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('rd', (YLeaf(YType.str, 'rd'), ['str','str','str'])),
                ])
                self.name = None
                self.description = None
                self.rd = None

                self.address_family = Native.Vrf.Definition.AddressFamily()
                self.address_family.parent = self
                self._children_name_map["address_family"] = "address-family"

                self.route_target = Native.Vrf.Definition.RouteTarget()
                self.route_target.parent = self
                self._children_name_map["route_target"] = "route-target"

                self.vpn = Native.Vrf.Definition.Vpn()
                self.vpn.parent = self
                self._children_name_map["vpn"] = "vpn"
                self._segment_path = lambda: "definition" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vrf/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vrf.Definition, [u'name', u'description', u'rd'], name, value)


            class AddressFamily(Entity):
                """
                Enter Address Family command mode
                
                .. attribute:: ipv4
                
                	Address family
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4>`
                
                	**presence node**\: True
                
                .. attribute:: ipv6
                
                	Address family
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv6>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Vrf.Definition.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "definition"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Vrf.Definition.AddressFamily.Ipv4)), ("ipv6", ("ipv6", Native.Vrf.Definition.AddressFamily.Ipv6))])
                    self._leafs = OrderedDict()

                    self.ipv4 = None
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = None
                    self._children_name_map["ipv6"] = "ipv6"
                    self._segment_path = lambda: "address-family"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vrf.Definition.AddressFamily, [], name, value)


                class Ipv4(Entity):
                    """
                    Address family
                    
                    .. attribute:: export
                    
                    	VRF export
                    	**type**\:  :py:class:`Export <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Export>`
                    
                    .. attribute:: maximum
                    
                    	Maximum number of routes allowed in this routing table
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Maximum>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: mdt
                    
                    	Backbone Multicast Distribution Tree
                    	**type**\:  :py:class:`Mdt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Mdt>`
                    
                    .. attribute:: route_target
                    
                    	Specify Target VPN Extended Communities
                    	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget>`
                    
                    .. attribute:: bgp
                    
                    	Commands pertaining to BGP
                    	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Bgp>`
                    
                    .. attribute:: import_
                    
                    	VRF import
                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Import>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Vrf.Definition.AddressFamily.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("export", ("export", Native.Vrf.Definition.AddressFamily.Ipv4.Export)), ("maximum", ("maximum", Native.Vrf.Definition.AddressFamily.Ipv4.Maximum)), ("mdt", ("mdt", Native.Vrf.Definition.AddressFamily.Ipv4.Mdt)), ("route-target", ("route_target", Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget)), ("bgp", ("bgp", Native.Vrf.Definition.AddressFamily.Ipv4.Bgp)), ("import", ("import_", Native.Vrf.Definition.AddressFamily.Ipv4.Import))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.export = Native.Vrf.Definition.AddressFamily.Ipv4.Export()
                        self.export.parent = self
                        self._children_name_map["export"] = "export"

                        self.maximum = None
                        self._children_name_map["maximum"] = "maximum"

                        self.mdt = Native.Vrf.Definition.AddressFamily.Ipv4.Mdt()
                        self.mdt.parent = self
                        self._children_name_map["mdt"] = "mdt"

                        self.route_target = Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget()
                        self.route_target.parent = self
                        self._children_name_map["route_target"] = "route-target"

                        self.bgp = Native.Vrf.Definition.AddressFamily.Ipv4.Bgp()
                        self.bgp.parent = self
                        self._children_name_map["bgp"] = "bgp"

                        self.import_ = Native.Vrf.Definition.AddressFamily.Ipv4.Import()
                        self.import_.parent = self
                        self._children_name_map["import_"] = "import"
                        self._segment_path = lambda: "ipv4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4, [], name, value)


                    class Export(Entity):
                        """
                        VRF export
                        
                        .. attribute:: map
                        
                        	WORD;;Route\-map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Vrf.Definition.AddressFamily.Ipv4.Export, self).__init__()

                            self.yang_name = "export"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('map', (YLeaf(YType.str, 'map'), ['str'])),
                            ])
                            self.map = None
                            self._segment_path = lambda: "export"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Export, [u'map'], name, value)


                    class Maximum(Entity):
                        """
                        Maximum number of routes allowed in this routing table
                        
                        .. attribute:: routes
                        
                        	Maximum number of routes allowed in this routing table
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: threshold
                        
                        	Threshold
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: reinstall
                        
                        	Reinstall previous rejected route due to over maximum route limit
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: warning_only
                        
                        	Only give a warning message if is limit exceeded
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Vrf.Definition.AddressFamily.Ipv4.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('routes', (YLeaf(YType.uint32, 'routes'), ['int'])),
                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                ('reinstall', (YLeaf(YType.uint16, 'reinstall'), ['int'])),
                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                            ])
                            self.routes = None
                            self.threshold = None
                            self.reinstall = None
                            self.warning_only = None
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Maximum, [u'routes', u'threshold', u'reinstall', u'warning_only'], name, value)


                    class Mdt(Entity):
                        """
                        Backbone Multicast Distribution Tree
                        
                        .. attribute:: default
                        
                        	The default group
                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Default>`
                        
                        .. attribute:: auto_discovery
                        
                        	BGP auto\-discovery for MVPN
                        	**type**\:  :py:class:`AutoDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.AutoDiscovery>`
                        
                        .. attribute:: data
                        
                        	MDT data trees
                        	**type**\:  :py:class:`Data <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Data>`
                        
                        .. attribute:: log_reuse
                        
                        	Event logging for data MDT reuse
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mtu
                        
                        	The MTU
                        	**type**\: int
                        
                        	**range:** 576..18010
                        
                        .. attribute:: overlay
                        
                        	MDT Overlay Protocol
                        	**type**\:  :py:class:`Overlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Overlay>`
                        
                        .. attribute:: preference
                        
                        	MDT preference (default pim mldp)
                        	**type**\: list of   :py:class:`Preference <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Preference>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt, self).__init__()

                            self.yang_name = "mdt"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("default", ("default", Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Default)), ("auto-discovery", ("auto_discovery", Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.AutoDiscovery)), ("data", ("data", Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Data)), ("overlay", ("overlay", Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Overlay))])
                            self._leafs = OrderedDict([
                                ('log_reuse', (YLeaf(YType.empty, 'log-reuse'), ['Empty'])),
                                ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                                ('preference', (YLeafList(YType.enumeration, 'preference'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Vrf.Definition.AddressFamily.Ipv4.Mdt.Preference')])),
                            ])
                            self.log_reuse = None
                            self.mtu = None
                            self.preference = []

                            self.default = Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Default()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"

                            self.auto_discovery = Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.AutoDiscovery()
                            self.auto_discovery.parent = self
                            self._children_name_map["auto_discovery"] = "auto-discovery"

                            self.data = Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Data()
                            self.data.parent = self
                            self._children_name_map["data"] = "data"

                            self.overlay = Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Overlay()
                            self.overlay.parent = self
                            self._children_name_map["overlay"] = "overlay"
                            self._segment_path = lambda: "mdt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt, [u'log_reuse', u'mtu', u'preference'], name, value)

                        class Preference(Enum):
                            """
                            Preference (Enum Class)

                            MDT preference (default pim mldp)

                            .. data:: mldp = 0

                            .. data:: pim = 1

                            """

                            mldp = Enum.YLeaf(0, "mldp")

                            pim = Enum.YLeaf(1, "pim")



                        class Default(Entity):
                            """
                            The default group
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mpls
                            
                            	MPLS tunnel options
                            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Default.Mpls>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Default, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "mdt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mpls", ("mpls", Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Default.Mpls))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ])
                                self.address = None

                                self.mpls = Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Default.Mpls()
                                self.mpls.parent = self
                                self._children_name_map["mpls"] = "mpls"
                                self._segment_path = lambda: "default"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Default, [u'address'], name, value)


                            class Mpls(Entity):
                                """
                                MPLS tunnel options
                                
                                .. attribute:: mldp
                                
                                	Use a MLDP LSP to create the default MDT
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Default.Mpls, self).__init__()

                                    self.yang_name = "mpls"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mldp', (YLeaf(YType.str, 'mldp'), ['str'])),
                                    ])
                                    self.mldp = None
                                    self._segment_path = lambda: "mpls"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Default.Mpls, [u'mldp'], name, value)


                        class AutoDiscovery(Entity):
                            """
                            BGP auto\-discovery for MVPN
                            
                            .. attribute:: pim
                            
                            	BGP auto\-discovery for PIM
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.AutoDiscovery, self).__init__()

                                self.yang_name = "auto-discovery"
                                self.yang_parent_name = "mdt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pim', (YLeaf(YType.empty, 'pim'), ['Empty'])),
                                ])
                                self.pim = None
                                self._segment_path = lambda: "auto-discovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.AutoDiscovery, [u'pim'], name, value)


                        class Data(Entity):
                            """
                            MDT data trees
                            
                            .. attribute:: multicast
                            
                            	
                            	**type**\: list of  		 :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Data.Multicast>`
                            
                            .. attribute:: list
                            
                            	Access\-list
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 100..199
                            
                            		**type**\: int
                            
                            			**range:** 2000..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: threshold
                            
                            	MDT switching threshold
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Data, self).__init__()

                                self.yang_name = "data"
                                self.yang_parent_name = "mdt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("multicast", ("multicast", Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Data.Multicast))])
                                self._leafs = OrderedDict([
                                    ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.list = None
                                self.threshold = None

                                self.multicast = YList(self)
                                self._segment_path = lambda: "data"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Data, [u'list', u'threshold'], name, value)


                            class Multicast(Entity):
                                """
                                
                                
                                .. attribute:: address  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: wildcard  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Data.Multicast, self).__init__()

                                    self.yang_name = "multicast"
                                    self.yang_parent_name = "data"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['address','wildcard']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                        ('wildcard', (YLeaf(YType.str, 'wildcard'), ['str'])),
                                    ])
                                    self.address = None
                                    self.wildcard = None
                                    self._segment_path = lambda: "multicast" + "[address='" + str(self.address) + "']" + "[wildcard='" + str(self.wildcard) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Data.Multicast, [u'address', u'wildcard'], name, value)


                        class Overlay(Entity):
                            """
                            MDT Overlay Protocol
                            
                            .. attribute:: use_bgp
                            
                            	Use BGP for Overlay Signaling
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Overlay, self).__init__()

                                self.yang_name = "overlay"
                                self.yang_parent_name = "mdt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('use_bgp', (YLeaf(YType.empty, 'use-bgp'), ['Empty'])),
                                ])
                                self.use_bgp = None
                                self._segment_path = lambda: "overlay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Mdt.Overlay, [u'use_bgp'], name, value)


                    class RouteTarget(Entity):
                        """
                        Specify Target VPN Extended Communities
                        
                        .. attribute:: export
                        
                        	Export Target\-VPN community
                        	**type**\: list of  		 :py:class:`Export <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget.Export>`
                        
                        .. attribute:: import_
                        
                        	Import Target\-VPN community
                        	**type**\: list of  		 :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget.Import>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget, self).__init__()

                            self.yang_name = "route-target"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("export", ("export", Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget.Export)), ("import", ("import_", Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget.Import))])
                            self._leafs = OrderedDict()

                            self.export = YList(self)
                            self.import_ = YList(self)
                            self._segment_path = lambda: "route-target"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget, [], name, value)


                        class Export(Entity):
                            """
                            Export Target\-VPN community
                            
                            .. attribute:: asn_ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: stitching
                            
                            	VXLAN route target set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget.Export, self).__init__()

                                self.yang_name = "export"
                                self.yang_parent_name = "route-target"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['asn_ip']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('asn_ip', (YLeaf(YType.str, 'asn-ip'), ['str'])),
                                    ('stitching', (YLeaf(YType.empty, 'stitching'), ['Empty'])),
                                ])
                                self.asn_ip = None
                                self.stitching = None
                                self._segment_path = lambda: "export" + "[asn-ip='" + str(self.asn_ip) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget.Export, [u'asn_ip', u'stitching'], name, value)


                        class Import(Entity):
                            """
                            Import Target\-VPN community
                            
                            .. attribute:: asn_ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: stitching
                            
                            	VXLAN route target set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget.Import, self).__init__()

                                self.yang_name = "import"
                                self.yang_parent_name = "route-target"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['asn_ip']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('asn_ip', (YLeaf(YType.str, 'asn-ip'), ['str'])),
                                    ('stitching', (YLeaf(YType.empty, 'stitching'), ['Empty'])),
                                ])
                                self.asn_ip = None
                                self.stitching = None
                                self._segment_path = lambda: "import" + "[asn-ip='" + str(self.asn_ip) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.RouteTarget.Import, [u'asn_ip', u'stitching'], name, value)


                    class Bgp(Entity):
                        """
                        Commands pertaining to BGP
                        
                        .. attribute:: next_hop
                        
                        	Next\-hop for the routes of a VRF in the backbone
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv4.Bgp.NextHop>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Vrf.Definition.AddressFamily.Ipv4.Bgp, self).__init__()

                            self.yang_name = "bgp"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.Vrf.Definition.AddressFamily.Ipv4.Bgp.NextHop))])
                            self._leafs = OrderedDict()

                            self.next_hop = Native.Vrf.Definition.AddressFamily.Ipv4.Bgp.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._segment_path = lambda: "bgp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Bgp, [], name, value)


                        class NextHop(Entity):
                            """
                            Next\-hop for the routes of a VRF in the backbone
                            
                            .. attribute:: loopback
                            
                            	Loopback interface number
                            	**type**\: int
                            
                            	**range:** 0..2147483647
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Vrf.Definition.AddressFamily.Ipv4.Bgp.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ])
                                self.loopback = None
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Bgp.NextHop, [u'loopback'], name, value)


                    class Import(Entity):
                        """
                        VRF import
                        
                        .. attribute:: map
                        
                        	Route\-map based VRF import
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Vrf.Definition.AddressFamily.Ipv4.Import, self).__init__()

                            self.yang_name = "import"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('map', (YLeaf(YType.str, 'map'), ['str'])),
                            ])
                            self.map = None
                            self._segment_path = lambda: "import"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv4.Import, [u'map'], name, value)


                class Ipv6(Entity):
                    """
                    Address family
                    
                    .. attribute:: mdt
                    
                    	Backbone Multicast Distribution Tree
                    	**type**\:  :py:class:`Mdt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv6.Mdt>`
                    
                    .. attribute:: route_target
                    
                    	Specify Target VPN Extended Communities
                    	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget>`
                    
                    .. attribute:: bgp
                    
                    	Commands pertaining to BGP
                    	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv6.Bgp>`
                    
                    .. attribute:: import_
                    
                    	VRF import
                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv6.Import>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Vrf.Definition.AddressFamily.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mdt", ("mdt", Native.Vrf.Definition.AddressFamily.Ipv6.Mdt)), ("route-target", ("route_target", Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget)), ("bgp", ("bgp", Native.Vrf.Definition.AddressFamily.Ipv6.Bgp)), ("import", ("import_", Native.Vrf.Definition.AddressFamily.Ipv6.Import))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.mdt = Native.Vrf.Definition.AddressFamily.Ipv6.Mdt()
                        self.mdt.parent = self
                        self._children_name_map["mdt"] = "mdt"

                        self.route_target = Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget()
                        self.route_target.parent = self
                        self._children_name_map["route_target"] = "route-target"

                        self.bgp = Native.Vrf.Definition.AddressFamily.Ipv6.Bgp()
                        self.bgp.parent = self
                        self._children_name_map["bgp"] = "bgp"

                        self.import_ = Native.Vrf.Definition.AddressFamily.Ipv6.Import()
                        self.import_.parent = self
                        self._children_name_map["import_"] = "import"
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv6, [], name, value)


                    class Mdt(Entity):
                        """
                        Backbone Multicast Distribution Tree
                        
                        .. attribute:: mtu
                        
                        	The MTU
                        	**type**\: int
                        
                        	**range:** 576..18010
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Vrf.Definition.AddressFamily.Ipv6.Mdt, self).__init__()

                            self.yang_name = "mdt"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                            ])
                            self.mtu = None
                            self._segment_path = lambda: "mdt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv6.Mdt, [u'mtu'], name, value)


                    class RouteTarget(Entity):
                        """
                        Specify Target VPN Extended Communities
                        
                        .. attribute:: export
                        
                        	Export Target\-VPN community
                        	**type**\: list of  		 :py:class:`Export <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget.Export>`
                        
                        .. attribute:: import_
                        
                        	Import Target\-VPN community
                        	**type**\: list of  		 :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget.Import>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget, self).__init__()

                            self.yang_name = "route-target"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("export", ("export", Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget.Export)), ("import", ("import_", Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget.Import))])
                            self._leafs = OrderedDict()

                            self.export = YList(self)
                            self.import_ = YList(self)
                            self._segment_path = lambda: "route-target"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget, [], name, value)


                        class Export(Entity):
                            """
                            Export Target\-VPN community
                            
                            .. attribute:: asn_ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: stitching
                            
                            	VXLAN route target set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget.Export, self).__init__()

                                self.yang_name = "export"
                                self.yang_parent_name = "route-target"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['asn_ip']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('asn_ip', (YLeaf(YType.str, 'asn-ip'), ['str'])),
                                    ('stitching', (YLeaf(YType.empty, 'stitching'), ['Empty'])),
                                ])
                                self.asn_ip = None
                                self.stitching = None
                                self._segment_path = lambda: "export" + "[asn-ip='" + str(self.asn_ip) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget.Export, [u'asn_ip', u'stitching'], name, value)


                        class Import(Entity):
                            """
                            Import Target\-VPN community
                            
                            .. attribute:: asn_ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: stitching
                            
                            	VXLAN route target set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget.Import, self).__init__()

                                self.yang_name = "import"
                                self.yang_parent_name = "route-target"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['asn_ip']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('asn_ip', (YLeaf(YType.str, 'asn-ip'), ['str'])),
                                    ('stitching', (YLeaf(YType.empty, 'stitching'), ['Empty'])),
                                ])
                                self.asn_ip = None
                                self.stitching = None
                                self._segment_path = lambda: "import" + "[asn-ip='" + str(self.asn_ip) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv6.RouteTarget.Import, [u'asn_ip', u'stitching'], name, value)


                    class Bgp(Entity):
                        """
                        Commands pertaining to BGP
                        
                        .. attribute:: next_hop
                        
                        	Next\-hop for the routes of a VRF in the backbone
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Vrf.Definition.AddressFamily.Ipv6.Bgp, self).__init__()

                            self.yang_name = "bgp"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop))])
                            self._leafs = OrderedDict()

                            self.next_hop = Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._segment_path = lambda: "bgp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv6.Bgp, [], name, value)


                        class NextHop(Entity):
                            """
                            Next\-hop for the routes of a VRF in the backbone
                            
                            .. attribute:: ipv4
                            
                            	Use ipv4 address of the Loopback
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop.Ipv4>`
                            
                            .. attribute:: ipv6
                            
                            	Use ipv6 address of the Loopback
                            	**type**\:  :py:class:`Ipv6_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop.Ipv6_>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop.Ipv4)), ("ipv6", ("ipv6", Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop.Ipv6_))])
                                self._leafs = OrderedDict()

                                self.ipv4 = Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop.Ipv6_()
                                self.ipv6.parent = self
                                self._children_name_map["ipv6"] = "ipv6"
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop, [], name, value)


                            class Ipv4(Entity):
                                """
                                Use ipv4 address of the Loopback
                                
                                .. attribute:: loopback
                                
                                	Loopback interface number
                                	**type**\: int
                                
                                	**range:** 0..2147483647
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ])
                                    self.loopback = None
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop.Ipv4, [u'loopback'], name, value)


                            class Ipv6_(Entity):
                                """
                                Use ipv6 address of the Loopback
                                
                                .. attribute:: loopback
                                
                                	Loopback interface number
                                	**type**\: int
                                
                                	**range:** 0..2147483647
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop.Ipv6_, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ])
                                    self.loopback = None
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv6.Bgp.NextHop.Ipv6_, [u'loopback'], name, value)


                    class Import(Entity):
                        """
                        VRF import
                        
                        .. attribute:: map
                        
                        	Route\-map based VRF import
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Vrf.Definition.AddressFamily.Ipv6.Import, self).__init__()

                            self.yang_name = "import"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('map', (YLeaf(YType.str, 'map'), ['str'])),
                            ])
                            self.map = None
                            self._segment_path = lambda: "import"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vrf.Definition.AddressFamily.Ipv6.Import, [u'map'], name, value)


            class RouteTarget(Entity):
                """
                Specify Target VPN Extended Communities
                
                .. attribute:: export
                
                	Export Target\-VPN community
                	**type**\: list of  		 :py:class:`Export <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.RouteTarget.Export>`
                
                .. attribute:: import_
                
                	Import Target\-VPN community
                	**type**\: list of  		 :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vrf.Definition.RouteTarget.Import>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Vrf.Definition.RouteTarget, self).__init__()

                    self.yang_name = "route-target"
                    self.yang_parent_name = "definition"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("export", ("export", Native.Vrf.Definition.RouteTarget.Export)), ("import", ("import_", Native.Vrf.Definition.RouteTarget.Import))])
                    self._leafs = OrderedDict()

                    self.export = YList(self)
                    self.import_ = YList(self)
                    self._segment_path = lambda: "route-target"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vrf.Definition.RouteTarget, [], name, value)


                class Export(Entity):
                    """
                    Export Target\-VPN community
                    
                    .. attribute:: asn_ip  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                    
                    .. attribute:: stitching
                    
                    	VXLAN route target set
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Vrf.Definition.RouteTarget.Export, self).__init__()

                        self.yang_name = "export"
                        self.yang_parent_name = "route-target"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['asn_ip']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('asn_ip', (YLeaf(YType.str, 'asn-ip'), ['str'])),
                            ('stitching', (YLeaf(YType.empty, 'stitching'), ['Empty'])),
                        ])
                        self.asn_ip = None
                        self.stitching = None
                        self._segment_path = lambda: "export" + "[asn-ip='" + str(self.asn_ip) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Vrf.Definition.RouteTarget.Export, [u'asn_ip', u'stitching'], name, value)


                class Import(Entity):
                    """
                    Import Target\-VPN community
                    
                    .. attribute:: asn_ip  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                    
                    .. attribute:: stitching
                    
                    	VXLAN route target set
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Vrf.Definition.RouteTarget.Import, self).__init__()

                        self.yang_name = "import"
                        self.yang_parent_name = "route-target"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['asn_ip']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('asn_ip', (YLeaf(YType.str, 'asn-ip'), ['str'])),
                            ('stitching', (YLeaf(YType.empty, 'stitching'), ['Empty'])),
                        ])
                        self.asn_ip = None
                        self.stitching = None
                        self._segment_path = lambda: "import" + "[asn-ip='" + str(self.asn_ip) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Vrf.Definition.RouteTarget.Import, [u'asn_ip', u'stitching'], name, value)


            class Vpn(Entity):
                """
                Configure VPN ID as specified in rfc2685
                
                .. attribute:: id
                
                	Configure VPN ID in rfc2685 format
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F][0\-9a\-fA\-F]?[0\-9a\-fA\-F]?\:[0\-9a\-fA\-F][0\-9a\-fA\-F]?[0\-9a\-fA\-F]?[0\-9a\-fA\-F]?
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Vrf.Definition.Vpn, self).__init__()

                    self.yang_name = "vpn"
                    self.yang_parent_name = "definition"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                    ])
                    self.id = None
                    self._segment_path = lambda: "vpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vrf.Definition.Vpn, [u'id'], name, value)


    class Rmon(Entity):
        """
        Remote Monitoring
        
        .. attribute:: alarm
        
        	Configure an RMON alarm
        	**type**\: list of  		 :py:class:`Alarm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Rmon.Alarm>`
        
        .. attribute:: event
        
        	Configure an RMON event
        	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Rmon.Event>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Rmon, self).__init__()

            self.yang_name = "rmon"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("alarm", ("alarm", Native.Rmon.Alarm)), ("event", ("event", Native.Rmon.Event))])
            self._leafs = OrderedDict()

            self.alarm = YList(self)
            self.event = YList(self)
            self._segment_path = lambda: "rmon"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Rmon, [], name, value)


        class Alarm(Entity):
            """
            Configure an RMON alarm
            
            .. attribute:: number  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: mib_object
            
            	
            	**type**\: str
            
            .. attribute:: sample_interval
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: test_mode
            
            	
            	**type**\:  :py:class:`TestMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Rmon.Alarm.TestMode>`
            
            .. attribute:: rising_threshold
            
            	Configure the rising threshold
            	**type**\: int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: rising_event
            
            	
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: falling_threshold
            
            	Configure the falling threshold
            	**type**\: int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: falling_event
            
            	
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: owner
            
            	Specify an owner for the alarm
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Rmon.Alarm, self).__init__()

                self.yang_name = "alarm"
                self.yang_parent_name = "rmon"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['number']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                    ('mib_object', (YLeaf(YType.str, 'mib-object'), ['str'])),
                    ('sample_interval', (YLeaf(YType.uint32, 'sample-interval'), ['int'])),
                    ('test_mode', (YLeaf(YType.enumeration, 'test-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Rmon.Alarm.TestMode')])),
                    ('rising_threshold', (YLeaf(YType.int32, 'rising-threshold'), ['int'])),
                    ('rising_event', (YLeaf(YType.uint16, 'rising-event'), ['int'])),
                    ('falling_threshold', (YLeaf(YType.int32, 'falling-threshold'), ['int'])),
                    ('falling_event', (YLeaf(YType.uint16, 'falling-event'), ['int'])),
                    ('owner', (YLeaf(YType.str, 'owner'), ['str'])),
                ])
                self.number = None
                self.mib_object = None
                self.sample_interval = None
                self.test_mode = None
                self.rising_threshold = None
                self.rising_event = None
                self.falling_threshold = None
                self.falling_event = None
                self.owner = None
                self._segment_path = lambda: "alarm" + "[number='" + str(self.number) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/rmon/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Rmon.Alarm, [u'number', u'mib_object', u'sample_interval', u'test_mode', u'rising_threshold', u'rising_event', u'falling_threshold', u'falling_event', u'owner'], name, value)

            class TestMode(Enum):
                """
                TestMode (Enum Class)

                .. data:: absolute = 0

                .. data:: delta = 1

                """

                absolute = Enum.YLeaf(0, "absolute")

                delta = Enum.YLeaf(1, "delta")



        class Event(Entity):
            """
            Configure an RMON event
            
            .. attribute:: number  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: log
            
            	Generate RMON log when the event fires
            	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Rmon.Event.Log>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Rmon.Event, self).__init__()

                self.yang_name = "event"
                self.yang_parent_name = "rmon"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['number']
                self._child_classes = OrderedDict([("log", ("log", Native.Rmon.Event.Log))])
                self._leafs = OrderedDict([
                    ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                ])
                self.number = None

                self.log = None
                self._children_name_map["log"] = "log"
                self._segment_path = lambda: "event" + "[number='" + str(self.number) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/rmon/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Rmon.Event, [u'number'], name, value)


            class Log(Entity):
                """
                Generate RMON log when the event fires
                
                .. attribute:: trap
                
                	Generate SNMP trap when the event fires
                	**type**\: str
                
                .. attribute:: description
                
                	Specify a description of the event
                	**type**\: str
                
                .. attribute:: owner
                
                	Specify an owner for the event
                	**type**\: str
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Rmon.Event.Log, self).__init__()

                    self.yang_name = "log"
                    self.yang_parent_name = "event"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('trap', (YLeaf(YType.str, 'trap'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('owner', (YLeaf(YType.str, 'owner'), ['str'])),
                    ])
                    self.trap = None
                    self.description = None
                    self.owner = None
                    self._segment_path = lambda: "log"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Rmon.Event.Log, [u'trap', u'description', u'owner'], name, value)


    class Sampler(Entity):
        """
        Define a Sampler
        
        .. attribute:: name  (key)
        
        	
        	**type**\: str
        
        .. attribute:: description
        
        	Provide a description for this Sampler
        	**type**\: str
        
        .. attribute:: mode
        
        	Sampling mode
        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Sampler.Mode>`
        
        .. attribute:: granularity
        
        	Specify sampler granularity
        	**type**\:  :py:class:`Granularity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Sampler.Granularity>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Sampler, self).__init__()

            self.yang_name = "sampler"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['name']
            self._child_classes = OrderedDict([("Cisco-IOS-XE-flow:mode", ("mode", Native.Sampler.Mode)), ("Cisco-IOS-XE-flow:granularity", ("granularity", Native.Sampler.Granularity))])
            self._leafs = OrderedDict([
                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ('description', (YLeaf(YType.str, 'Cisco-IOS-XE-flow:description'), ['str'])),
            ])
            self.name = None
            self.description = None

            self.mode = Native.Sampler.Mode()
            self.mode.parent = self
            self._children_name_map["mode"] = "Cisco-IOS-XE-flow:mode"

            self.granularity = Native.Sampler.Granularity()
            self.granularity.parent = self
            self._children_name_map["granularity"] = "Cisco-IOS-XE-flow:granularity"
            self._segment_path = lambda: "sampler" + "[name='" + str(self.name) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Sampler, [u'name', 'description'], name, value)


        class Mode(Entity):
            """
            Sampling mode
            
            .. attribute:: deterministic
            
            	Deterministic mode of sampling
            	**type**\:  :py:class:`Deterministic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Sampler.Mode.Deterministic>`
            
            .. attribute:: hash
            
            	Hash mode of sampling
            	**type**\:  :py:class:`Hash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Sampler.Mode.Hash>`
            
            .. attribute:: random
            
            	Random mode of sampling
            	**type**\:  :py:class:`Random <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Sampler.Mode.Random>`
            
            

            """

            _prefix = 'ios-flow'
            _revision = '2018-01-04'

            def __init__(self):
                super(Native.Sampler.Mode, self).__init__()

                self.yang_name = "mode"
                self.yang_parent_name = "sampler"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("deterministic", ("deterministic", Native.Sampler.Mode.Deterministic)), ("hash", ("hash", Native.Sampler.Mode.Hash)), ("random", ("random", Native.Sampler.Mode.Random))])
                self._leafs = OrderedDict()

                self.deterministic = Native.Sampler.Mode.Deterministic()
                self.deterministic.parent = self
                self._children_name_map["deterministic"] = "deterministic"

                self.hash = Native.Sampler.Mode.Hash()
                self.hash.parent = self
                self._children_name_map["hash"] = "hash"

                self.random = Native.Sampler.Mode.Random()
                self.random.parent = self
                self._children_name_map["random"] = "random"
                self._segment_path = lambda: "Cisco-IOS-XE-flow:mode"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Sampler.Mode, [], name, value)


            class Deterministic(Entity):
                """
                Deterministic mode of sampling
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: out_of
                
                	Select M packets out of an N packet window
                	**type**\: int
                
                	**range:** 2..32768
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Sampler.Mode.Deterministic, self).__init__()

                    self.yang_name = "deterministic"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                        ('out_of', (YLeaf(YType.uint16, 'out-of'), ['int'])),
                    ])
                    self.number = None
                    self.out_of = None
                    self._segment_path = lambda: "deterministic"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Sampler.Mode.Deterministic, ['number', 'out_of'], name, value)


            class Hash(Entity):
                """
                Hash mode of sampling
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: out_of
                
                	Select 1 packets out of an N packets based on hash of ip\-id and udp / tcp checksum
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Sampler.Mode.Hash, self).__init__()

                    self.yang_name = "hash"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                        ('out_of', (YLeaf(YType.uint16, 'out-of'), ['int'])),
                    ])
                    self.number = None
                    self.out_of = None
                    self._segment_path = lambda: "hash"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Sampler.Mode.Hash, ['number', 'out_of'], name, value)


            class Random(Entity):
                """
                Random mode of sampling
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: out_of
                
                	Select M packets out of an N packet window
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Sampler.Mode.Random, self).__init__()

                    self.yang_name = "random"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                        ('out_of', (YLeaf(YType.uint16, 'out-of'), ['int'])),
                    ])
                    self.number = None
                    self.out_of = None
                    self._segment_path = lambda: "random"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Sampler.Mode.Random, ['number', 'out_of'], name, value)


        class Granularity(Entity):
            """
            Specify sampler granularity
            
            .. attribute:: connection
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: packet
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-flow'
            _revision = '2018-01-04'

            def __init__(self):
                super(Native.Sampler.Granularity, self).__init__()

                self.yang_name = "granularity"
                self.yang_parent_name = "sampler"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('connection', (YLeaf(YType.empty, 'connection'), ['Empty'])),
                    ('packet', (YLeaf(YType.empty, 'packet'), ['Empty'])),
                ])
                self.connection = None
                self.packet = None
                self._segment_path = lambda: "Cisco-IOS-XE-flow:granularity"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Sampler.Granularity, ['connection', 'packet'], name, value)


    class Flow(Entity):
        """
        Global Flow configuration subcommands
        
        .. attribute:: record
        
        	Define a Flow Record
        	**type**\: list of  		 :py:class:`Record <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record>`
        
        .. attribute:: exporter
        
        	Define a Flow Exporter
        	**type**\: list of  		 :py:class:`Exporter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter>`
        
        .. attribute:: monitor
        
        	Define a Flow Monitor
        	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Flow, self).__init__()

            self.yang_name = "flow"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-flow:record", ("record", Native.Flow.Record)), ("Cisco-IOS-XE-flow:exporter", ("exporter", Native.Flow.Exporter)), ("Cisco-IOS-XE-flow:monitor", ("monitor", Native.Flow.Monitor))])
            self._leafs = OrderedDict()

            self.record = YList(self)
            self.exporter = YList(self)
            self.monitor = YList(self)
            self._segment_path = lambda: "flow"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Flow, [], name, value)


        class Record(Entity):
            """
            Define a Flow Record
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: type
            
            	Type of the Flow Record
            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Type>`
            
            .. attribute:: collect
            
            	Specify a non\-key field
            	**type**\:  :py:class:`Collect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect>`
            
            .. attribute:: default
            
            	Set a command to its defaults
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default>`
            
            .. attribute:: description
            
            	Provide a description for this Flow Record
            	**type**\: str
            
            .. attribute:: match
            
            	Specify a key field
            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match>`
            
            

            """

            _prefix = 'ios-flow'
            _revision = '2018-01-04'

            def __init__(self):
                super(Native.Flow.Record, self).__init__()

                self.yang_name = "record"
                self.yang_parent_name = "flow"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("collect", ("collect", Native.Flow.Record.Collect)), ("default", ("default", Native.Flow.Record.Default)), ("match", ("match", Native.Flow.Record.Match))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Flow.Record.Type')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                ])
                self.name = None
                self.type = None
                self.description = None

                self.collect = Native.Flow.Record.Collect()
                self.collect.parent = self
                self._children_name_map["collect"] = "collect"

                self.default = Native.Flow.Record.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.match = Native.Flow.Record.Match()
                self.match.parent = self
                self._children_name_map["match"] = "match"
                self._segment_path = lambda: "Cisco-IOS-XE-flow:record" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/flow/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Flow.Record, ['name', 'type', 'description'], name, value)

            class Type(Enum):
                """
                Type (Enum Class)

                Type of the Flow Record

                .. data:: performance_monitor = 0

                """

                performance_monitor = Enum.YLeaf(0, "performance-monitor")



            class Collect(Entity):
                """
                Specify a non\-key field
                
                .. attribute:: application
                
                	Application fields
                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application>`
                
                .. attribute:: connection
                
                	Connection fields
                	**type**\:  :py:class:`Connection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection>`
                
                .. attribute:: counter
                
                	Counter fields
                	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Counter>`
                
                .. attribute:: datalink
                
                	Datalink (layer2) fields
                	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Datalink>`
                
                .. attribute:: flow
                
                	Flow identifying fields
                	**type**\:  :py:class:`Flow_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Flow_>`
                
                .. attribute:: interface
                
                	Interface fields
                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Interface>`
                
                .. attribute:: ipv4
                
                	IPv4 fields
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4>`
                
                .. attribute:: ipv6
                
                	IPv6 fields
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6>`
                
                .. attribute:: metadata
                
                	Metadata fields
                	**type**\:  :py:class:`Metadata <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Metadata>`
                
                .. attribute:: monitor
                
                	monitor fields
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Monitor>`
                
                .. attribute:: mpls
                
                	MPLS fields
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Mpls>`
                
                .. attribute:: network
                
                	network metrics
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Network>`
                
                .. attribute:: pfr
                
                	PfR metrics
                	**type**\:  :py:class:`Pfr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr>`
                
                .. attribute:: policy
                
                	policy fields
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Policy>`
                
                .. attribute:: routing
                
                	Routing attributes
                	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing>`
                
                .. attribute:: services
                
                	Services fields
                	**type**\:  :py:class:`Services <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Services>`
                
                .. attribute:: timestamp
                
                	Timestamp fields
                	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Timestamp>`
                
                .. attribute:: transport
                
                	Transport layer fields
                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport>`
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Record.Collect, self).__init__()

                    self.yang_name = "collect"
                    self.yang_parent_name = "record"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("application", ("application", Native.Flow.Record.Collect.Application)), ("connection", ("connection", Native.Flow.Record.Collect.Connection)), ("counter", ("counter", Native.Flow.Record.Collect.Counter)), ("datalink", ("datalink", Native.Flow.Record.Collect.Datalink)), ("flow", ("flow", Native.Flow.Record.Collect.Flow_)), ("interface", ("interface", Native.Flow.Record.Collect.Interface)), ("ipv4", ("ipv4", Native.Flow.Record.Collect.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Collect.Ipv6)), ("metadata", ("metadata", Native.Flow.Record.Collect.Metadata)), ("monitor", ("monitor", Native.Flow.Record.Collect.Monitor)), ("mpls", ("mpls", Native.Flow.Record.Collect.Mpls)), ("network", ("network", Native.Flow.Record.Collect.Network)), ("pfr", ("pfr", Native.Flow.Record.Collect.Pfr)), ("policy", ("policy", Native.Flow.Record.Collect.Policy)), ("routing", ("routing", Native.Flow.Record.Collect.Routing)), ("services", ("services", Native.Flow.Record.Collect.Services)), ("timestamp", ("timestamp", Native.Flow.Record.Collect.Timestamp)), ("transport", ("transport", Native.Flow.Record.Collect.Transport))])
                    self._leafs = OrderedDict()

                    self.application = Native.Flow.Record.Collect.Application()
                    self.application.parent = self
                    self._children_name_map["application"] = "application"

                    self.connection = Native.Flow.Record.Collect.Connection()
                    self.connection.parent = self
                    self._children_name_map["connection"] = "connection"

                    self.counter = Native.Flow.Record.Collect.Counter()
                    self.counter.parent = self
                    self._children_name_map["counter"] = "counter"

                    self.datalink = Native.Flow.Record.Collect.Datalink()
                    self.datalink.parent = self
                    self._children_name_map["datalink"] = "datalink"

                    self.flow = Native.Flow.Record.Collect.Flow_()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"

                    self.interface = Native.Flow.Record.Collect.Interface()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.ipv4 = Native.Flow.Record.Collect.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = Native.Flow.Record.Collect.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.metadata = Native.Flow.Record.Collect.Metadata()
                    self.metadata.parent = self
                    self._children_name_map["metadata"] = "metadata"

                    self.monitor = Native.Flow.Record.Collect.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"

                    self.mpls = Native.Flow.Record.Collect.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"

                    self.network = Native.Flow.Record.Collect.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.pfr = Native.Flow.Record.Collect.Pfr()
                    self.pfr.parent = self
                    self._children_name_map["pfr"] = "pfr"

                    self.policy = Native.Flow.Record.Collect.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.routing = Native.Flow.Record.Collect.Routing()
                    self.routing.parent = self
                    self._children_name_map["routing"] = "routing"

                    self.services = Native.Flow.Record.Collect.Services()
                    self.services.parent = self
                    self._children_name_map["services"] = "services"

                    self.timestamp = Native.Flow.Record.Collect.Timestamp()
                    self.timestamp.parent = self
                    self._children_name_map["timestamp"] = "timestamp"

                    self.transport = Native.Flow.Record.Collect.Transport()
                    self.transport.parent = self
                    self._children_name_map["transport"] = "transport"
                    self._segment_path = lambda: "collect"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Record.Collect, [], name, value)


                class Application(Entity):
                    """
                    Application fields
                    
                    .. attribute:: dns
                    
                    	Domain Name Server lookup
                    	**type**\:  :py:class:`Dns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Dns>`
                    
                    .. attribute:: http
                    
                    	World Wide Web traffic
                    	**type**\:  :py:class:`Http <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Http>`
                    
                    .. attribute:: media
                    
                    	Media fields
                    	**type**\:  :py:class:`Media <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Media>`
                    
                    .. attribute:: name
                    
                    	Application name
                    	**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Name>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: nntp
                    
                    	Network news transfer protocol
                    	**type**\:  :py:class:`Nntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Nntp>`
                    
                    .. attribute:: pop3
                    
                    	Post Office Protocol 3
                    	**type**\:  :py:class:`Pop3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Pop3>`
                    
                    .. attribute:: rtmp
                    
                    	Real Time Messaging Protocol
                    	**type**\:  :py:class:`Rtmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Rtmp>`
                    
                    .. attribute:: rtsp
                    
                    	Real Time Streaming Protocol
                    	**type**\:  :py:class:`Rtsp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Rtsp>`
                    
                    .. attribute:: sip
                    
                    	Session Initiation Protocol
                    	**type**\:  :py:class:`Sip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Sip>`
                    
                    .. attribute:: smtp
                    
                    	Simple Mail Transfer Protocol
                    	**type**\:  :py:class:`Smtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Smtp>`
                    
                    .. attribute:: ssl
                    
                    	Secure Socket Layer Protocol
                    	**type**\:  :py:class:`Ssl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Ssl>`
                    
                    .. attribute:: vendor
                    
                    	Application vendor id
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: version
                    
                    	Application version id
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Application, self).__init__()

                        self.yang_name = "application"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dns", ("dns", Native.Flow.Record.Collect.Application.Dns)), ("http", ("http", Native.Flow.Record.Collect.Application.Http)), ("media", ("media", Native.Flow.Record.Collect.Application.Media)), ("name", ("name", Native.Flow.Record.Collect.Application.Name)), ("nntp", ("nntp", Native.Flow.Record.Collect.Application.Nntp)), ("pop3", ("pop3", Native.Flow.Record.Collect.Application.Pop3)), ("rtmp", ("rtmp", Native.Flow.Record.Collect.Application.Rtmp)), ("rtsp", ("rtsp", Native.Flow.Record.Collect.Application.Rtsp)), ("sip", ("sip", Native.Flow.Record.Collect.Application.Sip)), ("smtp", ("smtp", Native.Flow.Record.Collect.Application.Smtp)), ("ssl", ("ssl", Native.Flow.Record.Collect.Application.Ssl))])
                        self._leafs = OrderedDict([
                            ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                            ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                        ])
                        self.vendor = None
                        self.version = None

                        self.dns = Native.Flow.Record.Collect.Application.Dns()
                        self.dns.parent = self
                        self._children_name_map["dns"] = "dns"

                        self.http = Native.Flow.Record.Collect.Application.Http()
                        self.http.parent = self
                        self._children_name_map["http"] = "http"

                        self.media = Native.Flow.Record.Collect.Application.Media()
                        self.media.parent = self
                        self._children_name_map["media"] = "media"

                        self.name = None
                        self._children_name_map["name"] = "name"

                        self.nntp = Native.Flow.Record.Collect.Application.Nntp()
                        self.nntp.parent = self
                        self._children_name_map["nntp"] = "nntp"

                        self.pop3 = Native.Flow.Record.Collect.Application.Pop3()
                        self.pop3.parent = self
                        self._children_name_map["pop3"] = "pop3"

                        self.rtmp = Native.Flow.Record.Collect.Application.Rtmp()
                        self.rtmp.parent = self
                        self._children_name_map["rtmp"] = "rtmp"

                        self.rtsp = Native.Flow.Record.Collect.Application.Rtsp()
                        self.rtsp.parent = self
                        self._children_name_map["rtsp"] = "rtsp"

                        self.sip = Native.Flow.Record.Collect.Application.Sip()
                        self.sip.parent = self
                        self._children_name_map["sip"] = "sip"

                        self.smtp = Native.Flow.Record.Collect.Application.Smtp()
                        self.smtp.parent = self
                        self._children_name_map["smtp"] = "smtp"

                        self.ssl = Native.Flow.Record.Collect.Application.Ssl()
                        self.ssl.parent = self
                        self._children_name_map["ssl"] = "ssl"
                        self._segment_path = lambda: "application"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Application, ['vendor', 'version'], name, value)


                    class Dns(Entity):
                        """
                        Domain Name Server lookup
                        
                        .. attribute:: domain_name
                        
                        	Domain name
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Application.Dns, self).__init__()

                            self.yang_name = "dns"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('domain_name', (YLeaf(YType.empty, 'domain-name'), ['Empty'])),
                            ])
                            self.domain_name = None
                            self._segment_path = lambda: "dns"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Application.Dns, ['domain_name'], name, value)


                    class Http(Entity):
                        """
                        World Wide Web traffic
                        
                        .. attribute:: host
                        
                        	Host name of Origin Server containing resource
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: referer
                        
                        	Address the resource request was obtained from
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: uri
                        
                        	List of URIs and associated hit counts
                        	**type**\:  :py:class:`Uri <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Http.Uri>`
                        
                        .. attribute:: url
                        
                        	Uniform Resource Locator path
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: user_agent
                        
                        	Software used by agent sending the request
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Application.Http, self).__init__()

                            self.yang_name = "http"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("uri", ("uri", Native.Flow.Record.Collect.Application.Http.Uri))])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('referer', (YLeaf(YType.empty, 'referer'), ['Empty'])),
                                ('url', (YLeaf(YType.empty, 'url'), ['Empty'])),
                                ('user_agent', (YLeaf(YType.empty, 'user-agent'), ['Empty'])),
                            ])
                            self.host = None
                            self.referer = None
                            self.url = None
                            self.user_agent = None

                            self.uri = Native.Flow.Record.Collect.Application.Http.Uri()
                            self.uri.parent = self
                            self._children_name_map["uri"] = "uri"
                            self._segment_path = lambda: "http"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Application.Http, ['host', 'referer', 'url', 'user_agent'], name, value)


                        class Uri(Entity):
                            """
                            List of URIs and associated hit counts
                            
                            .. attribute:: statistics
                            
                            	Collect URI statistics
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Application.Http.Uri, self).__init__()

                                self.yang_name = "uri"
                                self.yang_parent_name = "http"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('statistics', (YLeaf(YType.empty, 'statistics'), ['Empty'])),
                                ])
                                self.statistics = None
                                self._segment_path = lambda: "uri"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Application.Http.Uri, ['statistics'], name, value)


                    class Media(Entity):
                        """
                        Media fields
                        
                        .. attribute:: bytes
                        
                        	Media fields
                        	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Media.Bytes>`
                        
                        .. attribute:: event
                        
                        	Flags indicating media events
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: packets
                        
                        	Media fields
                        	**type**\:  :py:class:`Packets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Media.Packets>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Application.Media, self).__init__()

                            self.yang_name = "media"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Collect.Application.Media.Bytes)), ("packets", ("packets", Native.Flow.Record.Collect.Application.Media.Packets))])
                            self._leafs = OrderedDict([
                                ('event', (YLeaf(YType.empty, 'event'), ['Empty'])),
                            ])
                            self.event = None

                            self.bytes = Native.Flow.Record.Collect.Application.Media.Bytes()
                            self.bytes.parent = self
                            self._children_name_map["bytes"] = "bytes"

                            self.packets = Native.Flow.Record.Collect.Application.Media.Packets()
                            self.packets.parent = self
                            self._children_name_map["packets"] = "packets"
                            self._segment_path = lambda: "media"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Application.Media, ['event'], name, value)


                        class Bytes(Entity):
                            """
                            Media fields
                            
                            .. attribute:: counter
                            
                            	A count of the number of bytes of media payload
                            	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Media.Bytes.Counter>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: rate
                            
                            	Byte rate for the media stream
                            	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Media.Bytes.Rate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Application.Media.Bytes, self).__init__()

                                self.yang_name = "bytes"
                                self.yang_parent_name = "media"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Collect.Application.Media.Bytes.Counter)), ("rate", ("rate", Native.Flow.Record.Collect.Application.Media.Bytes.Rate))])
                                self._leafs = OrderedDict()

                                self.counter = None
                                self._children_name_map["counter"] = "counter"

                                self.rate = None
                                self._children_name_map["rate"] = "rate"
                                self._segment_path = lambda: "bytes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Application.Media.Bytes, [], name, value)


                            class Counter(Entity):
                                """
                                A count of the number of bytes of media payload
                                
                                .. attribute:: long
                                
                                	A count of the number of bytes of media payload (64 bit counter)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Application.Media.Bytes.Counter, self).__init__()

                                    self.yang_name = "counter"
                                    self.yang_parent_name = "bytes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                    ])
                                    self.long = None
                                    self._segment_path = lambda: "counter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Application.Media.Bytes.Counter, ['long'], name, value)


                            class Rate(Entity):
                                """
                                Byte rate for the media stream
                                
                                .. attribute:: per_flow
                                
                                	Average media byte rate across flows
                                	**type**\:  :py:class:`PerFlow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Media.Bytes.Rate.PerFlow>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Application.Media.Bytes.Rate, self).__init__()

                                    self.yang_name = "rate"
                                    self.yang_parent_name = "bytes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("per-flow", ("per_flow", Native.Flow.Record.Collect.Application.Media.Bytes.Rate.PerFlow))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.per_flow = None
                                    self._children_name_map["per_flow"] = "per-flow"
                                    self._segment_path = lambda: "rate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Application.Media.Bytes.Rate, [], name, value)


                                class PerFlow(Entity):
                                    """
                                    Average media byte rate across flows
                                    
                                    .. attribute:: max
                                    
                                    	Maximum byte rate in the media stream
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Minumun byte rate in the media stream
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Collect.Application.Media.Bytes.Rate.PerFlow, self).__init__()

                                        self.yang_name = "per-flow"
                                        self.yang_parent_name = "rate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ])
                                        self.max = None
                                        self.min = None
                                        self._segment_path = lambda: "per-flow"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Collect.Application.Media.Bytes.Rate.PerFlow, ['max', 'min'], name, value)


                        class Packets(Entity):
                            """
                            Media fields
                            
                            .. attribute:: counter
                            
                            	A count of the number of packets with a media payload
                            	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Media.Packets.Counter>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: rate
                            
                            	Packet rate for the media stream
                            	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Media.Packets.Rate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Application.Media.Packets, self).__init__()

                                self.yang_name = "packets"
                                self.yang_parent_name = "media"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Collect.Application.Media.Packets.Counter)), ("rate", ("rate", Native.Flow.Record.Collect.Application.Media.Packets.Rate))])
                                self._leafs = OrderedDict()

                                self.counter = None
                                self._children_name_map["counter"] = "counter"

                                self.rate = None
                                self._children_name_map["rate"] = "rate"
                                self._segment_path = lambda: "packets"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Application.Media.Packets, [], name, value)


                            class Counter(Entity):
                                """
                                A count of the number of packets with a media payload
                                
                                .. attribute:: long
                                
                                	A count of the number of packets with a media payload (64 bit counter)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Application.Media.Packets.Counter, self).__init__()

                                    self.yang_name = "counter"
                                    self.yang_parent_name = "packets"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                    ])
                                    self.long = None
                                    self._segment_path = lambda: "counter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Application.Media.Packets.Counter, ['long'], name, value)


                            class Rate(Entity):
                                """
                                Packet rate for the media stream
                                
                                .. attribute:: variation
                                
                                	Variation in packet rate from configured expected rate
                                	**type**\:  :py:class:`Variation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Application.Media.Packets.Rate.Variation>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Application.Media.Packets.Rate, self).__init__()

                                    self.yang_name = "rate"
                                    self.yang_parent_name = "packets"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("variation", ("variation", Native.Flow.Record.Collect.Application.Media.Packets.Rate.Variation))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.variation = None
                                    self._children_name_map["variation"] = "variation"
                                    self._segment_path = lambda: "rate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Application.Media.Packets.Rate, [], name, value)


                                class Variation(Entity):
                                    """
                                    Variation in packet rate from configured expected rate
                                    
                                    .. attribute:: max
                                    
                                    	Max variation in packet rate from configured expected rate
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Variation in packet rate from configured expected rate
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sum
                                    
                                    	The sum of media rate variation from the configured rate for the RTP stream
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Collect.Application.Media.Packets.Rate.Variation, self).__init__()

                                        self.yang_name = "variation"
                                        self.yang_parent_name = "rate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.max = None
                                        self.min = None
                                        self.sum = None
                                        self._segment_path = lambda: "variation"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Collect.Application.Media.Packets.Rate.Variation, ['max', 'min', 'sum'], name, value)


                    class Name(Entity):
                        """
                        Application name
                        
                        .. attribute:: account_on_resolution
                        
                        	Account on resolution
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Application.Name, self).__init__()

                            self.yang_name = "name"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('account_on_resolution', (YLeaf(YType.empty, 'account-on-resolution'), ['Empty'])),
                            ])
                            self.account_on_resolution = None
                            self._segment_path = lambda: "name"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Application.Name, ['account_on_resolution'], name, value)


                    class Nntp(Entity):
                        """
                        Network news transfer protocol
                        
                        .. attribute:: group_name
                        
                        	NNTP Group name
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Application.Nntp, self).__init__()

                            self.yang_name = "nntp"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('group_name', (YLeaf(YType.empty, 'group-name'), ['Empty'])),
                            ])
                            self.group_name = None
                            self._segment_path = lambda: "nntp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Application.Nntp, ['group_name'], name, value)


                    class Pop3(Entity):
                        """
                        Post Office Protocol 3
                        
                        .. attribute:: server
                        
                        	POP3 Server Name
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Application.Pop3, self).__init__()

                            self.yang_name = "pop3"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                            ])
                            self.server = None
                            self._segment_path = lambda: "pop3"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Application.Pop3, ['server'], name, value)


                    class Rtmp(Entity):
                        """
                        Real Time Messaging Protocol
                        
                        .. attribute:: pageurl
                        
                        	RTMP page url address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Application.Rtmp, self).__init__()

                            self.yang_name = "rtmp"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('pageurl', (YLeaf(YType.empty, 'pageUrl'), ['Empty'])),
                            ])
                            self.pageurl = None
                            self._segment_path = lambda: "rtmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Application.Rtmp, ['pageurl'], name, value)


                    class Rtsp(Entity):
                        """
                        Real Time Streaming Protocol
                        
                        .. attribute:: host
                        
                        	RTSP Host Name
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Application.Rtsp, self).__init__()

                            self.yang_name = "rtsp"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                            ])
                            self.host = None
                            self._segment_path = lambda: "rtsp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Application.Rtsp, ['host'], name, value)


                    class Sip(Entity):
                        """
                        Session Initiation Protocol
                        
                        .. attribute:: destination
                        
                        	The destination domain of SIP transactions
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: source
                        
                        	The source domain of SIP transactions
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Application.Sip, self).__init__()

                            self.yang_name = "sip"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('destination', (YLeaf(YType.empty, 'destination'), ['Empty'])),
                                ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                            ])
                            self.destination = None
                            self.source = None
                            self._segment_path = lambda: "sip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Application.Sip, ['destination', 'source'], name, value)


                    class Smtp(Entity):
                        """
                        Simple Mail Transfer Protocol
                        
                        .. attribute:: sender
                        
                        	SMTP Sender Mail Address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: server
                        
                        	SMTP Server Name
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Application.Smtp, self).__init__()

                            self.yang_name = "smtp"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sender', (YLeaf(YType.empty, 'sender'), ['Empty'])),
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                            ])
                            self.sender = None
                            self.server = None
                            self._segment_path = lambda: "smtp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Application.Smtp, ['sender', 'server'], name, value)


                    class Ssl(Entity):
                        """
                        Secure Socket Layer Protocol
                        
                        .. attribute:: common_name
                        
                        	Certificate Common Name (CN)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Application.Ssl, self).__init__()

                            self.yang_name = "ssl"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('common_name', (YLeaf(YType.empty, 'common-name'), ['Empty'])),
                            ])
                            self.common_name = None
                            self._segment_path = lambda: "ssl"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Application.Ssl, ['common_name'], name, value)


                class Connection(Entity):
                    """
                    Connection fields
                    
                    .. attribute:: client
                    
                    	Client side (flow initiator) related metrics
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Client>`
                    
                    .. attribute:: delay
                    
                    	Connection delay metrics
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay>`
                    
                    .. attribute:: id
                    
                    	An identifier for a connection between client and server
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: initiator
                    
                    	The direction of the flow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: new_connections
                    
                    	The number of connection initiations observed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: server
                    
                    	Server side (flow responder) related metrics
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Server>`
                    
                    .. attribute:: sum_duration
                    
                    	The overall time in seconds for all connections
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transaction
                    
                    	Transaction related metrics
                    	**type**\:  :py:class:`Transaction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Transaction>`
                    
                    .. attribute:: transaction_id
                    
                    	An identifier for a transaction between client and server
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Connection, self).__init__()

                        self.yang_name = "connection"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("client", ("client", Native.Flow.Record.Collect.Connection.Client)), ("delay", ("delay", Native.Flow.Record.Collect.Connection.Delay)), ("server", ("server", Native.Flow.Record.Collect.Connection.Server)), ("transaction", ("transaction", Native.Flow.Record.Collect.Connection.Transaction))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                            ('initiator', (YLeaf(YType.empty, 'initiator'), ['Empty'])),
                            ('new_connections', (YLeaf(YType.empty, 'new-connections'), ['Empty'])),
                            ('sum_duration', (YLeaf(YType.empty, 'sum-duration'), ['Empty'])),
                            ('transaction_id', (YLeaf(YType.empty, 'transaction-id'), ['Empty'])),
                        ])
                        self.id = None
                        self.initiator = None
                        self.new_connections = None
                        self.sum_duration = None
                        self.transaction_id = None

                        self.client = Native.Flow.Record.Collect.Connection.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "client"

                        self.delay = Native.Flow.Record.Collect.Connection.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"

                        self.server = Native.Flow.Record.Collect.Connection.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.transaction = Native.Flow.Record.Collect.Connection.Transaction()
                        self.transaction.parent = self
                        self._children_name_map["transaction"] = "transaction"
                        self._segment_path = lambda: "connection"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Connection, ['id', 'initiator', 'new_connections', 'sum_duration', 'transaction_id'], name, value)


                    class Client(Entity):
                        """
                        Client side (flow initiator) related metrics
                        
                        .. attribute:: all
                        
                        	All non\-key client metrics
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: counter
                        
                        	Client side counter metrics
                        	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Client.Counter>`
                        
                        .. attribute:: ipv4
                        
                        	Client side IPv4 metrics
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Client.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	Client side IPv6 metrics
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Client.Ipv6>`
                        
                        .. attribute:: transport
                        
                        	Client side transport metrics
                        	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Client.Transport>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Connection.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "connection"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Collect.Connection.Client.Counter)), ("ipv4", ("ipv4", Native.Flow.Record.Collect.Connection.Client.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Collect.Connection.Client.Ipv6)), ("transport", ("transport", Native.Flow.Record.Collect.Connection.Client.Transport))])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                            ])
                            self.all = None

                            self.counter = Native.Flow.Record.Collect.Connection.Client.Counter()
                            self.counter.parent = self
                            self._children_name_map["counter"] = "counter"

                            self.ipv4 = Native.Flow.Record.Collect.Connection.Client.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = Native.Flow.Record.Collect.Connection.Client.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.transport = Native.Flow.Record.Collect.Connection.Client.Transport()
                            self.transport.parent = self
                            self._children_name_map["transport"] = "transport"
                            self._segment_path = lambda: "client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Connection.Client, ['all'], name, value)


                        class Counter(Entity):
                            """
                            Client side counter metrics
                            
                            .. attribute:: bytes
                            
                            	Number of bytes sent by the client
                            	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Client.Counter.Bytes>`
                            
                            .. attribute:: packets
                            
                            	Number of packets sent by the client
                            	**type**\:  :py:class:`Packets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Client.Counter.Packets>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Client.Counter, self).__init__()

                                self.yang_name = "counter"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Collect.Connection.Client.Counter.Bytes)), ("packets", ("packets", Native.Flow.Record.Collect.Connection.Client.Counter.Packets))])
                                self._leafs = OrderedDict()

                                self.bytes = Native.Flow.Record.Collect.Connection.Client.Counter.Bytes()
                                self.bytes.parent = self
                                self._children_name_map["bytes"] = "bytes"

                                self.packets = Native.Flow.Record.Collect.Connection.Client.Counter.Packets()
                                self.packets.parent = self
                                self._children_name_map["packets"] = "packets"
                                self._segment_path = lambda: "counter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Client.Counter, [], name, value)


                            class Bytes(Entity):
                                """
                                Number of bytes sent by the client
                                
                                .. attribute:: long
                                
                                	64 bits counter
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: network
                                
                                	Number of bytes sent by the client
                                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Client.Counter.Bytes.Network>`
                                
                                .. attribute:: retransmitted
                                
                                	Number of bytes retransmitted by the client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transport
                                
                                	Number of bytes sent by the client
                                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Client.Counter.Bytes.Transport>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Connection.Client.Counter.Bytes, self).__init__()

                                    self.yang_name = "bytes"
                                    self.yang_parent_name = "counter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("network", ("network", Native.Flow.Record.Collect.Connection.Client.Counter.Bytes.Network)), ("transport", ("transport", Native.Flow.Record.Collect.Connection.Client.Counter.Bytes.Transport))])
                                    self._leafs = OrderedDict([
                                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ('retransmitted', (YLeaf(YType.empty, 'retransmitted'), ['Empty'])),
                                    ])
                                    self.long = None
                                    self.retransmitted = None

                                    self.network = Native.Flow.Record.Collect.Connection.Client.Counter.Bytes.Network()
                                    self.network.parent = self
                                    self._children_name_map["network"] = "network"

                                    self.transport = Native.Flow.Record.Collect.Connection.Client.Counter.Bytes.Transport()
                                    self.transport.parent = self
                                    self._children_name_map["transport"] = "transport"
                                    self._segment_path = lambda: "bytes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Connection.Client.Counter.Bytes, ['long', 'retransmitted'], name, value)


                                class Network(Entity):
                                    """
                                    Number of bytes sent by the client
                                    
                                    .. attribute:: long
                                    
                                    	Total number of bytes transmitted by the client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Collect.Connection.Client.Counter.Bytes.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "bytes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self._segment_path = lambda: "network"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Collect.Connection.Client.Counter.Bytes.Network, ['long'], name, value)


                                class Transport(Entity):
                                    """
                                    Number of bytes sent by the client
                                    
                                    .. attribute:: long
                                    
                                    	64 bit counter
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Collect.Connection.Client.Counter.Bytes.Transport, self).__init__()

                                        self.yang_name = "transport"
                                        self.yang_parent_name = "bytes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self._segment_path = lambda: "transport"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Collect.Connection.Client.Counter.Bytes.Transport, ['long'], name, value)


                            class Packets(Entity):
                                """
                                Number of packets sent by the client
                                
                                .. attribute:: long
                                
                                	64 bits counter
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: retransmitted
                                
                                	Number of packets retransmitted by the client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Connection.Client.Counter.Packets, self).__init__()

                                    self.yang_name = "packets"
                                    self.yang_parent_name = "counter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ('retransmitted', (YLeaf(YType.empty, 'retransmitted'), ['Empty'])),
                                    ])
                                    self.long = None
                                    self.retransmitted = None
                                    self._segment_path = lambda: "packets"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Connection.Client.Counter.Packets, ['long', 'retransmitted'], name, value)


                        class Ipv4(Entity):
                            """
                            Client side IPv4 metrics
                            
                            .. attribute:: address
                            
                            	IPv4 address of the flow initiator
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Client.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Client.Ipv4, ['address'], name, value)


                        class Ipv6(Entity):
                            """
                            Client side IPv6 metrics
                            
                            .. attribute:: address
                            
                            	IPv6 address of the flow initiator
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Client.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Client.Ipv6, ['address'], name, value)


                        class Transport(Entity):
                            """
                            Client side transport metrics
                            
                            .. attribute:: port
                            
                            	Transport port of the flow initiator
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Client.Transport, self).__init__()

                                self.yang_name = "transport"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port', (YLeaf(YType.empty, 'port'), ['Empty'])),
                                ])
                                self.port = None
                                self._segment_path = lambda: "transport"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Client.Transport, ['port'], name, value)


                    class Delay(Entity):
                        """
                        Connection delay metrics
                        
                        .. attribute:: all
                        
                        	All non\-key client metrics
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: application
                        
                        	Application time metrics
                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Application>`
                        
                        .. attribute:: network
                        
                        	Network time metrics
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Network>`
                        
                        .. attribute:: response
                        
                        	Response time metrics
                        	**type**\:  :py:class:`Response <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Response>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Connection.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "connection"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("application", ("application", Native.Flow.Record.Collect.Connection.Delay.Application)), ("network", ("network", Native.Flow.Record.Collect.Connection.Delay.Network)), ("response", ("response", Native.Flow.Record.Collect.Connection.Delay.Response))])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                            ])
                            self.all = None

                            self.application = Native.Flow.Record.Collect.Connection.Delay.Application()
                            self.application.parent = self
                            self._children_name_map["application"] = "application"

                            self.network = Native.Flow.Record.Collect.Connection.Delay.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.response = Native.Flow.Record.Collect.Connection.Delay.Response()
                            self.response.parent = self
                            self._children_name_map["response"] = "response"
                            self._segment_path = lambda: "delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay, ['all'], name, value)


                        class Application(Entity):
                            """
                            Application time metrics
                            
                            .. attribute:: max
                            
                            	Maximum application response time
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: min
                            
                            	Minimum application response time
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sum
                            
                            	Total application response time
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Delay.Application, self).__init__()

                                self.yang_name = "application"
                                self.yang_parent_name = "delay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                    ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                ])
                                self.max = None
                                self.min = None
                                self.sum = None
                                self._segment_path = lambda: "application"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Application, ['max', 'min', 'sum'], name, value)


                        class Network(Entity):
                            """
                            Network time metrics
                            
                            .. attribute:: client_to_server
                            
                            	RTT between the client and the server
                            	**type**\:  :py:class:`ClientToServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Network.ClientToServer>`
                            
                            .. attribute:: long_lived
                            
                            	Long\-lived network delay metrics
                            	**type**\:  :py:class:`LongLived <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Network.LongLived>`
                            
                            .. attribute:: to_client
                            
                            	RTT from observation point to the client
                            	**type**\:  :py:class:`ToClient <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Network.ToClient>`
                            
                            .. attribute:: to_server
                            
                            	RTT from observation point to the server
                            	**type**\:  :py:class:`ToServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Network.ToServer>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Delay.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "delay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("client-to-server", ("client_to_server", Native.Flow.Record.Collect.Connection.Delay.Network.ClientToServer)), ("long-lived", ("long_lived", Native.Flow.Record.Collect.Connection.Delay.Network.LongLived)), ("to-client", ("to_client", Native.Flow.Record.Collect.Connection.Delay.Network.ToClient)), ("to-server", ("to_server", Native.Flow.Record.Collect.Connection.Delay.Network.ToServer))])
                                self._leafs = OrderedDict()

                                self.client_to_server = Native.Flow.Record.Collect.Connection.Delay.Network.ClientToServer()
                                self.client_to_server.parent = self
                                self._children_name_map["client_to_server"] = "client-to-server"

                                self.long_lived = Native.Flow.Record.Collect.Connection.Delay.Network.LongLived()
                                self.long_lived.parent = self
                                self._children_name_map["long_lived"] = "long-lived"

                                self.to_client = Native.Flow.Record.Collect.Connection.Delay.Network.ToClient()
                                self.to_client.parent = self
                                self._children_name_map["to_client"] = "to-client"

                                self.to_server = Native.Flow.Record.Collect.Connection.Delay.Network.ToServer()
                                self.to_server.parent = self
                                self._children_name_map["to_server"] = "to-server"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Network, [], name, value)


                            class ClientToServer(Entity):
                                """
                                RTT between the client and the server
                                
                                .. attribute:: max
                                
                                	Maximum network time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Minimum network time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: num_samples
                                
                                	The number of CSND samples
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sum
                                
                                	Total network time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Connection.Delay.Network.ClientToServer, self).__init__()

                                    self.yang_name = "client-to-server"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ('num_samples', (YLeaf(YType.empty, 'num-samples'), ['Empty'])),
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self.num_samples = None
                                    self.sum = None
                                    self._segment_path = lambda: "client-to-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Network.ClientToServer, ['max', 'min', 'num_samples', 'sum'], name, value)


                            class LongLived(Entity):
                                """
                                Long\-lived network delay metrics
                                
                                .. attribute:: client_to_serve
                                
                                	Long\-lived network delay client\-to\-server metrics
                                	**type**\:  :py:class:`ClientToServe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ClientToServe>`
                                
                                .. attribute:: to_client
                                
                                	Long\-lived network delay to\-client metrics
                                	**type**\:  :py:class:`ToClient <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ToClient>`
                                
                                .. attribute:: to_serve
                                
                                	Long\-lived network delay to\-server metrics
                                	**type**\:  :py:class:`ToServe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ToServe>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Connection.Delay.Network.LongLived, self).__init__()

                                    self.yang_name = "long-lived"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("client-to-serve", ("client_to_serve", Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ClientToServe)), ("to-client", ("to_client", Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ToClient)), ("to-serve", ("to_serve", Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ToServe))])
                                    self._leafs = OrderedDict()

                                    self.client_to_serve = Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ClientToServe()
                                    self.client_to_serve.parent = self
                                    self._children_name_map["client_to_serve"] = "client-to-serve"

                                    self.to_client = Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ToClient()
                                    self.to_client.parent = self
                                    self._children_name_map["to_client"] = "to-client"

                                    self.to_serve = Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ToServe()
                                    self.to_serve.parent = self
                                    self._children_name_map["to_serve"] = "to-serve"
                                    self._segment_path = lambda: "long-lived"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Network.LongLived, [], name, value)


                                class ClientToServe(Entity):
                                    """
                                    Long\-lived network delay client\-to\-server metrics
                                    
                                    .. attribute:: sum
                                    
                                    	Total network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ClientToServe, self).__init__()

                                        self.yang_name = "client-to-serve"
                                        self.yang_parent_name = "long-lived"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.sum = None
                                        self._segment_path = lambda: "client-to-serve"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ClientToServe, ['sum'], name, value)


                                class ToClient(Entity):
                                    """
                                    Long\-lived network delay to\-client metrics
                                    
                                    .. attribute:: sum
                                    
                                    	Total network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ToClient, self).__init__()

                                        self.yang_name = "to-client"
                                        self.yang_parent_name = "long-lived"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.sum = None
                                        self._segment_path = lambda: "to-client"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ToClient, ['sum'], name, value)


                                class ToServe(Entity):
                                    """
                                    Long\-lived network delay to\-server metrics
                                    
                                    .. attribute:: sum
                                    
                                    	Total network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ToServe, self).__init__()

                                        self.yang_name = "to-serve"
                                        self.yang_parent_name = "long-lived"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.sum = None
                                        self._segment_path = lambda: "to-serve"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Network.LongLived.ToServe, ['sum'], name, value)


                            class ToClient(Entity):
                                """
                                RTT from observation point to the client
                                
                                .. attribute:: max
                                
                                	Maximum network time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Minimum network time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: num_samples
                                
                                	The number of CND samples
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sum
                                
                                	Total network time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Connection.Delay.Network.ToClient, self).__init__()

                                    self.yang_name = "to-client"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ('num_samples', (YLeaf(YType.empty, 'num-samples'), ['Empty'])),
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self.num_samples = None
                                    self.sum = None
                                    self._segment_path = lambda: "to-client"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Network.ToClient, ['max', 'min', 'num_samples', 'sum'], name, value)


                            class ToServer(Entity):
                                """
                                RTT from observation point to the server
                                
                                .. attribute:: max
                                
                                	Maximum network time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Minimum network time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: num_samples
                                
                                	The number of SND samples
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sum
                                
                                	Total network time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Connection.Delay.Network.ToServer, self).__init__()

                                    self.yang_name = "to-server"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ('num_samples', (YLeaf(YType.empty, 'num-samples'), ['Empty'])),
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self.num_samples = None
                                    self.sum = None
                                    self._segment_path = lambda: "to-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Network.ToServer, ['max', 'min', 'num_samples', 'sum'], name, value)


                        class Response(Entity):
                            """
                            Response time metrics
                            
                            .. attribute:: client_to_server
                            
                            	Response time as seen by the client
                            	**type**\:  :py:class:`ClientToServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Response.ClientToServer>`
                            
                            .. attribute:: to_server
                            
                            	Response time as seen from observation point
                            	**type**\:  :py:class:`ToServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Response.ToServer>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Delay.Response, self).__init__()

                                self.yang_name = "response"
                                self.yang_parent_name = "delay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("client-to-server", ("client_to_server", Native.Flow.Record.Collect.Connection.Delay.Response.ClientToServer)), ("to-server", ("to_server", Native.Flow.Record.Collect.Connection.Delay.Response.ToServer))])
                                self._leafs = OrderedDict()

                                self.client_to_server = Native.Flow.Record.Collect.Connection.Delay.Response.ClientToServer()
                                self.client_to_server.parent = self
                                self._children_name_map["client_to_server"] = "client-to-server"

                                self.to_server = Native.Flow.Record.Collect.Connection.Delay.Response.ToServer()
                                self.to_server.parent = self
                                self._children_name_map["to_server"] = "to-server"
                                self._segment_path = lambda: "response"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Response, [], name, value)


                            class ClientToServer(Entity):
                                """
                                Response time as seen by the client
                                
                                .. attribute:: max
                                
                                	Maximum response time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Minimum response time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sum
                                
                                	Total response time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Connection.Delay.Response.ClientToServer, self).__init__()

                                    self.yang_name = "client-to-server"
                                    self.yang_parent_name = "response"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self.sum = None
                                    self._segment_path = lambda: "client-to-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Response.ClientToServer, ['max', 'min', 'sum'], name, value)


                            class ToServer(Entity):
                                """
                                Response time as seen from observation point
                                
                                .. attribute:: histogram
                                
                                	Histogram for response time
                                	**type**\:  :py:class:`Histogram <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Delay.Response.ToServer.Histogram>`
                                
                                .. attribute:: max
                                
                                	Maximum response time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Minimum response time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sum
                                
                                	Total response time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Connection.Delay.Response.ToServer, self).__init__()

                                    self.yang_name = "to-server"
                                    self.yang_parent_name = "response"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('histogram', (YLeaf(YType.enumeration, 'histogram'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Flow.Record.Collect.Connection.Delay.Response.ToServer.Histogram')])),
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.histogram = None
                                    self.max = None
                                    self.min = None
                                    self.sum = None
                                    self._segment_path = lambda: "to-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Connection.Delay.Response.ToServer, ['histogram', 'max', 'min', 'sum'], name, value)

                                class Histogram(Enum):
                                    """
                                    Histogram (Enum Class)

                                    Histogram for response time

                                    .. data:: all = 0

                                    .. data:: bucket1 = 1

                                    .. data:: bucket2 = 2

                                    .. data:: bucket3 = 3

                                    .. data:: bucket4 = 4

                                    .. data:: bucket5 = 5

                                    .. data:: bucket6 = 6

                                    .. data:: bucket7 = 7

                                    .. data:: late = 8

                                    """

                                    all = Enum.YLeaf(0, "all")

                                    bucket1 = Enum.YLeaf(1, "bucket1")

                                    bucket2 = Enum.YLeaf(2, "bucket2")

                                    bucket3 = Enum.YLeaf(3, "bucket3")

                                    bucket4 = Enum.YLeaf(4, "bucket4")

                                    bucket5 = Enum.YLeaf(5, "bucket5")

                                    bucket6 = Enum.YLeaf(6, "bucket6")

                                    bucket7 = Enum.YLeaf(7, "bucket7")

                                    late = Enum.YLeaf(8, "late")



                    class Server(Entity):
                        """
                        Server side (flow responder) related metrics
                        
                        .. attribute:: all
                        
                        	All non\-key server metrics
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: counter
                        
                        	Server side counter metrics
                        	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Server.Counter>`
                        
                        .. attribute:: ipv4
                        
                        	Server side IPv4 metrics
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Server.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	Server side IPv6 metrics
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Server.Ipv6>`
                        
                        .. attribute:: transport
                        
                        	Server side transport metrics
                        	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Server.Transport>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Connection.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "connection"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Collect.Connection.Server.Counter)), ("ipv4", ("ipv4", Native.Flow.Record.Collect.Connection.Server.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Collect.Connection.Server.Ipv6)), ("transport", ("transport", Native.Flow.Record.Collect.Connection.Server.Transport))])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                            ])
                            self.all = None

                            self.counter = Native.Flow.Record.Collect.Connection.Server.Counter()
                            self.counter.parent = self
                            self._children_name_map["counter"] = "counter"

                            self.ipv4 = Native.Flow.Record.Collect.Connection.Server.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = Native.Flow.Record.Collect.Connection.Server.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.transport = Native.Flow.Record.Collect.Connection.Server.Transport()
                            self.transport.parent = self
                            self._children_name_map["transport"] = "transport"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Connection.Server, ['all'], name, value)


                        class Counter(Entity):
                            """
                            Server side counter metrics
                            
                            .. attribute:: bytes
                            
                            	Number of bytes sent by the server
                            	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Server.Counter.Bytes>`
                            
                            .. attribute:: packets
                            
                            	Number of packets sent by the server
                            	**type**\:  :py:class:`Packets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Server.Counter.Packets>`
                            
                            .. attribute:: responses
                            
                            	Number of responses sent by the server
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Server.Counter, self).__init__()

                                self.yang_name = "counter"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Collect.Connection.Server.Counter.Bytes)), ("packets", ("packets", Native.Flow.Record.Collect.Connection.Server.Counter.Packets))])
                                self._leafs = OrderedDict([
                                    ('responses', (YLeaf(YType.empty, 'responses'), ['Empty'])),
                                ])
                                self.responses = None

                                self.bytes = Native.Flow.Record.Collect.Connection.Server.Counter.Bytes()
                                self.bytes.parent = self
                                self._children_name_map["bytes"] = "bytes"

                                self.packets = Native.Flow.Record.Collect.Connection.Server.Counter.Packets()
                                self.packets.parent = self
                                self._children_name_map["packets"] = "packets"
                                self._segment_path = lambda: "counter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Server.Counter, ['responses'], name, value)


                            class Bytes(Entity):
                                """
                                Number of bytes sent by the server
                                
                                .. attribute:: long
                                
                                	64 bits counter
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: network
                                
                                	Number of bytes sent by the server
                                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Server.Counter.Bytes.Network>`
                                
                                .. attribute:: retransmitted
                                
                                	Number of bytes retransmitted by the server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transport
                                
                                	Number of bytes sent by the server
                                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Server.Counter.Bytes.Transport>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Connection.Server.Counter.Bytes, self).__init__()

                                    self.yang_name = "bytes"
                                    self.yang_parent_name = "counter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("network", ("network", Native.Flow.Record.Collect.Connection.Server.Counter.Bytes.Network)), ("transport", ("transport", Native.Flow.Record.Collect.Connection.Server.Counter.Bytes.Transport))])
                                    self._leafs = OrderedDict([
                                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ('retransmitted', (YLeaf(YType.empty, 'retransmitted'), ['Empty'])),
                                    ])
                                    self.long = None
                                    self.retransmitted = None

                                    self.network = Native.Flow.Record.Collect.Connection.Server.Counter.Bytes.Network()
                                    self.network.parent = self
                                    self._children_name_map["network"] = "network"

                                    self.transport = Native.Flow.Record.Collect.Connection.Server.Counter.Bytes.Transport()
                                    self.transport.parent = self
                                    self._children_name_map["transport"] = "transport"
                                    self._segment_path = lambda: "bytes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Connection.Server.Counter.Bytes, ['long', 'retransmitted'], name, value)


                                class Network(Entity):
                                    """
                                    Number of bytes sent by the server
                                    
                                    .. attribute:: long
                                    
                                    	Total number of bytes transmitted by the server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Collect.Connection.Server.Counter.Bytes.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "bytes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self._segment_path = lambda: "network"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Collect.Connection.Server.Counter.Bytes.Network, ['long'], name, value)


                                class Transport(Entity):
                                    """
                                    Number of bytes sent by the server
                                    
                                    .. attribute:: long
                                    
                                    	64 bit counter
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Collect.Connection.Server.Counter.Bytes.Transport, self).__init__()

                                        self.yang_name = "transport"
                                        self.yang_parent_name = "bytes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self._segment_path = lambda: "transport"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Collect.Connection.Server.Counter.Bytes.Transport, ['long'], name, value)


                            class Packets(Entity):
                                """
                                Number of packets sent by the server
                                
                                .. attribute:: long
                                
                                	64 bits counter
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: retransmitted
                                
                                	Number of packets retransmitted by the server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Connection.Server.Counter.Packets, self).__init__()

                                    self.yang_name = "packets"
                                    self.yang_parent_name = "counter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ('retransmitted', (YLeaf(YType.empty, 'retransmitted'), ['Empty'])),
                                    ])
                                    self.long = None
                                    self.retransmitted = None
                                    self._segment_path = lambda: "packets"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Connection.Server.Counter.Packets, ['long', 'retransmitted'], name, value)


                        class Ipv4(Entity):
                            """
                            Server side IPv4 metrics
                            
                            .. attribute:: address
                            
                            	IPv4 address of the flow responder
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Server.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Server.Ipv4, ['address'], name, value)


                        class Ipv6(Entity):
                            """
                            Server side IPv6 metrics
                            
                            .. attribute:: address
                            
                            	IPv6 address of the flow responder
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Server.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Server.Ipv6, ['address'], name, value)


                        class Transport(Entity):
                            """
                            Server side transport metrics
                            
                            .. attribute:: port
                            
                            	Transport port of the flow responder
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Server.Transport, self).__init__()

                                self.yang_name = "transport"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port', (YLeaf(YType.empty, 'port'), ['Empty'])),
                                ])
                                self.port = None
                                self._segment_path = lambda: "transport"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Server.Transport, ['port'], name, value)


                    class Transaction(Entity):
                        """
                        Transaction related metrics
                        
                        .. attribute:: all
                        
                        	All non\-key transaction metrics
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: counter
                        
                        	Transaction counter metrics
                        	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Transaction.Counter>`
                        
                        .. attribute:: duration
                        
                        	Transaction duration metrics
                        	**type**\:  :py:class:`Duration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Connection.Transaction.Duration>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Connection.Transaction, self).__init__()

                            self.yang_name = "transaction"
                            self.yang_parent_name = "connection"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Collect.Connection.Transaction.Counter)), ("duration", ("duration", Native.Flow.Record.Collect.Connection.Transaction.Duration))])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                            ])
                            self.all = None

                            self.counter = Native.Flow.Record.Collect.Connection.Transaction.Counter()
                            self.counter.parent = self
                            self._children_name_map["counter"] = "counter"

                            self.duration = Native.Flow.Record.Collect.Connection.Transaction.Duration()
                            self.duration.parent = self
                            self._children_name_map["duration"] = "duration"
                            self._segment_path = lambda: "transaction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Connection.Transaction, ['all'], name, value)


                        class Counter(Entity):
                            """
                            Transaction counter metrics
                            
                            .. attribute:: complete
                            
                            	Number of completed transactions
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Transaction.Counter, self).__init__()

                                self.yang_name = "counter"
                                self.yang_parent_name = "transaction"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('complete', (YLeaf(YType.empty, 'complete'), ['Empty'])),
                                ])
                                self.complete = None
                                self._segment_path = lambda: "counter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Transaction.Counter, ['complete'], name, value)


                        class Duration(Entity):
                            """
                            Transaction duration metrics
                            
                            .. attribute:: max
                            
                            	Maximum transaction time
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: min
                            
                            	Minimum transaction time
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sum
                            
                            	Total transaction time
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Connection.Transaction.Duration, self).__init__()

                                self.yang_name = "duration"
                                self.yang_parent_name = "transaction"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                    ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                ])
                                self.max = None
                                self.min = None
                                self.sum = None
                                self._segment_path = lambda: "duration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Connection.Transaction.Duration, ['max', 'min', 'sum'], name, value)


                class Counter(Entity):
                    """
                    Counter fields
                    
                    .. attribute:: bytes
                    
                    	Total number of bytes
                    	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Counter.Bytes>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flows
                    
                    	Total number of flows
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: packets
                    
                    	Total number of packets
                    	**type**\:  :py:class:`Packets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Counter.Packets>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Counter, self).__init__()

                        self.yang_name = "counter"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Collect.Counter.Bytes)), ("packets", ("packets", Native.Flow.Record.Collect.Counter.Packets))])
                        self._leafs = OrderedDict([
                            ('flows', (YLeaf(YType.empty, 'flows'), ['Empty'])),
                        ])
                        self.flows = None

                        self.bytes = None
                        self._children_name_map["bytes"] = "bytes"

                        self.packets = None
                        self._children_name_map["packets"] = "packets"
                        self._segment_path = lambda: "counter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Counter, ['flows'], name, value)


                    class Bytes(Entity):
                        """
                        Total number of bytes
                        
                        .. attribute:: long
                        
                        	Total number of bytes (64 bit counter)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rate
                        
                        	Byte rate for the flow
                        	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Counter.Bytes.Rate>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: squared
                        
                        	Total of the square of the number of bytes
                        	**type**\:  :py:class:`Squared <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Counter.Bytes.Squared>`
                        
                        .. attribute:: layer2
                        
                        	Total number of layer 2 bytes
                        	**type**\:  :py:class:`Layer2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Counter.Bytes.Layer2>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Counter.Bytes, self).__init__()

                            self.yang_name = "bytes"
                            self.yang_parent_name = "counter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rate", ("rate", Native.Flow.Record.Collect.Counter.Bytes.Rate)), ("squared", ("squared", Native.Flow.Record.Collect.Counter.Bytes.Squared)), ("layer2", ("layer2", Native.Flow.Record.Collect.Counter.Bytes.Layer2))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                            ])
                            self.long = None

                            self.rate = None
                            self._children_name_map["rate"] = "rate"

                            self.squared = Native.Flow.Record.Collect.Counter.Bytes.Squared()
                            self.squared.parent = self
                            self._children_name_map["squared"] = "squared"

                            self.layer2 = Native.Flow.Record.Collect.Counter.Bytes.Layer2()
                            self.layer2.parent = self
                            self._children_name_map["layer2"] = "layer2"
                            self._segment_path = lambda: "bytes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Counter.Bytes, ['long'], name, value)


                        class Rate(Entity):
                            """
                            Byte rate for the flow
                            
                            .. attribute:: per_flow
                            
                            	Average byte rate for the flow
                            	**type**\:  :py:class:`PerFlow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Counter.Bytes.Rate.PerFlow>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Counter.Bytes.Rate, self).__init__()

                                self.yang_name = "rate"
                                self.yang_parent_name = "bytes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("per-flow", ("per_flow", Native.Flow.Record.Collect.Counter.Bytes.Rate.PerFlow))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.per_flow = None
                                self._children_name_map["per_flow"] = "per-flow"
                                self._segment_path = lambda: "rate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Counter.Bytes.Rate, [], name, value)


                            class PerFlow(Entity):
                                """
                                Average byte rate for the flow
                                
                                .. attribute:: max
                                
                                	Maximum byte rate among the aggregated flows
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Minimum byte rate among the aggregated flows
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Counter.Bytes.Rate.PerFlow, self).__init__()

                                    self.yang_name = "per-flow"
                                    self.yang_parent_name = "rate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self._segment_path = lambda: "per-flow"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Counter.Bytes.Rate.PerFlow, ['max', 'min'], name, value)


                        class Squared(Entity):
                            """
                            Total of the square of the number of bytes
                            
                            .. attribute:: long
                            
                            	Total of the square of the packet length in bytes (64 bit counter)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Counter.Bytes.Squared, self).__init__()

                                self.yang_name = "squared"
                                self.yang_parent_name = "bytes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                ])
                                self.long = None
                                self._segment_path = lambda: "squared"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Counter.Bytes.Squared, ['long'], name, value)


                        class Layer2(Entity):
                            """
                            Total number of layer 2 bytes
                            
                            .. attribute:: long
                            
                            	Total number of layer 2 bytes (64 bit counter)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Counter.Bytes.Layer2, self).__init__()

                                self.yang_name = "layer2"
                                self.yang_parent_name = "bytes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                ])
                                self.long = None
                                self._segment_path = lambda: "layer2"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Counter.Bytes.Layer2, ['long'], name, value)


                    class Packets(Entity):
                        """
                        Total number of packets
                        
                        .. attribute:: dropped
                        
                        	Dropped packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: long
                        
                        	Total number of packets (64 bit counter)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rate
                        
                        	Packet rate for the flow
                        	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Counter.Packets.Rate>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Counter.Packets, self).__init__()

                            self.yang_name = "packets"
                            self.yang_parent_name = "counter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rate", ("rate", Native.Flow.Record.Collect.Counter.Packets.Rate))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('dropped', (YLeaf(YType.empty, 'dropped'), ['Empty'])),
                                ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                            ])
                            self.dropped = None
                            self.long = None

                            self.rate = None
                            self._children_name_map["rate"] = "rate"
                            self._segment_path = lambda: "packets"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Counter.Packets, ['dropped', 'long'], name, value)


                        class Rate(Entity):
                            """
                            Packet rate for the flow
                            
                            .. attribute:: per_flow
                            
                            	Average packet rate for aggregated flows
                            	**type**\:  :py:class:`PerFlow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Counter.Packets.Rate.PerFlow>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Counter.Packets.Rate, self).__init__()

                                self.yang_name = "rate"
                                self.yang_parent_name = "packets"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("per-flow", ("per_flow", Native.Flow.Record.Collect.Counter.Packets.Rate.PerFlow))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.per_flow = None
                                self._children_name_map["per_flow"] = "per-flow"
                                self._segment_path = lambda: "rate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Counter.Packets.Rate, [], name, value)


                            class PerFlow(Entity):
                                """
                                Average packet rate for aggregated flows
                                
                                .. attribute:: max
                                
                                	Maximum packet rate in the aggregated flows
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Minimum packet rate in the aggregated flows
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Counter.Packets.Rate.PerFlow, self).__init__()

                                    self.yang_name = "per-flow"
                                    self.yang_parent_name = "rate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self._segment_path = lambda: "per-flow"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Counter.Packets.Rate.PerFlow, ['max', 'min'], name, value)


                class Datalink(Entity):
                    """
                    Datalink (layer2) fields
                    
                    .. attribute:: destination_vlan_id
                    
                    	ID of the VLAN that the packet is going to
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dot1q
                    
                    	dot1q field
                    	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Datalink.Dot1q>`
                    
                    .. attribute:: ethertype
                    
                    	The Ethertype of the packet
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vlan
                    
                    	The VLAN the packet is on
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Datalink.Vlan>`
                    
                    .. attribute:: mac
                    
                    	MAC fields
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Datalink.Mac>`
                    
                    .. attribute:: source_vlan_id
                    
                    	ID of the VLAN that the packet came from
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Datalink, self).__init__()

                        self.yang_name = "datalink"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dot1q", ("dot1q", Native.Flow.Record.Collect.Datalink.Dot1q)), ("mac", ("mac", Native.Flow.Record.Collect.Datalink.Mac))])
                        self._leafs = OrderedDict([
                            ('destination_vlan_id', (YLeaf(YType.empty, 'destination-vlan-id'), ['Empty'])),
                            ('ethertype', (YLeaf(YType.empty, 'ethertype'), ['Empty'])),
                            ('vlan', (YLeaf(YType.enumeration, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Flow.Record.Collect.Datalink.Vlan')])),
                            ('source_vlan_id', (YLeaf(YType.empty, 'source-vlan-id'), ['Empty'])),
                        ])
                        self.destination_vlan_id = None
                        self.ethertype = None
                        self.vlan = None
                        self.source_vlan_id = None

                        self.dot1q = Native.Flow.Record.Collect.Datalink.Dot1q()
                        self.dot1q.parent = self
                        self._children_name_map["dot1q"] = "dot1q"

                        self.mac = Native.Flow.Record.Collect.Datalink.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"
                        self._segment_path = lambda: "datalink"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Datalink, ['destination_vlan_id', 'ethertype', 'vlan', 'source_vlan_id'], name, value)

                    class Vlan(Enum):
                        """
                        Vlan (Enum Class)

                        The VLAN the packet is on

                        .. data:: input = 0

                        .. data:: output = 1

                        """

                        input = Enum.YLeaf(0, "input")

                        output = Enum.YLeaf(1, "output")



                    class Dot1q(Entity):
                        """
                        dot1q field
                        
                        .. attribute:: priority
                        
                        	The CoS field out of the dot1q header
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	The VLAN the packet is on
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Datalink.Dot1q.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Datalink.Dot1q, self).__init__()

                            self.yang_name = "dot1q"
                            self.yang_parent_name = "datalink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Flow.Record.Collect.Datalink.Dot1q.Vlan))])
                            self._leafs = OrderedDict([
                                ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                            ])
                            self.priority = None

                            self.vlan = Native.Flow.Record.Collect.Datalink.Dot1q.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "dot1q"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Datalink.Dot1q, ['priority'], name, value)


                        class Vlan(Entity):
                            """
                            The VLAN the packet is on
                            
                            .. attribute:: input
                            
                            	The VLAN the packet is on at input
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: output
                            
                            	The VLAN the packet is on at output
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Datalink.Dot1q.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "dot1q"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                    ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ])
                                self.input = None
                                self.output = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Datalink.Dot1q.Vlan, ['input', 'output'], name, value)


                    class Mac(Entity):
                        """
                        MAC fields
                        
                        .. attribute:: destination
                        
                        	destination MAC fields
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Datalink.Mac.Destination>`
                        
                        .. attribute:: source
                        
                        	source MAC fields
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Datalink.Mac.Source>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Datalink.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "datalink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Collect.Datalink.Mac.Destination)), ("source", ("source", Native.Flow.Record.Collect.Datalink.Mac.Source))])
                            self._leafs = OrderedDict()

                            self.destination = Native.Flow.Record.Collect.Datalink.Mac.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.source = Native.Flow.Record.Collect.Datalink.Mac.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Datalink.Mac, [], name, value)


                        class Destination(Entity):
                            """
                            destination MAC fields
                            
                            .. attribute:: address
                            
                            	Destination MAC address from packet
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Datalink.Mac.Destination.Address>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Datalink.Mac.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Collect.Datalink.Mac.Destination.Address))])
                                self._leafs = OrderedDict()

                                self.address = Native.Flow.Record.Collect.Datalink.Mac.Destination.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Datalink.Mac.Destination, [], name, value)


                            class Address(Entity):
                                """
                                Destination MAC address from packet
                                
                                .. attribute:: input
                                
                                	Destination MAC address from packet at input
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: output
                                
                                	Destination MAC address from packet at output
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Datalink.Mac.Destination.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                        ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                    ])
                                    self.input = None
                                    self.output = None
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Datalink.Mac.Destination.Address, ['input', 'output'], name, value)


                        class Source(Entity):
                            """
                            source MAC fields
                            
                            .. attribute:: address
                            
                            	Source MAC address from packet
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Datalink.Mac.Source.Address>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Datalink.Mac.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Collect.Datalink.Mac.Source.Address))])
                                self._leafs = OrderedDict()

                                self.address = Native.Flow.Record.Collect.Datalink.Mac.Source.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Datalink.Mac.Source, [], name, value)


                            class Address(Entity):
                                """
                                Source MAC address from packet
                                
                                .. attribute:: input
                                
                                	Source MAC address from packet at input
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: output
                                
                                	Source MAC address from packet at output
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Datalink.Mac.Source.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                        ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                    ])
                                    self.input = None
                                    self.output = None
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Datalink.Mac.Source.Address, ['input', 'output'], name, value)


                class Flow_(Entity):
                    """
                    Flow identifying fields
                    
                    .. attribute:: cts
                    
                    	Cisco Trusted Security fields
                    	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Flow_.Cts>`
                    
                    .. attribute:: direction
                    
                    	Direction the flow was monitored in
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: observation
                    
                    	Flow observation metrics
                    	**type**\:  :py:class:`Observation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Flow_.Observation>`
                    
                    .. attribute:: sampler
                    
                    	ID of the sampler
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: end_reason
                    
                    	The reason for a flow ending
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Flow_, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("cts", ("cts", Native.Flow.Record.Collect.Flow_.Cts)), ("observation", ("observation", Native.Flow.Record.Collect.Flow_.Observation))])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.empty, 'direction'), ['Empty'])),
                            ('sampler', (YLeaf(YType.empty, 'sampler'), ['Empty'])),
                            ('end_reason', (YLeaf(YType.empty, 'end-reason'), ['Empty'])),
                        ])
                        self.direction = None
                        self.sampler = None
                        self.end_reason = None

                        self.cts = Native.Flow.Record.Collect.Flow_.Cts()
                        self.cts.parent = self
                        self._children_name_map["cts"] = "cts"

                        self.observation = Native.Flow.Record.Collect.Flow_.Observation()
                        self.observation.parent = self
                        self._children_name_map["observation"] = "observation"
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Flow_, ['direction', 'sampler', 'end_reason'], name, value)


                    class Cts(Entity):
                        """
                        Cisco Trusted Security fields
                        
                        .. attribute:: destination
                        
                        	Cisco Trusted Security destination fields
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Flow_.Cts.Destination>`
                        
                        .. attribute:: source
                        
                        	Cisco Trusted Security source fields
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Flow_.Cts.Source>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Flow_.Cts, self).__init__()

                            self.yang_name = "cts"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Collect.Flow_.Cts.Destination)), ("source", ("source", Native.Flow.Record.Collect.Flow_.Cts.Source))])
                            self._leafs = OrderedDict()

                            self.destination = Native.Flow.Record.Collect.Flow_.Cts.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.source = Native.Flow.Record.Collect.Flow_.Cts.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "cts"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Flow_.Cts, [], name, value)


                        class Destination(Entity):
                            """
                            Cisco Trusted Security destination fields
                            
                            .. attribute:: group_tag
                            
                            	destination group\-tag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Flow_.Cts.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "cts"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group_tag', (YLeaf(YType.empty, 'group-tag'), ['Empty'])),
                                ])
                                self.group_tag = None
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Flow_.Cts.Destination, ['group_tag'], name, value)


                        class Source(Entity):
                            """
                            Cisco Trusted Security source fields
                            
                            .. attribute:: group_tag
                            
                            	source group\-tag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Flow_.Cts.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "cts"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group_tag', (YLeaf(YType.empty, 'group-tag'), ['Empty'])),
                                ])
                                self.group_tag = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Flow_.Cts.Source, ['group_tag'], name, value)


                    class Observation(Entity):
                        """
                        Flow observation metrics
                        
                        .. attribute:: point
                        
                        	Observation point ID
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Flow_.Observation, self).__init__()

                            self.yang_name = "observation"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('point', (YLeaf(YType.empty, 'point'), ['Empty'])),
                            ])
                            self.point = None
                            self._segment_path = lambda: "observation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Flow_.Observation, ['point'], name, value)


                class Interface(Entity):
                    """
                    Interface fields
                    
                    .. attribute:: input
                    
                    	The input interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Interface.Input>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: output
                    
                    	The output interface
                    	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Interface.Output>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Flow.Record.Collect.Interface.Input)), ("output", ("output", Native.Flow.Record.Collect.Interface.Output))])
                        self._leafs = OrderedDict()

                        self.input = None
                        self._children_name_map["input"] = "input"

                        self.output = None
                        self._children_name_map["output"] = "output"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Interface, [], name, value)


                    class Input(Entity):
                        """
                        The input interface
                        
                        .. attribute:: snmp
                        
                        	SNMP Index of the input interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Interface.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('snmp', (YLeaf(YType.empty, 'snmp'), ['Empty'])),
                            ])
                            self.snmp = None
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Interface.Input, ['snmp'], name, value)


                    class Output(Entity):
                        """
                        The output interface
                        
                        .. attribute:: snmp
                        
                        	SNMP Index of the output interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Interface.Output, self).__init__()

                            self.yang_name = "output"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('snmp', (YLeaf(YType.empty, 'snmp'), ['Empty'])),
                            ])
                            self.snmp = None
                            self._segment_path = lambda: "output"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Interface.Output, ['snmp'], name, value)


                class Ipv4(Entity):
                    """
                    IPv4 fields
                    
                    .. attribute:: destination
                    
                    	IPv4 destination address based fields
                    	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Destination>`
                    
                    .. attribute:: dscp
                    
                    	IPv4 DSCP (part of TOS)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: fragmentation
                    
                    	IPv4 fragmentation fields
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Fragmentation>`
                    
                    .. attribute:: header_length
                    
                    	IPv4 header length (IHL in 32 bit words)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: id
                    
                    	IPv4 ID
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: length
                    
                    	IPv4 length fields
                    	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Length>`
                    
                    .. attribute:: option
                    
                    	IPv4 option fields
                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Option>`
                    
                    .. attribute:: precedence
                    
                    	IPv4 precedence (part of TOS)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: protocol
                    
                    	IPv4 protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: section
                    
                    	Part of the packet
                    	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Section>`
                    
                    .. attribute:: source
                    
                    	IPv4 source address based fields
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Source>`
                    
                    .. attribute:: tos
                    
                    	IPv4 type of service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: total_length
                    
                    	IPv4 total length
                    	**type**\:  :py:class:`TotalLength <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.TotalLength>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ttl
                    
                    	IPv4 TTL
                    	**type**\:  :py:class:`Ttl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Ttl>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: version
                    
                    	IP version from IPv4 header
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Collect.Ipv4.Destination)), ("fragmentation", ("fragmentation", Native.Flow.Record.Collect.Ipv4.Fragmentation)), ("length", ("length", Native.Flow.Record.Collect.Ipv4.Length)), ("option", ("option", Native.Flow.Record.Collect.Ipv4.Option)), ("section", ("section", Native.Flow.Record.Collect.Ipv4.Section)), ("source", ("source", Native.Flow.Record.Collect.Ipv4.Source)), ("total-length", ("total_length", Native.Flow.Record.Collect.Ipv4.TotalLength)), ("ttl", ("ttl", Native.Flow.Record.Collect.Ipv4.Ttl))])
                        self._leafs = OrderedDict([
                            ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ('header_length', (YLeaf(YType.empty, 'header-length'), ['Empty'])),
                            ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                            ('precedence', (YLeaf(YType.empty, 'precedence'), ['Empty'])),
                            ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                            ('tos', (YLeaf(YType.empty, 'tos'), ['Empty'])),
                            ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                        ])
                        self.dscp = None
                        self.header_length = None
                        self.id = None
                        self.precedence = None
                        self.protocol = None
                        self.tos = None
                        self.version = None

                        self.destination = Native.Flow.Record.Collect.Ipv4.Destination()
                        self.destination.parent = self
                        self._children_name_map["destination"] = "destination"

                        self.fragmentation = Native.Flow.Record.Collect.Ipv4.Fragmentation()
                        self.fragmentation.parent = self
                        self._children_name_map["fragmentation"] = "fragmentation"

                        self.length = Native.Flow.Record.Collect.Ipv4.Length()
                        self.length.parent = self
                        self._children_name_map["length"] = "length"

                        self.option = Native.Flow.Record.Collect.Ipv4.Option()
                        self.option.parent = self
                        self._children_name_map["option"] = "option"

                        self.section = Native.Flow.Record.Collect.Ipv4.Section()
                        self.section.parent = self
                        self._children_name_map["section"] = "section"

                        self.source = Native.Flow.Record.Collect.Ipv4.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"

                        self.total_length = None
                        self._children_name_map["total_length"] = "total-length"

                        self.ttl = None
                        self._children_name_map["ttl"] = "ttl"
                        self._segment_path = lambda: "ipv4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Ipv4, ['dscp', 'header_length', 'id', 'precedence', 'protocol', 'tos', 'version'], name, value)


                    class Destination(Entity):
                        """
                        IPv4 destination address based fields
                        
                        .. attribute:: address
                        
                        	IPv4 destination address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mask
                        
                        	IPv4 address mask for the IPv4 destination address
                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Destination.Mask>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix
                        
                        	IPv4 address prefix for the IPv4 destination address
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Destination.Prefix>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv4.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Collect.Ipv4.Destination.Mask)), ("prefix", ("prefix", Native.Flow.Record.Collect.Ipv4.Destination.Prefix))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                            ])
                            self.address = None

                            self.mask = None
                            self._children_name_map["mask"] = "mask"

                            self.prefix = None
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "destination"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Destination, ['address'], name, value)


                        class Mask(Entity):
                            """
                            IPv4 address mask for the IPv4 destination address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..32
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv4.Destination.Mask, self).__init__()

                                self.yang_name = "mask"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "mask"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Destination.Mask, ['minimum_mask'], name, value)


                        class Prefix(Entity):
                            """
                            IPv4 address prefix for the IPv4 destination address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..32
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv4.Destination.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Destination.Prefix, ['minimum_mask'], name, value)


                    class Fragmentation(Entity):
                        """
                        IPv4 fragmentation fields
                        
                        .. attribute:: flags
                        
                        	IPv4 fragmentation flags
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: offset
                        
                        	IPv4 fragmentation offset
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv4.Fragmentation, self).__init__()

                            self.yang_name = "fragmentation"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('flags', (YLeaf(YType.empty, 'flags'), ['Empty'])),
                                ('offset', (YLeaf(YType.empty, 'offset'), ['Empty'])),
                            ])
                            self.flags = None
                            self.offset = None
                            self._segment_path = lambda: "fragmentation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Fragmentation, ['flags', 'offset'], name, value)


                    class Length(Entity):
                        """
                        IPv4 length fields
                        
                        .. attribute:: header
                        
                        	Length of the IPv4 header in bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: payload
                        
                        	Length of the IPv4 payload in bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: total
                        
                        	Total length of the IPv4 header and payload in bytes
                        	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Length.Total>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv4.Length, self).__init__()

                            self.yang_name = "length"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("total", ("total", Native.Flow.Record.Collect.Ipv4.Length.Total))])
                            self._leafs = OrderedDict([
                                ('header', (YLeaf(YType.empty, 'header'), ['Empty'])),
                                ('payload', (YLeaf(YType.empty, 'payload'), ['Empty'])),
                            ])
                            self.header = None
                            self.payload = None

                            self.total = None
                            self._children_name_map["total"] = "total"
                            self._segment_path = lambda: "length"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Length, ['header', 'payload'], name, value)


                        class Total(Entity):
                            """
                            Total length of the IPv4 header and payload in bytes
                            
                            .. attribute:: maximum
                            
                            	Maximum total length in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	Minimum total length in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv4.Length.Total, self).__init__()

                                self.yang_name = "total"
                                self.yang_parent_name = "length"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self._segment_path = lambda: "total"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Length.Total, ['maximum', 'minimum'], name, value)


                    class Option(Entity):
                        """
                        IPv4 option fields
                        
                        .. attribute:: map
                        
                        	Bitmap of IPv4 options
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv4.Option, self).__init__()

                            self.yang_name = "option"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('map', (YLeaf(YType.empty, 'map'), ['Empty'])),
                            ])
                            self.map = None
                            self._segment_path = lambda: "option"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Option, ['map'], name, value)


                    class Section(Entity):
                        """
                        Part of the packet
                        
                        .. attribute:: header
                        
                        	Raw data starting at the IPv4 header
                        	**type**\:  :py:class:`Header <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Section.Header>`
                        
                        .. attribute:: payload
                        
                        	Raw data starting at the IPv4 payload
                        	**type**\:  :py:class:`Payload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Section.Payload>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv4.Section, self).__init__()

                            self.yang_name = "section"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("header", ("header", Native.Flow.Record.Collect.Ipv4.Section.Header)), ("payload", ("payload", Native.Flow.Record.Collect.Ipv4.Section.Payload))])
                            self._leafs = OrderedDict()

                            self.header = Native.Flow.Record.Collect.Ipv4.Section.Header()
                            self.header.parent = self
                            self._children_name_map["header"] = "header"

                            self.payload = Native.Flow.Record.Collect.Ipv4.Section.Payload()
                            self.payload.parent = self
                            self._children_name_map["payload"] = "payload"
                            self._segment_path = lambda: "section"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Section, [], name, value)


                        class Header(Entity):
                            """
                            Raw data starting at the IPv4 header
                            
                            .. attribute:: size
                            
                            	Specify the number of bytes to capture
                            	**type**\: int
                            
                            	**range:** 1..1200
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv4.Section.Header, self).__init__()

                                self.yang_name = "header"
                                self.yang_parent_name = "section"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                ])
                                self.size = None
                                self._segment_path = lambda: "header"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Section.Header, ['size'], name, value)


                        class Payload(Entity):
                            """
                            Raw data starting at the IPv4 payload
                            
                            .. attribute:: size
                            
                            	Specify the number of bytes to capture
                            	**type**\: int
                            
                            	**range:** 1..1200
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv4.Section.Payload, self).__init__()

                                self.yang_name = "payload"
                                self.yang_parent_name = "section"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                ])
                                self.size = None
                                self._segment_path = lambda: "payload"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Section.Payload, ['size'], name, value)


                    class Source(Entity):
                        """
                        IPv4 source address based fields
                        
                        .. attribute:: address
                        
                        	IPv4 source address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mask
                        
                        	IPv4 address mask for the IPv4 source address
                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Source.Mask>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix
                        
                        	IPv4 address prefix for the IPv4 source address
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv4.Source.Prefix>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv4.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Collect.Ipv4.Source.Mask)), ("prefix", ("prefix", Native.Flow.Record.Collect.Ipv4.Source.Prefix))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                            ])
                            self.address = None

                            self.mask = None
                            self._children_name_map["mask"] = "mask"

                            self.prefix = None
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Source, ['address'], name, value)


                        class Mask(Entity):
                            """
                            IPv4 address mask for the IPv4 source address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..32
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv4.Source.Mask, self).__init__()

                                self.yang_name = "mask"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "mask"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Source.Mask, ['minimum_mask'], name, value)


                        class Prefix(Entity):
                            """
                            IPv4 address prefix for the IPv4 source address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..32
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv4.Source.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Source.Prefix, ['minimum_mask'], name, value)


                    class TotalLength(Entity):
                        """
                        IPv4 total length
                        
                        .. attribute:: maximum
                        
                        	Largest value for IPv4 length seen in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: minimum
                        
                        	Smallest value for IPv4 length seen in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv4.TotalLength, self).__init__()

                            self.yang_name = "total-length"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                            ])
                            self.maximum = None
                            self.minimum = None
                            self._segment_path = lambda: "total-length"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv4.TotalLength, ['maximum', 'minimum'], name, value)


                    class Ttl(Entity):
                        """
                        IPv4 TTL
                        
                        .. attribute:: maximum
                        
                        	Largest value seen for TTL in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: minimum
                        
                        	Smallest value seen for TTL in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv4.Ttl, self).__init__()

                            self.yang_name = "ttl"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                            ])
                            self.maximum = None
                            self.minimum = None
                            self._segment_path = lambda: "ttl"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv4.Ttl, ['maximum', 'minimum'], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 fields
                    
                    .. attribute:: destination
                    
                    	IPv6 destination address based fields
                    	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Destination>`
                    
                    .. attribute:: dscp
                    
                    	IPv6 DSCP (part of Traffic Class)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: extension
                    
                    	IPv6 extension header fields
                    	**type**\:  :py:class:`Extension <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Extension>`
                    
                    .. attribute:: flow_label
                    
                    	IPv6 flow label
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: fragmentation
                    
                    	IPv6 fragmentation fields
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Fragmentation>`
                    
                    .. attribute:: hop_limit
                    
                    	IPv6 hop limit
                    	**type**\:  :py:class:`HopLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.HopLimit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: length
                    
                    	IPv6 length fields
                    	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Length>`
                    
                    .. attribute:: next_header
                    
                    	The value of the next\-header field in the IPv6 header
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: payload_length
                    
                    	Length of the IPv6 payload in bytes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: precedence
                    
                    	IPv6 precedence (part of Traffic Class)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: protocol
                    
                    	IPv6 payload protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: section
                    
                    	Part of the packet
                    	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Section>`
                    
                    .. attribute:: source
                    
                    	IPv6 source address based fields
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Source>`
                    
                    .. attribute:: traffic_class
                    
                    	IPv6 traffic class
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: version
                    
                    	IP version from IPv6 header
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Collect.Ipv6.Destination)), ("extension", ("extension", Native.Flow.Record.Collect.Ipv6.Extension)), ("fragmentation", ("fragmentation", Native.Flow.Record.Collect.Ipv6.Fragmentation)), ("hop-limit", ("hop_limit", Native.Flow.Record.Collect.Ipv6.HopLimit)), ("length", ("length", Native.Flow.Record.Collect.Ipv6.Length)), ("section", ("section", Native.Flow.Record.Collect.Ipv6.Section)), ("source", ("source", Native.Flow.Record.Collect.Ipv6.Source))])
                        self._leafs = OrderedDict([
                            ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ('flow_label', (YLeaf(YType.empty, 'flow-label'), ['Empty'])),
                            ('next_header', (YLeaf(YType.empty, 'next-header'), ['Empty'])),
                            ('payload_length', (YLeaf(YType.empty, 'payload-length'), ['Empty'])),
                            ('precedence', (YLeaf(YType.empty, 'precedence'), ['Empty'])),
                            ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                            ('traffic_class', (YLeaf(YType.empty, 'traffic-class'), ['Empty'])),
                            ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                        ])
                        self.dscp = None
                        self.flow_label = None
                        self.next_header = None
                        self.payload_length = None
                        self.precedence = None
                        self.protocol = None
                        self.traffic_class = None
                        self.version = None

                        self.destination = Native.Flow.Record.Collect.Ipv6.Destination()
                        self.destination.parent = self
                        self._children_name_map["destination"] = "destination"

                        self.extension = Native.Flow.Record.Collect.Ipv6.Extension()
                        self.extension.parent = self
                        self._children_name_map["extension"] = "extension"

                        self.fragmentation = Native.Flow.Record.Collect.Ipv6.Fragmentation()
                        self.fragmentation.parent = self
                        self._children_name_map["fragmentation"] = "fragmentation"

                        self.hop_limit = None
                        self._children_name_map["hop_limit"] = "hop-limit"

                        self.length = Native.Flow.Record.Collect.Ipv6.Length()
                        self.length.parent = self
                        self._children_name_map["length"] = "length"

                        self.section = Native.Flow.Record.Collect.Ipv6.Section()
                        self.section.parent = self
                        self._children_name_map["section"] = "section"

                        self.source = Native.Flow.Record.Collect.Ipv6.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Ipv6, ['dscp', 'flow_label', 'next_header', 'payload_length', 'precedence', 'protocol', 'traffic_class', 'version'], name, value)


                    class Destination(Entity):
                        """
                        IPv6 destination address based fields
                        
                        .. attribute:: address
                        
                        	IPv6 destination address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mask
                        
                        	IPv6 address mask for the IPv6 destination address
                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Destination.Mask>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix
                        
                        	IPv6 address prefix for the IPv6 destination address
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Destination.Prefix>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv6.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Collect.Ipv6.Destination.Mask)), ("prefix", ("prefix", Native.Flow.Record.Collect.Ipv6.Destination.Prefix))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                            ])
                            self.address = None

                            self.mask = None
                            self._children_name_map["mask"] = "mask"

                            self.prefix = None
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "destination"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Destination, ['address'], name, value)


                        class Mask(Entity):
                            """
                            IPv6 address mask for the IPv6 destination address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..128
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv6.Destination.Mask, self).__init__()

                                self.yang_name = "mask"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "mask"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Destination.Mask, ['minimum_mask'], name, value)


                        class Prefix(Entity):
                            """
                            IPv6 address prefix for the IPv6 destination address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..128
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv6.Destination.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Destination.Prefix, ['minimum_mask'], name, value)


                    class Extension(Entity):
                        """
                        IPv6 extension header fields
                        
                        .. attribute:: map
                        
                        	Bitmap of IPv6 extension headers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv6.Extension, self).__init__()

                            self.yang_name = "extension"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('map', (YLeaf(YType.empty, 'map'), ['Empty'])),
                            ])
                            self.map = None
                            self._segment_path = lambda: "extension"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Extension, ['map'], name, value)


                    class Fragmentation(Entity):
                        """
                        IPv6 fragmentation fields
                        
                        .. attribute:: flags
                        
                        	IPv6 fragmentation flags
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: id
                        
                        	IPv6 fragmentation ID
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: offset
                        
                        	IPv6 fragmentation offset
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv6.Fragmentation, self).__init__()

                            self.yang_name = "fragmentation"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('flags', (YLeaf(YType.empty, 'flags'), ['Empty'])),
                                ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                                ('offset', (YLeaf(YType.empty, 'offset'), ['Empty'])),
                            ])
                            self.flags = None
                            self.id = None
                            self.offset = None
                            self._segment_path = lambda: "fragmentation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Fragmentation, ['flags', 'id', 'offset'], name, value)


                    class HopLimit(Entity):
                        """
                        IPv6 hop limit
                        
                        .. attribute:: maximum
                        
                        	Largest value seen for hop\-limit in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: minimum
                        
                        	Smallest value seen for hop\-limit in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv6.HopLimit, self).__init__()

                            self.yang_name = "hop-limit"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                            ])
                            self.maximum = None
                            self.minimum = None
                            self._segment_path = lambda: "hop-limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv6.HopLimit, ['maximum', 'minimum'], name, value)


                    class Length(Entity):
                        """
                        IPv6 length fields
                        
                        .. attribute:: header
                        
                        	Length of the IPv6 header, not including any extension headers, in bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: payload
                        
                        	Length of the IPv6 payload, including any extension headers, in bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: total
                        
                        	Total length of the IPv6 header and payload in bytes
                        	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Length.Total>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv6.Length, self).__init__()

                            self.yang_name = "length"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("total", ("total", Native.Flow.Record.Collect.Ipv6.Length.Total))])
                            self._leafs = OrderedDict([
                                ('header', (YLeaf(YType.empty, 'header'), ['Empty'])),
                                ('payload', (YLeaf(YType.empty, 'payload'), ['Empty'])),
                            ])
                            self.header = None
                            self.payload = None

                            self.total = None
                            self._children_name_map["total"] = "total"
                            self._segment_path = lambda: "length"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Length, ['header', 'payload'], name, value)


                        class Total(Entity):
                            """
                            Total length of the IPv6 header and payload in bytes
                            
                            .. attribute:: maximum
                            
                            	Maximum total length in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	Minimum total length in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv6.Length.Total, self).__init__()

                                self.yang_name = "total"
                                self.yang_parent_name = "length"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self._segment_path = lambda: "total"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Length.Total, ['maximum', 'minimum'], name, value)


                    class Section(Entity):
                        """
                        Part of the packet
                        
                        .. attribute:: header
                        
                        	Raw data starting at the IPv6 header
                        	**type**\:  :py:class:`Header <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Section.Header>`
                        
                        .. attribute:: payload
                        
                        	Raw data starting at the IPv6 payload
                        	**type**\:  :py:class:`Payload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Section.Payload>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv6.Section, self).__init__()

                            self.yang_name = "section"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("header", ("header", Native.Flow.Record.Collect.Ipv6.Section.Header)), ("payload", ("payload", Native.Flow.Record.Collect.Ipv6.Section.Payload))])
                            self._leafs = OrderedDict()

                            self.header = Native.Flow.Record.Collect.Ipv6.Section.Header()
                            self.header.parent = self
                            self._children_name_map["header"] = "header"

                            self.payload = Native.Flow.Record.Collect.Ipv6.Section.Payload()
                            self.payload.parent = self
                            self._children_name_map["payload"] = "payload"
                            self._segment_path = lambda: "section"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Section, [], name, value)


                        class Header(Entity):
                            """
                            Raw data starting at the IPv6 header
                            
                            .. attribute:: size
                            
                            	Specify the number of bytes to capture
                            	**type**\: int
                            
                            	**range:** 1..1200
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv6.Section.Header, self).__init__()

                                self.yang_name = "header"
                                self.yang_parent_name = "section"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                ])
                                self.size = None
                                self._segment_path = lambda: "header"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Section.Header, ['size'], name, value)


                        class Payload(Entity):
                            """
                            Raw data starting at the IPv6 payload
                            
                            .. attribute:: size
                            
                            	Specify the number of bytes to capture
                            	**type**\: int
                            
                            	**range:** 1..1200
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv6.Section.Payload, self).__init__()

                                self.yang_name = "payload"
                                self.yang_parent_name = "section"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                ])
                                self.size = None
                                self._segment_path = lambda: "payload"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Section.Payload, ['size'], name, value)


                    class Source(Entity):
                        """
                        IPv6 source address based fields
                        
                        .. attribute:: address
                        
                        	IPv6 source address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mask
                        
                        	IPv6 address mask for the IPv6 source address
                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Source.Mask>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix
                        
                        	IPv6 address prefix for the IPv6 source address
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Ipv6.Source.Prefix>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Ipv6.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Collect.Ipv6.Source.Mask)), ("prefix", ("prefix", Native.Flow.Record.Collect.Ipv6.Source.Prefix))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                            ])
                            self.address = None

                            self.mask = None
                            self._children_name_map["mask"] = "mask"

                            self.prefix = None
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Source, ['address'], name, value)


                        class Mask(Entity):
                            """
                            IPv6 address mask for the IPv6 source address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..128
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv6.Source.Mask, self).__init__()

                                self.yang_name = "mask"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "mask"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Source.Mask, ['minimum_mask'], name, value)


                        class Prefix(Entity):
                            """
                            IPv6 address prefix for the IPv6 source address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..128
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Ipv6.Source.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Ipv6.Source.Prefix, ['minimum_mask'], name, value)


                class Metadata(Entity):
                    """
                    Metadata fields
                    
                    .. attribute:: clock_rate
                    
                    	Metadata clock\-rate
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: global_session_id
                    
                    	Metadata global\-session\-id
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_party_session_id
                    
                    	Metadata multi\-party\-session\-id
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Metadata, self).__init__()

                        self.yang_name = "metadata"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('clock_rate', (YLeaf(YType.empty, 'clock-rate'), ['Empty'])),
                            ('global_session_id', (YLeaf(YType.empty, 'global-session-id'), ['Empty'])),
                            ('multi_party_session_id', (YLeaf(YType.empty, 'multi-party-session-id'), ['Empty'])),
                        ])
                        self.clock_rate = None
                        self.global_session_id = None
                        self.multi_party_session_id = None
                        self._segment_path = lambda: "metadata"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Metadata, ['clock_rate', 'global_session_id', 'multi_party_session_id'], name, value)


                class Monitor(Entity):
                    """
                    monitor fields
                    
                    .. attribute:: event
                    
                    	Flags indicating monitor events
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('event', (YLeaf(YType.empty, 'event'), ['Empty'])),
                        ])
                        self.event = None
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Monitor, ['event'], name, value)


                class Mpls(Entity):
                    """
                    MPLS fields
                    
                    .. attribute:: label
                    
                    	MPLS label details
                    	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Mpls.Label>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("label", ("label", Native.Flow.Record.Collect.Mpls.Label))])
                        self._leafs = OrderedDict()

                        self.label = Native.Flow.Record.Collect.Mpls.Label()
                        self.label.parent = self
                        self._children_name_map["label"] = "label"
                        self._segment_path = lambda: "mpls"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Mpls, [], name, value)


                    class Label(Entity):
                        """
                        MPLS label details
                        
                        .. attribute:: one
                        
                        	MPLS label 1 information
                        	**type**\:  :py:class:`One <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Mpls.Label.One>`
                        
                        .. attribute:: two
                        
                        	MPLS label 2 information
                        	**type**\:  :py:class:`Two <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Mpls.Label.Two>`
                        
                        .. attribute:: three
                        
                        	MPLS label 3 information
                        	**type**\:  :py:class:`Three <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Mpls.Label.Three>`
                        
                        .. attribute:: four
                        
                        	MPLS label 4 information
                        	**type**\:  :py:class:`Four <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Mpls.Label.Four>`
                        
                        .. attribute:: five
                        
                        	MPLS label 5 information
                        	**type**\:  :py:class:`Five <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Mpls.Label.Five>`
                        
                        .. attribute:: six
                        
                        	MPLS label 6 information
                        	**type**\:  :py:class:`Six <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Mpls.Label.Six>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Mpls.Label, self).__init__()

                            self.yang_name = "label"
                            self.yang_parent_name = "mpls"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("one", ("one", Native.Flow.Record.Collect.Mpls.Label.One)), ("two", ("two", Native.Flow.Record.Collect.Mpls.Label.Two)), ("three", ("three", Native.Flow.Record.Collect.Mpls.Label.Three)), ("four", ("four", Native.Flow.Record.Collect.Mpls.Label.Four)), ("five", ("five", Native.Flow.Record.Collect.Mpls.Label.Five)), ("six", ("six", Native.Flow.Record.Collect.Mpls.Label.Six))])
                            self._leafs = OrderedDict()

                            self.one = Native.Flow.Record.Collect.Mpls.Label.One()
                            self.one.parent = self
                            self._children_name_map["one"] = "one"

                            self.two = Native.Flow.Record.Collect.Mpls.Label.Two()
                            self.two.parent = self
                            self._children_name_map["two"] = "two"

                            self.three = Native.Flow.Record.Collect.Mpls.Label.Three()
                            self.three.parent = self
                            self._children_name_map["three"] = "three"

                            self.four = Native.Flow.Record.Collect.Mpls.Label.Four()
                            self.four.parent = self
                            self._children_name_map["four"] = "four"

                            self.five = Native.Flow.Record.Collect.Mpls.Label.Five()
                            self.five.parent = self
                            self._children_name_map["five"] = "five"

                            self.six = Native.Flow.Record.Collect.Mpls.Label.Six()
                            self.six.parent = self
                            self._children_name_map["six"] = "six"
                            self._segment_path = lambda: "label"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Mpls.Label, [], name, value)


                        class One(Entity):
                            """
                            MPLS label 1 information
                            
                            .. attribute:: details
                            
                            	MPLS label 1 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: exp
                            
                            	MPLS EXP field from the last label that was pushed
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ttl
                            
                            	MPLS TTL field from the last label that was pushed
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: type
                            
                            	MPLS label type of the last label that was pushed
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Mpls.Label.One, self).__init__()

                                self.yang_name = "one"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ('exp', (YLeaf(YType.empty, 'exp'), ['Empty'])),
                                    ('ttl', (YLeaf(YType.empty, 'ttl'), ['Empty'])),
                                    ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                ])
                                self.details = None
                                self.exp = None
                                self.ttl = None
                                self.type = None
                                self._segment_path = lambda: "one"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Mpls.Label.One, ['details', 'exp', 'ttl', 'type'], name, value)


                        class Two(Entity):
                            """
                            MPLS label 2 information
                            
                            .. attribute:: details
                            
                            	MPLS label 2 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Mpls.Label.Two, self).__init__()

                                self.yang_name = "two"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                ])
                                self.details = None
                                self._segment_path = lambda: "two"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Mpls.Label.Two, ['details'], name, value)


                        class Three(Entity):
                            """
                            MPLS label 3 information
                            
                            .. attribute:: details
                            
                            	MPLS label 3 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Mpls.Label.Three, self).__init__()

                                self.yang_name = "three"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                ])
                                self.details = None
                                self._segment_path = lambda: "three"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Mpls.Label.Three, ['details'], name, value)


                        class Four(Entity):
                            """
                            MPLS label 4 information
                            
                            .. attribute:: details
                            
                            	MPLS label 4 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Mpls.Label.Four, self).__init__()

                                self.yang_name = "four"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                ])
                                self.details = None
                                self._segment_path = lambda: "four"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Mpls.Label.Four, ['details'], name, value)


                        class Five(Entity):
                            """
                            MPLS label 5 information
                            
                            .. attribute:: details
                            
                            	MPLS label 5 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Mpls.Label.Five, self).__init__()

                                self.yang_name = "five"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                ])
                                self.details = None
                                self._segment_path = lambda: "five"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Mpls.Label.Five, ['details'], name, value)


                        class Six(Entity):
                            """
                            MPLS label 6 information
                            
                            .. attribute:: details
                            
                            	MPLS label 6 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Mpls.Label.Six, self).__init__()

                                self.yang_name = "six"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                ])
                                self.details = None
                                self._segment_path = lambda: "six"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Mpls.Label.Six, ['details'], name, value)


                class Network(Entity):
                    """
                    network metrics
                    
                    .. attribute:: delay
                    
                    	network delay metrics
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Network.Delay>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("delay", ("delay", Native.Flow.Record.Collect.Network.Delay))])
                        self._leafs = OrderedDict()

                        self.delay = Native.Flow.Record.Collect.Network.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Network, [], name, value)


                    class Delay(Entity):
                        """
                        network delay metrics
                        
                        .. attribute:: sample
                        
                        	The number of samples of roundtrip delay
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: sum
                        
                        	The sum of roundtrip delay
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Network.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sample', (YLeaf(YType.empty, 'sample'), ['Empty'])),
                                ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                            ])
                            self.sample = None
                            self.sum = None
                            self._segment_path = lambda: "delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Network.Delay, ['sample', 'sum'], name, value)


                class Pfr(Entity):
                    """
                    PfR metrics
                    
                    .. attribute:: label
                    
                    	PfR label metrics
                    	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.Label>`
                    
                    .. attribute:: one_way_delay
                    
                    	The packet transmission delay between specified nodes
                    	**type**\:  :py:class:`OneWayDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.OneWayDelay>`
                    
                    .. attribute:: service
                    
                    	PfR service metrics
                    	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.Service>`
                    
                    .. attribute:: site
                    
                    	PfR site  metrics
                    	**type**\:  :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.Site>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Pfr, self).__init__()

                        self.yang_name = "pfr"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("label", ("label", Native.Flow.Record.Collect.Pfr.Label)), ("one-way-delay", ("one_way_delay", Native.Flow.Record.Collect.Pfr.OneWayDelay)), ("service", ("service", Native.Flow.Record.Collect.Pfr.Service)), ("site", ("site", Native.Flow.Record.Collect.Pfr.Site))])
                        self._leafs = OrderedDict()

                        self.label = Native.Flow.Record.Collect.Pfr.Label()
                        self.label.parent = self
                        self._children_name_map["label"] = "label"

                        self.one_way_delay = Native.Flow.Record.Collect.Pfr.OneWayDelay()
                        self.one_way_delay.parent = self
                        self._children_name_map["one_way_delay"] = "one-way-delay"

                        self.service = Native.Flow.Record.Collect.Pfr.Service()
                        self.service.parent = self
                        self._children_name_map["service"] = "service"

                        self.site = Native.Flow.Record.Collect.Pfr.Site()
                        self.site.parent = self
                        self._children_name_map["site"] = "site"
                        self._segment_path = lambda: "pfr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Pfr, [], name, value)


                    class Label(Entity):
                        """
                        PfR label metrics
                        
                        .. attribute:: identifier
                        
                        	pfr label id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Pfr.Label, self).__init__()

                            self.yang_name = "label"
                            self.yang_parent_name = "pfr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('identifier', (YLeaf(YType.empty, 'identifier'), ['Empty'])),
                            ])
                            self.identifier = None
                            self._segment_path = lambda: "label"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Pfr.Label, ['identifier'], name, value)


                    class OneWayDelay(Entity):
                        """
                        The packet transmission delay between specified nodes
                        
                        .. attribute:: samples
                        
                        	Total number of one\-way\-delay samples
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: sum
                        
                        	The packet transmission delay sum between specified nodes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Pfr.OneWayDelay, self).__init__()

                            self.yang_name = "one-way-delay"
                            self.yang_parent_name = "pfr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('samples', (YLeaf(YType.empty, 'samples'), ['Empty'])),
                                ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                            ])
                            self.samples = None
                            self.sum = None
                            self._segment_path = lambda: "one-way-delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Pfr.OneWayDelay, ['samples', 'sum'], name, value)


                    class Service(Entity):
                        """
                        PfR service metrics
                        
                        .. attribute:: provider
                        
                        	PfR service provider metrics
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tag
                        
                        	PfR service provider tag metrics
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: identifier
                        
                        	PfR service provider tag
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Pfr.Service, self).__init__()

                            self.yang_name = "service"
                            self.yang_parent_name = "pfr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('provider', (YLeaf(YType.empty, 'provider'), ['Empty'])),
                                ('tag', (YLeaf(YType.empty, 'tag'), ['Empty'])),
                                ('identifier', (YLeaf(YType.empty, 'identifier'), ['Empty'])),
                            ])
                            self.provider = None
                            self.tag = None
                            self.identifier = None
                            self._segment_path = lambda: "service"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Pfr.Service, ['provider', 'tag', 'identifier'], name, value)


                    class Site(Entity):
                        """
                        PfR site  metrics
                        
                        .. attribute:: destination
                        
                        	PfR site destination metrics
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.Site.Destination>`
                        
                        .. attribute:: source
                        
                        	PfR site source metrics
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.Site.Source>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Pfr.Site, self).__init__()

                            self.yang_name = "site"
                            self.yang_parent_name = "pfr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Collect.Pfr.Site.Destination)), ("source", ("source", Native.Flow.Record.Collect.Pfr.Site.Source))])
                            self._leafs = OrderedDict()

                            self.destination = Native.Flow.Record.Collect.Pfr.Site.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.source = Native.Flow.Record.Collect.Pfr.Site.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "site"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Pfr.Site, [], name, value)


                        class Destination(Entity):
                            """
                            PfR site destination metrics
                            
                            .. attribute:: id
                            
                            	PfR site destination ID metrics
                            	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.Site.Destination.Id>`
                            
                            .. attribute:: prefix
                            
                            	PfR site prefix of the packet destination
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.Site.Destination.Prefix>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Pfr.Site.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "site"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("id", ("id", Native.Flow.Record.Collect.Pfr.Site.Destination.Id)), ("prefix", ("prefix", Native.Flow.Record.Collect.Pfr.Site.Destination.Prefix))])
                                self._leafs = OrderedDict()

                                self.id = Native.Flow.Record.Collect.Pfr.Site.Destination.Id()
                                self.id.parent = self
                                self._children_name_map["id"] = "id"

                                self.prefix = Native.Flow.Record.Collect.Pfr.Site.Destination.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Pfr.Site.Destination, [], name, value)


                            class Id(Entity):
                                """
                                PfR site destination ID metrics
                                
                                .. attribute:: ipv4
                                
                                	site ID of the packet destination
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Pfr.Site.Destination.Id, self).__init__()

                                    self.yang_name = "id"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ])
                                    self.ipv4 = None
                                    self._segment_path = lambda: "id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Pfr.Site.Destination.Id, ['ipv4'], name, value)


                            class Prefix(Entity):
                                """
                                PfR site prefix of the packet destination
                                
                                .. attribute:: ipv4
                                
                                	site prefix of the packet destination
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: mask
                                
                                	PfR site prefix mask of the packet destination
                                	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.Site.Destination.Prefix.Mask>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Pfr.Site.Destination.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Collect.Pfr.Site.Destination.Prefix.Mask))])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ])
                                    self.ipv4 = None

                                    self.mask = Native.Flow.Record.Collect.Pfr.Site.Destination.Prefix.Mask()
                                    self.mask.parent = self
                                    self._children_name_map["mask"] = "mask"
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Pfr.Site.Destination.Prefix, ['ipv4'], name, value)


                                class Mask(Entity):
                                    """
                                    PfR site prefix mask of the packet destination
                                    
                                    .. attribute:: ipv4
                                    
                                    	site prefix mask of the packet destination
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Collect.Pfr.Site.Destination.Prefix.Mask, self).__init__()

                                        self.yang_name = "mask"
                                        self.yang_parent_name = "prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "mask"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Collect.Pfr.Site.Destination.Prefix.Mask, ['ipv4'], name, value)


                        class Source(Entity):
                            """
                            PfR site source metrics
                            
                            .. attribute:: id
                            
                            	PfR site source ID metrics
                            	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.Site.Source.Id>`
                            
                            .. attribute:: prefix
                            
                            	PfR site prefix of the packet source
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.Site.Source.Prefix>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Pfr.Site.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "site"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("id", ("id", Native.Flow.Record.Collect.Pfr.Site.Source.Id)), ("prefix", ("prefix", Native.Flow.Record.Collect.Pfr.Site.Source.Prefix))])
                                self._leafs = OrderedDict()

                                self.id = Native.Flow.Record.Collect.Pfr.Site.Source.Id()
                                self.id.parent = self
                                self._children_name_map["id"] = "id"

                                self.prefix = Native.Flow.Record.Collect.Pfr.Site.Source.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Pfr.Site.Source, [], name, value)


                            class Id(Entity):
                                """
                                PfR site source ID metrics
                                
                                .. attribute:: ipv4
                                
                                	site ID of the packet source
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Pfr.Site.Source.Id, self).__init__()

                                    self.yang_name = "id"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ])
                                    self.ipv4 = None
                                    self._segment_path = lambda: "id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Pfr.Site.Source.Id, ['ipv4'], name, value)


                            class Prefix(Entity):
                                """
                                PfR site prefix of the packet source
                                
                                .. attribute:: ipv4
                                
                                	site prefix of the packet source
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: mask
                                
                                	PfR site prefix mask of the packet source
                                	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Pfr.Site.Source.Prefix.Mask>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Pfr.Site.Source.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Collect.Pfr.Site.Source.Prefix.Mask))])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ])
                                    self.ipv4 = None

                                    self.mask = Native.Flow.Record.Collect.Pfr.Site.Source.Prefix.Mask()
                                    self.mask.parent = self
                                    self._children_name_map["mask"] = "mask"
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Pfr.Site.Source.Prefix, ['ipv4'], name, value)


                                class Mask(Entity):
                                    """
                                    PfR site prefix mask of the packet source
                                    
                                    .. attribute:: ipv4
                                    
                                    	site prefix mask of the packet source
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Collect.Pfr.Site.Source.Prefix.Mask, self).__init__()

                                        self.yang_name = "mask"
                                        self.yang_parent_name = "prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "mask"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Collect.Pfr.Site.Source.Prefix.Mask, ['ipv4'], name, value)


                class Policy(Entity):
                    """
                    policy fields
                    
                    .. attribute:: performance_monitor
                    
                    	Performance\-monitor policy related metrics
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Policy.PerformanceMonitor>`
                    
                    .. attribute:: qos
                    
                    	QoS policy related metrics
                    	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Policy.Qos>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("performance-monitor", ("performance_monitor", Native.Flow.Record.Collect.Policy.PerformanceMonitor)), ("qos", ("qos", Native.Flow.Record.Collect.Policy.Qos))])
                        self._leafs = OrderedDict()

                        self.performance_monitor = Native.Flow.Record.Collect.Policy.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.qos = Native.Flow.Record.Collect.Policy.Qos()
                        self.qos.parent = self
                        self._children_name_map["qos"] = "qos"
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Policy, [], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Performance\-monitor policy related metrics
                        
                        .. attribute:: classification
                        
                        	Classification metrics
                        	**type**\:  :py:class:`Classification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Policy.PerformanceMonitor.Classification>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Policy.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("classification", ("classification", Native.Flow.Record.Collect.Policy.PerformanceMonitor.Classification))])
                            self._leafs = OrderedDict()

                            self.classification = Native.Flow.Record.Collect.Policy.PerformanceMonitor.Classification()
                            self.classification.parent = self
                            self._children_name_map["classification"] = "classification"
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Policy.PerformanceMonitor, [], name, value)


                        class Classification(Entity):
                            """
                            Classification metrics
                            
                            .. attribute:: hierarchy
                            
                            	Performance\-monitor class hierarchy
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Policy.PerformanceMonitor.Classification, self).__init__()

                                self.yang_name = "classification"
                                self.yang_parent_name = "performance-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hierarchy', (YLeaf(YType.empty, 'hierarchy'), ['Empty'])),
                                ])
                                self.hierarchy = None
                                self._segment_path = lambda: "classification"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Policy.PerformanceMonitor.Classification, ['hierarchy'], name, value)


                    class Qos(Entity):
                        """
                        QoS policy related metrics
                        
                        .. attribute:: classification
                        
                        	Classification metrics
                        	**type**\:  :py:class:`Classification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Policy.Qos.Classification>`
                        
                        .. attribute:: queue
                        
                        	Queue metrics
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Policy.Qos.Queue>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Policy.Qos, self).__init__()

                            self.yang_name = "qos"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("classification", ("classification", Native.Flow.Record.Collect.Policy.Qos.Classification)), ("queue", ("queue", Native.Flow.Record.Collect.Policy.Qos.Queue))])
                            self._leafs = OrderedDict()

                            self.classification = Native.Flow.Record.Collect.Policy.Qos.Classification()
                            self.classification.parent = self
                            self._children_name_map["classification"] = "classification"

                            self.queue = Native.Flow.Record.Collect.Policy.Qos.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "qos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Policy.Qos, [], name, value)


                        class Classification(Entity):
                            """
                            Classification metrics
                            
                            .. attribute:: hierarchy
                            
                            	QoS class hierarchy
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Policy.Qos.Classification, self).__init__()

                                self.yang_name = "classification"
                                self.yang_parent_name = "qos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hierarchy', (YLeaf(YType.empty, 'hierarchy'), ['Empty'])),
                                ])
                                self.hierarchy = None
                                self._segment_path = lambda: "classification"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Policy.Qos.Classification, ['hierarchy'], name, value)


                        class Queue(Entity):
                            """
                            Queue metrics
                            
                            .. attribute:: drops
                            
                            	QoS queue drops
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: index
                            
                            	QoS queue index
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Policy.Qos.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "qos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('drops', (YLeaf(YType.empty, 'drops'), ['Empty'])),
                                    ('index', (YLeaf(YType.empty, 'index'), ['Empty'])),
                                ])
                                self.drops = None
                                self.index = None
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Policy.Qos.Queue, ['drops', 'index'], name, value)


                class Routing(Entity):
                    """
                    Routing attributes
                    
                    .. attribute:: destination
                    
                    	Destination routing attributes
                    	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.Destination>`
                    
                    .. attribute:: forwarding_status
                    
                    	Forwarding status of the packet
                    	**type**\:  :py:class:`ForwardingStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.ForwardingStatus>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: is_multicast
                    
                    	Indicates if this is multicast
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: next_hop
                    
                    	Information regarding the next hop
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.NextHop>`
                    
                    .. attribute:: pw
                    
                    	Pseudowire fields
                    	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.Pw>`
                    
                    .. attribute:: source
                    
                    	Source routing attributes
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.Source>`
                    
                    .. attribute:: vrf
                    
                    	VRF routing attributes
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Routing, self).__init__()

                        self.yang_name = "routing"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Collect.Routing.Destination)), ("forwarding-status", ("forwarding_status", Native.Flow.Record.Collect.Routing.ForwardingStatus)), ("next-hop", ("next_hop", Native.Flow.Record.Collect.Routing.NextHop)), ("pw", ("pw", Native.Flow.Record.Collect.Routing.Pw)), ("source", ("source", Native.Flow.Record.Collect.Routing.Source)), ("vrf", ("vrf", Native.Flow.Record.Collect.Routing.Vrf))])
                        self._leafs = OrderedDict([
                            ('is_multicast', (YLeaf(YType.empty, 'is-multicast'), ['Empty'])),
                        ])
                        self.is_multicast = None

                        self.destination = Native.Flow.Record.Collect.Routing.Destination()
                        self.destination.parent = self
                        self._children_name_map["destination"] = "destination"

                        self.forwarding_status = None
                        self._children_name_map["forwarding_status"] = "forwarding-status"

                        self.next_hop = Native.Flow.Record.Collect.Routing.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"

                        self.pw = Native.Flow.Record.Collect.Routing.Pw()
                        self.pw.parent = self
                        self._children_name_map["pw"] = "pw"

                        self.source = Native.Flow.Record.Collect.Routing.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"

                        self.vrf = Native.Flow.Record.Collect.Routing.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "routing"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Routing, ['is_multicast'], name, value)


                    class Destination(Entity):
                        """
                        Destination routing attributes
                        
                        .. attribute:: as_
                        
                        	AS number of the destination network
                        	**type**\:  :py:class:`As <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.Destination.As>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: traffic_index
                        
                        	BGP destination traffic index
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Routing.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("as", ("as_", Native.Flow.Record.Collect.Routing.Destination.As))])
                            self._leafs = OrderedDict([
                                ('traffic_index', (YLeaf(YType.empty, 'traffic-index'), ['Empty'])),
                            ])
                            self.traffic_index = None

                            self.as_ = None
                            self._children_name_map["as_"] = "as"
                            self._segment_path = lambda: "destination"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Routing.Destination, ['traffic_index'], name, value)


                        class As(Entity):
                            """
                            AS number of the destination network
                            
                            .. attribute:: as4_octet
                            
                            	4 octet AS number of the destination network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: peer
                            
                            	AS number of the peer network we will forward to
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.Destination.As.Peer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Routing.Destination.As, self).__init__()

                                self.yang_name = "as"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Flow.Record.Collect.Routing.Destination.As.Peer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('as4_octet', (YLeaf(YType.empty, 'as4-octet'), ['Empty'])),
                                ])
                                self.as4_octet = None

                                self.peer = None
                                self._children_name_map["peer"] = "peer"
                                self._segment_path = lambda: "as"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Routing.Destination.As, ['as4_octet'], name, value)


                            class Peer(Entity):
                                """
                                AS number of the peer network we will forward to
                                
                                .. attribute:: peer4_octet
                                
                                	4 octet AS number of the peer network we will forward to
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Routing.Destination.As.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "as"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('peer4_octet', (YLeaf(YType.empty, 'peer4-octet'), ['Empty'])),
                                    ])
                                    self.peer4_octet = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Routing.Destination.As.Peer, ['peer4_octet'], name, value)


                    class ForwardingStatus(Entity):
                        """
                        Forwarding status of the packet
                        
                        .. attribute:: reason
                        
                        	Forwarding status reason of the packet
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Routing.ForwardingStatus, self).__init__()

                            self.yang_name = "forwarding-status"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('reason', (YLeaf(YType.empty, 'reason'), ['Empty'])),
                            ])
                            self.reason = None
                            self._segment_path = lambda: "forwarding-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Routing.ForwardingStatus, ['reason'], name, value)


                    class NextHop(Entity):
                        """
                        Information regarding the next hop
                        
                        .. attribute:: address
                        
                        	IP address of the next hop
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.NextHop.Address>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Routing.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Collect.Routing.NextHop.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Flow.Record.Collect.Routing.NextHop.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Routing.NextHop, [], name, value)


                        class Address(Entity):
                            """
                            IP address of the next hop
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address of the next hop
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.NextHop.Address.Ipv4>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address of the next hop
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.NextHop.Address.Ipv6>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Routing.NextHop.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Collect.Routing.NextHop.Address.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Collect.Routing.NextHop.Address.Ipv6))])
                                self._leafs = OrderedDict()

                                self.ipv4 = None
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = None
                                self._children_name_map["ipv6"] = "ipv6"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Routing.NextHop.Address, [], name, value)


                            class Ipv4(Entity):
                                """
                                IPv4 address of the next hop
                                
                                .. attribute:: bgp
                                
                                	IPv4 address of the BGP next hop
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Routing.NextHop.Address.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                                    ])
                                    self.bgp = None
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Routing.NextHop.Address.Ipv4, ['bgp'], name, value)


                            class Ipv6(Entity):
                                """
                                IPv6 address of the next hop
                                
                                .. attribute:: bgp
                                
                                	IPv6 address of the BGP next hop
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Routing.NextHop.Address.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                                    ])
                                    self.bgp = None
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Routing.NextHop.Address.Ipv6, ['bgp'], name, value)


                    class Pw(Entity):
                        """
                        Pseudowire fields
                        
                        .. attribute:: destination
                        
                        	Pseudowire destination
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.Pw.Destination>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Routing.Pw, self).__init__()

                            self.yang_name = "pw"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Collect.Routing.Pw.Destination))])
                            self._leafs = OrderedDict()

                            self.destination = Native.Flow.Record.Collect.Routing.Pw.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"
                            self._segment_path = lambda: "pw"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Routing.Pw, [], name, value)


                        class Destination(Entity):
                            """
                            Pseudowire destination
                            
                            .. attribute:: address
                            
                            	Pseudowire destination address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Routing.Pw.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "pw"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Routing.Pw.Destination, ['address'], name, value)


                    class Source(Entity):
                        """
                        Source routing attributes
                        
                        .. attribute:: as_
                        
                        	AS number of the original network
                        	**type**\:  :py:class:`As <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.Source.As>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: traffic_index
                        
                        	BGP source traffic index
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Routing.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("as", ("as_", Native.Flow.Record.Collect.Routing.Source.As))])
                            self._leafs = OrderedDict([
                                ('traffic_index', (YLeaf(YType.empty, 'traffic-index'), ['Empty'])),
                            ])
                            self.traffic_index = None

                            self.as_ = None
                            self._children_name_map["as_"] = "as"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Routing.Source, ['traffic_index'], name, value)


                        class As(Entity):
                            """
                            AS number of the original network
                            
                            .. attribute:: as4_octet
                            
                            	4 octet AS number of the original network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: peer
                            
                            	AS number of the peer network where the packet came from
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Routing.Source.As.Peer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Routing.Source.As, self).__init__()

                                self.yang_name = "as"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Flow.Record.Collect.Routing.Source.As.Peer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('as4_octet', (YLeaf(YType.empty, 'as4-octet'), ['Empty'])),
                                ])
                                self.as4_octet = None

                                self.peer = None
                                self._children_name_map["peer"] = "peer"
                                self._segment_path = lambda: "as"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Routing.Source.As, ['as4_octet'], name, value)


                            class Peer(Entity):
                                """
                                AS number of the peer network where the packet came from
                                
                                .. attribute:: peer4_octet
                                
                                	4 octet AS number of the peer network where the packet came from
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Routing.Source.As.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "as"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('peer4_octet', (YLeaf(YType.empty, 'peer4-octet'), ['Empty'])),
                                    ])
                                    self.peer4_octet = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Routing.Source.As.Peer, ['peer4_octet'], name, value)


                    class Vrf(Entity):
                        """
                        VRF routing attributes
                        
                        .. attribute:: input
                        
                        	VRF ID for incoming packet
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	VRF ID for outgoing packet
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Routing.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Routing.Vrf, ['input', 'output'], name, value)


                class Services(Entity):
                    """
                    Services fields
                    
                    .. attribute:: waas
                    
                    	WAAS (Wide Area Application Services) metrics
                    	**type**\:  :py:class:`Waas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Services.Waas>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Services, self).__init__()

                        self.yang_name = "services"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("waas", ("waas", Native.Flow.Record.Collect.Services.Waas))])
                        self._leafs = OrderedDict()

                        self.waas = Native.Flow.Record.Collect.Services.Waas()
                        self.waas.parent = self
                        self._children_name_map["waas"] = "waas"
                        self._segment_path = lambda: "services"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Services, [], name, value)


                    class Waas(Entity):
                        """
                        WAAS (Wide Area Application Services) metrics
                        
                        .. attribute:: passthrough_reason
                        
                        	WAAS passthrough reason
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: segment
                        
                        	WAAS optimization segment
                        	**type**\:  :py:class:`Segment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Services.Waas.Segment>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Services.Waas, self).__init__()

                            self.yang_name = "waas"
                            self.yang_parent_name = "services"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("segment", ("segment", Native.Flow.Record.Collect.Services.Waas.Segment))])
                            self._leafs = OrderedDict([
                                ('passthrough_reason', (YLeaf(YType.empty, 'passthrough-reason'), ['Empty'])),
                            ])
                            self.passthrough_reason = None

                            self.segment = None
                            self._children_name_map["segment"] = "segment"
                            self._segment_path = lambda: "waas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Services.Waas, ['passthrough_reason'], name, value)


                        class Segment(Entity):
                            """
                            WAAS optimization segment
                            
                            .. attribute:: account_on_resolution
                            
                            	Account on resolution
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Services.Waas.Segment, self).__init__()

                                self.yang_name = "segment"
                                self.yang_parent_name = "waas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('account_on_resolution', (YLeaf(YType.empty, 'account-on-resolution'), ['Empty'])),
                                ])
                                self.account_on_resolution = None
                                self._segment_path = lambda: "segment"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Services.Waas.Segment, ['account_on_resolution'], name, value)


                class Timestamp(Entity):
                    """
                    Timestamp fields
                    
                    .. attribute:: absolute
                    
                    	Timestamps based on the epoch of 00\:00 UTC 1st Jan 1970
                    	**type**\:  :py:class:`Absolute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Timestamp.Absolute>`
                    
                    .. attribute:: interval
                    
                    	Epoch of a monitoring interval
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sys_uptime
                    
                    	Timestamps based on the sys\-uptime
                    	**type**\:  :py:class:`SysUptime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Timestamp.SysUptime>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Timestamp, self).__init__()

                        self.yang_name = "timestamp"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("absolute", ("absolute", Native.Flow.Record.Collect.Timestamp.Absolute)), ("sys-uptime", ("sys_uptime", Native.Flow.Record.Collect.Timestamp.SysUptime))])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.empty, 'interval'), ['Empty'])),
                        ])
                        self.interval = None

                        self.absolute = Native.Flow.Record.Collect.Timestamp.Absolute()
                        self.absolute.parent = self
                        self._children_name_map["absolute"] = "absolute"

                        self.sys_uptime = Native.Flow.Record.Collect.Timestamp.SysUptime()
                        self.sys_uptime.parent = self
                        self._children_name_map["sys_uptime"] = "sys-uptime"
                        self._segment_path = lambda: "timestamp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Timestamp, ['interval'], name, value)


                    class Absolute(Entity):
                        """
                        Timestamps based on the epoch of 00\:00 UTC 1st Jan 1970
                        
                        .. attribute:: first
                        
                        	Absolute time the first packet was seen (milliseconds)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: last
                        
                        	Absolute time the most recent packet was seen (milliseconds)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: monitoring_interval
                        
                        	Monitoring interval timestamps
                        	**type**\:  :py:class:`MonitoringInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Timestamp.Absolute.MonitoringInterval>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Timestamp.Absolute, self).__init__()

                            self.yang_name = "absolute"
                            self.yang_parent_name = "timestamp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("monitoring-interval", ("monitoring_interval", Native.Flow.Record.Collect.Timestamp.Absolute.MonitoringInterval))])
                            self._leafs = OrderedDict([
                                ('first', (YLeaf(YType.empty, 'first'), ['Empty'])),
                                ('last', (YLeaf(YType.empty, 'last'), ['Empty'])),
                            ])
                            self.first = None
                            self.last = None

                            self.monitoring_interval = Native.Flow.Record.Collect.Timestamp.Absolute.MonitoringInterval()
                            self.monitoring_interval.parent = self
                            self._children_name_map["monitoring_interval"] = "monitoring-interval"
                            self._segment_path = lambda: "absolute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Timestamp.Absolute, ['first', 'last'], name, value)


                        class MonitoringInterval(Entity):
                            """
                            Monitoring interval timestamps
                            
                            .. attribute:: end
                            
                            	Absolute end time of a monitoring interval (milliseconds)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: start
                            
                            	Absolute start time of a monitoring interval (milliseconds)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Timestamp.Absolute.MonitoringInterval, self).__init__()

                                self.yang_name = "monitoring-interval"
                                self.yang_parent_name = "absolute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('end', (YLeaf(YType.empty, 'end'), ['Empty'])),
                                    ('start', (YLeaf(YType.empty, 'start'), ['Empty'])),
                                ])
                                self.end = None
                                self.start = None
                                self._segment_path = lambda: "monitoring-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Timestamp.Absolute.MonitoringInterval, ['end', 'start'], name, value)


                    class SysUptime(Entity):
                        """
                        Timestamps based on the sys\-uptime
                        
                        .. attribute:: first
                        
                        	Time the first packet was seen
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: last
                        
                        	Time the most recent packet was seen
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Timestamp.SysUptime, self).__init__()

                            self.yang_name = "sys-uptime"
                            self.yang_parent_name = "timestamp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('first', (YLeaf(YType.empty, 'first'), ['Empty'])),
                                ('last', (YLeaf(YType.empty, 'last'), ['Empty'])),
                            ])
                            self.first = None
                            self.last = None
                            self._segment_path = lambda: "sys-uptime"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Timestamp.SysUptime, ['first', 'last'], name, value)


                class Transport(Entity):
                    """
                    Transport layer fields
                    
                    .. attribute:: bytes
                    
                    	Bytes fields
                    	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Bytes>`
                    
                    .. attribute:: destination_port
                    
                    	Transport destination port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: icmp
                    
                    	ICMP fields
                    	**type**\:  :py:class:`Icmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Icmp>`
                    
                    .. attribute:: igmp
                    
                    	IGMP fields
                    	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Igmp>`
                    
                    .. attribute:: source_port
                    
                    	Transport source port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: tcp
                    
                    	TCP fields
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Tcp>`
                    
                    .. attribute:: udp
                    
                    	UDP fields
                    	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Udp>`
                    
                    .. attribute:: event
                    
                    	Transport event fields
                    	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Event>`
                    
                    .. attribute:: packets
                    
                    	Transport packet fields
                    	**type**\:  :py:class:`Packets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Packets>`
                    
                    .. attribute:: round_trip_time
                    
                    	RTT calculation for flow
                    	**type**\:  :py:class:`RoundTripTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.RoundTripTime>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: rtp
                    
                    	RTP fields
                    	**type**\:  :py:class:`Rtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Rtp>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Collect.Transport, self).__init__()

                        self.yang_name = "transport"
                        self.yang_parent_name = "collect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Collect.Transport.Bytes)), ("icmp", ("icmp", Native.Flow.Record.Collect.Transport.Icmp)), ("igmp", ("igmp", Native.Flow.Record.Collect.Transport.Igmp)), ("tcp", ("tcp", Native.Flow.Record.Collect.Transport.Tcp)), ("udp", ("udp", Native.Flow.Record.Collect.Transport.Udp)), ("event", ("event", Native.Flow.Record.Collect.Transport.Event)), ("packets", ("packets", Native.Flow.Record.Collect.Transport.Packets)), ("round-trip-time", ("round_trip_time", Native.Flow.Record.Collect.Transport.RoundTripTime)), ("rtp", ("rtp", Native.Flow.Record.Collect.Transport.Rtp))])
                        self._leafs = OrderedDict([
                            ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                            ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                        ])
                        self.destination_port = None
                        self.source_port = None

                        self.bytes = Native.Flow.Record.Collect.Transport.Bytes()
                        self.bytes.parent = self
                        self._children_name_map["bytes"] = "bytes"

                        self.icmp = Native.Flow.Record.Collect.Transport.Icmp()
                        self.icmp.parent = self
                        self._children_name_map["icmp"] = "icmp"

                        self.igmp = Native.Flow.Record.Collect.Transport.Igmp()
                        self.igmp.parent = self
                        self._children_name_map["igmp"] = "igmp"

                        self.tcp = Native.Flow.Record.Collect.Transport.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"

                        self.udp = Native.Flow.Record.Collect.Transport.Udp()
                        self.udp.parent = self
                        self._children_name_map["udp"] = "udp"

                        self.event = Native.Flow.Record.Collect.Transport.Event()
                        self.event.parent = self
                        self._children_name_map["event"] = "event"

                        self.packets = Native.Flow.Record.Collect.Transport.Packets()
                        self.packets.parent = self
                        self._children_name_map["packets"] = "packets"

                        self.round_trip_time = None
                        self._children_name_map["round_trip_time"] = "round-trip-time"

                        self.rtp = Native.Flow.Record.Collect.Transport.Rtp()
                        self.rtp.parent = self
                        self._children_name_map["rtp"] = "rtp"
                        self._segment_path = lambda: "transport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Collect.Transport, ['destination_port', 'source_port'], name, value)


                    class Bytes(Entity):
                        """
                        Bytes fields
                        
                        .. attribute:: expected
                        
                        	Transport bytes expected
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: lost
                        
                        	Transport bytes lost
                        	**type**\:  :py:class:`Lost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Bytes.Lost>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: out_of_order
                        
                        	Total number of out\-of\-order bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Transport.Bytes, self).__init__()

                            self.yang_name = "bytes"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lost", ("lost", Native.Flow.Record.Collect.Transport.Bytes.Lost))])
                            self._leafs = OrderedDict([
                                ('expected', (YLeaf(YType.empty, 'expected'), ['Empty'])),
                                ('out_of_order', (YLeaf(YType.empty, 'out-of-order'), ['Empty'])),
                            ])
                            self.expected = None
                            self.out_of_order = None

                            self.lost = None
                            self._children_name_map["lost"] = "lost"
                            self._segment_path = lambda: "bytes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Transport.Bytes, ['expected', 'out_of_order'], name, value)


                        class Lost(Entity):
                            """
                            Transport bytes lost
                            
                            .. attribute:: rate
                            
                            	Transport bytes lost rate
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Bytes.Lost, self).__init__()

                                self.yang_name = "lost"
                                self.yang_parent_name = "bytes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.empty, 'rate'), ['Empty'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "lost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Bytes.Lost, ['rate'], name, value)


                    class Icmp(Entity):
                        """
                        ICMP fields
                        
                        .. attribute:: ipv4
                        
                        	IPv4 ICMP fields
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Icmp.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	IPv6 ICMP fields
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Icmp.Ipv6>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Transport.Icmp, self).__init__()

                            self.yang_name = "icmp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Collect.Transport.Icmp.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Collect.Transport.Icmp.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = Native.Flow.Record.Collect.Transport.Icmp.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = Native.Flow.Record.Collect.Transport.Icmp.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "icmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Transport.Icmp, [], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 ICMP fields
                            
                            .. attribute:: code
                            
                            	IPv4 ICMP code
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: type
                            
                            	IPv4 ICMP type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Icmp.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "icmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('code', (YLeaf(YType.empty, 'code'), ['Empty'])),
                                    ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                ])
                                self.code = None
                                self.type = None
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Icmp.Ipv4, ['code', 'type'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 ICMP fields
                            
                            .. attribute:: code
                            
                            	IPv6 ICMP code
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: type
                            
                            	IPv6 ICMP type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Icmp.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "icmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('code', (YLeaf(YType.empty, 'code'), ['Empty'])),
                                    ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                ])
                                self.code = None
                                self.type = None
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Icmp.Ipv6, ['code', 'type'], name, value)


                    class Igmp(Entity):
                        """
                        IGMP fields
                        
                        .. attribute:: type
                        
                        	IGMP type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Transport.Igmp, self).__init__()

                            self.yang_name = "igmp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                            ])
                            self.type = None
                            self._segment_path = lambda: "igmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Transport.Igmp, ['type'], name, value)


                    class Tcp(Entity):
                        """
                        TCP fields
                        
                        .. attribute:: acknowledgement_number
                        
                        	TCP acknowledgement number
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: destination_port
                        
                        	TCP destination port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: flags
                        
                        	TCP flags
                        	**type**\:  :py:class:`Flags <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Tcp.Flags>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flow
                        
                        	TCP flow
                        	**type**\:  :py:class:`Flow_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Tcp.Flow_>`
                        
                        .. attribute:: header_length
                        
                        	TCP header length (in 32 bit words)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: maximum_segment_size
                        
                        	The maximum size of TCP segment
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: option
                        
                        	TCP option fields
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Tcp.Option>`
                        
                        .. attribute:: sequence_number
                        
                        	TCP sequence number
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: source_port
                        
                        	TCP source port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: urgent_pointer
                        
                        	TCP urgent pointer
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: window_size
                        
                        	TCP window size
                        	**type**\:  :py:class:`WindowSize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Tcp.WindowSize>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Transport.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("flags", ("flags", Native.Flow.Record.Collect.Transport.Tcp.Flags)), ("flow", ("flow", Native.Flow.Record.Collect.Transport.Tcp.Flow_)), ("option", ("option", Native.Flow.Record.Collect.Transport.Tcp.Option)), ("window-size", ("window_size", Native.Flow.Record.Collect.Transport.Tcp.WindowSize))])
                            self._leafs = OrderedDict([
                                ('acknowledgement_number', (YLeaf(YType.empty, 'acknowledgement-number'), ['Empty'])),
                                ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                                ('header_length', (YLeaf(YType.empty, 'header-length'), ['Empty'])),
                                ('maximum_segment_size', (YLeaf(YType.empty, 'maximum-segment-size'), ['Empty'])),
                                ('sequence_number', (YLeaf(YType.empty, 'sequence-number'), ['Empty'])),
                                ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                                ('urgent_pointer', (YLeaf(YType.empty, 'urgent-pointer'), ['Empty'])),
                            ])
                            self.acknowledgement_number = None
                            self.destination_port = None
                            self.header_length = None
                            self.maximum_segment_size = None
                            self.sequence_number = None
                            self.source_port = None
                            self.urgent_pointer = None

                            self.flags = None
                            self._children_name_map["flags"] = "flags"

                            self.flow = Native.Flow.Record.Collect.Transport.Tcp.Flow_()
                            self.flow.parent = self
                            self._children_name_map["flow"] = "flow"

                            self.option = Native.Flow.Record.Collect.Transport.Tcp.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.window_size = None
                            self._children_name_map["window_size"] = "window-size"
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Transport.Tcp, ['acknowledgement_number', 'destination_port', 'header_length', 'maximum_segment_size', 'sequence_number', 'source_port', 'urgent_pointer'], name, value)


                        class Flags(Entity):
                            """
                            TCP flags
                            
                            .. attribute:: ack
                            
                            	TCP acknowledgement flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cwr
                            
                            	TCP congestion window reduced flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ece
                            
                            	TCP ECN echo flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: fin
                            
                            	TCP finish flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: psh
                            
                            	TCP push flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rst
                            
                            	TCP reset flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: syn
                            
                            	TCP synchronise flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: urg
                            
                            	TCP urgent flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Tcp.Flags, self).__init__()

                                self.yang_name = "flags"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                    ('cwr', (YLeaf(YType.empty, 'cwr'), ['Empty'])),
                                    ('ece', (YLeaf(YType.empty, 'ece'), ['Empty'])),
                                    ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                    ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                    ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                    ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                    ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                ])
                                self.ack = None
                                self.cwr = None
                                self.ece = None
                                self.fin = None
                                self.psh = None
                                self.rst = None
                                self.syn = None
                                self.urg = None
                                self._segment_path = lambda: "flags"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Tcp.Flags, ['ack', 'cwr', 'ece', 'fin', 'psh', 'rst', 'syn', 'urg'], name, value)


                        class Flow_(Entity):
                            """
                            TCP flow
                            
                            .. attribute:: count
                            
                            	Number of tcp flows
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Tcp.Flow_, self).__init__()

                                self.yang_name = "flow"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('count', (YLeaf(YType.empty, 'count'), ['Empty'])),
                                ])
                                self.count = None
                                self._segment_path = lambda: "flow"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Tcp.Flow_, ['count'], name, value)


                        class Option(Entity):
                            """
                            TCP option fields
                            
                            .. attribute:: map
                            
                            	Bitmap of TCP options
                            	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Tcp.Option.Map>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Tcp.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map", ("map", Native.Flow.Record.Collect.Transport.Tcp.Option.Map))])
                                self._leafs = OrderedDict()

                                self.map = None
                                self._children_name_map["map"] = "map"
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Tcp.Option, [], name, value)


                            class Map(Entity):
                                """
                                Bitmap of TCP options
                                
                                .. attribute:: long
                                
                                	Extended bitmap of TCP options
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Transport.Tcp.Option.Map, self).__init__()

                                    self.yang_name = "map"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                    ])
                                    self.long = None
                                    self._segment_path = lambda: "map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Transport.Tcp.Option.Map, ['long'], name, value)


                        class WindowSize(Entity):
                            """
                            TCP window size
                            
                            .. attribute:: average
                            
                            	The average size of TCP window
                            	**type**\:  :py:class:`Average <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Tcp.WindowSize.Average>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: maximum
                            
                            	The maximum size of TCP window
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	The minimum size of TCP window
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sum
                            
                            	The sum of TCP window size
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Tcp.WindowSize, self).__init__()

                                self.yang_name = "window-size"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("average", ("average", Native.Flow.Record.Collect.Transport.Tcp.WindowSize.Average))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                    ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self.sum = None

                                self.average = None
                                self._children_name_map["average"] = "average"
                                self._segment_path = lambda: "window-size"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Tcp.WindowSize, ['maximum', 'minimum', 'sum'], name, value)


                            class Average(Entity):
                                """
                                The average size of TCP window
                                
                                .. attribute:: sum
                                
                                	The sum of per flow TCP window average size
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Transport.Tcp.WindowSize.Average, self).__init__()

                                    self.yang_name = "average"
                                    self.yang_parent_name = "window-size"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.sum = None
                                    self._segment_path = lambda: "average"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Transport.Tcp.WindowSize.Average, ['sum'], name, value)


                    class Udp(Entity):
                        """
                        UDP fields
                        
                        .. attribute:: destination_port
                        
                        	UDP destination port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: message_length
                        
                        	UDP message length
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: source_port
                        
                        	UDP source port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Transport.Udp, self).__init__()

                            self.yang_name = "udp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                                ('message_length', (YLeaf(YType.empty, 'message-length'), ['Empty'])),
                                ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                            ])
                            self.destination_port = None
                            self.message_length = None
                            self.source_port = None
                            self._segment_path = lambda: "udp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Transport.Udp, ['destination_port', 'message_length', 'source_port'], name, value)


                    class Event(Entity):
                        """
                        Transport event fields
                        
                        .. attribute:: packet_loss
                        
                        	Transport event packet\-loss fields
                        	**type**\:  :py:class:`PacketLoss <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Event.PacketLoss>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Transport.Event, self).__init__()

                            self.yang_name = "event"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("packet-loss", ("packet_loss", Native.Flow.Record.Collect.Transport.Event.PacketLoss))])
                            self._leafs = OrderedDict()

                            self.packet_loss = Native.Flow.Record.Collect.Transport.Event.PacketLoss()
                            self.packet_loss.parent = self
                            self._children_name_map["packet_loss"] = "packet-loss"
                            self._segment_path = lambda: "event"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Transport.Event, [], name, value)


                        class PacketLoss(Entity):
                            """
                            Transport event packet\-loss fields
                            
                            .. attribute:: counter
                            
                            	Count of sets of packets that were lost
                            	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Event.PacketLoss.Counter>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Event.PacketLoss, self).__init__()

                                self.yang_name = "packet-loss"
                                self.yang_parent_name = "event"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Collect.Transport.Event.PacketLoss.Counter))])
                                self._leafs = OrderedDict()

                                self.counter = None
                                self._children_name_map["counter"] = "counter"
                                self._segment_path = lambda: "packet-loss"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Event.PacketLoss, [], name, value)


                            class Counter(Entity):
                                """
                                Count of sets of packets that were lost
                                
                                .. attribute:: max
                                
                                	Highest packet loss counter when multiple flows are aggregated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Lowest packet loss counter when multiple flows are aggregated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Transport.Event.PacketLoss.Counter, self).__init__()

                                    self.yang_name = "counter"
                                    self.yang_parent_name = "packet-loss"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self._segment_path = lambda: "counter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Transport.Event.PacketLoss.Counter, ['max', 'min'], name, value)


                    class Packets(Entity):
                        """
                        Transport packet fields
                        
                        .. attribute:: expected
                        
                        	Transport packets expected fields
                        	**type**\:  :py:class:`Expected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Packets.Expected>`
                        
                        .. attribute:: lost
                        
                        	Transport packets lost fields
                        	**type**\:  :py:class:`Lost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Packets.Lost>`
                        
                        .. attribute:: out_of_order
                        
                        	Total number of out\-of\-order bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Transport.Packets, self).__init__()

                            self.yang_name = "packets"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("expected", ("expected", Native.Flow.Record.Collect.Transport.Packets.Expected)), ("lost", ("lost", Native.Flow.Record.Collect.Transport.Packets.Lost))])
                            self._leafs = OrderedDict([
                                ('out_of_order', (YLeaf(YType.empty, 'out-of-order'), ['Empty'])),
                            ])
                            self.out_of_order = None

                            self.expected = Native.Flow.Record.Collect.Transport.Packets.Expected()
                            self.expected.parent = self
                            self._children_name_map["expected"] = "expected"

                            self.lost = Native.Flow.Record.Collect.Transport.Packets.Lost()
                            self.lost.parent = self
                            self._children_name_map["lost"] = "lost"
                            self._segment_path = lambda: "packets"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Transport.Packets, ['out_of_order'], name, value)


                        class Expected(Entity):
                            """
                            Transport packets expected fields
                            
                            .. attribute:: counter
                            
                            	Expected number of packets from sequencing information
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Packets.Expected, self).__init__()

                                self.yang_name = "expected"
                                self.yang_parent_name = "packets"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('counter', (YLeaf(YType.empty, 'counter'), ['Empty'])),
                                ])
                                self.counter = None
                                self._segment_path = lambda: "expected"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Packets.Expected, ['counter'], name, value)


                        class Lost(Entity):
                            """
                            Transport packets lost fields
                            
                            .. attribute:: counter
                            
                            	A count of the number of lost packets from sequencing information
                            	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Packets.Lost.Counter>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: rate
                            
                            	Packet loss rate from sequencing information
                            	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Packets.Lost.Rate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Packets.Lost, self).__init__()

                                self.yang_name = "lost"
                                self.yang_parent_name = "packets"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Collect.Transport.Packets.Lost.Counter)), ("rate", ("rate", Native.Flow.Record.Collect.Transport.Packets.Lost.Rate))])
                                self._leafs = OrderedDict()

                                self.counter = None
                                self._children_name_map["counter"] = "counter"

                                self.rate = None
                                self._children_name_map["rate"] = "rate"
                                self._segment_path = lambda: "lost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Packets.Lost, [], name, value)


                            class Counter(Entity):
                                """
                                A count of the number of lost packets from sequencing information
                                
                                .. attribute:: max
                                
                                	Highest lost packet count seen among the aggregated flows
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Lowest lost packet count seen among the aggregated flows
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Transport.Packets.Lost.Counter, self).__init__()

                                    self.yang_name = "counter"
                                    self.yang_parent_name = "lost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self._segment_path = lambda: "counter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Transport.Packets.Lost.Counter, ['max', 'min'], name, value)


                            class Rate(Entity):
                                """
                                Packet loss rate from sequencing information
                                
                                .. attribute:: max
                                
                                	Maximum packet loss rate in the aggregated flows
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Minimum packet loss rate in the aggregated flows
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Transport.Packets.Lost.Rate, self).__init__()

                                    self.yang_name = "rate"
                                    self.yang_parent_name = "lost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self._segment_path = lambda: "rate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Transport.Packets.Lost.Rate, ['max', 'min'], name, value)


                    class RoundTripTime(Entity):
                        """
                        RTT calculation for flow
                        
                        .. attribute:: max
                        
                        	Highest RTT among all flows
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: min
                        
                        	Lowest RTT among all flows
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: samples
                        
                        	RTT samples
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: sum
                        
                        	Sum RTT for all flows
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Transport.RoundTripTime, self).__init__()

                            self.yang_name = "round-trip-time"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                ('samples', (YLeaf(YType.empty, 'samples'), ['Empty'])),
                                ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                            ])
                            self.max = None
                            self.min = None
                            self.samples = None
                            self.sum = None
                            self._segment_path = lambda: "round-trip-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Transport.RoundTripTime, ['max', 'min', 'samples', 'sum'], name, value)


                    class Rtp(Entity):
                        """
                        RTP fields
                        
                        .. attribute:: flow
                        
                        	RTP  flow
                        	**type**\:  :py:class:`Flow_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Rtp.Flow_>`
                        
                        .. attribute:: jitter
                        
                        	RTP jitter fields
                        	**type**\:  :py:class:`Jitter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Rtp.Jitter>`
                        
                        .. attribute:: payload_type
                        
                        	RTP payload type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ssrc
                        
                        	RTP SSRC
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Collect.Transport.Rtp, self).__init__()

                            self.yang_name = "rtp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("flow", ("flow", Native.Flow.Record.Collect.Transport.Rtp.Flow_)), ("jitter", ("jitter", Native.Flow.Record.Collect.Transport.Rtp.Jitter))])
                            self._leafs = OrderedDict([
                                ('payload_type', (YLeaf(YType.empty, 'payload-type'), ['Empty'])),
                                ('ssrc', (YLeaf(YType.empty, 'ssrc'), ['Empty'])),
                            ])
                            self.payload_type = None
                            self.ssrc = None

                            self.flow = Native.Flow.Record.Collect.Transport.Rtp.Flow_()
                            self.flow.parent = self
                            self._children_name_map["flow"] = "flow"

                            self.jitter = Native.Flow.Record.Collect.Transport.Rtp.Jitter()
                            self.jitter.parent = self
                            self._children_name_map["jitter"] = "jitter"
                            self._segment_path = lambda: "rtp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Collect.Transport.Rtp, ['payload_type', 'ssrc'], name, value)


                        class Flow_(Entity):
                            """
                            RTP  flow
                            
                            .. attribute:: count
                            
                            	Number of RTP flows
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Rtp.Flow_, self).__init__()

                                self.yang_name = "flow"
                                self.yang_parent_name = "rtp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('count', (YLeaf(YType.empty, 'count'), ['Empty'])),
                                ])
                                self.count = None
                                self._segment_path = lambda: "flow"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Rtp.Flow_, ['count'], name, value)


                        class Jitter(Entity):
                            """
                            RTP jitter fields
                            
                            .. attribute:: maximum
                            
                            	Maximum jitter for the RTP stream
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mean
                            
                            	Mean jitter for the RTP stream
                            	**type**\:  :py:class:`Mean <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Collect.Transport.Rtp.Jitter.Mean>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: minimum
                            
                            	Minimum jitter for the RTP stream
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Collect.Transport.Rtp.Jitter, self).__init__()

                                self.yang_name = "jitter"
                                self.yang_parent_name = "rtp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mean", ("mean", Native.Flow.Record.Collect.Transport.Rtp.Jitter.Mean))])
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None

                                self.mean = None
                                self._children_name_map["mean"] = "mean"
                                self._segment_path = lambda: "jitter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Collect.Transport.Rtp.Jitter, ['maximum', 'minimum'], name, value)


                            class Mean(Entity):
                                """
                                Mean jitter for the RTP stream
                                
                                .. attribute:: sum
                                
                                	The sum of jitter mean for the RTP stream
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Collect.Transport.Rtp.Jitter.Mean, self).__init__()

                                    self.yang_name = "mean"
                                    self.yang_parent_name = "jitter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.sum = None
                                    self._segment_path = lambda: "mean"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Collect.Transport.Rtp.Jitter.Mean, ['sum'], name, value)


            class Default(Entity):
                """
                Set a command to its defaults
                
                .. attribute:: collect
                
                	Specify a non\-key field
                	**type**\:  :py:class:`Collect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect>`
                
                .. attribute:: description
                
                	Provide a description for this Flow Record
                	**type**\: str
                
                .. attribute:: match
                
                	Specify a key field
                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match>`
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Record.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "record"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("collect", ("collect", Native.Flow.Record.Default.Collect)), ("match", ("match", Native.Flow.Record.Default.Match))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.collect = Native.Flow.Record.Default.Collect()
                    self.collect.parent = self
                    self._children_name_map["collect"] = "collect"

                    self.match = Native.Flow.Record.Default.Match()
                    self.match.parent = self
                    self._children_name_map["match"] = "match"
                    self._segment_path = lambda: "default"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Record.Default, ['description'], name, value)


                class Collect(Entity):
                    """
                    Specify a non\-key field
                    
                    .. attribute:: application
                    
                    	Application fields
                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application>`
                    
                    .. attribute:: connection
                    
                    	Connection fields
                    	**type**\:  :py:class:`Connection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection>`
                    
                    .. attribute:: counter
                    
                    	Counter fields
                    	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Counter>`
                    
                    .. attribute:: datalink
                    
                    	Datalink (layer2) fields
                    	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Datalink>`
                    
                    .. attribute:: flow
                    
                    	Flow identifying fields
                    	**type**\:  :py:class:`Flow_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Flow_>`
                    
                    .. attribute:: interface
                    
                    	Interface fields
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Interface>`
                    
                    .. attribute:: ipv4
                    
                    	IPv4 fields
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 fields
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6>`
                    
                    .. attribute:: metadata
                    
                    	Metadata fields
                    	**type**\:  :py:class:`Metadata <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Metadata>`
                    
                    .. attribute:: monitor
                    
                    	monitor fields
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Monitor>`
                    
                    .. attribute:: mpls
                    
                    	MPLS fields
                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Mpls>`
                    
                    .. attribute:: network
                    
                    	network metrics
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Network>`
                    
                    .. attribute:: pfr
                    
                    	PfR metrics
                    	**type**\:  :py:class:`Pfr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr>`
                    
                    .. attribute:: policy
                    
                    	policy fields
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Policy>`
                    
                    .. attribute:: routing
                    
                    	Routing attributes
                    	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing>`
                    
                    .. attribute:: services
                    
                    	Services fields
                    	**type**\:  :py:class:`Services <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Services>`
                    
                    .. attribute:: timestamp
                    
                    	Timestamp fields
                    	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Timestamp>`
                    
                    .. attribute:: transport
                    
                    	Transport layer fields
                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Default.Collect, self).__init__()

                        self.yang_name = "collect"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("application", ("application", Native.Flow.Record.Default.Collect.Application)), ("connection", ("connection", Native.Flow.Record.Default.Collect.Connection)), ("counter", ("counter", Native.Flow.Record.Default.Collect.Counter)), ("datalink", ("datalink", Native.Flow.Record.Default.Collect.Datalink)), ("flow", ("flow", Native.Flow.Record.Default.Collect.Flow_)), ("interface", ("interface", Native.Flow.Record.Default.Collect.Interface)), ("ipv4", ("ipv4", Native.Flow.Record.Default.Collect.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Default.Collect.Ipv6)), ("metadata", ("metadata", Native.Flow.Record.Default.Collect.Metadata)), ("monitor", ("monitor", Native.Flow.Record.Default.Collect.Monitor)), ("mpls", ("mpls", Native.Flow.Record.Default.Collect.Mpls)), ("network", ("network", Native.Flow.Record.Default.Collect.Network)), ("pfr", ("pfr", Native.Flow.Record.Default.Collect.Pfr)), ("policy", ("policy", Native.Flow.Record.Default.Collect.Policy)), ("routing", ("routing", Native.Flow.Record.Default.Collect.Routing)), ("services", ("services", Native.Flow.Record.Default.Collect.Services)), ("timestamp", ("timestamp", Native.Flow.Record.Default.Collect.Timestamp)), ("transport", ("transport", Native.Flow.Record.Default.Collect.Transport))])
                        self._leafs = OrderedDict()

                        self.application = Native.Flow.Record.Default.Collect.Application()
                        self.application.parent = self
                        self._children_name_map["application"] = "application"

                        self.connection = Native.Flow.Record.Default.Collect.Connection()
                        self.connection.parent = self
                        self._children_name_map["connection"] = "connection"

                        self.counter = Native.Flow.Record.Default.Collect.Counter()
                        self.counter.parent = self
                        self._children_name_map["counter"] = "counter"

                        self.datalink = Native.Flow.Record.Default.Collect.Datalink()
                        self.datalink.parent = self
                        self._children_name_map["datalink"] = "datalink"

                        self.flow = Native.Flow.Record.Default.Collect.Flow_()
                        self.flow.parent = self
                        self._children_name_map["flow"] = "flow"

                        self.interface = Native.Flow.Record.Default.Collect.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"

                        self.ipv4 = Native.Flow.Record.Default.Collect.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Flow.Record.Default.Collect.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.metadata = Native.Flow.Record.Default.Collect.Metadata()
                        self.metadata.parent = self
                        self._children_name_map["metadata"] = "metadata"

                        self.monitor = Native.Flow.Record.Default.Collect.Monitor()
                        self.monitor.parent = self
                        self._children_name_map["monitor"] = "monitor"

                        self.mpls = Native.Flow.Record.Default.Collect.Mpls()
                        self.mpls.parent = self
                        self._children_name_map["mpls"] = "mpls"

                        self.network = Native.Flow.Record.Default.Collect.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.pfr = Native.Flow.Record.Default.Collect.Pfr()
                        self.pfr.parent = self
                        self._children_name_map["pfr"] = "pfr"

                        self.policy = Native.Flow.Record.Default.Collect.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.routing = Native.Flow.Record.Default.Collect.Routing()
                        self.routing.parent = self
                        self._children_name_map["routing"] = "routing"

                        self.services = Native.Flow.Record.Default.Collect.Services()
                        self.services.parent = self
                        self._children_name_map["services"] = "services"

                        self.timestamp = Native.Flow.Record.Default.Collect.Timestamp()
                        self.timestamp.parent = self
                        self._children_name_map["timestamp"] = "timestamp"

                        self.transport = Native.Flow.Record.Default.Collect.Transport()
                        self.transport.parent = self
                        self._children_name_map["transport"] = "transport"
                        self._segment_path = lambda: "collect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Default.Collect, [], name, value)


                    class Application(Entity):
                        """
                        Application fields
                        
                        .. attribute:: dns
                        
                        	Domain Name Server lookup
                        	**type**\:  :py:class:`Dns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Dns>`
                        
                        .. attribute:: http
                        
                        	World Wide Web traffic
                        	**type**\:  :py:class:`Http <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Http>`
                        
                        .. attribute:: media
                        
                        	Media fields
                        	**type**\:  :py:class:`Media <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Media>`
                        
                        .. attribute:: name
                        
                        	Application name
                        	**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Name>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: nntp
                        
                        	Network news transfer protocol
                        	**type**\:  :py:class:`Nntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Nntp>`
                        
                        .. attribute:: pop3
                        
                        	Post Office Protocol 3
                        	**type**\:  :py:class:`Pop3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Pop3>`
                        
                        .. attribute:: rtmp
                        
                        	Real Time Messaging Protocol
                        	**type**\:  :py:class:`Rtmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Rtmp>`
                        
                        .. attribute:: rtsp
                        
                        	Real Time Streaming Protocol
                        	**type**\:  :py:class:`Rtsp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Rtsp>`
                        
                        .. attribute:: sip
                        
                        	Session Initiation Protocol
                        	**type**\:  :py:class:`Sip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Sip>`
                        
                        .. attribute:: smtp
                        
                        	Simple Mail Transfer Protocol
                        	**type**\:  :py:class:`Smtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Smtp>`
                        
                        .. attribute:: ssl
                        
                        	Secure Socket Layer Protocol
                        	**type**\:  :py:class:`Ssl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Ssl>`
                        
                        .. attribute:: vendor
                        
                        	Application vendor id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: version
                        
                        	Application version id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Application, self).__init__()

                            self.yang_name = "application"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dns", ("dns", Native.Flow.Record.Default.Collect.Application.Dns)), ("http", ("http", Native.Flow.Record.Default.Collect.Application.Http)), ("media", ("media", Native.Flow.Record.Default.Collect.Application.Media)), ("name", ("name", Native.Flow.Record.Default.Collect.Application.Name)), ("nntp", ("nntp", Native.Flow.Record.Default.Collect.Application.Nntp)), ("pop3", ("pop3", Native.Flow.Record.Default.Collect.Application.Pop3)), ("rtmp", ("rtmp", Native.Flow.Record.Default.Collect.Application.Rtmp)), ("rtsp", ("rtsp", Native.Flow.Record.Default.Collect.Application.Rtsp)), ("sip", ("sip", Native.Flow.Record.Default.Collect.Application.Sip)), ("smtp", ("smtp", Native.Flow.Record.Default.Collect.Application.Smtp)), ("ssl", ("ssl", Native.Flow.Record.Default.Collect.Application.Ssl))])
                            self._leafs = OrderedDict([
                                ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                            ])
                            self.vendor = None
                            self.version = None

                            self.dns = Native.Flow.Record.Default.Collect.Application.Dns()
                            self.dns.parent = self
                            self._children_name_map["dns"] = "dns"

                            self.http = Native.Flow.Record.Default.Collect.Application.Http()
                            self.http.parent = self
                            self._children_name_map["http"] = "http"

                            self.media = Native.Flow.Record.Default.Collect.Application.Media()
                            self.media.parent = self
                            self._children_name_map["media"] = "media"

                            self.name = None
                            self._children_name_map["name"] = "name"

                            self.nntp = Native.Flow.Record.Default.Collect.Application.Nntp()
                            self.nntp.parent = self
                            self._children_name_map["nntp"] = "nntp"

                            self.pop3 = Native.Flow.Record.Default.Collect.Application.Pop3()
                            self.pop3.parent = self
                            self._children_name_map["pop3"] = "pop3"

                            self.rtmp = Native.Flow.Record.Default.Collect.Application.Rtmp()
                            self.rtmp.parent = self
                            self._children_name_map["rtmp"] = "rtmp"

                            self.rtsp = Native.Flow.Record.Default.Collect.Application.Rtsp()
                            self.rtsp.parent = self
                            self._children_name_map["rtsp"] = "rtsp"

                            self.sip = Native.Flow.Record.Default.Collect.Application.Sip()
                            self.sip.parent = self
                            self._children_name_map["sip"] = "sip"

                            self.smtp = Native.Flow.Record.Default.Collect.Application.Smtp()
                            self.smtp.parent = self
                            self._children_name_map["smtp"] = "smtp"

                            self.ssl = Native.Flow.Record.Default.Collect.Application.Ssl()
                            self.ssl.parent = self
                            self._children_name_map["ssl"] = "ssl"
                            self._segment_path = lambda: "application"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Application, ['vendor', 'version'], name, value)


                        class Dns(Entity):
                            """
                            Domain Name Server lookup
                            
                            .. attribute:: domain_name
                            
                            	Domain name
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Application.Dns, self).__init__()

                                self.yang_name = "dns"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain_name', (YLeaf(YType.empty, 'domain-name'), ['Empty'])),
                                ])
                                self.domain_name = None
                                self._segment_path = lambda: "dns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Dns, ['domain_name'], name, value)


                        class Http(Entity):
                            """
                            World Wide Web traffic
                            
                            .. attribute:: host
                            
                            	Host name of Origin Server containing resource
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: referer
                            
                            	Address the resource request was obtained from
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: uri
                            
                            	List of URIs and associated hit counts
                            	**type**\:  :py:class:`Uri <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Http.Uri>`
                            
                            .. attribute:: url
                            
                            	Uniform Resource Locator path
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: user_agent
                            
                            	Software used by agent sending the request
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Application.Http, self).__init__()

                                self.yang_name = "http"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("uri", ("uri", Native.Flow.Record.Default.Collect.Application.Http.Uri))])
                                self._leafs = OrderedDict([
                                    ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                    ('referer', (YLeaf(YType.empty, 'referer'), ['Empty'])),
                                    ('url', (YLeaf(YType.empty, 'url'), ['Empty'])),
                                    ('user_agent', (YLeaf(YType.empty, 'user-agent'), ['Empty'])),
                                ])
                                self.host = None
                                self.referer = None
                                self.url = None
                                self.user_agent = None

                                self.uri = Native.Flow.Record.Default.Collect.Application.Http.Uri()
                                self.uri.parent = self
                                self._children_name_map["uri"] = "uri"
                                self._segment_path = lambda: "http"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Http, ['host', 'referer', 'url', 'user_agent'], name, value)


                            class Uri(Entity):
                                """
                                List of URIs and associated hit counts
                                
                                .. attribute:: statistics
                                
                                	Collect URI statistics
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Application.Http.Uri, self).__init__()

                                    self.yang_name = "uri"
                                    self.yang_parent_name = "http"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('statistics', (YLeaf(YType.empty, 'statistics'), ['Empty'])),
                                    ])
                                    self.statistics = None
                                    self._segment_path = lambda: "uri"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Http.Uri, ['statistics'], name, value)


                        class Media(Entity):
                            """
                            Media fields
                            
                            .. attribute:: bytes
                            
                            	Media fields
                            	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Media.Bytes>`
                            
                            .. attribute:: event
                            
                            	Flags indicating media events
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: packets
                            
                            	Media fields
                            	**type**\:  :py:class:`Packets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Media.Packets>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Application.Media, self).__init__()

                                self.yang_name = "media"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Default.Collect.Application.Media.Bytes)), ("packets", ("packets", Native.Flow.Record.Default.Collect.Application.Media.Packets))])
                                self._leafs = OrderedDict([
                                    ('event', (YLeaf(YType.empty, 'event'), ['Empty'])),
                                ])
                                self.event = None

                                self.bytes = Native.Flow.Record.Default.Collect.Application.Media.Bytes()
                                self.bytes.parent = self
                                self._children_name_map["bytes"] = "bytes"

                                self.packets = Native.Flow.Record.Default.Collect.Application.Media.Packets()
                                self.packets.parent = self
                                self._children_name_map["packets"] = "packets"
                                self._segment_path = lambda: "media"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Media, ['event'], name, value)


                            class Bytes(Entity):
                                """
                                Media fields
                                
                                .. attribute:: counter
                                
                                	A count of the number of bytes of media payload
                                	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Media.Bytes.Counter>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: rate
                                
                                	Byte rate for the media stream
                                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Media.Bytes.Rate>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Application.Media.Bytes, self).__init__()

                                    self.yang_name = "bytes"
                                    self.yang_parent_name = "media"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Default.Collect.Application.Media.Bytes.Counter)), ("rate", ("rate", Native.Flow.Record.Default.Collect.Application.Media.Bytes.Rate))])
                                    self._leafs = OrderedDict()

                                    self.counter = None
                                    self._children_name_map["counter"] = "counter"

                                    self.rate = None
                                    self._children_name_map["rate"] = "rate"
                                    self._segment_path = lambda: "bytes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Media.Bytes, [], name, value)


                                class Counter(Entity):
                                    """
                                    A count of the number of bytes of media payload
                                    
                                    .. attribute:: long
                                    
                                    	A count of the number of bytes of media payload (64 bit counter)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Application.Media.Bytes.Counter, self).__init__()

                                        self.yang_name = "counter"
                                        self.yang_parent_name = "bytes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self._segment_path = lambda: "counter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Media.Bytes.Counter, ['long'], name, value)


                                class Rate(Entity):
                                    """
                                    Byte rate for the media stream
                                    
                                    .. attribute:: per_flow
                                    
                                    	Average media byte rate across flows
                                    	**type**\:  :py:class:`PerFlow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Media.Bytes.Rate.PerFlow>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Application.Media.Bytes.Rate, self).__init__()

                                        self.yang_name = "rate"
                                        self.yang_parent_name = "bytes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("per-flow", ("per_flow", Native.Flow.Record.Default.Collect.Application.Media.Bytes.Rate.PerFlow))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.per_flow = None
                                        self._children_name_map["per_flow"] = "per-flow"
                                        self._segment_path = lambda: "rate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Media.Bytes.Rate, [], name, value)


                                    class PerFlow(Entity):
                                        """
                                        Average media byte rate across flows
                                        
                                        .. attribute:: max
                                        
                                        	Maximum byte rate in the media stream
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: min
                                        
                                        	Minumun byte rate in the media stream
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Collect.Application.Media.Bytes.Rate.PerFlow, self).__init__()

                                            self.yang_name = "per-flow"
                                            self.yang_parent_name = "rate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                                ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                            ])
                                            self.max = None
                                            self.min = None
                                            self._segment_path = lambda: "per-flow"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Media.Bytes.Rate.PerFlow, ['max', 'min'], name, value)


                            class Packets(Entity):
                                """
                                Media fields
                                
                                .. attribute:: counter
                                
                                	A count of the number of packets with a media payload
                                	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Media.Packets.Counter>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: rate
                                
                                	Packet rate for the media stream
                                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Media.Packets.Rate>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Application.Media.Packets, self).__init__()

                                    self.yang_name = "packets"
                                    self.yang_parent_name = "media"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Default.Collect.Application.Media.Packets.Counter)), ("rate", ("rate", Native.Flow.Record.Default.Collect.Application.Media.Packets.Rate))])
                                    self._leafs = OrderedDict()

                                    self.counter = None
                                    self._children_name_map["counter"] = "counter"

                                    self.rate = None
                                    self._children_name_map["rate"] = "rate"
                                    self._segment_path = lambda: "packets"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Media.Packets, [], name, value)


                                class Counter(Entity):
                                    """
                                    A count of the number of packets with a media payload
                                    
                                    .. attribute:: long
                                    
                                    	A count of the number of packets with a media payload (64 bit counter)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Application.Media.Packets.Counter, self).__init__()

                                        self.yang_name = "counter"
                                        self.yang_parent_name = "packets"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self._segment_path = lambda: "counter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Media.Packets.Counter, ['long'], name, value)


                                class Rate(Entity):
                                    """
                                    Packet rate for the media stream
                                    
                                    .. attribute:: variation
                                    
                                    	Variation in packet rate from configured expected rate
                                    	**type**\:  :py:class:`Variation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Application.Media.Packets.Rate.Variation>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Application.Media.Packets.Rate, self).__init__()

                                        self.yang_name = "rate"
                                        self.yang_parent_name = "packets"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("variation", ("variation", Native.Flow.Record.Default.Collect.Application.Media.Packets.Rate.Variation))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.variation = None
                                        self._children_name_map["variation"] = "variation"
                                        self._segment_path = lambda: "rate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Media.Packets.Rate, [], name, value)


                                    class Variation(Entity):
                                        """
                                        Variation in packet rate from configured expected rate
                                        
                                        .. attribute:: max
                                        
                                        	Max variation in packet rate from configured expected rate
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: min
                                        
                                        	Variation in packet rate from configured expected rate
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: sum
                                        
                                        	The sum of media rate variation from the configured rate for the RTP stream
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Collect.Application.Media.Packets.Rate.Variation, self).__init__()

                                            self.yang_name = "variation"
                                            self.yang_parent_name = "rate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                                ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                                ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                            ])
                                            self.max = None
                                            self.min = None
                                            self.sum = None
                                            self._segment_path = lambda: "variation"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Media.Packets.Rate.Variation, ['max', 'min', 'sum'], name, value)


                        class Name(Entity):
                            """
                            Application name
                            
                            .. attribute:: account_on_resolution
                            
                            	Account on resolution
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Application.Name, self).__init__()

                                self.yang_name = "name"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('account_on_resolution', (YLeaf(YType.empty, 'account-on-resolution'), ['Empty'])),
                                ])
                                self.account_on_resolution = None
                                self._segment_path = lambda: "name"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Name, ['account_on_resolution'], name, value)


                        class Nntp(Entity):
                            """
                            Network news transfer protocol
                            
                            .. attribute:: group_name
                            
                            	NNTP Group name
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Application.Nntp, self).__init__()

                                self.yang_name = "nntp"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group_name', (YLeaf(YType.empty, 'group-name'), ['Empty'])),
                                ])
                                self.group_name = None
                                self._segment_path = lambda: "nntp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Nntp, ['group_name'], name, value)


                        class Pop3(Entity):
                            """
                            Post Office Protocol 3
                            
                            .. attribute:: server
                            
                            	POP3 Server Name
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Application.Pop3, self).__init__()

                                self.yang_name = "pop3"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                                ])
                                self.server = None
                                self._segment_path = lambda: "pop3"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Pop3, ['server'], name, value)


                        class Rtmp(Entity):
                            """
                            Real Time Messaging Protocol
                            
                            .. attribute:: pageurl
                            
                            	RTMP page url address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Application.Rtmp, self).__init__()

                                self.yang_name = "rtmp"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pageurl', (YLeaf(YType.empty, 'pageUrl'), ['Empty'])),
                                ])
                                self.pageurl = None
                                self._segment_path = lambda: "rtmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Rtmp, ['pageurl'], name, value)


                        class Rtsp(Entity):
                            """
                            Real Time Streaming Protocol
                            
                            .. attribute:: host
                            
                            	RTSP Host Name
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Application.Rtsp, self).__init__()

                                self.yang_name = "rtsp"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ])
                                self.host = None
                                self._segment_path = lambda: "rtsp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Rtsp, ['host'], name, value)


                        class Sip(Entity):
                            """
                            Session Initiation Protocol
                            
                            .. attribute:: destination
                            
                            	The destination domain of SIP transactions
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: source
                            
                            	The source domain of SIP transactions
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Application.Sip, self).__init__()

                                self.yang_name = "sip"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('destination', (YLeaf(YType.empty, 'destination'), ['Empty'])),
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                ])
                                self.destination = None
                                self.source = None
                                self._segment_path = lambda: "sip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Sip, ['destination', 'source'], name, value)


                        class Smtp(Entity):
                            """
                            Simple Mail Transfer Protocol
                            
                            .. attribute:: sender
                            
                            	SMTP Sender Mail Address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: server
                            
                            	SMTP Server Name
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Application.Smtp, self).__init__()

                                self.yang_name = "smtp"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sender', (YLeaf(YType.empty, 'sender'), ['Empty'])),
                                    ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                                ])
                                self.sender = None
                                self.server = None
                                self._segment_path = lambda: "smtp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Smtp, ['sender', 'server'], name, value)


                        class Ssl(Entity):
                            """
                            Secure Socket Layer Protocol
                            
                            .. attribute:: common_name
                            
                            	Certificate Common Name (CN)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Application.Ssl, self).__init__()

                                self.yang_name = "ssl"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common_name', (YLeaf(YType.empty, 'common-name'), ['Empty'])),
                                ])
                                self.common_name = None
                                self._segment_path = lambda: "ssl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Application.Ssl, ['common_name'], name, value)


                    class Connection(Entity):
                        """
                        Connection fields
                        
                        .. attribute:: client
                        
                        	Client side (flow initiator) related metrics
                        	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Client>`
                        
                        .. attribute:: delay
                        
                        	Connection delay metrics
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay>`
                        
                        .. attribute:: id
                        
                        	An identifier for a connection between client and server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: initiator
                        
                        	The direction of the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: new_connections
                        
                        	The number of connection initiations observed
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: server
                        
                        	Server side (flow responder) related metrics
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Server>`
                        
                        .. attribute:: sum_duration
                        
                        	The overall time in seconds for all connections
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: transaction
                        
                        	Transaction related metrics
                        	**type**\:  :py:class:`Transaction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Transaction>`
                        
                        .. attribute:: transaction_id
                        
                        	An identifier for a transaction between client and server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Connection, self).__init__()

                            self.yang_name = "connection"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client", ("client", Native.Flow.Record.Default.Collect.Connection.Client)), ("delay", ("delay", Native.Flow.Record.Default.Collect.Connection.Delay)), ("server", ("server", Native.Flow.Record.Default.Collect.Connection.Server)), ("transaction", ("transaction", Native.Flow.Record.Default.Collect.Connection.Transaction))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                                ('initiator', (YLeaf(YType.empty, 'initiator'), ['Empty'])),
                                ('new_connections', (YLeaf(YType.empty, 'new-connections'), ['Empty'])),
                                ('sum_duration', (YLeaf(YType.empty, 'sum-duration'), ['Empty'])),
                                ('transaction_id', (YLeaf(YType.empty, 'transaction-id'), ['Empty'])),
                            ])
                            self.id = None
                            self.initiator = None
                            self.new_connections = None
                            self.sum_duration = None
                            self.transaction_id = None

                            self.client = Native.Flow.Record.Default.Collect.Connection.Client()
                            self.client.parent = self
                            self._children_name_map["client"] = "client"

                            self.delay = Native.Flow.Record.Default.Collect.Connection.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"

                            self.server = Native.Flow.Record.Default.Collect.Connection.Server()
                            self.server.parent = self
                            self._children_name_map["server"] = "server"

                            self.transaction = Native.Flow.Record.Default.Collect.Connection.Transaction()
                            self.transaction.parent = self
                            self._children_name_map["transaction"] = "transaction"
                            self._segment_path = lambda: "connection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Connection, ['id', 'initiator', 'new_connections', 'sum_duration', 'transaction_id'], name, value)


                        class Client(Entity):
                            """
                            Client side (flow initiator) related metrics
                            
                            .. attribute:: all
                            
                            	All non\-key client metrics
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: counter
                            
                            	Client side counter metrics
                            	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Client.Counter>`
                            
                            .. attribute:: ipv4
                            
                            	Client side IPv4 metrics
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Client.Ipv4>`
                            
                            .. attribute:: ipv6
                            
                            	Client side IPv6 metrics
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Client.Ipv6>`
                            
                            .. attribute:: transport
                            
                            	Client side transport metrics
                            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Client.Transport>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Connection.Client, self).__init__()

                                self.yang_name = "client"
                                self.yang_parent_name = "connection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Default.Collect.Connection.Client.Counter)), ("ipv4", ("ipv4", Native.Flow.Record.Default.Collect.Connection.Client.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Default.Collect.Connection.Client.Ipv6)), ("transport", ("transport", Native.Flow.Record.Default.Collect.Connection.Client.Transport))])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None

                                self.counter = Native.Flow.Record.Default.Collect.Connection.Client.Counter()
                                self.counter.parent = self
                                self._children_name_map["counter"] = "counter"

                                self.ipv4 = Native.Flow.Record.Default.Collect.Connection.Client.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = Native.Flow.Record.Default.Collect.Connection.Client.Ipv6()
                                self.ipv6.parent = self
                                self._children_name_map["ipv6"] = "ipv6"

                                self.transport = Native.Flow.Record.Default.Collect.Connection.Client.Transport()
                                self.transport.parent = self
                                self._children_name_map["transport"] = "transport"
                                self._segment_path = lambda: "client"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Client, ['all'], name, value)


                            class Counter(Entity):
                                """
                                Client side counter metrics
                                
                                .. attribute:: bytes
                                
                                	Number of bytes sent by the client
                                	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes>`
                                
                                .. attribute:: packets
                                
                                	Number of packets sent by the client
                                	**type**\:  :py:class:`Packets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Client.Counter.Packets>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Client.Counter, self).__init__()

                                    self.yang_name = "counter"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes)), ("packets", ("packets", Native.Flow.Record.Default.Collect.Connection.Client.Counter.Packets))])
                                    self._leafs = OrderedDict()

                                    self.bytes = Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes()
                                    self.bytes.parent = self
                                    self._children_name_map["bytes"] = "bytes"

                                    self.packets = Native.Flow.Record.Default.Collect.Connection.Client.Counter.Packets()
                                    self.packets.parent = self
                                    self._children_name_map["packets"] = "packets"
                                    self._segment_path = lambda: "counter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Client.Counter, [], name, value)


                                class Bytes(Entity):
                                    """
                                    Number of bytes sent by the client
                                    
                                    .. attribute:: long
                                    
                                    	64 bits counter
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: network
                                    
                                    	Number of bytes sent by the client
                                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes.Network>`
                                    
                                    .. attribute:: retransmitted
                                    
                                    	Number of bytes retransmitted by the client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: transport
                                    
                                    	Number of bytes sent by the client
                                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes.Transport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes, self).__init__()

                                        self.yang_name = "bytes"
                                        self.yang_parent_name = "counter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("network", ("network", Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes.Network)), ("transport", ("transport", Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes.Transport))])
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                            ('retransmitted', (YLeaf(YType.empty, 'retransmitted'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self.retransmitted = None

                                        self.network = Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes.Network()
                                        self.network.parent = self
                                        self._children_name_map["network"] = "network"

                                        self.transport = Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes.Transport()
                                        self.transport.parent = self
                                        self._children_name_map["transport"] = "transport"
                                        self._segment_path = lambda: "bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes, ['long', 'retransmitted'], name, value)


                                    class Network(Entity):
                                        """
                                        Number of bytes sent by the client
                                        
                                        .. attribute:: long
                                        
                                        	Total number of bytes transmitted by the client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "bytes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                            ])
                                            self.long = None
                                            self._segment_path = lambda: "network"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes.Network, ['long'], name, value)


                                    class Transport(Entity):
                                        """
                                        Number of bytes sent by the client
                                        
                                        .. attribute:: long
                                        
                                        	64 bit counter
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes.Transport, self).__init__()

                                            self.yang_name = "transport"
                                            self.yang_parent_name = "bytes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                            ])
                                            self.long = None
                                            self._segment_path = lambda: "transport"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Client.Counter.Bytes.Transport, ['long'], name, value)


                                class Packets(Entity):
                                    """
                                    Number of packets sent by the client
                                    
                                    .. attribute:: long
                                    
                                    	64 bits counter
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: retransmitted
                                    
                                    	Number of packets retransmitted by the client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Connection.Client.Counter.Packets, self).__init__()

                                        self.yang_name = "packets"
                                        self.yang_parent_name = "counter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                            ('retransmitted', (YLeaf(YType.empty, 'retransmitted'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self.retransmitted = None
                                        self._segment_path = lambda: "packets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Client.Counter.Packets, ['long', 'retransmitted'], name, value)


                            class Ipv4(Entity):
                                """
                                Client side IPv4 metrics
                                
                                .. attribute:: address
                                
                                	IPv4 address of the flow initiator
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Client.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Client.Ipv4, ['address'], name, value)


                            class Ipv6(Entity):
                                """
                                Client side IPv6 metrics
                                
                                .. attribute:: address
                                
                                	IPv6 address of the flow initiator
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Client.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Client.Ipv6, ['address'], name, value)


                            class Transport(Entity):
                                """
                                Client side transport metrics
                                
                                .. attribute:: port
                                
                                	Transport port of the flow initiator
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Client.Transport, self).__init__()

                                    self.yang_name = "transport"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.empty, 'port'), ['Empty'])),
                                    ])
                                    self.port = None
                                    self._segment_path = lambda: "transport"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Client.Transport, ['port'], name, value)


                        class Delay(Entity):
                            """
                            Connection delay metrics
                            
                            .. attribute:: all
                            
                            	All non\-key client metrics
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: application
                            
                            	Application time metrics
                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Application>`
                            
                            .. attribute:: network
                            
                            	Network time metrics
                            	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Network>`
                            
                            .. attribute:: response
                            
                            	Response time metrics
                            	**type**\:  :py:class:`Response <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Response>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Connection.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "connection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("application", ("application", Native.Flow.Record.Default.Collect.Connection.Delay.Application)), ("network", ("network", Native.Flow.Record.Default.Collect.Connection.Delay.Network)), ("response", ("response", Native.Flow.Record.Default.Collect.Connection.Delay.Response))])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None

                                self.application = Native.Flow.Record.Default.Collect.Connection.Delay.Application()
                                self.application.parent = self
                                self._children_name_map["application"] = "application"

                                self.network = Native.Flow.Record.Default.Collect.Connection.Delay.Network()
                                self.network.parent = self
                                self._children_name_map["network"] = "network"

                                self.response = Native.Flow.Record.Default.Collect.Connection.Delay.Response()
                                self.response.parent = self
                                self._children_name_map["response"] = "response"
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay, ['all'], name, value)


                            class Application(Entity):
                                """
                                Application time metrics
                                
                                .. attribute:: max
                                
                                	Maximum application response time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Minimum application response time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sum
                                
                                	Total application response time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Delay.Application, self).__init__()

                                    self.yang_name = "application"
                                    self.yang_parent_name = "delay"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self.sum = None
                                    self._segment_path = lambda: "application"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Application, ['max', 'min', 'sum'], name, value)


                            class Network(Entity):
                                """
                                Network time metrics
                                
                                .. attribute:: client_to_server
                                
                                	RTT between the client and the server
                                	**type**\:  :py:class:`ClientToServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Network.ClientToServer>`
                                
                                .. attribute:: long_lived
                                
                                	Long\-lived network delay metrics
                                	**type**\:  :py:class:`LongLived <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived>`
                                
                                .. attribute:: to_client
                                
                                	RTT from observation point to the client
                                	**type**\:  :py:class:`ToClient <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Network.ToClient>`
                                
                                .. attribute:: to_server
                                
                                	RTT from observation point to the server
                                	**type**\:  :py:class:`ToServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Network.ToServer>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Delay.Network, self).__init__()

                                    self.yang_name = "network"
                                    self.yang_parent_name = "delay"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("client-to-server", ("client_to_server", Native.Flow.Record.Default.Collect.Connection.Delay.Network.ClientToServer)), ("long-lived", ("long_lived", Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived)), ("to-client", ("to_client", Native.Flow.Record.Default.Collect.Connection.Delay.Network.ToClient)), ("to-server", ("to_server", Native.Flow.Record.Default.Collect.Connection.Delay.Network.ToServer))])
                                    self._leafs = OrderedDict()

                                    self.client_to_server = Native.Flow.Record.Default.Collect.Connection.Delay.Network.ClientToServer()
                                    self.client_to_server.parent = self
                                    self._children_name_map["client_to_server"] = "client-to-server"

                                    self.long_lived = Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived()
                                    self.long_lived.parent = self
                                    self._children_name_map["long_lived"] = "long-lived"

                                    self.to_client = Native.Flow.Record.Default.Collect.Connection.Delay.Network.ToClient()
                                    self.to_client.parent = self
                                    self._children_name_map["to_client"] = "to-client"

                                    self.to_server = Native.Flow.Record.Default.Collect.Connection.Delay.Network.ToServer()
                                    self.to_server.parent = self
                                    self._children_name_map["to_server"] = "to-server"
                                    self._segment_path = lambda: "network"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Network, [], name, value)


                                class ClientToServer(Entity):
                                    """
                                    RTT between the client and the server
                                    
                                    .. attribute:: max
                                    
                                    	Maximum network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Minimum network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: num_samples
                                    
                                    	The number of CSND samples
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sum
                                    
                                    	Total network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Connection.Delay.Network.ClientToServer, self).__init__()

                                        self.yang_name = "client-to-server"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                            ('num_samples', (YLeaf(YType.empty, 'num-samples'), ['Empty'])),
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.max = None
                                        self.min = None
                                        self.num_samples = None
                                        self.sum = None
                                        self._segment_path = lambda: "client-to-server"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Network.ClientToServer, ['max', 'min', 'num_samples', 'sum'], name, value)


                                class LongLived(Entity):
                                    """
                                    Long\-lived network delay metrics
                                    
                                    .. attribute:: client_to_serve
                                    
                                    	Long\-lived network delay client\-to\-server metrics
                                    	**type**\:  :py:class:`ClientToServe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ClientToServe>`
                                    
                                    .. attribute:: to_client
                                    
                                    	Long\-lived network delay to\-client metrics
                                    	**type**\:  :py:class:`ToClient <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ToClient>`
                                    
                                    .. attribute:: to_serve
                                    
                                    	Long\-lived network delay to\-server metrics
                                    	**type**\:  :py:class:`ToServe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ToServe>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived, self).__init__()

                                        self.yang_name = "long-lived"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("client-to-serve", ("client_to_serve", Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ClientToServe)), ("to-client", ("to_client", Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ToClient)), ("to-serve", ("to_serve", Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ToServe))])
                                        self._leafs = OrderedDict()

                                        self.client_to_serve = Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ClientToServe()
                                        self.client_to_serve.parent = self
                                        self._children_name_map["client_to_serve"] = "client-to-serve"

                                        self.to_client = Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ToClient()
                                        self.to_client.parent = self
                                        self._children_name_map["to_client"] = "to-client"

                                        self.to_serve = Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ToServe()
                                        self.to_serve.parent = self
                                        self._children_name_map["to_serve"] = "to-serve"
                                        self._segment_path = lambda: "long-lived"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived, [], name, value)


                                    class ClientToServe(Entity):
                                        """
                                        Long\-lived network delay client\-to\-server metrics
                                        
                                        .. attribute:: sum
                                        
                                        	Total network time
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ClientToServe, self).__init__()

                                            self.yang_name = "client-to-serve"
                                            self.yang_parent_name = "long-lived"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                            ])
                                            self.sum = None
                                            self._segment_path = lambda: "client-to-serve"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ClientToServe, ['sum'], name, value)


                                    class ToClient(Entity):
                                        """
                                        Long\-lived network delay to\-client metrics
                                        
                                        .. attribute:: sum
                                        
                                        	Total network time
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ToClient, self).__init__()

                                            self.yang_name = "to-client"
                                            self.yang_parent_name = "long-lived"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                            ])
                                            self.sum = None
                                            self._segment_path = lambda: "to-client"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ToClient, ['sum'], name, value)


                                    class ToServe(Entity):
                                        """
                                        Long\-lived network delay to\-server metrics
                                        
                                        .. attribute:: sum
                                        
                                        	Total network time
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ToServe, self).__init__()

                                            self.yang_name = "to-serve"
                                            self.yang_parent_name = "long-lived"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                            ])
                                            self.sum = None
                                            self._segment_path = lambda: "to-serve"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Network.LongLived.ToServe, ['sum'], name, value)


                                class ToClient(Entity):
                                    """
                                    RTT from observation point to the client
                                    
                                    .. attribute:: max
                                    
                                    	Maximum network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Minimum network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: num_samples
                                    
                                    	The number of CND samples
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sum
                                    
                                    	Total network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Connection.Delay.Network.ToClient, self).__init__()

                                        self.yang_name = "to-client"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                            ('num_samples', (YLeaf(YType.empty, 'num-samples'), ['Empty'])),
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.max = None
                                        self.min = None
                                        self.num_samples = None
                                        self.sum = None
                                        self._segment_path = lambda: "to-client"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Network.ToClient, ['max', 'min', 'num_samples', 'sum'], name, value)


                                class ToServer(Entity):
                                    """
                                    RTT from observation point to the server
                                    
                                    .. attribute:: max
                                    
                                    	Maximum network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Minimum network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: num_samples
                                    
                                    	The number of SND samples
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sum
                                    
                                    	Total network time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Connection.Delay.Network.ToServer, self).__init__()

                                        self.yang_name = "to-server"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                            ('num_samples', (YLeaf(YType.empty, 'num-samples'), ['Empty'])),
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.max = None
                                        self.min = None
                                        self.num_samples = None
                                        self.sum = None
                                        self._segment_path = lambda: "to-server"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Network.ToServer, ['max', 'min', 'num_samples', 'sum'], name, value)


                            class Response(Entity):
                                """
                                Response time metrics
                                
                                .. attribute:: client_to_server
                                
                                	Response time as seen by the client
                                	**type**\:  :py:class:`ClientToServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Response.ClientToServer>`
                                
                                .. attribute:: to_server
                                
                                	Response time as seen from observation point
                                	**type**\:  :py:class:`ToServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Response.ToServer>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Delay.Response, self).__init__()

                                    self.yang_name = "response"
                                    self.yang_parent_name = "delay"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("client-to-server", ("client_to_server", Native.Flow.Record.Default.Collect.Connection.Delay.Response.ClientToServer)), ("to-server", ("to_server", Native.Flow.Record.Default.Collect.Connection.Delay.Response.ToServer))])
                                    self._leafs = OrderedDict()

                                    self.client_to_server = Native.Flow.Record.Default.Collect.Connection.Delay.Response.ClientToServer()
                                    self.client_to_server.parent = self
                                    self._children_name_map["client_to_server"] = "client-to-server"

                                    self.to_server = Native.Flow.Record.Default.Collect.Connection.Delay.Response.ToServer()
                                    self.to_server.parent = self
                                    self._children_name_map["to_server"] = "to-server"
                                    self._segment_path = lambda: "response"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Response, [], name, value)


                                class ClientToServer(Entity):
                                    """
                                    Response time as seen by the client
                                    
                                    .. attribute:: max
                                    
                                    	Maximum response time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Minimum response time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sum
                                    
                                    	Total response time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Connection.Delay.Response.ClientToServer, self).__init__()

                                        self.yang_name = "client-to-server"
                                        self.yang_parent_name = "response"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.max = None
                                        self.min = None
                                        self.sum = None
                                        self._segment_path = lambda: "client-to-server"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Response.ClientToServer, ['max', 'min', 'sum'], name, value)


                                class ToServer(Entity):
                                    """
                                    Response time as seen from observation point
                                    
                                    .. attribute:: histogram
                                    
                                    	Histogram for response time
                                    	**type**\:  :py:class:`Histogram <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Delay.Response.ToServer.Histogram>`
                                    
                                    .. attribute:: max
                                    
                                    	Maximum response time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Minimum response time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sum
                                    
                                    	Total response time
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Connection.Delay.Response.ToServer, self).__init__()

                                        self.yang_name = "to-server"
                                        self.yang_parent_name = "response"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('histogram', (YLeaf(YType.enumeration, 'histogram'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Flow.Record.Default.Collect.Connection.Delay.Response.ToServer.Histogram')])),
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.histogram = None
                                        self.max = None
                                        self.min = None
                                        self.sum = None
                                        self._segment_path = lambda: "to-server"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Delay.Response.ToServer, ['histogram', 'max', 'min', 'sum'], name, value)

                                    class Histogram(Enum):
                                        """
                                        Histogram (Enum Class)

                                        Histogram for response time

                                        .. data:: all = 0

                                        .. data:: bucket1 = 1

                                        .. data:: bucket2 = 2

                                        .. data:: bucket3 = 3

                                        .. data:: bucket4 = 4

                                        .. data:: bucket5 = 5

                                        .. data:: bucket6 = 6

                                        .. data:: bucket7 = 7

                                        .. data:: late = 8

                                        """

                                        all = Enum.YLeaf(0, "all")

                                        bucket1 = Enum.YLeaf(1, "bucket1")

                                        bucket2 = Enum.YLeaf(2, "bucket2")

                                        bucket3 = Enum.YLeaf(3, "bucket3")

                                        bucket4 = Enum.YLeaf(4, "bucket4")

                                        bucket5 = Enum.YLeaf(5, "bucket5")

                                        bucket6 = Enum.YLeaf(6, "bucket6")

                                        bucket7 = Enum.YLeaf(7, "bucket7")

                                        late = Enum.YLeaf(8, "late")



                        class Server(Entity):
                            """
                            Server side (flow responder) related metrics
                            
                            .. attribute:: all
                            
                            	All non\-key server metrics
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: counter
                            
                            	Server side counter metrics
                            	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Server.Counter>`
                            
                            .. attribute:: ipv4
                            
                            	Server side IPv4 metrics
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Server.Ipv4>`
                            
                            .. attribute:: ipv6
                            
                            	Server side IPv6 metrics
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Server.Ipv6>`
                            
                            .. attribute:: transport
                            
                            	Server side transport metrics
                            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Server.Transport>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Connection.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "connection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Default.Collect.Connection.Server.Counter)), ("ipv4", ("ipv4", Native.Flow.Record.Default.Collect.Connection.Server.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Default.Collect.Connection.Server.Ipv6)), ("transport", ("transport", Native.Flow.Record.Default.Collect.Connection.Server.Transport))])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None

                                self.counter = Native.Flow.Record.Default.Collect.Connection.Server.Counter()
                                self.counter.parent = self
                                self._children_name_map["counter"] = "counter"

                                self.ipv4 = Native.Flow.Record.Default.Collect.Connection.Server.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = Native.Flow.Record.Default.Collect.Connection.Server.Ipv6()
                                self.ipv6.parent = self
                                self._children_name_map["ipv6"] = "ipv6"

                                self.transport = Native.Flow.Record.Default.Collect.Connection.Server.Transport()
                                self.transport.parent = self
                                self._children_name_map["transport"] = "transport"
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Server, ['all'], name, value)


                            class Counter(Entity):
                                """
                                Server side counter metrics
                                
                                .. attribute:: bytes
                                
                                	Number of bytes sent by the server
                                	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes>`
                                
                                .. attribute:: packets
                                
                                	Number of packets sent by the server
                                	**type**\:  :py:class:`Packets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Server.Counter.Packets>`
                                
                                .. attribute:: responses
                                
                                	Number of responses sent by the server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Server.Counter, self).__init__()

                                    self.yang_name = "counter"
                                    self.yang_parent_name = "server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes)), ("packets", ("packets", Native.Flow.Record.Default.Collect.Connection.Server.Counter.Packets))])
                                    self._leafs = OrderedDict([
                                        ('responses', (YLeaf(YType.empty, 'responses'), ['Empty'])),
                                    ])
                                    self.responses = None

                                    self.bytes = Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes()
                                    self.bytes.parent = self
                                    self._children_name_map["bytes"] = "bytes"

                                    self.packets = Native.Flow.Record.Default.Collect.Connection.Server.Counter.Packets()
                                    self.packets.parent = self
                                    self._children_name_map["packets"] = "packets"
                                    self._segment_path = lambda: "counter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Server.Counter, ['responses'], name, value)


                                class Bytes(Entity):
                                    """
                                    Number of bytes sent by the server
                                    
                                    .. attribute:: long
                                    
                                    	64 bits counter
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: network
                                    
                                    	Number of bytes sent by the server
                                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes.Network>`
                                    
                                    .. attribute:: retransmitted
                                    
                                    	Number of bytes retransmitted by the server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: transport
                                    
                                    	Number of bytes sent by the server
                                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes.Transport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes, self).__init__()

                                        self.yang_name = "bytes"
                                        self.yang_parent_name = "counter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("network", ("network", Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes.Network)), ("transport", ("transport", Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes.Transport))])
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                            ('retransmitted', (YLeaf(YType.empty, 'retransmitted'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self.retransmitted = None

                                        self.network = Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes.Network()
                                        self.network.parent = self
                                        self._children_name_map["network"] = "network"

                                        self.transport = Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes.Transport()
                                        self.transport.parent = self
                                        self._children_name_map["transport"] = "transport"
                                        self._segment_path = lambda: "bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes, ['long', 'retransmitted'], name, value)


                                    class Network(Entity):
                                        """
                                        Number of bytes sent by the server
                                        
                                        .. attribute:: long
                                        
                                        	Total number of bytes transmitted by the server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "bytes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                            ])
                                            self.long = None
                                            self._segment_path = lambda: "network"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes.Network, ['long'], name, value)


                                    class Transport(Entity):
                                        """
                                        Number of bytes sent by the server
                                        
                                        .. attribute:: long
                                        
                                        	64 bit counter
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes.Transport, self).__init__()

                                            self.yang_name = "transport"
                                            self.yang_parent_name = "bytes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                            ])
                                            self.long = None
                                            self._segment_path = lambda: "transport"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Server.Counter.Bytes.Transport, ['long'], name, value)


                                class Packets(Entity):
                                    """
                                    Number of packets sent by the server
                                    
                                    .. attribute:: long
                                    
                                    	64 bits counter
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: retransmitted
                                    
                                    	Number of packets retransmitted by the server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Connection.Server.Counter.Packets, self).__init__()

                                        self.yang_name = "packets"
                                        self.yang_parent_name = "counter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                            ('retransmitted', (YLeaf(YType.empty, 'retransmitted'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self.retransmitted = None
                                        self._segment_path = lambda: "packets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Server.Counter.Packets, ['long', 'retransmitted'], name, value)


                            class Ipv4(Entity):
                                """
                                Server side IPv4 metrics
                                
                                .. attribute:: address
                                
                                	IPv4 address of the flow responder
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Server.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Server.Ipv4, ['address'], name, value)


                            class Ipv6(Entity):
                                """
                                Server side IPv6 metrics
                                
                                .. attribute:: address
                                
                                	IPv6 address of the flow responder
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Server.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Server.Ipv6, ['address'], name, value)


                            class Transport(Entity):
                                """
                                Server side transport metrics
                                
                                .. attribute:: port
                                
                                	Transport port of the flow responder
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Server.Transport, self).__init__()

                                    self.yang_name = "transport"
                                    self.yang_parent_name = "server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.empty, 'port'), ['Empty'])),
                                    ])
                                    self.port = None
                                    self._segment_path = lambda: "transport"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Server.Transport, ['port'], name, value)


                        class Transaction(Entity):
                            """
                            Transaction related metrics
                            
                            .. attribute:: all
                            
                            	All non\-key transaction metrics
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: counter
                            
                            	Transaction counter metrics
                            	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Transaction.Counter>`
                            
                            .. attribute:: duration
                            
                            	Transaction duration metrics
                            	**type**\:  :py:class:`Duration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Connection.Transaction.Duration>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Connection.Transaction, self).__init__()

                                self.yang_name = "transaction"
                                self.yang_parent_name = "connection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Default.Collect.Connection.Transaction.Counter)), ("duration", ("duration", Native.Flow.Record.Default.Collect.Connection.Transaction.Duration))])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None

                                self.counter = Native.Flow.Record.Default.Collect.Connection.Transaction.Counter()
                                self.counter.parent = self
                                self._children_name_map["counter"] = "counter"

                                self.duration = Native.Flow.Record.Default.Collect.Connection.Transaction.Duration()
                                self.duration.parent = self
                                self._children_name_map["duration"] = "duration"
                                self._segment_path = lambda: "transaction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Transaction, ['all'], name, value)


                            class Counter(Entity):
                                """
                                Transaction counter metrics
                                
                                .. attribute:: complete
                                
                                	Number of completed transactions
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Transaction.Counter, self).__init__()

                                    self.yang_name = "counter"
                                    self.yang_parent_name = "transaction"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('complete', (YLeaf(YType.empty, 'complete'), ['Empty'])),
                                    ])
                                    self.complete = None
                                    self._segment_path = lambda: "counter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Transaction.Counter, ['complete'], name, value)


                            class Duration(Entity):
                                """
                                Transaction duration metrics
                                
                                .. attribute:: max
                                
                                	Maximum transaction time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: min
                                
                                	Minimum transaction time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sum
                                
                                	Total transaction time
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Connection.Transaction.Duration, self).__init__()

                                    self.yang_name = "duration"
                                    self.yang_parent_name = "transaction"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self.sum = None
                                    self._segment_path = lambda: "duration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Connection.Transaction.Duration, ['max', 'min', 'sum'], name, value)


                    class Counter(Entity):
                        """
                        Counter fields
                        
                        .. attribute:: bytes
                        
                        	Total number of bytes
                        	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Counter.Bytes>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flows
                        
                        	Total number of flows
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: packets
                        
                        	Total number of packets
                        	**type**\:  :py:class:`Packets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Counter.Packets>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Counter, self).__init__()

                            self.yang_name = "counter"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Default.Collect.Counter.Bytes)), ("packets", ("packets", Native.Flow.Record.Default.Collect.Counter.Packets))])
                            self._leafs = OrderedDict([
                                ('flows', (YLeaf(YType.empty, 'flows'), ['Empty'])),
                            ])
                            self.flows = None

                            self.bytes = None
                            self._children_name_map["bytes"] = "bytes"

                            self.packets = None
                            self._children_name_map["packets"] = "packets"
                            self._segment_path = lambda: "counter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Counter, ['flows'], name, value)


                        class Bytes(Entity):
                            """
                            Total number of bytes
                            
                            .. attribute:: long
                            
                            	Total number of bytes (64 bit counter)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Byte rate for the flow
                            	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Counter.Bytes.Rate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: squared
                            
                            	Total of the square of the number of bytes
                            	**type**\:  :py:class:`Squared <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Counter.Bytes.Squared>`
                            
                            .. attribute:: layer2
                            
                            	Total number of layer 2 bytes
                            	**type**\:  :py:class:`Layer2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Counter.Bytes.Layer2>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Counter.Bytes, self).__init__()

                                self.yang_name = "bytes"
                                self.yang_parent_name = "counter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rate", ("rate", Native.Flow.Record.Default.Collect.Counter.Bytes.Rate)), ("squared", ("squared", Native.Flow.Record.Default.Collect.Counter.Bytes.Squared)), ("layer2", ("layer2", Native.Flow.Record.Default.Collect.Counter.Bytes.Layer2))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                ])
                                self.long = None

                                self.rate = None
                                self._children_name_map["rate"] = "rate"

                                self.squared = Native.Flow.Record.Default.Collect.Counter.Bytes.Squared()
                                self.squared.parent = self
                                self._children_name_map["squared"] = "squared"

                                self.layer2 = Native.Flow.Record.Default.Collect.Counter.Bytes.Layer2()
                                self.layer2.parent = self
                                self._children_name_map["layer2"] = "layer2"
                                self._segment_path = lambda: "bytes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Counter.Bytes, ['long'], name, value)


                            class Rate(Entity):
                                """
                                Byte rate for the flow
                                
                                .. attribute:: per_flow
                                
                                	Average byte rate for the flow
                                	**type**\:  :py:class:`PerFlow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Counter.Bytes.Rate.PerFlow>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Counter.Bytes.Rate, self).__init__()

                                    self.yang_name = "rate"
                                    self.yang_parent_name = "bytes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("per-flow", ("per_flow", Native.Flow.Record.Default.Collect.Counter.Bytes.Rate.PerFlow))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.per_flow = None
                                    self._children_name_map["per_flow"] = "per-flow"
                                    self._segment_path = lambda: "rate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Counter.Bytes.Rate, [], name, value)


                                class PerFlow(Entity):
                                    """
                                    Average byte rate for the flow
                                    
                                    .. attribute:: max
                                    
                                    	Maximum byte rate among the aggregated flows
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Minimum byte rate among the aggregated flows
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Counter.Bytes.Rate.PerFlow, self).__init__()

                                        self.yang_name = "per-flow"
                                        self.yang_parent_name = "rate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ])
                                        self.max = None
                                        self.min = None
                                        self._segment_path = lambda: "per-flow"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Counter.Bytes.Rate.PerFlow, ['max', 'min'], name, value)


                            class Squared(Entity):
                                """
                                Total of the square of the number of bytes
                                
                                .. attribute:: long
                                
                                	Total of the square of the packet length in bytes (64 bit counter)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Counter.Bytes.Squared, self).__init__()

                                    self.yang_name = "squared"
                                    self.yang_parent_name = "bytes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                    ])
                                    self.long = None
                                    self._segment_path = lambda: "squared"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Counter.Bytes.Squared, ['long'], name, value)


                            class Layer2(Entity):
                                """
                                Total number of layer 2 bytes
                                
                                .. attribute:: long
                                
                                	Total number of layer 2 bytes (64 bit counter)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Counter.Bytes.Layer2, self).__init__()

                                    self.yang_name = "layer2"
                                    self.yang_parent_name = "bytes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                    ])
                                    self.long = None
                                    self._segment_path = lambda: "layer2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Counter.Bytes.Layer2, ['long'], name, value)


                        class Packets(Entity):
                            """
                            Total number of packets
                            
                            .. attribute:: dropped
                            
                            	Dropped packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: long
                            
                            	Total number of packets (64 bit counter)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Packet rate for the flow
                            	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Counter.Packets.Rate>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Counter.Packets, self).__init__()

                                self.yang_name = "packets"
                                self.yang_parent_name = "counter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rate", ("rate", Native.Flow.Record.Default.Collect.Counter.Packets.Rate))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('dropped', (YLeaf(YType.empty, 'dropped'), ['Empty'])),
                                    ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                ])
                                self.dropped = None
                                self.long = None

                                self.rate = None
                                self._children_name_map["rate"] = "rate"
                                self._segment_path = lambda: "packets"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Counter.Packets, ['dropped', 'long'], name, value)


                            class Rate(Entity):
                                """
                                Packet rate for the flow
                                
                                .. attribute:: per_flow
                                
                                	Average packet rate for aggregated flows
                                	**type**\:  :py:class:`PerFlow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Counter.Packets.Rate.PerFlow>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Counter.Packets.Rate, self).__init__()

                                    self.yang_name = "rate"
                                    self.yang_parent_name = "packets"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("per-flow", ("per_flow", Native.Flow.Record.Default.Collect.Counter.Packets.Rate.PerFlow))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.per_flow = None
                                    self._children_name_map["per_flow"] = "per-flow"
                                    self._segment_path = lambda: "rate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Counter.Packets.Rate, [], name, value)


                                class PerFlow(Entity):
                                    """
                                    Average packet rate for aggregated flows
                                    
                                    .. attribute:: max
                                    
                                    	Maximum packet rate in the aggregated flows
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Minimum packet rate in the aggregated flows
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Counter.Packets.Rate.PerFlow, self).__init__()

                                        self.yang_name = "per-flow"
                                        self.yang_parent_name = "rate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ])
                                        self.max = None
                                        self.min = None
                                        self._segment_path = lambda: "per-flow"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Counter.Packets.Rate.PerFlow, ['max', 'min'], name, value)


                    class Datalink(Entity):
                        """
                        Datalink (layer2) fields
                        
                        .. attribute:: destination_vlan_id
                        
                        	ID of the VLAN that the packet is going to
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1q
                        
                        	dot1q field
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Datalink.Dot1q>`
                        
                        .. attribute:: ethertype
                        
                        	The Ethertype of the packet
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	The VLAN the packet is on
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Datalink.Vlan>`
                        
                        .. attribute:: mac
                        
                        	MAC fields
                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Datalink.Mac>`
                        
                        .. attribute:: source_vlan_id
                        
                        	ID of the VLAN that the packet came from
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Datalink, self).__init__()

                            self.yang_name = "datalink"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1q", ("dot1q", Native.Flow.Record.Default.Collect.Datalink.Dot1q)), ("mac", ("mac", Native.Flow.Record.Default.Collect.Datalink.Mac))])
                            self._leafs = OrderedDict([
                                ('destination_vlan_id', (YLeaf(YType.empty, 'destination-vlan-id'), ['Empty'])),
                                ('ethertype', (YLeaf(YType.empty, 'ethertype'), ['Empty'])),
                                ('vlan', (YLeaf(YType.enumeration, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Flow.Record.Default.Collect.Datalink.Vlan')])),
                                ('source_vlan_id', (YLeaf(YType.empty, 'source-vlan-id'), ['Empty'])),
                            ])
                            self.destination_vlan_id = None
                            self.ethertype = None
                            self.vlan = None
                            self.source_vlan_id = None

                            self.dot1q = Native.Flow.Record.Default.Collect.Datalink.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.mac = Native.Flow.Record.Default.Collect.Datalink.Mac()
                            self.mac.parent = self
                            self._children_name_map["mac"] = "mac"
                            self._segment_path = lambda: "datalink"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Datalink, ['destination_vlan_id', 'ethertype', 'vlan', 'source_vlan_id'], name, value)

                        class Vlan(Enum):
                            """
                            Vlan (Enum Class)

                            The VLAN the packet is on

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                        class Dot1q(Entity):
                            """
                            dot1q field
                            
                            .. attribute:: priority
                            
                            	The CoS field out of the dot1q header
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	The VLAN the packet is on
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Datalink.Dot1q.Vlan>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Datalink.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "datalink"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Flow.Record.Default.Collect.Datalink.Dot1q.Vlan))])
                                self._leafs = OrderedDict([
                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                ])
                                self.priority = None

                                self.vlan = Native.Flow.Record.Default.Collect.Datalink.Dot1q.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Datalink.Dot1q, ['priority'], name, value)


                            class Vlan(Entity):
                                """
                                The VLAN the packet is on
                                
                                .. attribute:: input
                                
                                	The VLAN the packet is on at input
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: output
                                
                                	The VLAN the packet is on at output
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Datalink.Dot1q.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                        ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                    ])
                                    self.input = None
                                    self.output = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Datalink.Dot1q.Vlan, ['input', 'output'], name, value)


                        class Mac(Entity):
                            """
                            MAC fields
                            
                            .. attribute:: destination
                            
                            	destination MAC fields
                            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Datalink.Mac.Destination>`
                            
                            .. attribute:: source
                            
                            	source MAC fields
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Datalink.Mac.Source>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Datalink.Mac, self).__init__()

                                self.yang_name = "mac"
                                self.yang_parent_name = "datalink"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Collect.Datalink.Mac.Destination)), ("source", ("source", Native.Flow.Record.Default.Collect.Datalink.Mac.Source))])
                                self._leafs = OrderedDict()

                                self.destination = Native.Flow.Record.Default.Collect.Datalink.Mac.Destination()
                                self.destination.parent = self
                                self._children_name_map["destination"] = "destination"

                                self.source = Native.Flow.Record.Default.Collect.Datalink.Mac.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "mac"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Datalink.Mac, [], name, value)


                            class Destination(Entity):
                                """
                                destination MAC fields
                                
                                .. attribute:: address
                                
                                	Destination MAC address from packet
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Datalink.Mac.Destination.Address>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Datalink.Mac.Destination, self).__init__()

                                    self.yang_name = "destination"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Default.Collect.Datalink.Mac.Destination.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = Native.Flow.Record.Default.Collect.Datalink.Mac.Destination.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "destination"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Datalink.Mac.Destination, [], name, value)


                                class Address(Entity):
                                    """
                                    Destination MAC address from packet
                                    
                                    .. attribute:: input
                                    
                                    	Destination MAC address from packet at input
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: output
                                    
                                    	Destination MAC address from packet at output
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Datalink.Mac.Destination.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "destination"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                            ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                        ])
                                        self.input = None
                                        self.output = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Datalink.Mac.Destination.Address, ['input', 'output'], name, value)


                            class Source(Entity):
                                """
                                source MAC fields
                                
                                .. attribute:: address
                                
                                	Source MAC address from packet
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Datalink.Mac.Source.Address>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Datalink.Mac.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Default.Collect.Datalink.Mac.Source.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = Native.Flow.Record.Default.Collect.Datalink.Mac.Source.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Datalink.Mac.Source, [], name, value)


                                class Address(Entity):
                                    """
                                    Source MAC address from packet
                                    
                                    .. attribute:: input
                                    
                                    	Source MAC address from packet at input
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: output
                                    
                                    	Source MAC address from packet at output
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Datalink.Mac.Source.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                            ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                        ])
                                        self.input = None
                                        self.output = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Datalink.Mac.Source.Address, ['input', 'output'], name, value)


                    class Flow_(Entity):
                        """
                        Flow identifying fields
                        
                        .. attribute:: cts
                        
                        	Cisco Trusted Security fields
                        	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Flow_.Cts>`
                        
                        .. attribute:: direction
                        
                        	Direction the flow was monitored in
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: observation
                        
                        	Flow observation metrics
                        	**type**\:  :py:class:`Observation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Flow_.Observation>`
                        
                        .. attribute:: sampler
                        
                        	ID of the sampler
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: end_reason
                        
                        	The reason for a flow ending
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Flow_, self).__init__()

                            self.yang_name = "flow"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cts", ("cts", Native.Flow.Record.Default.Collect.Flow_.Cts)), ("observation", ("observation", Native.Flow.Record.Default.Collect.Flow_.Observation))])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.empty, 'direction'), ['Empty'])),
                                ('sampler', (YLeaf(YType.empty, 'sampler'), ['Empty'])),
                                ('end_reason', (YLeaf(YType.empty, 'end-reason'), ['Empty'])),
                            ])
                            self.direction = None
                            self.sampler = None
                            self.end_reason = None

                            self.cts = Native.Flow.Record.Default.Collect.Flow_.Cts()
                            self.cts.parent = self
                            self._children_name_map["cts"] = "cts"

                            self.observation = Native.Flow.Record.Default.Collect.Flow_.Observation()
                            self.observation.parent = self
                            self._children_name_map["observation"] = "observation"
                            self._segment_path = lambda: "flow"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Flow_, ['direction', 'sampler', 'end_reason'], name, value)


                        class Cts(Entity):
                            """
                            Cisco Trusted Security fields
                            
                            .. attribute:: destination
                            
                            	Cisco Trusted Security destination fields
                            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Flow_.Cts.Destination>`
                            
                            .. attribute:: source
                            
                            	Cisco Trusted Security source fields
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Flow_.Cts.Source>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Flow_.Cts, self).__init__()

                                self.yang_name = "cts"
                                self.yang_parent_name = "flow"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Collect.Flow_.Cts.Destination)), ("source", ("source", Native.Flow.Record.Default.Collect.Flow_.Cts.Source))])
                                self._leafs = OrderedDict()

                                self.destination = Native.Flow.Record.Default.Collect.Flow_.Cts.Destination()
                                self.destination.parent = self
                                self._children_name_map["destination"] = "destination"

                                self.source = Native.Flow.Record.Default.Collect.Flow_.Cts.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "cts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Flow_.Cts, [], name, value)


                            class Destination(Entity):
                                """
                                Cisco Trusted Security destination fields
                                
                                .. attribute:: group_tag
                                
                                	destination group\-tag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Flow_.Cts.Destination, self).__init__()

                                    self.yang_name = "destination"
                                    self.yang_parent_name = "cts"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('group_tag', (YLeaf(YType.empty, 'group-tag'), ['Empty'])),
                                    ])
                                    self.group_tag = None
                                    self._segment_path = lambda: "destination"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Flow_.Cts.Destination, ['group_tag'], name, value)


                            class Source(Entity):
                                """
                                Cisco Trusted Security source fields
                                
                                .. attribute:: group_tag
                                
                                	source group\-tag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Flow_.Cts.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "cts"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('group_tag', (YLeaf(YType.empty, 'group-tag'), ['Empty'])),
                                    ])
                                    self.group_tag = None
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Flow_.Cts.Source, ['group_tag'], name, value)


                        class Observation(Entity):
                            """
                            Flow observation metrics
                            
                            .. attribute:: point
                            
                            	Observation point ID
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Flow_.Observation, self).__init__()

                                self.yang_name = "observation"
                                self.yang_parent_name = "flow"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('point', (YLeaf(YType.empty, 'point'), ['Empty'])),
                                ])
                                self.point = None
                                self._segment_path = lambda: "observation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Flow_.Observation, ['point'], name, value)


                    class Interface(Entity):
                        """
                        Interface fields
                        
                        .. attribute:: input
                        
                        	The input interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Interface.Input>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: output
                        
                        	The output interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Interface.Output>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Flow.Record.Default.Collect.Interface.Input)), ("output", ("output", Native.Flow.Record.Default.Collect.Interface.Output))])
                            self._leafs = OrderedDict()

                            self.input = None
                            self._children_name_map["input"] = "input"

                            self.output = None
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Interface, [], name, value)


                        class Input(Entity):
                            """
                            The input interface
                            
                            .. attribute:: snmp
                            
                            	SNMP Index of the input interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Interface.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('snmp', (YLeaf(YType.empty, 'snmp'), ['Empty'])),
                                ])
                                self.snmp = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Interface.Input, ['snmp'], name, value)


                        class Output(Entity):
                            """
                            The output interface
                            
                            .. attribute:: snmp
                            
                            	SNMP Index of the output interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Interface.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('snmp', (YLeaf(YType.empty, 'snmp'), ['Empty'])),
                                ])
                                self.snmp = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Interface.Output, ['snmp'], name, value)


                    class Ipv4(Entity):
                        """
                        IPv4 fields
                        
                        .. attribute:: destination
                        
                        	IPv4 destination address based fields
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Destination>`
                        
                        .. attribute:: dscp
                        
                        	IPv4 DSCP (part of TOS)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fragmentation
                        
                        	IPv4 fragmentation fields
                        	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Fragmentation>`
                        
                        .. attribute:: header_length
                        
                        	IPv4 header length (IHL in 32 bit words)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: id
                        
                        	IPv4 ID
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: length
                        
                        	IPv4 length fields
                        	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Length>`
                        
                        .. attribute:: option
                        
                        	IPv4 option fields
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Option>`
                        
                        .. attribute:: precedence
                        
                        	IPv4 precedence (part of TOS)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: protocol
                        
                        	IPv4 protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: section
                        
                        	Part of the packet
                        	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Section>`
                        
                        .. attribute:: source
                        
                        	IPv4 source address based fields
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Source>`
                        
                        .. attribute:: tos
                        
                        	IPv4 type of service
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: total_length
                        
                        	IPv4 total length
                        	**type**\:  :py:class:`TotalLength <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.TotalLength>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ttl
                        
                        	IPv4 TTL
                        	**type**\:  :py:class:`Ttl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Ttl>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: version
                        
                        	IP version from IPv4 header
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Collect.Ipv4.Destination)), ("fragmentation", ("fragmentation", Native.Flow.Record.Default.Collect.Ipv4.Fragmentation)), ("length", ("length", Native.Flow.Record.Default.Collect.Ipv4.Length)), ("option", ("option", Native.Flow.Record.Default.Collect.Ipv4.Option)), ("section", ("section", Native.Flow.Record.Default.Collect.Ipv4.Section)), ("source", ("source", Native.Flow.Record.Default.Collect.Ipv4.Source)), ("total-length", ("total_length", Native.Flow.Record.Default.Collect.Ipv4.TotalLength)), ("ttl", ("ttl", Native.Flow.Record.Default.Collect.Ipv4.Ttl))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                                ('header_length', (YLeaf(YType.empty, 'header-length'), ['Empty'])),
                                ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                                ('precedence', (YLeaf(YType.empty, 'precedence'), ['Empty'])),
                                ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                                ('tos', (YLeaf(YType.empty, 'tos'), ['Empty'])),
                                ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                            ])
                            self.dscp = None
                            self.header_length = None
                            self.id = None
                            self.precedence = None
                            self.protocol = None
                            self.tos = None
                            self.version = None

                            self.destination = Native.Flow.Record.Default.Collect.Ipv4.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.fragmentation = Native.Flow.Record.Default.Collect.Ipv4.Fragmentation()
                            self.fragmentation.parent = self
                            self._children_name_map["fragmentation"] = "fragmentation"

                            self.length = Native.Flow.Record.Default.Collect.Ipv4.Length()
                            self.length.parent = self
                            self._children_name_map["length"] = "length"

                            self.option = Native.Flow.Record.Default.Collect.Ipv4.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.section = Native.Flow.Record.Default.Collect.Ipv4.Section()
                            self.section.parent = self
                            self._children_name_map["section"] = "section"

                            self.source = Native.Flow.Record.Default.Collect.Ipv4.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"

                            self.total_length = None
                            self._children_name_map["total_length"] = "total-length"

                            self.ttl = None
                            self._children_name_map["ttl"] = "ttl"
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4, ['dscp', 'header_length', 'id', 'precedence', 'protocol', 'tos', 'version'], name, value)


                        class Destination(Entity):
                            """
                            IPv4 destination address based fields
                            
                            .. attribute:: address
                            
                            	IPv4 destination address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mask
                            
                            	IPv4 address mask for the IPv4 destination address
                            	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Destination.Mask>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: prefix
                            
                            	IPv4 address prefix for the IPv4 destination address
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Destination.Prefix>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv4.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Collect.Ipv4.Destination.Mask)), ("prefix", ("prefix", Native.Flow.Record.Default.Collect.Ipv4.Destination.Prefix))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None

                                self.mask = None
                                self._children_name_map["mask"] = "mask"

                                self.prefix = None
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Destination, ['address'], name, value)


                            class Mask(Entity):
                                """
                                IPv4 address mask for the IPv4 destination address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv4.Destination.Mask, self).__init__()

                                    self.yang_name = "mask"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "mask"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Destination.Mask, ['minimum_mask'], name, value)


                            class Prefix(Entity):
                                """
                                IPv4 address prefix for the IPv4 destination address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv4.Destination.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Destination.Prefix, ['minimum_mask'], name, value)


                        class Fragmentation(Entity):
                            """
                            IPv4 fragmentation fields
                            
                            .. attribute:: flags
                            
                            	IPv4 fragmentation flags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: offset
                            
                            	IPv4 fragmentation offset
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv4.Fragmentation, self).__init__()

                                self.yang_name = "fragmentation"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('flags', (YLeaf(YType.empty, 'flags'), ['Empty'])),
                                    ('offset', (YLeaf(YType.empty, 'offset'), ['Empty'])),
                                ])
                                self.flags = None
                                self.offset = None
                                self._segment_path = lambda: "fragmentation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Fragmentation, ['flags', 'offset'], name, value)


                        class Length(Entity):
                            """
                            IPv4 length fields
                            
                            .. attribute:: header
                            
                            	Length of the IPv4 header in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: payload
                            
                            	Length of the IPv4 payload in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: total
                            
                            	Total length of the IPv4 header and payload in bytes
                            	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Length.Total>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv4.Length, self).__init__()

                                self.yang_name = "length"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("total", ("total", Native.Flow.Record.Default.Collect.Ipv4.Length.Total))])
                                self._leafs = OrderedDict([
                                    ('header', (YLeaf(YType.empty, 'header'), ['Empty'])),
                                    ('payload', (YLeaf(YType.empty, 'payload'), ['Empty'])),
                                ])
                                self.header = None
                                self.payload = None

                                self.total = None
                                self._children_name_map["total"] = "total"
                                self._segment_path = lambda: "length"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Length, ['header', 'payload'], name, value)


                            class Total(Entity):
                                """
                                Total length of the IPv4 header and payload in bytes
                                
                                .. attribute:: maximum
                                
                                	Maximum total length in bytes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minimum
                                
                                	Minimum total length in bytes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv4.Length.Total, self).__init__()

                                    self.yang_name = "total"
                                    self.yang_parent_name = "length"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                        ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                    ])
                                    self.maximum = None
                                    self.minimum = None
                                    self._segment_path = lambda: "total"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Length.Total, ['maximum', 'minimum'], name, value)


                        class Option(Entity):
                            """
                            IPv4 option fields
                            
                            .. attribute:: map
                            
                            	Bitmap of IPv4 options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv4.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('map', (YLeaf(YType.empty, 'map'), ['Empty'])),
                                ])
                                self.map = None
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Option, ['map'], name, value)


                        class Section(Entity):
                            """
                            Part of the packet
                            
                            .. attribute:: header
                            
                            	Raw data starting at the IPv4 header
                            	**type**\:  :py:class:`Header <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Section.Header>`
                            
                            .. attribute:: payload
                            
                            	Raw data starting at the IPv4 payload
                            	**type**\:  :py:class:`Payload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Section.Payload>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv4.Section, self).__init__()

                                self.yang_name = "section"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("header", ("header", Native.Flow.Record.Default.Collect.Ipv4.Section.Header)), ("payload", ("payload", Native.Flow.Record.Default.Collect.Ipv4.Section.Payload))])
                                self._leafs = OrderedDict()

                                self.header = Native.Flow.Record.Default.Collect.Ipv4.Section.Header()
                                self.header.parent = self
                                self._children_name_map["header"] = "header"

                                self.payload = Native.Flow.Record.Default.Collect.Ipv4.Section.Payload()
                                self.payload.parent = self
                                self._children_name_map["payload"] = "payload"
                                self._segment_path = lambda: "section"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Section, [], name, value)


                            class Header(Entity):
                                """
                                Raw data starting at the IPv4 header
                                
                                .. attribute:: size
                                
                                	Specify the number of bytes to capture
                                	**type**\: int
                                
                                	**range:** 1..1200
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv4.Section.Header, self).__init__()

                                    self.yang_name = "header"
                                    self.yang_parent_name = "section"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                    ])
                                    self.size = None
                                    self._segment_path = lambda: "header"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Section.Header, ['size'], name, value)


                            class Payload(Entity):
                                """
                                Raw data starting at the IPv4 payload
                                
                                .. attribute:: size
                                
                                	Specify the number of bytes to capture
                                	**type**\: int
                                
                                	**range:** 1..1200
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv4.Section.Payload, self).__init__()

                                    self.yang_name = "payload"
                                    self.yang_parent_name = "section"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                    ])
                                    self.size = None
                                    self._segment_path = lambda: "payload"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Section.Payload, ['size'], name, value)


                        class Source(Entity):
                            """
                            IPv4 source address based fields
                            
                            .. attribute:: address
                            
                            	IPv4 source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mask
                            
                            	IPv4 address mask for the IPv4 source address
                            	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Source.Mask>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: prefix
                            
                            	IPv4 address prefix for the IPv4 source address
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv4.Source.Prefix>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv4.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Collect.Ipv4.Source.Mask)), ("prefix", ("prefix", Native.Flow.Record.Default.Collect.Ipv4.Source.Prefix))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None

                                self.mask = None
                                self._children_name_map["mask"] = "mask"

                                self.prefix = None
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Source, ['address'], name, value)


                            class Mask(Entity):
                                """
                                IPv4 address mask for the IPv4 source address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv4.Source.Mask, self).__init__()

                                    self.yang_name = "mask"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "mask"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Source.Mask, ['minimum_mask'], name, value)


                            class Prefix(Entity):
                                """
                                IPv4 address prefix for the IPv4 source address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv4.Source.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Source.Prefix, ['minimum_mask'], name, value)


                        class TotalLength(Entity):
                            """
                            IPv4 total length
                            
                            .. attribute:: maximum
                            
                            	Largest value for IPv4 length seen in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	Smallest value for IPv4 length seen in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv4.TotalLength, self).__init__()

                                self.yang_name = "total-length"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self._segment_path = lambda: "total-length"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.TotalLength, ['maximum', 'minimum'], name, value)


                        class Ttl(Entity):
                            """
                            IPv4 TTL
                            
                            .. attribute:: maximum
                            
                            	Largest value seen for TTL in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	Smallest value seen for TTL in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv4.Ttl, self).__init__()

                                self.yang_name = "ttl"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self._segment_path = lambda: "ttl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv4.Ttl, ['maximum', 'minimum'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 fields
                        
                        .. attribute:: destination
                        
                        	IPv6 destination address based fields
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Destination>`
                        
                        .. attribute:: dscp
                        
                        	IPv6 DSCP (part of Traffic Class)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: extension
                        
                        	IPv6 extension header fields
                        	**type**\:  :py:class:`Extension <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Extension>`
                        
                        .. attribute:: flow_label
                        
                        	IPv6 flow label
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fragmentation
                        
                        	IPv6 fragmentation fields
                        	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Fragmentation>`
                        
                        .. attribute:: hop_limit
                        
                        	IPv6 hop limit
                        	**type**\:  :py:class:`HopLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.HopLimit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: length
                        
                        	IPv6 length fields
                        	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Length>`
                        
                        .. attribute:: next_header
                        
                        	The value of the next\-header field in the IPv6 header
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: payload_length
                        
                        	Length of the IPv6 payload in bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: precedence
                        
                        	IPv6 precedence (part of Traffic Class)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: protocol
                        
                        	IPv6 payload protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: section
                        
                        	Part of the packet
                        	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Section>`
                        
                        .. attribute:: source
                        
                        	IPv6 source address based fields
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Source>`
                        
                        .. attribute:: traffic_class
                        
                        	IPv6 traffic class
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: version
                        
                        	IP version from IPv6 header
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Collect.Ipv6.Destination)), ("extension", ("extension", Native.Flow.Record.Default.Collect.Ipv6.Extension)), ("fragmentation", ("fragmentation", Native.Flow.Record.Default.Collect.Ipv6.Fragmentation)), ("hop-limit", ("hop_limit", Native.Flow.Record.Default.Collect.Ipv6.HopLimit)), ("length", ("length", Native.Flow.Record.Default.Collect.Ipv6.Length)), ("section", ("section", Native.Flow.Record.Default.Collect.Ipv6.Section)), ("source", ("source", Native.Flow.Record.Default.Collect.Ipv6.Source))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                                ('flow_label', (YLeaf(YType.empty, 'flow-label'), ['Empty'])),
                                ('next_header', (YLeaf(YType.empty, 'next-header'), ['Empty'])),
                                ('payload_length', (YLeaf(YType.empty, 'payload-length'), ['Empty'])),
                                ('precedence', (YLeaf(YType.empty, 'precedence'), ['Empty'])),
                                ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                                ('traffic_class', (YLeaf(YType.empty, 'traffic-class'), ['Empty'])),
                                ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                            ])
                            self.dscp = None
                            self.flow_label = None
                            self.next_header = None
                            self.payload_length = None
                            self.precedence = None
                            self.protocol = None
                            self.traffic_class = None
                            self.version = None

                            self.destination = Native.Flow.Record.Default.Collect.Ipv6.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.extension = Native.Flow.Record.Default.Collect.Ipv6.Extension()
                            self.extension.parent = self
                            self._children_name_map["extension"] = "extension"

                            self.fragmentation = Native.Flow.Record.Default.Collect.Ipv6.Fragmentation()
                            self.fragmentation.parent = self
                            self._children_name_map["fragmentation"] = "fragmentation"

                            self.hop_limit = None
                            self._children_name_map["hop_limit"] = "hop-limit"

                            self.length = Native.Flow.Record.Default.Collect.Ipv6.Length()
                            self.length.parent = self
                            self._children_name_map["length"] = "length"

                            self.section = Native.Flow.Record.Default.Collect.Ipv6.Section()
                            self.section.parent = self
                            self._children_name_map["section"] = "section"

                            self.source = Native.Flow.Record.Default.Collect.Ipv6.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6, ['dscp', 'flow_label', 'next_header', 'payload_length', 'precedence', 'protocol', 'traffic_class', 'version'], name, value)


                        class Destination(Entity):
                            """
                            IPv6 destination address based fields
                            
                            .. attribute:: address
                            
                            	IPv6 destination address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mask
                            
                            	IPv6 address mask for the IPv6 destination address
                            	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Destination.Mask>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: prefix
                            
                            	IPv6 address prefix for the IPv6 destination address
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Destination.Prefix>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv6.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Collect.Ipv6.Destination.Mask)), ("prefix", ("prefix", Native.Flow.Record.Default.Collect.Ipv6.Destination.Prefix))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None

                                self.mask = None
                                self._children_name_map["mask"] = "mask"

                                self.prefix = None
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Destination, ['address'], name, value)


                            class Mask(Entity):
                                """
                                IPv6 address mask for the IPv6 destination address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..128
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv6.Destination.Mask, self).__init__()

                                    self.yang_name = "mask"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "mask"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Destination.Mask, ['minimum_mask'], name, value)


                            class Prefix(Entity):
                                """
                                IPv6 address prefix for the IPv6 destination address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..128
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv6.Destination.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Destination.Prefix, ['minimum_mask'], name, value)


                        class Extension(Entity):
                            """
                            IPv6 extension header fields
                            
                            .. attribute:: map
                            
                            	Bitmap of IPv6 extension headers
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv6.Extension, self).__init__()

                                self.yang_name = "extension"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('map', (YLeaf(YType.empty, 'map'), ['Empty'])),
                                ])
                                self.map = None
                                self._segment_path = lambda: "extension"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Extension, ['map'], name, value)


                        class Fragmentation(Entity):
                            """
                            IPv6 fragmentation fields
                            
                            .. attribute:: flags
                            
                            	IPv6 fragmentation flags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: id
                            
                            	IPv6 fragmentation ID
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: offset
                            
                            	IPv6 fragmentation offset
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv6.Fragmentation, self).__init__()

                                self.yang_name = "fragmentation"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('flags', (YLeaf(YType.empty, 'flags'), ['Empty'])),
                                    ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                                    ('offset', (YLeaf(YType.empty, 'offset'), ['Empty'])),
                                ])
                                self.flags = None
                                self.id = None
                                self.offset = None
                                self._segment_path = lambda: "fragmentation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Fragmentation, ['flags', 'id', 'offset'], name, value)


                        class HopLimit(Entity):
                            """
                            IPv6 hop limit
                            
                            .. attribute:: maximum
                            
                            	Largest value seen for hop\-limit in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	Smallest value seen for hop\-limit in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv6.HopLimit, self).__init__()

                                self.yang_name = "hop-limit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self._segment_path = lambda: "hop-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.HopLimit, ['maximum', 'minimum'], name, value)


                        class Length(Entity):
                            """
                            IPv6 length fields
                            
                            .. attribute:: header
                            
                            	Length of the IPv6 header, not including any extension headers, in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: payload
                            
                            	Length of the IPv6 payload, including any extension headers, in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: total
                            
                            	Total length of the IPv6 header and payload in bytes
                            	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Length.Total>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv6.Length, self).__init__()

                                self.yang_name = "length"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("total", ("total", Native.Flow.Record.Default.Collect.Ipv6.Length.Total))])
                                self._leafs = OrderedDict([
                                    ('header', (YLeaf(YType.empty, 'header'), ['Empty'])),
                                    ('payload', (YLeaf(YType.empty, 'payload'), ['Empty'])),
                                ])
                                self.header = None
                                self.payload = None

                                self.total = None
                                self._children_name_map["total"] = "total"
                                self._segment_path = lambda: "length"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Length, ['header', 'payload'], name, value)


                            class Total(Entity):
                                """
                                Total length of the IPv6 header and payload in bytes
                                
                                .. attribute:: maximum
                                
                                	Maximum total length in bytes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minimum
                                
                                	Minimum total length in bytes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv6.Length.Total, self).__init__()

                                    self.yang_name = "total"
                                    self.yang_parent_name = "length"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                        ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                    ])
                                    self.maximum = None
                                    self.minimum = None
                                    self._segment_path = lambda: "total"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Length.Total, ['maximum', 'minimum'], name, value)


                        class Section(Entity):
                            """
                            Part of the packet
                            
                            .. attribute:: header
                            
                            	Raw data starting at the IPv6 header
                            	**type**\:  :py:class:`Header <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Section.Header>`
                            
                            .. attribute:: payload
                            
                            	Raw data starting at the IPv6 payload
                            	**type**\:  :py:class:`Payload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Section.Payload>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv6.Section, self).__init__()

                                self.yang_name = "section"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("header", ("header", Native.Flow.Record.Default.Collect.Ipv6.Section.Header)), ("payload", ("payload", Native.Flow.Record.Default.Collect.Ipv6.Section.Payload))])
                                self._leafs = OrderedDict()

                                self.header = Native.Flow.Record.Default.Collect.Ipv6.Section.Header()
                                self.header.parent = self
                                self._children_name_map["header"] = "header"

                                self.payload = Native.Flow.Record.Default.Collect.Ipv6.Section.Payload()
                                self.payload.parent = self
                                self._children_name_map["payload"] = "payload"
                                self._segment_path = lambda: "section"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Section, [], name, value)


                            class Header(Entity):
                                """
                                Raw data starting at the IPv6 header
                                
                                .. attribute:: size
                                
                                	Specify the number of bytes to capture
                                	**type**\: int
                                
                                	**range:** 1..1200
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv6.Section.Header, self).__init__()

                                    self.yang_name = "header"
                                    self.yang_parent_name = "section"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                    ])
                                    self.size = None
                                    self._segment_path = lambda: "header"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Section.Header, ['size'], name, value)


                            class Payload(Entity):
                                """
                                Raw data starting at the IPv6 payload
                                
                                .. attribute:: size
                                
                                	Specify the number of bytes to capture
                                	**type**\: int
                                
                                	**range:** 1..1200
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv6.Section.Payload, self).__init__()

                                    self.yang_name = "payload"
                                    self.yang_parent_name = "section"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                    ])
                                    self.size = None
                                    self._segment_path = lambda: "payload"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Section.Payload, ['size'], name, value)


                        class Source(Entity):
                            """
                            IPv6 source address based fields
                            
                            .. attribute:: address
                            
                            	IPv6 source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mask
                            
                            	IPv6 address mask for the IPv6 source address
                            	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Source.Mask>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: prefix
                            
                            	IPv6 address prefix for the IPv6 source address
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Ipv6.Source.Prefix>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Ipv6.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Collect.Ipv6.Source.Mask)), ("prefix", ("prefix", Native.Flow.Record.Default.Collect.Ipv6.Source.Prefix))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None

                                self.mask = None
                                self._children_name_map["mask"] = "mask"

                                self.prefix = None
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Source, ['address'], name, value)


                            class Mask(Entity):
                                """
                                IPv6 address mask for the IPv6 source address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..128
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv6.Source.Mask, self).__init__()

                                    self.yang_name = "mask"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "mask"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Source.Mask, ['minimum_mask'], name, value)


                            class Prefix(Entity):
                                """
                                IPv6 address prefix for the IPv6 source address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..128
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Ipv6.Source.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Ipv6.Source.Prefix, ['minimum_mask'], name, value)


                    class Metadata(Entity):
                        """
                        Metadata fields
                        
                        .. attribute:: clock_rate
                        
                        	Metadata clock\-rate
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: global_session_id
                        
                        	Metadata global\-session\-id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multi_party_session_id
                        
                        	Metadata multi\-party\-session\-id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Metadata, self).__init__()

                            self.yang_name = "metadata"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('clock_rate', (YLeaf(YType.empty, 'clock-rate'), ['Empty'])),
                                ('global_session_id', (YLeaf(YType.empty, 'global-session-id'), ['Empty'])),
                                ('multi_party_session_id', (YLeaf(YType.empty, 'multi-party-session-id'), ['Empty'])),
                            ])
                            self.clock_rate = None
                            self.global_session_id = None
                            self.multi_party_session_id = None
                            self._segment_path = lambda: "metadata"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Metadata, ['clock_rate', 'global_session_id', 'multi_party_session_id'], name, value)


                    class Monitor(Entity):
                        """
                        monitor fields
                        
                        .. attribute:: event
                        
                        	Flags indicating monitor events
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('event', (YLeaf(YType.empty, 'event'), ['Empty'])),
                            ])
                            self.event = None
                            self._segment_path = lambda: "monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Monitor, ['event'], name, value)


                    class Mpls(Entity):
                        """
                        MPLS fields
                        
                        .. attribute:: label
                        
                        	MPLS label details
                        	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Mpls.Label>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Mpls, self).__init__()

                            self.yang_name = "mpls"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("label", ("label", Native.Flow.Record.Default.Collect.Mpls.Label))])
                            self._leafs = OrderedDict()

                            self.label = Native.Flow.Record.Default.Collect.Mpls.Label()
                            self.label.parent = self
                            self._children_name_map["label"] = "label"
                            self._segment_path = lambda: "mpls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Mpls, [], name, value)


                        class Label(Entity):
                            """
                            MPLS label details
                            
                            .. attribute:: one
                            
                            	MPLS label 1 information
                            	**type**\:  :py:class:`One <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Mpls.Label.One>`
                            
                            .. attribute:: two
                            
                            	MPLS label 2 information
                            	**type**\:  :py:class:`Two <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Mpls.Label.Two>`
                            
                            .. attribute:: three
                            
                            	MPLS label 3 information
                            	**type**\:  :py:class:`Three <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Mpls.Label.Three>`
                            
                            .. attribute:: four
                            
                            	MPLS label 4 information
                            	**type**\:  :py:class:`Four <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Mpls.Label.Four>`
                            
                            .. attribute:: five
                            
                            	MPLS label 5 information
                            	**type**\:  :py:class:`Five <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Mpls.Label.Five>`
                            
                            .. attribute:: six
                            
                            	MPLS label 6 information
                            	**type**\:  :py:class:`Six <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Mpls.Label.Six>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Mpls.Label, self).__init__()

                                self.yang_name = "label"
                                self.yang_parent_name = "mpls"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("one", ("one", Native.Flow.Record.Default.Collect.Mpls.Label.One)), ("two", ("two", Native.Flow.Record.Default.Collect.Mpls.Label.Two)), ("three", ("three", Native.Flow.Record.Default.Collect.Mpls.Label.Three)), ("four", ("four", Native.Flow.Record.Default.Collect.Mpls.Label.Four)), ("five", ("five", Native.Flow.Record.Default.Collect.Mpls.Label.Five)), ("six", ("six", Native.Flow.Record.Default.Collect.Mpls.Label.Six))])
                                self._leafs = OrderedDict()

                                self.one = Native.Flow.Record.Default.Collect.Mpls.Label.One()
                                self.one.parent = self
                                self._children_name_map["one"] = "one"

                                self.two = Native.Flow.Record.Default.Collect.Mpls.Label.Two()
                                self.two.parent = self
                                self._children_name_map["two"] = "two"

                                self.three = Native.Flow.Record.Default.Collect.Mpls.Label.Three()
                                self.three.parent = self
                                self._children_name_map["three"] = "three"

                                self.four = Native.Flow.Record.Default.Collect.Mpls.Label.Four()
                                self.four.parent = self
                                self._children_name_map["four"] = "four"

                                self.five = Native.Flow.Record.Default.Collect.Mpls.Label.Five()
                                self.five.parent = self
                                self._children_name_map["five"] = "five"

                                self.six = Native.Flow.Record.Default.Collect.Mpls.Label.Six()
                                self.six.parent = self
                                self._children_name_map["six"] = "six"
                                self._segment_path = lambda: "label"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Mpls.Label, [], name, value)


                            class One(Entity):
                                """
                                MPLS label 1 information
                                
                                .. attribute:: details
                                
                                	MPLS label 1 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: exp
                                
                                	MPLS EXP field from the last label that was pushed
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ttl
                                
                                	MPLS TTL field from the last label that was pushed
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: type
                                
                                	MPLS label type of the last label that was pushed
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Mpls.Label.One, self).__init__()

                                    self.yang_name = "one"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                        ('exp', (YLeaf(YType.empty, 'exp'), ['Empty'])),
                                        ('ttl', (YLeaf(YType.empty, 'ttl'), ['Empty'])),
                                        ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self.exp = None
                                    self.ttl = None
                                    self.type = None
                                    self._segment_path = lambda: "one"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Mpls.Label.One, ['details', 'exp', 'ttl', 'type'], name, value)


                            class Two(Entity):
                                """
                                MPLS label 2 information
                                
                                .. attribute:: details
                                
                                	MPLS label 2 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Mpls.Label.Two, self).__init__()

                                    self.yang_name = "two"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self._segment_path = lambda: "two"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Mpls.Label.Two, ['details'], name, value)


                            class Three(Entity):
                                """
                                MPLS label 3 information
                                
                                .. attribute:: details
                                
                                	MPLS label 3 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Mpls.Label.Three, self).__init__()

                                    self.yang_name = "three"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self._segment_path = lambda: "three"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Mpls.Label.Three, ['details'], name, value)


                            class Four(Entity):
                                """
                                MPLS label 4 information
                                
                                .. attribute:: details
                                
                                	MPLS label 4 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Mpls.Label.Four, self).__init__()

                                    self.yang_name = "four"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self._segment_path = lambda: "four"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Mpls.Label.Four, ['details'], name, value)


                            class Five(Entity):
                                """
                                MPLS label 5 information
                                
                                .. attribute:: details
                                
                                	MPLS label 5 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Mpls.Label.Five, self).__init__()

                                    self.yang_name = "five"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self._segment_path = lambda: "five"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Mpls.Label.Five, ['details'], name, value)


                            class Six(Entity):
                                """
                                MPLS label 6 information
                                
                                .. attribute:: details
                                
                                	MPLS label 6 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Mpls.Label.Six, self).__init__()

                                    self.yang_name = "six"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self._segment_path = lambda: "six"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Mpls.Label.Six, ['details'], name, value)


                    class Network(Entity):
                        """
                        network metrics
                        
                        .. attribute:: delay
                        
                        	network delay metrics
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Network.Delay>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Flow.Record.Default.Collect.Network.Delay))])
                            self._leafs = OrderedDict()

                            self.delay = Native.Flow.Record.Default.Collect.Network.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Network, [], name, value)


                        class Delay(Entity):
                            """
                            network delay metrics
                            
                            .. attribute:: sample
                            
                            	The number of samples of roundtrip delay
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sum
                            
                            	The sum of roundtrip delay
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Network.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sample', (YLeaf(YType.empty, 'sample'), ['Empty'])),
                                    ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                ])
                                self.sample = None
                                self.sum = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Network.Delay, ['sample', 'sum'], name, value)


                    class Pfr(Entity):
                        """
                        PfR metrics
                        
                        .. attribute:: label
                        
                        	PfR label metrics
                        	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.Label>`
                        
                        .. attribute:: one_way_delay
                        
                        	The packet transmission delay between specified nodes
                        	**type**\:  :py:class:`OneWayDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.OneWayDelay>`
                        
                        .. attribute:: service
                        
                        	PfR service metrics
                        	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.Service>`
                        
                        .. attribute:: site
                        
                        	PfR site  metrics
                        	**type**\:  :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.Site>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Pfr, self).__init__()

                            self.yang_name = "pfr"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("label", ("label", Native.Flow.Record.Default.Collect.Pfr.Label)), ("one-way-delay", ("one_way_delay", Native.Flow.Record.Default.Collect.Pfr.OneWayDelay)), ("service", ("service", Native.Flow.Record.Default.Collect.Pfr.Service)), ("site", ("site", Native.Flow.Record.Default.Collect.Pfr.Site))])
                            self._leafs = OrderedDict()

                            self.label = Native.Flow.Record.Default.Collect.Pfr.Label()
                            self.label.parent = self
                            self._children_name_map["label"] = "label"

                            self.one_way_delay = Native.Flow.Record.Default.Collect.Pfr.OneWayDelay()
                            self.one_way_delay.parent = self
                            self._children_name_map["one_way_delay"] = "one-way-delay"

                            self.service = Native.Flow.Record.Default.Collect.Pfr.Service()
                            self.service.parent = self
                            self._children_name_map["service"] = "service"

                            self.site = Native.Flow.Record.Default.Collect.Pfr.Site()
                            self.site.parent = self
                            self._children_name_map["site"] = "site"
                            self._segment_path = lambda: "pfr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr, [], name, value)


                        class Label(Entity):
                            """
                            PfR label metrics
                            
                            .. attribute:: identifier
                            
                            	pfr label id
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Pfr.Label, self).__init__()

                                self.yang_name = "label"
                                self.yang_parent_name = "pfr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('identifier', (YLeaf(YType.empty, 'identifier'), ['Empty'])),
                                ])
                                self.identifier = None
                                self._segment_path = lambda: "label"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.Label, ['identifier'], name, value)


                        class OneWayDelay(Entity):
                            """
                            The packet transmission delay between specified nodes
                            
                            .. attribute:: samples
                            
                            	Total number of one\-way\-delay samples
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sum
                            
                            	The packet transmission delay sum between specified nodes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Pfr.OneWayDelay, self).__init__()

                                self.yang_name = "one-way-delay"
                                self.yang_parent_name = "pfr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('samples', (YLeaf(YType.empty, 'samples'), ['Empty'])),
                                    ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                ])
                                self.samples = None
                                self.sum = None
                                self._segment_path = lambda: "one-way-delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.OneWayDelay, ['samples', 'sum'], name, value)


                        class Service(Entity):
                            """
                            PfR service metrics
                            
                            .. attribute:: provider
                            
                            	PfR service provider metrics
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: tag
                            
                            	PfR service provider tag metrics
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: identifier
                            
                            	PfR service provider tag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Pfr.Service, self).__init__()

                                self.yang_name = "service"
                                self.yang_parent_name = "pfr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('provider', (YLeaf(YType.empty, 'provider'), ['Empty'])),
                                    ('tag', (YLeaf(YType.empty, 'tag'), ['Empty'])),
                                    ('identifier', (YLeaf(YType.empty, 'identifier'), ['Empty'])),
                                ])
                                self.provider = None
                                self.tag = None
                                self.identifier = None
                                self._segment_path = lambda: "service"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.Service, ['provider', 'tag', 'identifier'], name, value)


                        class Site(Entity):
                            """
                            PfR site  metrics
                            
                            .. attribute:: destination
                            
                            	PfR site destination metrics
                            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.Site.Destination>`
                            
                            .. attribute:: source
                            
                            	PfR site source metrics
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.Site.Source>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Pfr.Site, self).__init__()

                                self.yang_name = "site"
                                self.yang_parent_name = "pfr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Collect.Pfr.Site.Destination)), ("source", ("source", Native.Flow.Record.Default.Collect.Pfr.Site.Source))])
                                self._leafs = OrderedDict()

                                self.destination = Native.Flow.Record.Default.Collect.Pfr.Site.Destination()
                                self.destination.parent = self
                                self._children_name_map["destination"] = "destination"

                                self.source = Native.Flow.Record.Default.Collect.Pfr.Site.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "site"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.Site, [], name, value)


                            class Destination(Entity):
                                """
                                PfR site destination metrics
                                
                                .. attribute:: id
                                
                                	PfR site destination ID metrics
                                	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Id>`
                                
                                .. attribute:: prefix
                                
                                	PfR site prefix of the packet destination
                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Prefix>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Pfr.Site.Destination, self).__init__()

                                    self.yang_name = "destination"
                                    self.yang_parent_name = "site"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("id", ("id", Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Id)), ("prefix", ("prefix", Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Prefix))])
                                    self._leafs = OrderedDict()

                                    self.id = Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Id()
                                    self.id.parent = self
                                    self._children_name_map["id"] = "id"

                                    self.prefix = Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                    self._segment_path = lambda: "destination"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.Site.Destination, [], name, value)


                                class Id(Entity):
                                    """
                                    PfR site destination ID metrics
                                    
                                    .. attribute:: ipv4
                                    
                                    	site ID of the packet destination
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Id, self).__init__()

                                        self.yang_name = "id"
                                        self.yang_parent_name = "destination"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Id, ['ipv4'], name, value)


                                class Prefix(Entity):
                                    """
                                    PfR site prefix of the packet destination
                                    
                                    .. attribute:: ipv4
                                    
                                    	site prefix of the packet destination
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: mask
                                    
                                    	PfR site prefix mask of the packet destination
                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Prefix.Mask>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Prefix, self).__init__()

                                        self.yang_name = "prefix"
                                        self.yang_parent_name = "destination"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Prefix.Mask))])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None

                                        self.mask = Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Prefix.Mask()
                                        self.mask.parent = self
                                        self._children_name_map["mask"] = "mask"
                                        self._segment_path = lambda: "prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Prefix, ['ipv4'], name, value)


                                    class Mask(Entity):
                                        """
                                        PfR site prefix mask of the packet destination
                                        
                                        .. attribute:: ipv4
                                        
                                        	site prefix mask of the packet destination
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Prefix.Mask, self).__init__()

                                            self.yang_name = "mask"
                                            self.yang_parent_name = "prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                            ])
                                            self.ipv4 = None
                                            self._segment_path = lambda: "mask"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.Site.Destination.Prefix.Mask, ['ipv4'], name, value)


                            class Source(Entity):
                                """
                                PfR site source metrics
                                
                                .. attribute:: id
                                
                                	PfR site source ID metrics
                                	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.Site.Source.Id>`
                                
                                .. attribute:: prefix
                                
                                	PfR site prefix of the packet source
                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.Site.Source.Prefix>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Pfr.Site.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "site"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("id", ("id", Native.Flow.Record.Default.Collect.Pfr.Site.Source.Id)), ("prefix", ("prefix", Native.Flow.Record.Default.Collect.Pfr.Site.Source.Prefix))])
                                    self._leafs = OrderedDict()

                                    self.id = Native.Flow.Record.Default.Collect.Pfr.Site.Source.Id()
                                    self.id.parent = self
                                    self._children_name_map["id"] = "id"

                                    self.prefix = Native.Flow.Record.Default.Collect.Pfr.Site.Source.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.Site.Source, [], name, value)


                                class Id(Entity):
                                    """
                                    PfR site source ID metrics
                                    
                                    .. attribute:: ipv4
                                    
                                    	site ID of the packet source
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Pfr.Site.Source.Id, self).__init__()

                                        self.yang_name = "id"
                                        self.yang_parent_name = "source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.Site.Source.Id, ['ipv4'], name, value)


                                class Prefix(Entity):
                                    """
                                    PfR site prefix of the packet source
                                    
                                    .. attribute:: ipv4
                                    
                                    	site prefix of the packet source
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: mask
                                    
                                    	PfR site prefix mask of the packet source
                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Pfr.Site.Source.Prefix.Mask>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Pfr.Site.Source.Prefix, self).__init__()

                                        self.yang_name = "prefix"
                                        self.yang_parent_name = "source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Collect.Pfr.Site.Source.Prefix.Mask))])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None

                                        self.mask = Native.Flow.Record.Default.Collect.Pfr.Site.Source.Prefix.Mask()
                                        self.mask.parent = self
                                        self._children_name_map["mask"] = "mask"
                                        self._segment_path = lambda: "prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.Site.Source.Prefix, ['ipv4'], name, value)


                                    class Mask(Entity):
                                        """
                                        PfR site prefix mask of the packet source
                                        
                                        .. attribute:: ipv4
                                        
                                        	site prefix mask of the packet source
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Collect.Pfr.Site.Source.Prefix.Mask, self).__init__()

                                            self.yang_name = "mask"
                                            self.yang_parent_name = "prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                            ])
                                            self.ipv4 = None
                                            self._segment_path = lambda: "mask"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Collect.Pfr.Site.Source.Prefix.Mask, ['ipv4'], name, value)


                    class Policy(Entity):
                        """
                        policy fields
                        
                        .. attribute:: performance_monitor
                        
                        	Performance\-monitor policy related metrics
                        	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Policy.PerformanceMonitor>`
                        
                        .. attribute:: qos
                        
                        	QoS policy related metrics
                        	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Policy.Qos>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("performance-monitor", ("performance_monitor", Native.Flow.Record.Default.Collect.Policy.PerformanceMonitor)), ("qos", ("qos", Native.Flow.Record.Default.Collect.Policy.Qos))])
                            self._leafs = OrderedDict()

                            self.performance_monitor = Native.Flow.Record.Default.Collect.Policy.PerformanceMonitor()
                            self.performance_monitor.parent = self
                            self._children_name_map["performance_monitor"] = "performance-monitor"

                            self.qos = Native.Flow.Record.Default.Collect.Policy.Qos()
                            self.qos.parent = self
                            self._children_name_map["qos"] = "qos"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Policy, [], name, value)


                        class PerformanceMonitor(Entity):
                            """
                            Performance\-monitor policy related metrics
                            
                            .. attribute:: classification
                            
                            	Classification metrics
                            	**type**\:  :py:class:`Classification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Policy.PerformanceMonitor.Classification>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Policy.PerformanceMonitor, self).__init__()

                                self.yang_name = "performance-monitor"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("classification", ("classification", Native.Flow.Record.Default.Collect.Policy.PerformanceMonitor.Classification))])
                                self._leafs = OrderedDict()

                                self.classification = Native.Flow.Record.Default.Collect.Policy.PerformanceMonitor.Classification()
                                self.classification.parent = self
                                self._children_name_map["classification"] = "classification"
                                self._segment_path = lambda: "performance-monitor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Policy.PerformanceMonitor, [], name, value)


                            class Classification(Entity):
                                """
                                Classification metrics
                                
                                .. attribute:: hierarchy
                                
                                	Performance\-monitor class hierarchy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Policy.PerformanceMonitor.Classification, self).__init__()

                                    self.yang_name = "classification"
                                    self.yang_parent_name = "performance-monitor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hierarchy', (YLeaf(YType.empty, 'hierarchy'), ['Empty'])),
                                    ])
                                    self.hierarchy = None
                                    self._segment_path = lambda: "classification"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Policy.PerformanceMonitor.Classification, ['hierarchy'], name, value)


                        class Qos(Entity):
                            """
                            QoS policy related metrics
                            
                            .. attribute:: classification
                            
                            	Classification metrics
                            	**type**\:  :py:class:`Classification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Policy.Qos.Classification>`
                            
                            .. attribute:: queue
                            
                            	Queue metrics
                            	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Policy.Qos.Queue>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Policy.Qos, self).__init__()

                                self.yang_name = "qos"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("classification", ("classification", Native.Flow.Record.Default.Collect.Policy.Qos.Classification)), ("queue", ("queue", Native.Flow.Record.Default.Collect.Policy.Qos.Queue))])
                                self._leafs = OrderedDict()

                                self.classification = Native.Flow.Record.Default.Collect.Policy.Qos.Classification()
                                self.classification.parent = self
                                self._children_name_map["classification"] = "classification"

                                self.queue = Native.Flow.Record.Default.Collect.Policy.Qos.Queue()
                                self.queue.parent = self
                                self._children_name_map["queue"] = "queue"
                                self._segment_path = lambda: "qos"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Policy.Qos, [], name, value)


                            class Classification(Entity):
                                """
                                Classification metrics
                                
                                .. attribute:: hierarchy
                                
                                	QoS class hierarchy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Policy.Qos.Classification, self).__init__()

                                    self.yang_name = "classification"
                                    self.yang_parent_name = "qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hierarchy', (YLeaf(YType.empty, 'hierarchy'), ['Empty'])),
                                    ])
                                    self.hierarchy = None
                                    self._segment_path = lambda: "classification"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Policy.Qos.Classification, ['hierarchy'], name, value)


                            class Queue(Entity):
                                """
                                Queue metrics
                                
                                .. attribute:: drops
                                
                                	QoS queue drops
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: index
                                
                                	QoS queue index
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Policy.Qos.Queue, self).__init__()

                                    self.yang_name = "queue"
                                    self.yang_parent_name = "qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('drops', (YLeaf(YType.empty, 'drops'), ['Empty'])),
                                        ('index', (YLeaf(YType.empty, 'index'), ['Empty'])),
                                    ])
                                    self.drops = None
                                    self.index = None
                                    self._segment_path = lambda: "queue"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Policy.Qos.Queue, ['drops', 'index'], name, value)


                    class Routing(Entity):
                        """
                        Routing attributes
                        
                        .. attribute:: destination
                        
                        	Destination routing attributes
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.Destination>`
                        
                        .. attribute:: forwarding_status
                        
                        	Forwarding status of the packet
                        	**type**\:  :py:class:`ForwardingStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.ForwardingStatus>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: is_multicast
                        
                        	Indicates if this is multicast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: next_hop
                        
                        	Information regarding the next hop
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.NextHop>`
                        
                        .. attribute:: pw
                        
                        	Pseudowire fields
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.Pw>`
                        
                        .. attribute:: source
                        
                        	Source routing attributes
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.Source>`
                        
                        .. attribute:: vrf
                        
                        	VRF routing attributes
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Routing, self).__init__()

                            self.yang_name = "routing"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Collect.Routing.Destination)), ("forwarding-status", ("forwarding_status", Native.Flow.Record.Default.Collect.Routing.ForwardingStatus)), ("next-hop", ("next_hop", Native.Flow.Record.Default.Collect.Routing.NextHop)), ("pw", ("pw", Native.Flow.Record.Default.Collect.Routing.Pw)), ("source", ("source", Native.Flow.Record.Default.Collect.Routing.Source)), ("vrf", ("vrf", Native.Flow.Record.Default.Collect.Routing.Vrf))])
                            self._leafs = OrderedDict([
                                ('is_multicast', (YLeaf(YType.empty, 'is-multicast'), ['Empty'])),
                            ])
                            self.is_multicast = None

                            self.destination = Native.Flow.Record.Default.Collect.Routing.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.forwarding_status = None
                            self._children_name_map["forwarding_status"] = "forwarding-status"

                            self.next_hop = Native.Flow.Record.Default.Collect.Routing.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"

                            self.pw = Native.Flow.Record.Default.Collect.Routing.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"

                            self.source = Native.Flow.Record.Default.Collect.Routing.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"

                            self.vrf = Native.Flow.Record.Default.Collect.Routing.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._segment_path = lambda: "routing"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Routing, ['is_multicast'], name, value)


                        class Destination(Entity):
                            """
                            Destination routing attributes
                            
                            .. attribute:: as_
                            
                            	AS number of the destination network
                            	**type**\:  :py:class:`As <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.Destination.As>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: traffic_index
                            
                            	BGP destination traffic index
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Routing.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("as", ("as_", Native.Flow.Record.Default.Collect.Routing.Destination.As))])
                                self._leafs = OrderedDict([
                                    ('traffic_index', (YLeaf(YType.empty, 'traffic-index'), ['Empty'])),
                                ])
                                self.traffic_index = None

                                self.as_ = None
                                self._children_name_map["as_"] = "as"
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.Destination, ['traffic_index'], name, value)


                            class As(Entity):
                                """
                                AS number of the destination network
                                
                                .. attribute:: as4_octet
                                
                                	4 octet AS number of the destination network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: peer
                                
                                	AS number of the peer network we will forward to
                                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.Destination.As.Peer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Routing.Destination.As, self).__init__()

                                    self.yang_name = "as"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("peer", ("peer", Native.Flow.Record.Default.Collect.Routing.Destination.As.Peer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('as4_octet', (YLeaf(YType.empty, 'as4-octet'), ['Empty'])),
                                    ])
                                    self.as4_octet = None

                                    self.peer = None
                                    self._children_name_map["peer"] = "peer"
                                    self._segment_path = lambda: "as"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.Destination.As, ['as4_octet'], name, value)


                                class Peer(Entity):
                                    """
                                    AS number of the peer network we will forward to
                                    
                                    .. attribute:: peer4_octet
                                    
                                    	4 octet AS number of the peer network we will forward to
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Routing.Destination.As.Peer, self).__init__()

                                        self.yang_name = "peer"
                                        self.yang_parent_name = "as"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('peer4_octet', (YLeaf(YType.empty, 'peer4-octet'), ['Empty'])),
                                        ])
                                        self.peer4_octet = None
                                        self._segment_path = lambda: "peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.Destination.As.Peer, ['peer4_octet'], name, value)


                        class ForwardingStatus(Entity):
                            """
                            Forwarding status of the packet
                            
                            .. attribute:: reason
                            
                            	Forwarding status reason of the packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Routing.ForwardingStatus, self).__init__()

                                self.yang_name = "forwarding-status"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('reason', (YLeaf(YType.empty, 'reason'), ['Empty'])),
                                ])
                                self.reason = None
                                self._segment_path = lambda: "forwarding-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.ForwardingStatus, ['reason'], name, value)


                        class NextHop(Entity):
                            """
                            Information regarding the next hop
                            
                            .. attribute:: address
                            
                            	IP address of the next hop
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.NextHop.Address>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Routing.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Default.Collect.Routing.NextHop.Address))])
                                self._leafs = OrderedDict()

                                self.address = Native.Flow.Record.Default.Collect.Routing.NextHop.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.NextHop, [], name, value)


                            class Address(Entity):
                                """
                                IP address of the next hop
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address of the next hop
                                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.NextHop.Address.Ipv4>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address of the next hop
                                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.NextHop.Address.Ipv6>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Routing.NextHop.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Default.Collect.Routing.NextHop.Address.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Default.Collect.Routing.NextHop.Address.Ipv6))])
                                    self._leafs = OrderedDict()

                                    self.ipv4 = None
                                    self._children_name_map["ipv4"] = "ipv4"

                                    self.ipv6 = None
                                    self._children_name_map["ipv6"] = "ipv6"
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.NextHop.Address, [], name, value)


                                class Ipv4(Entity):
                                    """
                                    IPv4 address of the next hop
                                    
                                    .. attribute:: bgp
                                    
                                    	IPv4 address of the BGP next hop
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Routing.NextHop.Address.Ipv4, self).__init__()

                                        self.yang_name = "ipv4"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                                        ])
                                        self.bgp = None
                                        self._segment_path = lambda: "ipv4"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.NextHop.Address.Ipv4, ['bgp'], name, value)


                                class Ipv6(Entity):
                                    """
                                    IPv6 address of the next hop
                                    
                                    .. attribute:: bgp
                                    
                                    	IPv6 address of the BGP next hop
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Routing.NextHop.Address.Ipv6, self).__init__()

                                        self.yang_name = "ipv6"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                                        ])
                                        self.bgp = None
                                        self._segment_path = lambda: "ipv6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.NextHop.Address.Ipv6, ['bgp'], name, value)


                        class Pw(Entity):
                            """
                            Pseudowire fields
                            
                            .. attribute:: destination
                            
                            	Pseudowire destination
                            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.Pw.Destination>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Routing.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Collect.Routing.Pw.Destination))])
                                self._leafs = OrderedDict()

                                self.destination = Native.Flow.Record.Default.Collect.Routing.Pw.Destination()
                                self.destination.parent = self
                                self._children_name_map["destination"] = "destination"
                                self._segment_path = lambda: "pw"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.Pw, [], name, value)


                            class Destination(Entity):
                                """
                                Pseudowire destination
                                
                                .. attribute:: address
                                
                                	Pseudowire destination address
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Routing.Pw.Destination, self).__init__()

                                    self.yang_name = "destination"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self._segment_path = lambda: "destination"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.Pw.Destination, ['address'], name, value)


                        class Source(Entity):
                            """
                            Source routing attributes
                            
                            .. attribute:: as_
                            
                            	AS number of the original network
                            	**type**\:  :py:class:`As <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.Source.As>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: traffic_index
                            
                            	BGP source traffic index
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Routing.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("as", ("as_", Native.Flow.Record.Default.Collect.Routing.Source.As))])
                                self._leafs = OrderedDict([
                                    ('traffic_index', (YLeaf(YType.empty, 'traffic-index'), ['Empty'])),
                                ])
                                self.traffic_index = None

                                self.as_ = None
                                self._children_name_map["as_"] = "as"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.Source, ['traffic_index'], name, value)


                            class As(Entity):
                                """
                                AS number of the original network
                                
                                .. attribute:: as4_octet
                                
                                	4 octet AS number of the original network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: peer
                                
                                	AS number of the peer network where the packet came from
                                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Routing.Source.As.Peer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Routing.Source.As, self).__init__()

                                    self.yang_name = "as"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("peer", ("peer", Native.Flow.Record.Default.Collect.Routing.Source.As.Peer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('as4_octet', (YLeaf(YType.empty, 'as4-octet'), ['Empty'])),
                                    ])
                                    self.as4_octet = None

                                    self.peer = None
                                    self._children_name_map["peer"] = "peer"
                                    self._segment_path = lambda: "as"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.Source.As, ['as4_octet'], name, value)


                                class Peer(Entity):
                                    """
                                    AS number of the peer network where the packet came from
                                    
                                    .. attribute:: peer4_octet
                                    
                                    	4 octet AS number of the peer network where the packet came from
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Routing.Source.As.Peer, self).__init__()

                                        self.yang_name = "peer"
                                        self.yang_parent_name = "as"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('peer4_octet', (YLeaf(YType.empty, 'peer4-octet'), ['Empty'])),
                                        ])
                                        self.peer4_octet = None
                                        self._segment_path = lambda: "peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.Source.As.Peer, ['peer4_octet'], name, value)


                        class Vrf(Entity):
                            """
                            VRF routing attributes
                            
                            .. attribute:: input
                            
                            	VRF ID for incoming packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: output
                            
                            	VRF ID for outgoing packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Routing.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                    ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ])
                                self.input = None
                                self.output = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Routing.Vrf, ['input', 'output'], name, value)


                    class Services(Entity):
                        """
                        Services fields
                        
                        .. attribute:: waas
                        
                        	WAAS (Wide Area Application Services) metrics
                        	**type**\:  :py:class:`Waas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Services.Waas>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Services, self).__init__()

                            self.yang_name = "services"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("waas", ("waas", Native.Flow.Record.Default.Collect.Services.Waas))])
                            self._leafs = OrderedDict()

                            self.waas = Native.Flow.Record.Default.Collect.Services.Waas()
                            self.waas.parent = self
                            self._children_name_map["waas"] = "waas"
                            self._segment_path = lambda: "services"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Services, [], name, value)


                        class Waas(Entity):
                            """
                            WAAS (Wide Area Application Services) metrics
                            
                            .. attribute:: passthrough_reason
                            
                            	WAAS passthrough reason
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: segment
                            
                            	WAAS optimization segment
                            	**type**\:  :py:class:`Segment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Services.Waas.Segment>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Services.Waas, self).__init__()

                                self.yang_name = "waas"
                                self.yang_parent_name = "services"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("segment", ("segment", Native.Flow.Record.Default.Collect.Services.Waas.Segment))])
                                self._leafs = OrderedDict([
                                    ('passthrough_reason', (YLeaf(YType.empty, 'passthrough-reason'), ['Empty'])),
                                ])
                                self.passthrough_reason = None

                                self.segment = None
                                self._children_name_map["segment"] = "segment"
                                self._segment_path = lambda: "waas"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Services.Waas, ['passthrough_reason'], name, value)


                            class Segment(Entity):
                                """
                                WAAS optimization segment
                                
                                .. attribute:: account_on_resolution
                                
                                	Account on resolution
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Services.Waas.Segment, self).__init__()

                                    self.yang_name = "segment"
                                    self.yang_parent_name = "waas"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('account_on_resolution', (YLeaf(YType.empty, 'account-on-resolution'), ['Empty'])),
                                    ])
                                    self.account_on_resolution = None
                                    self._segment_path = lambda: "segment"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Services.Waas.Segment, ['account_on_resolution'], name, value)


                    class Timestamp(Entity):
                        """
                        Timestamp fields
                        
                        .. attribute:: absolute
                        
                        	Timestamps based on the epoch of 00\:00 UTC 1st Jan 1970
                        	**type**\:  :py:class:`Absolute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Timestamp.Absolute>`
                        
                        .. attribute:: interval
                        
                        	Epoch of a monitoring interval
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: sys_uptime
                        
                        	Timestamps based on the sys\-uptime
                        	**type**\:  :py:class:`SysUptime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Timestamp.SysUptime>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Timestamp, self).__init__()

                            self.yang_name = "timestamp"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("absolute", ("absolute", Native.Flow.Record.Default.Collect.Timestamp.Absolute)), ("sys-uptime", ("sys_uptime", Native.Flow.Record.Default.Collect.Timestamp.SysUptime))])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.empty, 'interval'), ['Empty'])),
                            ])
                            self.interval = None

                            self.absolute = Native.Flow.Record.Default.Collect.Timestamp.Absolute()
                            self.absolute.parent = self
                            self._children_name_map["absolute"] = "absolute"

                            self.sys_uptime = Native.Flow.Record.Default.Collect.Timestamp.SysUptime()
                            self.sys_uptime.parent = self
                            self._children_name_map["sys_uptime"] = "sys-uptime"
                            self._segment_path = lambda: "timestamp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Timestamp, ['interval'], name, value)


                        class Absolute(Entity):
                            """
                            Timestamps based on the epoch of 00\:00 UTC 1st Jan 1970
                            
                            .. attribute:: first
                            
                            	Absolute time the first packet was seen (milliseconds)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: last
                            
                            	Absolute time the most recent packet was seen (milliseconds)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: monitoring_interval
                            
                            	Monitoring interval timestamps
                            	**type**\:  :py:class:`MonitoringInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Timestamp.Absolute.MonitoringInterval>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Timestamp.Absolute, self).__init__()

                                self.yang_name = "absolute"
                                self.yang_parent_name = "timestamp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("monitoring-interval", ("monitoring_interval", Native.Flow.Record.Default.Collect.Timestamp.Absolute.MonitoringInterval))])
                                self._leafs = OrderedDict([
                                    ('first', (YLeaf(YType.empty, 'first'), ['Empty'])),
                                    ('last', (YLeaf(YType.empty, 'last'), ['Empty'])),
                                ])
                                self.first = None
                                self.last = None

                                self.monitoring_interval = Native.Flow.Record.Default.Collect.Timestamp.Absolute.MonitoringInterval()
                                self.monitoring_interval.parent = self
                                self._children_name_map["monitoring_interval"] = "monitoring-interval"
                                self._segment_path = lambda: "absolute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Timestamp.Absolute, ['first', 'last'], name, value)


                            class MonitoringInterval(Entity):
                                """
                                Monitoring interval timestamps
                                
                                .. attribute:: end
                                
                                	Absolute end time of a monitoring interval (milliseconds)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: start
                                
                                	Absolute start time of a monitoring interval (milliseconds)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Timestamp.Absolute.MonitoringInterval, self).__init__()

                                    self.yang_name = "monitoring-interval"
                                    self.yang_parent_name = "absolute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('end', (YLeaf(YType.empty, 'end'), ['Empty'])),
                                        ('start', (YLeaf(YType.empty, 'start'), ['Empty'])),
                                    ])
                                    self.end = None
                                    self.start = None
                                    self._segment_path = lambda: "monitoring-interval"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Timestamp.Absolute.MonitoringInterval, ['end', 'start'], name, value)


                        class SysUptime(Entity):
                            """
                            Timestamps based on the sys\-uptime
                            
                            .. attribute:: first
                            
                            	Time the first packet was seen
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: last
                            
                            	Time the most recent packet was seen
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Timestamp.SysUptime, self).__init__()

                                self.yang_name = "sys-uptime"
                                self.yang_parent_name = "timestamp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('first', (YLeaf(YType.empty, 'first'), ['Empty'])),
                                    ('last', (YLeaf(YType.empty, 'last'), ['Empty'])),
                                ])
                                self.first = None
                                self.last = None
                                self._segment_path = lambda: "sys-uptime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Timestamp.SysUptime, ['first', 'last'], name, value)


                    class Transport(Entity):
                        """
                        Transport layer fields
                        
                        .. attribute:: bytes
                        
                        	Bytes fields
                        	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Bytes>`
                        
                        .. attribute:: destination_port
                        
                        	Transport destination port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: icmp
                        
                        	ICMP fields
                        	**type**\:  :py:class:`Icmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Icmp>`
                        
                        .. attribute:: igmp
                        
                        	IGMP fields
                        	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Igmp>`
                        
                        .. attribute:: source_port
                        
                        	Transport source port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tcp
                        
                        	TCP fields
                        	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Tcp>`
                        
                        .. attribute:: udp
                        
                        	UDP fields
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Udp>`
                        
                        .. attribute:: event
                        
                        	Transport event fields
                        	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Event>`
                        
                        .. attribute:: packets
                        
                        	Transport packet fields
                        	**type**\:  :py:class:`Packets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Packets>`
                        
                        .. attribute:: round_trip_time
                        
                        	RTT calculation for flow
                        	**type**\:  :py:class:`RoundTripTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.RoundTripTime>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: rtp
                        
                        	RTP fields
                        	**type**\:  :py:class:`Rtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Rtp>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Collect.Transport, self).__init__()

                            self.yang_name = "transport"
                            self.yang_parent_name = "collect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Default.Collect.Transport.Bytes)), ("icmp", ("icmp", Native.Flow.Record.Default.Collect.Transport.Icmp)), ("igmp", ("igmp", Native.Flow.Record.Default.Collect.Transport.Igmp)), ("tcp", ("tcp", Native.Flow.Record.Default.Collect.Transport.Tcp)), ("udp", ("udp", Native.Flow.Record.Default.Collect.Transport.Udp)), ("event", ("event", Native.Flow.Record.Default.Collect.Transport.Event)), ("packets", ("packets", Native.Flow.Record.Default.Collect.Transport.Packets)), ("round-trip-time", ("round_trip_time", Native.Flow.Record.Default.Collect.Transport.RoundTripTime)), ("rtp", ("rtp", Native.Flow.Record.Default.Collect.Transport.Rtp))])
                            self._leafs = OrderedDict([
                                ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                                ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                            ])
                            self.destination_port = None
                            self.source_port = None

                            self.bytes = Native.Flow.Record.Default.Collect.Transport.Bytes()
                            self.bytes.parent = self
                            self._children_name_map["bytes"] = "bytes"

                            self.icmp = Native.Flow.Record.Default.Collect.Transport.Icmp()
                            self.icmp.parent = self
                            self._children_name_map["icmp"] = "icmp"

                            self.igmp = Native.Flow.Record.Default.Collect.Transport.Igmp()
                            self.igmp.parent = self
                            self._children_name_map["igmp"] = "igmp"

                            self.tcp = Native.Flow.Record.Default.Collect.Transport.Tcp()
                            self.tcp.parent = self
                            self._children_name_map["tcp"] = "tcp"

                            self.udp = Native.Flow.Record.Default.Collect.Transport.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"

                            self.event = Native.Flow.Record.Default.Collect.Transport.Event()
                            self.event.parent = self
                            self._children_name_map["event"] = "event"

                            self.packets = Native.Flow.Record.Default.Collect.Transport.Packets()
                            self.packets.parent = self
                            self._children_name_map["packets"] = "packets"

                            self.round_trip_time = None
                            self._children_name_map["round_trip_time"] = "round-trip-time"

                            self.rtp = Native.Flow.Record.Default.Collect.Transport.Rtp()
                            self.rtp.parent = self
                            self._children_name_map["rtp"] = "rtp"
                            self._segment_path = lambda: "transport"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Collect.Transport, ['destination_port', 'source_port'], name, value)


                        class Bytes(Entity):
                            """
                            Bytes fields
                            
                            .. attribute:: expected
                            
                            	Transport bytes expected
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: lost
                            
                            	Transport bytes lost
                            	**type**\:  :py:class:`Lost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Bytes.Lost>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: out_of_order
                            
                            	Total number of out\-of\-order bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Transport.Bytes, self).__init__()

                                self.yang_name = "bytes"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lost", ("lost", Native.Flow.Record.Default.Collect.Transport.Bytes.Lost))])
                                self._leafs = OrderedDict([
                                    ('expected', (YLeaf(YType.empty, 'expected'), ['Empty'])),
                                    ('out_of_order', (YLeaf(YType.empty, 'out-of-order'), ['Empty'])),
                                ])
                                self.expected = None
                                self.out_of_order = None

                                self.lost = None
                                self._children_name_map["lost"] = "lost"
                                self._segment_path = lambda: "bytes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Bytes, ['expected', 'out_of_order'], name, value)


                            class Lost(Entity):
                                """
                                Transport bytes lost
                                
                                .. attribute:: rate
                                
                                	Transport bytes lost rate
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Bytes.Lost, self).__init__()

                                    self.yang_name = "lost"
                                    self.yang_parent_name = "bytes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('rate', (YLeaf(YType.empty, 'rate'), ['Empty'])),
                                    ])
                                    self.rate = None
                                    self._segment_path = lambda: "lost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Bytes.Lost, ['rate'], name, value)


                        class Icmp(Entity):
                            """
                            ICMP fields
                            
                            .. attribute:: ipv4
                            
                            	IPv4 ICMP fields
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Icmp.Ipv4>`
                            
                            .. attribute:: ipv6
                            
                            	IPv6 ICMP fields
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Icmp.Ipv6>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Transport.Icmp, self).__init__()

                                self.yang_name = "icmp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Default.Collect.Transport.Icmp.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Default.Collect.Transport.Icmp.Ipv6))])
                                self._leafs = OrderedDict()

                                self.ipv4 = Native.Flow.Record.Default.Collect.Transport.Icmp.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = Native.Flow.Record.Default.Collect.Transport.Icmp.Ipv6()
                                self.ipv6.parent = self
                                self._children_name_map["ipv6"] = "ipv6"
                                self._segment_path = lambda: "icmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Icmp, [], name, value)


                            class Ipv4(Entity):
                                """
                                IPv4 ICMP fields
                                
                                .. attribute:: code
                                
                                	IPv4 ICMP code
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: type
                                
                                	IPv4 ICMP type
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Icmp.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "icmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('code', (YLeaf(YType.empty, 'code'), ['Empty'])),
                                        ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                    ])
                                    self.code = None
                                    self.type = None
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Icmp.Ipv4, ['code', 'type'], name, value)


                            class Ipv6(Entity):
                                """
                                IPv6 ICMP fields
                                
                                .. attribute:: code
                                
                                	IPv6 ICMP code
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: type
                                
                                	IPv6 ICMP type
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Icmp.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "icmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('code', (YLeaf(YType.empty, 'code'), ['Empty'])),
                                        ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                    ])
                                    self.code = None
                                    self.type = None
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Icmp.Ipv6, ['code', 'type'], name, value)


                        class Igmp(Entity):
                            """
                            IGMP fields
                            
                            .. attribute:: type
                            
                            	IGMP type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Transport.Igmp, self).__init__()

                                self.yang_name = "igmp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                ])
                                self.type = None
                                self._segment_path = lambda: "igmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Igmp, ['type'], name, value)


                        class Tcp(Entity):
                            """
                            TCP fields
                            
                            .. attribute:: acknowledgement_number
                            
                            	TCP acknowledgement number
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: destination_port
                            
                            	TCP destination port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: flags
                            
                            	TCP flags
                            	**type**\:  :py:class:`Flags <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Tcp.Flags>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: flow
                            
                            	TCP flow
                            	**type**\:  :py:class:`Flow_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Tcp.Flow_>`
                            
                            .. attribute:: header_length
                            
                            	TCP header length (in 32 bit words)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: maximum_segment_size
                            
                            	The maximum size of TCP segment
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: option
                            
                            	TCP option fields
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Tcp.Option>`
                            
                            .. attribute:: sequence_number
                            
                            	TCP sequence number
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: source_port
                            
                            	TCP source port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: urgent_pointer
                            
                            	TCP urgent pointer
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: window_size
                            
                            	TCP window size
                            	**type**\:  :py:class:`WindowSize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Tcp.WindowSize>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Transport.Tcp, self).__init__()

                                self.yang_name = "tcp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("flags", ("flags", Native.Flow.Record.Default.Collect.Transport.Tcp.Flags)), ("flow", ("flow", Native.Flow.Record.Default.Collect.Transport.Tcp.Flow_)), ("option", ("option", Native.Flow.Record.Default.Collect.Transport.Tcp.Option)), ("window-size", ("window_size", Native.Flow.Record.Default.Collect.Transport.Tcp.WindowSize))])
                                self._leafs = OrderedDict([
                                    ('acknowledgement_number', (YLeaf(YType.empty, 'acknowledgement-number'), ['Empty'])),
                                    ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                                    ('header_length', (YLeaf(YType.empty, 'header-length'), ['Empty'])),
                                    ('maximum_segment_size', (YLeaf(YType.empty, 'maximum-segment-size'), ['Empty'])),
                                    ('sequence_number', (YLeaf(YType.empty, 'sequence-number'), ['Empty'])),
                                    ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                                    ('urgent_pointer', (YLeaf(YType.empty, 'urgent-pointer'), ['Empty'])),
                                ])
                                self.acknowledgement_number = None
                                self.destination_port = None
                                self.header_length = None
                                self.maximum_segment_size = None
                                self.sequence_number = None
                                self.source_port = None
                                self.urgent_pointer = None

                                self.flags = None
                                self._children_name_map["flags"] = "flags"

                                self.flow = Native.Flow.Record.Default.Collect.Transport.Tcp.Flow_()
                                self.flow.parent = self
                                self._children_name_map["flow"] = "flow"

                                self.option = Native.Flow.Record.Default.Collect.Transport.Tcp.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.window_size = None
                                self._children_name_map["window_size"] = "window-size"
                                self._segment_path = lambda: "tcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Tcp, ['acknowledgement_number', 'destination_port', 'header_length', 'maximum_segment_size', 'sequence_number', 'source_port', 'urgent_pointer'], name, value)


                            class Flags(Entity):
                                """
                                TCP flags
                                
                                .. attribute:: ack
                                
                                	TCP acknowledgement flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: cwr
                                
                                	TCP congestion window reduced flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ece
                                
                                	TCP ECN echo flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: fin
                                
                                	TCP finish flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: psh
                                
                                	TCP push flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rst
                                
                                	TCP reset flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: syn
                                
                                	TCP synchronise flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: urg
                                
                                	TCP urgent flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Tcp.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "tcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                        ('cwr', (YLeaf(YType.empty, 'cwr'), ['Empty'])),
                                        ('ece', (YLeaf(YType.empty, 'ece'), ['Empty'])),
                                        ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                        ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                        ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                        ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                        ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                    ])
                                    self.ack = None
                                    self.cwr = None
                                    self.ece = None
                                    self.fin = None
                                    self.psh = None
                                    self.rst = None
                                    self.syn = None
                                    self.urg = None
                                    self._segment_path = lambda: "flags"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Tcp.Flags, ['ack', 'cwr', 'ece', 'fin', 'psh', 'rst', 'syn', 'urg'], name, value)


                            class Flow_(Entity):
                                """
                                TCP flow
                                
                                .. attribute:: count
                                
                                	Number of tcp flows
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Tcp.Flow_, self).__init__()

                                    self.yang_name = "flow"
                                    self.yang_parent_name = "tcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.empty, 'count'), ['Empty'])),
                                    ])
                                    self.count = None
                                    self._segment_path = lambda: "flow"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Tcp.Flow_, ['count'], name, value)


                            class Option(Entity):
                                """
                                TCP option fields
                                
                                .. attribute:: map
                                
                                	Bitmap of TCP options
                                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Tcp.Option.Map>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Tcp.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "tcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map", ("map", Native.Flow.Record.Default.Collect.Transport.Tcp.Option.Map))])
                                    self._leafs = OrderedDict()

                                    self.map = None
                                    self._children_name_map["map"] = "map"
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Tcp.Option, [], name, value)


                                class Map(Entity):
                                    """
                                    Bitmap of TCP options
                                    
                                    .. attribute:: long
                                    
                                    	Extended bitmap of TCP options
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Transport.Tcp.Option.Map, self).__init__()

                                        self.yang_name = "map"
                                        self.yang_parent_name = "option"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self._segment_path = lambda: "map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Tcp.Option.Map, ['long'], name, value)


                            class WindowSize(Entity):
                                """
                                TCP window size
                                
                                .. attribute:: average
                                
                                	The average size of TCP window
                                	**type**\:  :py:class:`Average <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Tcp.WindowSize.Average>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: maximum
                                
                                	The maximum size of TCP window
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minimum
                                
                                	The minimum size of TCP window
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sum
                                
                                	The sum of TCP window size
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Tcp.WindowSize, self).__init__()

                                    self.yang_name = "window-size"
                                    self.yang_parent_name = "tcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("average", ("average", Native.Flow.Record.Default.Collect.Transport.Tcp.WindowSize.Average))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                        ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.maximum = None
                                    self.minimum = None
                                    self.sum = None

                                    self.average = None
                                    self._children_name_map["average"] = "average"
                                    self._segment_path = lambda: "window-size"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Tcp.WindowSize, ['maximum', 'minimum', 'sum'], name, value)


                                class Average(Entity):
                                    """
                                    The average size of TCP window
                                    
                                    .. attribute:: sum
                                    
                                    	The sum of per flow TCP window average size
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Transport.Tcp.WindowSize.Average, self).__init__()

                                        self.yang_name = "average"
                                        self.yang_parent_name = "window-size"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.sum = None
                                        self._segment_path = lambda: "average"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Tcp.WindowSize.Average, ['sum'], name, value)


                        class Udp(Entity):
                            """
                            UDP fields
                            
                            .. attribute:: destination_port
                            
                            	UDP destination port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: message_length
                            
                            	UDP message length
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: source_port
                            
                            	UDP source port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Transport.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                                    ('message_length', (YLeaf(YType.empty, 'message-length'), ['Empty'])),
                                    ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                                ])
                                self.destination_port = None
                                self.message_length = None
                                self.source_port = None
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Udp, ['destination_port', 'message_length', 'source_port'], name, value)


                        class Event(Entity):
                            """
                            Transport event fields
                            
                            .. attribute:: packet_loss
                            
                            	Transport event packet\-loss fields
                            	**type**\:  :py:class:`PacketLoss <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Event.PacketLoss>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Transport.Event, self).__init__()

                                self.yang_name = "event"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("packet-loss", ("packet_loss", Native.Flow.Record.Default.Collect.Transport.Event.PacketLoss))])
                                self._leafs = OrderedDict()

                                self.packet_loss = Native.Flow.Record.Default.Collect.Transport.Event.PacketLoss()
                                self.packet_loss.parent = self
                                self._children_name_map["packet_loss"] = "packet-loss"
                                self._segment_path = lambda: "event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Event, [], name, value)


                            class PacketLoss(Entity):
                                """
                                Transport event packet\-loss fields
                                
                                .. attribute:: counter
                                
                                	Count of sets of packets that were lost
                                	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Event.PacketLoss.Counter>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Event.PacketLoss, self).__init__()

                                    self.yang_name = "packet-loss"
                                    self.yang_parent_name = "event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Default.Collect.Transport.Event.PacketLoss.Counter))])
                                    self._leafs = OrderedDict()

                                    self.counter = None
                                    self._children_name_map["counter"] = "counter"
                                    self._segment_path = lambda: "packet-loss"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Event.PacketLoss, [], name, value)


                                class Counter(Entity):
                                    """
                                    Count of sets of packets that were lost
                                    
                                    .. attribute:: max
                                    
                                    	Highest packet loss counter when multiple flows are aggregated
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Lowest packet loss counter when multiple flows are aggregated
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Transport.Event.PacketLoss.Counter, self).__init__()

                                        self.yang_name = "counter"
                                        self.yang_parent_name = "packet-loss"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ])
                                        self.max = None
                                        self.min = None
                                        self._segment_path = lambda: "counter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Event.PacketLoss.Counter, ['max', 'min'], name, value)


                        class Packets(Entity):
                            """
                            Transport packet fields
                            
                            .. attribute:: expected
                            
                            	Transport packets expected fields
                            	**type**\:  :py:class:`Expected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Packets.Expected>`
                            
                            .. attribute:: lost
                            
                            	Transport packets lost fields
                            	**type**\:  :py:class:`Lost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Packets.Lost>`
                            
                            .. attribute:: out_of_order
                            
                            	Total number of out\-of\-order bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Transport.Packets, self).__init__()

                                self.yang_name = "packets"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("expected", ("expected", Native.Flow.Record.Default.Collect.Transport.Packets.Expected)), ("lost", ("lost", Native.Flow.Record.Default.Collect.Transport.Packets.Lost))])
                                self._leafs = OrderedDict([
                                    ('out_of_order', (YLeaf(YType.empty, 'out-of-order'), ['Empty'])),
                                ])
                                self.out_of_order = None

                                self.expected = Native.Flow.Record.Default.Collect.Transport.Packets.Expected()
                                self.expected.parent = self
                                self._children_name_map["expected"] = "expected"

                                self.lost = Native.Flow.Record.Default.Collect.Transport.Packets.Lost()
                                self.lost.parent = self
                                self._children_name_map["lost"] = "lost"
                                self._segment_path = lambda: "packets"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Packets, ['out_of_order'], name, value)


                            class Expected(Entity):
                                """
                                Transport packets expected fields
                                
                                .. attribute:: counter
                                
                                	Expected number of packets from sequencing information
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Packets.Expected, self).__init__()

                                    self.yang_name = "expected"
                                    self.yang_parent_name = "packets"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('counter', (YLeaf(YType.empty, 'counter'), ['Empty'])),
                                    ])
                                    self.counter = None
                                    self._segment_path = lambda: "expected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Packets.Expected, ['counter'], name, value)


                            class Lost(Entity):
                                """
                                Transport packets lost fields
                                
                                .. attribute:: counter
                                
                                	A count of the number of lost packets from sequencing information
                                	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Packets.Lost.Counter>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: rate
                                
                                	Packet loss rate from sequencing information
                                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Packets.Lost.Rate>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Packets.Lost, self).__init__()

                                    self.yang_name = "lost"
                                    self.yang_parent_name = "packets"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("counter", ("counter", Native.Flow.Record.Default.Collect.Transport.Packets.Lost.Counter)), ("rate", ("rate", Native.Flow.Record.Default.Collect.Transport.Packets.Lost.Rate))])
                                    self._leafs = OrderedDict()

                                    self.counter = None
                                    self._children_name_map["counter"] = "counter"

                                    self.rate = None
                                    self._children_name_map["rate"] = "rate"
                                    self._segment_path = lambda: "lost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Packets.Lost, [], name, value)


                                class Counter(Entity):
                                    """
                                    A count of the number of lost packets from sequencing information
                                    
                                    .. attribute:: max
                                    
                                    	Highest lost packet count seen among the aggregated flows
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Lowest lost packet count seen among the aggregated flows
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Transport.Packets.Lost.Counter, self).__init__()

                                        self.yang_name = "counter"
                                        self.yang_parent_name = "lost"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ])
                                        self.max = None
                                        self.min = None
                                        self._segment_path = lambda: "counter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Packets.Lost.Counter, ['max', 'min'], name, value)


                                class Rate(Entity):
                                    """
                                    Packet loss rate from sequencing information
                                    
                                    .. attribute:: max
                                    
                                    	Maximum packet loss rate in the aggregated flows
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: min
                                    
                                    	Minimum packet loss rate in the aggregated flows
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Transport.Packets.Lost.Rate, self).__init__()

                                        self.yang_name = "rate"
                                        self.yang_parent_name = "lost"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                            ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                        ])
                                        self.max = None
                                        self.min = None
                                        self._segment_path = lambda: "rate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Packets.Lost.Rate, ['max', 'min'], name, value)


                        class RoundTripTime(Entity):
                            """
                            RTT calculation for flow
                            
                            .. attribute:: max
                            
                            	Highest RTT among all flows
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: min
                            
                            	Lowest RTT among all flows
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: samples
                            
                            	RTT samples
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sum
                            
                            	Sum RTT for all flows
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Transport.RoundTripTime, self).__init__()

                                self.yang_name = "round-trip-time"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('max', (YLeaf(YType.empty, 'max'), ['Empty'])),
                                    ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ('samples', (YLeaf(YType.empty, 'samples'), ['Empty'])),
                                    ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                ])
                                self.max = None
                                self.min = None
                                self.samples = None
                                self.sum = None
                                self._segment_path = lambda: "round-trip-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.RoundTripTime, ['max', 'min', 'samples', 'sum'], name, value)


                        class Rtp(Entity):
                            """
                            RTP fields
                            
                            .. attribute:: flow
                            
                            	RTP  flow
                            	**type**\:  :py:class:`Flow_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Rtp.Flow_>`
                            
                            .. attribute:: jitter
                            
                            	RTP jitter fields
                            	**type**\:  :py:class:`Jitter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Rtp.Jitter>`
                            
                            .. attribute:: payload_type
                            
                            	RTP payload type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ssrc
                            
                            	RTP SSRC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Collect.Transport.Rtp, self).__init__()

                                self.yang_name = "rtp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("flow", ("flow", Native.Flow.Record.Default.Collect.Transport.Rtp.Flow_)), ("jitter", ("jitter", Native.Flow.Record.Default.Collect.Transport.Rtp.Jitter))])
                                self._leafs = OrderedDict([
                                    ('payload_type', (YLeaf(YType.empty, 'payload-type'), ['Empty'])),
                                    ('ssrc', (YLeaf(YType.empty, 'ssrc'), ['Empty'])),
                                ])
                                self.payload_type = None
                                self.ssrc = None

                                self.flow = Native.Flow.Record.Default.Collect.Transport.Rtp.Flow_()
                                self.flow.parent = self
                                self._children_name_map["flow"] = "flow"

                                self.jitter = Native.Flow.Record.Default.Collect.Transport.Rtp.Jitter()
                                self.jitter.parent = self
                                self._children_name_map["jitter"] = "jitter"
                                self._segment_path = lambda: "rtp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Rtp, ['payload_type', 'ssrc'], name, value)


                            class Flow_(Entity):
                                """
                                RTP  flow
                                
                                .. attribute:: count
                                
                                	Number of RTP flows
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Rtp.Flow_, self).__init__()

                                    self.yang_name = "flow"
                                    self.yang_parent_name = "rtp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.empty, 'count'), ['Empty'])),
                                    ])
                                    self.count = None
                                    self._segment_path = lambda: "flow"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Rtp.Flow_, ['count'], name, value)


                            class Jitter(Entity):
                                """
                                RTP jitter fields
                                
                                .. attribute:: maximum
                                
                                	Maximum jitter for the RTP stream
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: mean
                                
                                	Mean jitter for the RTP stream
                                	**type**\:  :py:class:`Mean <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Collect.Transport.Rtp.Jitter.Mean>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: minimum
                                
                                	Minimum jitter for the RTP stream
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Collect.Transport.Rtp.Jitter, self).__init__()

                                    self.yang_name = "jitter"
                                    self.yang_parent_name = "rtp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mean", ("mean", Native.Flow.Record.Default.Collect.Transport.Rtp.Jitter.Mean))])
                                    self._leafs = OrderedDict([
                                        ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                        ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                    ])
                                    self.maximum = None
                                    self.minimum = None

                                    self.mean = None
                                    self._children_name_map["mean"] = "mean"
                                    self._segment_path = lambda: "jitter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Rtp.Jitter, ['maximum', 'minimum'], name, value)


                                class Mean(Entity):
                                    """
                                    Mean jitter for the RTP stream
                                    
                                    .. attribute:: sum
                                    
                                    	The sum of jitter mean for the RTP stream
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Collect.Transport.Rtp.Jitter.Mean, self).__init__()

                                        self.yang_name = "mean"
                                        self.yang_parent_name = "jitter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.sum = None
                                        self._segment_path = lambda: "mean"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Collect.Transport.Rtp.Jitter.Mean, ['sum'], name, value)


                class Match(Entity):
                    """
                    Specify a key field
                    
                    .. attribute:: application
                    
                    	Application fields
                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Application>`
                    
                    .. attribute:: connection
                    
                    	Connection fields
                    	**type**\:  :py:class:`Connection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Connection>`
                    
                    .. attribute:: datalink
                    
                    	Datalink (layer2) fields
                    	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Datalink>`
                    
                    .. attribute:: flow
                    
                    	Flow identifying fields
                    	**type**\:  :py:class:`Flow_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Flow_>`
                    
                    .. attribute:: interface
                    
                    	Interface fields
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Interface>`
                    
                    .. attribute:: ipv4
                    
                    	IPv4 fields
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 fields
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6>`
                    
                    .. attribute:: metadata
                    
                    	Metadata fields
                    	**type**\:  :py:class:`Metadata <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Metadata>`
                    
                    .. attribute:: mpls
                    
                    	MPLS fields
                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Mpls>`
                    
                    .. attribute:: network
                    
                    	network metrics
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Network>`
                    
                    .. attribute:: pfr
                    
                    	PfR metrics
                    	**type**\:  :py:class:`Pfr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr>`
                    
                    .. attribute:: policy
                    
                    	policy fields
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Policy>`
                    
                    .. attribute:: routing
                    
                    	Routing attributes
                    	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing>`
                    
                    .. attribute:: services
                    
                    	Services fields
                    	**type**\:  :py:class:`Services <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Services>`
                    
                    .. attribute:: timestamp
                    
                    	Timestamp fields
                    	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Timestamp>`
                    
                    .. attribute:: transport
                    
                    	Transport layer fields
                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Default.Match, self).__init__()

                        self.yang_name = "match"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("application", ("application", Native.Flow.Record.Default.Match.Application)), ("connection", ("connection", Native.Flow.Record.Default.Match.Connection)), ("datalink", ("datalink", Native.Flow.Record.Default.Match.Datalink)), ("flow", ("flow", Native.Flow.Record.Default.Match.Flow_)), ("interface", ("interface", Native.Flow.Record.Default.Match.Interface)), ("ipv4", ("ipv4", Native.Flow.Record.Default.Match.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Default.Match.Ipv6)), ("metadata", ("metadata", Native.Flow.Record.Default.Match.Metadata)), ("mpls", ("mpls", Native.Flow.Record.Default.Match.Mpls)), ("network", ("network", Native.Flow.Record.Default.Match.Network)), ("pfr", ("pfr", Native.Flow.Record.Default.Match.Pfr)), ("policy", ("policy", Native.Flow.Record.Default.Match.Policy)), ("routing", ("routing", Native.Flow.Record.Default.Match.Routing)), ("services", ("services", Native.Flow.Record.Default.Match.Services)), ("timestamp", ("timestamp", Native.Flow.Record.Default.Match.Timestamp)), ("transport", ("transport", Native.Flow.Record.Default.Match.Transport))])
                        self._leafs = OrderedDict()

                        self.application = Native.Flow.Record.Default.Match.Application()
                        self.application.parent = self
                        self._children_name_map["application"] = "application"

                        self.connection = Native.Flow.Record.Default.Match.Connection()
                        self.connection.parent = self
                        self._children_name_map["connection"] = "connection"

                        self.datalink = Native.Flow.Record.Default.Match.Datalink()
                        self.datalink.parent = self
                        self._children_name_map["datalink"] = "datalink"

                        self.flow = Native.Flow.Record.Default.Match.Flow_()
                        self.flow.parent = self
                        self._children_name_map["flow"] = "flow"

                        self.interface = Native.Flow.Record.Default.Match.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"

                        self.ipv4 = Native.Flow.Record.Default.Match.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Flow.Record.Default.Match.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.metadata = Native.Flow.Record.Default.Match.Metadata()
                        self.metadata.parent = self
                        self._children_name_map["metadata"] = "metadata"

                        self.mpls = Native.Flow.Record.Default.Match.Mpls()
                        self.mpls.parent = self
                        self._children_name_map["mpls"] = "mpls"

                        self.network = Native.Flow.Record.Default.Match.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.pfr = Native.Flow.Record.Default.Match.Pfr()
                        self.pfr.parent = self
                        self._children_name_map["pfr"] = "pfr"

                        self.policy = Native.Flow.Record.Default.Match.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.routing = Native.Flow.Record.Default.Match.Routing()
                        self.routing.parent = self
                        self._children_name_map["routing"] = "routing"

                        self.services = Native.Flow.Record.Default.Match.Services()
                        self.services.parent = self
                        self._children_name_map["services"] = "services"

                        self.timestamp = Native.Flow.Record.Default.Match.Timestamp()
                        self.timestamp.parent = self
                        self._children_name_map["timestamp"] = "timestamp"

                        self.transport = Native.Flow.Record.Default.Match.Transport()
                        self.transport.parent = self
                        self._children_name_map["transport"] = "transport"
                        self._segment_path = lambda: "match"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Default.Match, [], name, value)


                    class Application(Entity):
                        """
                        Application fields
                        
                        .. attribute:: name
                        
                        	Application name
                        	**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Application.Name>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: vendor
                        
                        	Application vendor id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: version
                        
                        	Application version id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Application, self).__init__()

                            self.yang_name = "application"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("name", ("name", Native.Flow.Record.Default.Match.Application.Name))])
                            self._leafs = OrderedDict([
                                ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                            ])
                            self.vendor = None
                            self.version = None

                            self.name = None
                            self._children_name_map["name"] = "name"
                            self._segment_path = lambda: "application"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Application, ['vendor', 'version'], name, value)


                        class Name(Entity):
                            """
                            Application name
                            
                            .. attribute:: account_on_resolution
                            
                            	Account on resolution
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Application.Name, self).__init__()

                                self.yang_name = "name"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('account_on_resolution', (YLeaf(YType.empty, 'account-on-resolution'), ['Empty'])),
                                ])
                                self.account_on_resolution = None
                                self._segment_path = lambda: "name"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Application.Name, ['account_on_resolution'], name, value)


                    class Connection(Entity):
                        """
                        Connection fields
                        
                        .. attribute:: client
                        
                        	Client side (flow initiator) related metrics
                        	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Connection.Client>`
                        
                        .. attribute:: id
                        
                        	An identifier for a connection between client and server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: initiator
                        
                        	The direction of the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: server
                        
                        	Server side (flow responder) related metrics
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Connection.Server>`
                        
                        .. attribute:: transaction_id
                        
                        	An identifier for a transaction between client and server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Connection, self).__init__()

                            self.yang_name = "connection"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client", ("client", Native.Flow.Record.Default.Match.Connection.Client)), ("server", ("server", Native.Flow.Record.Default.Match.Connection.Server))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                                ('initiator', (YLeaf(YType.empty, 'initiator'), ['Empty'])),
                                ('transaction_id', (YLeaf(YType.empty, 'transaction-id'), ['Empty'])),
                            ])
                            self.id = None
                            self.initiator = None
                            self.transaction_id = None

                            self.client = Native.Flow.Record.Default.Match.Connection.Client()
                            self.client.parent = self
                            self._children_name_map["client"] = "client"

                            self.server = Native.Flow.Record.Default.Match.Connection.Server()
                            self.server.parent = self
                            self._children_name_map["server"] = "server"
                            self._segment_path = lambda: "connection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Connection, ['id', 'initiator', 'transaction_id'], name, value)


                        class Client(Entity):
                            """
                            Client side (flow initiator) related metrics
                            
                            .. attribute:: ipv4
                            
                            	Client side IPv4 metrics
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Connection.Client.Ipv4>`
                            
                            .. attribute:: ipv6
                            
                            	Client side IPv6 metrics
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Connection.Client.Ipv6>`
                            
                            .. attribute:: transport
                            
                            	Client side transport metrics
                            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Connection.Client.Transport>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Connection.Client, self).__init__()

                                self.yang_name = "client"
                                self.yang_parent_name = "connection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Default.Match.Connection.Client.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Default.Match.Connection.Client.Ipv6)), ("transport", ("transport", Native.Flow.Record.Default.Match.Connection.Client.Transport))])
                                self._leafs = OrderedDict()

                                self.ipv4 = Native.Flow.Record.Default.Match.Connection.Client.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = Native.Flow.Record.Default.Match.Connection.Client.Ipv6()
                                self.ipv6.parent = self
                                self._children_name_map["ipv6"] = "ipv6"

                                self.transport = Native.Flow.Record.Default.Match.Connection.Client.Transport()
                                self.transport.parent = self
                                self._children_name_map["transport"] = "transport"
                                self._segment_path = lambda: "client"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Connection.Client, [], name, value)


                            class Ipv4(Entity):
                                """
                                Client side IPv4 metrics
                                
                                .. attribute:: address
                                
                                	IPv4 address of the flow initiator
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Connection.Client.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Connection.Client.Ipv4, ['address'], name, value)


                            class Ipv6(Entity):
                                """
                                Client side IPv6 metrics
                                
                                .. attribute:: address
                                
                                	IPv6 address of the flow initiator
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Connection.Client.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Connection.Client.Ipv6, ['address'], name, value)


                            class Transport(Entity):
                                """
                                Client side transport metrics
                                
                                .. attribute:: port
                                
                                	Transport port of the flow initiator
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Connection.Client.Transport, self).__init__()

                                    self.yang_name = "transport"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.empty, 'port'), ['Empty'])),
                                    ])
                                    self.port = None
                                    self._segment_path = lambda: "transport"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Connection.Client.Transport, ['port'], name, value)


                        class Server(Entity):
                            """
                            Server side (flow responder) related metrics
                            
                            .. attribute:: ipv4
                            
                            	Server side IPv4 metrics
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Connection.Server.Ipv4>`
                            
                            .. attribute:: ipv6
                            
                            	Server side IPv6 metrics
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Connection.Server.Ipv6>`
                            
                            .. attribute:: transport
                            
                            	Server side transport metrics
                            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Connection.Server.Transport>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Connection.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "connection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Default.Match.Connection.Server.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Default.Match.Connection.Server.Ipv6)), ("transport", ("transport", Native.Flow.Record.Default.Match.Connection.Server.Transport))])
                                self._leafs = OrderedDict()

                                self.ipv4 = Native.Flow.Record.Default.Match.Connection.Server.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = Native.Flow.Record.Default.Match.Connection.Server.Ipv6()
                                self.ipv6.parent = self
                                self._children_name_map["ipv6"] = "ipv6"

                                self.transport = Native.Flow.Record.Default.Match.Connection.Server.Transport()
                                self.transport.parent = self
                                self._children_name_map["transport"] = "transport"
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Connection.Server, [], name, value)


                            class Ipv4(Entity):
                                """
                                Server side IPv4 metrics
                                
                                .. attribute:: address
                                
                                	IPv4 address of the flow responder
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Connection.Server.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Connection.Server.Ipv4, ['address'], name, value)


                            class Ipv6(Entity):
                                """
                                Server side IPv6 metrics
                                
                                .. attribute:: address
                                
                                	IPv6 address of the flow responder
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Connection.Server.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Connection.Server.Ipv6, ['address'], name, value)


                            class Transport(Entity):
                                """
                                Server side transport metrics
                                
                                .. attribute:: port
                                
                                	Transport port of the flow responder
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Connection.Server.Transport, self).__init__()

                                    self.yang_name = "transport"
                                    self.yang_parent_name = "server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.empty, 'port'), ['Empty'])),
                                    ])
                                    self.port = None
                                    self._segment_path = lambda: "transport"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Connection.Server.Transport, ['port'], name, value)


                    class Datalink(Entity):
                        """
                        Datalink (layer2) fields
                        
                        .. attribute:: destination_vlan_id
                        
                        	ID of the VLAN that the packet is going to
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1q
                        
                        	dot1q field
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Datalink.Dot1q>`
                        
                        .. attribute:: ethertype
                        
                        	The Ethertype of the packet
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	The VLAN the packet is on
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Datalink.Vlan>`
                        
                        .. attribute:: mac
                        
                        	MAC fields
                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Datalink.Mac>`
                        
                        .. attribute:: source_vlan_id
                        
                        	ID of the VLAN that the packet came from
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Datalink, self).__init__()

                            self.yang_name = "datalink"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1q", ("dot1q", Native.Flow.Record.Default.Match.Datalink.Dot1q)), ("mac", ("mac", Native.Flow.Record.Default.Match.Datalink.Mac))])
                            self._leafs = OrderedDict([
                                ('destination_vlan_id', (YLeaf(YType.empty, 'destination-vlan-id'), ['Empty'])),
                                ('ethertype', (YLeaf(YType.empty, 'ethertype'), ['Empty'])),
                                ('vlan', (YLeaf(YType.enumeration, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Flow.Record.Default.Match.Datalink.Vlan')])),
                                ('source_vlan_id', (YLeaf(YType.empty, 'source-vlan-id'), ['Empty'])),
                            ])
                            self.destination_vlan_id = None
                            self.ethertype = None
                            self.vlan = None
                            self.source_vlan_id = None

                            self.dot1q = Native.Flow.Record.Default.Match.Datalink.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.mac = Native.Flow.Record.Default.Match.Datalink.Mac()
                            self.mac.parent = self
                            self._children_name_map["mac"] = "mac"
                            self._segment_path = lambda: "datalink"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Datalink, ['destination_vlan_id', 'ethertype', 'vlan', 'source_vlan_id'], name, value)

                        class Vlan(Enum):
                            """
                            Vlan (Enum Class)

                            The VLAN the packet is on

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                        class Dot1q(Entity):
                            """
                            dot1q field
                            
                            .. attribute:: priority
                            
                            	The CoS field out of the dot1q header
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	The VLAN the packet is on
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Datalink.Dot1q.Vlan>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Datalink.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "datalink"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Flow.Record.Default.Match.Datalink.Dot1q.Vlan))])
                                self._leafs = OrderedDict([
                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                ])
                                self.priority = None

                                self.vlan = Native.Flow.Record.Default.Match.Datalink.Dot1q.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Datalink.Dot1q, ['priority'], name, value)


                            class Vlan(Entity):
                                """
                                The VLAN the packet is on
                                
                                .. attribute:: input
                                
                                	The VLAN the packet is on at input
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: output
                                
                                	The VLAN the packet is on at output
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Datalink.Dot1q.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                        ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                    ])
                                    self.input = None
                                    self.output = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Datalink.Dot1q.Vlan, ['input', 'output'], name, value)


                        class Mac(Entity):
                            """
                            MAC fields
                            
                            .. attribute:: destination
                            
                            	destination MAC fields
                            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Datalink.Mac.Destination>`
                            
                            .. attribute:: source
                            
                            	source MAC fields
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Datalink.Mac.Source>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Datalink.Mac, self).__init__()

                                self.yang_name = "mac"
                                self.yang_parent_name = "datalink"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Match.Datalink.Mac.Destination)), ("source", ("source", Native.Flow.Record.Default.Match.Datalink.Mac.Source))])
                                self._leafs = OrderedDict()

                                self.destination = Native.Flow.Record.Default.Match.Datalink.Mac.Destination()
                                self.destination.parent = self
                                self._children_name_map["destination"] = "destination"

                                self.source = Native.Flow.Record.Default.Match.Datalink.Mac.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "mac"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Datalink.Mac, [], name, value)


                            class Destination(Entity):
                                """
                                destination MAC fields
                                
                                .. attribute:: address
                                
                                	Destination MAC address from packet
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Datalink.Mac.Destination.Address>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Datalink.Mac.Destination, self).__init__()

                                    self.yang_name = "destination"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Default.Match.Datalink.Mac.Destination.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = Native.Flow.Record.Default.Match.Datalink.Mac.Destination.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "destination"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Datalink.Mac.Destination, [], name, value)


                                class Address(Entity):
                                    """
                                    Destination MAC address from packet
                                    
                                    .. attribute:: input
                                    
                                    	Destination MAC address from packet at input
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: output
                                    
                                    	Destination MAC address from packet at output
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Datalink.Mac.Destination.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "destination"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                            ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                        ])
                                        self.input = None
                                        self.output = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Datalink.Mac.Destination.Address, ['input', 'output'], name, value)


                            class Source(Entity):
                                """
                                source MAC fields
                                
                                .. attribute:: address
                                
                                	Source MAC address from packet
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Datalink.Mac.Source.Address>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Datalink.Mac.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Default.Match.Datalink.Mac.Source.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = Native.Flow.Record.Default.Match.Datalink.Mac.Source.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Datalink.Mac.Source, [], name, value)


                                class Address(Entity):
                                    """
                                    Source MAC address from packet
                                    
                                    .. attribute:: input
                                    
                                    	Source MAC address from packet at input
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: output
                                    
                                    	Source MAC address from packet at output
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Datalink.Mac.Source.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                            ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                        ])
                                        self.input = None
                                        self.output = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Datalink.Mac.Source.Address, ['input', 'output'], name, value)


                    class Flow_(Entity):
                        """
                        Flow identifying fields
                        
                        .. attribute:: cts
                        
                        	Cisco Trusted Security fields
                        	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Flow_.Cts>`
                        
                        .. attribute:: direction
                        
                        	Direction the flow was monitored in
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: observation
                        
                        	Flow observation metrics
                        	**type**\:  :py:class:`Observation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Flow_.Observation>`
                        
                        .. attribute:: sampler
                        
                        	ID of the sampler
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Flow_, self).__init__()

                            self.yang_name = "flow"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cts", ("cts", Native.Flow.Record.Default.Match.Flow_.Cts)), ("observation", ("observation", Native.Flow.Record.Default.Match.Flow_.Observation))])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.empty, 'direction'), ['Empty'])),
                                ('sampler', (YLeaf(YType.empty, 'sampler'), ['Empty'])),
                            ])
                            self.direction = None
                            self.sampler = None

                            self.cts = Native.Flow.Record.Default.Match.Flow_.Cts()
                            self.cts.parent = self
                            self._children_name_map["cts"] = "cts"

                            self.observation = Native.Flow.Record.Default.Match.Flow_.Observation()
                            self.observation.parent = self
                            self._children_name_map["observation"] = "observation"
                            self._segment_path = lambda: "flow"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Flow_, ['direction', 'sampler'], name, value)


                        class Cts(Entity):
                            """
                            Cisco Trusted Security fields
                            
                            .. attribute:: destination
                            
                            	Cisco Trusted Security destination fields
                            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Flow_.Cts.Destination>`
                            
                            .. attribute:: source
                            
                            	Cisco Trusted Security source fields
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Flow_.Cts.Source>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Flow_.Cts, self).__init__()

                                self.yang_name = "cts"
                                self.yang_parent_name = "flow"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Match.Flow_.Cts.Destination)), ("source", ("source", Native.Flow.Record.Default.Match.Flow_.Cts.Source))])
                                self._leafs = OrderedDict()

                                self.destination = Native.Flow.Record.Default.Match.Flow_.Cts.Destination()
                                self.destination.parent = self
                                self._children_name_map["destination"] = "destination"

                                self.source = Native.Flow.Record.Default.Match.Flow_.Cts.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "cts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Flow_.Cts, [], name, value)


                            class Destination(Entity):
                                """
                                Cisco Trusted Security destination fields
                                
                                .. attribute:: group_tag
                                
                                	destination group\-tag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Flow_.Cts.Destination, self).__init__()

                                    self.yang_name = "destination"
                                    self.yang_parent_name = "cts"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('group_tag', (YLeaf(YType.empty, 'group-tag'), ['Empty'])),
                                    ])
                                    self.group_tag = None
                                    self._segment_path = lambda: "destination"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Flow_.Cts.Destination, ['group_tag'], name, value)


                            class Source(Entity):
                                """
                                Cisco Trusted Security source fields
                                
                                .. attribute:: group_tag
                                
                                	source group\-tag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Flow_.Cts.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "cts"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('group_tag', (YLeaf(YType.empty, 'group-tag'), ['Empty'])),
                                    ])
                                    self.group_tag = None
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Flow_.Cts.Source, ['group_tag'], name, value)


                        class Observation(Entity):
                            """
                            Flow observation metrics
                            
                            .. attribute:: point
                            
                            	Observation point ID
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Flow_.Observation, self).__init__()

                                self.yang_name = "observation"
                                self.yang_parent_name = "flow"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('point', (YLeaf(YType.empty, 'point'), ['Empty'])),
                                ])
                                self.point = None
                                self._segment_path = lambda: "observation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Flow_.Observation, ['point'], name, value)


                    class Interface(Entity):
                        """
                        Interface fields
                        
                        .. attribute:: input
                        
                        	The input interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Interface.Input>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: output
                        
                        	The output interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Interface.Output>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Flow.Record.Default.Match.Interface.Input)), ("output", ("output", Native.Flow.Record.Default.Match.Interface.Output))])
                            self._leafs = OrderedDict()

                            self.input = None
                            self._children_name_map["input"] = "input"

                            self.output = None
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Interface, [], name, value)


                        class Input(Entity):
                            """
                            The input interface
                            
                            .. attribute:: snmp
                            
                            	SNMP Index of the input interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Interface.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('snmp', (YLeaf(YType.empty, 'snmp'), ['Empty'])),
                                ])
                                self.snmp = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Interface.Input, ['snmp'], name, value)


                        class Output(Entity):
                            """
                            The output interface
                            
                            .. attribute:: snmp
                            
                            	SNMP Index of the output interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Interface.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('snmp', (YLeaf(YType.empty, 'snmp'), ['Empty'])),
                                ])
                                self.snmp = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Interface.Output, ['snmp'], name, value)


                    class Ipv4(Entity):
                        """
                        IPv4 fields
                        
                        .. attribute:: destination
                        
                        	IPv4 destination address based fields
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Destination>`
                        
                        .. attribute:: dscp
                        
                        	IPv4 DSCP (part of TOS)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fragmentation
                        
                        	IPv4 fragmentation fields
                        	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Fragmentation>`
                        
                        .. attribute:: header_length
                        
                        	IPv4 header length (IHL in 32 bit words)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: id
                        
                        	IPv4 ID
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: length
                        
                        	IPv4 length fields
                        	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Length>`
                        
                        .. attribute:: option
                        
                        	IPv4 option fields
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Option>`
                        
                        .. attribute:: precedence
                        
                        	IPv4 precedence (part of TOS)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: protocol
                        
                        	IPv4 protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: section
                        
                        	Part of the packet
                        	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Section>`
                        
                        .. attribute:: source
                        
                        	IPv4 source address based fields
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Source>`
                        
                        .. attribute:: tos
                        
                        	IPv4 type of service
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: total_length
                        
                        	IPv4 total length
                        	**type**\:  :py:class:`TotalLength <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.TotalLength>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ttl
                        
                        	IPv4 TTL
                        	**type**\:  :py:class:`Ttl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Ttl>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: version
                        
                        	IP version from IPv4 header
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Match.Ipv4.Destination)), ("fragmentation", ("fragmentation", Native.Flow.Record.Default.Match.Ipv4.Fragmentation)), ("length", ("length", Native.Flow.Record.Default.Match.Ipv4.Length)), ("option", ("option", Native.Flow.Record.Default.Match.Ipv4.Option)), ("section", ("section", Native.Flow.Record.Default.Match.Ipv4.Section)), ("source", ("source", Native.Flow.Record.Default.Match.Ipv4.Source)), ("total-length", ("total_length", Native.Flow.Record.Default.Match.Ipv4.TotalLength)), ("ttl", ("ttl", Native.Flow.Record.Default.Match.Ipv4.Ttl))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                                ('header_length', (YLeaf(YType.empty, 'header-length'), ['Empty'])),
                                ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                                ('precedence', (YLeaf(YType.empty, 'precedence'), ['Empty'])),
                                ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                                ('tos', (YLeaf(YType.empty, 'tos'), ['Empty'])),
                                ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                            ])
                            self.dscp = None
                            self.header_length = None
                            self.id = None
                            self.precedence = None
                            self.protocol = None
                            self.tos = None
                            self.version = None

                            self.destination = Native.Flow.Record.Default.Match.Ipv4.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.fragmentation = Native.Flow.Record.Default.Match.Ipv4.Fragmentation()
                            self.fragmentation.parent = self
                            self._children_name_map["fragmentation"] = "fragmentation"

                            self.length = Native.Flow.Record.Default.Match.Ipv4.Length()
                            self.length.parent = self
                            self._children_name_map["length"] = "length"

                            self.option = Native.Flow.Record.Default.Match.Ipv4.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.section = Native.Flow.Record.Default.Match.Ipv4.Section()
                            self.section.parent = self
                            self._children_name_map["section"] = "section"

                            self.source = Native.Flow.Record.Default.Match.Ipv4.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"

                            self.total_length = None
                            self._children_name_map["total_length"] = "total-length"

                            self.ttl = None
                            self._children_name_map["ttl"] = "ttl"
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4, ['dscp', 'header_length', 'id', 'precedence', 'protocol', 'tos', 'version'], name, value)


                        class Destination(Entity):
                            """
                            IPv4 destination address based fields
                            
                            .. attribute:: address
                            
                            	IPv4 destination address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mask
                            
                            	IPv4 address mask for the IPv4 destination address
                            	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Destination.Mask>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: prefix
                            
                            	IPv4 address prefix for the IPv4 destination address
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Destination.Prefix>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv4.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Match.Ipv4.Destination.Mask)), ("prefix", ("prefix", Native.Flow.Record.Default.Match.Ipv4.Destination.Prefix))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None

                                self.mask = None
                                self._children_name_map["mask"] = "mask"

                                self.prefix = None
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Destination, ['address'], name, value)


                            class Mask(Entity):
                                """
                                IPv4 address mask for the IPv4 destination address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv4.Destination.Mask, self).__init__()

                                    self.yang_name = "mask"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "mask"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Destination.Mask, ['minimum_mask'], name, value)


                            class Prefix(Entity):
                                """
                                IPv4 address prefix for the IPv4 destination address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv4.Destination.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Destination.Prefix, ['minimum_mask'], name, value)


                        class Fragmentation(Entity):
                            """
                            IPv4 fragmentation fields
                            
                            .. attribute:: flags
                            
                            	IPv4 fragmentation flags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: offset
                            
                            	IPv4 fragmentation offset
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv4.Fragmentation, self).__init__()

                                self.yang_name = "fragmentation"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('flags', (YLeaf(YType.empty, 'flags'), ['Empty'])),
                                    ('offset', (YLeaf(YType.empty, 'offset'), ['Empty'])),
                                ])
                                self.flags = None
                                self.offset = None
                                self._segment_path = lambda: "fragmentation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Fragmentation, ['flags', 'offset'], name, value)


                        class Length(Entity):
                            """
                            IPv4 length fields
                            
                            .. attribute:: header
                            
                            	Length of the IPv4 header in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: payload
                            
                            	Length of the IPv4 payload in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: total
                            
                            	Total length of the IPv4 header and payload in bytes
                            	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Length.Total>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv4.Length, self).__init__()

                                self.yang_name = "length"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("total", ("total", Native.Flow.Record.Default.Match.Ipv4.Length.Total))])
                                self._leafs = OrderedDict([
                                    ('header', (YLeaf(YType.empty, 'header'), ['Empty'])),
                                    ('payload', (YLeaf(YType.empty, 'payload'), ['Empty'])),
                                ])
                                self.header = None
                                self.payload = None

                                self.total = None
                                self._children_name_map["total"] = "total"
                                self._segment_path = lambda: "length"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Length, ['header', 'payload'], name, value)


                            class Total(Entity):
                                """
                                Total length of the IPv4 header and payload in bytes
                                
                                .. attribute:: maximum
                                
                                	Maximum total length in bytes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minimum
                                
                                	Minimum total length in bytes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv4.Length.Total, self).__init__()

                                    self.yang_name = "total"
                                    self.yang_parent_name = "length"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                        ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                    ])
                                    self.maximum = None
                                    self.minimum = None
                                    self._segment_path = lambda: "total"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Length.Total, ['maximum', 'minimum'], name, value)


                        class Option(Entity):
                            """
                            IPv4 option fields
                            
                            .. attribute:: map
                            
                            	Bitmap of IPv4 options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv4.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('map', (YLeaf(YType.empty, 'map'), ['Empty'])),
                                ])
                                self.map = None
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Option, ['map'], name, value)


                        class Section(Entity):
                            """
                            Part of the packet
                            
                            .. attribute:: header
                            
                            	Raw data starting at the IPv4 header
                            	**type**\:  :py:class:`Header <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Section.Header>`
                            
                            .. attribute:: payload
                            
                            	Raw data starting at the IPv4 payload
                            	**type**\:  :py:class:`Payload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Section.Payload>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv4.Section, self).__init__()

                                self.yang_name = "section"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("header", ("header", Native.Flow.Record.Default.Match.Ipv4.Section.Header)), ("payload", ("payload", Native.Flow.Record.Default.Match.Ipv4.Section.Payload))])
                                self._leafs = OrderedDict()

                                self.header = Native.Flow.Record.Default.Match.Ipv4.Section.Header()
                                self.header.parent = self
                                self._children_name_map["header"] = "header"

                                self.payload = Native.Flow.Record.Default.Match.Ipv4.Section.Payload()
                                self.payload.parent = self
                                self._children_name_map["payload"] = "payload"
                                self._segment_path = lambda: "section"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Section, [], name, value)


                            class Header(Entity):
                                """
                                Raw data starting at the IPv4 header
                                
                                .. attribute:: size
                                
                                	Specify the number of bytes to capture
                                	**type**\: int
                                
                                	**range:** 1..1200
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv4.Section.Header, self).__init__()

                                    self.yang_name = "header"
                                    self.yang_parent_name = "section"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                    ])
                                    self.size = None
                                    self._segment_path = lambda: "header"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Section.Header, ['size'], name, value)


                            class Payload(Entity):
                                """
                                Raw data starting at the IPv4 payload
                                
                                .. attribute:: size
                                
                                	Specify the number of bytes to capture
                                	**type**\: int
                                
                                	**range:** 1..1200
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv4.Section.Payload, self).__init__()

                                    self.yang_name = "payload"
                                    self.yang_parent_name = "section"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                    ])
                                    self.size = None
                                    self._segment_path = lambda: "payload"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Section.Payload, ['size'], name, value)


                        class Source(Entity):
                            """
                            IPv4 source address based fields
                            
                            .. attribute:: address
                            
                            	IPv4 source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mask
                            
                            	IPv4 address mask for the IPv4 source address
                            	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Source.Mask>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: prefix
                            
                            	IPv4 address prefix for the IPv4 source address
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv4.Source.Prefix>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv4.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Match.Ipv4.Source.Mask)), ("prefix", ("prefix", Native.Flow.Record.Default.Match.Ipv4.Source.Prefix))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None

                                self.mask = None
                                self._children_name_map["mask"] = "mask"

                                self.prefix = None
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Source, ['address'], name, value)


                            class Mask(Entity):
                                """
                                IPv4 address mask for the IPv4 source address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv4.Source.Mask, self).__init__()

                                    self.yang_name = "mask"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "mask"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Source.Mask, ['minimum_mask'], name, value)


                            class Prefix(Entity):
                                """
                                IPv4 address prefix for the IPv4 source address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv4.Source.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Source.Prefix, ['minimum_mask'], name, value)


                        class TotalLength(Entity):
                            """
                            IPv4 total length
                            
                            .. attribute:: maximum
                            
                            	Largest value for IPv4 length seen in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	Smallest value for IPv4 length seen in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv4.TotalLength, self).__init__()

                                self.yang_name = "total-length"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self._segment_path = lambda: "total-length"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.TotalLength, ['maximum', 'minimum'], name, value)


                        class Ttl(Entity):
                            """
                            IPv4 TTL
                            
                            .. attribute:: maximum
                            
                            	Largest value seen for TTL in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	Smallest value seen for TTL in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv4.Ttl, self).__init__()

                                self.yang_name = "ttl"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self._segment_path = lambda: "ttl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv4.Ttl, ['maximum', 'minimum'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 fields
                        
                        .. attribute:: destination
                        
                        	IPv6 destination address based fields
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Destination>`
                        
                        .. attribute:: dscp
                        
                        	IPv6 DSCP (part of Traffic Class)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: extension
                        
                        	IPv6 extension header fields
                        	**type**\:  :py:class:`Extension <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Extension>`
                        
                        .. attribute:: flow_label
                        
                        	IPv6 flow label
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fragmentation
                        
                        	IPv6 fragmentation fields
                        	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Fragmentation>`
                        
                        .. attribute:: hop_limit
                        
                        	IPv6 hop limit
                        	**type**\:  :py:class:`HopLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.HopLimit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: length
                        
                        	IPv6 length fields
                        	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Length>`
                        
                        .. attribute:: next_header
                        
                        	The value of the next\-header field in the IPv6 header
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: payload_length
                        
                        	Length of the IPv6 payload in bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: precedence
                        
                        	IPv6 precedence (part of Traffic Class)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: protocol
                        
                        	IPv6 payload protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: section
                        
                        	Part of the packet
                        	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Section>`
                        
                        .. attribute:: source
                        
                        	IPv6 source address based fields
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Source>`
                        
                        .. attribute:: traffic_class
                        
                        	IPv6 traffic class
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: version
                        
                        	IP version from IPv6 header
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Match.Ipv6.Destination)), ("extension", ("extension", Native.Flow.Record.Default.Match.Ipv6.Extension)), ("fragmentation", ("fragmentation", Native.Flow.Record.Default.Match.Ipv6.Fragmentation)), ("hop-limit", ("hop_limit", Native.Flow.Record.Default.Match.Ipv6.HopLimit)), ("length", ("length", Native.Flow.Record.Default.Match.Ipv6.Length)), ("section", ("section", Native.Flow.Record.Default.Match.Ipv6.Section)), ("source", ("source", Native.Flow.Record.Default.Match.Ipv6.Source))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                                ('flow_label', (YLeaf(YType.empty, 'flow-label'), ['Empty'])),
                                ('next_header', (YLeaf(YType.empty, 'next-header'), ['Empty'])),
                                ('payload_length', (YLeaf(YType.empty, 'payload-length'), ['Empty'])),
                                ('precedence', (YLeaf(YType.empty, 'precedence'), ['Empty'])),
                                ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                                ('traffic_class', (YLeaf(YType.empty, 'traffic-class'), ['Empty'])),
                                ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                            ])
                            self.dscp = None
                            self.flow_label = None
                            self.next_header = None
                            self.payload_length = None
                            self.precedence = None
                            self.protocol = None
                            self.traffic_class = None
                            self.version = None

                            self.destination = Native.Flow.Record.Default.Match.Ipv6.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.extension = Native.Flow.Record.Default.Match.Ipv6.Extension()
                            self.extension.parent = self
                            self._children_name_map["extension"] = "extension"

                            self.fragmentation = Native.Flow.Record.Default.Match.Ipv6.Fragmentation()
                            self.fragmentation.parent = self
                            self._children_name_map["fragmentation"] = "fragmentation"

                            self.hop_limit = None
                            self._children_name_map["hop_limit"] = "hop-limit"

                            self.length = Native.Flow.Record.Default.Match.Ipv6.Length()
                            self.length.parent = self
                            self._children_name_map["length"] = "length"

                            self.section = Native.Flow.Record.Default.Match.Ipv6.Section()
                            self.section.parent = self
                            self._children_name_map["section"] = "section"

                            self.source = Native.Flow.Record.Default.Match.Ipv6.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6, ['dscp', 'flow_label', 'next_header', 'payload_length', 'precedence', 'protocol', 'traffic_class', 'version'], name, value)


                        class Destination(Entity):
                            """
                            IPv6 destination address based fields
                            
                            .. attribute:: address
                            
                            	IPv6 destination address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mask
                            
                            	IPv6 address mask for the IPv6 destination address
                            	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Destination.Mask>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: prefix
                            
                            	IPv6 address prefix for the IPv6 destination address
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Destination.Prefix>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv6.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Match.Ipv6.Destination.Mask)), ("prefix", ("prefix", Native.Flow.Record.Default.Match.Ipv6.Destination.Prefix))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None

                                self.mask = None
                                self._children_name_map["mask"] = "mask"

                                self.prefix = None
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Destination, ['address'], name, value)


                            class Mask(Entity):
                                """
                                IPv6 address mask for the IPv6 destination address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..128
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv6.Destination.Mask, self).__init__()

                                    self.yang_name = "mask"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "mask"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Destination.Mask, ['minimum_mask'], name, value)


                            class Prefix(Entity):
                                """
                                IPv6 address prefix for the IPv6 destination address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..128
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv6.Destination.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Destination.Prefix, ['minimum_mask'], name, value)


                        class Extension(Entity):
                            """
                            IPv6 extension header fields
                            
                            .. attribute:: map
                            
                            	Bitmap of IPv6 extension headers
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv6.Extension, self).__init__()

                                self.yang_name = "extension"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('map', (YLeaf(YType.empty, 'map'), ['Empty'])),
                                ])
                                self.map = None
                                self._segment_path = lambda: "extension"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Extension, ['map'], name, value)


                        class Fragmentation(Entity):
                            """
                            IPv6 fragmentation fields
                            
                            .. attribute:: flags
                            
                            	IPv6 fragmentation flags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: id
                            
                            	IPv6 fragmentation ID
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: offset
                            
                            	IPv6 fragmentation offset
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv6.Fragmentation, self).__init__()

                                self.yang_name = "fragmentation"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('flags', (YLeaf(YType.empty, 'flags'), ['Empty'])),
                                    ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                                    ('offset', (YLeaf(YType.empty, 'offset'), ['Empty'])),
                                ])
                                self.flags = None
                                self.id = None
                                self.offset = None
                                self._segment_path = lambda: "fragmentation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Fragmentation, ['flags', 'id', 'offset'], name, value)


                        class HopLimit(Entity):
                            """
                            IPv6 hop limit
                            
                            .. attribute:: maximum
                            
                            	Largest value seen for hop\-limit in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	Smallest value seen for hop\-limit in the flow
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv6.HopLimit, self).__init__()

                                self.yang_name = "hop-limit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self._segment_path = lambda: "hop-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.HopLimit, ['maximum', 'minimum'], name, value)


                        class Length(Entity):
                            """
                            IPv6 length fields
                            
                            .. attribute:: header
                            
                            	Length of the IPv6 header, not including any extension headers, in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: payload
                            
                            	Length of the IPv6 payload, including any extension headers, in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: total
                            
                            	Total length of the IPv6 header and payload in bytes
                            	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Length.Total>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv6.Length, self).__init__()

                                self.yang_name = "length"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("total", ("total", Native.Flow.Record.Default.Match.Ipv6.Length.Total))])
                                self._leafs = OrderedDict([
                                    ('header', (YLeaf(YType.empty, 'header'), ['Empty'])),
                                    ('payload', (YLeaf(YType.empty, 'payload'), ['Empty'])),
                                ])
                                self.header = None
                                self.payload = None

                                self.total = None
                                self._children_name_map["total"] = "total"
                                self._segment_path = lambda: "length"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Length, ['header', 'payload'], name, value)


                            class Total(Entity):
                                """
                                Total length of the IPv6 header and payload in bytes
                                
                                .. attribute:: maximum
                                
                                	Maximum total length in bytes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minimum
                                
                                	Minimum total length in bytes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv6.Length.Total, self).__init__()

                                    self.yang_name = "total"
                                    self.yang_parent_name = "length"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                        ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                    ])
                                    self.maximum = None
                                    self.minimum = None
                                    self._segment_path = lambda: "total"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Length.Total, ['maximum', 'minimum'], name, value)


                        class Section(Entity):
                            """
                            Part of the packet
                            
                            .. attribute:: header
                            
                            	Raw data starting at the IPv6 header
                            	**type**\:  :py:class:`Header <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Section.Header>`
                            
                            .. attribute:: payload
                            
                            	Raw data starting at the IPv6 payload
                            	**type**\:  :py:class:`Payload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Section.Payload>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv6.Section, self).__init__()

                                self.yang_name = "section"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("header", ("header", Native.Flow.Record.Default.Match.Ipv6.Section.Header)), ("payload", ("payload", Native.Flow.Record.Default.Match.Ipv6.Section.Payload))])
                                self._leafs = OrderedDict()

                                self.header = Native.Flow.Record.Default.Match.Ipv6.Section.Header()
                                self.header.parent = self
                                self._children_name_map["header"] = "header"

                                self.payload = Native.Flow.Record.Default.Match.Ipv6.Section.Payload()
                                self.payload.parent = self
                                self._children_name_map["payload"] = "payload"
                                self._segment_path = lambda: "section"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Section, [], name, value)


                            class Header(Entity):
                                """
                                Raw data starting at the IPv6 header
                                
                                .. attribute:: size
                                
                                	Specify the number of bytes to capture
                                	**type**\: int
                                
                                	**range:** 1..1200
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv6.Section.Header, self).__init__()

                                    self.yang_name = "header"
                                    self.yang_parent_name = "section"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                    ])
                                    self.size = None
                                    self._segment_path = lambda: "header"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Section.Header, ['size'], name, value)


                            class Payload(Entity):
                                """
                                Raw data starting at the IPv6 payload
                                
                                .. attribute:: size
                                
                                	Specify the number of bytes to capture
                                	**type**\: int
                                
                                	**range:** 1..1200
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv6.Section.Payload, self).__init__()

                                    self.yang_name = "payload"
                                    self.yang_parent_name = "section"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                    ])
                                    self.size = None
                                    self._segment_path = lambda: "payload"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Section.Payload, ['size'], name, value)


                        class Source(Entity):
                            """
                            IPv6 source address based fields
                            
                            .. attribute:: address
                            
                            	IPv6 source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mask
                            
                            	IPv6 address mask for the IPv6 source address
                            	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Source.Mask>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: prefix
                            
                            	IPv6 address prefix for the IPv6 source address
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Ipv6.Source.Prefix>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Ipv6.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Match.Ipv6.Source.Mask)), ("prefix", ("prefix", Native.Flow.Record.Default.Match.Ipv6.Source.Prefix))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None

                                self.mask = None
                                self._children_name_map["mask"] = "mask"

                                self.prefix = None
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Source, ['address'], name, value)


                            class Mask(Entity):
                                """
                                IPv6 address mask for the IPv6 source address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..128
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv6.Source.Mask, self).__init__()

                                    self.yang_name = "mask"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "mask"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Source.Mask, ['minimum_mask'], name, value)


                            class Prefix(Entity):
                                """
                                IPv6 address prefix for the IPv6 source address
                                
                                .. attribute:: minimum_mask
                                
                                	Provide a minimum mask for this field
                                	**type**\: int
                                
                                	**range:** 1..128
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Ipv6.Source.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                    ])
                                    self.minimum_mask = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Ipv6.Source.Prefix, ['minimum_mask'], name, value)


                    class Metadata(Entity):
                        """
                        Metadata fields
                        
                        .. attribute:: global_session_id
                        
                        	Metadata global\-session\-id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multi_party_session_id
                        
                        	Metadata multi\-party\-session\-id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Metadata, self).__init__()

                            self.yang_name = "metadata"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('global_session_id', (YLeaf(YType.empty, 'global-session-id'), ['Empty'])),
                                ('multi_party_session_id', (YLeaf(YType.empty, 'multi-party-session-id'), ['Empty'])),
                            ])
                            self.global_session_id = None
                            self.multi_party_session_id = None
                            self._segment_path = lambda: "metadata"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Metadata, ['global_session_id', 'multi_party_session_id'], name, value)


                    class Mpls(Entity):
                        """
                        MPLS fields
                        
                        .. attribute:: label
                        
                        	MPLS label details
                        	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Mpls.Label>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Mpls, self).__init__()

                            self.yang_name = "mpls"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("label", ("label", Native.Flow.Record.Default.Match.Mpls.Label))])
                            self._leafs = OrderedDict()

                            self.label = Native.Flow.Record.Default.Match.Mpls.Label()
                            self.label.parent = self
                            self._children_name_map["label"] = "label"
                            self._segment_path = lambda: "mpls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Mpls, [], name, value)


                        class Label(Entity):
                            """
                            MPLS label details
                            
                            .. attribute:: one
                            
                            	MPLS label 1 information
                            	**type**\:  :py:class:`One <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Mpls.Label.One>`
                            
                            .. attribute:: two
                            
                            	MPLS label 2 information
                            	**type**\:  :py:class:`Two <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Mpls.Label.Two>`
                            
                            .. attribute:: three
                            
                            	MPLS label 3 information
                            	**type**\:  :py:class:`Three <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Mpls.Label.Three>`
                            
                            .. attribute:: four
                            
                            	MPLS label 4 information
                            	**type**\:  :py:class:`Four <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Mpls.Label.Four>`
                            
                            .. attribute:: five
                            
                            	MPLS label 5 information
                            	**type**\:  :py:class:`Five <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Mpls.Label.Five>`
                            
                            .. attribute:: six
                            
                            	MPLS label 6 information
                            	**type**\:  :py:class:`Six <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Mpls.Label.Six>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Mpls.Label, self).__init__()

                                self.yang_name = "label"
                                self.yang_parent_name = "mpls"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("one", ("one", Native.Flow.Record.Default.Match.Mpls.Label.One)), ("two", ("two", Native.Flow.Record.Default.Match.Mpls.Label.Two)), ("three", ("three", Native.Flow.Record.Default.Match.Mpls.Label.Three)), ("four", ("four", Native.Flow.Record.Default.Match.Mpls.Label.Four)), ("five", ("five", Native.Flow.Record.Default.Match.Mpls.Label.Five)), ("six", ("six", Native.Flow.Record.Default.Match.Mpls.Label.Six))])
                                self._leafs = OrderedDict()

                                self.one = Native.Flow.Record.Default.Match.Mpls.Label.One()
                                self.one.parent = self
                                self._children_name_map["one"] = "one"

                                self.two = Native.Flow.Record.Default.Match.Mpls.Label.Two()
                                self.two.parent = self
                                self._children_name_map["two"] = "two"

                                self.three = Native.Flow.Record.Default.Match.Mpls.Label.Three()
                                self.three.parent = self
                                self._children_name_map["three"] = "three"

                                self.four = Native.Flow.Record.Default.Match.Mpls.Label.Four()
                                self.four.parent = self
                                self._children_name_map["four"] = "four"

                                self.five = Native.Flow.Record.Default.Match.Mpls.Label.Five()
                                self.five.parent = self
                                self._children_name_map["five"] = "five"

                                self.six = Native.Flow.Record.Default.Match.Mpls.Label.Six()
                                self.six.parent = self
                                self._children_name_map["six"] = "six"
                                self._segment_path = lambda: "label"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Mpls.Label, [], name, value)


                            class One(Entity):
                                """
                                MPLS label 1 information
                                
                                .. attribute:: details
                                
                                	MPLS label 1 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: exp
                                
                                	MPLS EXP field from the last label that was pushed
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ttl
                                
                                	MPLS TTL field from the last label that was pushed
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: type
                                
                                	MPLS label type of the last label that was pushed
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Mpls.Label.One, self).__init__()

                                    self.yang_name = "one"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                        ('exp', (YLeaf(YType.empty, 'exp'), ['Empty'])),
                                        ('ttl', (YLeaf(YType.empty, 'ttl'), ['Empty'])),
                                        ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self.exp = None
                                    self.ttl = None
                                    self.type = None
                                    self._segment_path = lambda: "one"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Mpls.Label.One, ['details', 'exp', 'ttl', 'type'], name, value)


                            class Two(Entity):
                                """
                                MPLS label 2 information
                                
                                .. attribute:: details
                                
                                	MPLS label 2 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Mpls.Label.Two, self).__init__()

                                    self.yang_name = "two"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self._segment_path = lambda: "two"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Mpls.Label.Two, ['details'], name, value)


                            class Three(Entity):
                                """
                                MPLS label 3 information
                                
                                .. attribute:: details
                                
                                	MPLS label 3 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Mpls.Label.Three, self).__init__()

                                    self.yang_name = "three"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self._segment_path = lambda: "three"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Mpls.Label.Three, ['details'], name, value)


                            class Four(Entity):
                                """
                                MPLS label 4 information
                                
                                .. attribute:: details
                                
                                	MPLS label 4 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Mpls.Label.Four, self).__init__()

                                    self.yang_name = "four"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self._segment_path = lambda: "four"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Mpls.Label.Four, ['details'], name, value)


                            class Five(Entity):
                                """
                                MPLS label 5 information
                                
                                .. attribute:: details
                                
                                	MPLS label 5 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Mpls.Label.Five, self).__init__()

                                    self.yang_name = "five"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self._segment_path = lambda: "five"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Mpls.Label.Five, ['details'], name, value)


                            class Six(Entity):
                                """
                                MPLS label 6 information
                                
                                .. attribute:: details
                                
                                	MPLS label 6 details
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Mpls.Label.Six, self).__init__()

                                    self.yang_name = "six"
                                    self.yang_parent_name = "label"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ])
                                    self.details = None
                                    self._segment_path = lambda: "six"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Mpls.Label.Six, ['details'], name, value)


                    class Network(Entity):
                        """
                        network metrics
                        
                        .. attribute:: delay
                        
                        	network delay metrics
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Network.Delay>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Flow.Record.Default.Match.Network.Delay))])
                            self._leafs = OrderedDict()

                            self.delay = Native.Flow.Record.Default.Match.Network.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Network, [], name, value)


                        class Delay(Entity):
                            """
                            network delay metrics
                            
                            .. attribute:: sample
                            
                            	The number of samples of roundtrip delay
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sum
                            
                            	The sum of roundtrip delay
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Network.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sample', (YLeaf(YType.empty, 'sample'), ['Empty'])),
                                    ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                ])
                                self.sample = None
                                self.sum = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Network.Delay, ['sample', 'sum'], name, value)


                    class Pfr(Entity):
                        """
                        PfR metrics
                        
                        .. attribute:: label
                        
                        	PfR label metrics
                        	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.Label>`
                        
                        .. attribute:: one_way_delay
                        
                        	The packet transmission delay between specified nodes
                        	**type**\:  :py:class:`OneWayDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.OneWayDelay>`
                        
                        .. attribute:: service
                        
                        	PfR service metrics
                        	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.Service>`
                        
                        .. attribute:: site
                        
                        	PfR site  metrics
                        	**type**\:  :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.Site>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Pfr, self).__init__()

                            self.yang_name = "pfr"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("label", ("label", Native.Flow.Record.Default.Match.Pfr.Label)), ("one-way-delay", ("one_way_delay", Native.Flow.Record.Default.Match.Pfr.OneWayDelay)), ("service", ("service", Native.Flow.Record.Default.Match.Pfr.Service)), ("site", ("site", Native.Flow.Record.Default.Match.Pfr.Site))])
                            self._leafs = OrderedDict()

                            self.label = Native.Flow.Record.Default.Match.Pfr.Label()
                            self.label.parent = self
                            self._children_name_map["label"] = "label"

                            self.one_way_delay = Native.Flow.Record.Default.Match.Pfr.OneWayDelay()
                            self.one_way_delay.parent = self
                            self._children_name_map["one_way_delay"] = "one-way-delay"

                            self.service = Native.Flow.Record.Default.Match.Pfr.Service()
                            self.service.parent = self
                            self._children_name_map["service"] = "service"

                            self.site = Native.Flow.Record.Default.Match.Pfr.Site()
                            self.site.parent = self
                            self._children_name_map["site"] = "site"
                            self._segment_path = lambda: "pfr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Pfr, [], name, value)


                        class Label(Entity):
                            """
                            PfR label metrics
                            
                            .. attribute:: identifier
                            
                            	pfr label id
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Pfr.Label, self).__init__()

                                self.yang_name = "label"
                                self.yang_parent_name = "pfr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('identifier', (YLeaf(YType.empty, 'identifier'), ['Empty'])),
                                ])
                                self.identifier = None
                                self._segment_path = lambda: "label"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.Label, ['identifier'], name, value)


                        class OneWayDelay(Entity):
                            """
                            The packet transmission delay between specified nodes
                            
                            .. attribute:: samples
                            
                            	Total number of one\-way\-delay samples
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sum
                            
                            	The packet transmission delay sum between specified nodes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Pfr.OneWayDelay, self).__init__()

                                self.yang_name = "one-way-delay"
                                self.yang_parent_name = "pfr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('samples', (YLeaf(YType.empty, 'samples'), ['Empty'])),
                                    ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                ])
                                self.samples = None
                                self.sum = None
                                self._segment_path = lambda: "one-way-delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.OneWayDelay, ['samples', 'sum'], name, value)


                        class Service(Entity):
                            """
                            PfR service metrics
                            
                            .. attribute:: provider
                            
                            	PfR service provider metrics
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: tag
                            
                            	PfR service provider tag metrics
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: identifier
                            
                            	PfR service provider tag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Pfr.Service, self).__init__()

                                self.yang_name = "service"
                                self.yang_parent_name = "pfr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('provider', (YLeaf(YType.empty, 'provider'), ['Empty'])),
                                    ('tag', (YLeaf(YType.empty, 'tag'), ['Empty'])),
                                    ('identifier', (YLeaf(YType.empty, 'identifier'), ['Empty'])),
                                ])
                                self.provider = None
                                self.tag = None
                                self.identifier = None
                                self._segment_path = lambda: "service"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.Service, ['provider', 'tag', 'identifier'], name, value)


                        class Site(Entity):
                            """
                            PfR site  metrics
                            
                            .. attribute:: destination
                            
                            	PfR site destination metrics
                            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.Site.Destination>`
                            
                            .. attribute:: source
                            
                            	PfR site source metrics
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.Site.Source>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Pfr.Site, self).__init__()

                                self.yang_name = "site"
                                self.yang_parent_name = "pfr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Match.Pfr.Site.Destination)), ("source", ("source", Native.Flow.Record.Default.Match.Pfr.Site.Source))])
                                self._leafs = OrderedDict()

                                self.destination = Native.Flow.Record.Default.Match.Pfr.Site.Destination()
                                self.destination.parent = self
                                self._children_name_map["destination"] = "destination"

                                self.source = Native.Flow.Record.Default.Match.Pfr.Site.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "site"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.Site, [], name, value)


                            class Destination(Entity):
                                """
                                PfR site destination metrics
                                
                                .. attribute:: id
                                
                                	PfR site destination ID metrics
                                	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.Site.Destination.Id>`
                                
                                .. attribute:: prefix
                                
                                	PfR site prefix of the packet destination
                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.Site.Destination.Prefix>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Pfr.Site.Destination, self).__init__()

                                    self.yang_name = "destination"
                                    self.yang_parent_name = "site"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("id", ("id", Native.Flow.Record.Default.Match.Pfr.Site.Destination.Id)), ("prefix", ("prefix", Native.Flow.Record.Default.Match.Pfr.Site.Destination.Prefix))])
                                    self._leafs = OrderedDict()

                                    self.id = Native.Flow.Record.Default.Match.Pfr.Site.Destination.Id()
                                    self.id.parent = self
                                    self._children_name_map["id"] = "id"

                                    self.prefix = Native.Flow.Record.Default.Match.Pfr.Site.Destination.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                    self._segment_path = lambda: "destination"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.Site.Destination, [], name, value)


                                class Id(Entity):
                                    """
                                    PfR site destination ID metrics
                                    
                                    .. attribute:: ipv4
                                    
                                    	site ID of the packet destination
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Pfr.Site.Destination.Id, self).__init__()

                                        self.yang_name = "id"
                                        self.yang_parent_name = "destination"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.Site.Destination.Id, ['ipv4'], name, value)


                                class Prefix(Entity):
                                    """
                                    PfR site prefix of the packet destination
                                    
                                    .. attribute:: ipv4
                                    
                                    	site prefix of the packet destination
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: mask
                                    
                                    	PfR site prefix mask of the packet destination
                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.Site.Destination.Prefix.Mask>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Pfr.Site.Destination.Prefix, self).__init__()

                                        self.yang_name = "prefix"
                                        self.yang_parent_name = "destination"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Match.Pfr.Site.Destination.Prefix.Mask))])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None

                                        self.mask = Native.Flow.Record.Default.Match.Pfr.Site.Destination.Prefix.Mask()
                                        self.mask.parent = self
                                        self._children_name_map["mask"] = "mask"
                                        self._segment_path = lambda: "prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.Site.Destination.Prefix, ['ipv4'], name, value)


                                    class Mask(Entity):
                                        """
                                        PfR site prefix mask of the packet destination
                                        
                                        .. attribute:: ipv4
                                        
                                        	site prefix mask of the packet destination
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Match.Pfr.Site.Destination.Prefix.Mask, self).__init__()

                                            self.yang_name = "mask"
                                            self.yang_parent_name = "prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                            ])
                                            self.ipv4 = None
                                            self._segment_path = lambda: "mask"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.Site.Destination.Prefix.Mask, ['ipv4'], name, value)


                            class Source(Entity):
                                """
                                PfR site source metrics
                                
                                .. attribute:: id
                                
                                	PfR site source ID metrics
                                	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.Site.Source.Id>`
                                
                                .. attribute:: prefix
                                
                                	PfR site prefix of the packet source
                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.Site.Source.Prefix>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Pfr.Site.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "site"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("id", ("id", Native.Flow.Record.Default.Match.Pfr.Site.Source.Id)), ("prefix", ("prefix", Native.Flow.Record.Default.Match.Pfr.Site.Source.Prefix))])
                                    self._leafs = OrderedDict()

                                    self.id = Native.Flow.Record.Default.Match.Pfr.Site.Source.Id()
                                    self.id.parent = self
                                    self._children_name_map["id"] = "id"

                                    self.prefix = Native.Flow.Record.Default.Match.Pfr.Site.Source.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.Site.Source, [], name, value)


                                class Id(Entity):
                                    """
                                    PfR site source ID metrics
                                    
                                    .. attribute:: ipv4
                                    
                                    	site ID of the packet source
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Pfr.Site.Source.Id, self).__init__()

                                        self.yang_name = "id"
                                        self.yang_parent_name = "source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.Site.Source.Id, ['ipv4'], name, value)


                                class Prefix(Entity):
                                    """
                                    PfR site prefix of the packet source
                                    
                                    .. attribute:: ipv4
                                    
                                    	site prefix of the packet source
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: mask
                                    
                                    	PfR site prefix mask of the packet source
                                    	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Pfr.Site.Source.Prefix.Mask>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Pfr.Site.Source.Prefix, self).__init__()

                                        self.yang_name = "prefix"
                                        self.yang_parent_name = "source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Default.Match.Pfr.Site.Source.Prefix.Mask))])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None

                                        self.mask = Native.Flow.Record.Default.Match.Pfr.Site.Source.Prefix.Mask()
                                        self.mask.parent = self
                                        self._children_name_map["mask"] = "mask"
                                        self._segment_path = lambda: "prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.Site.Source.Prefix, ['ipv4'], name, value)


                                    class Mask(Entity):
                                        """
                                        PfR site prefix mask of the packet source
                                        
                                        .. attribute:: ipv4
                                        
                                        	site prefix mask of the packet source
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-flow'
                                        _revision = '2018-01-04'

                                        def __init__(self):
                                            super(Native.Flow.Record.Default.Match.Pfr.Site.Source.Prefix.Mask, self).__init__()

                                            self.yang_name = "mask"
                                            self.yang_parent_name = "prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                            ])
                                            self.ipv4 = None
                                            self._segment_path = lambda: "mask"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Flow.Record.Default.Match.Pfr.Site.Source.Prefix.Mask, ['ipv4'], name, value)


                    class Policy(Entity):
                        """
                        policy fields
                        
                        .. attribute:: performance_monitor
                        
                        	Performance\-monitor policy related metrics
                        	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Policy.PerformanceMonitor>`
                        
                        .. attribute:: qos
                        
                        	QoS policy related metrics
                        	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Policy.Qos>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("performance-monitor", ("performance_monitor", Native.Flow.Record.Default.Match.Policy.PerformanceMonitor)), ("qos", ("qos", Native.Flow.Record.Default.Match.Policy.Qos))])
                            self._leafs = OrderedDict()

                            self.performance_monitor = Native.Flow.Record.Default.Match.Policy.PerformanceMonitor()
                            self.performance_monitor.parent = self
                            self._children_name_map["performance_monitor"] = "performance-monitor"

                            self.qos = Native.Flow.Record.Default.Match.Policy.Qos()
                            self.qos.parent = self
                            self._children_name_map["qos"] = "qos"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Policy, [], name, value)


                        class PerformanceMonitor(Entity):
                            """
                            Performance\-monitor policy related metrics
                            
                            .. attribute:: classification
                            
                            	Classification metrics
                            	**type**\:  :py:class:`Classification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Policy.PerformanceMonitor.Classification>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Policy.PerformanceMonitor, self).__init__()

                                self.yang_name = "performance-monitor"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("classification", ("classification", Native.Flow.Record.Default.Match.Policy.PerformanceMonitor.Classification))])
                                self._leafs = OrderedDict()

                                self.classification = Native.Flow.Record.Default.Match.Policy.PerformanceMonitor.Classification()
                                self.classification.parent = self
                                self._children_name_map["classification"] = "classification"
                                self._segment_path = lambda: "performance-monitor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Policy.PerformanceMonitor, [], name, value)


                            class Classification(Entity):
                                """
                                Classification metrics
                                
                                .. attribute:: hierarchy
                                
                                	Performance\-monitor class hierarchy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Policy.PerformanceMonitor.Classification, self).__init__()

                                    self.yang_name = "classification"
                                    self.yang_parent_name = "performance-monitor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hierarchy', (YLeaf(YType.empty, 'hierarchy'), ['Empty'])),
                                    ])
                                    self.hierarchy = None
                                    self._segment_path = lambda: "classification"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Policy.PerformanceMonitor.Classification, ['hierarchy'], name, value)


                        class Qos(Entity):
                            """
                            QoS policy related metrics
                            
                            .. attribute:: classification
                            
                            	Classification metrics
                            	**type**\:  :py:class:`Classification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Policy.Qos.Classification>`
                            
                            .. attribute:: queue
                            
                            	Queue metrics
                            	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Policy.Qos.Queue>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Policy.Qos, self).__init__()

                                self.yang_name = "qos"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("classification", ("classification", Native.Flow.Record.Default.Match.Policy.Qos.Classification)), ("queue", ("queue", Native.Flow.Record.Default.Match.Policy.Qos.Queue))])
                                self._leafs = OrderedDict()

                                self.classification = Native.Flow.Record.Default.Match.Policy.Qos.Classification()
                                self.classification.parent = self
                                self._children_name_map["classification"] = "classification"

                                self.queue = Native.Flow.Record.Default.Match.Policy.Qos.Queue()
                                self.queue.parent = self
                                self._children_name_map["queue"] = "queue"
                                self._segment_path = lambda: "qos"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Policy.Qos, [], name, value)


                            class Classification(Entity):
                                """
                                Classification metrics
                                
                                .. attribute:: hierarchy
                                
                                	QoS class hierarchy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Policy.Qos.Classification, self).__init__()

                                    self.yang_name = "classification"
                                    self.yang_parent_name = "qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hierarchy', (YLeaf(YType.empty, 'hierarchy'), ['Empty'])),
                                    ])
                                    self.hierarchy = None
                                    self._segment_path = lambda: "classification"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Policy.Qos.Classification, ['hierarchy'], name, value)


                            class Queue(Entity):
                                """
                                Queue metrics
                                
                                .. attribute:: drops
                                
                                	QoS queue drops
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: index
                                
                                	QoS queue index
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Policy.Qos.Queue, self).__init__()

                                    self.yang_name = "queue"
                                    self.yang_parent_name = "qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('drops', (YLeaf(YType.empty, 'drops'), ['Empty'])),
                                        ('index', (YLeaf(YType.empty, 'index'), ['Empty'])),
                                    ])
                                    self.drops = None
                                    self.index = None
                                    self._segment_path = lambda: "queue"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Policy.Qos.Queue, ['drops', 'index'], name, value)


                    class Routing(Entity):
                        """
                        Routing attributes
                        
                        .. attribute:: destination
                        
                        	Destination routing attributes
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.Destination>`
                        
                        .. attribute:: forwarding_status
                        
                        	Forwarding status of the packet
                        	**type**\:  :py:class:`ForwardingStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.ForwardingStatus>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: is_multicast
                        
                        	Indicates if this is multicast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: next_hop
                        
                        	Information regarding the next hop
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.NextHop>`
                        
                        .. attribute:: pw
                        
                        	Pseudowire fields
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.Pw>`
                        
                        .. attribute:: source
                        
                        	Source routing attributes
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.Source>`
                        
                        .. attribute:: vrf
                        
                        	VRF routing attributes
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Routing, self).__init__()

                            self.yang_name = "routing"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Match.Routing.Destination)), ("forwarding-status", ("forwarding_status", Native.Flow.Record.Default.Match.Routing.ForwardingStatus)), ("next-hop", ("next_hop", Native.Flow.Record.Default.Match.Routing.NextHop)), ("pw", ("pw", Native.Flow.Record.Default.Match.Routing.Pw)), ("source", ("source", Native.Flow.Record.Default.Match.Routing.Source)), ("vrf", ("vrf", Native.Flow.Record.Default.Match.Routing.Vrf))])
                            self._leafs = OrderedDict([
                                ('is_multicast', (YLeaf(YType.empty, 'is-multicast'), ['Empty'])),
                            ])
                            self.is_multicast = None

                            self.destination = Native.Flow.Record.Default.Match.Routing.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.forwarding_status = None
                            self._children_name_map["forwarding_status"] = "forwarding-status"

                            self.next_hop = Native.Flow.Record.Default.Match.Routing.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"

                            self.pw = Native.Flow.Record.Default.Match.Routing.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"

                            self.source = Native.Flow.Record.Default.Match.Routing.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"

                            self.vrf = Native.Flow.Record.Default.Match.Routing.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._segment_path = lambda: "routing"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Routing, ['is_multicast'], name, value)


                        class Destination(Entity):
                            """
                            Destination routing attributes
                            
                            .. attribute:: as_
                            
                            	AS number of the destination network
                            	**type**\:  :py:class:`As <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.Destination.As>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: traffic_index
                            
                            	BGP destination traffic index
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Routing.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("as", ("as_", Native.Flow.Record.Default.Match.Routing.Destination.As))])
                                self._leafs = OrderedDict([
                                    ('traffic_index', (YLeaf(YType.empty, 'traffic-index'), ['Empty'])),
                                ])
                                self.traffic_index = None

                                self.as_ = None
                                self._children_name_map["as_"] = "as"
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Routing.Destination, ['traffic_index'], name, value)


                            class As(Entity):
                                """
                                AS number of the destination network
                                
                                .. attribute:: as4_octet
                                
                                	4 octet AS number of the destination network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: peer
                                
                                	AS number of the peer network we will forward to
                                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.Destination.As.Peer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Routing.Destination.As, self).__init__()

                                    self.yang_name = "as"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("peer", ("peer", Native.Flow.Record.Default.Match.Routing.Destination.As.Peer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('as4_octet', (YLeaf(YType.empty, 'as4-octet'), ['Empty'])),
                                    ])
                                    self.as4_octet = None

                                    self.peer = None
                                    self._children_name_map["peer"] = "peer"
                                    self._segment_path = lambda: "as"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Routing.Destination.As, ['as4_octet'], name, value)


                                class Peer(Entity):
                                    """
                                    AS number of the peer network we will forward to
                                    
                                    .. attribute:: peer4_octet
                                    
                                    	4 octet AS number of the peer network we will forward to
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Routing.Destination.As.Peer, self).__init__()

                                        self.yang_name = "peer"
                                        self.yang_parent_name = "as"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('peer4_octet', (YLeaf(YType.empty, 'peer4-octet'), ['Empty'])),
                                        ])
                                        self.peer4_octet = None
                                        self._segment_path = lambda: "peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Routing.Destination.As.Peer, ['peer4_octet'], name, value)


                        class ForwardingStatus(Entity):
                            """
                            Forwarding status of the packet
                            
                            .. attribute:: reason
                            
                            	Forwarding status reason of the packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Routing.ForwardingStatus, self).__init__()

                                self.yang_name = "forwarding-status"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('reason', (YLeaf(YType.empty, 'reason'), ['Empty'])),
                                ])
                                self.reason = None
                                self._segment_path = lambda: "forwarding-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Routing.ForwardingStatus, ['reason'], name, value)


                        class NextHop(Entity):
                            """
                            Information regarding the next hop
                            
                            .. attribute:: address
                            
                            	IP address of the next hop
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.NextHop.Address>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Routing.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Default.Match.Routing.NextHop.Address))])
                                self._leafs = OrderedDict()

                                self.address = Native.Flow.Record.Default.Match.Routing.NextHop.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Routing.NextHop, [], name, value)


                            class Address(Entity):
                                """
                                IP address of the next hop
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address of the next hop
                                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.NextHop.Address.Ipv4>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address of the next hop
                                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.NextHop.Address.Ipv6>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Routing.NextHop.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Default.Match.Routing.NextHop.Address.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Default.Match.Routing.NextHop.Address.Ipv6))])
                                    self._leafs = OrderedDict()

                                    self.ipv4 = None
                                    self._children_name_map["ipv4"] = "ipv4"

                                    self.ipv6 = None
                                    self._children_name_map["ipv6"] = "ipv6"
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Routing.NextHop.Address, [], name, value)


                                class Ipv4(Entity):
                                    """
                                    IPv4 address of the next hop
                                    
                                    .. attribute:: bgp
                                    
                                    	IPv4 address of the BGP next hop
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Routing.NextHop.Address.Ipv4, self).__init__()

                                        self.yang_name = "ipv4"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                                        ])
                                        self.bgp = None
                                        self._segment_path = lambda: "ipv4"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Routing.NextHop.Address.Ipv4, ['bgp'], name, value)


                                class Ipv6(Entity):
                                    """
                                    IPv6 address of the next hop
                                    
                                    .. attribute:: bgp
                                    
                                    	IPv6 address of the BGP next hop
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Routing.NextHop.Address.Ipv6, self).__init__()

                                        self.yang_name = "ipv6"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                                        ])
                                        self.bgp = None
                                        self._segment_path = lambda: "ipv6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Routing.NextHop.Address.Ipv6, ['bgp'], name, value)


                        class Pw(Entity):
                            """
                            Pseudowire fields
                            
                            .. attribute:: destination
                            
                            	Pseudowire destination
                            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.Pw.Destination>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Routing.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Default.Match.Routing.Pw.Destination))])
                                self._leafs = OrderedDict()

                                self.destination = Native.Flow.Record.Default.Match.Routing.Pw.Destination()
                                self.destination.parent = self
                                self._children_name_map["destination"] = "destination"
                                self._segment_path = lambda: "pw"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Routing.Pw, [], name, value)


                            class Destination(Entity):
                                """
                                Pseudowire destination
                                
                                .. attribute:: address
                                
                                	Pseudowire destination address
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Routing.Pw.Destination, self).__init__()

                                    self.yang_name = "destination"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self._segment_path = lambda: "destination"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Routing.Pw.Destination, ['address'], name, value)


                        class Source(Entity):
                            """
                            Source routing attributes
                            
                            .. attribute:: as_
                            
                            	AS number of the original network
                            	**type**\:  :py:class:`As <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.Source.As>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: traffic_index
                            
                            	BGP source traffic index
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Routing.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("as", ("as_", Native.Flow.Record.Default.Match.Routing.Source.As))])
                                self._leafs = OrderedDict([
                                    ('traffic_index', (YLeaf(YType.empty, 'traffic-index'), ['Empty'])),
                                ])
                                self.traffic_index = None

                                self.as_ = None
                                self._children_name_map["as_"] = "as"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Routing.Source, ['traffic_index'], name, value)


                            class As(Entity):
                                """
                                AS number of the original network
                                
                                .. attribute:: as4_octet
                                
                                	4 octet AS number of the original network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: peer
                                
                                	AS number of the peer network where the packet came from
                                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Routing.Source.As.Peer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Routing.Source.As, self).__init__()

                                    self.yang_name = "as"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("peer", ("peer", Native.Flow.Record.Default.Match.Routing.Source.As.Peer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('as4_octet', (YLeaf(YType.empty, 'as4-octet'), ['Empty'])),
                                    ])
                                    self.as4_octet = None

                                    self.peer = None
                                    self._children_name_map["peer"] = "peer"
                                    self._segment_path = lambda: "as"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Routing.Source.As, ['as4_octet'], name, value)


                                class Peer(Entity):
                                    """
                                    AS number of the peer network where the packet came from
                                    
                                    .. attribute:: peer4_octet
                                    
                                    	4 octet AS number of the peer network where the packet came from
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Routing.Source.As.Peer, self).__init__()

                                        self.yang_name = "peer"
                                        self.yang_parent_name = "as"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('peer4_octet', (YLeaf(YType.empty, 'peer4-octet'), ['Empty'])),
                                        ])
                                        self.peer4_octet = None
                                        self._segment_path = lambda: "peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Routing.Source.As.Peer, ['peer4_octet'], name, value)


                        class Vrf(Entity):
                            """
                            VRF routing attributes
                            
                            .. attribute:: input
                            
                            	VRF ID for incoming packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: output
                            
                            	VRF ID for outgoing packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Routing.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                    ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ])
                                self.input = None
                                self.output = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Routing.Vrf, ['input', 'output'], name, value)


                    class Services(Entity):
                        """
                        Services fields
                        
                        .. attribute:: waas
                        
                        	WAAS (Wide Area Application Services) metrics
                        	**type**\:  :py:class:`Waas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Services.Waas>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Services, self).__init__()

                            self.yang_name = "services"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("waas", ("waas", Native.Flow.Record.Default.Match.Services.Waas))])
                            self._leafs = OrderedDict()

                            self.waas = Native.Flow.Record.Default.Match.Services.Waas()
                            self.waas.parent = self
                            self._children_name_map["waas"] = "waas"
                            self._segment_path = lambda: "services"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Services, [], name, value)


                        class Waas(Entity):
                            """
                            WAAS (Wide Area Application Services) metrics
                            
                            .. attribute:: passthrough_reason
                            
                            	WAAS passthrough reason
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: segment
                            
                            	WAAS optimization segment
                            	**type**\:  :py:class:`Segment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Services.Waas.Segment>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Services.Waas, self).__init__()

                                self.yang_name = "waas"
                                self.yang_parent_name = "services"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("segment", ("segment", Native.Flow.Record.Default.Match.Services.Waas.Segment))])
                                self._leafs = OrderedDict([
                                    ('passthrough_reason', (YLeaf(YType.empty, 'passthrough-reason'), ['Empty'])),
                                ])
                                self.passthrough_reason = None

                                self.segment = None
                                self._children_name_map["segment"] = "segment"
                                self._segment_path = lambda: "waas"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Services.Waas, ['passthrough_reason'], name, value)


                            class Segment(Entity):
                                """
                                WAAS optimization segment
                                
                                .. attribute:: account_on_resolution
                                
                                	Account on resolution
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Services.Waas.Segment, self).__init__()

                                    self.yang_name = "segment"
                                    self.yang_parent_name = "waas"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('account_on_resolution', (YLeaf(YType.empty, 'account-on-resolution'), ['Empty'])),
                                    ])
                                    self.account_on_resolution = None
                                    self._segment_path = lambda: "segment"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Services.Waas.Segment, ['account_on_resolution'], name, value)


                    class Timestamp(Entity):
                        """
                        Timestamp fields
                        
                        .. attribute:: absolute
                        
                        	Timestamps based on the epoch of 00\:00 UTC 1st Jan 1970
                        	**type**\:  :py:class:`Absolute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Timestamp.Absolute>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Timestamp, self).__init__()

                            self.yang_name = "timestamp"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("absolute", ("absolute", Native.Flow.Record.Default.Match.Timestamp.Absolute))])
                            self._leafs = OrderedDict()

                            self.absolute = Native.Flow.Record.Default.Match.Timestamp.Absolute()
                            self.absolute.parent = self
                            self._children_name_map["absolute"] = "absolute"
                            self._segment_path = lambda: "timestamp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Timestamp, [], name, value)


                        class Absolute(Entity):
                            """
                            Timestamps based on the epoch of 00\:00 UTC 1st Jan 1970
                            
                            .. attribute:: monitoring_interval
                            
                            	Monitoring interval timestamps
                            	**type**\:  :py:class:`MonitoringInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Timestamp.Absolute.MonitoringInterval>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Timestamp.Absolute, self).__init__()

                                self.yang_name = "absolute"
                                self.yang_parent_name = "timestamp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("monitoring-interval", ("monitoring_interval", Native.Flow.Record.Default.Match.Timestamp.Absolute.MonitoringInterval))])
                                self._leafs = OrderedDict()

                                self.monitoring_interval = Native.Flow.Record.Default.Match.Timestamp.Absolute.MonitoringInterval()
                                self.monitoring_interval.parent = self
                                self._children_name_map["monitoring_interval"] = "monitoring-interval"
                                self._segment_path = lambda: "absolute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Timestamp.Absolute, [], name, value)


                            class MonitoringInterval(Entity):
                                """
                                Monitoring interval timestamps
                                
                                .. attribute:: start
                                
                                	Absolute start time of a monitoring interval (milliseconds)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Timestamp.Absolute.MonitoringInterval, self).__init__()

                                    self.yang_name = "monitoring-interval"
                                    self.yang_parent_name = "absolute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('start', (YLeaf(YType.empty, 'start'), ['Empty'])),
                                    ])
                                    self.start = None
                                    self._segment_path = lambda: "monitoring-interval"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Timestamp.Absolute.MonitoringInterval, ['start'], name, value)


                    class Transport(Entity):
                        """
                        Transport layer fields
                        
                        .. attribute:: bytes
                        
                        	Bytes fields
                        	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Bytes>`
                        
                        .. attribute:: rtp
                        
                        	RTP fields
                        	**type**\:  :py:class:`Rtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Rtp>`
                        
                        .. attribute:: destination_port
                        
                        	Transport destination port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: icmp
                        
                        	ICMP fields
                        	**type**\:  :py:class:`Icmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Icmp>`
                        
                        .. attribute:: igmp
                        
                        	IGMP fields
                        	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Igmp>`
                        
                        .. attribute:: source_port
                        
                        	Transport source port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tcp
                        
                        	TCP fields
                        	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Tcp>`
                        
                        .. attribute:: udp
                        
                        	UDP fields
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Udp>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Default.Match.Transport, self).__init__()

                            self.yang_name = "transport"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Default.Match.Transport.Bytes)), ("rtp", ("rtp", Native.Flow.Record.Default.Match.Transport.Rtp)), ("icmp", ("icmp", Native.Flow.Record.Default.Match.Transport.Icmp)), ("igmp", ("igmp", Native.Flow.Record.Default.Match.Transport.Igmp)), ("tcp", ("tcp", Native.Flow.Record.Default.Match.Transport.Tcp)), ("udp", ("udp", Native.Flow.Record.Default.Match.Transport.Udp))])
                            self._leafs = OrderedDict([
                                ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                                ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                            ])
                            self.destination_port = None
                            self.source_port = None

                            self.bytes = Native.Flow.Record.Default.Match.Transport.Bytes()
                            self.bytes.parent = self
                            self._children_name_map["bytes"] = "bytes"

                            self.rtp = Native.Flow.Record.Default.Match.Transport.Rtp()
                            self.rtp.parent = self
                            self._children_name_map["rtp"] = "rtp"

                            self.icmp = Native.Flow.Record.Default.Match.Transport.Icmp()
                            self.icmp.parent = self
                            self._children_name_map["icmp"] = "icmp"

                            self.igmp = Native.Flow.Record.Default.Match.Transport.Igmp()
                            self.igmp.parent = self
                            self._children_name_map["igmp"] = "igmp"

                            self.tcp = Native.Flow.Record.Default.Match.Transport.Tcp()
                            self.tcp.parent = self
                            self._children_name_map["tcp"] = "tcp"

                            self.udp = Native.Flow.Record.Default.Match.Transport.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"
                            self._segment_path = lambda: "transport"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Default.Match.Transport, ['destination_port', 'source_port'], name, value)


                        class Bytes(Entity):
                            """
                            Bytes fields
                            
                            .. attribute:: expected
                            
                            	Transport bytes expected
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: lost
                            
                            	Transport bytes lost
                            	**type**\:  :py:class:`Lost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Bytes.Lost>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Transport.Bytes, self).__init__()

                                self.yang_name = "bytes"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lost", ("lost", Native.Flow.Record.Default.Match.Transport.Bytes.Lost))])
                                self._leafs = OrderedDict([
                                    ('expected', (YLeaf(YType.empty, 'expected'), ['Empty'])),
                                ])
                                self.expected = None

                                self.lost = None
                                self._children_name_map["lost"] = "lost"
                                self._segment_path = lambda: "bytes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Bytes, ['expected'], name, value)


                            class Lost(Entity):
                                """
                                Transport bytes lost
                                
                                .. attribute:: rate
                                
                                	Transport bytes lost rate
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Transport.Bytes.Lost, self).__init__()

                                    self.yang_name = "lost"
                                    self.yang_parent_name = "bytes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('rate', (YLeaf(YType.empty, 'rate'), ['Empty'])),
                                    ])
                                    self.rate = None
                                    self._segment_path = lambda: "lost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Bytes.Lost, ['rate'], name, value)


                        class Rtp(Entity):
                            """
                            RTP fields
                            
                            .. attribute:: ssrc
                            
                            	RTP SSRC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Transport.Rtp, self).__init__()

                                self.yang_name = "rtp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ssrc', (YLeaf(YType.empty, 'ssrc'), ['Empty'])),
                                ])
                                self.ssrc = None
                                self._segment_path = lambda: "rtp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Rtp, ['ssrc'], name, value)


                        class Icmp(Entity):
                            """
                            ICMP fields
                            
                            .. attribute:: ipv4
                            
                            	IPv4 ICMP fields
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Icmp.Ipv4>`
                            
                            .. attribute:: ipv6
                            
                            	IPv6 ICMP fields
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Icmp.Ipv6>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Transport.Icmp, self).__init__()

                                self.yang_name = "icmp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Default.Match.Transport.Icmp.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Default.Match.Transport.Icmp.Ipv6))])
                                self._leafs = OrderedDict()

                                self.ipv4 = Native.Flow.Record.Default.Match.Transport.Icmp.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = Native.Flow.Record.Default.Match.Transport.Icmp.Ipv6()
                                self.ipv6.parent = self
                                self._children_name_map["ipv6"] = "ipv6"
                                self._segment_path = lambda: "icmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Icmp, [], name, value)


                            class Ipv4(Entity):
                                """
                                IPv4 ICMP fields
                                
                                .. attribute:: code
                                
                                	IPv4 ICMP code
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: type
                                
                                	IPv4 ICMP type
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Transport.Icmp.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "icmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('code', (YLeaf(YType.empty, 'code'), ['Empty'])),
                                        ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                    ])
                                    self.code = None
                                    self.type = None
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Icmp.Ipv4, ['code', 'type'], name, value)


                            class Ipv6(Entity):
                                """
                                IPv6 ICMP fields
                                
                                .. attribute:: code
                                
                                	IPv6 ICMP code
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: type
                                
                                	IPv6 ICMP type
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Transport.Icmp.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "icmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('code', (YLeaf(YType.empty, 'code'), ['Empty'])),
                                        ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                    ])
                                    self.code = None
                                    self.type = None
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Icmp.Ipv6, ['code', 'type'], name, value)


                        class Igmp(Entity):
                            """
                            IGMP fields
                            
                            .. attribute:: type
                            
                            	IGMP type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Transport.Igmp, self).__init__()

                                self.yang_name = "igmp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                ])
                                self.type = None
                                self._segment_path = lambda: "igmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Igmp, ['type'], name, value)


                        class Tcp(Entity):
                            """
                            TCP fields
                            
                            .. attribute:: acknowledgement_number
                            
                            	TCP acknowledgement number
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: destination_port
                            
                            	TCP destination port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: flags
                            
                            	TCP flags
                            	**type**\:  :py:class:`Flags <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Tcp.Flags>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: flow
                            
                            	TCP flow
                            	**type**\:  :py:class:`Flow_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Tcp.Flow_>`
                            
                            .. attribute:: header_length
                            
                            	TCP header length (in 32 bit words)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: maximum_segment_size
                            
                            	The maximum size of TCP segment
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: option
                            
                            	TCP option fields
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Tcp.Option>`
                            
                            .. attribute:: sequence_number
                            
                            	TCP sequence number
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: source_port
                            
                            	TCP source port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: urgent_pointer
                            
                            	TCP urgent pointer
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: window_size
                            
                            	TCP window size
                            	**type**\:  :py:class:`WindowSize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Tcp.WindowSize>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Transport.Tcp, self).__init__()

                                self.yang_name = "tcp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("flags", ("flags", Native.Flow.Record.Default.Match.Transport.Tcp.Flags)), ("flow", ("flow", Native.Flow.Record.Default.Match.Transport.Tcp.Flow_)), ("option", ("option", Native.Flow.Record.Default.Match.Transport.Tcp.Option)), ("window-size", ("window_size", Native.Flow.Record.Default.Match.Transport.Tcp.WindowSize))])
                                self._leafs = OrderedDict([
                                    ('acknowledgement_number', (YLeaf(YType.empty, 'acknowledgement-number'), ['Empty'])),
                                    ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                                    ('header_length', (YLeaf(YType.empty, 'header-length'), ['Empty'])),
                                    ('maximum_segment_size', (YLeaf(YType.empty, 'maximum-segment-size'), ['Empty'])),
                                    ('sequence_number', (YLeaf(YType.empty, 'sequence-number'), ['Empty'])),
                                    ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                                    ('urgent_pointer', (YLeaf(YType.empty, 'urgent-pointer'), ['Empty'])),
                                ])
                                self.acknowledgement_number = None
                                self.destination_port = None
                                self.header_length = None
                                self.maximum_segment_size = None
                                self.sequence_number = None
                                self.source_port = None
                                self.urgent_pointer = None

                                self.flags = None
                                self._children_name_map["flags"] = "flags"

                                self.flow = Native.Flow.Record.Default.Match.Transport.Tcp.Flow_()
                                self.flow.parent = self
                                self._children_name_map["flow"] = "flow"

                                self.option = Native.Flow.Record.Default.Match.Transport.Tcp.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.window_size = None
                                self._children_name_map["window_size"] = "window-size"
                                self._segment_path = lambda: "tcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Tcp, ['acknowledgement_number', 'destination_port', 'header_length', 'maximum_segment_size', 'sequence_number', 'source_port', 'urgent_pointer'], name, value)


                            class Flags(Entity):
                                """
                                TCP flags
                                
                                .. attribute:: ack
                                
                                	TCP acknowledgement flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: cwr
                                
                                	TCP congestion window reduced flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ece
                                
                                	TCP ECN echo flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: fin
                                
                                	TCP finish flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: psh
                                
                                	TCP push flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rst
                                
                                	TCP reset flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: syn
                                
                                	TCP synchronise flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: urg
                                
                                	TCP urgent flag
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Transport.Tcp.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "tcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                        ('cwr', (YLeaf(YType.empty, 'cwr'), ['Empty'])),
                                        ('ece', (YLeaf(YType.empty, 'ece'), ['Empty'])),
                                        ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                        ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                        ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                        ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                        ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                    ])
                                    self.ack = None
                                    self.cwr = None
                                    self.ece = None
                                    self.fin = None
                                    self.psh = None
                                    self.rst = None
                                    self.syn = None
                                    self.urg = None
                                    self._segment_path = lambda: "flags"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Tcp.Flags, ['ack', 'cwr', 'ece', 'fin', 'psh', 'rst', 'syn', 'urg'], name, value)


                            class Flow_(Entity):
                                """
                                TCP flow
                                
                                .. attribute:: count
                                
                                	Number of tcp flows
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Transport.Tcp.Flow_, self).__init__()

                                    self.yang_name = "flow"
                                    self.yang_parent_name = "tcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.empty, 'count'), ['Empty'])),
                                    ])
                                    self.count = None
                                    self._segment_path = lambda: "flow"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Tcp.Flow_, ['count'], name, value)


                            class Option(Entity):
                                """
                                TCP option fields
                                
                                .. attribute:: map
                                
                                	Bitmap of TCP options
                                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Tcp.Option.Map>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Transport.Tcp.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "tcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map", ("map", Native.Flow.Record.Default.Match.Transport.Tcp.Option.Map))])
                                    self._leafs = OrderedDict()

                                    self.map = None
                                    self._children_name_map["map"] = "map"
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Tcp.Option, [], name, value)


                                class Map(Entity):
                                    """
                                    Bitmap of TCP options
                                    
                                    .. attribute:: long
                                    
                                    	Extended bitmap of TCP options
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Transport.Tcp.Option.Map, self).__init__()

                                        self.yang_name = "map"
                                        self.yang_parent_name = "option"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                        ])
                                        self.long = None
                                        self._segment_path = lambda: "map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Tcp.Option.Map, ['long'], name, value)


                            class WindowSize(Entity):
                                """
                                TCP window size
                                
                                .. attribute:: average
                                
                                	The average size of TCP window
                                	**type**\:  :py:class:`Average <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Default.Match.Transport.Tcp.WindowSize.Average>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: maximum
                                
                                	The maximum size of TCP window
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minimum
                                
                                	The minimum size of TCP window
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sum
                                
                                	The sum of TCP window size
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Default.Match.Transport.Tcp.WindowSize, self).__init__()

                                    self.yang_name = "window-size"
                                    self.yang_parent_name = "tcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("average", ("average", Native.Flow.Record.Default.Match.Transport.Tcp.WindowSize.Average))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                        ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.maximum = None
                                    self.minimum = None
                                    self.sum = None

                                    self.average = None
                                    self._children_name_map["average"] = "average"
                                    self._segment_path = lambda: "window-size"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Tcp.WindowSize, ['maximum', 'minimum', 'sum'], name, value)


                                class Average(Entity):
                                    """
                                    The average size of TCP window
                                    
                                    .. attribute:: sum
                                    
                                    	The sum of per flow TCP window average size
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Default.Match.Transport.Tcp.WindowSize.Average, self).__init__()

                                        self.yang_name = "average"
                                        self.yang_parent_name = "window-size"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                        ])
                                        self.sum = None
                                        self._segment_path = lambda: "average"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Tcp.WindowSize.Average, ['sum'], name, value)


                        class Udp(Entity):
                            """
                            UDP fields
                            
                            .. attribute:: destination_port
                            
                            	UDP destination port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: message_length
                            
                            	UDP message length
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: source_port
                            
                            	UDP source port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Default.Match.Transport.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                                    ('message_length', (YLeaf(YType.empty, 'message-length'), ['Empty'])),
                                    ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                                ])
                                self.destination_port = None
                                self.message_length = None
                                self.source_port = None
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Default.Match.Transport.Udp, ['destination_port', 'message_length', 'source_port'], name, value)


            class Match(Entity):
                """
                Specify a key field
                
                .. attribute:: application
                
                	Application fields
                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Application>`
                
                .. attribute:: connection
                
                	Connection fields
                	**type**\:  :py:class:`Connection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Connection>`
                
                .. attribute:: datalink
                
                	Datalink (layer2) fields
                	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Datalink>`
                
                .. attribute:: flow
                
                	Flow identifying fields
                	**type**\:  :py:class:`Flow_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Flow_>`
                
                .. attribute:: interface
                
                	Interface fields
                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Interface>`
                
                .. attribute:: ipv4
                
                	IPv4 fields
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4>`
                
                .. attribute:: ipv6
                
                	IPv6 fields
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6>`
                
                .. attribute:: metadata
                
                	Metadata fields
                	**type**\:  :py:class:`Metadata <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Metadata>`
                
                .. attribute:: mpls
                
                	MPLS fields
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Mpls>`
                
                .. attribute:: network
                
                	network metrics
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Network>`
                
                .. attribute:: pfr
                
                	PfR metrics
                	**type**\:  :py:class:`Pfr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr>`
                
                .. attribute:: policy
                
                	policy fields
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Policy>`
                
                .. attribute:: routing
                
                	Routing attributes
                	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing>`
                
                .. attribute:: services
                
                	Services fields
                	**type**\:  :py:class:`Services <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Services>`
                
                .. attribute:: timestamp
                
                	Timestamp fields
                	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Timestamp>`
                
                .. attribute:: transport
                
                	Transport layer fields
                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport>`
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Record.Match, self).__init__()

                    self.yang_name = "match"
                    self.yang_parent_name = "record"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("application", ("application", Native.Flow.Record.Match.Application)), ("connection", ("connection", Native.Flow.Record.Match.Connection)), ("datalink", ("datalink", Native.Flow.Record.Match.Datalink)), ("flow", ("flow", Native.Flow.Record.Match.Flow_)), ("interface", ("interface", Native.Flow.Record.Match.Interface)), ("ipv4", ("ipv4", Native.Flow.Record.Match.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Match.Ipv6)), ("metadata", ("metadata", Native.Flow.Record.Match.Metadata)), ("mpls", ("mpls", Native.Flow.Record.Match.Mpls)), ("network", ("network", Native.Flow.Record.Match.Network)), ("pfr", ("pfr", Native.Flow.Record.Match.Pfr)), ("policy", ("policy", Native.Flow.Record.Match.Policy)), ("routing", ("routing", Native.Flow.Record.Match.Routing)), ("services", ("services", Native.Flow.Record.Match.Services)), ("timestamp", ("timestamp", Native.Flow.Record.Match.Timestamp)), ("transport", ("transport", Native.Flow.Record.Match.Transport))])
                    self._leafs = OrderedDict()

                    self.application = Native.Flow.Record.Match.Application()
                    self.application.parent = self
                    self._children_name_map["application"] = "application"

                    self.connection = Native.Flow.Record.Match.Connection()
                    self.connection.parent = self
                    self._children_name_map["connection"] = "connection"

                    self.datalink = Native.Flow.Record.Match.Datalink()
                    self.datalink.parent = self
                    self._children_name_map["datalink"] = "datalink"

                    self.flow = Native.Flow.Record.Match.Flow_()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"

                    self.interface = Native.Flow.Record.Match.Interface()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.ipv4 = Native.Flow.Record.Match.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = Native.Flow.Record.Match.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.metadata = Native.Flow.Record.Match.Metadata()
                    self.metadata.parent = self
                    self._children_name_map["metadata"] = "metadata"

                    self.mpls = Native.Flow.Record.Match.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"

                    self.network = Native.Flow.Record.Match.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.pfr = Native.Flow.Record.Match.Pfr()
                    self.pfr.parent = self
                    self._children_name_map["pfr"] = "pfr"

                    self.policy = Native.Flow.Record.Match.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.routing = Native.Flow.Record.Match.Routing()
                    self.routing.parent = self
                    self._children_name_map["routing"] = "routing"

                    self.services = Native.Flow.Record.Match.Services()
                    self.services.parent = self
                    self._children_name_map["services"] = "services"

                    self.timestamp = Native.Flow.Record.Match.Timestamp()
                    self.timestamp.parent = self
                    self._children_name_map["timestamp"] = "timestamp"

                    self.transport = Native.Flow.Record.Match.Transport()
                    self.transport.parent = self
                    self._children_name_map["transport"] = "transport"
                    self._segment_path = lambda: "match"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Record.Match, [], name, value)


                class Application(Entity):
                    """
                    Application fields
                    
                    .. attribute:: name
                    
                    	Application name
                    	**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Application.Name>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: vendor
                    
                    	Application vendor id
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: version
                    
                    	Application version id
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Application, self).__init__()

                        self.yang_name = "application"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("name", ("name", Native.Flow.Record.Match.Application.Name))])
                        self._leafs = OrderedDict([
                            ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                            ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                        ])
                        self.vendor = None
                        self.version = None

                        self.name = None
                        self._children_name_map["name"] = "name"
                        self._segment_path = lambda: "application"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Application, ['vendor', 'version'], name, value)


                    class Name(Entity):
                        """
                        Application name
                        
                        .. attribute:: account_on_resolution
                        
                        	Account on resolution
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Application.Name, self).__init__()

                            self.yang_name = "name"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('account_on_resolution', (YLeaf(YType.empty, 'account-on-resolution'), ['Empty'])),
                            ])
                            self.account_on_resolution = None
                            self._segment_path = lambda: "name"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Application.Name, ['account_on_resolution'], name, value)


                class Connection(Entity):
                    """
                    Connection fields
                    
                    .. attribute:: client
                    
                    	Client side (flow initiator) related metrics
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Connection.Client>`
                    
                    .. attribute:: id
                    
                    	An identifier for a connection between client and server
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: initiator
                    
                    	The direction of the flow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: server
                    
                    	Server side (flow responder) related metrics
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Connection.Server>`
                    
                    .. attribute:: transaction_id
                    
                    	An identifier for a transaction between client and server
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Connection, self).__init__()

                        self.yang_name = "connection"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("client", ("client", Native.Flow.Record.Match.Connection.Client)), ("server", ("server", Native.Flow.Record.Match.Connection.Server))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                            ('initiator', (YLeaf(YType.empty, 'initiator'), ['Empty'])),
                            ('transaction_id', (YLeaf(YType.empty, 'transaction-id'), ['Empty'])),
                        ])
                        self.id = None
                        self.initiator = None
                        self.transaction_id = None

                        self.client = Native.Flow.Record.Match.Connection.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "client"

                        self.server = Native.Flow.Record.Match.Connection.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"
                        self._segment_path = lambda: "connection"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Connection, ['id', 'initiator', 'transaction_id'], name, value)


                    class Client(Entity):
                        """
                        Client side (flow initiator) related metrics
                        
                        .. attribute:: ipv4
                        
                        	Client side IPv4 metrics
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Connection.Client.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	Client side IPv6 metrics
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Connection.Client.Ipv6>`
                        
                        .. attribute:: transport
                        
                        	Client side transport metrics
                        	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Connection.Client.Transport>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Connection.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "connection"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Match.Connection.Client.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Match.Connection.Client.Ipv6)), ("transport", ("transport", Native.Flow.Record.Match.Connection.Client.Transport))])
                            self._leafs = OrderedDict()

                            self.ipv4 = Native.Flow.Record.Match.Connection.Client.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = Native.Flow.Record.Match.Connection.Client.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.transport = Native.Flow.Record.Match.Connection.Client.Transport()
                            self.transport.parent = self
                            self._children_name_map["transport"] = "transport"
                            self._segment_path = lambda: "client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Connection.Client, [], name, value)


                        class Ipv4(Entity):
                            """
                            Client side IPv4 metrics
                            
                            .. attribute:: address
                            
                            	IPv4 address of the flow initiator
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Connection.Client.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Connection.Client.Ipv4, ['address'], name, value)


                        class Ipv6(Entity):
                            """
                            Client side IPv6 metrics
                            
                            .. attribute:: address
                            
                            	IPv6 address of the flow initiator
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Connection.Client.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Connection.Client.Ipv6, ['address'], name, value)


                        class Transport(Entity):
                            """
                            Client side transport metrics
                            
                            .. attribute:: port
                            
                            	Transport port of the flow initiator
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Connection.Client.Transport, self).__init__()

                                self.yang_name = "transport"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port', (YLeaf(YType.empty, 'port'), ['Empty'])),
                                ])
                                self.port = None
                                self._segment_path = lambda: "transport"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Connection.Client.Transport, ['port'], name, value)


                    class Server(Entity):
                        """
                        Server side (flow responder) related metrics
                        
                        .. attribute:: ipv4
                        
                        	Server side IPv4 metrics
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Connection.Server.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	Server side IPv6 metrics
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Connection.Server.Ipv6>`
                        
                        .. attribute:: transport
                        
                        	Server side transport metrics
                        	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Connection.Server.Transport>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Connection.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "connection"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Match.Connection.Server.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Match.Connection.Server.Ipv6)), ("transport", ("transport", Native.Flow.Record.Match.Connection.Server.Transport))])
                            self._leafs = OrderedDict()

                            self.ipv4 = Native.Flow.Record.Match.Connection.Server.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = Native.Flow.Record.Match.Connection.Server.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.transport = Native.Flow.Record.Match.Connection.Server.Transport()
                            self.transport.parent = self
                            self._children_name_map["transport"] = "transport"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Connection.Server, [], name, value)


                        class Ipv4(Entity):
                            """
                            Server side IPv4 metrics
                            
                            .. attribute:: address
                            
                            	IPv4 address of the flow responder
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Connection.Server.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Connection.Server.Ipv4, ['address'], name, value)


                        class Ipv6(Entity):
                            """
                            Server side IPv6 metrics
                            
                            .. attribute:: address
                            
                            	IPv6 address of the flow responder
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Connection.Server.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Connection.Server.Ipv6, ['address'], name, value)


                        class Transport(Entity):
                            """
                            Server side transport metrics
                            
                            .. attribute:: port
                            
                            	Transport port of the flow responder
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Connection.Server.Transport, self).__init__()

                                self.yang_name = "transport"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port', (YLeaf(YType.empty, 'port'), ['Empty'])),
                                ])
                                self.port = None
                                self._segment_path = lambda: "transport"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Connection.Server.Transport, ['port'], name, value)


                class Datalink(Entity):
                    """
                    Datalink (layer2) fields
                    
                    .. attribute:: destination_vlan_id
                    
                    	ID of the VLAN that the packet is going to
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dot1q
                    
                    	dot1q field
                    	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Datalink.Dot1q>`
                    
                    .. attribute:: ethertype
                    
                    	The Ethertype of the packet
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vlan
                    
                    	The VLAN the packet is on
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Datalink.Vlan>`
                    
                    .. attribute:: mac
                    
                    	MAC fields
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Datalink.Mac>`
                    
                    .. attribute:: source_vlan_id
                    
                    	ID of the VLAN that the packet came from
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Datalink, self).__init__()

                        self.yang_name = "datalink"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dot1q", ("dot1q", Native.Flow.Record.Match.Datalink.Dot1q)), ("mac", ("mac", Native.Flow.Record.Match.Datalink.Mac))])
                        self._leafs = OrderedDict([
                            ('destination_vlan_id', (YLeaf(YType.empty, 'destination-vlan-id'), ['Empty'])),
                            ('ethertype', (YLeaf(YType.empty, 'ethertype'), ['Empty'])),
                            ('vlan', (YLeaf(YType.enumeration, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Flow.Record.Match.Datalink.Vlan')])),
                            ('source_vlan_id', (YLeaf(YType.empty, 'source-vlan-id'), ['Empty'])),
                        ])
                        self.destination_vlan_id = None
                        self.ethertype = None
                        self.vlan = None
                        self.source_vlan_id = None

                        self.dot1q = Native.Flow.Record.Match.Datalink.Dot1q()
                        self.dot1q.parent = self
                        self._children_name_map["dot1q"] = "dot1q"

                        self.mac = Native.Flow.Record.Match.Datalink.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"
                        self._segment_path = lambda: "datalink"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Datalink, ['destination_vlan_id', 'ethertype', 'vlan', 'source_vlan_id'], name, value)

                    class Vlan(Enum):
                        """
                        Vlan (Enum Class)

                        The VLAN the packet is on

                        .. data:: input = 0

                        .. data:: output = 1

                        """

                        input = Enum.YLeaf(0, "input")

                        output = Enum.YLeaf(1, "output")



                    class Dot1q(Entity):
                        """
                        dot1q field
                        
                        .. attribute:: priority
                        
                        	The CoS field out of the dot1q header
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	The VLAN the packet is on
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Datalink.Dot1q.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Datalink.Dot1q, self).__init__()

                            self.yang_name = "dot1q"
                            self.yang_parent_name = "datalink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Flow.Record.Match.Datalink.Dot1q.Vlan))])
                            self._leafs = OrderedDict([
                                ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                            ])
                            self.priority = None

                            self.vlan = Native.Flow.Record.Match.Datalink.Dot1q.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "dot1q"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Datalink.Dot1q, ['priority'], name, value)


                        class Vlan(Entity):
                            """
                            The VLAN the packet is on
                            
                            .. attribute:: input
                            
                            	The VLAN the packet is on at input
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: output
                            
                            	The VLAN the packet is on at output
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Datalink.Dot1q.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "dot1q"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                    ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ])
                                self.input = None
                                self.output = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Datalink.Dot1q.Vlan, ['input', 'output'], name, value)


                    class Mac(Entity):
                        """
                        MAC fields
                        
                        .. attribute:: destination
                        
                        	destination MAC fields
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Datalink.Mac.Destination>`
                        
                        .. attribute:: source
                        
                        	source MAC fields
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Datalink.Mac.Source>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Datalink.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "datalink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Match.Datalink.Mac.Destination)), ("source", ("source", Native.Flow.Record.Match.Datalink.Mac.Source))])
                            self._leafs = OrderedDict()

                            self.destination = Native.Flow.Record.Match.Datalink.Mac.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.source = Native.Flow.Record.Match.Datalink.Mac.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Datalink.Mac, [], name, value)


                        class Destination(Entity):
                            """
                            destination MAC fields
                            
                            .. attribute:: address
                            
                            	Destination MAC address from packet
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Datalink.Mac.Destination.Address>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Datalink.Mac.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Match.Datalink.Mac.Destination.Address))])
                                self._leafs = OrderedDict()

                                self.address = Native.Flow.Record.Match.Datalink.Mac.Destination.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Datalink.Mac.Destination, [], name, value)


                            class Address(Entity):
                                """
                                Destination MAC address from packet
                                
                                .. attribute:: input
                                
                                	Destination MAC address from packet at input
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: output
                                
                                	Destination MAC address from packet at output
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Datalink.Mac.Destination.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                        ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                    ])
                                    self.input = None
                                    self.output = None
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Datalink.Mac.Destination.Address, ['input', 'output'], name, value)


                        class Source(Entity):
                            """
                            source MAC fields
                            
                            .. attribute:: address
                            
                            	Source MAC address from packet
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Datalink.Mac.Source.Address>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Datalink.Mac.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Match.Datalink.Mac.Source.Address))])
                                self._leafs = OrderedDict()

                                self.address = Native.Flow.Record.Match.Datalink.Mac.Source.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Datalink.Mac.Source, [], name, value)


                            class Address(Entity):
                                """
                                Source MAC address from packet
                                
                                .. attribute:: input
                                
                                	Source MAC address from packet at input
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: output
                                
                                	Source MAC address from packet at output
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Datalink.Mac.Source.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                        ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                    ])
                                    self.input = None
                                    self.output = None
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Datalink.Mac.Source.Address, ['input', 'output'], name, value)


                class Flow_(Entity):
                    """
                    Flow identifying fields
                    
                    .. attribute:: cts
                    
                    	Cisco Trusted Security fields
                    	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Flow_.Cts>`
                    
                    .. attribute:: direction
                    
                    	Direction the flow was monitored in
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: observation
                    
                    	Flow observation metrics
                    	**type**\:  :py:class:`Observation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Flow_.Observation>`
                    
                    .. attribute:: sampler
                    
                    	ID of the sampler
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Flow_, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("cts", ("cts", Native.Flow.Record.Match.Flow_.Cts)), ("observation", ("observation", Native.Flow.Record.Match.Flow_.Observation))])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.empty, 'direction'), ['Empty'])),
                            ('sampler', (YLeaf(YType.empty, 'sampler'), ['Empty'])),
                        ])
                        self.direction = None
                        self.sampler = None

                        self.cts = Native.Flow.Record.Match.Flow_.Cts()
                        self.cts.parent = self
                        self._children_name_map["cts"] = "cts"

                        self.observation = Native.Flow.Record.Match.Flow_.Observation()
                        self.observation.parent = self
                        self._children_name_map["observation"] = "observation"
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Flow_, ['direction', 'sampler'], name, value)


                    class Cts(Entity):
                        """
                        Cisco Trusted Security fields
                        
                        .. attribute:: destination
                        
                        	Cisco Trusted Security destination fields
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Flow_.Cts.Destination>`
                        
                        .. attribute:: source
                        
                        	Cisco Trusted Security source fields
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Flow_.Cts.Source>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Flow_.Cts, self).__init__()

                            self.yang_name = "cts"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Match.Flow_.Cts.Destination)), ("source", ("source", Native.Flow.Record.Match.Flow_.Cts.Source))])
                            self._leafs = OrderedDict()

                            self.destination = Native.Flow.Record.Match.Flow_.Cts.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.source = Native.Flow.Record.Match.Flow_.Cts.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "cts"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Flow_.Cts, [], name, value)


                        class Destination(Entity):
                            """
                            Cisco Trusted Security destination fields
                            
                            .. attribute:: group_tag
                            
                            	destination group\-tag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Flow_.Cts.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "cts"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group_tag', (YLeaf(YType.empty, 'group-tag'), ['Empty'])),
                                ])
                                self.group_tag = None
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Flow_.Cts.Destination, ['group_tag'], name, value)


                        class Source(Entity):
                            """
                            Cisco Trusted Security source fields
                            
                            .. attribute:: group_tag
                            
                            	source group\-tag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Flow_.Cts.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "cts"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group_tag', (YLeaf(YType.empty, 'group-tag'), ['Empty'])),
                                ])
                                self.group_tag = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Flow_.Cts.Source, ['group_tag'], name, value)


                    class Observation(Entity):
                        """
                        Flow observation metrics
                        
                        .. attribute:: point
                        
                        	Observation point ID
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Flow_.Observation, self).__init__()

                            self.yang_name = "observation"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('point', (YLeaf(YType.empty, 'point'), ['Empty'])),
                            ])
                            self.point = None
                            self._segment_path = lambda: "observation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Flow_.Observation, ['point'], name, value)


                class Interface(Entity):
                    """
                    Interface fields
                    
                    .. attribute:: input
                    
                    	The input interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Interface.Input>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: output
                    
                    	The output interface
                    	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Interface.Output>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Flow.Record.Match.Interface.Input)), ("output", ("output", Native.Flow.Record.Match.Interface.Output))])
                        self._leafs = OrderedDict()

                        self.input = None
                        self._children_name_map["input"] = "input"

                        self.output = None
                        self._children_name_map["output"] = "output"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Interface, [], name, value)


                    class Input(Entity):
                        """
                        The input interface
                        
                        .. attribute:: snmp
                        
                        	SNMP Index of the input interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Interface.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('snmp', (YLeaf(YType.empty, 'snmp'), ['Empty'])),
                            ])
                            self.snmp = None
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Interface.Input, ['snmp'], name, value)


                    class Output(Entity):
                        """
                        The output interface
                        
                        .. attribute:: snmp
                        
                        	SNMP Index of the output interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Interface.Output, self).__init__()

                            self.yang_name = "output"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('snmp', (YLeaf(YType.empty, 'snmp'), ['Empty'])),
                            ])
                            self.snmp = None
                            self._segment_path = lambda: "output"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Interface.Output, ['snmp'], name, value)


                class Ipv4(Entity):
                    """
                    IPv4 fields
                    
                    .. attribute:: destination
                    
                    	IPv4 destination address based fields
                    	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Destination>`
                    
                    .. attribute:: dscp
                    
                    	IPv4 DSCP (part of TOS)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: fragmentation
                    
                    	IPv4 fragmentation fields
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Fragmentation>`
                    
                    .. attribute:: header_length
                    
                    	IPv4 header length (IHL in 32 bit words)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: id
                    
                    	IPv4 ID
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: length
                    
                    	IPv4 length fields
                    	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Length>`
                    
                    .. attribute:: option
                    
                    	IPv4 option fields
                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Option>`
                    
                    .. attribute:: precedence
                    
                    	IPv4 precedence (part of TOS)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: protocol
                    
                    	IPv4 protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: section
                    
                    	Part of the packet
                    	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Section>`
                    
                    .. attribute:: source
                    
                    	IPv4 source address based fields
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Source>`
                    
                    .. attribute:: tos
                    
                    	IPv4 type of service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: total_length
                    
                    	IPv4 total length
                    	**type**\:  :py:class:`TotalLength <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.TotalLength>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ttl
                    
                    	IPv4 TTL
                    	**type**\:  :py:class:`Ttl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Ttl>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: version
                    
                    	IP version from IPv4 header
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Match.Ipv4.Destination)), ("fragmentation", ("fragmentation", Native.Flow.Record.Match.Ipv4.Fragmentation)), ("length", ("length", Native.Flow.Record.Match.Ipv4.Length)), ("option", ("option", Native.Flow.Record.Match.Ipv4.Option)), ("section", ("section", Native.Flow.Record.Match.Ipv4.Section)), ("source", ("source", Native.Flow.Record.Match.Ipv4.Source)), ("total-length", ("total_length", Native.Flow.Record.Match.Ipv4.TotalLength)), ("ttl", ("ttl", Native.Flow.Record.Match.Ipv4.Ttl))])
                        self._leafs = OrderedDict([
                            ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ('header_length', (YLeaf(YType.empty, 'header-length'), ['Empty'])),
                            ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                            ('precedence', (YLeaf(YType.empty, 'precedence'), ['Empty'])),
                            ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                            ('tos', (YLeaf(YType.empty, 'tos'), ['Empty'])),
                            ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                        ])
                        self.dscp = None
                        self.header_length = None
                        self.id = None
                        self.precedence = None
                        self.protocol = None
                        self.tos = None
                        self.version = None

                        self.destination = Native.Flow.Record.Match.Ipv4.Destination()
                        self.destination.parent = self
                        self._children_name_map["destination"] = "destination"

                        self.fragmentation = Native.Flow.Record.Match.Ipv4.Fragmentation()
                        self.fragmentation.parent = self
                        self._children_name_map["fragmentation"] = "fragmentation"

                        self.length = Native.Flow.Record.Match.Ipv4.Length()
                        self.length.parent = self
                        self._children_name_map["length"] = "length"

                        self.option = Native.Flow.Record.Match.Ipv4.Option()
                        self.option.parent = self
                        self._children_name_map["option"] = "option"

                        self.section = Native.Flow.Record.Match.Ipv4.Section()
                        self.section.parent = self
                        self._children_name_map["section"] = "section"

                        self.source = Native.Flow.Record.Match.Ipv4.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"

                        self.total_length = None
                        self._children_name_map["total_length"] = "total-length"

                        self.ttl = None
                        self._children_name_map["ttl"] = "ttl"
                        self._segment_path = lambda: "ipv4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Ipv4, ['dscp', 'header_length', 'id', 'precedence', 'protocol', 'tos', 'version'], name, value)


                    class Destination(Entity):
                        """
                        IPv4 destination address based fields
                        
                        .. attribute:: address
                        
                        	IPv4 destination address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mask
                        
                        	IPv4 address mask for the IPv4 destination address
                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Destination.Mask>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix
                        
                        	IPv4 address prefix for the IPv4 destination address
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Destination.Prefix>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv4.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Match.Ipv4.Destination.Mask)), ("prefix", ("prefix", Native.Flow.Record.Match.Ipv4.Destination.Prefix))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                            ])
                            self.address = None

                            self.mask = None
                            self._children_name_map["mask"] = "mask"

                            self.prefix = None
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "destination"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv4.Destination, ['address'], name, value)


                        class Mask(Entity):
                            """
                            IPv4 address mask for the IPv4 destination address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..32
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv4.Destination.Mask, self).__init__()

                                self.yang_name = "mask"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "mask"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv4.Destination.Mask, ['minimum_mask'], name, value)


                        class Prefix(Entity):
                            """
                            IPv4 address prefix for the IPv4 destination address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..32
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv4.Destination.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv4.Destination.Prefix, ['minimum_mask'], name, value)


                    class Fragmentation(Entity):
                        """
                        IPv4 fragmentation fields
                        
                        .. attribute:: flags
                        
                        	IPv4 fragmentation flags
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: offset
                        
                        	IPv4 fragmentation offset
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv4.Fragmentation, self).__init__()

                            self.yang_name = "fragmentation"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('flags', (YLeaf(YType.empty, 'flags'), ['Empty'])),
                                ('offset', (YLeaf(YType.empty, 'offset'), ['Empty'])),
                            ])
                            self.flags = None
                            self.offset = None
                            self._segment_path = lambda: "fragmentation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv4.Fragmentation, ['flags', 'offset'], name, value)


                    class Length(Entity):
                        """
                        IPv4 length fields
                        
                        .. attribute:: header
                        
                        	Length of the IPv4 header in bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: payload
                        
                        	Length of the IPv4 payload in bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: total
                        
                        	Total length of the IPv4 header and payload in bytes
                        	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Length.Total>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv4.Length, self).__init__()

                            self.yang_name = "length"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("total", ("total", Native.Flow.Record.Match.Ipv4.Length.Total))])
                            self._leafs = OrderedDict([
                                ('header', (YLeaf(YType.empty, 'header'), ['Empty'])),
                                ('payload', (YLeaf(YType.empty, 'payload'), ['Empty'])),
                            ])
                            self.header = None
                            self.payload = None

                            self.total = None
                            self._children_name_map["total"] = "total"
                            self._segment_path = lambda: "length"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv4.Length, ['header', 'payload'], name, value)


                        class Total(Entity):
                            """
                            Total length of the IPv4 header and payload in bytes
                            
                            .. attribute:: maximum
                            
                            	Maximum total length in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	Minimum total length in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv4.Length.Total, self).__init__()

                                self.yang_name = "total"
                                self.yang_parent_name = "length"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self._segment_path = lambda: "total"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv4.Length.Total, ['maximum', 'minimum'], name, value)


                    class Option(Entity):
                        """
                        IPv4 option fields
                        
                        .. attribute:: map
                        
                        	Bitmap of IPv4 options
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv4.Option, self).__init__()

                            self.yang_name = "option"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('map', (YLeaf(YType.empty, 'map'), ['Empty'])),
                            ])
                            self.map = None
                            self._segment_path = lambda: "option"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv4.Option, ['map'], name, value)


                    class Section(Entity):
                        """
                        Part of the packet
                        
                        .. attribute:: header
                        
                        	Raw data starting at the IPv4 header
                        	**type**\:  :py:class:`Header <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Section.Header>`
                        
                        .. attribute:: payload
                        
                        	Raw data starting at the IPv4 payload
                        	**type**\:  :py:class:`Payload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Section.Payload>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv4.Section, self).__init__()

                            self.yang_name = "section"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("header", ("header", Native.Flow.Record.Match.Ipv4.Section.Header)), ("payload", ("payload", Native.Flow.Record.Match.Ipv4.Section.Payload))])
                            self._leafs = OrderedDict()

                            self.header = Native.Flow.Record.Match.Ipv4.Section.Header()
                            self.header.parent = self
                            self._children_name_map["header"] = "header"

                            self.payload = Native.Flow.Record.Match.Ipv4.Section.Payload()
                            self.payload.parent = self
                            self._children_name_map["payload"] = "payload"
                            self._segment_path = lambda: "section"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv4.Section, [], name, value)


                        class Header(Entity):
                            """
                            Raw data starting at the IPv4 header
                            
                            .. attribute:: size
                            
                            	Specify the number of bytes to capture
                            	**type**\: int
                            
                            	**range:** 1..1200
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv4.Section.Header, self).__init__()

                                self.yang_name = "header"
                                self.yang_parent_name = "section"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                ])
                                self.size = None
                                self._segment_path = lambda: "header"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv4.Section.Header, ['size'], name, value)


                        class Payload(Entity):
                            """
                            Raw data starting at the IPv4 payload
                            
                            .. attribute:: size
                            
                            	Specify the number of bytes to capture
                            	**type**\: int
                            
                            	**range:** 1..1200
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv4.Section.Payload, self).__init__()

                                self.yang_name = "payload"
                                self.yang_parent_name = "section"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                ])
                                self.size = None
                                self._segment_path = lambda: "payload"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv4.Section.Payload, ['size'], name, value)


                    class Source(Entity):
                        """
                        IPv4 source address based fields
                        
                        .. attribute:: address
                        
                        	IPv4 source address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mask
                        
                        	IPv4 address mask for the IPv4 source address
                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Source.Mask>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix
                        
                        	IPv4 address prefix for the IPv4 source address
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv4.Source.Prefix>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv4.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Match.Ipv4.Source.Mask)), ("prefix", ("prefix", Native.Flow.Record.Match.Ipv4.Source.Prefix))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                            ])
                            self.address = None

                            self.mask = None
                            self._children_name_map["mask"] = "mask"

                            self.prefix = None
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv4.Source, ['address'], name, value)


                        class Mask(Entity):
                            """
                            IPv4 address mask for the IPv4 source address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..32
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv4.Source.Mask, self).__init__()

                                self.yang_name = "mask"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "mask"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv4.Source.Mask, ['minimum_mask'], name, value)


                        class Prefix(Entity):
                            """
                            IPv4 address prefix for the IPv4 source address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..32
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv4.Source.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv4.Source.Prefix, ['minimum_mask'], name, value)


                    class TotalLength(Entity):
                        """
                        IPv4 total length
                        
                        .. attribute:: maximum
                        
                        	Largest value for IPv4 length seen in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: minimum
                        
                        	Smallest value for IPv4 length seen in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv4.TotalLength, self).__init__()

                            self.yang_name = "total-length"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                            ])
                            self.maximum = None
                            self.minimum = None
                            self._segment_path = lambda: "total-length"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv4.TotalLength, ['maximum', 'minimum'], name, value)


                    class Ttl(Entity):
                        """
                        IPv4 TTL
                        
                        .. attribute:: maximum
                        
                        	Largest value seen for TTL in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: minimum
                        
                        	Smallest value seen for TTL in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv4.Ttl, self).__init__()

                            self.yang_name = "ttl"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                            ])
                            self.maximum = None
                            self.minimum = None
                            self._segment_path = lambda: "ttl"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv4.Ttl, ['maximum', 'minimum'], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 fields
                    
                    .. attribute:: destination
                    
                    	IPv6 destination address based fields
                    	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Destination>`
                    
                    .. attribute:: dscp
                    
                    	IPv6 DSCP (part of Traffic Class)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: extension
                    
                    	IPv6 extension header fields
                    	**type**\:  :py:class:`Extension <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Extension>`
                    
                    .. attribute:: flow_label
                    
                    	IPv6 flow label
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: fragmentation
                    
                    	IPv6 fragmentation fields
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Fragmentation>`
                    
                    .. attribute:: hop_limit
                    
                    	IPv6 hop limit
                    	**type**\:  :py:class:`HopLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.HopLimit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: length
                    
                    	IPv6 length fields
                    	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Length>`
                    
                    .. attribute:: next_header
                    
                    	The value of the next\-header field in the IPv6 header
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: payload_length
                    
                    	Length of the IPv6 payload in bytes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: precedence
                    
                    	IPv6 precedence (part of Traffic Class)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: protocol
                    
                    	IPv6 payload protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: section
                    
                    	Part of the packet
                    	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Section>`
                    
                    .. attribute:: source
                    
                    	IPv6 source address based fields
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Source>`
                    
                    .. attribute:: traffic_class
                    
                    	IPv6 traffic class
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: version
                    
                    	IP version from IPv6 header
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Match.Ipv6.Destination)), ("extension", ("extension", Native.Flow.Record.Match.Ipv6.Extension)), ("fragmentation", ("fragmentation", Native.Flow.Record.Match.Ipv6.Fragmentation)), ("hop-limit", ("hop_limit", Native.Flow.Record.Match.Ipv6.HopLimit)), ("length", ("length", Native.Flow.Record.Match.Ipv6.Length)), ("section", ("section", Native.Flow.Record.Match.Ipv6.Section)), ("source", ("source", Native.Flow.Record.Match.Ipv6.Source))])
                        self._leafs = OrderedDict([
                            ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ('flow_label', (YLeaf(YType.empty, 'flow-label'), ['Empty'])),
                            ('next_header', (YLeaf(YType.empty, 'next-header'), ['Empty'])),
                            ('payload_length', (YLeaf(YType.empty, 'payload-length'), ['Empty'])),
                            ('precedence', (YLeaf(YType.empty, 'precedence'), ['Empty'])),
                            ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                            ('traffic_class', (YLeaf(YType.empty, 'traffic-class'), ['Empty'])),
                            ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                        ])
                        self.dscp = None
                        self.flow_label = None
                        self.next_header = None
                        self.payload_length = None
                        self.precedence = None
                        self.protocol = None
                        self.traffic_class = None
                        self.version = None

                        self.destination = Native.Flow.Record.Match.Ipv6.Destination()
                        self.destination.parent = self
                        self._children_name_map["destination"] = "destination"

                        self.extension = Native.Flow.Record.Match.Ipv6.Extension()
                        self.extension.parent = self
                        self._children_name_map["extension"] = "extension"

                        self.fragmentation = Native.Flow.Record.Match.Ipv6.Fragmentation()
                        self.fragmentation.parent = self
                        self._children_name_map["fragmentation"] = "fragmentation"

                        self.hop_limit = None
                        self._children_name_map["hop_limit"] = "hop-limit"

                        self.length = Native.Flow.Record.Match.Ipv6.Length()
                        self.length.parent = self
                        self._children_name_map["length"] = "length"

                        self.section = Native.Flow.Record.Match.Ipv6.Section()
                        self.section.parent = self
                        self._children_name_map["section"] = "section"

                        self.source = Native.Flow.Record.Match.Ipv6.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Ipv6, ['dscp', 'flow_label', 'next_header', 'payload_length', 'precedence', 'protocol', 'traffic_class', 'version'], name, value)


                    class Destination(Entity):
                        """
                        IPv6 destination address based fields
                        
                        .. attribute:: address
                        
                        	IPv6 destination address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mask
                        
                        	IPv6 address mask for the IPv6 destination address
                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Destination.Mask>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix
                        
                        	IPv6 address prefix for the IPv6 destination address
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Destination.Prefix>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv6.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Match.Ipv6.Destination.Mask)), ("prefix", ("prefix", Native.Flow.Record.Match.Ipv6.Destination.Prefix))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                            ])
                            self.address = None

                            self.mask = None
                            self._children_name_map["mask"] = "mask"

                            self.prefix = None
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "destination"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv6.Destination, ['address'], name, value)


                        class Mask(Entity):
                            """
                            IPv6 address mask for the IPv6 destination address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..128
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv6.Destination.Mask, self).__init__()

                                self.yang_name = "mask"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "mask"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv6.Destination.Mask, ['minimum_mask'], name, value)


                        class Prefix(Entity):
                            """
                            IPv6 address prefix for the IPv6 destination address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..128
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv6.Destination.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv6.Destination.Prefix, ['minimum_mask'], name, value)


                    class Extension(Entity):
                        """
                        IPv6 extension header fields
                        
                        .. attribute:: map
                        
                        	Bitmap of IPv6 extension headers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv6.Extension, self).__init__()

                            self.yang_name = "extension"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('map', (YLeaf(YType.empty, 'map'), ['Empty'])),
                            ])
                            self.map = None
                            self._segment_path = lambda: "extension"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv6.Extension, ['map'], name, value)


                    class Fragmentation(Entity):
                        """
                        IPv6 fragmentation fields
                        
                        .. attribute:: flags
                        
                        	IPv6 fragmentation flags
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: id
                        
                        	IPv6 fragmentation ID
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: offset
                        
                        	IPv6 fragmentation offset
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv6.Fragmentation, self).__init__()

                            self.yang_name = "fragmentation"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('flags', (YLeaf(YType.empty, 'flags'), ['Empty'])),
                                ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                                ('offset', (YLeaf(YType.empty, 'offset'), ['Empty'])),
                            ])
                            self.flags = None
                            self.id = None
                            self.offset = None
                            self._segment_path = lambda: "fragmentation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv6.Fragmentation, ['flags', 'id', 'offset'], name, value)


                    class HopLimit(Entity):
                        """
                        IPv6 hop limit
                        
                        .. attribute:: maximum
                        
                        	Largest value seen for hop\-limit in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: minimum
                        
                        	Smallest value seen for hop\-limit in the flow
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv6.HopLimit, self).__init__()

                            self.yang_name = "hop-limit"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                            ])
                            self.maximum = None
                            self.minimum = None
                            self._segment_path = lambda: "hop-limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv6.HopLimit, ['maximum', 'minimum'], name, value)


                    class Length(Entity):
                        """
                        IPv6 length fields
                        
                        .. attribute:: header
                        
                        	Length of the IPv6 header, not including any extension headers, in bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: payload
                        
                        	Length of the IPv6 payload, including any extension headers, in bytes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: total
                        
                        	Total length of the IPv6 header and payload in bytes
                        	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Length.Total>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv6.Length, self).__init__()

                            self.yang_name = "length"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("total", ("total", Native.Flow.Record.Match.Ipv6.Length.Total))])
                            self._leafs = OrderedDict([
                                ('header', (YLeaf(YType.empty, 'header'), ['Empty'])),
                                ('payload', (YLeaf(YType.empty, 'payload'), ['Empty'])),
                            ])
                            self.header = None
                            self.payload = None

                            self.total = None
                            self._children_name_map["total"] = "total"
                            self._segment_path = lambda: "length"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv6.Length, ['header', 'payload'], name, value)


                        class Total(Entity):
                            """
                            Total length of the IPv6 header and payload in bytes
                            
                            .. attribute:: maximum
                            
                            	Maximum total length in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	Minimum total length in bytes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv6.Length.Total, self).__init__()

                                self.yang_name = "total"
                                self.yang_parent_name = "length"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self._segment_path = lambda: "total"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv6.Length.Total, ['maximum', 'minimum'], name, value)


                    class Section(Entity):
                        """
                        Part of the packet
                        
                        .. attribute:: header
                        
                        	Raw data starting at the IPv6 header
                        	**type**\:  :py:class:`Header <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Section.Header>`
                        
                        .. attribute:: payload
                        
                        	Raw data starting at the IPv6 payload
                        	**type**\:  :py:class:`Payload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Section.Payload>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv6.Section, self).__init__()

                            self.yang_name = "section"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("header", ("header", Native.Flow.Record.Match.Ipv6.Section.Header)), ("payload", ("payload", Native.Flow.Record.Match.Ipv6.Section.Payload))])
                            self._leafs = OrderedDict()

                            self.header = Native.Flow.Record.Match.Ipv6.Section.Header()
                            self.header.parent = self
                            self._children_name_map["header"] = "header"

                            self.payload = Native.Flow.Record.Match.Ipv6.Section.Payload()
                            self.payload.parent = self
                            self._children_name_map["payload"] = "payload"
                            self._segment_path = lambda: "section"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv6.Section, [], name, value)


                        class Header(Entity):
                            """
                            Raw data starting at the IPv6 header
                            
                            .. attribute:: size
                            
                            	Specify the number of bytes to capture
                            	**type**\: int
                            
                            	**range:** 1..1200
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv6.Section.Header, self).__init__()

                                self.yang_name = "header"
                                self.yang_parent_name = "section"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                ])
                                self.size = None
                                self._segment_path = lambda: "header"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv6.Section.Header, ['size'], name, value)


                        class Payload(Entity):
                            """
                            Raw data starting at the IPv6 payload
                            
                            .. attribute:: size
                            
                            	Specify the number of bytes to capture
                            	**type**\: int
                            
                            	**range:** 1..1200
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv6.Section.Payload, self).__init__()

                                self.yang_name = "payload"
                                self.yang_parent_name = "section"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                ])
                                self.size = None
                                self._segment_path = lambda: "payload"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv6.Section.Payload, ['size'], name, value)


                    class Source(Entity):
                        """
                        IPv6 source address based fields
                        
                        .. attribute:: address
                        
                        	IPv6 source address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mask
                        
                        	IPv6 address mask for the IPv6 source address
                        	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Source.Mask>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix
                        
                        	IPv6 address prefix for the IPv6 source address
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Ipv6.Source.Prefix>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Ipv6.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Match.Ipv6.Source.Mask)), ("prefix", ("prefix", Native.Flow.Record.Match.Ipv6.Source.Prefix))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                            ])
                            self.address = None

                            self.mask = None
                            self._children_name_map["mask"] = "mask"

                            self.prefix = None
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Ipv6.Source, ['address'], name, value)


                        class Mask(Entity):
                            """
                            IPv6 address mask for the IPv6 source address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..128
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv6.Source.Mask, self).__init__()

                                self.yang_name = "mask"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "mask"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv6.Source.Mask, ['minimum_mask'], name, value)


                        class Prefix(Entity):
                            """
                            IPv6 address prefix for the IPv6 source address
                            
                            .. attribute:: minimum_mask
                            
                            	Provide a minimum mask for this field
                            	**type**\: int
                            
                            	**range:** 1..128
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Ipv6.Source.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_mask', (YLeaf(YType.uint8, 'minimum-mask'), ['int'])),
                                ])
                                self.minimum_mask = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Ipv6.Source.Prefix, ['minimum_mask'], name, value)


                class Metadata(Entity):
                    """
                    Metadata fields
                    
                    .. attribute:: global_session_id
                    
                    	Metadata global\-session\-id
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_party_session_id
                    
                    	Metadata multi\-party\-session\-id
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Metadata, self).__init__()

                        self.yang_name = "metadata"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('global_session_id', (YLeaf(YType.empty, 'global-session-id'), ['Empty'])),
                            ('multi_party_session_id', (YLeaf(YType.empty, 'multi-party-session-id'), ['Empty'])),
                        ])
                        self.global_session_id = None
                        self.multi_party_session_id = None
                        self._segment_path = lambda: "metadata"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Metadata, ['global_session_id', 'multi_party_session_id'], name, value)


                class Mpls(Entity):
                    """
                    MPLS fields
                    
                    .. attribute:: label
                    
                    	MPLS label details
                    	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Mpls.Label>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("label", ("label", Native.Flow.Record.Match.Mpls.Label))])
                        self._leafs = OrderedDict()

                        self.label = Native.Flow.Record.Match.Mpls.Label()
                        self.label.parent = self
                        self._children_name_map["label"] = "label"
                        self._segment_path = lambda: "mpls"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Mpls, [], name, value)


                    class Label(Entity):
                        """
                        MPLS label details
                        
                        .. attribute:: one
                        
                        	MPLS label 1 information
                        	**type**\:  :py:class:`One <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Mpls.Label.One>`
                        
                        .. attribute:: two
                        
                        	MPLS label 2 information
                        	**type**\:  :py:class:`Two <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Mpls.Label.Two>`
                        
                        .. attribute:: three
                        
                        	MPLS label 3 information
                        	**type**\:  :py:class:`Three <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Mpls.Label.Three>`
                        
                        .. attribute:: four
                        
                        	MPLS label 4 information
                        	**type**\:  :py:class:`Four <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Mpls.Label.Four>`
                        
                        .. attribute:: five
                        
                        	MPLS label 5 information
                        	**type**\:  :py:class:`Five <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Mpls.Label.Five>`
                        
                        .. attribute:: six
                        
                        	MPLS label 6 information
                        	**type**\:  :py:class:`Six <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Mpls.Label.Six>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Mpls.Label, self).__init__()

                            self.yang_name = "label"
                            self.yang_parent_name = "mpls"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("one", ("one", Native.Flow.Record.Match.Mpls.Label.One)), ("two", ("two", Native.Flow.Record.Match.Mpls.Label.Two)), ("three", ("three", Native.Flow.Record.Match.Mpls.Label.Three)), ("four", ("four", Native.Flow.Record.Match.Mpls.Label.Four)), ("five", ("five", Native.Flow.Record.Match.Mpls.Label.Five)), ("six", ("six", Native.Flow.Record.Match.Mpls.Label.Six))])
                            self._leafs = OrderedDict()

                            self.one = Native.Flow.Record.Match.Mpls.Label.One()
                            self.one.parent = self
                            self._children_name_map["one"] = "one"

                            self.two = Native.Flow.Record.Match.Mpls.Label.Two()
                            self.two.parent = self
                            self._children_name_map["two"] = "two"

                            self.three = Native.Flow.Record.Match.Mpls.Label.Three()
                            self.three.parent = self
                            self._children_name_map["three"] = "three"

                            self.four = Native.Flow.Record.Match.Mpls.Label.Four()
                            self.four.parent = self
                            self._children_name_map["four"] = "four"

                            self.five = Native.Flow.Record.Match.Mpls.Label.Five()
                            self.five.parent = self
                            self._children_name_map["five"] = "five"

                            self.six = Native.Flow.Record.Match.Mpls.Label.Six()
                            self.six.parent = self
                            self._children_name_map["six"] = "six"
                            self._segment_path = lambda: "label"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Mpls.Label, [], name, value)


                        class One(Entity):
                            """
                            MPLS label 1 information
                            
                            .. attribute:: details
                            
                            	MPLS label 1 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: exp
                            
                            	MPLS EXP field from the last label that was pushed
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ttl
                            
                            	MPLS TTL field from the last label that was pushed
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: type
                            
                            	MPLS label type of the last label that was pushed
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Mpls.Label.One, self).__init__()

                                self.yang_name = "one"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                    ('exp', (YLeaf(YType.empty, 'exp'), ['Empty'])),
                                    ('ttl', (YLeaf(YType.empty, 'ttl'), ['Empty'])),
                                    ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                ])
                                self.details = None
                                self.exp = None
                                self.ttl = None
                                self.type = None
                                self._segment_path = lambda: "one"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Mpls.Label.One, ['details', 'exp', 'ttl', 'type'], name, value)


                        class Two(Entity):
                            """
                            MPLS label 2 information
                            
                            .. attribute:: details
                            
                            	MPLS label 2 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Mpls.Label.Two, self).__init__()

                                self.yang_name = "two"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                ])
                                self.details = None
                                self._segment_path = lambda: "two"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Mpls.Label.Two, ['details'], name, value)


                        class Three(Entity):
                            """
                            MPLS label 3 information
                            
                            .. attribute:: details
                            
                            	MPLS label 3 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Mpls.Label.Three, self).__init__()

                                self.yang_name = "three"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                ])
                                self.details = None
                                self._segment_path = lambda: "three"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Mpls.Label.Three, ['details'], name, value)


                        class Four(Entity):
                            """
                            MPLS label 4 information
                            
                            .. attribute:: details
                            
                            	MPLS label 4 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Mpls.Label.Four, self).__init__()

                                self.yang_name = "four"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                ])
                                self.details = None
                                self._segment_path = lambda: "four"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Mpls.Label.Four, ['details'], name, value)


                        class Five(Entity):
                            """
                            MPLS label 5 information
                            
                            .. attribute:: details
                            
                            	MPLS label 5 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Mpls.Label.Five, self).__init__()

                                self.yang_name = "five"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                ])
                                self.details = None
                                self._segment_path = lambda: "five"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Mpls.Label.Five, ['details'], name, value)


                        class Six(Entity):
                            """
                            MPLS label 6 information
                            
                            .. attribute:: details
                            
                            	MPLS label 6 details
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Mpls.Label.Six, self).__init__()

                                self.yang_name = "six"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('details', (YLeaf(YType.empty, 'details'), ['Empty'])),
                                ])
                                self.details = None
                                self._segment_path = lambda: "six"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Mpls.Label.Six, ['details'], name, value)


                class Network(Entity):
                    """
                    network metrics
                    
                    .. attribute:: delay
                    
                    	network delay metrics
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Network.Delay>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("delay", ("delay", Native.Flow.Record.Match.Network.Delay))])
                        self._leafs = OrderedDict()

                        self.delay = Native.Flow.Record.Match.Network.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Network, [], name, value)


                    class Delay(Entity):
                        """
                        network delay metrics
                        
                        .. attribute:: sample
                        
                        	The number of samples of roundtrip delay
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: sum
                        
                        	The sum of roundtrip delay
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Network.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sample', (YLeaf(YType.empty, 'sample'), ['Empty'])),
                                ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                            ])
                            self.sample = None
                            self.sum = None
                            self._segment_path = lambda: "delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Network.Delay, ['sample', 'sum'], name, value)


                class Pfr(Entity):
                    """
                    PfR metrics
                    
                    .. attribute:: label
                    
                    	PfR label metrics
                    	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.Label>`
                    
                    .. attribute:: one_way_delay
                    
                    	The packet transmission delay between specified nodes
                    	**type**\:  :py:class:`OneWayDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.OneWayDelay>`
                    
                    .. attribute:: service
                    
                    	PfR service metrics
                    	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.Service>`
                    
                    .. attribute:: site
                    
                    	PfR site  metrics
                    	**type**\:  :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.Site>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Pfr, self).__init__()

                        self.yang_name = "pfr"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("label", ("label", Native.Flow.Record.Match.Pfr.Label)), ("one-way-delay", ("one_way_delay", Native.Flow.Record.Match.Pfr.OneWayDelay)), ("service", ("service", Native.Flow.Record.Match.Pfr.Service)), ("site", ("site", Native.Flow.Record.Match.Pfr.Site))])
                        self._leafs = OrderedDict()

                        self.label = Native.Flow.Record.Match.Pfr.Label()
                        self.label.parent = self
                        self._children_name_map["label"] = "label"

                        self.one_way_delay = Native.Flow.Record.Match.Pfr.OneWayDelay()
                        self.one_way_delay.parent = self
                        self._children_name_map["one_way_delay"] = "one-way-delay"

                        self.service = Native.Flow.Record.Match.Pfr.Service()
                        self.service.parent = self
                        self._children_name_map["service"] = "service"

                        self.site = Native.Flow.Record.Match.Pfr.Site()
                        self.site.parent = self
                        self._children_name_map["site"] = "site"
                        self._segment_path = lambda: "pfr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Pfr, [], name, value)


                    class Label(Entity):
                        """
                        PfR label metrics
                        
                        .. attribute:: identifier
                        
                        	pfr label id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Pfr.Label, self).__init__()

                            self.yang_name = "label"
                            self.yang_parent_name = "pfr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('identifier', (YLeaf(YType.empty, 'identifier'), ['Empty'])),
                            ])
                            self.identifier = None
                            self._segment_path = lambda: "label"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Pfr.Label, ['identifier'], name, value)


                    class OneWayDelay(Entity):
                        """
                        The packet transmission delay between specified nodes
                        
                        .. attribute:: samples
                        
                        	Total number of one\-way\-delay samples
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: sum
                        
                        	The packet transmission delay sum between specified nodes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Pfr.OneWayDelay, self).__init__()

                            self.yang_name = "one-way-delay"
                            self.yang_parent_name = "pfr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('samples', (YLeaf(YType.empty, 'samples'), ['Empty'])),
                                ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                            ])
                            self.samples = None
                            self.sum = None
                            self._segment_path = lambda: "one-way-delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Pfr.OneWayDelay, ['samples', 'sum'], name, value)


                    class Service(Entity):
                        """
                        PfR service metrics
                        
                        .. attribute:: provider
                        
                        	PfR service provider metrics
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tag
                        
                        	PfR service provider tag metrics
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: identifier
                        
                        	PfR service provider tag
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Pfr.Service, self).__init__()

                            self.yang_name = "service"
                            self.yang_parent_name = "pfr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('provider', (YLeaf(YType.empty, 'provider'), ['Empty'])),
                                ('tag', (YLeaf(YType.empty, 'tag'), ['Empty'])),
                                ('identifier', (YLeaf(YType.empty, 'identifier'), ['Empty'])),
                            ])
                            self.provider = None
                            self.tag = None
                            self.identifier = None
                            self._segment_path = lambda: "service"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Pfr.Service, ['provider', 'tag', 'identifier'], name, value)


                    class Site(Entity):
                        """
                        PfR site  metrics
                        
                        .. attribute:: destination
                        
                        	PfR site destination metrics
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.Site.Destination>`
                        
                        .. attribute:: source
                        
                        	PfR site source metrics
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.Site.Source>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Pfr.Site, self).__init__()

                            self.yang_name = "site"
                            self.yang_parent_name = "pfr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Match.Pfr.Site.Destination)), ("source", ("source", Native.Flow.Record.Match.Pfr.Site.Source))])
                            self._leafs = OrderedDict()

                            self.destination = Native.Flow.Record.Match.Pfr.Site.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.source = Native.Flow.Record.Match.Pfr.Site.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "site"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Pfr.Site, [], name, value)


                        class Destination(Entity):
                            """
                            PfR site destination metrics
                            
                            .. attribute:: id
                            
                            	PfR site destination ID metrics
                            	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.Site.Destination.Id>`
                            
                            .. attribute:: prefix
                            
                            	PfR site prefix of the packet destination
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.Site.Destination.Prefix>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Pfr.Site.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "site"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("id", ("id", Native.Flow.Record.Match.Pfr.Site.Destination.Id)), ("prefix", ("prefix", Native.Flow.Record.Match.Pfr.Site.Destination.Prefix))])
                                self._leafs = OrderedDict()

                                self.id = Native.Flow.Record.Match.Pfr.Site.Destination.Id()
                                self.id.parent = self
                                self._children_name_map["id"] = "id"

                                self.prefix = Native.Flow.Record.Match.Pfr.Site.Destination.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Pfr.Site.Destination, [], name, value)


                            class Id(Entity):
                                """
                                PfR site destination ID metrics
                                
                                .. attribute:: ipv4
                                
                                	site ID of the packet destination
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Pfr.Site.Destination.Id, self).__init__()

                                    self.yang_name = "id"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ])
                                    self.ipv4 = None
                                    self._segment_path = lambda: "id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Pfr.Site.Destination.Id, ['ipv4'], name, value)


                            class Prefix(Entity):
                                """
                                PfR site prefix of the packet destination
                                
                                .. attribute:: ipv4
                                
                                	site prefix of the packet destination
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: mask
                                
                                	PfR site prefix mask of the packet destination
                                	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.Site.Destination.Prefix.Mask>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Pfr.Site.Destination.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "destination"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Match.Pfr.Site.Destination.Prefix.Mask))])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ])
                                    self.ipv4 = None

                                    self.mask = Native.Flow.Record.Match.Pfr.Site.Destination.Prefix.Mask()
                                    self.mask.parent = self
                                    self._children_name_map["mask"] = "mask"
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Pfr.Site.Destination.Prefix, ['ipv4'], name, value)


                                class Mask(Entity):
                                    """
                                    PfR site prefix mask of the packet destination
                                    
                                    .. attribute:: ipv4
                                    
                                    	site prefix mask of the packet destination
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Match.Pfr.Site.Destination.Prefix.Mask, self).__init__()

                                        self.yang_name = "mask"
                                        self.yang_parent_name = "prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "mask"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Match.Pfr.Site.Destination.Prefix.Mask, ['ipv4'], name, value)


                        class Source(Entity):
                            """
                            PfR site source metrics
                            
                            .. attribute:: id
                            
                            	PfR site source ID metrics
                            	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.Site.Source.Id>`
                            
                            .. attribute:: prefix
                            
                            	PfR site prefix of the packet source
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.Site.Source.Prefix>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Pfr.Site.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "site"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("id", ("id", Native.Flow.Record.Match.Pfr.Site.Source.Id)), ("prefix", ("prefix", Native.Flow.Record.Match.Pfr.Site.Source.Prefix))])
                                self._leafs = OrderedDict()

                                self.id = Native.Flow.Record.Match.Pfr.Site.Source.Id()
                                self.id.parent = self
                                self._children_name_map["id"] = "id"

                                self.prefix = Native.Flow.Record.Match.Pfr.Site.Source.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Pfr.Site.Source, [], name, value)


                            class Id(Entity):
                                """
                                PfR site source ID metrics
                                
                                .. attribute:: ipv4
                                
                                	site ID of the packet source
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Pfr.Site.Source.Id, self).__init__()

                                    self.yang_name = "id"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ])
                                    self.ipv4 = None
                                    self._segment_path = lambda: "id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Pfr.Site.Source.Id, ['ipv4'], name, value)


                            class Prefix(Entity):
                                """
                                PfR site prefix of the packet source
                                
                                .. attribute:: ipv4
                                
                                	site prefix of the packet source
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: mask
                                
                                	PfR site prefix mask of the packet source
                                	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Pfr.Site.Source.Prefix.Mask>`
                                
                                

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Pfr.Site.Source.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mask", ("mask", Native.Flow.Record.Match.Pfr.Site.Source.Prefix.Mask))])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ])
                                    self.ipv4 = None

                                    self.mask = Native.Flow.Record.Match.Pfr.Site.Source.Prefix.Mask()
                                    self.mask.parent = self
                                    self._children_name_map["mask"] = "mask"
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Pfr.Site.Source.Prefix, ['ipv4'], name, value)


                                class Mask(Entity):
                                    """
                                    PfR site prefix mask of the packet source
                                    
                                    .. attribute:: ipv4
                                    
                                    	site prefix mask of the packet source
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-flow'
                                    _revision = '2018-01-04'

                                    def __init__(self):
                                        super(Native.Flow.Record.Match.Pfr.Site.Source.Prefix.Mask, self).__init__()

                                        self.yang_name = "mask"
                                        self.yang_parent_name = "prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "mask"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Flow.Record.Match.Pfr.Site.Source.Prefix.Mask, ['ipv4'], name, value)


                class Policy(Entity):
                    """
                    policy fields
                    
                    .. attribute:: performance_monitor
                    
                    	Performance\-monitor policy related metrics
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Policy.PerformanceMonitor>`
                    
                    .. attribute:: qos
                    
                    	QoS policy related metrics
                    	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Policy.Qos>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("performance-monitor", ("performance_monitor", Native.Flow.Record.Match.Policy.PerformanceMonitor)), ("qos", ("qos", Native.Flow.Record.Match.Policy.Qos))])
                        self._leafs = OrderedDict()

                        self.performance_monitor = Native.Flow.Record.Match.Policy.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.qos = Native.Flow.Record.Match.Policy.Qos()
                        self.qos.parent = self
                        self._children_name_map["qos"] = "qos"
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Policy, [], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Performance\-monitor policy related metrics
                        
                        .. attribute:: classification
                        
                        	Classification metrics
                        	**type**\:  :py:class:`Classification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Policy.PerformanceMonitor.Classification>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Policy.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("classification", ("classification", Native.Flow.Record.Match.Policy.PerformanceMonitor.Classification))])
                            self._leafs = OrderedDict()

                            self.classification = Native.Flow.Record.Match.Policy.PerformanceMonitor.Classification()
                            self.classification.parent = self
                            self._children_name_map["classification"] = "classification"
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Policy.PerformanceMonitor, [], name, value)


                        class Classification(Entity):
                            """
                            Classification metrics
                            
                            .. attribute:: hierarchy
                            
                            	Performance\-monitor class hierarchy
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Policy.PerformanceMonitor.Classification, self).__init__()

                                self.yang_name = "classification"
                                self.yang_parent_name = "performance-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hierarchy', (YLeaf(YType.empty, 'hierarchy'), ['Empty'])),
                                ])
                                self.hierarchy = None
                                self._segment_path = lambda: "classification"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Policy.PerformanceMonitor.Classification, ['hierarchy'], name, value)


                    class Qos(Entity):
                        """
                        QoS policy related metrics
                        
                        .. attribute:: classification
                        
                        	Classification metrics
                        	**type**\:  :py:class:`Classification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Policy.Qos.Classification>`
                        
                        .. attribute:: queue
                        
                        	Queue metrics
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Policy.Qos.Queue>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Policy.Qos, self).__init__()

                            self.yang_name = "qos"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("classification", ("classification", Native.Flow.Record.Match.Policy.Qos.Classification)), ("queue", ("queue", Native.Flow.Record.Match.Policy.Qos.Queue))])
                            self._leafs = OrderedDict()

                            self.classification = Native.Flow.Record.Match.Policy.Qos.Classification()
                            self.classification.parent = self
                            self._children_name_map["classification"] = "classification"

                            self.queue = Native.Flow.Record.Match.Policy.Qos.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "qos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Policy.Qos, [], name, value)


                        class Classification(Entity):
                            """
                            Classification metrics
                            
                            .. attribute:: hierarchy
                            
                            	QoS class hierarchy
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Policy.Qos.Classification, self).__init__()

                                self.yang_name = "classification"
                                self.yang_parent_name = "qos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hierarchy', (YLeaf(YType.empty, 'hierarchy'), ['Empty'])),
                                ])
                                self.hierarchy = None
                                self._segment_path = lambda: "classification"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Policy.Qos.Classification, ['hierarchy'], name, value)


                        class Queue(Entity):
                            """
                            Queue metrics
                            
                            .. attribute:: drops
                            
                            	QoS queue drops
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: index
                            
                            	QoS queue index
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Policy.Qos.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "qos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('drops', (YLeaf(YType.empty, 'drops'), ['Empty'])),
                                    ('index', (YLeaf(YType.empty, 'index'), ['Empty'])),
                                ])
                                self.drops = None
                                self.index = None
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Policy.Qos.Queue, ['drops', 'index'], name, value)


                class Routing(Entity):
                    """
                    Routing attributes
                    
                    .. attribute:: destination
                    
                    	Destination routing attributes
                    	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.Destination>`
                    
                    .. attribute:: forwarding_status
                    
                    	Forwarding status of the packet
                    	**type**\:  :py:class:`ForwardingStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.ForwardingStatus>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: is_multicast
                    
                    	Indicates if this is multicast
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: next_hop
                    
                    	Information regarding the next hop
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.NextHop>`
                    
                    .. attribute:: pw
                    
                    	Pseudowire fields
                    	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.Pw>`
                    
                    .. attribute:: source
                    
                    	Source routing attributes
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.Source>`
                    
                    .. attribute:: vrf
                    
                    	VRF routing attributes
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Routing, self).__init__()

                        self.yang_name = "routing"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Match.Routing.Destination)), ("forwarding-status", ("forwarding_status", Native.Flow.Record.Match.Routing.ForwardingStatus)), ("next-hop", ("next_hop", Native.Flow.Record.Match.Routing.NextHop)), ("pw", ("pw", Native.Flow.Record.Match.Routing.Pw)), ("source", ("source", Native.Flow.Record.Match.Routing.Source)), ("vrf", ("vrf", Native.Flow.Record.Match.Routing.Vrf))])
                        self._leafs = OrderedDict([
                            ('is_multicast', (YLeaf(YType.empty, 'is-multicast'), ['Empty'])),
                        ])
                        self.is_multicast = None

                        self.destination = Native.Flow.Record.Match.Routing.Destination()
                        self.destination.parent = self
                        self._children_name_map["destination"] = "destination"

                        self.forwarding_status = None
                        self._children_name_map["forwarding_status"] = "forwarding-status"

                        self.next_hop = Native.Flow.Record.Match.Routing.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"

                        self.pw = Native.Flow.Record.Match.Routing.Pw()
                        self.pw.parent = self
                        self._children_name_map["pw"] = "pw"

                        self.source = Native.Flow.Record.Match.Routing.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"

                        self.vrf = Native.Flow.Record.Match.Routing.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "routing"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Routing, ['is_multicast'], name, value)


                    class Destination(Entity):
                        """
                        Destination routing attributes
                        
                        .. attribute:: as_
                        
                        	AS number of the destination network
                        	**type**\:  :py:class:`As <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.Destination.As>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: traffic_index
                        
                        	BGP destination traffic index
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Routing.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("as", ("as_", Native.Flow.Record.Match.Routing.Destination.As))])
                            self._leafs = OrderedDict([
                                ('traffic_index', (YLeaf(YType.empty, 'traffic-index'), ['Empty'])),
                            ])
                            self.traffic_index = None

                            self.as_ = None
                            self._children_name_map["as_"] = "as"
                            self._segment_path = lambda: "destination"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Routing.Destination, ['traffic_index'], name, value)


                        class As(Entity):
                            """
                            AS number of the destination network
                            
                            .. attribute:: as4_octet
                            
                            	4 octet AS number of the destination network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: peer
                            
                            	AS number of the peer network we will forward to
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.Destination.As.Peer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Routing.Destination.As, self).__init__()

                                self.yang_name = "as"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Flow.Record.Match.Routing.Destination.As.Peer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('as4_octet', (YLeaf(YType.empty, 'as4-octet'), ['Empty'])),
                                ])
                                self.as4_octet = None

                                self.peer = None
                                self._children_name_map["peer"] = "peer"
                                self._segment_path = lambda: "as"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Routing.Destination.As, ['as4_octet'], name, value)


                            class Peer(Entity):
                                """
                                AS number of the peer network we will forward to
                                
                                .. attribute:: peer4_octet
                                
                                	4 octet AS number of the peer network we will forward to
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Routing.Destination.As.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "as"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('peer4_octet', (YLeaf(YType.empty, 'peer4-octet'), ['Empty'])),
                                    ])
                                    self.peer4_octet = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Routing.Destination.As.Peer, ['peer4_octet'], name, value)


                    class ForwardingStatus(Entity):
                        """
                        Forwarding status of the packet
                        
                        .. attribute:: reason
                        
                        	Forwarding status reason of the packet
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Routing.ForwardingStatus, self).__init__()

                            self.yang_name = "forwarding-status"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('reason', (YLeaf(YType.empty, 'reason'), ['Empty'])),
                            ])
                            self.reason = None
                            self._segment_path = lambda: "forwarding-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Routing.ForwardingStatus, ['reason'], name, value)


                    class NextHop(Entity):
                        """
                        Information regarding the next hop
                        
                        .. attribute:: address
                        
                        	IP address of the next hop
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.NextHop.Address>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Routing.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Flow.Record.Match.Routing.NextHop.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Flow.Record.Match.Routing.NextHop.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Routing.NextHop, [], name, value)


                        class Address(Entity):
                            """
                            IP address of the next hop
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address of the next hop
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.NextHop.Address.Ipv4>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address of the next hop
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.NextHop.Address.Ipv6>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Routing.NextHop.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Match.Routing.NextHop.Address.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Match.Routing.NextHop.Address.Ipv6))])
                                self._leafs = OrderedDict()

                                self.ipv4 = None
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = None
                                self._children_name_map["ipv6"] = "ipv6"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Routing.NextHop.Address, [], name, value)


                            class Ipv4(Entity):
                                """
                                IPv4 address of the next hop
                                
                                .. attribute:: bgp
                                
                                	IPv4 address of the BGP next hop
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Routing.NextHop.Address.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                                    ])
                                    self.bgp = None
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Routing.NextHop.Address.Ipv4, ['bgp'], name, value)


                            class Ipv6(Entity):
                                """
                                IPv6 address of the next hop
                                
                                .. attribute:: bgp
                                
                                	IPv6 address of the BGP next hop
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Routing.NextHop.Address.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                                    ])
                                    self.bgp = None
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Routing.NextHop.Address.Ipv6, ['bgp'], name, value)


                    class Pw(Entity):
                        """
                        Pseudowire fields
                        
                        .. attribute:: destination
                        
                        	Pseudowire destination
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.Pw.Destination>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Routing.Pw, self).__init__()

                            self.yang_name = "pw"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Record.Match.Routing.Pw.Destination))])
                            self._leafs = OrderedDict()

                            self.destination = Native.Flow.Record.Match.Routing.Pw.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"
                            self._segment_path = lambda: "pw"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Routing.Pw, [], name, value)


                        class Destination(Entity):
                            """
                            Pseudowire destination
                            
                            .. attribute:: address
                            
                            	Pseudowire destination address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Routing.Pw.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "pw"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Routing.Pw.Destination, ['address'], name, value)


                    class Source(Entity):
                        """
                        Source routing attributes
                        
                        .. attribute:: as_
                        
                        	AS number of the original network
                        	**type**\:  :py:class:`As <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.Source.As>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: traffic_index
                        
                        	BGP source traffic index
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Routing.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("as", ("as_", Native.Flow.Record.Match.Routing.Source.As))])
                            self._leafs = OrderedDict([
                                ('traffic_index', (YLeaf(YType.empty, 'traffic-index'), ['Empty'])),
                            ])
                            self.traffic_index = None

                            self.as_ = None
                            self._children_name_map["as_"] = "as"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Routing.Source, ['traffic_index'], name, value)


                        class As(Entity):
                            """
                            AS number of the original network
                            
                            .. attribute:: as4_octet
                            
                            	4 octet AS number of the original network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: peer
                            
                            	AS number of the peer network where the packet came from
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Routing.Source.As.Peer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Routing.Source.As, self).__init__()

                                self.yang_name = "as"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Flow.Record.Match.Routing.Source.As.Peer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('as4_octet', (YLeaf(YType.empty, 'as4-octet'), ['Empty'])),
                                ])
                                self.as4_octet = None

                                self.peer = None
                                self._children_name_map["peer"] = "peer"
                                self._segment_path = lambda: "as"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Routing.Source.As, ['as4_octet'], name, value)


                            class Peer(Entity):
                                """
                                AS number of the peer network where the packet came from
                                
                                .. attribute:: peer4_octet
                                
                                	4 octet AS number of the peer network where the packet came from
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Routing.Source.As.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "as"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('peer4_octet', (YLeaf(YType.empty, 'peer4-octet'), ['Empty'])),
                                    ])
                                    self.peer4_octet = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Routing.Source.As.Peer, ['peer4_octet'], name, value)


                    class Vrf(Entity):
                        """
                        VRF routing attributes
                        
                        .. attribute:: input
                        
                        	VRF ID for incoming packet
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	VRF ID for outgoing packet
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Routing.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Routing.Vrf, ['input', 'output'], name, value)


                class Services(Entity):
                    """
                    Services fields
                    
                    .. attribute:: waas
                    
                    	WAAS (Wide Area Application Services) metrics
                    	**type**\:  :py:class:`Waas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Services.Waas>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Services, self).__init__()

                        self.yang_name = "services"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("waas", ("waas", Native.Flow.Record.Match.Services.Waas))])
                        self._leafs = OrderedDict()

                        self.waas = Native.Flow.Record.Match.Services.Waas()
                        self.waas.parent = self
                        self._children_name_map["waas"] = "waas"
                        self._segment_path = lambda: "services"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Services, [], name, value)


                    class Waas(Entity):
                        """
                        WAAS (Wide Area Application Services) metrics
                        
                        .. attribute:: passthrough_reason
                        
                        	WAAS passthrough reason
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: segment
                        
                        	WAAS optimization segment
                        	**type**\:  :py:class:`Segment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Services.Waas.Segment>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Services.Waas, self).__init__()

                            self.yang_name = "waas"
                            self.yang_parent_name = "services"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("segment", ("segment", Native.Flow.Record.Match.Services.Waas.Segment))])
                            self._leafs = OrderedDict([
                                ('passthrough_reason', (YLeaf(YType.empty, 'passthrough-reason'), ['Empty'])),
                            ])
                            self.passthrough_reason = None

                            self.segment = None
                            self._children_name_map["segment"] = "segment"
                            self._segment_path = lambda: "waas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Services.Waas, ['passthrough_reason'], name, value)


                        class Segment(Entity):
                            """
                            WAAS optimization segment
                            
                            .. attribute:: account_on_resolution
                            
                            	Account on resolution
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Services.Waas.Segment, self).__init__()

                                self.yang_name = "segment"
                                self.yang_parent_name = "waas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('account_on_resolution', (YLeaf(YType.empty, 'account-on-resolution'), ['Empty'])),
                                ])
                                self.account_on_resolution = None
                                self._segment_path = lambda: "segment"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Services.Waas.Segment, ['account_on_resolution'], name, value)


                class Timestamp(Entity):
                    """
                    Timestamp fields
                    
                    .. attribute:: absolute
                    
                    	Timestamps based on the epoch of 00\:00 UTC 1st Jan 1970
                    	**type**\:  :py:class:`Absolute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Timestamp.Absolute>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Timestamp, self).__init__()

                        self.yang_name = "timestamp"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("absolute", ("absolute", Native.Flow.Record.Match.Timestamp.Absolute))])
                        self._leafs = OrderedDict()

                        self.absolute = Native.Flow.Record.Match.Timestamp.Absolute()
                        self.absolute.parent = self
                        self._children_name_map["absolute"] = "absolute"
                        self._segment_path = lambda: "timestamp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Timestamp, [], name, value)


                    class Absolute(Entity):
                        """
                        Timestamps based on the epoch of 00\:00 UTC 1st Jan 1970
                        
                        .. attribute:: monitoring_interval
                        
                        	Monitoring interval timestamps
                        	**type**\:  :py:class:`MonitoringInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Timestamp.Absolute.MonitoringInterval>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Timestamp.Absolute, self).__init__()

                            self.yang_name = "absolute"
                            self.yang_parent_name = "timestamp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("monitoring-interval", ("monitoring_interval", Native.Flow.Record.Match.Timestamp.Absolute.MonitoringInterval))])
                            self._leafs = OrderedDict()

                            self.monitoring_interval = Native.Flow.Record.Match.Timestamp.Absolute.MonitoringInterval()
                            self.monitoring_interval.parent = self
                            self._children_name_map["monitoring_interval"] = "monitoring-interval"
                            self._segment_path = lambda: "absolute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Timestamp.Absolute, [], name, value)


                        class MonitoringInterval(Entity):
                            """
                            Monitoring interval timestamps
                            
                            .. attribute:: start
                            
                            	Absolute start time of a monitoring interval (milliseconds)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Timestamp.Absolute.MonitoringInterval, self).__init__()

                                self.yang_name = "monitoring-interval"
                                self.yang_parent_name = "absolute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('start', (YLeaf(YType.empty, 'start'), ['Empty'])),
                                ])
                                self.start = None
                                self._segment_path = lambda: "monitoring-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Timestamp.Absolute.MonitoringInterval, ['start'], name, value)


                class Transport(Entity):
                    """
                    Transport layer fields
                    
                    .. attribute:: bytes
                    
                    	Bytes fields
                    	**type**\:  :py:class:`Bytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Bytes>`
                    
                    .. attribute:: rtp
                    
                    	RTP fields
                    	**type**\:  :py:class:`Rtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Rtp>`
                    
                    .. attribute:: destination_port
                    
                    	Transport destination port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: icmp
                    
                    	ICMP fields
                    	**type**\:  :py:class:`Icmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Icmp>`
                    
                    .. attribute:: igmp
                    
                    	IGMP fields
                    	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Igmp>`
                    
                    .. attribute:: source_port
                    
                    	Transport source port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: tcp
                    
                    	TCP fields
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Tcp>`
                    
                    .. attribute:: udp
                    
                    	UDP fields
                    	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Udp>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Record.Match.Transport, self).__init__()

                        self.yang_name = "transport"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bytes", ("bytes", Native.Flow.Record.Match.Transport.Bytes)), ("rtp", ("rtp", Native.Flow.Record.Match.Transport.Rtp)), ("icmp", ("icmp", Native.Flow.Record.Match.Transport.Icmp)), ("igmp", ("igmp", Native.Flow.Record.Match.Transport.Igmp)), ("tcp", ("tcp", Native.Flow.Record.Match.Transport.Tcp)), ("udp", ("udp", Native.Flow.Record.Match.Transport.Udp))])
                        self._leafs = OrderedDict([
                            ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                            ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                        ])
                        self.destination_port = None
                        self.source_port = None

                        self.bytes = Native.Flow.Record.Match.Transport.Bytes()
                        self.bytes.parent = self
                        self._children_name_map["bytes"] = "bytes"

                        self.rtp = Native.Flow.Record.Match.Transport.Rtp()
                        self.rtp.parent = self
                        self._children_name_map["rtp"] = "rtp"

                        self.icmp = Native.Flow.Record.Match.Transport.Icmp()
                        self.icmp.parent = self
                        self._children_name_map["icmp"] = "icmp"

                        self.igmp = Native.Flow.Record.Match.Transport.Igmp()
                        self.igmp.parent = self
                        self._children_name_map["igmp"] = "igmp"

                        self.tcp = Native.Flow.Record.Match.Transport.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"

                        self.udp = Native.Flow.Record.Match.Transport.Udp()
                        self.udp.parent = self
                        self._children_name_map["udp"] = "udp"
                        self._segment_path = lambda: "transport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Record.Match.Transport, ['destination_port', 'source_port'], name, value)


                    class Bytes(Entity):
                        """
                        Bytes fields
                        
                        .. attribute:: expected
                        
                        	Transport bytes expected
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: lost
                        
                        	Transport bytes lost
                        	**type**\:  :py:class:`Lost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Bytes.Lost>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Transport.Bytes, self).__init__()

                            self.yang_name = "bytes"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lost", ("lost", Native.Flow.Record.Match.Transport.Bytes.Lost))])
                            self._leafs = OrderedDict([
                                ('expected', (YLeaf(YType.empty, 'expected'), ['Empty'])),
                            ])
                            self.expected = None

                            self.lost = None
                            self._children_name_map["lost"] = "lost"
                            self._segment_path = lambda: "bytes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Transport.Bytes, ['expected'], name, value)


                        class Lost(Entity):
                            """
                            Transport bytes lost
                            
                            .. attribute:: rate
                            
                            	Transport bytes lost rate
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Transport.Bytes.Lost, self).__init__()

                                self.yang_name = "lost"
                                self.yang_parent_name = "bytes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.empty, 'rate'), ['Empty'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "lost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Transport.Bytes.Lost, ['rate'], name, value)


                    class Rtp(Entity):
                        """
                        RTP fields
                        
                        .. attribute:: ssrc
                        
                        	RTP SSRC
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Transport.Rtp, self).__init__()

                            self.yang_name = "rtp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ssrc', (YLeaf(YType.empty, 'ssrc'), ['Empty'])),
                            ])
                            self.ssrc = None
                            self._segment_path = lambda: "rtp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Transport.Rtp, ['ssrc'], name, value)


                    class Icmp(Entity):
                        """
                        ICMP fields
                        
                        .. attribute:: ipv4
                        
                        	IPv4 ICMP fields
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Icmp.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	IPv6 ICMP fields
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Icmp.Ipv6>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Transport.Icmp, self).__init__()

                            self.yang_name = "icmp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Record.Match.Transport.Icmp.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Record.Match.Transport.Icmp.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = Native.Flow.Record.Match.Transport.Icmp.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = Native.Flow.Record.Match.Transport.Icmp.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "icmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Transport.Icmp, [], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 ICMP fields
                            
                            .. attribute:: code
                            
                            	IPv4 ICMP code
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: type
                            
                            	IPv4 ICMP type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Transport.Icmp.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "icmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('code', (YLeaf(YType.empty, 'code'), ['Empty'])),
                                    ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                ])
                                self.code = None
                                self.type = None
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Transport.Icmp.Ipv4, ['code', 'type'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 ICMP fields
                            
                            .. attribute:: code
                            
                            	IPv6 ICMP code
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: type
                            
                            	IPv6 ICMP type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Transport.Icmp.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "icmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('code', (YLeaf(YType.empty, 'code'), ['Empty'])),
                                    ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                                ])
                                self.code = None
                                self.type = None
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Transport.Icmp.Ipv6, ['code', 'type'], name, value)


                    class Igmp(Entity):
                        """
                        IGMP fields
                        
                        .. attribute:: type
                        
                        	IGMP type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Transport.Igmp, self).__init__()

                            self.yang_name = "igmp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                            ])
                            self.type = None
                            self._segment_path = lambda: "igmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Transport.Igmp, ['type'], name, value)


                    class Tcp(Entity):
                        """
                        TCP fields
                        
                        .. attribute:: acknowledgement_number
                        
                        	TCP acknowledgement number
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: destination_port
                        
                        	TCP destination port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: flags
                        
                        	TCP flags
                        	**type**\:  :py:class:`Flags <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Tcp.Flags>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flow
                        
                        	TCP flow
                        	**type**\:  :py:class:`Flow_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Tcp.Flow_>`
                        
                        .. attribute:: header_length
                        
                        	TCP header length (in 32 bit words)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: maximum_segment_size
                        
                        	The maximum size of TCP segment
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: option
                        
                        	TCP option fields
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Tcp.Option>`
                        
                        .. attribute:: sequence_number
                        
                        	TCP sequence number
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: source_port
                        
                        	TCP source port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: urgent_pointer
                        
                        	TCP urgent pointer
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: window_size
                        
                        	TCP window size
                        	**type**\:  :py:class:`WindowSize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Tcp.WindowSize>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Transport.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("flags", ("flags", Native.Flow.Record.Match.Transport.Tcp.Flags)), ("flow", ("flow", Native.Flow.Record.Match.Transport.Tcp.Flow_)), ("option", ("option", Native.Flow.Record.Match.Transport.Tcp.Option)), ("window-size", ("window_size", Native.Flow.Record.Match.Transport.Tcp.WindowSize))])
                            self._leafs = OrderedDict([
                                ('acknowledgement_number', (YLeaf(YType.empty, 'acknowledgement-number'), ['Empty'])),
                                ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                                ('header_length', (YLeaf(YType.empty, 'header-length'), ['Empty'])),
                                ('maximum_segment_size', (YLeaf(YType.empty, 'maximum-segment-size'), ['Empty'])),
                                ('sequence_number', (YLeaf(YType.empty, 'sequence-number'), ['Empty'])),
                                ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                                ('urgent_pointer', (YLeaf(YType.empty, 'urgent-pointer'), ['Empty'])),
                            ])
                            self.acknowledgement_number = None
                            self.destination_port = None
                            self.header_length = None
                            self.maximum_segment_size = None
                            self.sequence_number = None
                            self.source_port = None
                            self.urgent_pointer = None

                            self.flags = None
                            self._children_name_map["flags"] = "flags"

                            self.flow = Native.Flow.Record.Match.Transport.Tcp.Flow_()
                            self.flow.parent = self
                            self._children_name_map["flow"] = "flow"

                            self.option = Native.Flow.Record.Match.Transport.Tcp.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.window_size = None
                            self._children_name_map["window_size"] = "window-size"
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Transport.Tcp, ['acknowledgement_number', 'destination_port', 'header_length', 'maximum_segment_size', 'sequence_number', 'source_port', 'urgent_pointer'], name, value)


                        class Flags(Entity):
                            """
                            TCP flags
                            
                            .. attribute:: ack
                            
                            	TCP acknowledgement flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cwr
                            
                            	TCP congestion window reduced flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ece
                            
                            	TCP ECN echo flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: fin
                            
                            	TCP finish flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: psh
                            
                            	TCP push flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rst
                            
                            	TCP reset flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: syn
                            
                            	TCP synchronise flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: urg
                            
                            	TCP urgent flag
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Transport.Tcp.Flags, self).__init__()

                                self.yang_name = "flags"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                    ('cwr', (YLeaf(YType.empty, 'cwr'), ['Empty'])),
                                    ('ece', (YLeaf(YType.empty, 'ece'), ['Empty'])),
                                    ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                    ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                    ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                    ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                    ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                ])
                                self.ack = None
                                self.cwr = None
                                self.ece = None
                                self.fin = None
                                self.psh = None
                                self.rst = None
                                self.syn = None
                                self.urg = None
                                self._segment_path = lambda: "flags"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Transport.Tcp.Flags, ['ack', 'cwr', 'ece', 'fin', 'psh', 'rst', 'syn', 'urg'], name, value)


                        class Flow_(Entity):
                            """
                            TCP flow
                            
                            .. attribute:: count
                            
                            	Number of tcp flows
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Transport.Tcp.Flow_, self).__init__()

                                self.yang_name = "flow"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('count', (YLeaf(YType.empty, 'count'), ['Empty'])),
                                ])
                                self.count = None
                                self._segment_path = lambda: "flow"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Transport.Tcp.Flow_, ['count'], name, value)


                        class Option(Entity):
                            """
                            TCP option fields
                            
                            .. attribute:: map
                            
                            	Bitmap of TCP options
                            	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Tcp.Option.Map>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Transport.Tcp.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map", ("map", Native.Flow.Record.Match.Transport.Tcp.Option.Map))])
                                self._leafs = OrderedDict()

                                self.map = None
                                self._children_name_map["map"] = "map"
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Transport.Tcp.Option, [], name, value)


                            class Map(Entity):
                                """
                                Bitmap of TCP options
                                
                                .. attribute:: long
                                
                                	Extended bitmap of TCP options
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Transport.Tcp.Option.Map, self).__init__()

                                    self.yang_name = "map"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                                    ])
                                    self.long = None
                                    self._segment_path = lambda: "map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Transport.Tcp.Option.Map, ['long'], name, value)


                        class WindowSize(Entity):
                            """
                            TCP window size
                            
                            .. attribute:: average
                            
                            	The average size of TCP window
                            	**type**\:  :py:class:`Average <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Record.Match.Transport.Tcp.WindowSize.Average>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: maximum
                            
                            	The maximum size of TCP window
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minimum
                            
                            	The minimum size of TCP window
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sum
                            
                            	The sum of TCP window size
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Record.Match.Transport.Tcp.WindowSize, self).__init__()

                                self.yang_name = "window-size"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("average", ("average", Native.Flow.Record.Match.Transport.Tcp.WindowSize.Average))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                    ('minimum', (YLeaf(YType.empty, 'minimum'), ['Empty'])),
                                    ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                ])
                                self.maximum = None
                                self.minimum = None
                                self.sum = None

                                self.average = None
                                self._children_name_map["average"] = "average"
                                self._segment_path = lambda: "window-size"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Record.Match.Transport.Tcp.WindowSize, ['maximum', 'minimum', 'sum'], name, value)


                            class Average(Entity):
                                """
                                The average size of TCP window
                                
                                .. attribute:: sum
                                
                                	The sum of per flow TCP window average size
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-flow'
                                _revision = '2018-01-04'

                                def __init__(self):
                                    super(Native.Flow.Record.Match.Transport.Tcp.WindowSize.Average, self).__init__()

                                    self.yang_name = "average"
                                    self.yang_parent_name = "window-size"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('sum', (YLeaf(YType.empty, 'sum'), ['Empty'])),
                                    ])
                                    self.sum = None
                                    self._segment_path = lambda: "average"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Flow.Record.Match.Transport.Tcp.WindowSize.Average, ['sum'], name, value)


                    class Udp(Entity):
                        """
                        UDP fields
                        
                        .. attribute:: destination_port
                        
                        	UDP destination port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: message_length
                        
                        	UDP message length
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: source_port
                        
                        	UDP source port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Record.Match.Transport.Udp, self).__init__()

                            self.yang_name = "udp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('destination_port', (YLeaf(YType.empty, 'destination-port'), ['Empty'])),
                                ('message_length', (YLeaf(YType.empty, 'message-length'), ['Empty'])),
                                ('source_port', (YLeaf(YType.empty, 'source-port'), ['Empty'])),
                            ])
                            self.destination_port = None
                            self.message_length = None
                            self.source_port = None
                            self._segment_path = lambda: "udp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Record.Match.Transport.Udp, ['destination_port', 'message_length', 'source_port'], name, value)


        class Exporter(Entity):
            """
            Define a Flow Exporter
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: description
            
            	Provide a description for this Flow Exporter
            	**type**\: str
            
            .. attribute:: destination
            
            	Export destination configuration
            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Destination>`
            
            .. attribute:: dscp
            
            	Optional DSCP
            	**type**\: int
            
            	**range:** 0..63
            
            .. attribute:: export_protocol
            
            	Export protocol version
            	**type**\:  :py:class:`ExportProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.ExportProtocol>`
            
            .. attribute:: option
            
            	Select an option for exporting
            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Option>`
            
            .. attribute:: output_features
            
            	
            	**type**\:  :py:class:`OutputFeatures <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.OutputFeatures>`
            
            	**presence node**\: True
            
            .. attribute:: source
            
            	Originating interface
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Source>`
            
            .. attribute:: template
            
            	Flow Exporter template configuration
            	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Template>`
            
            .. attribute:: transport
            
            	Transport protocol
            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Transport>`
            
            .. attribute:: ttl
            
            	Optional TTL or hop limit
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: default
            
            	Set a command to its defaults
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default>`
            
            

            """

            _prefix = 'ios-flow'
            _revision = '2018-01-04'

            def __init__(self):
                super(Native.Flow.Exporter, self).__init__()

                self.yang_name = "exporter"
                self.yang_parent_name = "flow"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("destination", ("destination", Native.Flow.Exporter.Destination)), ("option", ("option", Native.Flow.Exporter.Option)), ("output-features", ("output_features", Native.Flow.Exporter.OutputFeatures)), ("source", ("source", Native.Flow.Exporter.Source)), ("template", ("template", Native.Flow.Exporter.Template)), ("transport", ("transport", Native.Flow.Exporter.Transport)), ("default", ("default", Native.Flow.Exporter.Default))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                    ('export_protocol', (YLeaf(YType.enumeration, 'export-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Flow.Exporter.ExportProtocol')])),
                    ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                ])
                self.name = None
                self.description = None
                self.dscp = None
                self.export_protocol = None
                self.ttl = None

                self.destination = Native.Flow.Exporter.Destination()
                self.destination.parent = self
                self._children_name_map["destination"] = "destination"

                self.option = Native.Flow.Exporter.Option()
                self.option.parent = self
                self._children_name_map["option"] = "option"

                self.output_features = None
                self._children_name_map["output_features"] = "output-features"

                self.source = Native.Flow.Exporter.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.template = Native.Flow.Exporter.Template()
                self.template.parent = self
                self._children_name_map["template"] = "template"

                self.transport = Native.Flow.Exporter.Transport()
                self.transport.parent = self
                self._children_name_map["transport"] = "transport"

                self.default = Native.Flow.Exporter.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"
                self._segment_path = lambda: "Cisco-IOS-XE-flow:exporter" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/flow/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Flow.Exporter, ['name', 'description', 'dscp', 'export_protocol', 'ttl'], name, value)

            class ExportProtocol(Enum):
                """
                ExportProtocol (Enum Class)

                Export protocol version

                .. data:: ipfix = 0

                .. data:: netflow_v5 = 1

                .. data:: netflow_v9 = 2

                """

                ipfix = Enum.YLeaf(0, "ipfix")

                netflow_v5 = Enum.YLeaf(1, "netflow-v5")

                netflow_v9 = Enum.YLeaf(2, "netflow-v9")



            class Destination(Entity):
                """
                Export destination configuration
                
                .. attribute:: ipdest
                
                	
                	**type**\:  :py:class:`Ipdest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Destination.Ipdest>`
                
                .. attribute:: local
                
                	Export to a local collector
                	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Destination.Local>`
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Exporter.Destination, self).__init__()

                    self.yang_name = "destination"
                    self.yang_parent_name = "exporter"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipdest", ("ipdest", Native.Flow.Exporter.Destination.Ipdest)), ("local", ("local", Native.Flow.Exporter.Destination.Local))])
                    self._leafs = OrderedDict()

                    self.ipdest = Native.Flow.Exporter.Destination.Ipdest()
                    self.ipdest.parent = self
                    self._children_name_map["ipdest"] = "ipdest"

                    self.local = Native.Flow.Exporter.Destination.Local()
                    self.local.parent = self
                    self._children_name_map["local"] = "local"
                    self._segment_path = lambda: "destination"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Exporter.Destination, [], name, value)


                class Ipdest(Entity):
                    """
                    
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vrf
                    
                    	Optional VRF label
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Destination.Ipdest, self).__init__()

                        self.yang_name = "ipdest"
                        self.yang_parent_name = "destination"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.ip = None
                        self.vrf = None
                        self._segment_path = lambda: "ipdest"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Destination.Ipdest, ['ip', 'vrf'], name, value)


                class Local(Entity):
                    """
                    Export to a local collector
                    
                    .. attribute:: wlc
                    
                    	WLC local collector
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Destination.Local, self).__init__()

                        self.yang_name = "local"
                        self.yang_parent_name = "destination"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('wlc', (YLeaf(YType.empty, 'wlc'), ['Empty'])),
                        ])
                        self.wlc = None
                        self._segment_path = lambda: "local"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Destination.Local, ['wlc'], name, value)


            class Option(Entity):
                """
                Select an option for exporting
                
                .. attribute:: application_attributes
                
                	Application Attributes Table Option
                	**type**\:  :py:class:`ApplicationAttributes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Option.ApplicationAttributes>`
                
                	**presence node**\: True
                
                .. attribute:: application_table
                
                	Application Table Option
                	**type**\:  :py:class:`ApplicationTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Option.ApplicationTable>`
                
                	**presence node**\: True
                
                .. attribute:: c3pl_class_table
                
                	C3PL class cce\-id table
                	**type**\:  :py:class:`C3plClassTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Option.C3plClassTable>`
                
                	**presence node**\: True
                
                .. attribute:: c3pl_policy_table
                
                	C3PL policy cce\-id table
                	**type**\:  :py:class:`C3plPolicyTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Option.C3plPolicyTable>`
                
                	**presence node**\: True
                
                .. attribute:: exporter_stats
                
                	Exporter Statistics Option
                	**type**\:  :py:class:`ExporterStats <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Option.ExporterStats>`
                
                	**presence node**\: True
                
                .. attribute:: interface_table
                
                	Interface SNMP\-index\-to\-name Table Option
                	**type**\:  :py:class:`InterfaceTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Option.InterfaceTable>`
                
                	**presence node**\: True
                
                .. attribute:: metadata_version_table
                
                	Metadata Version Table Option
                	**type**\:  :py:class:`MetadataVersionTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Option.MetadataVersionTable>`
                
                	**presence node**\: True
                
                .. attribute:: sampler_table
                
                	Export Sampler Option
                	**type**\:  :py:class:`SamplerTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Option.SamplerTable>`
                
                	**presence node**\: True
                
                .. attribute:: sub_application_table
                
                	Sub Application Table Option
                	**type**\:  :py:class:`SubApplicationTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Option.SubApplicationTable>`
                
                	**presence node**\: True
                
                .. attribute:: vrf_table
                
                	VRF ID\-to\-name Table Option
                	**type**\:  :py:class:`VrfTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Option.VrfTable>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Exporter.Option, self).__init__()

                    self.yang_name = "option"
                    self.yang_parent_name = "exporter"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("application-attributes", ("application_attributes", Native.Flow.Exporter.Option.ApplicationAttributes)), ("application-table", ("application_table", Native.Flow.Exporter.Option.ApplicationTable)), ("c3pl-class-table", ("c3pl_class_table", Native.Flow.Exporter.Option.C3plClassTable)), ("c3pl-policy-table", ("c3pl_policy_table", Native.Flow.Exporter.Option.C3plPolicyTable)), ("exporter-stats", ("exporter_stats", Native.Flow.Exporter.Option.ExporterStats)), ("interface-table", ("interface_table", Native.Flow.Exporter.Option.InterfaceTable)), ("metadata-version-table", ("metadata_version_table", Native.Flow.Exporter.Option.MetadataVersionTable)), ("sampler-table", ("sampler_table", Native.Flow.Exporter.Option.SamplerTable)), ("sub-application-table", ("sub_application_table", Native.Flow.Exporter.Option.SubApplicationTable)), ("vrf-table", ("vrf_table", Native.Flow.Exporter.Option.VrfTable))])
                    self._leafs = OrderedDict()

                    self.application_attributes = None
                    self._children_name_map["application_attributes"] = "application-attributes"

                    self.application_table = None
                    self._children_name_map["application_table"] = "application-table"

                    self.c3pl_class_table = None
                    self._children_name_map["c3pl_class_table"] = "c3pl-class-table"

                    self.c3pl_policy_table = None
                    self._children_name_map["c3pl_policy_table"] = "c3pl-policy-table"

                    self.exporter_stats = None
                    self._children_name_map["exporter_stats"] = "exporter-stats"

                    self.interface_table = None
                    self._children_name_map["interface_table"] = "interface-table"

                    self.metadata_version_table = None
                    self._children_name_map["metadata_version_table"] = "metadata-version-table"

                    self.sampler_table = None
                    self._children_name_map["sampler_table"] = "sampler-table"

                    self.sub_application_table = None
                    self._children_name_map["sub_application_table"] = "sub-application-table"

                    self.vrf_table = None
                    self._children_name_map["vrf_table"] = "vrf-table"
                    self._segment_path = lambda: "option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Exporter.Option, [], name, value)


                class ApplicationAttributes(Entity):
                    """
                    Application Attributes Table Option
                    
                    .. attribute:: timeout
                    
                    	Option resend time
                    	**type**\: int
                    
                    	**range:** 1..86400
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Option.ApplicationAttributes, self).__init__()

                        self.yang_name = "application-attributes"
                        self.yang_parent_name = "option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "application-attributes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Option.ApplicationAttributes, ['timeout'], name, value)


                class ApplicationTable(Entity):
                    """
                    Application Table Option
                    
                    .. attribute:: timeout
                    
                    	Option resend time
                    	**type**\: int
                    
                    	**range:** 1..86400
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Option.ApplicationTable, self).__init__()

                        self.yang_name = "application-table"
                        self.yang_parent_name = "option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "application-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Option.ApplicationTable, ['timeout'], name, value)


                class C3plClassTable(Entity):
                    """
                    C3PL class cce\-id table
                    
                    .. attribute:: timeout
                    
                    	Option resend time
                    	**type**\: int
                    
                    	**range:** 1..86400
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Option.C3plClassTable, self).__init__()

                        self.yang_name = "c3pl-class-table"
                        self.yang_parent_name = "option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "c3pl-class-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Option.C3plClassTable, ['timeout'], name, value)


                class C3plPolicyTable(Entity):
                    """
                    C3PL policy cce\-id table
                    
                    .. attribute:: timeout
                    
                    	Option resend time
                    	**type**\: int
                    
                    	**range:** 1..86400
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Option.C3plPolicyTable, self).__init__()

                        self.yang_name = "c3pl-policy-table"
                        self.yang_parent_name = "option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "c3pl-policy-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Option.C3plPolicyTable, ['timeout'], name, value)


                class ExporterStats(Entity):
                    """
                    Exporter Statistics Option
                    
                    .. attribute:: timeout
                    
                    	Option resend time
                    	**type**\: int
                    
                    	**range:** 1..86400
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Option.ExporterStats, self).__init__()

                        self.yang_name = "exporter-stats"
                        self.yang_parent_name = "option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "exporter-stats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Option.ExporterStats, ['timeout'], name, value)


                class InterfaceTable(Entity):
                    """
                    Interface SNMP\-index\-to\-name Table Option
                    
                    .. attribute:: timeout
                    
                    	Option resend time
                    	**type**\: int
                    
                    	**range:** 1..86400
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Option.InterfaceTable, self).__init__()

                        self.yang_name = "interface-table"
                        self.yang_parent_name = "option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "interface-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Option.InterfaceTable, ['timeout'], name, value)


                class MetadataVersionTable(Entity):
                    """
                    Metadata Version Table Option
                    
                    .. attribute:: timeout
                    
                    	Option resend time
                    	**type**\: int
                    
                    	**range:** 1..86400
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Option.MetadataVersionTable, self).__init__()

                        self.yang_name = "metadata-version-table"
                        self.yang_parent_name = "option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "metadata-version-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Option.MetadataVersionTable, ['timeout'], name, value)


                class SamplerTable(Entity):
                    """
                    Export Sampler Option
                    
                    .. attribute:: timeout
                    
                    	Option resend time
                    	**type**\: int
                    
                    	**range:** 1..86400
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Option.SamplerTable, self).__init__()

                        self.yang_name = "sampler-table"
                        self.yang_parent_name = "option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "sampler-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Option.SamplerTable, ['timeout'], name, value)


                class SubApplicationTable(Entity):
                    """
                    Sub Application Table Option
                    
                    .. attribute:: timeout
                    
                    	Option resend time
                    	**type**\: int
                    
                    	**range:** 1..86400
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Option.SubApplicationTable, self).__init__()

                        self.yang_name = "sub-application-table"
                        self.yang_parent_name = "option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "sub-application-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Option.SubApplicationTable, ['timeout'], name, value)


                class VrfTable(Entity):
                    """
                    VRF ID\-to\-name Table Option
                    
                    .. attribute:: timeout
                    
                    	Option resend time
                    	**type**\: int
                    
                    	**range:** 1..86400
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Option.VrfTable, self).__init__()

                        self.yang_name = "vrf-table"
                        self.yang_parent_name = "option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "vrf-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Option.VrfTable, ['timeout'], name, value)


            class OutputFeatures(Entity):
                """
                
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Exporter.OutputFeatures, self).__init__()

                    self.yang_name = "output-features"
                    self.yang_parent_name = "exporter"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "output-features"
                    self._is_frozen = True


            class Source(Entity):
                """
                Originating interface
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Source.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Source.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Source.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Source.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Exporter.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "exporter"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Flow.Exporter.Source.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Flow.Exporter.Source.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Flow.Exporter.Source.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Flow.Exporter.Source.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.Flow.Exporter.Source.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.Flow.Exporter.Source.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.Flow.Exporter.Source.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.Flow.Exporter.Source.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Exporter.Source, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Source.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Source.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Source.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Source.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Source.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Source.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Source.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Source.PortChannelSubinterface, [u'port_channel'], name, value)


            class Template(Entity):
                """
                Flow Exporter template configuration
                
                .. attribute:: data
                
                	Flow Exporter data configuration
                	**type**\:  :py:class:`Data <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Template.Data>`
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Exporter.Template, self).__init__()

                    self.yang_name = "template"
                    self.yang_parent_name = "exporter"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("data", ("data", Native.Flow.Exporter.Template.Data))])
                    self._leafs = OrderedDict()

                    self.data = Native.Flow.Exporter.Template.Data()
                    self.data.parent = self
                    self._children_name_map["data"] = "data"
                    self._segment_path = lambda: "template"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Exporter.Template, [], name, value)


                class Data(Entity):
                    """
                    Flow Exporter data configuration
                    
                    .. attribute:: timeout
                    
                    	Resend data based on a timeout
                    	**type**\: int
                    
                    	**range:** 1..86400
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Template.Data, self).__init__()

                        self.yang_name = "data"
                        self.yang_parent_name = "template"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "data"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Template.Data, ['timeout'], name, value)


            class Transport(Entity):
                """
                Transport protocol
                
                .. attribute:: udp
                
                	UDP transport protocol
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Exporter.Transport, self).__init__()

                    self.yang_name = "transport"
                    self.yang_parent_name = "exporter"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('udp', (YLeaf(YType.uint16, 'udp'), ['int'])),
                    ])
                    self.udp = None
                    self._segment_path = lambda: "transport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Exporter.Transport, ['udp'], name, value)


            class Default(Entity):
                """
                Set a command to its defaults
                
                .. attribute:: description
                
                	Provide a description for this Flow Exporter
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dscp
                
                	Optional DSCP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: export_protocol
                
                	Export protocol version
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: option
                
                	Select an option for exporting
                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Option>`
                
                .. attribute:: template
                
                	Flow Exporter template configuration
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Template>`
                
                .. attribute:: transport
                
                	Transport protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ttl
                
                	Optional TTL or hop limit
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Exporter.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "exporter"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("option", ("option", Native.Flow.Exporter.Default.Option)), ("template", ("template", Native.Flow.Exporter.Default.Template))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.empty, 'description'), ['Empty'])),
                        ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                        ('export_protocol', (YLeaf(YType.empty, 'export-protocol'), ['Empty'])),
                        ('transport', (YLeaf(YType.empty, 'transport'), ['Empty'])),
                        ('ttl', (YLeaf(YType.empty, 'ttl'), ['Empty'])),
                    ])
                    self.description = None
                    self.dscp = None
                    self.export_protocol = None
                    self.transport = None
                    self.ttl = None

                    self.option = Native.Flow.Exporter.Default.Option()
                    self.option.parent = self
                    self._children_name_map["option"] = "option"

                    self.template = Native.Flow.Exporter.Default.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "default"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Exporter.Default, ['description', 'dscp', 'export_protocol', 'transport', 'ttl'], name, value)


                class Option(Entity):
                    """
                    Select an option for exporting
                    
                    .. attribute:: application_attributes
                    
                    	Application Attributes Table Option
                    	**type**\:  :py:class:`ApplicationAttributes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Option.ApplicationAttributes>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: c3pl_class_table
                    
                    	C3PL class cce\-id table
                    	**type**\:  :py:class:`C3plClassTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Option.C3plClassTable>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: c3pl_policy_table
                    
                    	C3PL policy cce\-id table
                    	**type**\:  :py:class:`C3plPolicyTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Option.C3plPolicyTable>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: exporter_stats
                    
                    	Exporter Statistics Option
                    	**type**\:  :py:class:`ExporterStats <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Option.ExporterStats>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: interface_table
                    
                    	Interface SNMP\-index\-to\-name Table Option
                    	**type**\:  :py:class:`InterfaceTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Option.InterfaceTable>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: metadata_version_table
                    
                    	Metadata Version Table Option
                    	**type**\:  :py:class:`MetadataVersionTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Option.MetadataVersionTable>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: sampler_table
                    
                    	Export Sampler Option
                    	**type**\:  :py:class:`SamplerTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Option.SamplerTable>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: sub_application_table
                    
                    	Sub Application Table Option
                    	**type**\:  :py:class:`SubApplicationTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Option.SubApplicationTable>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: vrf_table
                    
                    	VRF ID\-to\-name Table Option
                    	**type**\:  :py:class:`VrfTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Option.VrfTable>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Default.Option, self).__init__()

                        self.yang_name = "option"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("application-attributes", ("application_attributes", Native.Flow.Exporter.Default.Option.ApplicationAttributes)), ("c3pl-class-table", ("c3pl_class_table", Native.Flow.Exporter.Default.Option.C3plClassTable)), ("c3pl-policy-table", ("c3pl_policy_table", Native.Flow.Exporter.Default.Option.C3plPolicyTable)), ("exporter-stats", ("exporter_stats", Native.Flow.Exporter.Default.Option.ExporterStats)), ("interface-table", ("interface_table", Native.Flow.Exporter.Default.Option.InterfaceTable)), ("metadata-version-table", ("metadata_version_table", Native.Flow.Exporter.Default.Option.MetadataVersionTable)), ("sampler-table", ("sampler_table", Native.Flow.Exporter.Default.Option.SamplerTable)), ("sub-application-table", ("sub_application_table", Native.Flow.Exporter.Default.Option.SubApplicationTable)), ("vrf-table", ("vrf_table", Native.Flow.Exporter.Default.Option.VrfTable))])
                        self._leafs = OrderedDict()

                        self.application_attributes = None
                        self._children_name_map["application_attributes"] = "application-attributes"

                        self.c3pl_class_table = None
                        self._children_name_map["c3pl_class_table"] = "c3pl-class-table"

                        self.c3pl_policy_table = None
                        self._children_name_map["c3pl_policy_table"] = "c3pl-policy-table"

                        self.exporter_stats = None
                        self._children_name_map["exporter_stats"] = "exporter-stats"

                        self.interface_table = None
                        self._children_name_map["interface_table"] = "interface-table"

                        self.metadata_version_table = None
                        self._children_name_map["metadata_version_table"] = "metadata-version-table"

                        self.sampler_table = None
                        self._children_name_map["sampler_table"] = "sampler-table"

                        self.sub_application_table = None
                        self._children_name_map["sub_application_table"] = "sub-application-table"

                        self.vrf_table = None
                        self._children_name_map["vrf_table"] = "vrf-table"
                        self._segment_path = lambda: "option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Default.Option, [], name, value)


                    class ApplicationAttributes(Entity):
                        """
                        Application Attributes Table Option
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Exporter.Default.Option.ApplicationAttributes, self).__init__()

                            self.yang_name = "application-attributes"
                            self.yang_parent_name = "option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "application-attributes"
                            self._is_frozen = True


                    class C3plClassTable(Entity):
                        """
                        C3PL class cce\-id table
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Exporter.Default.Option.C3plClassTable, self).__init__()

                            self.yang_name = "c3pl-class-table"
                            self.yang_parent_name = "option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "c3pl-class-table"
                            self._is_frozen = True


                    class C3plPolicyTable(Entity):
                        """
                        C3PL policy cce\-id table
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Exporter.Default.Option.C3plPolicyTable, self).__init__()

                            self.yang_name = "c3pl-policy-table"
                            self.yang_parent_name = "option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "c3pl-policy-table"
                            self._is_frozen = True


                    class ExporterStats(Entity):
                        """
                        Exporter Statistics Option
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Exporter.Default.Option.ExporterStats, self).__init__()

                            self.yang_name = "exporter-stats"
                            self.yang_parent_name = "option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "exporter-stats"
                            self._is_frozen = True


                    class InterfaceTable(Entity):
                        """
                        Interface SNMP\-index\-to\-name Table Option
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Exporter.Default.Option.InterfaceTable, self).__init__()

                            self.yang_name = "interface-table"
                            self.yang_parent_name = "option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "interface-table"
                            self._is_frozen = True


                    class MetadataVersionTable(Entity):
                        """
                        Metadata Version Table Option
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Exporter.Default.Option.MetadataVersionTable, self).__init__()

                            self.yang_name = "metadata-version-table"
                            self.yang_parent_name = "option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "metadata-version-table"
                            self._is_frozen = True


                    class SamplerTable(Entity):
                        """
                        Export Sampler Option
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Exporter.Default.Option.SamplerTable, self).__init__()

                            self.yang_name = "sampler-table"
                            self.yang_parent_name = "option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "sampler-table"
                            self._is_frozen = True


                    class SubApplicationTable(Entity):
                        """
                        Sub Application Table Option
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Exporter.Default.Option.SubApplicationTable, self).__init__()

                            self.yang_name = "sub-application-table"
                            self.yang_parent_name = "option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "sub-application-table"
                            self._is_frozen = True


                    class VrfTable(Entity):
                        """
                        VRF ID\-to\-name Table Option
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Exporter.Default.Option.VrfTable, self).__init__()

                            self.yang_name = "vrf-table"
                            self.yang_parent_name = "option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "vrf-table"
                            self._is_frozen = True


                class Template(Entity):
                    """
                    Flow Exporter template configuration
                    
                    .. attribute:: data
                    
                    	Flow Exporter data configuration
                    	**type**\:  :py:class:`Data <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Exporter.Default.Template.Data>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Exporter.Default.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("data", ("data", Native.Flow.Exporter.Default.Template.Data))])
                        self._leafs = OrderedDict()

                        self.data = Native.Flow.Exporter.Default.Template.Data()
                        self.data.parent = self
                        self._children_name_map["data"] = "data"
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Exporter.Default.Template, [], name, value)


                    class Data(Entity):
                        """
                        Flow Exporter data configuration
                        
                        .. attribute:: timeout
                        
                        	Resend data based on a timeout
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Exporter.Default.Template.Data, self).__init__()

                            self.yang_name = "data"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('timeout', (YLeaf(YType.empty, 'timeout'), ['Empty'])),
                            ])
                            self.timeout = None
                            self._segment_path = lambda: "data"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Exporter.Default.Template.Data, ['timeout'], name, value)


        class Monitor(Entity):
            """
            Define a Flow Monitor
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: type
            
            	Type of the Flow Record
            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Type>`
            
            .. attribute:: cache
            
            	Monitor cache entries
            	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Cache>`
            
            .. attribute:: description
            
            	Provide a description for this Flow Monitor
            	**type**\: str
            
            .. attribute:: exporter
            
            	Add an Exporter to use to export records
            	**type**\: list of  		 :py:class:`Exporter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Exporter>`
            
            .. attribute:: history
            
            	Monitor history intervals
            	**type**\:  :py:class:`History <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.History>`
            
            .. attribute:: record
            
            	Specify Flow Record to use to define Cache
            	**type**\:  :py:class:`Record <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record>`
            
            .. attribute:: statistics
            
            	Collect statistics
            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Statistics>`
            
            .. attribute:: default
            
            	Set a command to its defaults
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Default>`
            
            

            """

            _prefix = 'ios-flow'
            _revision = '2018-01-04'

            def __init__(self):
                super(Native.Flow.Monitor, self).__init__()

                self.yang_name = "monitor"
                self.yang_parent_name = "flow"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("cache", ("cache", Native.Flow.Monitor.Cache)), ("exporter", ("exporter", Native.Flow.Monitor.Exporter)), ("history", ("history", Native.Flow.Monitor.History)), ("record", ("record", Native.Flow.Monitor.Record)), ("statistics", ("statistics", Native.Flow.Monitor.Statistics)), ("default", ("default", Native.Flow.Monitor.Default))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Flow.Monitor.Type')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                ])
                self.name = None
                self.type = None
                self.description = None

                self.cache = Native.Flow.Monitor.Cache()
                self.cache.parent = self
                self._children_name_map["cache"] = "cache"

                self.history = Native.Flow.Monitor.History()
                self.history.parent = self
                self._children_name_map["history"] = "history"

                self.record = Native.Flow.Monitor.Record()
                self.record.parent = self
                self._children_name_map["record"] = "record"

                self.statistics = Native.Flow.Monitor.Statistics()
                self.statistics.parent = self
                self._children_name_map["statistics"] = "statistics"

                self.default = Native.Flow.Monitor.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.exporter = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-flow:monitor" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/flow/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Flow.Monitor, ['name', 'type', 'description'], name, value)

            class Type(Enum):
                """
                Type (Enum Class)

                Type of the Flow Record

                .. data:: performance_monitor = 0

                """

                performance_monitor = Enum.YLeaf(0, "performance-monitor")



            class Cache(Entity):
                """
                Monitor cache entries
                
                .. attribute:: entries
                
                	Number of cache entries
                	**type**\: int
                
                	**range:** 16..2000000
                
                .. attribute:: timeout
                
                	Cache timeout
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Cache.Timeout>`
                
                .. attribute:: type
                
                	Cache type
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Cache.Type>`
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Monitor.Cache, self).__init__()

                    self.yang_name = "cache"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("timeout", ("timeout", Native.Flow.Monitor.Cache.Timeout))])
                    self._leafs = OrderedDict([
                        ('entries', (YLeaf(YType.uint32, 'entries'), ['int'])),
                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Flow.Monitor.Cache.Type')])),
                    ])
                    self.entries = None
                    self.type = None

                    self.timeout = Native.Flow.Monitor.Cache.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"
                    self._segment_path = lambda: "cache"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Monitor.Cache, ['entries', 'type'], name, value)

                class Type(Enum):
                    """
                    Type (Enum Class)

                    Cache type

                    .. data:: immediate = 0

                    .. data:: normal = 1

                    .. data:: permanent = 2

                    .. data:: synchronized = 3

                    """

                    immediate = Enum.YLeaf(0, "immediate")

                    normal = Enum.YLeaf(1, "normal")

                    permanent = Enum.YLeaf(2, "permanent")

                    synchronized = Enum.YLeaf(3, "synchronized")



                class Timeout(Entity):
                    """
                    Cache timeout
                    
                    .. attribute:: active
                    
                    	Active timeout
                    	**type**\: int
                    
                    	**range:** 1..604800
                    
                    .. attribute:: event
                    
                    	Timeout event
                    	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Cache.Timeout.Event>`
                    
                    .. attribute:: inactive
                    
                    	Inactive timeout
                    	**type**\: int
                    
                    	**range:** 1..604800
                    
                    .. attribute:: synchronized
                    
                    	Synchronized timeout
                    	**type**\: int
                    
                    	**range:** 1..300
                    
                    .. attribute:: update
                    
                    	Update timeout
                    	**type**\: int
                    
                    	**range:** 1..604800
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Monitor.Cache.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "cache"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("event", ("event", Native.Flow.Monitor.Cache.Timeout.Event))])
                        self._leafs = OrderedDict([
                            ('active', (YLeaf(YType.uint32, 'active'), ['int'])),
                            ('inactive', (YLeaf(YType.uint32, 'inactive'), ['int'])),
                            ('synchronized', (YLeaf(YType.uint16, 'synchronized'), ['int'])),
                            ('update', (YLeaf(YType.uint32, 'update'), ['int'])),
                        ])
                        self.active = None
                        self.inactive = None
                        self.synchronized = None
                        self.update = None

                        self.event = Native.Flow.Monitor.Cache.Timeout.Event()
                        self.event.parent = self
                        self._children_name_map["event"] = "event"
                        self._segment_path = lambda: "timeout"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Monitor.Cache.Timeout, ['active', 'inactive', 'synchronized', 'update'], name, value)


                    class Event(Entity):
                        """
                        Timeout event
                        
                        .. attribute:: transaction_end
                        
                        	Transaction\-end event
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Monitor.Cache.Timeout.Event, self).__init__()

                            self.yang_name = "event"
                            self.yang_parent_name = "timeout"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transaction_end', (YLeaf(YType.empty, 'transaction-end'), ['Empty'])),
                            ])
                            self.transaction_end = None
                            self._segment_path = lambda: "event"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Monitor.Cache.Timeout.Event, ['transaction_end'], name, value)


            class Exporter(Entity):
                """
                Add an Exporter to use to export records
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Monitor.Exporter, self).__init__()

                    self.yang_name = "exporter"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None
                    self._segment_path = lambda: "exporter" + "[name='" + str(self.name) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Monitor.Exporter, ['name'], name, value)


            class History(Entity):
                """
                Monitor history intervals
                
                .. attribute:: size
                
                	History size
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: timeout
                
                	Specify timeout interval
                	**type**\: int
                
                	**range:** 1..30
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Monitor.History, self).__init__()

                    self.yang_name = "history"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('size', (YLeaf(YType.uint8, 'size'), ['int'])),
                        ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                    ])
                    self.size = None
                    self.timeout = None
                    self._segment_path = lambda: "history"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Monitor.History, ['size', 'timeout'], name, value)


            class Record(Entity):
                """
                Specify Flow Record to use to define Cache
                
                .. attribute:: type
                
                	
                	**type**\: union of the below types:
                
                		**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Type>`
                
                		**type**\: str
                
                .. attribute:: netflow
                
                	Traditional NetFlow collection schemes
                	**type**\:  :py:class:`Netflow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow>`
                
                .. attribute:: wireless
                
                	Templates for wireless traffics
                	**type**\:  :py:class:`Wireless <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Wireless>`
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Monitor.Record, self).__init__()

                    self.yang_name = "record"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("netflow", ("netflow", Native.Flow.Monitor.Record.Netflow)), ("wireless", ("wireless", Native.Flow.Monitor.Record.Wireless))])
                    self._leafs = OrderedDict([
                        ('type', (YLeaf(YType.str, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Flow.Monitor.Record.Type'),'str'])),
                    ])
                    self.type = None

                    self.netflow = Native.Flow.Monitor.Record.Netflow()
                    self.netflow.parent = self
                    self._children_name_map["netflow"] = "netflow"

                    self.wireless = Native.Flow.Monitor.Record.Wireless()
                    self.wireless.parent = self
                    self._children_name_map["wireless"] = "wireless"
                    self._segment_path = lambda: "record"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Monitor.Record, ['type'], name, value)

                class Type(Enum):
                    """
                    Type (Enum Class)

                    .. data:: default_rtp = 0

                    .. data:: default_tcp = 1

                    .. data:: netflow_original = 2

                    """

                    default_rtp = Enum.YLeaf(0, "default-rtp")

                    default_tcp = Enum.YLeaf(1, "default-tcp")

                    netflow_original = Enum.YLeaf(2, "netflow-original")



                class Netflow(Entity):
                    """
                    Traditional NetFlow collection schemes
                    
                    .. attribute:: ipv4
                    
                    	Traditional IPv4 NetFlow collection schemes
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Traditional IPv6 NetFlow collection schemes
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Monitor.Record.Netflow, self).__init__()

                        self.yang_name = "netflow"
                        self.yang_parent_name = "record"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Monitor.Record.Netflow.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Monitor.Record.Netflow.Ipv6))])
                        self._leafs = OrderedDict()

                        self.ipv4 = Native.Flow.Monitor.Record.Netflow.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Flow.Monitor.Record.Netflow.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"
                        self._segment_path = lambda: "netflow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Monitor.Record.Netflow, [], name, value)


                    class Ipv4(Entity):
                        """
                        Traditional IPv4 NetFlow collection schemes
                        
                        .. attribute:: as_
                        
                        	AS aggregation schemes
                        	**type**\:  :py:class:`As <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4.As>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: destination_prefix
                        
                        	Destination Prefix aggregation schemes
                        	**type**\:  :py:class:`DestinationPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4.DestinationPrefix>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: original_input
                        
                        	Traditional IPv6 input NetFlow with ASs
                        	**type**\:  :py:class:`OriginalInput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4.OriginalInput>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: original_output
                        
                        	Traditional IPv6 output NetFlow with ASs
                        	**type**\:  :py:class:`OriginalOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4.OriginalOutput>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix
                        
                        	Source and Destination Prefixes aggregation schemes
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4.Prefix>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: protocol_port
                        
                        	Protocol and Ports aggregation scheme
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: source_prefix
                        
                        	Source AS and Prefix aggregation schemes
                        	**type**\:  :py:class:`SourcePrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4.SourcePrefix>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: as_tos
                        
                        	AS and TOS aggregation schemes
                        	**type**\:  :py:class:`AsTos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4.AsTos>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: bgp_nexthop_tos
                        
                        	BGP next\-hop and TOS aggregation schemes
                        	**type**\:  :py:class:`BgpNexthopTos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4.BgpNexthopTos>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: destination_prefix_tos
                        
                        	Destination Prefix and TOS  aggregation schemes
                        	**type**\:  :py:class:`DestinationPrefixTos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4.DestinationPrefixTos>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix_port
                        
                        	Prefixes and Ports aggregation scheme
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix_tos
                        
                        	Prefixes and TOS aggregation schemes
                        	**type**\:  :py:class:`PrefixTos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4.PrefixTos>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: protocol_port_tos
                        
                        	Protocol, Ports and TOS aggregation scheme
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: source_prefix_tos
                        
                        	Source Prefix and TOS aggregation schemes
                        	**type**\:  :py:class:`SourcePrefixTos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv4.SourcePrefixTos>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Monitor.Record.Netflow.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "netflow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("as", ("as_", Native.Flow.Monitor.Record.Netflow.Ipv4.As)), ("destination-prefix", ("destination_prefix", Native.Flow.Monitor.Record.Netflow.Ipv4.DestinationPrefix)), ("original-input", ("original_input", Native.Flow.Monitor.Record.Netflow.Ipv4.OriginalInput)), ("original-output", ("original_output", Native.Flow.Monitor.Record.Netflow.Ipv4.OriginalOutput)), ("prefix", ("prefix", Native.Flow.Monitor.Record.Netflow.Ipv4.Prefix)), ("source-prefix", ("source_prefix", Native.Flow.Monitor.Record.Netflow.Ipv4.SourcePrefix)), ("as-tos", ("as_tos", Native.Flow.Monitor.Record.Netflow.Ipv4.AsTos)), ("bgp-nexthop-tos", ("bgp_nexthop_tos", Native.Flow.Monitor.Record.Netflow.Ipv4.BgpNexthopTos)), ("destination-prefix-tos", ("destination_prefix_tos", Native.Flow.Monitor.Record.Netflow.Ipv4.DestinationPrefixTos)), ("prefix-tos", ("prefix_tos", Native.Flow.Monitor.Record.Netflow.Ipv4.PrefixTos)), ("source-prefix-tos", ("source_prefix_tos", Native.Flow.Monitor.Record.Netflow.Ipv4.SourcePrefixTos))])
                            self._leafs = OrderedDict([
                                ('protocol_port', (YLeaf(YType.empty, 'protocol-port'), ['Empty'])),
                                ('prefix_port', (YLeaf(YType.empty, 'prefix-port'), ['Empty'])),
                                ('protocol_port_tos', (YLeaf(YType.empty, 'protocol-port-tos'), ['Empty'])),
                            ])
                            self.protocol_port = None
                            self.prefix_port = None
                            self.protocol_port_tos = None

                            self.as_ = None
                            self._children_name_map["as_"] = "as"

                            self.destination_prefix = None
                            self._children_name_map["destination_prefix"] = "destination-prefix"

                            self.original_input = None
                            self._children_name_map["original_input"] = "original-input"

                            self.original_output = None
                            self._children_name_map["original_output"] = "original-output"

                            self.prefix = None
                            self._children_name_map["prefix"] = "prefix"

                            self.source_prefix = None
                            self._children_name_map["source_prefix"] = "source-prefix"

                            self.as_tos = None
                            self._children_name_map["as_tos"] = "as-tos"

                            self.bgp_nexthop_tos = None
                            self._children_name_map["bgp_nexthop_tos"] = "bgp-nexthop-tos"

                            self.destination_prefix_tos = None
                            self._children_name_map["destination_prefix_tos"] = "destination-prefix-tos"

                            self.prefix_tos = None
                            self._children_name_map["prefix_tos"] = "prefix-tos"

                            self.source_prefix_tos = None
                            self._children_name_map["source_prefix_tos"] = "source-prefix-tos"
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4, ['protocol_port', 'prefix_port', 'protocol_port_tos'], name, value)


                        class As(Entity):
                            """
                            AS aggregation schemes
                            
                            .. attribute:: peer
                            
                            	AS aggregation scheme with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv4.As, self).__init__()

                                self.yang_name = "as"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "as"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4.As, ['peer'], name, value)


                        class DestinationPrefix(Entity):
                            """
                            Destination Prefix aggregation schemes
                            
                            .. attribute:: peer
                            
                            	Destination Prefix aggregation scheme with peer AS
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv4.DestinationPrefix, self).__init__()

                                self.yang_name = "destination-prefix"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "destination-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4.DestinationPrefix, ['peer'], name, value)


                        class OriginalInput(Entity):
                            """
                            Traditional IPv6 input NetFlow with ASs
                            
                            .. attribute:: peer
                            
                            	Traditional IPv6 input NetFlow with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv4.OriginalInput, self).__init__()

                                self.yang_name = "original-input"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "original-input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4.OriginalInput, ['peer'], name, value)


                        class OriginalOutput(Entity):
                            """
                            Traditional IPv6 output NetFlow with ASs
                            
                            .. attribute:: peer
                            
                            	Traditional IPv6 output NetFlow with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv4.OriginalOutput, self).__init__()

                                self.yang_name = "original-output"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "original-output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4.OriginalOutput, ['peer'], name, value)


                        class Prefix(Entity):
                            """
                            Source and Destination Prefixes aggregation schemes
                            
                            .. attribute:: peer
                            
                            	Source and Destination Prefixes aggregation scheme with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv4.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4.Prefix, ['peer'], name, value)


                        class SourcePrefix(Entity):
                            """
                            Source AS and Prefix aggregation schemes
                            
                            .. attribute:: peer
                            
                            	Source AS and Prefix aggregation scheme with peer AS
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv4.SourcePrefix, self).__init__()

                                self.yang_name = "source-prefix"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "source-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4.SourcePrefix, ['peer'], name, value)


                        class AsTos(Entity):
                            """
                            AS and TOS aggregation schemes
                            
                            .. attribute:: peer
                            
                            	AS and TOS aggregation scheme with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv4.AsTos, self).__init__()

                                self.yang_name = "as-tos"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "as-tos"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4.AsTos, ['peer'], name, value)


                        class BgpNexthopTos(Entity):
                            """
                            BGP next\-hop and TOS aggregation schemes
                            
                            .. attribute:: peer
                            
                            	BGP next\-hop and TOS aggregation scheme with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv4.BgpNexthopTos, self).__init__()

                                self.yang_name = "bgp-nexthop-tos"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "bgp-nexthop-tos"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4.BgpNexthopTos, ['peer'], name, value)


                        class DestinationPrefixTos(Entity):
                            """
                            Destination Prefix and TOS  aggregation schemes
                            
                            .. attribute:: peer
                            
                            	Destination Prefix and TOS aggregation scheme with peer AS
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv4.DestinationPrefixTos, self).__init__()

                                self.yang_name = "destination-prefix-tos"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "destination-prefix-tos"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4.DestinationPrefixTos, ['peer'], name, value)


                        class PrefixTos(Entity):
                            """
                            Prefixes and TOS aggregation schemes
                            
                            .. attribute:: peer
                            
                            	Prefixes and TOS aggregation scheme with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv4.PrefixTos, self).__init__()

                                self.yang_name = "prefix-tos"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "prefix-tos"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4.PrefixTos, ['peer'], name, value)


                        class SourcePrefixTos(Entity):
                            """
                            Source Prefix and TOS aggregation schemes
                            
                            .. attribute:: peer
                            
                            	Source Prefix and TOS aggregation scheme with peer AS
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv4.SourcePrefixTos, self).__init__()

                                self.yang_name = "source-prefix-tos"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "source-prefix-tos"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv4.SourcePrefixTos, ['peer'], name, value)


                    class Ipv6(Entity):
                        """
                        Traditional IPv6 NetFlow collection schemes
                        
                        .. attribute:: as_
                        
                        	AS aggregation schemes
                        	**type**\:  :py:class:`As <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv6.As>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: destination_prefix
                        
                        	Destination Prefix aggregation schemes
                        	**type**\:  :py:class:`DestinationPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv6.DestinationPrefix>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: original_input
                        
                        	Traditional IPv6 input NetFlow with ASs
                        	**type**\:  :py:class:`OriginalInput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv6.OriginalInput>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: original_output
                        
                        	Traditional IPv6 output NetFlow with ASs
                        	**type**\:  :py:class:`OriginalOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv6.OriginalOutput>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix
                        
                        	Source and Destination Prefixes aggregation schemes
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv6.Prefix>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: protocol_port
                        
                        	Protocol and Ports aggregation scheme
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: source_prefix
                        
                        	Source AS and Prefix aggregation schemes
                        	**type**\:  :py:class:`SourcePrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv6.SourcePrefix>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: bgp_nexthop
                        
                        	BGP next\-hop aggregation schemes
                        	**type**\:  :py:class:`BgpNexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Netflow.Ipv6.BgpNexthop>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Monitor.Record.Netflow.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "netflow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("as", ("as_", Native.Flow.Monitor.Record.Netflow.Ipv6.As)), ("destination-prefix", ("destination_prefix", Native.Flow.Monitor.Record.Netflow.Ipv6.DestinationPrefix)), ("original-input", ("original_input", Native.Flow.Monitor.Record.Netflow.Ipv6.OriginalInput)), ("original-output", ("original_output", Native.Flow.Monitor.Record.Netflow.Ipv6.OriginalOutput)), ("prefix", ("prefix", Native.Flow.Monitor.Record.Netflow.Ipv6.Prefix)), ("source-prefix", ("source_prefix", Native.Flow.Monitor.Record.Netflow.Ipv6.SourcePrefix)), ("bgp-nexthop", ("bgp_nexthop", Native.Flow.Monitor.Record.Netflow.Ipv6.BgpNexthop))])
                            self._leafs = OrderedDict([
                                ('protocol_port', (YLeaf(YType.empty, 'protocol-port'), ['Empty'])),
                            ])
                            self.protocol_port = None

                            self.as_ = None
                            self._children_name_map["as_"] = "as"

                            self.destination_prefix = None
                            self._children_name_map["destination_prefix"] = "destination-prefix"

                            self.original_input = None
                            self._children_name_map["original_input"] = "original-input"

                            self.original_output = None
                            self._children_name_map["original_output"] = "original-output"

                            self.prefix = None
                            self._children_name_map["prefix"] = "prefix"

                            self.source_prefix = None
                            self._children_name_map["source_prefix"] = "source-prefix"

                            self.bgp_nexthop = None
                            self._children_name_map["bgp_nexthop"] = "bgp-nexthop"
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv6, ['protocol_port'], name, value)


                        class As(Entity):
                            """
                            AS aggregation schemes
                            
                            .. attribute:: peer
                            
                            	AS aggregation scheme with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv6.As, self).__init__()

                                self.yang_name = "as"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "as"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv6.As, ['peer'], name, value)


                        class DestinationPrefix(Entity):
                            """
                            Destination Prefix aggregation schemes
                            
                            .. attribute:: peer
                            
                            	Destination Prefix aggregation scheme with peer AS
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv6.DestinationPrefix, self).__init__()

                                self.yang_name = "destination-prefix"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "destination-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv6.DestinationPrefix, ['peer'], name, value)


                        class OriginalInput(Entity):
                            """
                            Traditional IPv6 input NetFlow with ASs
                            
                            .. attribute:: peer
                            
                            	Traditional IPv6 input NetFlow with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv6.OriginalInput, self).__init__()

                                self.yang_name = "original-input"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "original-input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv6.OriginalInput, ['peer'], name, value)


                        class OriginalOutput(Entity):
                            """
                            Traditional IPv6 output NetFlow with ASs
                            
                            .. attribute:: peer
                            
                            	Traditional IPv6 output NetFlow with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv6.OriginalOutput, self).__init__()

                                self.yang_name = "original-output"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "original-output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv6.OriginalOutput, ['peer'], name, value)


                        class Prefix(Entity):
                            """
                            Source and Destination Prefixes aggregation schemes
                            
                            .. attribute:: peer
                            
                            	Source and Destination Prefixes aggregation scheme with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv6.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv6.Prefix, ['peer'], name, value)


                        class SourcePrefix(Entity):
                            """
                            Source AS and Prefix aggregation schemes
                            
                            .. attribute:: peer
                            
                            	Source AS and Prefix aggregation scheme with peer AS
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv6.SourcePrefix, self).__init__()

                                self.yang_name = "source-prefix"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "source-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv6.SourcePrefix, ['peer'], name, value)


                        class BgpNexthop(Entity):
                            """
                            BGP next\-hop aggregation schemes
                            
                            .. attribute:: peer
                            
                            	BGP next\-hop aggregation scheme with peer ASs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Netflow.Ipv6.BgpNexthop, self).__init__()

                                self.yang_name = "bgp-nexthop"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                                ])
                                self.peer = None
                                self._segment_path = lambda: "bgp-nexthop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Netflow.Ipv6.BgpNexthop, ['peer'], name, value)


                class Wireless(Entity):
                    """
                    Templates for wireless traffics
                    
                    .. attribute:: avc
                    
                    	Schemas for Application Visibility Control
                    	**type**\:  :py:class:`Avc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Wireless.Avc>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Monitor.Record.Wireless, self).__init__()

                        self.yang_name = "wireless"
                        self.yang_parent_name = "record"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("avc", ("avc", Native.Flow.Monitor.Record.Wireless.Avc))])
                        self._leafs = OrderedDict()

                        self.avc = Native.Flow.Monitor.Record.Wireless.Avc()
                        self.avc.parent = self
                        self._children_name_map["avc"] = "avc"
                        self._segment_path = lambda: "wireless"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Monitor.Record.Wireless, [], name, value)


                    class Avc(Entity):
                        """
                        Schemas for Application Visibility Control
                        
                        .. attribute:: basic
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Wireless.Avc.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Record.Wireless.Avc.Ipv6>`
                        
                        .. attribute:: statistics
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Monitor.Record.Wireless.Avc, self).__init__()

                            self.yang_name = "avc"
                            self.yang_parent_name = "wireless"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Flow.Monitor.Record.Wireless.Avc.Ipv4)), ("ipv6", ("ipv6", Native.Flow.Monitor.Record.Wireless.Avc.Ipv6))])
                            self._leafs = OrderedDict([
                                ('basic', (YLeaf(YType.empty, 'basic'), ['Empty'])),
                                ('statistics', (YLeaf(YType.empty, 'statistics'), ['Empty'])),
                            ])
                            self.basic = None
                            self.statistics = None

                            self.ipv4 = Native.Flow.Monitor.Record.Wireless.Avc.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = Native.Flow.Monitor.Record.Wireless.Avc.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "avc"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Monitor.Record.Wireless.Avc, ['basic', 'statistics'], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: basic
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Wireless.Avc.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "avc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('basic', (YLeaf(YType.empty, 'basic'), ['Empty'])),
                                ])
                                self.basic = None
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Wireless.Avc.Ipv4, ['basic'], name, value)


                        class Ipv6(Entity):
                            """
                            
                            
                            .. attribute:: basic
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Record.Wireless.Avc.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "avc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('basic', (YLeaf(YType.empty, 'basic'), ['Empty'])),
                                ])
                                self.basic = None
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Record.Wireless.Avc.Ipv6, ['basic'], name, value)


            class Statistics(Entity):
                """
                Collect statistics
                
                .. attribute:: packet
                
                	Collect packet statistics
                	**type**\:  :py:class:`Packet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Statistics.Packet>`
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Monitor.Statistics, self).__init__()

                    self.yang_name = "statistics"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("packet", ("packet", Native.Flow.Monitor.Statistics.Packet))])
                    self._leafs = OrderedDict()

                    self.packet = Native.Flow.Monitor.Statistics.Packet()
                    self.packet.parent = self
                    self._children_name_map["packet"] = "packet"
                    self._segment_path = lambda: "statistics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Monitor.Statistics, [], name, value)


                class Packet(Entity):
                    """
                    Collect packet statistics
                    
                    .. attribute:: protocol
                    
                    	Collect packet protocol distribution statistics
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: size
                    
                    	Collect packet size distribution statistics
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Monitor.Statistics.Packet, self).__init__()

                        self.yang_name = "packet"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                            ('size', (YLeaf(YType.empty, 'size'), ['Empty'])),
                        ])
                        self.protocol = None
                        self.size = None
                        self._segment_path = lambda: "packet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Monitor.Statistics.Packet, ['protocol', 'size'], name, value)


            class Default(Entity):
                """
                Set a command to its defaults
                
                .. attribute:: cache
                
                	Monitor cache entries
                	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Default.Cache>`
                
                .. attribute:: description
                
                	Provide a description for this Flow Monitor
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: exporter
                
                	Add an Exporter to use to export records
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: record
                
                	Specify Flow Record to use to define Cache
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: statistics
                
                	Collect statistics
                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Default.Statistics>`
                
                

                """

                _prefix = 'ios-flow'
                _revision = '2018-01-04'

                def __init__(self):
                    super(Native.Flow.Monitor.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cache", ("cache", Native.Flow.Monitor.Default.Cache)), ("statistics", ("statistics", Native.Flow.Monitor.Default.Statistics))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.empty, 'description'), ['Empty'])),
                        ('exporter', (YLeaf(YType.empty, 'exporter'), ['Empty'])),
                        ('record', (YLeaf(YType.empty, 'record'), ['Empty'])),
                    ])
                    self.description = None
                    self.exporter = None
                    self.record = None

                    self.cache = Native.Flow.Monitor.Default.Cache()
                    self.cache.parent = self
                    self._children_name_map["cache"] = "cache"

                    self.statistics = Native.Flow.Monitor.Default.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"
                    self._segment_path = lambda: "default"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Flow.Monitor.Default, ['description', 'exporter', 'record'], name, value)


                class Cache(Entity):
                    """
                    Monitor cache entries
                    
                    .. attribute:: entries
                    
                    	Maximum flow entries in the Flow Cache
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: timeout
                    
                    	Configure flow cache timeout parameters
                    	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Default.Cache.Timeout>`
                    
                    .. attribute:: type
                    
                    	Set the type of the Flow Cache
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Monitor.Default.Cache, self).__init__()

                        self.yang_name = "cache"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("timeout", ("timeout", Native.Flow.Monitor.Default.Cache.Timeout))])
                        self._leafs = OrderedDict([
                            ('entries', (YLeaf(YType.empty, 'entries'), ['Empty'])),
                            ('type', (YLeaf(YType.empty, 'type'), ['Empty'])),
                        ])
                        self.entries = None
                        self.type = None

                        self.timeout = Native.Flow.Monitor.Default.Cache.Timeout()
                        self.timeout.parent = self
                        self._children_name_map["timeout"] = "timeout"
                        self._segment_path = lambda: "cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Monitor.Default.Cache, ['entries', 'type'], name, value)


                    class Timeout(Entity):
                        """
                        Configure flow cache timeout parameters
                        
                        .. attribute:: active
                        
                        	Specify the active flow timeout
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: event
                        
                        	Event\-based export
                        	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Default.Cache.Timeout.Event>`
                        
                        .. attribute:: inactive
                        
                        	Specify the inactive flow timeout
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: synchronized
                        
                        	Specify the timeout for a synchronized Flow Cache
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: update
                        
                        	Specify the update timeout for a permanent Flow Cache
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Monitor.Default.Cache.Timeout, self).__init__()

                            self.yang_name = "timeout"
                            self.yang_parent_name = "cache"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("event", ("event", Native.Flow.Monitor.Default.Cache.Timeout.Event))])
                            self._leafs = OrderedDict([
                                ('active', (YLeaf(YType.empty, 'active'), ['Empty'])),
                                ('inactive', (YLeaf(YType.empty, 'inactive'), ['Empty'])),
                                ('synchronized', (YLeaf(YType.empty, 'synchronized'), ['Empty'])),
                                ('update', (YLeaf(YType.empty, 'update'), ['Empty'])),
                            ])
                            self.active = None
                            self.inactive = None
                            self.synchronized = None
                            self.update = None

                            self.event = Native.Flow.Monitor.Default.Cache.Timeout.Event()
                            self.event.parent = self
                            self._children_name_map["event"] = "event"
                            self._segment_path = lambda: "timeout"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Monitor.Default.Cache.Timeout, ['active', 'inactive', 'synchronized', 'update'], name, value)


                        class Event(Entity):
                            """
                            Event\-based export
                            
                            .. attribute:: transaction_end
                            
                            	Export on transaction end event
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Flow.Monitor.Default.Cache.Timeout.Event, self).__init__()

                                self.yang_name = "event"
                                self.yang_parent_name = "timeout"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('transaction_end', (YLeaf(YType.empty, 'transaction-end'), ['Empty'])),
                                ])
                                self.transaction_end = None
                                self._segment_path = lambda: "event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Flow.Monitor.Default.Cache.Timeout.Event, ['transaction_end'], name, value)


                class Statistics(Entity):
                    """
                    Collect statistics
                    
                    .. attribute:: packet
                    
                    	Collect packet statistics
                    	**type**\:  :py:class:`Packet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Flow.Monitor.Default.Statistics.Packet>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Flow.Monitor.Default.Statistics, self).__init__()

                        self.yang_name = "statistics"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("packet", ("packet", Native.Flow.Monitor.Default.Statistics.Packet))])
                        self._leafs = OrderedDict()

                        self.packet = Native.Flow.Monitor.Default.Statistics.Packet()
                        self.packet.parent = self
                        self._children_name_map["packet"] = "packet"
                        self._segment_path = lambda: "statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Flow.Monitor.Default.Statistics, [], name, value)


                    class Packet(Entity):
                        """
                        Collect packet statistics
                        
                        .. attribute:: protocol
                        
                        	Collect packet protocol distribution statistics
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: size
                        
                        	Collect packet size distribution statistics
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Flow.Monitor.Default.Statistics.Packet, self).__init__()

                            self.yang_name = "packet"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                                ('size', (YLeaf(YType.empty, 'size'), ['Empty'])),
                            ])
                            self.protocol = None
                            self.size = None
                            self._segment_path = lambda: "packet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Flow.Monitor.Default.Statistics.Packet, ['protocol', 'size'], name, value)


    class Ip(Entity):
        """
        Global IP configuration subcommands
        
        .. attribute:: ospf
        
        	Configure for ospf
        	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ospf>`
        
        .. attribute:: admission
        
        	Network Admission Control (NAC)
        	**type**\:  :py:class:`Admission <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Admission>`
        
        .. attribute:: arp
        
        	IP ARP global configuration
        	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Arp>`
        
        .. attribute:: domain_list
        
        	Domain name to complete unqualified host names
        	**type**\:  :py:class:`DomainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.DomainList>`
        
        .. attribute:: finger
        
        	finger server
        	**type**\:  :py:class:`Finger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Finger>`
        
        	**presence node**\: True
        
        .. attribute:: rcmd
        
        	Rcmd commands
        	**type**\:  :py:class:`Rcmd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rcmd>`
        
        .. attribute:: subnet_zero
        
        	Allow 'subnet zero' subnets
        	**type**\: bool
        
        .. attribute:: bgp_community
        
        	format for BGP community
        	**type**\:  :py:class:`BgpCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.BgpCommunity>`
        
        .. attribute:: host_routing
        
        	Enable host\-based routing (proxy ARP and redirect)
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: vrf
        
        	Configure an IP VPN Routing/Forwarding instance
        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf>`
        
        .. attribute:: as_path
        
        	BGP autonomous system path filter
        	**type**\:  :py:class:`AsPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AsPath>`
        
        .. attribute:: local
        
        	Specify local options
        	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Local>`
        
        .. attribute:: cef
        
        	Cisco Express Forwarding
        	**type**\:  :py:class:`Cef <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef>`
        
        	**presence node**\: True
        
        .. attribute:: classless
        
        	Follow classless routing forwarding rules
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: domain
        
        	IP DNS Resolver
        	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Domain>`
        
        .. attribute:: domain_lookup_conf
        
        	
        	**type**\:  :py:class:`DomainLookupConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.DomainLookupConf>`
        
        .. attribute:: domain_lookup
        
        	Enable IP Domain Name System hostname translation
        	**type**\:  :py:class:`DomainLookup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.DomainLookup>`
        
        	**presence node**\: True
        
        .. attribute:: domain_name
        
        	Define the default domain name
        	**type**\: str
        
        .. attribute:: dns
        
        	Configure DNS server for a zone
        	**type**\:  :py:class:`Dns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dns>`
        
        .. attribute:: default_gateway
        
        	Specify default gateway (if not routing IP)
        	**type**\: str
        
        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
        
        .. attribute:: dhcp
        
        	Configure DHCP server and relay parameters
        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp>`
        
        .. attribute:: forward_protocol
        
        	Controls forwarding of physical and directed IP broadcasts
        	**type**\:  :py:class:`ForwardProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ForwardProtocol>`
        
        .. attribute:: gratuitous_arps_conf
        
        	
        	**type**\:  :py:class:`GratuitousArpsConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.GratuitousArpsConf>`
        
        .. attribute:: ftp
        
        	FTP configuration commands
        	**type**\:  :py:class:`Ftp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ftp>`
        
        .. attribute:: telnet
        
        	Specify telnet options
        	**type**\:  :py:class:`Telnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Telnet>`
        
        .. attribute:: host
        
        	Add an entry to the ip hostname table
        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Host>`
        
        .. attribute:: multicast
        
        	Global IP Multicast Commands
        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Multicast>`
        
        .. attribute:: name_server
        
        	
        	**type**\:  :py:class:`NameServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.NameServer>`
        
        .. attribute:: pim
        
        	PIM global commands
        	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim>`
        
        .. attribute:: prefix_list
        
        	Build a prefix list
        	**type**\:  :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList>`
        
        .. attribute:: route
        
        	Establish static routes
        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route>`
        
        .. attribute:: routing
        
        	Enable IP routing
        	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Routing>`
        
        	**presence node**\: True
        
        .. attribute:: explicit_path
        
        	Configure explicit\-path
        	**type**\:  :py:class:`ExplicitPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExplicitPath>`
        
        .. attribute:: scp
        
        	Scp commands
        	**type**\:  :py:class:`Scp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Scp>`
        
        .. attribute:: spd
        
        	spd
        	**type**\:  :py:class:`Spd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Spd>`
        
        .. attribute:: bootp
        
        	Config BOOTP services
        	**type**\:  :py:class:`Bootp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Bootp>`
        
        .. attribute:: source_route
        
        	Process packets with source routing header options
        	**type**\: bool
        
        .. attribute:: ssh
        
        	Configure ssh options
        	**type**\:  :py:class:`Ssh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh>`
        
        .. attribute:: tcp
        
        	Global TCP parameters
        	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tcp>`
        
        .. attribute:: tftp
        
        	tftp configuration commands
        	**type**\:  :py:class:`Tftp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tftp>`
        
        .. attribute:: access_list
        
        	IOS Named access list
        	**type**\:  :py:class:`AccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList>`
        
        .. attribute:: device
        
        	Device tracking
        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Device>`
        
        .. attribute:: igmp
        
        	IGMP global configuration
        	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp>`
        
        .. attribute:: radius
        
        	RADIUS configuration commands
        	**type**\:  :py:class:`Radius <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Radius>`
        
        .. attribute:: tacacs
        
        	TACACS configuration commands
        	**type**\:  :py:class:`Tacacs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tacacs>`
        
        .. attribute:: nbar
        
        	NBAR \- Network Based Application Recognition
        	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar>`
        
        .. attribute:: msdp
        
        	MSDP global commands
        	**type**\:  :py:class:`Msdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp>`
        
        .. attribute:: mcr_conf
        
        	
        	**type**\:  :py:class:`McrConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.McrConf>`
        
        .. attribute:: multicast_routing
        
        	Enable IP multicast forwarding
        	**type**\:  :py:class:`MulticastRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.MulticastRouting>`
        
        	**presence node**\: True
        
        .. attribute:: mroute
        
        	Configure static multicast routes
        	**type**\:  :py:class:`Mroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Mroute>`
        
        .. attribute:: rsvp
        
        	IP RSVP
        	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp>`
        
        .. attribute:: http
        
        	HTTP server configuration
        	**type**\:  :py:class:`Http <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Http>`
        
        .. attribute:: nat
        
        	NAT configuration commands
        	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat>`
        
        .. attribute:: icmp
        
        	ICMP options
        	**type**\:  :py:class:`Icmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Icmp>`
        
        .. attribute:: community_list
        
        	Add a community list entry
        	**type**\:  :py:class:`CommunityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList>`
        
        .. attribute:: extcommunity_list
        
        	Extended a community list entry
        	**type**\:  :py:class:`ExtcommunityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList>`
        
        .. attribute:: sla
        
        	IP Service Level Agreement
        	**type**\:  :py:class:`Sla <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla>`
        
        .. attribute:: wccp
        
        	Web\-Cache Coordination Protocol IPv4 Commands
        	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Ip, self).__init__()

            self.yang_name = "ip"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("ospf", ("ospf", Native.Ip.Ospf)), ("admission", ("admission", Native.Ip.Admission)), ("arp", ("arp", Native.Ip.Arp)), ("domain-list", ("domain_list", Native.Ip.DomainList)), ("finger", ("finger", Native.Ip.Finger)), ("rcmd", ("rcmd", Native.Ip.Rcmd)), ("bgp-community", ("bgp_community", Native.Ip.BgpCommunity)), ("vrf", ("vrf", Native.Ip.Vrf)), ("as-path", ("as_path", Native.Ip.AsPath)), ("local", ("local", Native.Ip.Local)), ("cef", ("cef", Native.Ip.Cef)), ("domain", ("domain", Native.Ip.Domain)), ("domain-lookup-conf", ("domain_lookup_conf", Native.Ip.DomainLookupConf)), ("domain-lookup", ("domain_lookup", Native.Ip.DomainLookup)), ("dns", ("dns", Native.Ip.Dns)), ("dhcp", ("dhcp", Native.Ip.Dhcp)), ("forward-protocol", ("forward_protocol", Native.Ip.ForwardProtocol)), ("gratuitous-arps-conf", ("gratuitous_arps_conf", Native.Ip.GratuitousArpsConf)), ("ftp", ("ftp", Native.Ip.Ftp)), ("telnet", ("telnet", Native.Ip.Telnet)), ("host", ("host", Native.Ip.Host)), ("multicast", ("multicast", Native.Ip.Multicast)), ("name-server", ("name_server", Native.Ip.NameServer)), ("pim", ("pim", Native.Ip.Pim)), ("prefix-list", ("prefix_list", Native.Ip.PrefixList)), ("route", ("route", Native.Ip.Route)), ("routing", ("routing", Native.Ip.Routing)), ("explicit-path", ("explicit_path", Native.Ip.ExplicitPath)), ("scp", ("scp", Native.Ip.Scp)), ("spd", ("spd", Native.Ip.Spd)), ("bootp", ("bootp", Native.Ip.Bootp)), ("ssh", ("ssh", Native.Ip.Ssh)), ("tcp", ("tcp", Native.Ip.Tcp)), ("tftp", ("tftp", Native.Ip.Tftp)), ("access-list", ("access_list", Native.Ip.AccessList)), ("device", ("device", Native.Ip.Device)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Ip.Igmp)), ("Cisco-IOS-XE-aaa:radius", ("radius", Native.Ip.Radius)), ("Cisco-IOS-XE-aaa:tacacs", ("tacacs", Native.Ip.Tacacs)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Ip.Nbar)), ("Cisco-IOS-XE-multicast:msdp", ("msdp", Native.Ip.Msdp)), ("Cisco-IOS-XE-multicast:mcr-conf", ("mcr_conf", Native.Ip.McrConf)), ("Cisco-IOS-XE-multicast:multicast-routing", ("multicast_routing", Native.Ip.MulticastRouting)), ("Cisco-IOS-XE-multicast:mroute", ("mroute", Native.Ip.Mroute)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Ip.Rsvp)), ("Cisco-IOS-XE-http:http", ("http", Native.Ip.Http)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Ip.Nat)), ("Cisco-IOS-XE-icmp:icmp", ("icmp", Native.Ip.Icmp)), ("Cisco-IOS-XE-bgp:community-list", ("community_list", Native.Ip.CommunityList)), ("Cisco-IOS-XE-bgp:extcommunity-list", ("extcommunity_list", Native.Ip.ExtcommunityList)), ("Cisco-IOS-XE-sla:sla", ("sla", Native.Ip.Sla)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Ip.Wccp))])
            self._leafs = OrderedDict([
                ('subnet_zero', (YLeaf(YType.boolean, 'subnet-zero'), ['bool'])),
                ('host_routing', (YLeaf(YType.empty, 'host-routing'), ['Empty'])),
                ('classless', (YLeaf(YType.empty, 'classless'), ['Empty'])),
                ('domain_name', (YLeaf(YType.str, 'domain-name'), ['str'])),
                ('default_gateway', (YLeaf(YType.str, 'default-gateway'), ['str'])),
                ('source_route', (YLeaf(YType.boolean, 'source-route'), ['bool'])),
            ])
            self.subnet_zero = None
            self.host_routing = None
            self.classless = None
            self.domain_name = None
            self.default_gateway = None
            self.source_route = None

            self.ospf = Native.Ip.Ospf()
            self.ospf.parent = self
            self._children_name_map["ospf"] = "ospf"

            self.admission = Native.Ip.Admission()
            self.admission.parent = self
            self._children_name_map["admission"] = "admission"

            self.arp = Native.Ip.Arp()
            self.arp.parent = self
            self._children_name_map["arp"] = "arp"

            self.domain_list = Native.Ip.DomainList()
            self.domain_list.parent = self
            self._children_name_map["domain_list"] = "domain-list"

            self.finger = None
            self._children_name_map["finger"] = "finger"

            self.rcmd = Native.Ip.Rcmd()
            self.rcmd.parent = self
            self._children_name_map["rcmd"] = "rcmd"

            self.bgp_community = Native.Ip.BgpCommunity()
            self.bgp_community.parent = self
            self._children_name_map["bgp_community"] = "bgp-community"

            self.as_path = Native.Ip.AsPath()
            self.as_path.parent = self
            self._children_name_map["as_path"] = "as-path"

            self.local = Native.Ip.Local()
            self.local.parent = self
            self._children_name_map["local"] = "local"

            self.cef = None
            self._children_name_map["cef"] = "cef"

            self.domain = Native.Ip.Domain()
            self.domain.parent = self
            self._children_name_map["domain"] = "domain"

            self.domain_lookup_conf = Native.Ip.DomainLookupConf()
            self.domain_lookup_conf.parent = self
            self._children_name_map["domain_lookup_conf"] = "domain-lookup-conf"

            self.domain_lookup = None
            self._children_name_map["domain_lookup"] = "domain-lookup"

            self.dns = Native.Ip.Dns()
            self.dns.parent = self
            self._children_name_map["dns"] = "dns"

            self.dhcp = Native.Ip.Dhcp()
            self.dhcp.parent = self
            self._children_name_map["dhcp"] = "dhcp"

            self.forward_protocol = Native.Ip.ForwardProtocol()
            self.forward_protocol.parent = self
            self._children_name_map["forward_protocol"] = "forward-protocol"

            self.gratuitous_arps_conf = Native.Ip.GratuitousArpsConf()
            self.gratuitous_arps_conf.parent = self
            self._children_name_map["gratuitous_arps_conf"] = "gratuitous-arps-conf"

            self.ftp = Native.Ip.Ftp()
            self.ftp.parent = self
            self._children_name_map["ftp"] = "ftp"

            self.telnet = Native.Ip.Telnet()
            self.telnet.parent = self
            self._children_name_map["telnet"] = "telnet"

            self.host = Native.Ip.Host()
            self.host.parent = self
            self._children_name_map["host"] = "host"

            self.multicast = Native.Ip.Multicast()
            self.multicast.parent = self
            self._children_name_map["multicast"] = "multicast"

            self.name_server = Native.Ip.NameServer()
            self.name_server.parent = self
            self._children_name_map["name_server"] = "name-server"

            self.pim = Native.Ip.Pim()
            self.pim.parent = self
            self._children_name_map["pim"] = "pim"

            self.prefix_list = Native.Ip.PrefixList()
            self.prefix_list.parent = self
            self._children_name_map["prefix_list"] = "prefix-list"

            self.route = Native.Ip.Route()
            self.route.parent = self
            self._children_name_map["route"] = "route"

            self.routing = None
            self._children_name_map["routing"] = "routing"

            self.explicit_path = Native.Ip.ExplicitPath()
            self.explicit_path.parent = self
            self._children_name_map["explicit_path"] = "explicit-path"

            self.scp = Native.Ip.Scp()
            self.scp.parent = self
            self._children_name_map["scp"] = "scp"

            self.spd = Native.Ip.Spd()
            self.spd.parent = self
            self._children_name_map["spd"] = "spd"

            self.bootp = Native.Ip.Bootp()
            self.bootp.parent = self
            self._children_name_map["bootp"] = "bootp"

            self.ssh = Native.Ip.Ssh()
            self.ssh.parent = self
            self._children_name_map["ssh"] = "ssh"

            self.tcp = Native.Ip.Tcp()
            self.tcp.parent = self
            self._children_name_map["tcp"] = "tcp"

            self.tftp = Native.Ip.Tftp()
            self.tftp.parent = self
            self._children_name_map["tftp"] = "tftp"

            self.access_list = Native.Ip.AccessList()
            self.access_list.parent = self
            self._children_name_map["access_list"] = "access-list"

            self.device = Native.Ip.Device()
            self.device.parent = self
            self._children_name_map["device"] = "device"

            self.igmp = Native.Ip.Igmp()
            self.igmp.parent = self
            self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

            self.radius = Native.Ip.Radius()
            self.radius.parent = self
            self._children_name_map["radius"] = "Cisco-IOS-XE-aaa:radius"

            self.tacacs = Native.Ip.Tacacs()
            self.tacacs.parent = self
            self._children_name_map["tacacs"] = "Cisco-IOS-XE-aaa:tacacs"

            self.nbar = Native.Ip.Nbar()
            self.nbar.parent = self
            self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

            self.msdp = Native.Ip.Msdp()
            self.msdp.parent = self
            self._children_name_map["msdp"] = "Cisco-IOS-XE-multicast:msdp"

            self.mcr_conf = Native.Ip.McrConf()
            self.mcr_conf.parent = self
            self._children_name_map["mcr_conf"] = "Cisco-IOS-XE-multicast:mcr-conf"

            self.multicast_routing = None
            self._children_name_map["multicast_routing"] = "Cisco-IOS-XE-multicast:multicast-routing"

            self.mroute = Native.Ip.Mroute()
            self.mroute.parent = self
            self._children_name_map["mroute"] = "Cisco-IOS-XE-multicast:mroute"

            self.rsvp = Native.Ip.Rsvp()
            self.rsvp.parent = self
            self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

            self.http = Native.Ip.Http()
            self.http.parent = self
            self._children_name_map["http"] = "Cisco-IOS-XE-http:http"

            self.nat = Native.Ip.Nat()
            self.nat.parent = self
            self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

            self.icmp = Native.Ip.Icmp()
            self.icmp.parent = self
            self._children_name_map["icmp"] = "Cisco-IOS-XE-icmp:icmp"

            self.community_list = Native.Ip.CommunityList()
            self.community_list.parent = self
            self._children_name_map["community_list"] = "Cisco-IOS-XE-bgp:community-list"

            self.extcommunity_list = Native.Ip.ExtcommunityList()
            self.extcommunity_list.parent = self
            self._children_name_map["extcommunity_list"] = "Cisco-IOS-XE-bgp:extcommunity-list"

            self.sla = Native.Ip.Sla()
            self.sla.parent = self
            self._children_name_map["sla"] = "Cisco-IOS-XE-sla:sla"

            self.wccp = Native.Ip.Wccp()
            self.wccp.parent = self
            self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

            self.vrf = YList(self)
            self._segment_path = lambda: "ip"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Ip, [u'subnet_zero', u'host_routing', u'classless', u'domain_name', u'default_gateway', u'source_route'], name, value)


        class Ospf(Entity):
            """
            Configure for ospf
            
            .. attribute:: name_lookup
            
            	Display OSPF router ids as DNS names
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Ospf, self).__init__()

                self.yang_name = "ospf"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name_lookup', (YLeaf(YType.empty, 'name-lookup'), ['Empty'])),
                ])
                self.name_lookup = None
                self._segment_path = lambda: "ospf"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Ospf, [u'name_lookup'], name, value)


        class Admission(Entity):
            """
            Network Admission Control (NAC)
            
            .. attribute:: watch_list
            
            	Watch\-list
            	**type**\:  :py:class:`WatchList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Admission.WatchList>`
            
            .. attribute:: name
            
            	Specify an Authentication Proxy Rule
            	**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Admission.Name>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Admission, self).__init__()

                self.yang_name = "admission"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("watch-list", ("watch_list", Native.Ip.Admission.WatchList)), ("name", ("name", Native.Ip.Admission.Name))])
                self._leafs = OrderedDict()

                self.watch_list = Native.Ip.Admission.WatchList()
                self.watch_list.parent = self
                self._children_name_map["watch_list"] = "watch-list"

                self.name = Native.Ip.Admission.Name()
                self.name.parent = self
                self._children_name_map["name"] = "name"
                self._segment_path = lambda: "admission"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Admission, [], name, value)


            class WatchList(Entity):
                """
                Watch\-list
                
                .. attribute:: expiry_time
                
                	Configure expiry time for watch\-list entries
                	**type**\: int
                
                	**range:** 0..35791
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Admission.WatchList, self).__init__()

                    self.yang_name = "watch-list"
                    self.yang_parent_name = "admission"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('expiry_time', (YLeaf(YType.uint16, 'expiry-time'), ['int'])),
                    ])
                    self.expiry_time = None
                    self._segment_path = lambda: "watch-list"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/admission/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Admission.WatchList, [u'expiry_time'], name, value)


            class Name(Entity):
                """
                Specify an Authentication Proxy Rule
                
                .. attribute:: webauth
                
                	help
                	**type**\:  :py:class:`Webauth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Admission.Name.Webauth>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Admission.Name, self).__init__()

                    self.yang_name = "name"
                    self.yang_parent_name = "admission"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("webauth", ("webauth", Native.Ip.Admission.Name.Webauth))])
                    self._leafs = OrderedDict()

                    self.webauth = Native.Ip.Admission.Name.Webauth()
                    self.webauth.parent = self
                    self._children_name_map["webauth"] = "webauth"
                    self._segment_path = lambda: "name"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/admission/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Admission.Name, [], name, value)


                class Webauth(Entity):
                    """
                    help
                    
                    .. attribute:: proxy
                    
                    	Authentication Proxy Protocol
                    	**type**\:  :py:class:`Proxy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Admission.Name.Webauth.Proxy>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Admission.Name.Webauth, self).__init__()

                        self.yang_name = "webauth"
                        self.yang_parent_name = "name"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("proxy", ("proxy", Native.Ip.Admission.Name.Webauth.Proxy))])
                        self._leafs = OrderedDict()

                        self.proxy = Native.Ip.Admission.Name.Webauth.Proxy()
                        self.proxy.parent = self
                        self._children_name_map["proxy"] = "proxy"
                        self._segment_path = lambda: "webauth"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/admission/name/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Admission.Name.Webauth, [], name, value)


                    class Proxy(Entity):
                        """
                        Authentication Proxy Protocol
                        
                        .. attribute:: http
                        
                        	HTTP Protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.Admission.Name.Webauth.Proxy, self).__init__()

                            self.yang_name = "proxy"
                            self.yang_parent_name = "webauth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('http', (YLeaf(YType.empty, 'http'), ['Empty'])),
                            ])
                            self.http = None
                            self._segment_path = lambda: "proxy"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/admission/name/webauth/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Admission.Name.Webauth.Proxy, [u'http'], name, value)


        class Arp(Entity):
            """
            IP ARP global configuration
            
            .. attribute:: incomplete
            
            	Fine\-tune the ARP Retry parameters
            	**type**\:  :py:class:`Incomplete <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Arp.Incomplete>`
            
            .. attribute:: inspection
            
            	Arp Inspection configuration
            	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Arp.Inspection>`
            
            .. attribute:: proxy
            
            	Gratuitous ARP control
            	**type**\:  :py:class:`Proxy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Arp.Proxy>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Arp, self).__init__()

                self.yang_name = "arp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("incomplete", ("incomplete", Native.Ip.Arp.Incomplete)), ("inspection", ("inspection", Native.Ip.Arp.Inspection)), ("proxy", ("proxy", Native.Ip.Arp.Proxy))])
                self._leafs = OrderedDict()

                self.incomplete = Native.Ip.Arp.Incomplete()
                self.incomplete.parent = self
                self._children_name_map["incomplete"] = "incomplete"

                self.inspection = Native.Ip.Arp.Inspection()
                self.inspection.parent = self
                self._children_name_map["inspection"] = "inspection"

                self.proxy = Native.Ip.Arp.Proxy()
                self.proxy.parent = self
                self._children_name_map["proxy"] = "proxy"
                self._segment_path = lambda: "arp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Arp, [], name, value)


            class Incomplete(Entity):
                """
                Fine\-tune the ARP Retry parameters
                
                .. attribute:: entries
                
                	Specify the number of IP addresses to resolve
                	**type**\: int
                
                	**range:** 1..2147483647
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Arp.Incomplete, self).__init__()

                    self.yang_name = "incomplete"
                    self.yang_parent_name = "arp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('entries', (YLeaf(YType.uint32, 'entries'), ['int'])),
                    ])
                    self.entries = None
                    self._segment_path = lambda: "incomplete"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/arp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Arp.Incomplete, [u'entries'], name, value)


            class Inspection(Entity):
                """
                Arp Inspection configuration
                
                .. attribute:: filter
                
                	Specify ARP acl to be applied
                	**type**\: list of  		 :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Arp.Inspection.Filter>`
                
                .. attribute:: validate
                
                	Validate addresses
                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Arp.Inspection.Validate>`
                
                .. attribute:: log_buffer
                
                	Log Buffer Configuration
                	**type**\:  :py:class:`LogBuffer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Arp.Inspection.LogBuffer>`
                
                .. attribute:: vlan
                
                	Enable/Disable ARP Inspection on vlans
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Arp.Inspection, self).__init__()

                    self.yang_name = "inspection"
                    self.yang_parent_name = "arp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("filter", ("filter", Native.Ip.Arp.Inspection.Filter)), ("validate", ("validate", Native.Ip.Arp.Inspection.Validate)), ("log-buffer", ("log_buffer", Native.Ip.Arp.Inspection.LogBuffer))])
                    self._leafs = OrderedDict([
                        ('vlan', (YLeaf(YType.str, 'vlan'), ['str'])),
                    ])
                    self.vlan = None

                    self.validate = Native.Ip.Arp.Inspection.Validate()
                    self.validate.parent = self
                    self._children_name_map["validate"] = "validate"

                    self.log_buffer = Native.Ip.Arp.Inspection.LogBuffer()
                    self.log_buffer.parent = self
                    self._children_name_map["log_buffer"] = "log-buffer"

                    self.filter = YList(self)
                    self._segment_path = lambda: "inspection"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/arp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Arp.Inspection, [u'vlan'], name, value)


                class Filter(Entity):
                    """
                    Specify ARP acl to be applied
                    
                    .. attribute:: arpacl  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: vlan
                    
                    	Vlans to apply the filter
                    	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Arp.Inspection.Filter.Vlan>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Arp.Inspection.Filter, self).__init__()

                        self.yang_name = "filter"
                        self.yang_parent_name = "inspection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['arpacl']
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Ip.Arp.Inspection.Filter.Vlan))])
                        self._leafs = OrderedDict([
                            ('arpacl', (YLeaf(YType.str, 'arpacl'), ['str'])),
                        ])
                        self.arpacl = None

                        self.vlan = YList(self)
                        self._segment_path = lambda: "filter" + "[arpacl='" + str(self.arpacl) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/arp/inspection/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Arp.Inspection.Filter, [u'arpacl'], name, value)


                    class Vlan(Entity):
                        """
                        Vlans to apply the filter
                        
                        .. attribute:: vlan_range  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: static
                        
                        	Apply the ACL statically
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.Arp.Inspection.Filter.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "filter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['vlan_range']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                            ])
                            self.vlan_range = None
                            self.static = None
                            self._segment_path = lambda: "vlan" + "[vlan-range='" + str(self.vlan_range) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Arp.Inspection.Filter.Vlan, [u'vlan_range', u'static'], name, value)


                class Validate(Entity):
                    """
                    Validate addresses
                    
                    .. attribute:: src_mac
                    
                    	Validate source MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dst_mac
                    
                    	Validate destination MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ip
                    
                    	Validate IP addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: allow
                    
                    	
                    	**type**\:  :py:class:`Allow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Arp.Inspection.Validate.Allow>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Arp.Inspection.Validate, self).__init__()

                        self.yang_name = "validate"
                        self.yang_parent_name = "inspection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("allow", ("allow", Native.Ip.Arp.Inspection.Validate.Allow))])
                        self._leafs = OrderedDict([
                            ('src_mac', (YLeaf(YType.empty, 'src-mac'), ['Empty'])),
                            ('dst_mac', (YLeaf(YType.empty, 'dst-mac'), ['Empty'])),
                            ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                        ])
                        self.src_mac = None
                        self.dst_mac = None
                        self.ip = None

                        self.allow = Native.Ip.Arp.Inspection.Validate.Allow()
                        self.allow.parent = self
                        self._children_name_map["allow"] = "allow"
                        self._segment_path = lambda: "validate"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/arp/inspection/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Arp.Inspection.Validate, [u'src_mac', u'dst_mac', u'ip'], name, value)


                    class Allow(Entity):
                        """
                        
                        
                        .. attribute:: zeros
                        
                        	Allow 0.0.0.0 sender IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.Arp.Inspection.Validate.Allow, self).__init__()

                            self.yang_name = "allow"
                            self.yang_parent_name = "validate"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('zeros', (YLeaf(YType.empty, 'zeros'), ['Empty'])),
                            ])
                            self.zeros = None
                            self._segment_path = lambda: "allow"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/arp/inspection/validate/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Arp.Inspection.Validate.Allow, [u'zeros'], name, value)


                class LogBuffer(Entity):
                    """
                    Log Buffer Configuration
                    
                    .. attribute:: entries
                    
                    	Number of entries for log buffer
                    	**type**\: int
                    
                    	**range:** 0..1024
                    
                    .. attribute:: logs
                    
                    	Number of logs per interval
                    	**type**\:  :py:class:`Logs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Arp.Inspection.LogBuffer.Logs>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Arp.Inspection.LogBuffer, self).__init__()

                        self.yang_name = "log-buffer"
                        self.yang_parent_name = "inspection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("logs", ("logs", Native.Ip.Arp.Inspection.LogBuffer.Logs))])
                        self._leafs = OrderedDict([
                            ('entries', (YLeaf(YType.uint16, 'entries'), ['int'])),
                        ])
                        self.entries = None

                        self.logs = Native.Ip.Arp.Inspection.LogBuffer.Logs()
                        self.logs.parent = self
                        self._children_name_map["logs"] = "logs"
                        self._segment_path = lambda: "log-buffer"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/arp/inspection/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Arp.Inspection.LogBuffer, [u'entries'], name, value)


                    class Logs(Entity):
                        """
                        Number of logs per interval
                        
                        .. attribute:: entries
                        
                        	Number of entries for log buffer
                        	**type**\: int
                        
                        	**range:** 0..1024
                        
                        .. attribute:: interval
                        
                        	Interval for controlling logging rate
                        	**type**\: int
                        
                        	**range:** 0..86400
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.Arp.Inspection.LogBuffer.Logs, self).__init__()

                            self.yang_name = "logs"
                            self.yang_parent_name = "log-buffer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entries', (YLeaf(YType.uint16, 'entries'), ['int'])),
                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                            ])
                            self.entries = None
                            self.interval = None
                            self._segment_path = lambda: "logs"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/arp/inspection/log-buffer/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Arp.Inspection.LogBuffer.Logs, [u'entries', u'interval'], name, value)


            class Proxy(Entity):
                """
                Gratuitous ARP control
                
                .. attribute:: disable
                
                	Disable proxy ARP on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Arp.Proxy, self).__init__()

                    self.yang_name = "proxy"
                    self.yang_parent_name = "arp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                    ])
                    self.disable = None
                    self._segment_path = lambda: "proxy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/arp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Arp.Proxy, [u'disable'], name, value)


        class DomainList(Entity):
            """
            Domain name to complete unqualified host names
            
            .. attribute:: domain_name
            
            	
            	**type**\: str
            
            .. attribute:: vrf
            
            	Specify VRF
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.DomainList.Vrf>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.DomainList, self).__init__()

                self.yang_name = "domain-list"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ip.DomainList.Vrf))])
                self._leafs = OrderedDict([
                    ('domain_name', (YLeaf(YType.str, 'domain-name'), ['str'])),
                ])
                self.domain_name = None

                self.vrf = Native.Ip.DomainList.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"
                self._segment_path = lambda: "domain-list"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.DomainList, [u'domain_name'], name, value)


            class Vrf(Entity):
                """
                Specify VRF
                
                .. attribute:: vrf_name
                
                	
                	**type**\: str
                
                .. attribute:: domain_name
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.DomainList.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "domain-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ('domain_name', (YLeaf(YType.str, 'domain-name'), ['str'])),
                    ])
                    self.vrf_name = None
                    self.domain_name = None
                    self._segment_path = lambda: "vrf"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.DomainList.Vrf, [u'vrf_name', u'domain_name'], name, value)


        class Finger(Entity):
            """
            finger server
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Finger, self).__init__()

                self.yang_name = "finger"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict()
                self._segment_path = lambda: "finger"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True


        class Rcmd(Entity):
            """
            Rcmd commands
            
            .. attribute:: rcp_enable
            
            	Enable server side of RCP
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: rsh_enable
            
            	Enable server side of RSh
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Rcmd, self).__init__()

                self.yang_name = "rcmd"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('rcp_enable', (YLeaf(YType.empty, 'rcp-enable'), ['Empty'])),
                    ('rsh_enable', (YLeaf(YType.empty, 'rsh-enable'), ['Empty'])),
                ])
                self.rcp_enable = None
                self.rsh_enable = None
                self._segment_path = lambda: "rcmd"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Rcmd, [u'rcp_enable', u'rsh_enable'], name, value)


        class BgpCommunity(Entity):
            """
            format for BGP community
            
            .. attribute:: new_format
            
            	select aa\:nn format for BGP community
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.BgpCommunity, self).__init__()

                self.yang_name = "bgp-community"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('new_format', (YLeaf(YType.empty, 'new-format'), ['Empty'])),
                ])
                self.new_format = None
                self._segment_path = lambda: "bgp-community"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.BgpCommunity, [u'new_format'], name, value)


        class Vrf(Entity):
            """
            Configure an IP VPN Routing/Forwarding instance
            
            .. attribute:: name  (key)
            
            	WORD;;VPN Routing/Forwarding instance name
            	**type**\: str
            
            .. attribute:: bgp
            
            	Commands pertaining to BGP
            	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Bgp>`
            
            .. attribute:: context
            
            	Associate SNMP context with this vrf
            	**type**\: str
            
            .. attribute:: description
            
            	VRF specific description
            	**type**\: str
            
            	**length:** 1..244
            
            .. attribute:: rd
            
            	Specify Route Distinguisher
            	**type**\: str
            
            	**pattern:** (\\d\*(.\\d\*)\*)?\:(\\d\*(.\\d\*)\*)?
            
            .. attribute:: export
            
            	VRF export
            	**type**\:  :py:class:`Export <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Export>`
            
            .. attribute:: import_
            
            	VRF import
            	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Import>`
            
            .. attribute:: maximum
            
            	Maximum number of routes allowed in this routing table
            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Maximum>`
            
            	**presence node**\: True
            
            .. attribute:: mdt
            
            	Backbone Multicast Distribution Tree
            	**type**\:  :py:class:`Mdt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Mdt>`
            
            	**presence node**\: True
            
            .. attribute:: route_target
            
            	Specify Target VPN Extended Communities
            	**type**\: list of  		 :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.RouteTarget>`
            
            .. attribute:: vpn
            
            	Configure VPN ID as specified in rfc2685
            	**type**\:  :py:class:`Vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Vpn>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Ip.Vrf.Bgp)), ("export", ("export", Native.Ip.Vrf.Export)), ("import", ("import_", Native.Ip.Vrf.Import)), ("maximum", ("maximum", Native.Ip.Vrf.Maximum)), ("mdt", ("mdt", Native.Ip.Vrf.Mdt)), ("route-target", ("route_target", Native.Ip.Vrf.RouteTarget)), ("vpn", ("vpn", Native.Ip.Vrf.Vpn))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('context', (YLeaf(YType.str, 'context'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                ])
                self.name = None
                self.context = None
                self.description = None
                self.rd = None

                self.bgp = Native.Ip.Vrf.Bgp()
                self.bgp.parent = self
                self._children_name_map["bgp"] = "bgp"

                self.export = Native.Ip.Vrf.Export()
                self.export.parent = self
                self._children_name_map["export"] = "export"

                self.import_ = Native.Ip.Vrf.Import()
                self.import_.parent = self
                self._children_name_map["import_"] = "import"

                self.maximum = None
                self._children_name_map["maximum"] = "maximum"

                self.mdt = None
                self._children_name_map["mdt"] = "mdt"

                self.vpn = Native.Ip.Vrf.Vpn()
                self.vpn.parent = self
                self._children_name_map["vpn"] = "vpn"

                self.route_target = YList(self)
                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Vrf, [u'name', u'context', u'description', u'rd'], name, value)


            class Bgp(Entity):
                """
                Commands pertaining to BGP
                
                .. attribute:: next_hop
                
                	Next\-hop for the routes of a VRF in the backbone
                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Bgp.NextHop>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Vrf.Bgp, self).__init__()

                    self.yang_name = "bgp"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.Ip.Vrf.Bgp.NextHop))])
                    self._leafs = OrderedDict()

                    self.next_hop = Native.Ip.Vrf.Bgp.NextHop()
                    self.next_hop.parent = self
                    self._children_name_map["next_hop"] = "next-hop"
                    self._segment_path = lambda: "bgp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Vrf.Bgp, [], name, value)


                class NextHop(Entity):
                    """
                    Next\-hop for the routes of a VRF in the backbone
                    
                    .. attribute:: loopback
                    
                    	Loopback interface number
                    	**type**\: int
                    
                    	**range:** 0..2147483647
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Vrf.Bgp.NextHop, self).__init__()

                        self.yang_name = "next-hop"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ])
                        self.loopback = None
                        self._segment_path = lambda: "next-hop"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Vrf.Bgp.NextHop, [u'loopback'], name, value)


            class Export(Entity):
                """
                VRF export
                
                .. attribute:: map
                
                	Route\-map based VRF export
                	**type**\: str
                
                .. attribute:: ipv4
                
                	Address family based VRF export
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Export.Ipv4>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Vrf.Export, self).__init__()

                    self.yang_name = "export"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Ip.Vrf.Export.Ipv4))])
                    self._leafs = OrderedDict([
                        ('map', (YLeaf(YType.str, 'map'), ['str'])),
                    ])
                    self.map = None

                    self.ipv4 = Native.Ip.Vrf.Export.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._segment_path = lambda: "export"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Vrf.Export, [u'map'], name, value)


                class Ipv4(Entity):
                    """
                    Address family based VRF export
                    
                    .. attribute:: ipv4_type
                    
                    	
                    	**type**\:  :py:class:`Ipv4Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Export.Ipv4.Ipv4Type>`
                    
                    .. attribute:: upper_limit
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: map
                    
                    	Route\-map based VRF export
                    	**type**\: str
                    
                    .. attribute:: map_only
                    
                    	Route\-map based VRF export
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Vrf.Export.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "export"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ipv4_type', (YLeaf(YType.enumeration, 'ipv4-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Vrf.Export.Ipv4.Ipv4Type')])),
                            ('upper_limit', (YLeaf(YType.uint32, 'upper-limit'), ['int'])),
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                            ('map_only', (YLeaf(YType.str, 'map-only'), ['str'])),
                        ])
                        self.ipv4_type = None
                        self.upper_limit = None
                        self.map = None
                        self.map_only = None
                        self._segment_path = lambda: "ipv4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Vrf.Export.Ipv4, [u'ipv4_type', u'upper_limit', u'map', u'map_only'], name, value)

                    class Ipv4Type(Enum):
                        """
                        Ipv4Type (Enum Class)

                        .. data:: unicast = 0

                        .. data:: multicast = 1

                        """

                        unicast = Enum.YLeaf(0, "unicast")

                        multicast = Enum.YLeaf(1, "multicast")



            class Import(Entity):
                """
                VRF import
                
                .. attribute:: map
                
                	Route\-map based VRF import
                	**type**\: str
                
                .. attribute:: ipv4
                
                	Address family based VRF import
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Import.Ipv4>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Vrf.Import, self).__init__()

                    self.yang_name = "import"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Ip.Vrf.Import.Ipv4))])
                    self._leafs = OrderedDict([
                        ('map', (YLeaf(YType.str, 'map'), ['str'])),
                    ])
                    self.map = None

                    self.ipv4 = Native.Ip.Vrf.Import.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._segment_path = lambda: "import"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Vrf.Import, [u'map'], name, value)


                class Ipv4(Entity):
                    """
                    Address family based VRF import
                    
                    .. attribute:: ipv4_type
                    
                    	
                    	**type**\:  :py:class:`Ipv4Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Import.Ipv4.Ipv4Type>`
                    
                    .. attribute:: upper_limit
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: map
                    
                    	Route\-map based VRF import
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Vrf.Import.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "import"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ipv4_type', (YLeaf(YType.enumeration, 'ipv4-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Vrf.Import.Ipv4.Ipv4Type')])),
                            ('upper_limit', (YLeaf(YType.uint32, 'upper-limit'), ['int'])),
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.ipv4_type = None
                        self.upper_limit = None
                        self.map = None
                        self._segment_path = lambda: "ipv4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Vrf.Import.Ipv4, [u'ipv4_type', u'upper_limit', u'map'], name, value)

                    class Ipv4Type(Enum):
                        """
                        Ipv4Type (Enum Class)

                        .. data:: unicast = 0

                        .. data:: multicast = 1

                        """

                        unicast = Enum.YLeaf(0, "unicast")

                        multicast = Enum.YLeaf(1, "multicast")



            class Maximum(Entity):
                """
                Maximum number of routes allowed in this routing table
                
                .. attribute:: routes
                
                	Maximum number of routes allowed in this routing table
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: threshold
                
                	Threshold
                	**type**\: int
                
                	**range:** 1..100
                
                .. attribute:: reinstall
                
                	Reinstall previous rejected route due to over maximum route limit
                	**type**\: int
                
                	**range:** 1..100
                
                .. attribute:: warning_only
                
                	Only give a warning message if is limit exceeded
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Vrf.Maximum, self).__init__()

                    self.yang_name = "maximum"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('routes', (YLeaf(YType.uint32, 'routes'), ['int'])),
                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                        ('reinstall', (YLeaf(YType.uint16, 'reinstall'), ['int'])),
                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                    ])
                    self.routes = None
                    self.threshold = None
                    self.reinstall = None
                    self.warning_only = None
                    self._segment_path = lambda: "maximum"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Vrf.Maximum, [u'routes', u'threshold', u'reinstall', u'warning_only'], name, value)


            class Mdt(Entity):
                """
                Backbone Multicast Distribution Tree
                
                .. attribute:: default
                
                	The default group
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: log_reuse
                
                	Event logging for data MDT reuse
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: data
                
                	MDT data group range
                	**type**\:  :py:class:`Data <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.Mdt.Data>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Vrf.Mdt, self).__init__()

                    self.yang_name = "mdt"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("data", ("data", Native.Ip.Vrf.Mdt.Data))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('default', (YLeaf(YType.str, 'default'), ['str'])),
                        ('log_reuse', (YLeaf(YType.empty, 'log-reuse'), ['Empty'])),
                    ])
                    self.default = None
                    self.log_reuse = None

                    self.data = Native.Ip.Vrf.Mdt.Data()
                    self.data.parent = self
                    self._children_name_map["data"] = "data"
                    self._segment_path = lambda: "mdt"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Vrf.Mdt, [u'default', u'log_reuse'], name, value)


                class Data(Entity):
                    """
                    MDT data group range
                    
                    .. attribute:: mulicast_address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: wildcard_bits
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: threshold
                    
                    	MDT switching threshold
                    	**type**\: int
                    
                    	**range:** 1..4294967
                    
                    .. attribute:: threshold_list
                    
                    	Access\-list
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 100..199
                    
                    		**type**\: int
                    
                    			**range:** 2000..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-fA\-F].\*
                    
                    .. attribute:: list
                    
                    	Access\-list
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 100..199
                    
                    		**type**\: int
                    
                    			**range:** 2000..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-fA\-F].\*
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Vrf.Mdt.Data, self).__init__()

                        self.yang_name = "data"
                        self.yang_parent_name = "mdt"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mulicast_address', (YLeaf(YType.str, 'mulicast-address'), ['str'])),
                            ('wildcard_bits', (YLeaf(YType.str, 'wildcard-bits'), ['str'])),
                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                            ('threshold_list', (YLeaf(YType.str, 'threshold-list'), ['int','int','str'])),
                            ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                        ])
                        self.mulicast_address = None
                        self.wildcard_bits = None
                        self.threshold = None
                        self.threshold_list = None
                        self.list = None
                        self._segment_path = lambda: "data"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Vrf.Mdt.Data, [u'mulicast_address', u'wildcard_bits', u'threshold', u'threshold_list', u'list'], name, value)


            class RouteTarget(Entity):
                """
                Specify Target VPN Extended Communities
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Vrf.RouteTarget.Direction>`
                
                .. attribute:: target  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (\\d\*(.\\d\*)\*)?\:(\\d\*(.\\d\*)\*)?
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Vrf.RouteTarget, self).__init__()

                    self.yang_name = "route-target"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction','target']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Vrf.RouteTarget.Direction')])),
                        ('target', (YLeaf(YType.str, 'target'), ['str'])),
                    ])
                    self.direction = None
                    self.target = None
                    self._segment_path = lambda: "route-target" + "[direction='" + str(self.direction) + "']" + "[target='" + str(self.target) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Vrf.RouteTarget, [u'direction', u'target'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: both = 0

                    .. data:: export = 1

                    .. data:: import_ = 2

                    """

                    both = Enum.YLeaf(0, "both")

                    export = Enum.YLeaf(1, "export")

                    import_ = Enum.YLeaf(2, "import")



            class Vpn(Entity):
                """
                Configure VPN ID as specified in rfc2685
                
                .. attribute:: id
                
                	Configure VPN ID in rfc2685 format
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F][0\-9a\-fA\-F]?[0\-9a\-fA\-F]?\:[0\-9a\-fA\-F][0\-9a\-fA\-F]?[0\-9a\-fA\-F]?[0\-9a\-fA\-F]?
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Vrf.Vpn, self).__init__()

                    self.yang_name = "vpn"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                    ])
                    self.id = None
                    self._segment_path = lambda: "vpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Vrf.Vpn, [u'id'], name, value)


        class AsPath(Entity):
            """
            BGP autonomous system path filter
            
            .. attribute:: access_list
            
            	Specify an access list number
            	**type**\: list of  		 :py:class:`AccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AsPath.AccessList>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.AsPath, self).__init__()

                self.yang_name = "as-path"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-bgp:access-list", ("access_list", Native.Ip.AsPath.AccessList))])
                self._leafs = OrderedDict()

                self.access_list = YList(self)
                self._segment_path = lambda: "as-path"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.AsPath, [], name, value)


            class AccessList(Entity):
                """
                Specify an access list number
                
                .. attribute:: name  (key)
                
                	
                	**type**\: int
                
                	**range:** 1..500
                
                .. attribute:: deny
                
                	Specify community to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AsPath.AccessList.Deny>`
                
                .. attribute:: permit
                
                	Specify community to accept
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AsPath.AccessList.Permit>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.AsPath.AccessList, self).__init__()

                    self.yang_name = "access-list"
                    self.yang_parent_name = "as-path"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.AsPath.AccessList.Deny)), ("permit", ("permit", Native.Ip.AsPath.AccessList.Permit))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ])
                    self.name = None

                    self.deny = Native.Ip.AsPath.AccessList.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.permit = Native.Ip.AsPath.AccessList.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._segment_path = lambda: "Cisco-IOS-XE-bgp:access-list" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/as-path/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.AsPath.AccessList, ['name'], name, value)


                class Deny(Entity):
                    """
                    Specify community to reject
                    
                    .. attribute:: deny_list
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.AsPath.AccessList.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "access-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('deny_list', (YLeafList(YType.str, 'deny-list'), ['str'])),
                        ])
                        self.deny_list = []
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.AsPath.AccessList.Deny, ['deny_list'], name, value)


                class Permit(Entity):
                    """
                    Specify community to accept
                    
                    .. attribute:: permit_list
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.AsPath.AccessList.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "access-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('permit_list', (YLeafList(YType.str, 'permit-list'), ['str'])),
                        ])
                        self.permit_list = []
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.AsPath.AccessList.Permit, ['permit_list'], name, value)


        class Local(Entity):
            """
            Specify local options
            
            .. attribute:: pool
            
            	IP Local address pool lists
            	**type**\: list of  		 :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Local.Pool>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Local, self).__init__()

                self.yang_name = "local"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("pool", ("pool", Native.Ip.Local.Pool))])
                self._leafs = OrderedDict()

                self.pool = YList(self)
                self._segment_path = lambda: "local"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Local, [], name, value)


            class Pool(Entity):
                """
                IP Local address pool lists
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Local.Pool.Id>`
                
                .. attribute:: start
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: last
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: group
                
                	Create ip local pool group
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Local.Pool, self).__init__()

                    self.yang_name = "pool"
                    self.yang_parent_name = "local"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Local.Pool.Id')])),
                        ('start', (YLeaf(YType.str, 'start'), ['str'])),
                        ('last', (YLeaf(YType.str, 'last'), ['str'])),
                        ('group', (YLeaf(YType.str, 'group'), ['str'])),
                    ])
                    self.id = None
                    self.start = None
                    self.last = None
                    self.group = None
                    self._segment_path = lambda: "pool" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/local/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Local.Pool, [u'id', u'start', u'last', u'group'], name, value)

                class Id(Enum):
                    """
                    Id (Enum Class)

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")



        class Cef(Entity):
            """
            Cisco Express Forwarding
            
            .. attribute:: accounting
            
            	Enable CEF accounting
            	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.Accounting>`
            
            .. attribute:: distributed
            
            	Distributed Cisco Express Forwarding
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: optimize
            
            	Optimizations
            	**type**\:  :py:class:`Optimize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.Optimize>`
            
            .. attribute:: traffic_statistics
            
            	Enable collection of traffic statistics
            	**type**\:  :py:class:`TrafficStatistics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.TrafficStatistics>`
            
            .. attribute:: load_sharing
            
            	Load sharing
            	**type**\:  :py:class:`LoadSharing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.LoadSharing>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Cef, self).__init__()

                self.yang_name = "cef"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-cef:accounting", ("accounting", Native.Ip.Cef.Accounting)), ("Cisco-IOS-XE-cef:optimize", ("optimize", Native.Ip.Cef.Optimize)), ("Cisco-IOS-XE-cef:traffic-statistics", ("traffic_statistics", Native.Ip.Cef.TrafficStatistics)), ("Cisco-IOS-XE-cef:load-sharing", ("load_sharing", Native.Ip.Cef.LoadSharing))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('distributed', (YLeaf(YType.empty, 'Cisco-IOS-XE-cef:distributed'), ['Empty'])),
                ])
                self.distributed = None

                self.accounting = Native.Ip.Cef.Accounting()
                self.accounting.parent = self
                self._children_name_map["accounting"] = "Cisco-IOS-XE-cef:accounting"

                self.optimize = Native.Ip.Cef.Optimize()
                self.optimize.parent = self
                self._children_name_map["optimize"] = "Cisco-IOS-XE-cef:optimize"

                self.traffic_statistics = Native.Ip.Cef.TrafficStatistics()
                self.traffic_statistics.parent = self
                self._children_name_map["traffic_statistics"] = "Cisco-IOS-XE-cef:traffic-statistics"

                self.load_sharing = Native.Ip.Cef.LoadSharing()
                self.load_sharing.parent = self
                self._children_name_map["load_sharing"] = "Cisco-IOS-XE-cef:load-sharing"
                self._segment_path = lambda: "cef"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Cef, ['distributed'], name, value)


            class Accounting(Entity):
                """
                Enable CEF accounting
                
                .. attribute:: per_prefix
                
                	Enable per prefix accounting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: non_recursive
                
                	Enable accounting for traffic through non\-recursive prefixes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: prefix_length
                
                	Enable prefix length accounting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: load_balance_hash
                
                	Enable load balance hash accounting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-cef'
                _revision = '2017-05-19'

                def __init__(self):
                    super(Native.Ip.Cef.Accounting, self).__init__()

                    self.yang_name = "accounting"
                    self.yang_parent_name = "cef"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('per_prefix', (YLeaf(YType.empty, 'per-prefix'), ['Empty'])),
                        ('non_recursive', (YLeaf(YType.empty, 'non-recursive'), ['Empty'])),
                        ('prefix_length', (YLeaf(YType.empty, 'prefix-length'), ['Empty'])),
                        ('load_balance_hash', (YLeaf(YType.empty, 'load-balance-hash'), ['Empty'])),
                    ])
                    self.per_prefix = None
                    self.non_recursive = None
                    self.prefix_length = None
                    self.load_balance_hash = None
                    self._segment_path = lambda: "Cisco-IOS-XE-cef:accounting"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Cef.Accounting, ['per_prefix', 'non_recursive', 'prefix_length', 'load_balance_hash'], name, value)


            class Optimize(Entity):
                """
                Optimizations
                
                .. attribute:: neighbor
                
                	Optimizations for directly connected neighbors
                	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.Optimize.Neighbor>`
                
                

                """

                _prefix = 'ios-cef'
                _revision = '2017-05-19'

                def __init__(self):
                    super(Native.Ip.Cef.Optimize, self).__init__()

                    self.yang_name = "optimize"
                    self.yang_parent_name = "cef"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Ip.Cef.Optimize.Neighbor))])
                    self._leafs = OrderedDict()

                    self.neighbor = Native.Ip.Cef.Optimize.Neighbor()
                    self.neighbor.parent = self
                    self._children_name_map["neighbor"] = "neighbor"
                    self._segment_path = lambda: "Cisco-IOS-XE-cef:optimize"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Cef.Optimize, [], name, value)


                class Neighbor(Entity):
                    """
                    Optimizations for directly connected neighbors
                    
                    .. attribute:: resolution
                    
                    	Trigger layer 2 address resolution directly from CEF
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Ip.Cef.Optimize.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "optimize"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('resolution', (YLeaf(YType.empty, 'resolution'), ['Empty'])),
                        ])
                        self.resolution = None
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/Cisco-IOS-XE-cef:optimize/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Cef.Optimize.Neighbor, ['resolution'], name, value)


            class TrafficStatistics(Entity):
                """
                Enable collection of traffic statistics
                
                .. attribute:: load_interval
                
                	Specify interval for load calculation
                	**type**\: int
                
                	**range:** 30..600
                
                .. attribute:: update_rate
                
                	Specify update rate for non\-recursive prefix stats
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-cef'
                _revision = '2017-05-19'

                def __init__(self):
                    super(Native.Ip.Cef.TrafficStatistics, self).__init__()

                    self.yang_name = "traffic-statistics"
                    self.yang_parent_name = "cef"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                        ('update_rate', (YLeaf(YType.uint16, 'update-rate'), ['int'])),
                    ])
                    self.load_interval = None
                    self.update_rate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-cef:traffic-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Cef.TrafficStatistics, ['load_interval', 'update_rate'], name, value)


            class LoadSharing(Entity):
                """
                Load sharing
                
                .. attribute:: algorithm
                
                	Per\-destination load sharing algorithm selection
                	**type**\:  :py:class:`Algorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.LoadSharing.Algorithm>`
                
                .. attribute:: key_control
                
                	Configure algorithm control values
                	**type**\:  :py:class:`KeyControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.LoadSharing.KeyControl>`
                
                

                """

                _prefix = 'ios-cef'
                _revision = '2017-05-19'

                def __init__(self):
                    super(Native.Ip.Cef.LoadSharing, self).__init__()

                    self.yang_name = "load-sharing"
                    self.yang_parent_name = "cef"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("algorithm", ("algorithm", Native.Ip.Cef.LoadSharing.Algorithm)), ("key-control", ("key_control", Native.Ip.Cef.LoadSharing.KeyControl))])
                    self._leafs = OrderedDict()

                    self.algorithm = Native.Ip.Cef.LoadSharing.Algorithm()
                    self.algorithm.parent = self
                    self._children_name_map["algorithm"] = "algorithm"

                    self.key_control = Native.Ip.Cef.LoadSharing.KeyControl()
                    self.key_control.parent = self
                    self._children_name_map["key_control"] = "key-control"
                    self._segment_path = lambda: "Cisco-IOS-XE-cef:load-sharing"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Cef.LoadSharing, [], name, value)


                class Algorithm(Entity):
                    """
                    Per\-destination load sharing algorithm selection
                    
                    .. attribute:: universal
                    
                    	Algorithm for use in most environments
                    	**type**\:  :py:class:`Universal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.LoadSharing.Algorithm.Universal>`
                    
                    .. attribute:: tunnel
                    
                    	Algorithm for use in tunnel only environments
                    	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.LoadSharing.Algorithm.Tunnel>`
                    
                    .. attribute:: original
                    
                    	Original algorithm
                    	**type**\:  :py:class:`Original <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.LoadSharing.Algorithm.Original>`
                    
                    .. attribute:: include_ports
                    
                    	Algorithm that includes layer 4 ports
                    	**type**\:  :py:class:`IncludePorts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Ip.Cef.LoadSharing.Algorithm, self).__init__()

                        self.yang_name = "algorithm"
                        self.yang_parent_name = "load-sharing"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("universal", ("universal", Native.Ip.Cef.LoadSharing.Algorithm.Universal)), ("tunnel", ("tunnel", Native.Ip.Cef.LoadSharing.Algorithm.Tunnel)), ("original", ("original", Native.Ip.Cef.LoadSharing.Algorithm.Original)), ("include-ports", ("include_ports", Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts))])
                        self._leafs = OrderedDict()

                        self.universal = Native.Ip.Cef.LoadSharing.Algorithm.Universal()
                        self.universal.parent = self
                        self._children_name_map["universal"] = "universal"

                        self.tunnel = Native.Ip.Cef.LoadSharing.Algorithm.Tunnel()
                        self.tunnel.parent = self
                        self._children_name_map["tunnel"] = "tunnel"

                        self.original = Native.Ip.Cef.LoadSharing.Algorithm.Original()
                        self.original.parent = self
                        self._children_name_map["original"] = "original"

                        self.include_ports = None
                        self._children_name_map["include_ports"] = "include-ports"
                        self._segment_path = lambda: "algorithm"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/Cisco-IOS-XE-cef:load-sharing/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Cef.LoadSharing.Algorithm, [], name, value)


                    class Universal(Entity):
                        """
                        Algorithm for use in most environments
                        
                        .. attribute:: universal
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fixed_id
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{1,8}
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Ip.Cef.LoadSharing.Algorithm.Universal, self).__init__()

                            self.yang_name = "universal"
                            self.yang_parent_name = "algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('universal', (YLeaf(YType.empty, 'universal'), ['Empty'])),
                                ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                            ])
                            self.universal = None
                            self.fixed_id = None
                            self._segment_path = lambda: "universal"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Cef.LoadSharing.Algorithm.Universal, ['universal', 'fixed_id'], name, value)


                    class Tunnel(Entity):
                        """
                        Algorithm for use in tunnel only environments
                        
                        .. attribute:: tunnel
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fixed_id
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{1,8}
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Ip.Cef.LoadSharing.Algorithm.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.empty, 'tunnel'), ['Empty'])),
                                ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                            ])
                            self.tunnel = None
                            self.fixed_id = None
                            self._segment_path = lambda: "tunnel"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Cef.LoadSharing.Algorithm.Tunnel, ['tunnel', 'fixed_id'], name, value)


                    class Original(Entity):
                        """
                        Original algorithm
                        
                        .. attribute:: original
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Ip.Cef.LoadSharing.Algorithm.Original, self).__init__()

                            self.yang_name = "original"
                            self.yang_parent_name = "algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('original', (YLeaf(YType.empty, 'original'), ['Empty'])),
                            ])
                            self.original = None
                            self._segment_path = lambda: "original"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Cef.LoadSharing.Algorithm.Original, ['original'], name, value)


                    class IncludePorts(Entity):
                        """
                        Algorithm that includes layer 4 ports
                        
                        .. attribute:: destination
                        
                        	Use destination port in hash function
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Destination>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Use source port in hash function
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts, self).__init__()

                            self.yang_name = "include-ports"
                            self.yang_parent_name = "algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Destination)), ("source", ("source", Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.destination = None
                            self._children_name_map["destination"] = "destination"

                            self.source = None
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "include-ports"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts, [], name, value)


                        class Destination(Entity):
                            """
                            Use destination port in hash function
                            
                            .. attribute:: fixed_id
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{1,8}
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-cef'
                            _revision = '2017-05-19'

                            def __init__(self):
                                super(Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "include-ports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                                ])
                                self.fixed_id = None
                                self._segment_path = lambda: "destination"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/include-ports/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Destination, ['fixed_id'], name, value)


                        class Source(Entity):
                            """
                            Use source port in hash function
                            
                            .. attribute:: destination
                            
                            	Use source and destination ports in hash function
                            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: fixed_id
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{1,8}
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-cef'
                            _revision = '2017-05-19'

                            def __init__(self):
                                super(Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "include-ports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("destination", ("destination", Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                                ])
                                self.fixed_id = None

                                self.destination = None
                                self._children_name_map["destination"] = "destination"
                                self._segment_path = lambda: "source"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/include-ports/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source, ['fixed_id'], name, value)


                            class Destination(Entity):
                                """
                                Use source and destination ports in hash function
                                
                                .. attribute:: gtp
                                
                                	Use GTP te\-id as source and destination ports in hash function
                                	**type**\:  :py:class:`Gtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination.Gtp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fixed_id
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{1,8}
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-cef'
                                _revision = '2017-05-19'

                                def __init__(self):
                                    super(Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination, self).__init__()

                                    self.yang_name = "destination"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gtp", ("gtp", Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination.Gtp))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                                    ])
                                    self.fixed_id = None

                                    self.gtp = None
                                    self._children_name_map["gtp"] = "gtp"
                                    self._segment_path = lambda: "destination"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/include-ports/source/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination, ['fixed_id'], name, value)


                                class Gtp(Entity):
                                    """
                                    Use GTP te\-id as source and destination ports in hash function
                                    
                                    .. attribute:: fixed_id
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cef'
                                    _revision = '2017-05-19'

                                    def __init__(self):
                                        super(Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination.Gtp, self).__init__()

                                        self.yang_name = "gtp"
                                        self.yang_parent_name = "destination"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                                        ])
                                        self.fixed_id = None
                                        self._segment_path = lambda: "gtp"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/include-ports/source/destination/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination.Gtp, ['fixed_id'], name, value)


                class KeyControl(Entity):
                    """
                    Configure algorithm control values
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Ip.Cef.LoadSharing.KeyControl, self).__init__()

                        self.yang_name = "key-control"
                        self.yang_parent_name = "load-sharing"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "key-control"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/cef/Cisco-IOS-XE-cef:load-sharing/%s" % self._segment_path()
                        self._is_frozen = True


        class Domain(Entity):
            """
            IP DNS Resolver
            
            .. attribute:: list
            
            	Domain name to complete unqualified host names
            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Domain.List>`
            
            .. attribute:: lookup
            
            	Enable IP Domain Name System hostname translation
            	**type**\: bool
            
            .. attribute:: lookup_settings
            
            	
            	**type**\:  :py:class:`LookupSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Domain.LookupSettings>`
            
            .. attribute:: name
            
            	Define the default domain name
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Domain, self).__init__()

                self.yang_name = "domain"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("list", ("list", Native.Ip.Domain.List)), ("lookup-settings", ("lookup_settings", Native.Ip.Domain.LookupSettings))])
                self._leafs = OrderedDict([
                    ('lookup', (YLeaf(YType.boolean, 'lookup'), ['bool'])),
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.lookup = None
                self.name = None

                self.list = Native.Ip.Domain.List()
                self.list.parent = self
                self._children_name_map["list"] = "list"

                self.lookup_settings = Native.Ip.Domain.LookupSettings()
                self.lookup_settings.parent = self
                self._children_name_map["lookup_settings"] = "lookup-settings"
                self._segment_path = lambda: "domain"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Domain, [u'lookup', u'name'], name, value)


            class List(Entity):
                """
                Domain name to complete unqualified host names
                
                .. attribute:: domain_name
                
                	
                	**type**\: list of str
                
                .. attribute:: vrf
                
                	Specify VRF
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Domain.List.Vrf>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Domain.List, self).__init__()

                    self.yang_name = "list"
                    self.yang_parent_name = "domain"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ip.Domain.List.Vrf))])
                    self._leafs = OrderedDict([
                        ('domain_name', (YLeafList(YType.str, 'domain-name'), ['str'])),
                    ])
                    self.domain_name = []

                    self.vrf = Native.Ip.Domain.List.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._segment_path = lambda: "list"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Domain.List, [u'domain_name'], name, value)


                class Vrf(Entity):
                    """
                    Specify VRF
                    
                    .. attribute:: vrf_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: domain_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Domain.List.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('domain_name', (YLeaf(YType.str, 'domain-name'), ['str'])),
                        ])
                        self.vrf_name = None
                        self.domain_name = None
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain/list/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Domain.List.Vrf, [u'vrf_name', u'domain_name'], name, value)


            class LookupSettings(Entity):
                """
                
                
                .. attribute:: lookup
                
                	Enable IP Domain Name System hostname translation
                	**type**\:  :py:class:`Lookup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Domain.LookupSettings.Lookup>`
                
                .. attribute:: name
                
                	Define the default domain name
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Domain.LookupSettings, self).__init__()

                    self.yang_name = "lookup-settings"
                    self.yang_parent_name = "domain"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("lookup", ("lookup", Native.Ip.Domain.LookupSettings.Lookup))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.lookup = Native.Ip.Domain.LookupSettings.Lookup()
                    self.lookup.parent = self
                    self._children_name_map["lookup"] = "lookup"
                    self._segment_path = lambda: "lookup-settings"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Domain.LookupSettings, [u'name'], name, value)


                class Lookup(Entity):
                    """
                    Enable IP Domain Name System hostname translation
                    
                    .. attribute:: nsap
                    
                    	Enable IP DNS queries for CLNS NSAP addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: source_interface
                    
                    	Specify source interface for DNS resolver
                    	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Domain.LookupSettings.Lookup.SourceInterface>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Domain.LookupSettings.Lookup, self).__init__()

                        self.yang_name = "lookup"
                        self.yang_parent_name = "lookup-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source-interface", ("source_interface", Native.Ip.Domain.LookupSettings.Lookup.SourceInterface))])
                        self._leafs = OrderedDict([
                            ('nsap', (YLeaf(YType.empty, 'nsap'), ['Empty'])),
                        ])
                        self.nsap = None

                        self.source_interface = Native.Ip.Domain.LookupSettings.Lookup.SourceInterface()
                        self.source_interface.parent = self
                        self._children_name_map["source_interface"] = "source-interface"
                        self._segment_path = lambda: "lookup"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain/lookup-settings/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Domain.LookupSettings.Lookup, [u'nsap'], name, value)


                    class SourceInterface(Entity):
                        """
                        Specify source interface for DNS resolver
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.Domain.LookupSettings.Lookup.SourceInterface, self).__init__()

                            self.yang_name = "source-interface"
                            self.yang_parent_name = "lookup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "source-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain/lookup-settings/lookup/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Domain.LookupSettings.Lookup.SourceInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "source-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain/lookup-settings/lookup/source-interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "source-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain/lookup-settings/lookup/source-interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "source-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain/lookup-settings/lookup/source-interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "source-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain/lookup-settings/lookup/source-interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Domain.LookupSettings.Lookup.SourceInterface.PortChannelSubinterface, [u'port_channel'], name, value)


        class DomainLookupConf(Entity):
            """
            
            
            .. attribute:: domain_lookup
            
            	
            	**type**\: bool
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.DomainLookupConf, self).__init__()

                self.yang_name = "domain-lookup-conf"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('domain_lookup', (YLeaf(YType.boolean, 'domain-lookup'), ['bool'])),
                ])
                self.domain_lookup = None
                self._segment_path = lambda: "domain-lookup-conf"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.DomainLookupConf, [u'domain_lookup'], name, value)


        class DomainLookup(Entity):
            """
            Enable IP Domain Name System hostname translation
            
            .. attribute:: nsap
            
            	Enable IP DNS queries for CLNS NSAP addresses
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: source_interface
            
            	Specify source interface for DNS resolver
            	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.DomainLookup.SourceInterface>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.DomainLookup, self).__init__()

                self.yang_name = "domain-lookup"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("source-interface", ("source_interface", Native.Ip.DomainLookup.SourceInterface))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('nsap', (YLeaf(YType.empty, 'nsap'), ['Empty'])),
                ])
                self.nsap = None

                self.source_interface = Native.Ip.DomainLookup.SourceInterface()
                self.source_interface.parent = self
                self._children_name_map["source_interface"] = "source-interface"
                self._segment_path = lambda: "domain-lookup"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.DomainLookup, [u'nsap'], name, value)


            class SourceInterface(Entity):
                """
                Specify source interface for DNS resolver
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.DomainLookup.SourceInterface.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.DomainLookup.SourceInterface.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.DomainLookup.SourceInterface.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.DomainLookup.SourceInterface.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.DomainLookup.SourceInterface, self).__init__()

                    self.yang_name = "source-interface"
                    self.yang_parent_name = "domain-lookup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Ip.DomainLookup.SourceInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Ip.DomainLookup.SourceInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Ip.DomainLookup.SourceInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Ip.DomainLookup.SourceInterface.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.Ip.DomainLookup.SourceInterface.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.Ip.DomainLookup.SourceInterface.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.Ip.DomainLookup.SourceInterface.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.Ip.DomainLookup.SourceInterface.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "source-interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain-lookup/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.DomainLookup.SourceInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.DomainLookup.SourceInterface.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain-lookup/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.DomainLookup.SourceInterface.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.DomainLookup.SourceInterface.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain-lookup/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.DomainLookup.SourceInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.DomainLookup.SourceInterface.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain-lookup/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.DomainLookup.SourceInterface.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.DomainLookup.SourceInterface.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/domain-lookup/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.DomainLookup.SourceInterface.PortChannelSubinterface, [u'port_channel'], name, value)


        class Dns(Entity):
            """
            Configure DNS server for a zone
            
            .. attribute:: server
            
            	Enable DNS server
            	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dns.Server>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Dns, self).__init__()

                self.yang_name = "dns"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("server", ("server", Native.Ip.Dns.Server))])
                self._leafs = OrderedDict()

                self.server = None
                self._children_name_map["server"] = "server"
                self._segment_path = lambda: "dns"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Dns, [], name, value)


            class Server(Entity):
                """
                Enable DNS server
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Dns.Server, self).__init__()

                    self.yang_name = "server"
                    self.yang_parent_name = "dns"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "server"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dns/%s" % self._segment_path()
                    self._is_frozen = True


        class Dhcp(Entity):
            """
            Configure DHCP server and relay parameters
            
            .. attribute:: aaa
            
            	Configure aaa attributes
            	**type**\:  :py:class:`Aaa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Aaa>`
            
            .. attribute:: bootp
            
            	BOOTP specific configuration
            	**type**\:  :py:class:`Bootp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Bootp>`
            
            .. attribute:: class_
            
            	Configure DHCP classes
            	**type**\: list of  		 :py:class:`Class <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Class>`
            
            .. attribute:: ping
            
            	Specify ping parameters used by DHCP
            	**type**\:  :py:class:`Ping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Ping>`
            
            .. attribute:: conflict
            
            	DHCP address conflict parameters
            	**type**\:  :py:class:`Conflict <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Conflict>`
            
            .. attribute:: excluded_address
            
            	Prevent DHCP from assigning certain addresses
            	**type**\:  :py:class:`ExcludedAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.ExcludedAddress>`
            
            .. attribute:: binding
            
            	DHCP address bindings
            	**type**\:  :py:class:`Binding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Binding>`
            
            .. attribute:: database
            
            	Configure DHCP database agents
            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Database>`
            
            .. attribute:: limit
            
            	Limit DHCP Lease
            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Limit>`
            
            .. attribute:: subscriber_id
            
            	Global subscriber\-id configuration
            	**type**\:  :py:class:`SubscriberId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SubscriberId>`
            
            .. attribute:: relay
            
            	DHCP relay agent parameters
            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Relay>`
            
            .. attribute:: pool
            
            	Configure DHCP address pools
            	**type**\: list of  		 :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool>`
            
            .. attribute:: smart_relay
            
            	Enable Smart Relay feature
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: snooping
            
            	DHCP Snooping
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: snooping_conf
            
            	
            	**type**\:  :py:class:`SnoopingConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf>`
            
            .. attribute:: use
            
            	Configure use of certain parameters during allocation
            	**type**\:  :py:class:`Use <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Use>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Dhcp, self).__init__()

                self.yang_name = "dhcp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:aaa", ("aaa", Native.Ip.Dhcp.Aaa)), ("Cisco-IOS-XE-dhcp:bootp", ("bootp", Native.Ip.Dhcp.Bootp)), ("Cisco-IOS-XE-dhcp:class", ("class_", Native.Ip.Dhcp.Class)), ("Cisco-IOS-XE-dhcp:ping", ("ping", Native.Ip.Dhcp.Ping)), ("Cisco-IOS-XE-dhcp:conflict", ("conflict", Native.Ip.Dhcp.Conflict)), ("Cisco-IOS-XE-dhcp:excluded-address", ("excluded_address", Native.Ip.Dhcp.ExcludedAddress)), ("Cisco-IOS-XE-dhcp:binding", ("binding", Native.Ip.Dhcp.Binding)), ("Cisco-IOS-XE-dhcp:database", ("database", Native.Ip.Dhcp.Database)), ("Cisco-IOS-XE-dhcp:limit", ("limit", Native.Ip.Dhcp.Limit)), ("Cisco-IOS-XE-dhcp:subscriber-id", ("subscriber_id", Native.Ip.Dhcp.SubscriberId)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:pool", ("pool", Native.Ip.Dhcp.Pool)), ("Cisco-IOS-XE-dhcp:snooping-conf", ("snooping_conf", Native.Ip.Dhcp.SnoopingConf)), ("Cisco-IOS-XE-dhcp:use", ("use", Native.Ip.Dhcp.Use))])
                self._leafs = OrderedDict([
                    ('smart_relay', (YLeaf(YType.empty, 'Cisco-IOS-XE-dhcp:smart-relay'), ['Empty'])),
                    ('snooping', (YLeaf(YType.empty, 'Cisco-IOS-XE-dhcp:snooping'), ['Empty'])),
                ])
                self.smart_relay = None
                self.snooping = None

                self.aaa = Native.Ip.Dhcp.Aaa()
                self.aaa.parent = self
                self._children_name_map["aaa"] = "Cisco-IOS-XE-dhcp:aaa"

                self.bootp = Native.Ip.Dhcp.Bootp()
                self.bootp.parent = self
                self._children_name_map["bootp"] = "Cisco-IOS-XE-dhcp:bootp"

                self.ping = Native.Ip.Dhcp.Ping()
                self.ping.parent = self
                self._children_name_map["ping"] = "Cisco-IOS-XE-dhcp:ping"

                self.conflict = Native.Ip.Dhcp.Conflict()
                self.conflict.parent = self
                self._children_name_map["conflict"] = "Cisco-IOS-XE-dhcp:conflict"

                self.excluded_address = Native.Ip.Dhcp.ExcludedAddress()
                self.excluded_address.parent = self
                self._children_name_map["excluded_address"] = "Cisco-IOS-XE-dhcp:excluded-address"

                self.binding = Native.Ip.Dhcp.Binding()
                self.binding.parent = self
                self._children_name_map["binding"] = "Cisco-IOS-XE-dhcp:binding"

                self.database = Native.Ip.Dhcp.Database()
                self.database.parent = self
                self._children_name_map["database"] = "Cisco-IOS-XE-dhcp:database"

                self.limit = Native.Ip.Dhcp.Limit()
                self.limit.parent = self
                self._children_name_map["limit"] = "Cisco-IOS-XE-dhcp:limit"

                self.subscriber_id = Native.Ip.Dhcp.SubscriberId()
                self.subscriber_id.parent = self
                self._children_name_map["subscriber_id"] = "Cisco-IOS-XE-dhcp:subscriber-id"

                self.relay = Native.Ip.Dhcp.Relay()
                self.relay.parent = self
                self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                self.snooping_conf = Native.Ip.Dhcp.SnoopingConf()
                self.snooping_conf.parent = self
                self._children_name_map["snooping_conf"] = "Cisco-IOS-XE-dhcp:snooping-conf"

                self.use = Native.Ip.Dhcp.Use()
                self.use.parent = self
                self._children_name_map["use"] = "Cisco-IOS-XE-dhcp:use"

                self.class_ = YList(self)
                self.pool = YList(self)
                self._segment_path = lambda: "dhcp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Dhcp, ['smart_relay', 'snooping'], name, value)


            class Aaa(Entity):
                """
                Configure aaa attributes
                
                .. attribute:: default
                
                	Specify default values for aaa attributes
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Aaa.Default>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.Aaa, self).__init__()

                    self.yang_name = "aaa"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Ip.Dhcp.Aaa.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Ip.Dhcp.Aaa.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:aaa"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.Aaa, [], name, value)


                class Default(Entity):
                    """
                    Specify default values for aaa attributes
                    
                    .. attribute:: username
                    
                    	Default username for non\-VRF pool subnet request or release
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Aaa.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "aaa"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('username', (YLeaf(YType.str, 'username'), ['str'])),
                        ])
                        self.username = None
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:aaa/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Aaa.Default, ['username'], name, value)


            class Bootp(Entity):
                """
                BOOTP specific configuration
                
                .. attribute:: ignore
                
                	Configure this DHCP server to ignore to BOOTP requests
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.Bootp, self).__init__()

                    self.yang_name = "bootp"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                    ])
                    self.ignore = None
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:bootp"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.Bootp, ['ignore'], name, value)


            class Class(Entity):
                """
                Configure DHCP classes
                
                .. attribute:: id  (key)
                
                	
                	**type**\: str
                
                .. attribute:: option
                
                	Raw DHCP options
                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Class.Option>`
                
                .. attribute:: relay
                
                	Enter relay agent information option configuration submode
                	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Class.Relay>`
                
                .. attribute:: remark
                
                	Specify a remark for this class
                	**type**\: str
                
                	**length:** 1..240
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.Class, self).__init__()

                    self.yang_name = "class"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("option", ("option", Native.Ip.Dhcp.Class.Option)), ("relay", ("relay", Native.Ip.Dhcp.Class.Relay))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                        ('remark', (YLeaf(YType.str, 'remark'), ['str'])),
                    ])
                    self.id = None
                    self.remark = None

                    self.option = Native.Ip.Dhcp.Class.Option()
                    self.option.parent = self
                    self._children_name_map["option"] = "option"

                    self.relay = Native.Ip.Dhcp.Class.Relay()
                    self.relay.parent = self
                    self._children_name_map["relay"] = "relay"
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:class" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.Class, ['id', 'remark'], name, value)


                class Option(Entity):
                    """
                    Raw DHCP options
                    
                    .. attribute:: option_list
                    
                    	
                    	**type**\: list of  		 :py:class:`OptionList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Class.Option.OptionList>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Class.Option, self).__init__()

                        self.yang_name = "option"
                        self.yang_parent_name = "class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("option-list", ("option_list", Native.Ip.Dhcp.Class.Option.OptionList))])
                        self._leafs = OrderedDict()

                        self.option_list = YList(self)
                        self._segment_path = lambda: "option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Class.Option, [], name, value)


                    class OptionList(Entity):
                        """
                        
                        
                        .. attribute:: option_range  (key)
                        
                        	DHCP option code (1\-254)
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        .. attribute:: line
                        
                        	Specify a regular expression string
                        	**type**\: str
                        
                        .. attribute:: hex_list
                        
                        	
                        	**type**\: list of  		 :py:class:`HexList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Class.Option.OptionList.HexList>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.Class.Option.OptionList, self).__init__()

                            self.yang_name = "option-list"
                            self.yang_parent_name = "option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['option_range']
                            self._child_classes = OrderedDict([("hex-list", ("hex_list", Native.Ip.Dhcp.Class.Option.OptionList.HexList))])
                            self._leafs = OrderedDict([
                                ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                ('line', (YLeaf(YType.str, 'LINE'), ['str'])),
                            ])
                            self.option_range = None
                            self.line = None

                            self.hex_list = YList(self)
                            self._segment_path = lambda: "option-list" + "[option-range='" + str(self.option_range) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.Class.Option.OptionList, ['option_range', 'line'], name, value)


                        class HexList(Entity):
                            """
                            
                            
                            .. attribute:: hex_string  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mask
                            
                            	Specify a bit mask for the pattern
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Ip.Dhcp.Class.Option.OptionList.HexList, self).__init__()

                                self.yang_name = "hex-list"
                                self.yang_parent_name = "option-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['hex_string']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hex_string', (YLeaf(YType.str, 'hex-string'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.hex_string = None
                                self.mask = None
                                self._segment_path = lambda: "hex-list" + "[hex-string='" + str(self.hex_string) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Dhcp.Class.Option.OptionList.HexList, ['hex_string', 'mask'], name, value)


                class Relay(Entity):
                    """
                    Enter relay agent information option configuration submode
                    
                    .. attribute:: agent
                    
                    	Enter relay agent information option configuration submode
                    	**type**\:  :py:class:`Agent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Class.Relay.Agent>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Class.Relay, self).__init__()

                        self.yang_name = "relay"
                        self.yang_parent_name = "class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("agent", ("agent", Native.Ip.Dhcp.Class.Relay.Agent))])
                        self._leafs = OrderedDict()

                        self.agent = Native.Ip.Dhcp.Class.Relay.Agent()
                        self.agent.parent = self
                        self._children_name_map["agent"] = "agent"
                        self._segment_path = lambda: "relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Class.Relay, [], name, value)


                    class Agent(Entity):
                        """
                        Enter relay agent information option configuration submode
                        
                        .. attribute:: information
                        
                        	Enter relay agent information option configuration submode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.Class.Relay.Agent, self).__init__()

                            self.yang_name = "agent"
                            self.yang_parent_name = "relay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('information', (YLeaf(YType.empty, 'information'), ['Empty'])),
                            ])
                            self.information = None
                            self._segment_path = lambda: "agent"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.Class.Relay.Agent, ['information'], name, value)


            class Ping(Entity):
                """
                Specify ping parameters used by DHCP
                
                .. attribute:: packets
                
                	Specify number of ping packets
                	**type**\:  :py:class:`Packets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Ping.Packets>`
                
                	**presence node**\: True
                
                .. attribute:: timeout
                
                	Specify ping timeout
                	**type**\: int
                
                	**range:** 100..10000
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.Ping, self).__init__()

                    self.yang_name = "ping"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("packets", ("packets", Native.Ip.Dhcp.Ping.Packets))])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                    ])
                    self.timeout = None

                    self.packets = None
                    self._children_name_map["packets"] = "packets"
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:ping"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.Ping, ['timeout'], name, value)


                class Packets(Entity):
                    """
                    Specify number of ping packets
                    
                    .. attribute:: number_packets
                    
                    	Number of ping packets (0 disables ping)
                    	**type**\: int
                    
                    	**range:** 0..10
                    
                    	**default value**\: 2
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Ping.Packets, self).__init__()

                        self.yang_name = "packets"
                        self.yang_parent_name = "ping"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('number_packets', (YLeaf(YType.uint8, 'number-packets'), ['int'])),
                        ])
                        self.number_packets = None
                        self._segment_path = lambda: "packets"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:ping/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Ping.Packets, ['number_packets'], name, value)


            class Conflict(Entity):
                """
                DHCP address conflict parameters
                
                .. attribute:: logging
                
                	Record address conflicts in a log file
                	**type**\: bool
                
                	**default value**\: true
                
                .. attribute:: resolution
                
                	DHCP address conflict resolution
                	**type**\:  :py:class:`Resolution <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Conflict.Resolution>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.Conflict, self).__init__()

                    self.yang_name = "conflict"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("resolution", ("resolution", Native.Ip.Dhcp.Conflict.Resolution))])
                    self._leafs = OrderedDict([
                        ('logging', (YLeaf(YType.boolean, 'logging'), ['bool'])),
                    ])
                    self.logging = None

                    self.resolution = None
                    self._children_name_map["resolution"] = "resolution"
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:conflict"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.Conflict, ['logging'], name, value)


                class Resolution(Entity):
                    """
                    DHCP address conflict resolution
                    
                    .. attribute:: interval
                    
                    	Time in Minutes
                    	**type**\: int
                    
                    	**range:** 5..1440
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Conflict.Resolution, self).__init__()

                        self.yang_name = "resolution"
                        self.yang_parent_name = "conflict"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                        ])
                        self.interval = None
                        self._segment_path = lambda: "resolution"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:conflict/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Conflict.Resolution, ['interval'], name, value)


            class ExcludedAddress(Entity):
                """
                Prevent DHCP from assigning certain addresses
                
                .. attribute:: low_address_list
                
                	
                	**type**\: list of  		 :py:class:`LowAddressList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.ExcludedAddress.LowAddressList>`
                
                .. attribute:: low_high_address_list
                
                	
                	**type**\: list of  		 :py:class:`LowHighAddressList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.ExcludedAddress.LowHighAddressList>`
                
                .. attribute:: vrf_low_address_list
                
                	
                	**type**\: list of  		 :py:class:`VrfLowAddressList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.ExcludedAddress.VrfLowAddressList>`
                
                .. attribute:: vrf_low_high_address_list
                
                	
                	**type**\: list of  		 :py:class:`VrfLowHighAddressList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.ExcludedAddress.VrfLowHighAddressList>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.ExcludedAddress, self).__init__()

                    self.yang_name = "excluded-address"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("low-address-list", ("low_address_list", Native.Ip.Dhcp.ExcludedAddress.LowAddressList)), ("low-high-address-list", ("low_high_address_list", Native.Ip.Dhcp.ExcludedAddress.LowHighAddressList)), ("vrf-low-address-list", ("vrf_low_address_list", Native.Ip.Dhcp.ExcludedAddress.VrfLowAddressList)), ("vrf-low-high-address-list", ("vrf_low_high_address_list", Native.Ip.Dhcp.ExcludedAddress.VrfLowHighAddressList))])
                    self._leafs = OrderedDict()

                    self.low_address_list = YList(self)
                    self.low_high_address_list = YList(self)
                    self.vrf_low_address_list = YList(self)
                    self.vrf_low_high_address_list = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:excluded-address"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.ExcludedAddress, [], name, value)


                class LowAddressList(Entity):
                    """
                    
                    
                    .. attribute:: low_address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.ExcludedAddress.LowAddressList, self).__init__()

                        self.yang_name = "low-address-list"
                        self.yang_parent_name = "excluded-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['low_address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('low_address', (YLeaf(YType.str, 'low-address'), ['str'])),
                        ])
                        self.low_address = None
                        self._segment_path = lambda: "low-address-list" + "[low-address='" + str(self.low_address) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:excluded-address/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.ExcludedAddress.LowAddressList, ['low_address'], name, value)


                class LowHighAddressList(Entity):
                    """
                    
                    
                    .. attribute:: low_address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: high_address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.ExcludedAddress.LowHighAddressList, self).__init__()

                        self.yang_name = "low-high-address-list"
                        self.yang_parent_name = "excluded-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['low_address','high_address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('low_address', (YLeaf(YType.str, 'low-address'), ['str'])),
                            ('high_address', (YLeaf(YType.str, 'high-address'), ['str'])),
                        ])
                        self.low_address = None
                        self.high_address = None
                        self._segment_path = lambda: "low-high-address-list" + "[low-address='" + str(self.low_address) + "']" + "[high-address='" + str(self.high_address) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:excluded-address/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.ExcludedAddress.LowHighAddressList, ['low_address', 'high_address'], name, value)


                class VrfLowAddressList(Entity):
                    """
                    
                    
                    .. attribute:: vrf  (key)
                    
                    	VRF name for excluded address range
                    	**type**\: str
                    
                    .. attribute:: low_address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.ExcludedAddress.VrfLowAddressList, self).__init__()

                        self.yang_name = "vrf-low-address-list"
                        self.yang_parent_name = "excluded-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['vrf','low_address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ('low_address', (YLeaf(YType.str, 'low-address'), ['str'])),
                        ])
                        self.vrf = None
                        self.low_address = None
                        self._segment_path = lambda: "vrf-low-address-list" + "[vrf='" + str(self.vrf) + "']" + "[low-address='" + str(self.low_address) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:excluded-address/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.ExcludedAddress.VrfLowAddressList, ['vrf', 'low_address'], name, value)


                class VrfLowHighAddressList(Entity):
                    """
                    
                    
                    .. attribute:: vrf  (key)
                    
                    	VRF name for excluded address range
                    	**type**\: str
                    
                    .. attribute:: low_address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: high_address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.ExcludedAddress.VrfLowHighAddressList, self).__init__()

                        self.yang_name = "vrf-low-high-address-list"
                        self.yang_parent_name = "excluded-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['vrf','low_address','high_address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ('low_address', (YLeaf(YType.str, 'low-address'), ['str'])),
                            ('high_address', (YLeaf(YType.str, 'high-address'), ['str'])),
                        ])
                        self.vrf = None
                        self.low_address = None
                        self.high_address = None
                        self._segment_path = lambda: "vrf-low-high-address-list" + "[vrf='" + str(self.vrf) + "']" + "[low-address='" + str(self.low_address) + "']" + "[high-address='" + str(self.high_address) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:excluded-address/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.ExcludedAddress.VrfLowHighAddressList, ['vrf', 'low_address', 'high_address'], name, value)


            class Binding(Entity):
                """
                DHCP address bindings
                
                .. attribute:: cleanup
                
                	Remove expired bindings
                	**type**\:  :py:class:`Cleanup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Binding.Cleanup>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.Binding, self).__init__()

                    self.yang_name = "binding"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cleanup", ("cleanup", Native.Ip.Dhcp.Binding.Cleanup))])
                    self._leafs = OrderedDict()

                    self.cleanup = Native.Ip.Dhcp.Binding.Cleanup()
                    self.cleanup.parent = self
                    self._children_name_map["cleanup"] = "cleanup"
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:binding"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.Binding, [], name, value)


                class Cleanup(Entity):
                    """
                    Remove expired bindings
                    
                    .. attribute:: interval
                    
                    	Time in seconds
                    	**type**\: int
                    
                    	**range:** 10..600
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Binding.Cleanup, self).__init__()

                        self.yang_name = "cleanup"
                        self.yang_parent_name = "binding"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                        ])
                        self.interval = None
                        self._segment_path = lambda: "cleanup"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:binding/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Binding.Cleanup, ['interval'], name, value)


            class Database(Entity):
                """
                Configure DHCP database agents
                
                .. attribute:: resource
                
                	Uniform Resource Locator (URL)
                	**type**\: list of  		 :py:class:`Resource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Database.Resource>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.Database, self).__init__()

                    self.yang_name = "database"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("resource", ("resource", Native.Ip.Dhcp.Database.Resource))])
                    self._leafs = OrderedDict()

                    self.resource = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:database"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.Database, [], name, value)


                class Resource(Entity):
                    """
                    Uniform Resource Locator (URL)
                    
                    .. attribute:: resource_locator  (key)
                    
                    	Uniform Resource Locator (URL)
                    	**type**\: str
                    
                    .. attribute:: write_delay
                    
                    	Set the database write delay
                    	**type**\: int
                    
                    	**range:** 60..4294967295
                    
                    .. attribute:: timeout
                    
                    	Set the database transfer timeout
                    	**type**\: int
                    
                    	**range:** 0..3600
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Database.Resource, self).__init__()

                        self.yang_name = "resource"
                        self.yang_parent_name = "database"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['resource_locator']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('resource_locator', (YLeaf(YType.str, 'resource-locator'), ['str'])),
                            ('write_delay', (YLeaf(YType.uint32, 'write-delay'), ['int'])),
                            ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                        ])
                        self.resource_locator = None
                        self.write_delay = None
                        self.timeout = None
                        self._segment_path = lambda: "resource" + "[resource-locator='" + str(self.resource_locator) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:database/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Database.Resource, ['resource_locator', 'write_delay', 'timeout'], name, value)


            class Limit(Entity):
                """
                Limit DHCP Lease
                
                .. attribute:: lease
                
                	DHCP lease
                	**type**\:  :py:class:`Lease <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Limit.Lease>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.Limit, self).__init__()

                    self.yang_name = "limit"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("lease", ("lease", Native.Ip.Dhcp.Limit.Lease))])
                    self._leafs = OrderedDict()

                    self.lease = Native.Ip.Dhcp.Limit.Lease()
                    self.lease.parent = self
                    self._children_name_map["lease"] = "lease"
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:limit"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.Limit, [], name, value)


                class Lease(Entity):
                    """
                    DHCP lease
                    
                    .. attribute:: log
                    
                    	Limit DHCP Lease
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: per
                    
                    	per
                    	**type**\:  :py:class:`Per <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Limit.Lease.Per>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Limit.Lease, self).__init__()

                        self.yang_name = "lease"
                        self.yang_parent_name = "limit"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("per", ("per", Native.Ip.Dhcp.Limit.Lease.Per))])
                        self._leafs = OrderedDict([
                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                        ])
                        self.log = None

                        self.per = Native.Ip.Dhcp.Limit.Lease.Per()
                        self.per.parent = self
                        self._children_name_map["per"] = "per"
                        self._segment_path = lambda: "lease"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:limit/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Limit.Lease, ['log'], name, value)


                    class Per(Entity):
                        """
                        per
                        
                        .. attribute:: interface
                        
                        	interface
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.Limit.Lease.Per, self).__init__()

                            self.yang_name = "per"
                            self.yang_parent_name = "lease"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.uint16, 'interface'), ['int'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "per"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:limit/lease/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.Limit.Lease.Per, ['interface'], name, value)


            class SubscriberId(Entity):
                """
                Global subscriber\-id configuration
                
                .. attribute:: interface_name
                
                	Use interface short\-name
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.SubscriberId, self).__init__()

                    self.yang_name = "subscriber-id"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interface_name', (YLeaf(YType.empty, 'interface-name'), ['Empty'])),
                    ])
                    self.interface_name = None
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:subscriber-id"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.SubscriberId, ['interface_name'], name, value)


            class Relay(Entity):
                """
                DHCP relay agent parameters
                
                .. attribute:: information
                
                	Relay agent information option
                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Relay.Information>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.Relay, self).__init__()

                    self.yang_name = "relay"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("information", ("information", Native.Ip.Dhcp.Relay.Information))])
                    self._leafs = OrderedDict()

                    self.information = Native.Ip.Dhcp.Relay.Information()
                    self.information.parent = self
                    self._children_name_map["information"] = "information"
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.Relay, [], name, value)


                class Information(Entity):
                    """
                    Relay agent information option
                    
                    .. attribute:: trust_all
                    
                    	Received DHCP packets may contain relay info option with zero giaddr
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: option
                    
                    	Insert relay information in BOOTREQUEST
                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Relay.Information.Option>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Relay.Information, self).__init__()

                        self.yang_name = "information"
                        self.yang_parent_name = "relay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("option", ("option", Native.Ip.Dhcp.Relay.Information.Option))])
                        self._leafs = OrderedDict([
                            ('trust_all', (YLeaf(YType.empty, 'trust-all'), ['Empty'])),
                        ])
                        self.trust_all = None

                        self.option = Native.Ip.Dhcp.Relay.Information.Option()
                        self.option.parent = self
                        self._children_name_map["option"] = "option"
                        self._segment_path = lambda: "information"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:relay/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Relay.Information, ['trust_all'], name, value)


                    class Option(Entity):
                        """
                        Insert relay information in BOOTREQUEST
                        
                        .. attribute:: option_default
                        
                        	Default option, no vpn
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vpn
                        
                        	Insert VPN sub\-options and change the giaddr to the outgoing interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.Relay.Information.Option, self).__init__()

                            self.yang_name = "option"
                            self.yang_parent_name = "information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('option_default', (YLeaf(YType.empty, 'option-default'), ['Empty'])),
                                ('vpn', (YLeaf(YType.empty, 'vpn'), ['Empty'])),
                            ])
                            self.option_default = None
                            self.vpn = None
                            self._segment_path = lambda: "option"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:relay/information/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.Relay.Information.Option, ['option_default', 'vpn'], name, value)


            class Pool(Entity):
                """
                Configure DHCP address pools
                
                .. attribute:: id  (key)
                
                	
                	**type**\: str
                
                .. attribute:: option
                
                	Raw DHCP options
                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.Option>`
                
                .. attribute:: class_
                
                	Specify a DHCP class
                	**type**\: list of  		 :py:class:`Class <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.Class>`
                
                .. attribute:: vrf
                
                	Associate this pool with a VRF
                	**type**\: str
                
                .. attribute:: lease
                
                	Address lease time
                	**type**\: list of  		 :py:class:`Lease <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.Lease>`
                
                .. attribute:: default_router
                
                	
                	**type**\:  :py:class:`DefaultRouter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.DefaultRouter>`
                
                .. attribute:: dns_server
                
                	
                	**type**\:  :py:class:`DnsServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.DnsServer>`
                
                .. attribute:: domain_name
                
                	Domain name
                	**type**\: str
                
                .. attribute:: network
                
                	Network number and mask
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.Network>`
                
                .. attribute:: host
                
                	Client IP address and mask
                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.Host>`
                
                .. attribute:: hardware_address
                
                	Client hardware address
                	**type**\:  :py:class:`HardwareAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.HardwareAddress>`
                
                .. attribute:: client_identifier
                
                	Client identifier, Dotted\-hexadecimal string (aabb.ccdd.eeff ...)
                	**type**\: str
                
                .. attribute:: client_name
                
                	Client name, Client name (domain should not be included)
                	**type**\: str
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.Pool, self).__init__()

                    self.yang_name = "pool"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("option", ("option", Native.Ip.Dhcp.Pool.Option)), ("class", ("class_", Native.Ip.Dhcp.Pool.Class)), ("lease", ("lease", Native.Ip.Dhcp.Pool.Lease)), ("default-router", ("default_router", Native.Ip.Dhcp.Pool.DefaultRouter)), ("dns-server", ("dns_server", Native.Ip.Dhcp.Pool.DnsServer)), ("network", ("network", Native.Ip.Dhcp.Pool.Network)), ("host", ("host", Native.Ip.Dhcp.Pool.Host)), ("hardware-address", ("hardware_address", Native.Ip.Dhcp.Pool.HardwareAddress))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ('domain_name', (YLeaf(YType.str, 'domain-name'), ['str'])),
                        ('client_identifier', (YLeaf(YType.str, 'client-identifier'), ['str'])),
                        ('client_name', (YLeaf(YType.str, 'client-name'), ['str'])),
                    ])
                    self.id = None
                    self.vrf = None
                    self.domain_name = None
                    self.client_identifier = None
                    self.client_name = None

                    self.option = Native.Ip.Dhcp.Pool.Option()
                    self.option.parent = self
                    self._children_name_map["option"] = "option"

                    self.default_router = Native.Ip.Dhcp.Pool.DefaultRouter()
                    self.default_router.parent = self
                    self._children_name_map["default_router"] = "default-router"

                    self.dns_server = Native.Ip.Dhcp.Pool.DnsServer()
                    self.dns_server.parent = self
                    self._children_name_map["dns_server"] = "dns-server"

                    self.network = Native.Ip.Dhcp.Pool.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.host = Native.Ip.Dhcp.Pool.Host()
                    self.host.parent = self
                    self._children_name_map["host"] = "host"

                    self.hardware_address = Native.Ip.Dhcp.Pool.HardwareAddress()
                    self.hardware_address.parent = self
                    self._children_name_map["hardware_address"] = "hardware-address"

                    self.class_ = YList(self)
                    self.lease = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:pool" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.Pool, ['id', 'vrf', 'domain_name', 'client_identifier', 'client_name'], name, value)


                class Option(Entity):
                    """
                    Raw DHCP options
                    
                    .. attribute:: option_range
                    
                    	
                    	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.Option.OptionRange>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Pool.Option, self).__init__()

                        self.yang_name = "option"
                        self.yang_parent_name = "pool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("option-range", ("option_range", Native.Ip.Dhcp.Pool.Option.OptionRange))])
                        self._leafs = OrderedDict()

                        self.option_range = YList(self)
                        self._segment_path = lambda: "option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Pool.Option, [], name, value)


                    class OptionRange(Entity):
                        """
                        
                        
                        .. attribute:: option_range  (key)
                        
                        	DHCP option code
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: ascii
                        
                        	Data is an NVT ASCII string
                        	**type**\: str
                        
                        .. attribute:: hex
                        
                        	Data is a hexadecimal string
                        	**type**\:  :py:class:`Hex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.Option.OptionRange.Hex>`
                        
                        .. attribute:: ip
                        
                        	Data is one or more IP addresses
                        	**type**\: union of the below types:
                        
                        		**type**\: list of str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: list of str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: list of str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.Pool.Option.OptionRange, self).__init__()

                            self.yang_name = "option-range"
                            self.yang_parent_name = "option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['option_range']
                            self._child_classes = OrderedDict([("hex", ("hex", Native.Ip.Dhcp.Pool.Option.OptionRange.Hex))])
                            self._leafs = OrderedDict([
                                ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                            ])
                            self.option_range = None
                            self.ascii = None
                            self.ip = []

                            self.hex = Native.Ip.Dhcp.Pool.Option.OptionRange.Hex()
                            self.hex.parent = self
                            self._children_name_map["hex"] = "hex"
                            self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.Pool.Option.OptionRange, ['option_range', 'ascii', 'ip'], name, value)


                        class Hex(Entity):
                            """
                            Data is a hexadecimal string
                            
                            .. attribute:: hex_line
                            
                            	Hexadecimal string, truncated to 180 hex characters entered
                            	**type**\: str
                            
                            .. attribute:: none
                            
                            	No data
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Ip.Dhcp.Pool.Option.OptionRange.Hex, self).__init__()

                                self.yang_name = "hex"
                                self.yang_parent_name = "option-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hex_line', (YLeaf(YType.str, 'hex-line'), ['str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                ])
                                self.hex_line = None
                                self.none = None
                                self._segment_path = lambda: "hex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Dhcp.Pool.Option.OptionRange.Hex, ['hex_line', 'none'], name, value)


                class Class(Entity):
                    """
                    Specify a DHCP class
                    
                    .. attribute:: name  (key)
                    
                    	DHCP class name
                    	**type**\: str
                    
                    .. attribute:: address
                    
                    	Specify an address range for this class
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.Class.Address>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Pool.Class, self).__init__()

                        self.yang_name = "class"
                        self.yang_parent_name = "pool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("address", ("address", Native.Ip.Dhcp.Pool.Class.Address))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.address = Native.Ip.Dhcp.Pool.Class.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._segment_path = lambda: "class" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Pool.Class, ['name'], name, value)


                    class Address(Entity):
                        """
                        Specify an address range for this class
                        
                        .. attribute:: range
                        
                        	
                        	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Pool.Class.Address.Range>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.Pool.Class.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Ip.Dhcp.Pool.Class.Address.Range))])
                            self._leafs = OrderedDict()

                            self.range = Native.Ip.Dhcp.Pool.Class.Address.Range()
                            self.range.parent = self
                            self._children_name_map["range"] = "range"
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.Pool.Class.Address, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: ipv4_start
                            
                            	Start IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_end
                            
                            	End IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Ip.Dhcp.Pool.Class.Address.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_start', (YLeaf(YType.str, 'ipv4-start'), ['str'])),
                                    ('ipv4_end', (YLeaf(YType.str, 'ipv4-end'), ['str'])),
                                ])
                                self.ipv4_start = None
                                self.ipv4_end = None
                                self._segment_path = lambda: "range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Dhcp.Pool.Class.Address.Range, ['ipv4_start', 'ipv4_end'], name, value)


                class Lease(Entity):
                    """
                    Address lease time
                    
                    .. attribute:: days  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..365
                    
                    .. attribute:: hours
                    
                    	Hours
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: minutes
                    
                    	Minutes
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Pool.Lease, self).__init__()

                        self.yang_name = "lease"
                        self.yang_parent_name = "pool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['days']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('days', (YLeaf(YType.uint16, 'Days'), ['int'])),
                            ('hours', (YLeaf(YType.uint8, 'Hours'), ['int'])),
                            ('minutes', (YLeaf(YType.uint8, 'Minutes'), ['int'])),
                        ])
                        self.days = None
                        self.hours = None
                        self.minutes = None
                        self._segment_path = lambda: "lease" + "[Days='" + str(self.days) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Pool.Lease, ['days', 'hours', 'minutes'], name, value)


                class DefaultRouter(Entity):
                    """
                    
                    
                    .. attribute:: default_router_list
                    
                    	Default routers
                    	**type**\: union of the below types:
                    
                    		**type**\: list of str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Pool.DefaultRouter, self).__init__()

                        self.yang_name = "default-router"
                        self.yang_parent_name = "pool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default_router_list', (YLeafList(YType.str, 'default-router-list'), ['str','str'])),
                        ])
                        self.default_router_list = []
                        self._segment_path = lambda: "default-router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Pool.DefaultRouter, ['default_router_list'], name, value)


                class DnsServer(Entity):
                    """
                    
                    
                    .. attribute:: dns_server_list
                    
                    	DNS servers
                    	**type**\: union of the below types:
                    
                    		**type**\: list of str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Pool.DnsServer, self).__init__()

                        self.yang_name = "dns-server"
                        self.yang_parent_name = "pool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dns_server_list', (YLeafList(YType.str, 'dns-server-list'), ['str','str'])),
                        ])
                        self.dns_server_list = []
                        self._segment_path = lambda: "dns-server"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Pool.DnsServer, ['dns_server_list'], name, value)


                class Network(Entity):
                    """
                    Network number and mask
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mask
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: secondary
                    
                    	Configure as secondary subnet
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Pool.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "pool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                            ('mask', (YLeaf(YType.str, 'mask'), ['str','str'])),
                            ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                        ])
                        self.number = None
                        self.mask = None
                        self.secondary = None
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Pool.Network, ['number', 'mask', 'secondary'], name, value)


                class Host(Entity):
                    """
                    Client IP address and mask
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mask
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Pool.Host, self).__init__()

                        self.yang_name = "host"
                        self.yang_parent_name = "pool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                        ])
                        self.number = None
                        self.mask = None
                        self._segment_path = lambda: "host"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Pool.Host, ['number', 'mask'], name, value)


                class HardwareAddress(Entity):
                    """
                    Client hardware address
                    
                    .. attribute:: hardware_address_val
                    
                    	Dotted\-hexadecimal string (aabb.ccdd.eeff ...)
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Pool.HardwareAddress, self).__init__()

                        self.yang_name = "hardware-address"
                        self.yang_parent_name = "pool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('hardware_address_val', (YLeaf(YType.str, 'hardware-address-val'), ['str'])),
                        ])
                        self.hardware_address_val = None
                        self._segment_path = lambda: "hardware-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Pool.HardwareAddress, ['hardware_address_val'], name, value)


            class SnoopingConf(Entity):
                """
                
                
                .. attribute:: snooping
                
                	DHCP Snooping
                	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.SnoopingConf, self).__init__()

                    self.yang_name = "snooping-conf"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("snooping", ("snooping", Native.Ip.Dhcp.SnoopingConf.Snooping))])
                    self._leafs = OrderedDict()

                    self.snooping = Native.Ip.Dhcp.SnoopingConf.Snooping()
                    self.snooping.parent = self
                    self._children_name_map["snooping"] = "snooping"
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping-conf"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.SnoopingConf, [], name, value)


                class Snooping(Entity):
                    """
                    DHCP Snooping
                    
                    .. attribute:: database
                    
                    	DHCP snooping database agent
                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping.Database>`
                    
                    .. attribute:: glean
                    
                    	DHCP read only snooping
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: information
                    
                    	DHCP Snooping information
                    	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping.Information>`
                    
                    .. attribute:: track
                    
                    	DHCP snooping track
                    	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping.Track>`
                    
                    .. attribute:: verify
                    
                    	DHCP snooping verify
                    	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping.Verify>`
                    
                    .. attribute:: vlan
                    
                    	DHCP Snooping vlan
                    	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping.Vlan>`
                    
                    .. attribute:: wireless
                    
                    	DHCP snooping wireless
                    	**type**\:  :py:class:`Wireless <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping.Wireless>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.SnoopingConf.Snooping, self).__init__()

                        self.yang_name = "snooping"
                        self.yang_parent_name = "snooping-conf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("database", ("database", Native.Ip.Dhcp.SnoopingConf.Snooping.Database)), ("information", ("information", Native.Ip.Dhcp.SnoopingConf.Snooping.Information)), ("track", ("track", Native.Ip.Dhcp.SnoopingConf.Snooping.Track)), ("verify", ("verify", Native.Ip.Dhcp.SnoopingConf.Snooping.Verify)), ("vlan", ("vlan", Native.Ip.Dhcp.SnoopingConf.Snooping.Vlan)), ("wireless", ("wireless", Native.Ip.Dhcp.SnoopingConf.Snooping.Wireless))])
                        self._leafs = OrderedDict([
                            ('glean', (YLeaf(YType.empty, 'glean'), ['Empty'])),
                        ])
                        self.glean = None

                        self.database = Native.Ip.Dhcp.SnoopingConf.Snooping.Database()
                        self.database.parent = self
                        self._children_name_map["database"] = "database"

                        self.information = Native.Ip.Dhcp.SnoopingConf.Snooping.Information()
                        self.information.parent = self
                        self._children_name_map["information"] = "information"

                        self.track = Native.Ip.Dhcp.SnoopingConf.Snooping.Track()
                        self.track.parent = self
                        self._children_name_map["track"] = "track"

                        self.verify = Native.Ip.Dhcp.SnoopingConf.Snooping.Verify()
                        self.verify.parent = self
                        self._children_name_map["verify"] = "verify"

                        self.wireless = Native.Ip.Dhcp.SnoopingConf.Snooping.Wireless()
                        self.wireless.parent = self
                        self._children_name_map["wireless"] = "wireless"

                        self.vlan = YList(self)
                        self._segment_path = lambda: "snooping"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping, ['glean'], name, value)


                    class Database(Entity):
                        """
                        DHCP snooping database agent
                        
                        .. attribute:: url
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: timeout
                        
                        	Configure abort timeout interval
                        	**type**\: int
                        
                        	**range:** 0..86400
                        
                        .. attribute:: write_delay
                        
                        	Configure delay timer for writes to URL
                        	**type**\: int
                        
                        	**range:** 15..86400
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.SnoopingConf.Snooping.Database, self).__init__()

                            self.yang_name = "database"
                            self.yang_parent_name = "snooping"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('url', (YLeaf(YType.str, 'url'), ['str'])),
                                ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                                ('write_delay', (YLeaf(YType.uint32, 'write-delay'), ['int'])),
                            ])
                            self.url = None
                            self.timeout = None
                            self.write_delay = None
                            self._segment_path = lambda: "database"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/snooping/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping.Database, ['url', 'timeout', 'write_delay'], name, value)


                    class Information(Entity):
                        """
                        DHCP Snooping information
                        
                        .. attribute:: option
                        
                        	
                        	**type**\: bool
                        
                        	**default value**\: true
                        
                        .. attribute:: options
                        
                        	
                        	**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.SnoopingConf.Snooping.Information, self).__init__()

                            self.yang_name = "information"
                            self.yang_parent_name = "snooping"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("options", ("options", Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options))])
                            self._leafs = OrderedDict([
                                ('option', (YLeaf(YType.boolean, 'option'), ['bool'])),
                            ])
                            self.option = None

                            self.options = Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options()
                            self.options.parent = self
                            self._children_name_map["options"] = "options"
                            self._segment_path = lambda: "information"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/snooping/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping.Information, ['option'], name, value)


                        class Options(Entity):
                            """
                            
                            
                            .. attribute:: option
                            
                            	DHCP Snooping information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options, self).__init__()

                                self.yang_name = "options"
                                self.yang_parent_name = "information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option", ("option", Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option))])
                                self._leafs = OrderedDict()

                                self.option = Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"
                                self._segment_path = lambda: "options"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/snooping/information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options, [], name, value)


                            class Option(Entity):
                                """
                                DHCP Snooping information option
                                
                                .. attribute:: allow_untrusted
                                
                                	DHCP Snooping information option allow\-untrusted
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: format
                                
                                	Option 82 information format
                                	**type**\:  :py:class:`Format <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option.Format>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "options"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("format", ("format", Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option.Format))])
                                    self._leafs = OrderedDict([
                                        ('allow_untrusted', (YLeaf(YType.empty, 'allow-untrusted'), ['Empty'])),
                                    ])
                                    self.allow_untrusted = None

                                    self.format = Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option.Format()
                                    self.format.parent = self
                                    self._children_name_map["format"] = "format"
                                    self._segment_path = lambda: "option"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/snooping/information/options/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option, ['allow_untrusted'], name, value)


                                class Format(Entity):
                                    """
                                    Option 82 information format
                                    
                                    .. attribute:: remote_id
                                    
                                    	Remote id option 82 format
                                    	**type**\:  :py:class:`RemoteId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option.Format.RemoteId>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option.Format, self).__init__()

                                        self.yang_name = "format"
                                        self.yang_parent_name = "option"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("remote-id", ("remote_id", Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option.Format.RemoteId))])
                                        self._leafs = OrderedDict()

                                        self.remote_id = Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option.Format.RemoteId()
                                        self.remote_id.parent = self
                                        self._children_name_map["remote_id"] = "remote-id"
                                        self._segment_path = lambda: "format"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/snooping/information/options/option/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option.Format, [], name, value)


                                    class RemoteId(Entity):
                                        """
                                        Remote id option 82 format
                                        
                                        .. attribute:: hostname
                                        
                                        	Use configured hostname for remote id
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: string
                                        
                                        	User defined string for remote id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option.Format.RemoteId, self).__init__()

                                            self.yang_name = "remote-id"
                                            self.yang_parent_name = "format"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('hostname', (YLeaf(YType.empty, 'hostname'), ['Empty'])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.hostname = None
                                            self.string = None
                                            self._segment_path = lambda: "remote-id"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/snooping/information/options/option/format/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping.Information.Options.Option.Format.RemoteId, ['hostname', 'string'], name, value)


                    class Track(Entity):
                        """
                        DHCP snooping track
                        
                        .. attribute:: host
                        
                        	DHCP snooping track host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.SnoopingConf.Snooping.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "snooping"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                            ])
                            self.host = None
                            self._segment_path = lambda: "track"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/snooping/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping.Track, ['host'], name, value)


                    class Verify(Entity):
                        """
                        DHCP snooping verify
                        
                        .. attribute:: mac_address
                        
                        	DHCP snooping verify mac\-address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: no_relay_agent_address
                        
                        	DHCP snooping verify giaddr
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.SnoopingConf.Snooping.Verify, self).__init__()

                            self.yang_name = "verify"
                            self.yang_parent_name = "snooping"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mac_address', (YLeaf(YType.empty, 'mac-address'), ['Empty'])),
                                ('no_relay_agent_address', (YLeaf(YType.empty, 'no-relay-agent-address'), ['Empty'])),
                            ])
                            self.mac_address = None
                            self.no_relay_agent_address = None
                            self._segment_path = lambda: "verify"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/snooping/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping.Verify, ['mac_address', 'no_relay_agent_address'], name, value)


                    class Vlan(Entity):
                        """
                        DHCP Snooping vlan
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.SnoopingConf.Snooping.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "snooping"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ])
                            self.id = None
                            self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/snooping/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping.Vlan, ['id'], name, value)


                    class Wireless(Entity):
                        """
                        DHCP snooping wireless
                        
                        .. attribute:: bootp_broadcast
                        
                        	DHCP snooping wireless bootp\-broadcast
                        	**type**\:  :py:class:`BootpBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.SnoopingConf.Snooping.Wireless.BootpBroadcast>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ip.Dhcp.SnoopingConf.Snooping.Wireless, self).__init__()

                            self.yang_name = "wireless"
                            self.yang_parent_name = "snooping"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bootp-broadcast", ("bootp_broadcast", Native.Ip.Dhcp.SnoopingConf.Snooping.Wireless.BootpBroadcast))])
                            self._leafs = OrderedDict()

                            self.bootp_broadcast = Native.Ip.Dhcp.SnoopingConf.Snooping.Wireless.BootpBroadcast()
                            self.bootp_broadcast.parent = self
                            self._children_name_map["bootp_broadcast"] = "bootp-broadcast"
                            self._segment_path = lambda: "wireless"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/snooping/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping.Wireless, [], name, value)


                        class BootpBroadcast(Entity):
                            """
                            DHCP snooping wireless bootp\-broadcast
                            
                            .. attribute:: enable
                            
                            	DHCP snooping wireless bootp\-broadcast enable
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Ip.Dhcp.SnoopingConf.Snooping.Wireless.BootpBroadcast, self).__init__()

                                self.yang_name = "bootp-broadcast"
                                self.yang_parent_name = "wireless"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                                ])
                                self.enable = None
                                self._segment_path = lambda: "bootp-broadcast"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:snooping-conf/snooping/wireless/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Dhcp.SnoopingConf.Snooping.Wireless.BootpBroadcast, ['enable'], name, value)


            class Use(Entity):
                """
                Configure use of certain parameters during allocation
                
                .. attribute:: class_
                
                	
                	**type**\:  :py:class:`Class <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Use.Class>`
                
                	**presence node**\: True
                
                .. attribute:: subscriber_id
                
                	Configure use of subscriber\-id suboption
                	**type**\:  :py:class:`SubscriberId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Use.SubscriberId>`
                
                .. attribute:: vrf
                
                	Ignore or use receiving interface VRF
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Dhcp.Use.Vrf>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ip.Dhcp.Use, self).__init__()

                    self.yang_name = "use"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("class", ("class_", Native.Ip.Dhcp.Use.Class)), ("subscriber-id", ("subscriber_id", Native.Ip.Dhcp.Use.SubscriberId)), ("vrf", ("vrf", Native.Ip.Dhcp.Use.Vrf))])
                    self._leafs = OrderedDict()

                    self.class_ = None
                    self._children_name_map["class_"] = "class"

                    self.subscriber_id = Native.Ip.Dhcp.Use.SubscriberId()
                    self.subscriber_id.parent = self
                    self._children_name_map["subscriber_id"] = "subscriber-id"

                    self.vrf = Native.Ip.Dhcp.Use.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:use"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Dhcp.Use, [], name, value)


                class Class(Entity):
                    """
                    
                    
                    .. attribute:: aaa
                    
                    	Configure use of aaa to get class
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Use.Class, self).__init__()

                        self.yang_name = "class"
                        self.yang_parent_name = "use"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aaa', (YLeaf(YType.empty, 'aaa'), ['Empty'])),
                        ])
                        self.aaa = None
                        self._segment_path = lambda: "class"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:use/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Use.Class, ['aaa'], name, value)


                class SubscriberId(Entity):
                    """
                    Configure use of subscriber\-id suboption
                    
                    .. attribute:: client_id
                    
                    	Use subscriber\-id suboption as client\-id
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Use.SubscriberId, self).__init__()

                        self.yang_name = "subscriber-id"
                        self.yang_parent_name = "use"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('client_id', (YLeaf(YType.empty, 'client-id'), ['Empty'])),
                        ])
                        self.client_id = None
                        self._segment_path = lambda: "subscriber-id"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:use/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Use.SubscriberId, ['client_id'], name, value)


                class Vrf(Entity):
                    """
                    Ignore or use receiving interface VRF
                    
                    .. attribute:: connected
                    
                    	Use input interface VRF when servicing connected clients
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: remote
                    
                    	Use input interface VRF when servicing remote clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ip.Dhcp.Use.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "use"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('connected', (YLeaf(YType.boolean, 'connected'), ['bool'])),
                            ('remote', (YLeaf(YType.empty, 'remote'), ['Empty'])),
                        ])
                        self.connected = None
                        self.remote = None
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/dhcp/Cisco-IOS-XE-dhcp:use/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Dhcp.Use.Vrf, ['connected', 'remote'], name, value)


        class ForwardProtocol(Entity):
            """
            Controls forwarding of physical and directed IP broadcasts
            
            .. attribute:: protocol
            
            	
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ForwardProtocol.Protocol>`
            
            .. attribute:: spanning_tree
            
            	Use transparent bridging to flood UDP broadcasts
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ForwardProtocol.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: udp
            
            	Packets to a specific UDP port
            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ForwardProtocol.Udp>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.ForwardProtocol, self).__init__()

                self.yang_name = "forward-protocol"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Ip.ForwardProtocol.SpanningTree)), ("udp", ("udp", Native.Ip.ForwardProtocol.Udp))])
                self._leafs = OrderedDict([
                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.ForwardProtocol.Protocol')])),
                ])
                self.protocol = None

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.udp = Native.Ip.ForwardProtocol.Udp()
                self.udp.parent = self
                self._children_name_map["udp"] = "udp"
                self._segment_path = lambda: "forward-protocol"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.ForwardProtocol, [u'protocol'], name, value)

            class Protocol(Enum):
                """
                Protocol (Enum Class)

                .. data:: nd = 0

                .. data:: sdns = 1

                .. data:: turbo_flood = 2

                """

                nd = Enum.YLeaf(0, "nd")

                sdns = Enum.YLeaf(1, "sdns")

                turbo_flood = Enum.YLeaf(2, "turbo-flood")



            class SpanningTree(Entity):
                """
                Use transparent bridging to flood UDP broadcasts
                
                .. attribute:: any_local_broadcast
                
                	Accept any local broadcast when flooding
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.ForwardProtocol.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "forward-protocol"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('any_local_broadcast', (YLeaf(YType.empty, 'any-local-broadcast'), ['Empty'])),
                    ])
                    self.any_local_broadcast = None
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/forward-protocol/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.ForwardProtocol.SpanningTree, [u'any_local_broadcast'], name, value)


            class Udp(Entity):
                """
                Packets to a specific UDP port
                
                .. attribute:: biff
                
                	Biff (mail notification, comsat, 512)
                	**type**\: bool
                
                .. attribute:: bootpc
                
                	Bootstrap Protocol (BOOTP) client (68)
                	**type**\: bool
                
                .. attribute:: bootps
                
                	Bootstrap Protocol (BOOTP) server (67)
                	**type**\: bool
                
                .. attribute:: discard
                
                	Discard (9)
                	**type**\: bool
                
                .. attribute:: dnsix
                
                	DNSIX security protocol auditing (195)
                	**type**\: bool
                
                .. attribute:: domain
                
                	Domain Name Service (DNS, 53)
                	**type**\: bool
                
                .. attribute:: echo
                
                	Echo (7)
                	**type**\: bool
                
                .. attribute:: isakmp
                
                	Internet Security Association and Key Management Protocol(500)
                	**type**\: bool
                
                .. attribute:: mobile_ip
                
                	Mobile IP registration (434)
                	**type**\: bool
                
                .. attribute:: nameserver
                
                	IEN116 name service (obsolete, 42)
                	**type**\: bool
                
                .. attribute:: netbios_dgm
                
                	NetBios datagram service (138)
                	**type**\: bool
                
                .. attribute:: netbios_ns
                
                	NetBios name service (137)
                	**type**\: bool
                
                .. attribute:: netbios_ss
                
                	NetBios session service (139)
                	**type**\: bool
                
                .. attribute:: non500_isakmp
                
                	Internet Security Association and Key Management Protocol(4500)
                	**type**\: bool
                
                .. attribute:: ntp
                
                	Network Time Protocol (123)
                	**type**\: bool
                
                .. attribute:: pim_auto_rp
                
                	PIM Auto\-RP (496)
                	**type**\: bool
                
                .. attribute:: rip
                
                	Routing Information Protocol (router, in.routed, 520)
                	**type**\: bool
                
                .. attribute:: snmp
                
                	Simple Network Management Protocol (161)
                	**type**\: bool
                
                .. attribute:: snmptrap
                
                	SNMP Traps (162)
                	**type**\: bool
                
                .. attribute:: sunrpc
                
                	Sun Remote Procedure Call (111)
                	**type**\: bool
                
                .. attribute:: syslog
                
                	System Logger (514)
                	**type**\: bool
                
                .. attribute:: tacacs
                
                	TAC Access Control System (49)
                	**type**\: bool
                
                .. attribute:: talk
                
                	Talk (517)
                	**type**\: bool
                
                .. attribute:: tftp
                
                	Trivial File Transfer Protocol (69)
                	**type**\: bool
                
                .. attribute:: time
                
                	Time (37)
                	**type**\: bool
                
                .. attribute:: who
                
                	Who service (rwho, 513)
                	**type**\: bool
                
                .. attribute:: xdmcp
                
                	X Display Manager Control Protocol (177)
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.ForwardProtocol.Udp, self).__init__()

                    self.yang_name = "udp"
                    self.yang_parent_name = "forward-protocol"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('biff', (YLeaf(YType.boolean, 'biff'), ['bool'])),
                        ('bootpc', (YLeaf(YType.boolean, 'bootpc'), ['bool'])),
                        ('bootps', (YLeaf(YType.boolean, 'bootps'), ['bool'])),
                        ('discard', (YLeaf(YType.boolean, 'discard'), ['bool'])),
                        ('dnsix', (YLeaf(YType.boolean, 'dnsix'), ['bool'])),
                        ('domain', (YLeaf(YType.boolean, 'domain'), ['bool'])),
                        ('echo', (YLeaf(YType.boolean, 'echo'), ['bool'])),
                        ('isakmp', (YLeaf(YType.boolean, 'isakmp'), ['bool'])),
                        ('mobile_ip', (YLeaf(YType.boolean, 'mobile-ip'), ['bool'])),
                        ('nameserver', (YLeaf(YType.boolean, 'nameserver'), ['bool'])),
                        ('netbios_dgm', (YLeaf(YType.boolean, 'netbios-dgm'), ['bool'])),
                        ('netbios_ns', (YLeaf(YType.boolean, 'netbios-ns'), ['bool'])),
                        ('netbios_ss', (YLeaf(YType.boolean, 'netbios-ss'), ['bool'])),
                        ('non500_isakmp', (YLeaf(YType.boolean, 'non500-isakmp'), ['bool'])),
                        ('ntp', (YLeaf(YType.boolean, 'ntp'), ['bool'])),
                        ('pim_auto_rp', (YLeaf(YType.boolean, 'pim-auto-rp'), ['bool'])),
                        ('rip', (YLeaf(YType.boolean, 'rip'), ['bool'])),
                        ('snmp', (YLeaf(YType.boolean, 'snmp'), ['bool'])),
                        ('snmptrap', (YLeaf(YType.boolean, 'snmptrap'), ['bool'])),
                        ('sunrpc', (YLeaf(YType.boolean, 'sunrpc'), ['bool'])),
                        ('syslog', (YLeaf(YType.boolean, 'syslog'), ['bool'])),
                        ('tacacs', (YLeaf(YType.boolean, 'tacacs'), ['bool'])),
                        ('talk', (YLeaf(YType.boolean, 'talk'), ['bool'])),
                        ('tftp', (YLeaf(YType.boolean, 'tftp'), ['bool'])),
                        ('time', (YLeaf(YType.boolean, 'time'), ['bool'])),
                        ('who', (YLeaf(YType.boolean, 'who'), ['bool'])),
                        ('xdmcp', (YLeaf(YType.boolean, 'xdmcp'), ['bool'])),
                    ])
                    self.biff = None
                    self.bootpc = None
                    self.bootps = None
                    self.discard = None
                    self.dnsix = None
                    self.domain = None
                    self.echo = None
                    self.isakmp = None
                    self.mobile_ip = None
                    self.nameserver = None
                    self.netbios_dgm = None
                    self.netbios_ns = None
                    self.netbios_ss = None
                    self.non500_isakmp = None
                    self.ntp = None
                    self.pim_auto_rp = None
                    self.rip = None
                    self.snmp = None
                    self.snmptrap = None
                    self.sunrpc = None
                    self.syslog = None
                    self.tacacs = None
                    self.talk = None
                    self.tftp = None
                    self.time = None
                    self.who = None
                    self.xdmcp = None
                    self._segment_path = lambda: "udp"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/forward-protocol/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.ForwardProtocol.Udp, [u'biff', u'bootpc', u'bootps', u'discard', u'dnsix', u'domain', u'echo', u'isakmp', u'mobile_ip', u'nameserver', u'netbios_dgm', u'netbios_ns', u'netbios_ss', u'non500_isakmp', u'ntp', u'pim_auto_rp', u'rip', u'snmp', u'snmptrap', u'sunrpc', u'syslog', u'tacacs', u'talk', u'tftp', u'time', u'who', u'xdmcp'], name, value)


        class GratuitousArpsConf(Entity):
            """
            
            
            .. attribute:: gratuitous_arps
            
            	
            	**type**\: bool
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.GratuitousArpsConf, self).__init__()

                self.yang_name = "gratuitous-arps-conf"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('gratuitous_arps', (YLeaf(YType.boolean, 'gratuitous-arps'), ['bool'])),
                ])
                self.gratuitous_arps = None
                self._segment_path = lambda: "gratuitous-arps-conf"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.GratuitousArpsConf, [u'gratuitous_arps'], name, value)


        class Ftp(Entity):
            """
            FTP configuration commands
            
            .. attribute:: source_interface
            
            	Specify interface for source address in FTP connections
            	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ftp.SourceInterface>`
            
            .. attribute:: passive
            
            	Connect using passive mode
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: password
            
            	Specify password for FTP connections;
            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ftp.Password>`
            
            .. attribute:: username
            
            	Specify username for FTP connections
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Ftp, self).__init__()

                self.yang_name = "ftp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("source-interface", ("source_interface", Native.Ip.Ftp.SourceInterface)), ("password", ("password", Native.Ip.Ftp.Password))])
                self._leafs = OrderedDict([
                    ('passive', (YLeaf(YType.empty, 'passive'), ['Empty'])),
                    ('username', (YLeaf(YType.str, 'username'), ['str'])),
                ])
                self.passive = None
                self.username = None

                self.source_interface = Native.Ip.Ftp.SourceInterface()
                self.source_interface.parent = self
                self._children_name_map["source_interface"] = "source-interface"

                self.password = Native.Ip.Ftp.Password()
                self.password.parent = self
                self._children_name_map["password"] = "password"
                self._segment_path = lambda: "ftp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Ftp, [u'passive', u'username'], name, value)


            class SourceInterface(Entity):
                """
                Specify interface for source address in FTP connections
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ftp.SourceInterface.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ftp.SourceInterface.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ftp.SourceInterface.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ftp.SourceInterface.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Ftp.SourceInterface, self).__init__()

                    self.yang_name = "source-interface"
                    self.yang_parent_name = "ftp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Ip.Ftp.SourceInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Ip.Ftp.SourceInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Ip.Ftp.SourceInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Ip.Ftp.SourceInterface.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.Ip.Ftp.SourceInterface.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.Ip.Ftp.SourceInterface.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.Ip.Ftp.SourceInterface.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.Ip.Ftp.SourceInterface.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "source-interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ftp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Ftp.SourceInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Ftp.SourceInterface.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ftp/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Ftp.SourceInterface.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Ftp.SourceInterface.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ftp/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Ftp.SourceInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Ftp.SourceInterface.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ftp/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Ftp.SourceInterface.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Ftp.SourceInterface.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ftp/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Ftp.SourceInterface.PortChannelSubinterface, [u'port_channel'], name, value)


            class Password(Entity):
                """
                Specify password for FTP connections;
                
                .. attribute:: password_container
                
                	
                	**type**\:  :py:class:`PasswordContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ftp.Password.PasswordContainer>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Ftp.Password, self).__init__()

                    self.yang_name = "password"
                    self.yang_parent_name = "ftp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("password-container", ("password_container", Native.Ip.Ftp.Password.PasswordContainer))])
                    self._leafs = OrderedDict()

                    self.password_container = Native.Ip.Ftp.Password.PasswordContainer()
                    self.password_container.parent = self
                    self._children_name_map["password_container"] = "password-container"
                    self._segment_path = lambda: "password"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ftp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Ftp.Password, [], name, value)


                class PasswordContainer(Entity):
                    """
                    
                    
                    .. attribute:: encryption
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..7
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ([1\-680\-9a\-zA\-Z].\*)\|(0.+)\|(7.+)
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Ftp.Password.PasswordContainer, self).__init__()

                        self.yang_name = "password-container"
                        self.yang_parent_name = "password"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('encryption', (YLeaf(YType.uint8, 'encryption'), ['int'])),
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.encryption = None
                        self.password = None
                        self._segment_path = lambda: "password-container"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ftp/password/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Ftp.Password.PasswordContainer, [u'encryption', u'password'], name, value)


        class Telnet(Entity):
            """
            Specify telnet options
            
            .. attribute:: source_interface
            
            	Specify source interface
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Telnet, self).__init__()

                self.yang_name = "telnet"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                ])
                self.source_interface = None
                self._segment_path = lambda: "telnet"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Telnet, [u'source_interface'], name, value)


        class Host(Entity):
            """
            Add an entry to the ip hostname table
            
            .. attribute:: host_list
            
            	
            	**type**\: list of  		 :py:class:`HostList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Host.HostList>`
            
            .. attribute:: vrf
            
            	Specify VRF
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Host.Vrf>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Host, self).__init__()

                self.yang_name = "host"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("host-list", ("host_list", Native.Ip.Host.HostList)), ("vrf", ("vrf", Native.Ip.Host.Vrf))])
                self._leafs = OrderedDict()

                self.host_list = YList(self)
                self.vrf = YList(self)
                self._segment_path = lambda: "host"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Host, [], name, value)


            class HostList(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	Name of host
                	**type**\: str
                
                .. attribute:: ip_list
                
                	Host IP address
                	**type**\: union of the below types:
                
                		**type**\: list of str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: list of str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Host.HostList, self).__init__()

                    self.yang_name = "host-list"
                    self.yang_parent_name = "host"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('ip_list', (YLeafList(YType.str, 'ip-list'), ['str','str'])),
                    ])
                    self.name = None
                    self.ip_list = []
                    self._segment_path = lambda: "host-list" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/host/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Host.HostList, [u'name', u'ip_list'], name, value)


            class Vrf(Entity):
                """
                Specify VRF
                
                .. attribute:: vrf_name  (key)
                
                	VRF name
                	**type**\: str
                
                .. attribute:: host_name
                
                	Name of host
                	**type**\: list of  		 :py:class:`HostName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Host.Vrf.HostName>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Host.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "host"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['vrf_name']
                    self._child_classes = OrderedDict([("host-name", ("host_name", Native.Ip.Host.Vrf.HostName))])
                    self._leafs = OrderedDict([
                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                    ])
                    self.vrf_name = None

                    self.host_name = YList(self)
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/host/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Host.Vrf, [u'vrf_name'], name, value)


                class HostName(Entity):
                    """
                    Name of host
                    
                    .. attribute:: host_name  (key)
                    
                    	Name of host
                    	**type**\: str
                    
                    .. attribute:: ip_list
                    
                    	Host IP address
                    	**type**\: union of the below types:
                    
                    		**type**\: list of str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: list of str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Host.Vrf.HostName, self).__init__()

                        self.yang_name = "host-name"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['host_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('host_name', (YLeaf(YType.str, 'host-name'), ['str'])),
                            ('ip_list', (YLeafList(YType.str, 'ip-list'), ['str','str'])),
                        ])
                        self.host_name = None
                        self.ip_list = []
                        self._segment_path = lambda: "host-name" + "[host-name='" + str(self.host_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Host.Vrf.HostName, [u'host_name', u'ip_list'], name, value)


        class Multicast(Entity):
            """
            Global IP Multicast Commands
            
            .. attribute:: route_limit
            
            	Maximum number of multicast routes
            	**type**\: int
            
            	**range:** 1..2147483647
            
            .. attribute:: multipath
            
            	RPF across equal\-cost paths
            	**type**\:  :py:class:`Multipath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Multicast.Multipath>`
            
            	**presence node**\: True
            
            .. attribute:: vrf
            
            	Select VPN Routing/Forwarding instance
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Multicast.Vrf>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Multicast, self).__init__()

                self.yang_name = "multicast"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:multipath", ("multipath", Native.Ip.Multicast.Multipath)), ("Cisco-IOS-XE-multicast:vrf", ("vrf", Native.Ip.Multicast.Vrf))])
                self._leafs = OrderedDict([
                    ('route_limit', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:route-limit'), ['int'])),
                ])
                self.route_limit = None

                self.multipath = None
                self._children_name_map["multipath"] = "Cisco-IOS-XE-multicast:multipath"

                self.vrf = YList(self)
                self._segment_path = lambda: "multicast"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Multicast, ['route_limit'], name, value)


            class Multipath(Entity):
                """
                RPF across equal\-cost paths
                
                .. attribute:: s_g_hash
                
                	Per\-(source, group) load sharing algorithm selection
                	**type**\:  :py:class:`SGHash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Multicast.Multipath.SGHash>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Multicast.Multipath, self).__init__()

                    self.yang_name = "multipath"
                    self.yang_parent_name = "multicast"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('s_g_hash', (YLeaf(YType.enumeration, 's-g-hash'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Multicast.Multipath.SGHash')])),
                    ])
                    self.s_g_hash = None
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:multipath"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/multicast/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Multicast.Multipath, ['s_g_hash'], name, value)

                class SGHash(Enum):
                    """
                    SGHash (Enum Class)

                    Per\-(source, group) load sharing algorithm selection

                    .. data:: basic = 0

                    .. data:: next_hop_based = 1

                    """

                    basic = Enum.YLeaf(0, "basic")

                    next_hop_based = Enum.YLeaf(1, "next-hop-based")



            class Vrf(Entity):
                """
                Select VPN Routing/Forwarding instance
                
                .. attribute:: name  (key)
                
                	VPN Routing/Forwarding instance name
                	**type**\: str
                
                .. attribute:: multipath
                
                	RPF across equal\-cost paths
                	**type**\:  :py:class:`Multipath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Multicast.Vrf.Multipath>`
                
                	**presence node**\: True
                
                .. attribute:: route_limit
                
                	Maximum number of multicast routes
                	**type**\:  :py:class:`RouteLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Multicast.Vrf.RouteLimit>`
                
                .. attribute:: rpf
                
                	RPF check configuration
                	**type**\:  :py:class:`Rpf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Multicast.Vrf.Rpf>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Multicast.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "multicast"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("multipath", ("multipath", Native.Ip.Multicast.Vrf.Multipath)), ("route-limit", ("route_limit", Native.Ip.Multicast.Vrf.RouteLimit)), ("rpf", ("rpf", Native.Ip.Multicast.Vrf.Rpf))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.multipath = None
                    self._children_name_map["multipath"] = "multipath"

                    self.route_limit = Native.Ip.Multicast.Vrf.RouteLimit()
                    self.route_limit.parent = self
                    self._children_name_map["route_limit"] = "route-limit"

                    self.rpf = Native.Ip.Multicast.Vrf.Rpf()
                    self.rpf.parent = self
                    self._children_name_map["rpf"] = "rpf"
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:vrf" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/multicast/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Multicast.Vrf, ['name'], name, value)


                class Multipath(Entity):
                    """
                    RPF across equal\-cost paths
                    
                    .. attribute:: s_g_hash
                    
                    	Per\-(source, group) load sharing algorithm selection
                    	**type**\:  :py:class:`SGHash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Multicast.Vrf.Multipath.SGHash>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Multicast.Vrf.Multipath, self).__init__()

                        self.yang_name = "multipath"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('s_g_hash', (YLeaf(YType.enumeration, 's-g-hash'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Multicast.Vrf.Multipath.SGHash')])),
                        ])
                        self.s_g_hash = None
                        self._segment_path = lambda: "multipath"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Multicast.Vrf.Multipath, ['s_g_hash'], name, value)

                    class SGHash(Enum):
                        """
                        SGHash (Enum Class)

                        Per\-(source, group) load sharing algorithm selection

                        .. data:: basic = 0

                        .. data:: next_hop_based = 1

                        """

                        basic = Enum.YLeaf(0, "basic")

                        next_hop_based = Enum.YLeaf(1, "next-hop-based")



                class RouteLimit(Entity):
                    """
                    Maximum number of multicast routes
                    
                    .. attribute:: no_routes
                    
                    	Number of routes
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: warning_threshold
                    
                    	Threshold at which to generate warning message
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Multicast.Vrf.RouteLimit, self).__init__()

                        self.yang_name = "route-limit"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('no_routes', (YLeaf(YType.uint32, 'no-routes'), ['int'])),
                            ('warning_threshold', (YLeaf(YType.uint32, 'warning-threshold'), ['int'])),
                        ])
                        self.no_routes = None
                        self.warning_threshold = None
                        self._segment_path = lambda: "route-limit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Multicast.Vrf.RouteLimit, ['no_routes', 'warning_threshold'], name, value)


                class Rpf(Entity):
                    """
                    RPF check configuration
                    
                    .. attribute:: select
                    
                    	Select table for RPF check
                    	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Multicast.Vrf.Rpf.Select>`
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Multicast.Vrf.Rpf, self).__init__()

                        self.yang_name = "rpf"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("select", ("select", Native.Ip.Multicast.Vrf.Rpf.Select))])
                        self._leafs = OrderedDict()

                        self.select = Native.Ip.Multicast.Vrf.Rpf.Select()
                        self.select.parent = self
                        self._children_name_map["select"] = "select"
                        self._segment_path = lambda: "rpf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Multicast.Vrf.Rpf, [], name, value)


                    class Select(Entity):
                        """
                        Select table for RPF check
                        
                        .. attribute:: vrf
                        
                        	Select VPN Routing/Forwarding instance
                        	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Multicast.Vrf.Rpf.Select.Vrf_>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Multicast.Vrf.Rpf.Select, self).__init__()

                            self.yang_name = "select"
                            self.yang_parent_name = "rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ip.Multicast.Vrf.Rpf.Select.Vrf_))])
                            self._leafs = OrderedDict()

                            self.vrf = YList(self)
                            self._segment_path = lambda: "select"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Multicast.Vrf.Rpf.Select, [], name, value)


                        class Vrf_(Entity):
                            """
                            Select VPN Routing/Forwarding instance
                            
                            .. attribute:: name  (key)
                            
                            	VPN Routing/Forwarding instance name
                            	**type**\: str
                            
                            .. attribute:: group_list
                            
                            	Group access\-list
                            	**type**\: list of  		 :py:class:`GroupList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Multicast.Vrf.Rpf.Select.Vrf_.GroupList>`
                            
                            

                            """

                            _prefix = 'ios-mc'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ip.Multicast.Vrf.Rpf.Select.Vrf_, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "select"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("group-list", ("group_list", Native.Ip.Multicast.Vrf.Rpf.Select.Vrf_.GroupList))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.group_list = YList(self)
                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Multicast.Vrf.Rpf.Select.Vrf_, ['name'], name, value)


                            class GroupList(Entity):
                                """
                                Group access\-list
                                
                                .. attribute:: group_list_name  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..99
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios-mc'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ip.Multicast.Vrf.Rpf.Select.Vrf_.GroupList, self).__init__()

                                    self.yang_name = "group-list"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['group_list_name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('group_list_name', (YLeaf(YType.str, 'group-list-name'), ['int','str'])),
                                    ])
                                    self.group_list_name = None
                                    self._segment_path = lambda: "group-list" + "[group-list-name='" + str(self.group_list_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Multicast.Vrf.Rpf.Select.Vrf_.GroupList, ['group_list_name'], name, value)


        class NameServer(Entity):
            """
            
            
            .. attribute:: no_vrf
            
            	
            	**type**\: union of the below types:
            
            		**type**\: list of str
            
            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            		**type**\: list of str
            
            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf
            
            	
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.NameServer.Vrf>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.NameServer, self).__init__()

                self.yang_name = "name-server"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ip.NameServer.Vrf))])
                self._leafs = OrderedDict([
                    ('no_vrf', (YLeafList(YType.str, 'no-vrf'), ['str','str'])),
                ])
                self.no_vrf = []

                self.vrf = YList(self)
                self._segment_path = lambda: "name-server"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.NameServer, [u'no_vrf'], name, value)


            class Vrf(Entity):
                """
                
                
                .. attribute:: word  (key)
                
                	
                	**type**\: str
                
                .. attribute:: server_ip
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.NameServer.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "name-server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['word']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('word', (YLeaf(YType.str, 'word'), ['str'])),
                        ('server_ip', (YLeaf(YType.str, 'server-ip'), ['str','str'])),
                    ])
                    self.word = None
                    self.server_ip = None
                    self._segment_path = lambda: "vrf" + "[word='" + str(self.word) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/name-server/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.NameServer.Vrf, [u'word', u'server_ip'], name, value)


        class Pim(Entity):
            """
            PIM global commands
            
            .. attribute:: accept_register
            
            	Registers accept filter
            	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.AcceptRegister>`
            
            .. attribute:: autorp
            
            	Configure AutoRP global operations
            	**type**\:  :py:class:`Autorp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Autorp>`
            
            	**presence node**\: True
            
            .. attribute:: register_source
            
            	Source address for PIM Register
            	**type**\: str
            
            .. attribute:: rp_address
            
            	PIM RP\-address (Rendezvous Point)
            	**type**\: list of  		 :py:class:`RpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.RpAddress>`
            
            .. attribute:: spt_threshold
            
            	Source\-tree switching threshold
            	**type**\: list of  		 :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.SptThreshold>`
            
            .. attribute:: spt_threshold_container
            
            	
            	**type**\:  :py:class:`SptThresholdContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.SptThresholdContainer>`
            
            .. attribute:: send_rp_announce
            
            	Auto\-RP send RP announcement
            	**type**\:  :py:class:`SendRpAnnounce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.SendRpAnnounce>`
            
            .. attribute:: send_rp_discovery
            
            	Auto\-RP send RP discovery message (as RP\-mapping agent)
            	**type**\:  :py:class:`SendRpDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.SendRpDiscovery>`
            
            .. attribute:: ssm
            
            	Configure Source Specific Multicast
            	**type**\:  :py:class:`Ssm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Ssm>`
            
            .. attribute:: vrf
            
            	Select VPN Routing/Forwarding instance
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Pim, self).__init__()

                self.yang_name = "pim"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:autorp", ("autorp", Native.Ip.Pim.Autorp)), ("Cisco-IOS-XE-multicast:rp-address", ("rp_address", Native.Ip.Pim.RpAddress)), ("Cisco-IOS-XE-multicast:spt-threshold", ("spt_threshold", Native.Ip.Pim.SptThreshold)), ("Cisco-IOS-XE-multicast:spt-threshold-container", ("spt_threshold_container", Native.Ip.Pim.SptThresholdContainer)), ("Cisco-IOS-XE-multicast:send-rp-announce", ("send_rp_announce", Native.Ip.Pim.SendRpAnnounce)), ("Cisco-IOS-XE-multicast:send-rp-discovery", ("send_rp_discovery", Native.Ip.Pim.SendRpDiscovery)), ("Cisco-IOS-XE-multicast:ssm", ("ssm", Native.Ip.Pim.Ssm)), ("Cisco-IOS-XE-multicast:vrf", ("vrf", Native.Ip.Pim.Vrf))])
                self._leafs = OrderedDict([
                    ('register_source', (YLeaf(YType.str, 'Cisco-IOS-XE-multicast:register-source'), ['str'])),
                ])
                self.register_source = None

                self.accept_register = Native.Ip.Pim.AcceptRegister()
                self.accept_register.parent = self
                self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                self.autorp = None
                self._children_name_map["autorp"] = "Cisco-IOS-XE-multicast:autorp"

                self.spt_threshold_container = Native.Ip.Pim.SptThresholdContainer()
                self.spt_threshold_container.parent = self
                self._children_name_map["spt_threshold_container"] = "Cisco-IOS-XE-multicast:spt-threshold-container"

                self.send_rp_announce = Native.Ip.Pim.SendRpAnnounce()
                self.send_rp_announce.parent = self
                self._children_name_map["send_rp_announce"] = "Cisco-IOS-XE-multicast:send-rp-announce"

                self.send_rp_discovery = Native.Ip.Pim.SendRpDiscovery()
                self.send_rp_discovery.parent = self
                self._children_name_map["send_rp_discovery"] = "Cisco-IOS-XE-multicast:send-rp-discovery"

                self.ssm = Native.Ip.Pim.Ssm()
                self.ssm.parent = self
                self._children_name_map["ssm"] = "Cisco-IOS-XE-multicast:ssm"

                self.rp_address = YList(self)
                self.spt_threshold = YList(self)
                self.vrf = YList(self)
                self._segment_path = lambda: "pim"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Pim, ['register_source'], name, value)


            class AcceptRegister(Entity):
                """
                Registers accept filter
                
                .. attribute:: list
                
                	Access list
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 100..199
                
                		**type**\: int
                
                			**range:** 2000..2699
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Pim.AcceptRegister, self).__init__()

                    self.yang_name = "accept-register"
                    self.yang_parent_name = "pim"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                    ])
                    self.list = None
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Pim.AcceptRegister, ['list'], name, value)


            class Autorp(Entity):
                """
                Configure AutoRP global operations
                
                .. attribute:: listener
                
                	Allow AutoRP packets across sparse mode interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Pim.Autorp, self).__init__()

                    self.yang_name = "autorp"
                    self.yang_parent_name = "pim"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('listener', (YLeaf(YType.empty, 'listener'), ['Empty'])),
                    ])
                    self.listener = None
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:autorp"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Pim.Autorp, ['listener'], name, value)


            class RpAddress(Entity):
                """
                PIM RP\-address (Rendezvous Point)
                
                .. attribute:: address  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: access_list
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: int
                
                			**range:** 1300..1999
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: override
                
                	Overrides dynamically learnt RP mappings
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Pim.RpAddress, self).__init__()

                    self.yang_name = "rp-address"
                    self.yang_parent_name = "pim"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['address']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int','str'])),
                        ('override', (YLeaf(YType.empty, 'override'), ['Empty'])),
                    ])
                    self.address = None
                    self.access_list = None
                    self.override = None
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:rp-address" + "[address='" + str(self.address) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Pim.RpAddress, ['address', 'access_list', 'override'], name, value)


            class SptThreshold(Entity):
                """
                Source\-tree switching threshold
                
                .. attribute:: how  (key)
                
                	
                	**type**\:  :py:class:`How <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.SptThreshold.How>`
                
                .. attribute:: group_list  (key)
                
                	Group address access\-list
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: int
                
                			**range:** 1300..1999
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Pim.SptThreshold, self).__init__()

                    self.yang_name = "spt-threshold"
                    self.yang_parent_name = "pim"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['how','group_list']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('how', (YLeaf(YType.enumeration, 'how'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Pim.SptThreshold.How')])),
                        ('group_list', (YLeaf(YType.str, 'group-list'), ['int','int','str'])),
                    ])
                    self.how = None
                    self.group_list = None
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:spt-threshold" + "[how='" + str(self.how) + "']" + "[group-list='" + str(self.group_list) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Pim.SptThreshold, ['how', 'group_list'], name, value)

                class How(Enum):
                    """
                    How (Enum Class)

                    .. data:: Y_0 = 0

                    .. data:: infinity = 1

                    """

                    Y_0 = Enum.YLeaf(0, "0")

                    infinity = Enum.YLeaf(1, "infinity")



            class SptThresholdContainer(Entity):
                """
                
                
                .. attribute:: spt_threshold
                
                	Source\-tree switching threshold
                	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.SptThresholdContainer.SptThreshold>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Pim.SptThresholdContainer, self).__init__()

                    self.yang_name = "spt-threshold-container"
                    self.yang_parent_name = "pim"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("spt-threshold", ("spt_threshold", Native.Ip.Pim.SptThresholdContainer.SptThreshold))])
                    self._leafs = OrderedDict()

                    self.spt_threshold = Native.Ip.Pim.SptThresholdContainer.SptThreshold()
                    self.spt_threshold.parent = self
                    self._children_name_map["spt_threshold"] = "spt-threshold"
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:spt-threshold-container"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Pim.SptThresholdContainer, [], name, value)


                class SptThreshold(Entity):
                    """
                    Source\-tree switching threshold
                    
                    .. attribute:: how
                    
                    	
                    	**type**\:  :py:class:`How <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.SptThresholdContainer.SptThreshold.How>`
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Pim.SptThresholdContainer.SptThreshold, self).__init__()

                        self.yang_name = "spt-threshold"
                        self.yang_parent_name = "spt-threshold-container"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('how', (YLeaf(YType.enumeration, 'how'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Pim.SptThresholdContainer.SptThreshold.How')])),
                        ])
                        self.how = None
                        self._segment_path = lambda: "spt-threshold"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/Cisco-IOS-XE-multicast:spt-threshold-container/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Pim.SptThresholdContainer.SptThreshold, ['how'], name, value)

                    class How(Enum):
                        """
                        How (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: infinity = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        infinity = Enum.YLeaf(1, "infinity")



            class SendRpAnnounce(Entity):
                """
                Auto\-RP send RP announcement
                
                .. attribute:: interface_list
                
                	
                	**type**\: list of  		 :py:class:`InterfaceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.SendRpAnnounce.InterfaceList>`
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: list of  		 :py:class:`PortChannel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.SendRpAnnounce.PortChannel>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Pim.SendRpAnnounce, self).__init__()

                    self.yang_name = "send-rp-announce"
                    self.yang_parent_name = "pim"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface_list", ("interface_list", Native.Ip.Pim.SendRpAnnounce.InterfaceList)), ("Port-channel", ("port_channel", Native.Ip.Pim.SendRpAnnounce.PortChannel))])
                    self._leafs = OrderedDict()

                    self.interface_list = YList(self)
                    self.port_channel = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:send-rp-announce"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Pim.SendRpAnnounce, [], name, value)


                class InterfaceList(Entity):
                    """
                    
                    
                    .. attribute:: if_name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: scope
                    
                    	RP announcement scope
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.SendRpAnnounce.InterfaceList.Scope>`
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Pim.SendRpAnnounce.InterfaceList, self).__init__()

                        self.yang_name = "interface_list"
                        self.yang_parent_name = "send-rp-announce"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['if_name']
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Ip.Pim.SendRpAnnounce.InterfaceList.Scope))])
                        self._leafs = OrderedDict([
                            ('if_name', (YLeaf(YType.str, 'if-name'), ['str'])),
                        ])
                        self.if_name = None

                        self.scope = Native.Ip.Pim.SendRpAnnounce.InterfaceList.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "interface_list" + "[if-name='" + str(self.if_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/Cisco-IOS-XE-multicast:send-rp-announce/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Pim.SendRpAnnounce.InterfaceList, ['if_name'], name, value)


                    class Scope(Entity):
                        """
                        RP announcement scope
                        
                        .. attribute:: pkt_ttl
                        
                        	TTL of the RP announce packet
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: group_list
                        
                        	Group access\-list
                        	**type**\:  :py:class:`GroupList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.SendRpAnnounce.InterfaceList.Scope.GroupList>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Pim.SendRpAnnounce.InterfaceList.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "interface_list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group-list", ("group_list", Native.Ip.Pim.SendRpAnnounce.InterfaceList.Scope.GroupList))])
                            self._leafs = OrderedDict([
                                ('pkt_ttl', (YLeaf(YType.uint8, 'pkt-ttl'), ['int'])),
                            ])
                            self.pkt_ttl = None

                            self.group_list = Native.Ip.Pim.SendRpAnnounce.InterfaceList.Scope.GroupList()
                            self.group_list.parent = self
                            self._children_name_map["group_list"] = "group-list"
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Pim.SendRpAnnounce.InterfaceList.Scope, ['pkt_ttl'], name, value)


                        class GroupList(Entity):
                            """
                            Group access\-list
                            
                            .. attribute:: acl_ref
                            
                            	Access\-list reference for multicast groups
                            	**type**\: int
                            
                            	**range:** 1..99
                            
                            .. attribute:: std_acl
                            
                            	IP Named Standard Access list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-mc'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ip.Pim.SendRpAnnounce.InterfaceList.Scope.GroupList, self).__init__()

                                self.yang_name = "group-list"
                                self.yang_parent_name = "scope"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_ref', (YLeaf(YType.uint8, 'acl-ref'), ['int'])),
                                    ('std_acl', (YLeaf(YType.str, 'std-acl'), ['str'])),
                                ])
                                self.acl_ref = None
                                self.std_acl = None
                                self._segment_path = lambda: "group-list"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Pim.SendRpAnnounce.InterfaceList.Scope.GroupList, ['acl_ref', 'std_acl'], name, value)


                class PortChannel(Entity):
                    """
                    Ethernet Channel of interfaces
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..512
                    
                    .. attribute:: scope
                    
                    	RP announcement scope
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Pim.SendRpAnnounce.PortChannel, self).__init__()

                        self.yang_name = "Port-channel"
                        self.yang_parent_name = "send-rp-announce"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.uint32, 'name'), ['int'])),
                            ('scope', (YLeaf(YType.uint8, 'scope'), ['int'])),
                        ])
                        self.name = None
                        self.scope = None
                        self._segment_path = lambda: "Port-channel" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/Cisco-IOS-XE-multicast:send-rp-announce/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Pim.SendRpAnnounce.PortChannel, ['name', 'scope'], name, value)


            class SendRpDiscovery(Entity):
                """
                Auto\-RP send RP discovery message (as RP\-mapping agent)
                
                .. attribute:: scope
                
                	Scope of the RP discovery packets\: TTL
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Pim.SendRpDiscovery, self).__init__()

                    self.yang_name = "send-rp-discovery"
                    self.yang_parent_name = "pim"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('scope', (YLeaf(YType.uint8, 'scope'), ['int'])),
                    ])
                    self.scope = None
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:send-rp-discovery"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Pim.SendRpDiscovery, ['scope'], name, value)


            class Ssm(Entity):
                """
                Configure Source Specific Multicast
                
                .. attribute:: range
                
                	ACL for group range to be used for SSM
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: default
                
                	Use 232/8 group range for SSM
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Pim.Ssm, self).__init__()

                    self.yang_name = "ssm"
                    self.yang_parent_name = "pim"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('range', (YLeaf(YType.str, 'range'), ['int','str'])),
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                    ])
                    self.range = None
                    self.default = None
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:ssm"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Pim.Ssm, ['range', 'default'], name, value)


            class Vrf(Entity):
                """
                Select VPN Routing/Forwarding instance
                
                .. attribute:: id  (key)
                
                	
                	**type**\: str
                
                .. attribute:: accept_register
                
                	Registers accept filter
                	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.AcceptRegister>`
                
                .. attribute:: autorp
                
                	Configure AutoRP global operations
                	**type**\:  :py:class:`Autorp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.Autorp>`
                
                	**presence node**\: True
                
                .. attribute:: register_source
                
                	Source address for PIM Register
                	**type**\: str
                
                .. attribute:: rp_address
                
                	PIM RP\-address (Rendezvous Point)
                	**type**\: list of  		 :py:class:`RpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.RpAddress>`
                
                .. attribute:: spt_threshold
                
                	Source\-tree switching threshold
                	**type**\: list of  		 :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.SptThreshold>`
                
                .. attribute:: spt_threshold_container
                
                	
                	**type**\:  :py:class:`SptThresholdContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.SptThresholdContainer>`
                
                .. attribute:: send_rp_announce
                
                	Auto\-RP send RP announcement
                	**type**\:  :py:class:`SendRpAnnounce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.SendRpAnnounce>`
                
                .. attribute:: send_rp_discovery
                
                	Auto\-RP send RP discovery message (as RP\-mapping agent)
                	**type**\:  :py:class:`SendRpDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.SendRpDiscovery>`
                
                .. attribute:: ssm
                
                	Configure Source Specific Multicast
                	**type**\:  :py:class:`Ssm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.Ssm>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Pim.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "pim"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("accept-register", ("accept_register", Native.Ip.Pim.Vrf.AcceptRegister)), ("autorp", ("autorp", Native.Ip.Pim.Vrf.Autorp)), ("rp-address", ("rp_address", Native.Ip.Pim.Vrf.RpAddress)), ("spt-threshold", ("spt_threshold", Native.Ip.Pim.Vrf.SptThreshold)), ("spt-threshold-container", ("spt_threshold_container", Native.Ip.Pim.Vrf.SptThresholdContainer)), ("send-rp-announce", ("send_rp_announce", Native.Ip.Pim.Vrf.SendRpAnnounce)), ("send-rp-discovery", ("send_rp_discovery", Native.Ip.Pim.Vrf.SendRpDiscovery)), ("ssm", ("ssm", Native.Ip.Pim.Vrf.Ssm))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                        ('register_source', (YLeaf(YType.str, 'register-source'), ['str'])),
                    ])
                    self.id = None
                    self.register_source = None

                    self.accept_register = Native.Ip.Pim.Vrf.AcceptRegister()
                    self.accept_register.parent = self
                    self._children_name_map["accept_register"] = "accept-register"

                    self.autorp = None
                    self._children_name_map["autorp"] = "autorp"

                    self.spt_threshold_container = Native.Ip.Pim.Vrf.SptThresholdContainer()
                    self.spt_threshold_container.parent = self
                    self._children_name_map["spt_threshold_container"] = "spt-threshold-container"

                    self.send_rp_announce = Native.Ip.Pim.Vrf.SendRpAnnounce()
                    self.send_rp_announce.parent = self
                    self._children_name_map["send_rp_announce"] = "send-rp-announce"

                    self.send_rp_discovery = Native.Ip.Pim.Vrf.SendRpDiscovery()
                    self.send_rp_discovery.parent = self
                    self._children_name_map["send_rp_discovery"] = "send-rp-discovery"

                    self.ssm = Native.Ip.Pim.Vrf.Ssm()
                    self.ssm.parent = self
                    self._children_name_map["ssm"] = "ssm"

                    self.rp_address = YList(self)
                    self.spt_threshold = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:vrf" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/pim/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Pim.Vrf, ['id', 'register_source'], name, value)


                class AcceptRegister(Entity):
                    """
                    Registers accept filter
                    
                    .. attribute:: list
                    
                    	Access list
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 100..199
                    
                    		**type**\: int
                    
                    			**range:** 2000..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Pim.Vrf.AcceptRegister, self).__init__()

                        self.yang_name = "accept-register"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                        ])
                        self.list = None
                        self._segment_path = lambda: "accept-register"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Pim.Vrf.AcceptRegister, ['list'], name, value)


                class Autorp(Entity):
                    """
                    Configure AutoRP global operations
                    
                    .. attribute:: listener
                    
                    	Allow AutoRP packets across sparse mode interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Pim.Vrf.Autorp, self).__init__()

                        self.yang_name = "autorp"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('listener', (YLeaf(YType.empty, 'listener'), ['Empty'])),
                        ])
                        self.listener = None
                        self._segment_path = lambda: "autorp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Pim.Vrf.Autorp, ['listener'], name, value)


                class RpAddress(Entity):
                    """
                    PIM RP\-address (Rendezvous Point)
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: override
                    
                    	Overrides dynamically learnt RP mappings
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Pim.Vrf.RpAddress, self).__init__()

                        self.yang_name = "rp-address"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int','str'])),
                            ('override', (YLeaf(YType.empty, 'override'), ['Empty'])),
                        ])
                        self.address = None
                        self.access_list = None
                        self.override = None
                        self._segment_path = lambda: "rp-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Pim.Vrf.RpAddress, ['address', 'access_list', 'override'], name, value)


                class SptThreshold(Entity):
                    """
                    Source\-tree switching threshold
                    
                    .. attribute:: how  (key)
                    
                    	
                    	**type**\:  :py:class:`How <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.SptThreshold.How>`
                    
                    .. attribute:: group_list  (key)
                    
                    	Group address access\-list
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Pim.Vrf.SptThreshold, self).__init__()

                        self.yang_name = "spt-threshold"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['how','group_list']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('how', (YLeaf(YType.enumeration, 'how'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Pim.Vrf.SptThreshold.How')])),
                            ('group_list', (YLeaf(YType.str, 'group-list'), ['int','int','str'])),
                        ])
                        self.how = None
                        self.group_list = None
                        self._segment_path = lambda: "spt-threshold" + "[how='" + str(self.how) + "']" + "[group-list='" + str(self.group_list) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Pim.Vrf.SptThreshold, ['how', 'group_list'], name, value)

                    class How(Enum):
                        """
                        How (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: infinity = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        infinity = Enum.YLeaf(1, "infinity")



                class SptThresholdContainer(Entity):
                    """
                    
                    
                    .. attribute:: spt_threshold
                    
                    	Source\-tree switching threshold
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.SptThresholdContainer.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Pim.Vrf.SptThresholdContainer, self).__init__()

                        self.yang_name = "spt-threshold-container"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spt-threshold", ("spt_threshold", Native.Ip.Pim.Vrf.SptThresholdContainer.SptThreshold))])
                        self._leafs = OrderedDict()

                        self.spt_threshold = Native.Ip.Pim.Vrf.SptThresholdContainer.SptThreshold()
                        self.spt_threshold.parent = self
                        self._children_name_map["spt_threshold"] = "spt-threshold"
                        self._segment_path = lambda: "spt-threshold-container"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Pim.Vrf.SptThresholdContainer, [], name, value)


                    class SptThreshold(Entity):
                        """
                        Source\-tree switching threshold
                        
                        .. attribute:: how
                        
                        	
                        	**type**\:  :py:class:`How <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.SptThresholdContainer.SptThreshold.How>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Pim.Vrf.SptThresholdContainer.SptThreshold, self).__init__()

                            self.yang_name = "spt-threshold"
                            self.yang_parent_name = "spt-threshold-container"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('how', (YLeaf(YType.enumeration, 'how'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Pim.Vrf.SptThresholdContainer.SptThreshold.How')])),
                            ])
                            self.how = None
                            self._segment_path = lambda: "spt-threshold"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Pim.Vrf.SptThresholdContainer.SptThreshold, ['how'], name, value)

                        class How(Enum):
                            """
                            How (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: infinity = 1

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            infinity = Enum.YLeaf(1, "infinity")



                class SendRpAnnounce(Entity):
                    """
                    Auto\-RP send RP announcement
                    
                    .. attribute:: interface_list
                    
                    	
                    	**type**\: list of  		 :py:class:`InterfaceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList>`
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: list of  		 :py:class:`PortChannel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.SendRpAnnounce.PortChannel>`
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Pim.Vrf.SendRpAnnounce, self).__init__()

                        self.yang_name = "send-rp-announce"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface_list", ("interface_list", Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList)), ("Port-channel", ("port_channel", Native.Ip.Pim.Vrf.SendRpAnnounce.PortChannel))])
                        self._leafs = OrderedDict()

                        self.interface_list = YList(self)
                        self.port_channel = YList(self)
                        self._segment_path = lambda: "send-rp-announce"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Pim.Vrf.SendRpAnnounce, [], name, value)


                    class InterfaceList(Entity):
                        """
                        
                        
                        .. attribute:: if_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: scope
                        
                        	RP announcement scope
                        	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList.Scope>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList, self).__init__()

                            self.yang_name = "interface_list"
                            self.yang_parent_name = "send-rp-announce"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['if_name']
                            self._child_classes = OrderedDict([("scope", ("scope", Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList.Scope))])
                            self._leafs = OrderedDict([
                                ('if_name', (YLeaf(YType.str, 'if-name'), ['str'])),
                            ])
                            self.if_name = None

                            self.scope = Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList.Scope()
                            self.scope.parent = self
                            self._children_name_map["scope"] = "scope"
                            self._segment_path = lambda: "interface_list" + "[if-name='" + str(self.if_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList, ['if_name'], name, value)


                        class Scope(Entity):
                            """
                            RP announcement scope
                            
                            .. attribute:: pkt_ttl
                            
                            	TTL of the RP announce packet
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: group_list
                            
                            	Group access\-list
                            	**type**\:  :py:class:`GroupList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList.Scope.GroupList>`
                            
                            

                            """

                            _prefix = 'ios-mc'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList.Scope, self).__init__()

                                self.yang_name = "scope"
                                self.yang_parent_name = "interface_list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("group-list", ("group_list", Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList.Scope.GroupList))])
                                self._leafs = OrderedDict([
                                    ('pkt_ttl', (YLeaf(YType.uint8, 'pkt-ttl'), ['int'])),
                                ])
                                self.pkt_ttl = None

                                self.group_list = Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList.Scope.GroupList()
                                self.group_list.parent = self
                                self._children_name_map["group_list"] = "group-list"
                                self._segment_path = lambda: "scope"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList.Scope, ['pkt_ttl'], name, value)


                            class GroupList(Entity):
                                """
                                Group access\-list
                                
                                .. attribute:: acl_ref
                                
                                	Access\-list reference for multicast groups
                                	**type**\: int
                                
                                	**range:** 1..99
                                
                                .. attribute:: std_acl
                                
                                	IP Named Standard Access list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-mc'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList.Scope.GroupList, self).__init__()

                                    self.yang_name = "group-list"
                                    self.yang_parent_name = "scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acl_ref', (YLeaf(YType.uint8, 'acl-ref'), ['int'])),
                                        ('std_acl', (YLeaf(YType.str, 'std-acl'), ['str'])),
                                    ])
                                    self.acl_ref = None
                                    self.std_acl = None
                                    self._segment_path = lambda: "group-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Pim.Vrf.SendRpAnnounce.InterfaceList.Scope.GroupList, ['acl_ref', 'std_acl'], name, value)


                    class PortChannel(Entity):
                        """
                        Ethernet Channel of interfaces
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..512
                        
                        .. attribute:: scope
                        
                        	RP announcement scope
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Pim.Vrf.SendRpAnnounce.PortChannel, self).__init__()

                            self.yang_name = "Port-channel"
                            self.yang_parent_name = "send-rp-announce"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.uint32, 'name'), ['int'])),
                                ('scope', (YLeaf(YType.uint8, 'scope'), ['int'])),
                            ])
                            self.name = None
                            self.scope = None
                            self._segment_path = lambda: "Port-channel" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Pim.Vrf.SendRpAnnounce.PortChannel, ['name', 'scope'], name, value)


                class SendRpDiscovery(Entity):
                    """
                    Auto\-RP send RP discovery message (as RP\-mapping agent)
                    
                    .. attribute:: scope
                    
                    	Scope of the RP discovery packets\: TTL
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Pim.Vrf.SendRpDiscovery, self).__init__()

                        self.yang_name = "send-rp-discovery"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('scope', (YLeaf(YType.uint8, 'scope'), ['int'])),
                        ])
                        self.scope = None
                        self._segment_path = lambda: "send-rp-discovery"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Pim.Vrf.SendRpDiscovery, ['scope'], name, value)


                class Ssm(Entity):
                    """
                    Configure Source Specific Multicast
                    
                    .. attribute:: range
                    
                    	ACL for group range to be used for SSM
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: default
                    
                    	Use 232/8 group range for SSM
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Pim.Vrf.Ssm, self).__init__()

                        self.yang_name = "ssm"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.str, 'range'), ['int','str'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.range = None
                        self.default = None
                        self._segment_path = lambda: "ssm"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Pim.Vrf.Ssm, ['range', 'default'], name, value)


        class PrefixList(Entity):
            """
            Build a prefix list
            
            .. attribute:: prefixes
            
            	
            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes>`
            
            .. attribute:: sequence_number
            
            	Include/exclude sequence numbers in NVGEN
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.PrefixList, self).__init__()

                self.yang_name = "prefix-list"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Ip.PrefixList.Prefixes))])
                self._leafs = OrderedDict([
                    ('sequence_number', (YLeaf(YType.empty, 'sequence-number'), ['Empty'])),
                ])
                self.sequence_number = None

                self.prefixes = YList(self)
                self._segment_path = lambda: "prefix-list"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.PrefixList, [u'sequence_number'], name, value)


            class Prefixes(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                	**pattern:** ([^s].\*)\|(s[^e].\*)\|(se[^q].\*)(seq[^u].\*)\|(sequ[^e].\*)\|(seque[^n].\*)\|(sequen[^c].\*)\|(sequenc[^e].\*)\|(sequence[^\\\-].\*)\|(sequence\\\-[^n].\*)\|(sequence\\\-n[^u].\*)\|(sequence\\\-nu[^m].\*)\|(sequence\\\-num[^b].\*)\|(sequence\\\-numb[^e].\*)\|(sequence\\\-numbe[^r].\*)\|(sequence\\\-number..\*)
                
                .. attribute:: description
                
                	Prefix\-list specific description
                	**type**\: str
                
                	**length:** 1..80
                
                .. attribute:: permit
                
                	Specify packets to forward
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Permit>`
                
                .. attribute:: deny
                
                	Specify packets to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Deny>`
                
                .. attribute:: seq
                
                	sequence number of an entry
                	**type**\: list of  		 :py:class:`Seq <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Seq>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.PrefixList.Prefixes, self).__init__()

                    self.yang_name = "prefixes"
                    self.yang_parent_name = "prefix-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("permit", ("permit", Native.Ip.PrefixList.Prefixes.Permit)), ("deny", ("deny", Native.Ip.PrefixList.Prefixes.Deny)), ("seq", ("seq", Native.Ip.PrefixList.Prefixes.Seq))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.name = None
                    self.description = None

                    self.permit = Native.Ip.PrefixList.Prefixes.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"

                    self.deny = Native.Ip.PrefixList.Prefixes.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.seq = YList(self)
                    self._segment_path = lambda: "prefixes" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/prefix-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.PrefixList.Prefixes, [u'name', u'description'], name, value)


                class Permit(Entity):
                    """
                    Specify packets to forward
                    
                    .. attribute:: prefix_only_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixOnlyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Permit.PrefixOnlyList>`
                    
                    .. attribute:: prefix_ge_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixGeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Permit.PrefixGeList>`
                    
                    .. attribute:: prefix_le_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixLeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Permit.PrefixLeList>`
                    
                    .. attribute:: prefix_ge_le_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixGeLeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Permit.PrefixGeLeList>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.PrefixList.Prefixes.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "prefixes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix-only-list", ("prefix_only_list", Native.Ip.PrefixList.Prefixes.Permit.PrefixOnlyList)), ("prefix-ge-list", ("prefix_ge_list", Native.Ip.PrefixList.Prefixes.Permit.PrefixGeList)), ("prefix-le-list", ("prefix_le_list", Native.Ip.PrefixList.Prefixes.Permit.PrefixLeList)), ("prefix-ge-le-list", ("prefix_ge_le_list", Native.Ip.PrefixList.Prefixes.Permit.PrefixGeLeList))])
                        self._leafs = OrderedDict()

                        self.prefix_only_list = YList(self)
                        self.prefix_ge_list = YList(self)
                        self.prefix_le_list = YList(self)
                        self.prefix_ge_le_list = YList(self)
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.PrefixList.Prefixes.Permit, [], name, value)


                    class PrefixOnlyList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.PrefixList.Prefixes.Permit.PrefixOnlyList, self).__init__()

                            self.yang_name = "prefix-only-list"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ])
                            self.prefix = None
                            self._segment_path = lambda: "prefix-only-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.PrefixList.Prefixes.Permit.PrefixOnlyList, [u'prefix'], name, value)


                    class PrefixGeList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        .. attribute:: ge  (key)
                        
                        	Minimum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.PrefixList.Prefixes.Permit.PrefixGeList, self).__init__()

                            self.yang_name = "prefix-ge-list"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix','ge']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('ge', (YLeaf(YType.uint8, 'ge'), ['int'])),
                            ])
                            self.prefix = None
                            self.ge = None
                            self._segment_path = lambda: "prefix-ge-list" + "[prefix='" + str(self.prefix) + "']" + "[ge='" + str(self.ge) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.PrefixList.Prefixes.Permit.PrefixGeList, [u'prefix', u'ge'], name, value)


                    class PrefixLeList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        .. attribute:: le  (key)
                        
                        	Maximum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.PrefixList.Prefixes.Permit.PrefixLeList, self).__init__()

                            self.yang_name = "prefix-le-list"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix','le']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('le', (YLeaf(YType.uint8, 'le'), ['int'])),
                            ])
                            self.prefix = None
                            self.le = None
                            self._segment_path = lambda: "prefix-le-list" + "[prefix='" + str(self.prefix) + "']" + "[le='" + str(self.le) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.PrefixList.Prefixes.Permit.PrefixLeList, [u'prefix', u'le'], name, value)


                    class PrefixGeLeList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        .. attribute:: ge  (key)
                        
                        	Minimum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: le  (key)
                        
                        	Maximum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.PrefixList.Prefixes.Permit.PrefixGeLeList, self).__init__()

                            self.yang_name = "prefix-ge-le-list"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix','ge','le']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('ge', (YLeaf(YType.uint8, 'ge'), ['int'])),
                                ('le', (YLeaf(YType.uint8, 'le'), ['int'])),
                            ])
                            self.prefix = None
                            self.ge = None
                            self.le = None
                            self._segment_path = lambda: "prefix-ge-le-list" + "[prefix='" + str(self.prefix) + "']" + "[ge='" + str(self.ge) + "']" + "[le='" + str(self.le) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.PrefixList.Prefixes.Permit.PrefixGeLeList, [u'prefix', u'ge', u'le'], name, value)


                class Deny(Entity):
                    """
                    Specify packets to reject
                    
                    .. attribute:: prefix_only_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixOnlyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Deny.PrefixOnlyList>`
                    
                    .. attribute:: prefix_ge_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixGeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Deny.PrefixGeList>`
                    
                    .. attribute:: prefix_le_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixLeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Deny.PrefixLeList>`
                    
                    .. attribute:: prefix_ge_le_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixGeLeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Deny.PrefixGeLeList>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.PrefixList.Prefixes.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "prefixes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix-only-list", ("prefix_only_list", Native.Ip.PrefixList.Prefixes.Deny.PrefixOnlyList)), ("prefix-ge-list", ("prefix_ge_list", Native.Ip.PrefixList.Prefixes.Deny.PrefixGeList)), ("prefix-le-list", ("prefix_le_list", Native.Ip.PrefixList.Prefixes.Deny.PrefixLeList)), ("prefix-ge-le-list", ("prefix_ge_le_list", Native.Ip.PrefixList.Prefixes.Deny.PrefixGeLeList))])
                        self._leafs = OrderedDict()

                        self.prefix_only_list = YList(self)
                        self.prefix_ge_list = YList(self)
                        self.prefix_le_list = YList(self)
                        self.prefix_ge_le_list = YList(self)
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.PrefixList.Prefixes.Deny, [], name, value)


                    class PrefixOnlyList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.PrefixList.Prefixes.Deny.PrefixOnlyList, self).__init__()

                            self.yang_name = "prefix-only-list"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ])
                            self.prefix = None
                            self._segment_path = lambda: "prefix-only-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.PrefixList.Prefixes.Deny.PrefixOnlyList, [u'prefix'], name, value)


                    class PrefixGeList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        .. attribute:: ge  (key)
                        
                        	Minimum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.PrefixList.Prefixes.Deny.PrefixGeList, self).__init__()

                            self.yang_name = "prefix-ge-list"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix','ge']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('ge', (YLeaf(YType.uint8, 'ge'), ['int'])),
                            ])
                            self.prefix = None
                            self.ge = None
                            self._segment_path = lambda: "prefix-ge-list" + "[prefix='" + str(self.prefix) + "']" + "[ge='" + str(self.ge) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.PrefixList.Prefixes.Deny.PrefixGeList, [u'prefix', u'ge'], name, value)


                    class PrefixLeList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        .. attribute:: le  (key)
                        
                        	Maximum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.PrefixList.Prefixes.Deny.PrefixLeList, self).__init__()

                            self.yang_name = "prefix-le-list"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix','le']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('le', (YLeaf(YType.uint8, 'le'), ['int'])),
                            ])
                            self.prefix = None
                            self.le = None
                            self._segment_path = lambda: "prefix-le-list" + "[prefix='" + str(self.prefix) + "']" + "[le='" + str(self.le) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.PrefixList.Prefixes.Deny.PrefixLeList, [u'prefix', u'le'], name, value)


                    class PrefixGeLeList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        .. attribute:: ge  (key)
                        
                        	Minimum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: le  (key)
                        
                        	Maximum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.PrefixList.Prefixes.Deny.PrefixGeLeList, self).__init__()

                            self.yang_name = "prefix-ge-le-list"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix','ge','le']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('ge', (YLeaf(YType.uint8, 'ge'), ['int'])),
                                ('le', (YLeaf(YType.uint8, 'le'), ['int'])),
                            ])
                            self.prefix = None
                            self.ge = None
                            self.le = None
                            self._segment_path = lambda: "prefix-ge-le-list" + "[prefix='" + str(self.prefix) + "']" + "[ge='" + str(self.ge) + "']" + "[le='" + str(self.le) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.PrefixList.Prefixes.Deny.PrefixGeLeList, [u'prefix', u'ge', u'le'], name, value)


                class Seq(Entity):
                    """
                    sequence number of an entry
                    
                    .. attribute:: no  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967294
                    
                    .. attribute:: deny
                    
                    	Specify packets to reject
                    	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Seq.Deny>`
                    
                    .. attribute:: permit
                    
                    	Specify packets to forward
                    	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.PrefixList.Prefixes.Seq.Permit>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.PrefixList.Prefixes.Seq, self).__init__()

                        self.yang_name = "seq"
                        self.yang_parent_name = "prefixes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['no']
                        self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.PrefixList.Prefixes.Seq.Deny)), ("permit", ("permit", Native.Ip.PrefixList.Prefixes.Seq.Permit))])
                        self._leafs = OrderedDict([
                            ('no', (YLeaf(YType.uint32, 'no'), ['int'])),
                        ])
                        self.no = None

                        self.deny = Native.Ip.PrefixList.Prefixes.Seq.Deny()
                        self.deny.parent = self
                        self._children_name_map["deny"] = "deny"

                        self.permit = Native.Ip.PrefixList.Prefixes.Seq.Permit()
                        self.permit.parent = self
                        self._children_name_map["permit"] = "permit"
                        self._segment_path = lambda: "seq" + "[no='" + str(self.no) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.PrefixList.Prefixes.Seq, [u'no'], name, value)


                    class Deny(Entity):
                        """
                        Specify packets to reject
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        .. attribute:: ge
                        
                        	Minimum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: le
                        
                        	Maximum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.PrefixList.Prefixes.Seq.Deny, self).__init__()

                            self.yang_name = "deny"
                            self.yang_parent_name = "seq"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('ge', (YLeaf(YType.uint8, 'ge'), ['int'])),
                                ('le', (YLeaf(YType.uint8, 'le'), ['int'])),
                            ])
                            self.ip = None
                            self.ge = None
                            self.le = None
                            self._segment_path = lambda: "deny"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.PrefixList.Prefixes.Seq.Deny, [u'ip', u'ge', u'le'], name, value)


                    class Permit(Entity):
                        """
                        Specify packets to forward
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        .. attribute:: ge
                        
                        	Minimum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: le
                        
                        	Maximum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.PrefixList.Prefixes.Seq.Permit, self).__init__()

                            self.yang_name = "permit"
                            self.yang_parent_name = "seq"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('ge', (YLeaf(YType.uint8, 'ge'), ['int'])),
                                ('le', (YLeaf(YType.uint8, 'le'), ['int'])),
                            ])
                            self.ip = None
                            self.ge = None
                            self.le = None
                            self._segment_path = lambda: "permit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.PrefixList.Prefixes.Seq.Permit, [u'ip', u'ge', u'le'], name, value)


        class Route(Entity):
            """
            Establish static routes
            
            .. attribute:: ip_route_interface_forwarding_list
            
            	
            	**type**\: list of  		 :py:class:`IpRouteInterfaceForwardingList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.IpRouteInterfaceForwardingList>`
            
            .. attribute:: profile
            
            	Enable IP routing table profile
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: static
            
            	Allow static routes
            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.Static>`
            
            .. attribute:: vrf
            
            	Configure static route for a VPN Routing/Forwarding instance
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.Vrf>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Route, self).__init__()

                self.yang_name = "route"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ip-route-interface-forwarding-list", ("ip_route_interface_forwarding_list", Native.Ip.Route.IpRouteInterfaceForwardingList)), ("static", ("static", Native.Ip.Route.Static)), ("vrf", ("vrf", Native.Ip.Route.Vrf))])
                self._leafs = OrderedDict([
                    ('profile', (YLeaf(YType.empty, 'profile'), ['Empty'])),
                ])
                self.profile = None

                self.static = Native.Ip.Route.Static()
                self.static.parent = self
                self._children_name_map["static"] = "static"

                self.ip_route_interface_forwarding_list = YList(self)
                self.vrf = YList(self)
                self._segment_path = lambda: "route"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Route, [u'profile'], name, value)


            class IpRouteInterfaceForwardingList(Entity):
                """
                
                
                .. attribute:: prefix  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mask  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: dhcp
                
                	Default Gateway obtained from DHCP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: metric
                
                	
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: fwd_list
                
                	
                	**type**\: list of  		 :py:class:`FwdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.IpRouteInterfaceForwardingList.FwdList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Route.IpRouteInterfaceForwardingList, self).__init__()

                    self.yang_name = "ip-route-interface-forwarding-list"
                    self.yang_parent_name = "route"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['prefix','mask']
                    self._child_classes = OrderedDict([("fwd-list", ("fwd_list", Native.Ip.Route.IpRouteInterfaceForwardingList.FwdList))])
                    self._leafs = OrderedDict([
                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                        ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                        ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                    ])
                    self.prefix = None
                    self.mask = None
                    self.dhcp = None
                    self.metric = None

                    self.fwd_list = YList(self)
                    self._segment_path = lambda: "ip-route-interface-forwarding-list" + "[prefix='" + str(self.prefix) + "']" + "[mask='" + str(self.mask) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/route/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Route.IpRouteInterfaceForwardingList, [u'prefix', u'mask', u'dhcp', u'metric'], name, value)


                class FwdList(Entity):
                    """
                    
                    
                    .. attribute:: fwd  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\:  :py:class:`Fwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList.Fwd>`
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    .. attribute:: interface_next_hop
                    
                    	
                    	**type**\: list of  		 :py:class:`InterfaceNextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.IpRouteInterfaceForwardingList.FwdList.InterfaceNextHop>`
                    
                    .. attribute:: dhcp
                    
                    	Default Gateway obtained from DHCP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: metric
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: global_
                    
                    	Next hop address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: name
                    
                    	Specify name of the next hop
                    	**type**\: str
                    
                    .. attribute:: permanent
                    
                    	permanent route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multicast
                    
                    	multicast route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: tag
                    
                    	Set tag for this route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: track
                    
                    	Install route depending on tracked item
                    	**type**\: int
                    
                    	**range:** 1..1000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Route.IpRouteInterfaceForwardingList.FwdList, self).__init__()

                        self.yang_name = "fwd-list"
                        self.yang_parent_name = "ip-route-interface-forwarding-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['fwd']
                        self._child_classes = OrderedDict([("interface-next-hop", ("interface_next_hop", Native.Ip.Route.IpRouteInterfaceForwardingList.FwdList.InterfaceNextHop))])
                        self._leafs = OrderedDict([
                            ('fwd', (YLeaf(YType.str, 'fwd'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList.Fwd'),'str','str'])),
                            ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                            ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                            ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                            ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                        ])
                        self.fwd = None
                        self.dhcp = None
                        self.metric = None
                        self.global_ = None
                        self.name = None
                        self.permanent = None
                        self.multicast = None
                        self.tag = None
                        self.track = None

                        self.interface_next_hop = YList(self)
                        self._segment_path = lambda: "fwd-list" + "[fwd='" + str(self.fwd) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Route.IpRouteInterfaceForwardingList.FwdList, [u'fwd', u'dhcp', u'metric', u'global_', u'name', u'permanent', u'multicast', u'tag', u'track'], name, value)

                    class Fwd(Enum):
                        """
                        Fwd (Enum Class)

                        .. data:: Null0 = 0

                        """

                        Null0 = Enum.YLeaf(0, "Null0")



                    class InterfaceNextHop(Entity):
                        """
                        
                        
                        .. attribute:: ip_address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: dhcp
                        
                        	Default Gateway obtained from DHCP
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: global_
                        
                        	Next hop address is global
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: name
                        
                        	Specify name of the next hop
                        	**type**\: str
                        
                        .. attribute:: permanent
                        
                        	permanent route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	multicast route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tag
                        
                        	Set tag for this route
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: track
                        
                        	Install route depending on tracked item
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.Route.IpRouteInterfaceForwardingList.FwdList.InterfaceNextHop, self).__init__()

                            self.yang_name = "interface-next-hop"
                            self.yang_parent_name = "fwd-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                            ])
                            self.ip_address = None
                            self.dhcp = None
                            self.metric = None
                            self.global_ = None
                            self.name = None
                            self.permanent = None
                            self.multicast = None
                            self.tag = None
                            self.track = None
                            self._segment_path = lambda: "interface-next-hop" + "[ip-address='" + str(self.ip_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Route.IpRouteInterfaceForwardingList.FwdList.InterfaceNextHop, [u'ip_address', u'dhcp', u'metric', u'global_', u'name', u'permanent', u'multicast', u'tag', u'track'], name, value)


            class Static(Entity):
                """
                Allow static routes
                
                .. attribute:: adjust_time
                
                	Time period for adjusting static routes
                	**type**\: int
                
                	**range:** 1..60
                
                .. attribute:: bfd
                
                	BFD tracked
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.Static.Bfd>`
                
                .. attribute:: install_routes_recurse_via_nexthop
                
                	installing recursive route next hop
                	**type**\:  :py:class:`InstallRoutesRecurseViaNexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.Static.InstallRoutesRecurseViaNexthop>`
                
                .. attribute:: inter_vrf
                
                	Across VRF interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Route.Static, self).__init__()

                    self.yang_name = "static"
                    self.yang_parent_name = "route"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bfd", ("bfd", Native.Ip.Route.Static.Bfd)), ("install-routes-recurse-via-nexthop", ("install_routes_recurse_via_nexthop", Native.Ip.Route.Static.InstallRoutesRecurseViaNexthop))])
                    self._leafs = OrderedDict([
                        ('adjust_time', (YLeaf(YType.uint8, 'adjust-time'), ['int'])),
                        ('inter_vrf', (YLeaf(YType.empty, 'inter-vrf'), ['Empty'])),
                    ])
                    self.adjust_time = None
                    self.inter_vrf = None

                    self.bfd = Native.Ip.Route.Static.Bfd()
                    self.bfd.parent = self
                    self._children_name_map["bfd"] = "bfd"

                    self.install_routes_recurse_via_nexthop = Native.Ip.Route.Static.InstallRoutesRecurseViaNexthop()
                    self.install_routes_recurse_via_nexthop.parent = self
                    self._children_name_map["install_routes_recurse_via_nexthop"] = "install-routes-recurse-via-nexthop"
                    self._segment_path = lambda: "static"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/route/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Route.Static, [u'adjust_time', u'inter_vrf'], name, value)


                class Bfd(Entity):
                    """
                    BFD tracked
                    
                    .. attribute:: interface
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: gateway_ip
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Route.Static.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "static"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str'])),
                        ])
                        self.interface = None
                        self.gateway_ip = None
                        self._segment_path = lambda: "bfd"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/route/static/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Route.Static.Bfd, [u'interface', u'gateway_ip'], name, value)


                class InstallRoutesRecurseViaNexthop(Entity):
                    """
                    installing recursive route next hop
                    
                    .. attribute:: vrf
                    
                    	Configure static route for a VPN Routing/Forwarding instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Route.Static.InstallRoutesRecurseViaNexthop, self).__init__()

                        self.yang_name = "install-routes-recurse-via-nexthop"
                        self.yang_parent_name = "static"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.vrf = None
                        self._segment_path = lambda: "install-routes-recurse-via-nexthop"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/route/static/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Route.Static.InstallRoutesRecurseViaNexthop, [u'vrf'], name, value)


            class Vrf(Entity):
                """
                Configure static route for a VPN Routing/Forwarding instance
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: ip_route_interface_forwarding_list
                
                	
                	**type**\: list of  		 :py:class:`IpRouteInterfaceForwardingList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Route.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "route"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("ip-route-interface-forwarding-list", ("ip_route_interface_forwarding_list", Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.ip_route_interface_forwarding_list = YList(self)
                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/route/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Route.Vrf, [u'name'], name, value)


                class IpRouteInterfaceForwardingList(Entity):
                    """
                    
                    
                    .. attribute:: prefix  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mask  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: dhcp
                    
                    	Default Gateway obtained from DHCP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: metric
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: fwd_list
                    
                    	
                    	**type**\: list of  		 :py:class:`FwdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList, self).__init__()

                        self.yang_name = "ip-route-interface-forwarding-list"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['prefix','mask']
                        self._child_classes = OrderedDict([("fwd-list", ("fwd_list", Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                            ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                        ])
                        self.prefix = None
                        self.mask = None
                        self.dhcp = None
                        self.metric = None

                        self.fwd_list = YList(self)
                        self._segment_path = lambda: "ip-route-interface-forwarding-list" + "[prefix='" + str(self.prefix) + "']" + "[mask='" + str(self.mask) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList, [u'prefix', u'mask', u'dhcp', u'metric'], name, value)


                    class FwdList(Entity):
                        """
                        
                        
                        .. attribute:: fwd  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Fwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList.Fwd>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        .. attribute:: interface_next_hop
                        
                        	
                        	**type**\: list of  		 :py:class:`InterfaceNextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList.InterfaceNextHop>`
                        
                        .. attribute:: dhcp
                        
                        	Default Gateway obtained from DHCP
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: global_
                        
                        	Next hop address is global
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: name
                        
                        	Specify name of the next hop
                        	**type**\: str
                        
                        .. attribute:: permanent
                        
                        	permanent route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	multicast route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tag
                        
                        	Set tag for this route
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: track
                        
                        	Install route depending on tracked item
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList, self).__init__()

                            self.yang_name = "fwd-list"
                            self.yang_parent_name = "ip-route-interface-forwarding-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['fwd']
                            self._child_classes = OrderedDict([("interface-next-hop", ("interface_next_hop", Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList.InterfaceNextHop))])
                            self._leafs = OrderedDict([
                                ('fwd', (YLeaf(YType.str, 'fwd'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList.Fwd'),'str','str'])),
                                ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                            ])
                            self.fwd = None
                            self.dhcp = None
                            self.metric = None
                            self.global_ = None
                            self.name = None
                            self.permanent = None
                            self.multicast = None
                            self.tag = None
                            self.track = None

                            self.interface_next_hop = YList(self)
                            self._segment_path = lambda: "fwd-list" + "[fwd='" + str(self.fwd) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList, [u'fwd', u'dhcp', u'metric', u'global_', u'name', u'permanent', u'multicast', u'tag', u'track'], name, value)

                        class Fwd(Enum):
                            """
                            Fwd (Enum Class)

                            .. data:: Null0 = 0

                            """

                            Null0 = Enum.YLeaf(0, "Null0")



                        class InterfaceNextHop(Entity):
                            """
                            
                            
                            .. attribute:: ip_address  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: dhcp
                            
                            	Default Gateway obtained from DHCP
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: metric
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: global_
                            
                            	Next hop address is global
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: name
                            
                            	Specify name of the next hop
                            	**type**\: str
                            
                            .. attribute:: permanent
                            
                            	permanent route
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: multicast
                            
                            	multicast route
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: tag
                            
                            	Set tag for this route
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: track
                            
                            	Install route depending on tracked item
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList.InterfaceNextHop, self).__init__()

                                self.yang_name = "interface-next-hop"
                                self.yang_parent_name = "fwd-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                    ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                    ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                    ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.ip_address = None
                                self.dhcp = None
                                self.metric = None
                                self.global_ = None
                                self.name = None
                                self.permanent = None
                                self.multicast = None
                                self.tag = None
                                self.track = None
                                self._segment_path = lambda: "interface-next-hop" + "[ip-address='" + str(self.ip_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Route.Vrf.IpRouteInterfaceForwardingList.FwdList.InterfaceNextHop, [u'ip_address', u'dhcp', u'metric', u'global_', u'name', u'permanent', u'multicast', u'tag', u'track'], name, value)


        class Routing(Entity):
            """
            Enable IP routing
            
            .. attribute:: protocol
            
            	IP routing protocol
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Routing.Protocol>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Routing, self).__init__()

                self.yang_name = "routing"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("protocol", ("protocol", Native.Ip.Routing.Protocol))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.protocol = Native.Ip.Routing.Protocol()
                self.protocol.parent = self
                self._children_name_map["protocol"] = "protocol"
                self._segment_path = lambda: "routing"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Routing, [], name, value)


            class Protocol(Entity):
                """
                IP routing protocol
                
                .. attribute:: purge
                
                	routes purge
                	**type**\:  :py:class:`Purge <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Routing.Protocol.Purge>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Routing.Protocol, self).__init__()

                    self.yang_name = "protocol"
                    self.yang_parent_name = "routing"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("purge", ("purge", Native.Ip.Routing.Protocol.Purge))])
                    self._leafs = OrderedDict()

                    self.purge = Native.Ip.Routing.Protocol.Purge()
                    self.purge.parent = self
                    self._children_name_map["purge"] = "purge"
                    self._segment_path = lambda: "protocol"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/routing/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Routing.Protocol, [], name, value)


                class Purge(Entity):
                    """
                    routes purge
                    
                    .. attribute:: interface
                    
                    	Perform IP routing protocol routes purge on link failures
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Routing.Protocol.Purge, self).__init__()

                        self.yang_name = "purge"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface', (YLeaf(YType.boolean, 'interface'), ['bool'])),
                        ])
                        self.interface = None
                        self._segment_path = lambda: "purge"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/routing/protocol/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Routing.Protocol.Purge, [u'interface'], name, value)


        class ExplicitPath(Entity):
            """
            Configure explicit\-path
            
            .. attribute:: identifier
            
            	Specify explicit path by number\: <1..65535>
            	**type**\: list of  		 :py:class:`Identifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExplicitPath.Identifier>`
            
            .. attribute:: name
            
            	Specify explicit path by name
            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExplicitPath.Name>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.ExplicitPath, self).__init__()

                self.yang_name = "explicit-path"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("identifier", ("identifier", Native.Ip.ExplicitPath.Identifier)), ("name", ("name", Native.Ip.ExplicitPath.Name))])
                self._leafs = OrderedDict()

                self.identifier = YList(self)
                self.name = YList(self)
                self._segment_path = lambda: "explicit-path"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.ExplicitPath, [], name, value)


            class Identifier(Entity):
                """
                Specify explicit path by number\: <1..65535>
                
                .. attribute:: pnum  (key)
                
                	
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: mode
                
                	
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExplicitPath.Identifier.Mode>`
                
                .. attribute:: index
                
                	Specify the next entry index to add, edit (or delete)\: <1..65535>
                	**type**\: list of  		 :py:class:`Index <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExplicitPath.Identifier.Index>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.ExplicitPath.Identifier, self).__init__()

                    self.yang_name = "identifier"
                    self.yang_parent_name = "explicit-path"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['pnum']
                    self._child_classes = OrderedDict([("index", ("index", Native.Ip.ExplicitPath.Identifier.Index))])
                    self._leafs = OrderedDict([
                        ('pnum', (YLeaf(YType.uint16, 'pnum'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.ExplicitPath.Identifier.Mode')])),
                    ])
                    self.pnum = None
                    self.mode = None

                    self.index = YList(self)
                    self._segment_path = lambda: "identifier" + "[pnum='" + str(self.pnum) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/explicit-path/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.ExplicitPath.Identifier, [u'pnum', u'mode'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    .. data:: enable = 0

                    .. data:: disable = 1

                    """

                    enable = Enum.YLeaf(0, "enable")

                    disable = Enum.YLeaf(1, "disable")



                class Index(Entity):
                    """
                    Specify the next entry index to add, edit (or delete)\: <1..65535>
                    
                    .. attribute:: idx  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: next_address
                    
                    	Specify the next address in the path
                    	**type**\:  :py:class:`NextAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExplicitPath.Identifier.Index.NextAddress>`
                    
                    .. attribute:: next_label
                    
                    	Specify the next MPLS label in the path\: <0..1048575>
                    	**type**\: int
                    
                    	**range:** 0..1048575
                    
                    .. attribute:: exclude_address
                    
                    	Exclude an address from subsequent partial path segments
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: exclude_srlg
                    
                    	Specify an address to get SRLGs from for exclusion
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.ExplicitPath.Identifier.Index, self).__init__()

                        self.yang_name = "index"
                        self.yang_parent_name = "identifier"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['idx']
                        self._child_classes = OrderedDict([("next-address", ("next_address", Native.Ip.ExplicitPath.Identifier.Index.NextAddress))])
                        self._leafs = OrderedDict([
                            ('idx', (YLeaf(YType.uint32, 'idx'), ['int'])),
                            ('next_label', (YLeaf(YType.uint32, 'next-label'), ['int'])),
                            ('exclude_address', (YLeaf(YType.str, 'exclude-address'), ['str'])),
                            ('exclude_srlg', (YLeaf(YType.str, 'exclude-srlg'), ['str'])),
                        ])
                        self.idx = None
                        self.next_label = None
                        self.exclude_address = None
                        self.exclude_srlg = None

                        self.next_address = Native.Ip.ExplicitPath.Identifier.Index.NextAddress()
                        self.next_address.parent = self
                        self._children_name_map["next_address"] = "next-address"
                        self._segment_path = lambda: "index" + "[idx='" + str(self.idx) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.ExplicitPath.Identifier.Index, [u'idx', u'next_label', u'exclude_address', u'exclude_srlg'], name, value)


                    class NextAddress(Entity):
                        """
                        Specify the next address in the path
                        
                        .. attribute:: loose
                        
                        	Target IPv4 address is loose
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv4
                        
                        	Target IPv4 address (strict)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.ExplicitPath.Identifier.Index.NextAddress, self).__init__()

                            self.yang_name = "next-address"
                            self.yang_parent_name = "index"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('loose', (YLeaf(YType.empty, 'loose'), ['Empty'])),
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                            ])
                            self.loose = None
                            self.ipv4 = None
                            self._segment_path = lambda: "next-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExplicitPath.Identifier.Index.NextAddress, [u'loose', u'ipv4'], name, value)


            class Name(Entity):
                """
                Specify explicit path by name
                
                .. attribute:: pname  (key)
                
                	
                	**type**\: str
                
                .. attribute:: mode
                
                	
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExplicitPath.Name.Mode>`
                
                .. attribute:: index
                
                	Specify the next entry index to add, edit (or delete)\: <1..65535>
                	**type**\: list of  		 :py:class:`Index <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExplicitPath.Name.Index>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.ExplicitPath.Name, self).__init__()

                    self.yang_name = "name"
                    self.yang_parent_name = "explicit-path"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['pname']
                    self._child_classes = OrderedDict([("index", ("index", Native.Ip.ExplicitPath.Name.Index))])
                    self._leafs = OrderedDict([
                        ('pname', (YLeaf(YType.str, 'pname'), ['str'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.ExplicitPath.Name.Mode')])),
                    ])
                    self.pname = None
                    self.mode = None

                    self.index = YList(self)
                    self._segment_path = lambda: "name" + "[pname='" + str(self.pname) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/explicit-path/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.ExplicitPath.Name, [u'pname', u'mode'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    .. data:: enable = 0

                    .. data:: disable = 1

                    """

                    enable = Enum.YLeaf(0, "enable")

                    disable = Enum.YLeaf(1, "disable")



                class Index(Entity):
                    """
                    Specify the next entry index to add, edit (or delete)\: <1..65535>
                    
                    .. attribute:: idx  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: next_address
                    
                    	Specify the next address in the path
                    	**type**\:  :py:class:`NextAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExplicitPath.Name.Index.NextAddress>`
                    
                    .. attribute:: next_label
                    
                    	Specify the next MPLS label in the path\: <0..1048575>
                    	**type**\: int
                    
                    	**range:** 0..1048575
                    
                    .. attribute:: exclude_address
                    
                    	Exclude an address from subsequent partial path segments
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: exclude_srlg
                    
                    	Specify an address to get SRLGs from for exclusion
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.ExplicitPath.Name.Index, self).__init__()

                        self.yang_name = "index"
                        self.yang_parent_name = "name"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['idx']
                        self._child_classes = OrderedDict([("next-address", ("next_address", Native.Ip.ExplicitPath.Name.Index.NextAddress))])
                        self._leafs = OrderedDict([
                            ('idx', (YLeaf(YType.uint32, 'idx'), ['int'])),
                            ('next_label', (YLeaf(YType.uint32, 'next-label'), ['int'])),
                            ('exclude_address', (YLeaf(YType.str, 'exclude-address'), ['str'])),
                            ('exclude_srlg', (YLeaf(YType.str, 'exclude-srlg'), ['str'])),
                        ])
                        self.idx = None
                        self.next_label = None
                        self.exclude_address = None
                        self.exclude_srlg = None

                        self.next_address = Native.Ip.ExplicitPath.Name.Index.NextAddress()
                        self.next_address.parent = self
                        self._children_name_map["next_address"] = "next-address"
                        self._segment_path = lambda: "index" + "[idx='" + str(self.idx) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.ExplicitPath.Name.Index, [u'idx', u'next_label', u'exclude_address', u'exclude_srlg'], name, value)


                    class NextAddress(Entity):
                        """
                        Specify the next address in the path
                        
                        .. attribute:: loose
                        
                        	Target IPv4 address is loose
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv4
                        
                        	Target IPv4 address (strict)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.ExplicitPath.Name.Index.NextAddress, self).__init__()

                            self.yang_name = "next-address"
                            self.yang_parent_name = "index"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('loose', (YLeaf(YType.empty, 'loose'), ['Empty'])),
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                            ])
                            self.loose = None
                            self.ipv4 = None
                            self._segment_path = lambda: "next-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExplicitPath.Name.Index.NextAddress, [u'loose', u'ipv4'], name, value)


        class Scp(Entity):
            """
            Scp commands
            
            .. attribute:: server
            
            	Configure SCP server\-side functionality
            	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Scp.Server>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Scp, self).__init__()

                self.yang_name = "scp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("server", ("server", Native.Ip.Scp.Server))])
                self._leafs = OrderedDict()

                self.server = Native.Ip.Scp.Server()
                self.server.parent = self
                self._children_name_map["server"] = "server"
                self._segment_path = lambda: "scp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Scp, [], name, value)


            class Server(Entity):
                """
                Configure SCP server\-side functionality
                
                .. attribute:: enable
                
                	Enable server side of SCP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Scp.Server, self).__init__()

                    self.yang_name = "server"
                    self.yang_parent_name = "scp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "server"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/scp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Scp.Server, [u'enable'], name, value)


        class Spd(Entity):
            """
            spd
            
            .. attribute:: mode
            
            	
            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Spd.Mode>`
            
            .. attribute:: queue
            
            	queue
            	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Spd.Queue>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Spd, self).__init__()

                self.yang_name = "spd"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("queue", ("queue", Native.Ip.Spd.Queue))])
                self._leafs = OrderedDict([
                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Spd.Mode')])),
                ])
                self.mode = None

                self.queue = Native.Ip.Spd.Queue()
                self.queue.parent = self
                self._children_name_map["queue"] = "queue"
                self._segment_path = lambda: "spd"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Spd, [u'mode'], name, value)

            class Mode(Enum):
                """
                Mode (Enum Class)

                .. data:: aggressive = 0

                """

                aggressive = Enum.YLeaf(0, "aggressive")



            class Queue(Entity):
                """
                queue
                
                .. attribute:: max_threshold
                
                	Max threshold
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: min_threshold
                
                	Min threshold
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Spd.Queue, self).__init__()

                    self.yang_name = "queue"
                    self.yang_parent_name = "spd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('max_threshold', (YLeaf(YType.uint16, 'max-threshold'), ['int'])),
                        ('min_threshold', (YLeaf(YType.uint16, 'min-threshold'), ['int'])),
                    ])
                    self.max_threshold = None
                    self.min_threshold = None
                    self._segment_path = lambda: "queue"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/spd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Spd.Queue, [u'max_threshold', u'min_threshold'], name, value)


        class Bootp(Entity):
            """
            Config BOOTP services
            
            .. attribute:: server
            
            	Enable BOOTP server
            	**type**\: bool
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Bootp, self).__init__()

                self.yang_name = "bootp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('server', (YLeaf(YType.boolean, 'server'), ['bool'])),
                ])
                self.server = None
                self._segment_path = lambda: "bootp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Bootp, [u'server'], name, value)


        class Ssh(Entity):
            """
            Configure ssh options
            
            .. attribute:: authentication_retries
            
            	Specify number of authentication retries
            	**type**\: int
            
            	**range:** 0..5
            
            .. attribute:: client
            
            	Configuration for client
            	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.Client>`
            
            .. attribute:: dscp
            
            	IP DSCP value for SSH traffic
            	**type**\: int
            
            	**range:** 0..63
            
            .. attribute:: logging
            
            	Configure logging for SSH
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.Logging>`
            
            .. attribute:: pubkey_chain
            
            	Configure public key\-chain parameters
            	**type**\:  :py:class:`PubkeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.PubkeyChain>`
            
            .. attribute:: precedence
            
            	IP Precedence value for SSH traffic
            	**type**\: int
            
            	**range:** 0..7
            
            .. attribute:: rsa
            
            	Configure RSA keypair name for SSH
            	**type**\:  :py:class:`Rsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.Rsa>`
            
            .. attribute:: server
            
            	Configuration for server
            	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.Server>`
            
            .. attribute:: source_interface
            
            	Specify interface for source address in SSH connections
            	**type**\: str
            
            .. attribute:: time_out
            
            	Specify SSH time\-out interval
            	**type**\: int
            
            	**range:** 1..120
            
            .. attribute:: version
            
            	Specify protocol version supported
            	**type**\: int
            
            	**range:** 1..2
            
            .. attribute:: maxstartups
            
            	Maximum number of server sessions
            	**type**\: int
            
            	**range:** 2..128
            
            .. attribute:: port
            
            	Starting (or only) Port number to listen on
            	**type**\: list of  		 :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.Port>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Ssh, self).__init__()

                self.yang_name = "ssh"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("client", ("client", Native.Ip.Ssh.Client)), ("logging", ("logging", Native.Ip.Ssh.Logging)), ("pubkey-chain", ("pubkey_chain", Native.Ip.Ssh.PubkeyChain)), ("rsa", ("rsa", Native.Ip.Ssh.Rsa)), ("server", ("server", Native.Ip.Ssh.Server)), ("port", ("port", Native.Ip.Ssh.Port))])
                self._leafs = OrderedDict([
                    ('authentication_retries', (YLeaf(YType.uint8, 'authentication-retries'), ['int'])),
                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                    ('precedence', (YLeaf(YType.uint8, 'precedence'), ['int'])),
                    ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                    ('time_out', (YLeaf(YType.uint8, 'time-out'), ['int'])),
                    ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                    ('maxstartups', (YLeaf(YType.uint8, 'maxstartups'), ['int'])),
                ])
                self.authentication_retries = None
                self.dscp = None
                self.precedence = None
                self.source_interface = None
                self.time_out = None
                self.version = None
                self.maxstartups = None

                self.client = Native.Ip.Ssh.Client()
                self.client.parent = self
                self._children_name_map["client"] = "client"

                self.logging = Native.Ip.Ssh.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.pubkey_chain = Native.Ip.Ssh.PubkeyChain()
                self.pubkey_chain.parent = self
                self._children_name_map["pubkey_chain"] = "pubkey-chain"

                self.rsa = Native.Ip.Ssh.Rsa()
                self.rsa.parent = self
                self._children_name_map["rsa"] = "rsa"

                self.server = Native.Ip.Ssh.Server()
                self.server.parent = self
                self._children_name_map["server"] = "server"

                self.port = YList(self)
                self._segment_path = lambda: "ssh"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Ssh, [u'authentication_retries', u'dscp', u'precedence', u'source_interface', u'time_out', u'version', u'maxstartups'], name, value)


            class Client(Entity):
                """
                Configuration for client
                
                .. attribute:: algorithm
                
                	Configure different algorithms used in SSH
                	**type**\:  :py:class:`Algorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.Client.Algorithm>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Ssh.Client, self).__init__()

                    self.yang_name = "client"
                    self.yang_parent_name = "ssh"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("algorithm", ("algorithm", Native.Ip.Ssh.Client.Algorithm))])
                    self._leafs = OrderedDict()

                    self.algorithm = Native.Ip.Ssh.Client.Algorithm()
                    self.algorithm.parent = self
                    self._children_name_map["algorithm"] = "algorithm"
                    self._segment_path = lambda: "client"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Ssh.Client, [], name, value)


                class Algorithm(Entity):
                    """
                    Configure different algorithms used in SSH
                    
                    .. attribute:: encryption
                    
                    	Encryption algorithms advertised to other party
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.Client.Algorithm.Encryption>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Ssh.Client.Algorithm, self).__init__()

                        self.yang_name = "algorithm"
                        self.yang_parent_name = "client"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("encryption", ("encryption", Native.Ip.Ssh.Client.Algorithm.Encryption))])
                        self._leafs = OrderedDict()

                        self.encryption = Native.Ip.Ssh.Client.Algorithm.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"
                        self._segment_path = lambda: "algorithm"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/client/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Ssh.Client.Algorithm, [], name, value)


                    class Encryption(Entity):
                        """
                        Encryption algorithms advertised to other party
                        
                        .. attribute:: aes128_ctr
                        
                        	AES with 128\-bit key in CTR mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: aes192_ctr
                        
                        	AEC with 192\-bit key in CTR mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: aes256_ctr
                        
                        	AEC with 256\-bit key in CTR mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.Ssh.Client.Algorithm.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('aes128_ctr', (YLeaf(YType.empty, 'aes128-ctr'), ['Empty'])),
                                ('aes192_ctr', (YLeaf(YType.empty, 'aes192-ctr'), ['Empty'])),
                                ('aes256_ctr', (YLeaf(YType.empty, 'aes256-ctr'), ['Empty'])),
                            ])
                            self.aes128_ctr = None
                            self.aes192_ctr = None
                            self.aes256_ctr = None
                            self._segment_path = lambda: "encryption"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/client/algorithm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Ssh.Client.Algorithm.Encryption, [u'aes128_ctr', u'aes192_ctr', u'aes256_ctr'], name, value)


            class Logging(Entity):
                """
                Configure logging for SSH
                
                .. attribute:: events
                
                	Log SSH events
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Ssh.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "ssh"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('events', (YLeaf(YType.empty, 'events'), ['Empty'])),
                    ])
                    self.events = None
                    self._segment_path = lambda: "logging"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Ssh.Logging, [u'events'], name, value)


            class PubkeyChain(Entity):
                """
                Configure public key\-chain parameters
                
                .. attribute:: username
                
                	
                	**type**\: list of  		 :py:class:`Username <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.PubkeyChain.Username>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Ssh.PubkeyChain, self).__init__()

                    self.yang_name = "pubkey-chain"
                    self.yang_parent_name = "ssh"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("username", ("username", Native.Ip.Ssh.PubkeyChain.Username))])
                    self._leafs = OrderedDict()

                    self.username = YList(self)
                    self._segment_path = lambda: "pubkey-chain"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Ssh.PubkeyChain, [], name, value)


                class Username(Entity):
                    """
                    
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: key_hash
                    
                    	
                    	**type**\: list of  		 :py:class:`KeyHash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.PubkeyChain.Username.KeyHash>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Ssh.PubkeyChain.Username, self).__init__()

                        self.yang_name = "username"
                        self.yang_parent_name = "pubkey-chain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("key-hash", ("key_hash", Native.Ip.Ssh.PubkeyChain.Username.KeyHash))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.key_hash = YList(self)
                        self._segment_path = lambda: "username" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/pubkey-chain/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Ssh.PubkeyChain.Username, [u'name'], name, value)


                    class KeyHash(Entity):
                        """
                        
                        
                        .. attribute:: key_type  (key)
                        
                        	
                        	**type**\:  :py:class:`KeyType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.PubkeyChain.Username.KeyHash.KeyType>`
                        
                        .. attribute:: key_hash_value  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.Ssh.PubkeyChain.Username.KeyHash, self).__init__()

                            self.yang_name = "key-hash"
                            self.yang_parent_name = "username"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['key_type','key_hash_value']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_type', (YLeaf(YType.enumeration, 'key-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Ssh.PubkeyChain.Username.KeyHash.KeyType')])),
                                ('key_hash_value', (YLeaf(YType.str, 'key-hash-value'), ['str'])),
                            ])
                            self.key_type = None
                            self.key_hash_value = None
                            self._segment_path = lambda: "key-hash" + "[key-type='" + str(self.key_type) + "']" + "[key-hash-value='" + str(self.key_hash_value) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Ssh.PubkeyChain.Username.KeyHash, [u'key_type', u'key_hash_value'], name, value)

                        class KeyType(Enum):
                            """
                            KeyType (Enum Class)

                            .. data:: ssh_rsa = 0

                            """

                            ssh_rsa = Enum.YLeaf(0, "ssh-rsa")



            class Rsa(Entity):
                """
                Configure RSA keypair name for SSH
                
                .. attribute:: keypair_name
                
                	keypair\-name
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Ssh.Rsa, self).__init__()

                    self.yang_name = "rsa"
                    self.yang_parent_name = "ssh"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('keypair_name', (YLeaf(YType.str, 'keypair-name'), ['str'])),
                    ])
                    self.keypair_name = None
                    self._segment_path = lambda: "rsa"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Ssh.Rsa, [u'keypair_name'], name, value)


            class Server(Entity):
                """
                Configuration for server
                
                .. attribute:: algorithm
                
                	Configure different algorithms used in SSH
                	**type**\:  :py:class:`Algorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.Server.Algorithm>`
                
                .. attribute:: peruser
                
                	Per User configs
                	**type**\:  :py:class:`Peruser <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.Server.Peruser>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Ssh.Server, self).__init__()

                    self.yang_name = "server"
                    self.yang_parent_name = "ssh"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("algorithm", ("algorithm", Native.Ip.Ssh.Server.Algorithm)), ("peruser", ("peruser", Native.Ip.Ssh.Server.Peruser))])
                    self._leafs = OrderedDict()

                    self.algorithm = Native.Ip.Ssh.Server.Algorithm()
                    self.algorithm.parent = self
                    self._children_name_map["algorithm"] = "algorithm"

                    self.peruser = Native.Ip.Ssh.Server.Peruser()
                    self.peruser.parent = self
                    self._children_name_map["peruser"] = "peruser"
                    self._segment_path = lambda: "server"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Ssh.Server, [], name, value)


                class Algorithm(Entity):
                    """
                    Configure different algorithms used in SSH
                    
                    .. attribute:: encryption
                    
                    	Encryption algorithms advertised to other party
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.Server.Algorithm.Encryption>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Ssh.Server.Algorithm, self).__init__()

                        self.yang_name = "algorithm"
                        self.yang_parent_name = "server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("encryption", ("encryption", Native.Ip.Ssh.Server.Algorithm.Encryption))])
                        self._leafs = OrderedDict()

                        self.encryption = Native.Ip.Ssh.Server.Algorithm.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"
                        self._segment_path = lambda: "algorithm"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Ssh.Server.Algorithm, [], name, value)


                    class Encryption(Entity):
                        """
                        Encryption algorithms advertised to other party
                        
                        .. attribute:: aes128_ctr
                        
                        	AES with 128\-bit key in CTR mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: aes192_ctr
                        
                        	AEC with 192\-bit key in CTR mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: aes256_ctr
                        
                        	AEC with 256\-bit key in CTR mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.Ssh.Server.Algorithm.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('aes128_ctr', (YLeaf(YType.empty, 'aes128-ctr'), ['Empty'])),
                                ('aes192_ctr', (YLeaf(YType.empty, 'aes192-ctr'), ['Empty'])),
                                ('aes256_ctr', (YLeaf(YType.empty, 'aes256-ctr'), ['Empty'])),
                            ])
                            self.aes128_ctr = None
                            self.aes192_ctr = None
                            self.aes256_ctr = None
                            self._segment_path = lambda: "encryption"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/server/algorithm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Ssh.Server.Algorithm.Encryption, [u'aes128_ctr', u'aes192_ctr', u'aes256_ctr'], name, value)


                class Peruser(Entity):
                    """
                    Per User configs
                    
                    .. attribute:: session
                    
                    	Per User Session
                    	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Ssh.Server.Peruser.Session>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Ssh.Server.Peruser, self).__init__()

                        self.yang_name = "peruser"
                        self.yang_parent_name = "server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("session", ("session", Native.Ip.Ssh.Server.Peruser.Session))])
                        self._leafs = OrderedDict()

                        self.session = Native.Ip.Ssh.Server.Peruser.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                        self._segment_path = lambda: "peruser"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Ssh.Server.Peruser, [], name, value)


                    class Session(Entity):
                        """
                        Per User Session
                        
                        .. attribute:: limit
                        
                        	Per User Session Limit
                        	**type**\: int
                        
                        	**range:** 1..16
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ip.Ssh.Server.Peruser.Session, self).__init__()

                            self.yang_name = "session"
                            self.yang_parent_name = "peruser"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                            ])
                            self.limit = None
                            self._segment_path = lambda: "session"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/server/peruser/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Ssh.Server.Peruser.Session, [u'limit'], name, value)


            class Port(Entity):
                """
                Starting (or only) Port number to listen on
                
                .. attribute:: port_no  (key)
                
                	Starting Port number
                	**type**\: int
                
                	**range:** 2000..10000
                
                .. attribute:: low_rotary
                
                	Starting (or only) rotary group number
                	**type**\: int
                
                	**range:** 1..127
                
                .. attribute:: high_rotary
                
                	Starting (or only) rotary group number
                	**type**\: int
                
                	**range:** 1..127
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Ssh.Port, self).__init__()

                    self.yang_name = "port"
                    self.yang_parent_name = "ssh"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['port_no']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_no', (YLeaf(YType.uint16, 'port-no'), ['int'])),
                        ('low_rotary', (YLeaf(YType.uint8, 'low-rotary'), ['int'])),
                        ('high_rotary', (YLeaf(YType.uint8, 'high-rotary'), ['int'])),
                    ])
                    self.port_no = None
                    self.low_rotary = None
                    self.high_rotary = None
                    self._segment_path = lambda: "port" + "[port-no='" + str(self.port_no) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/ssh/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Ssh.Port, [u'port_no', u'low_rotary', u'high_rotary'], name, value)


        class Tcp(Entity):
            """
            Global TCP parameters
            
            .. attribute:: path_mtu_discovery
            
            	Enable path\-MTU discovery on new TCP connections
            	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tcp.PathMtuDiscovery>`
            
            	**presence node**\: True
            
            .. attribute:: selective_ack
            
            	Enable TCP selective\-ACK
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: synwait_time
            
            	Set time to wait on new TCP connections
            	**type**\: int
            
            	**range:** 5..300
            
            .. attribute:: timestamp
            
            	Enable TCP timestamp option
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: window_size
            
            	TCP window size
            	**type**\: int
            
            	**range:** 0..1073741823
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Tcp, self).__init__()

                self.yang_name = "tcp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Ip.Tcp.PathMtuDiscovery))])
                self._leafs = OrderedDict([
                    ('selective_ack', (YLeaf(YType.empty, 'selective-ack'), ['Empty'])),
                    ('synwait_time', (YLeaf(YType.uint16, 'synwait-time'), ['int'])),
                    ('timestamp', (YLeaf(YType.empty, 'timestamp'), ['Empty'])),
                    ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                ])
                self.selective_ack = None
                self.synwait_time = None
                self.timestamp = None
                self.window_size = None

                self.path_mtu_discovery = None
                self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                self._segment_path = lambda: "tcp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Tcp, [u'selective_ack', u'synwait_time', u'timestamp', u'window_size'], name, value)


            class PathMtuDiscovery(Entity):
                """
                Enable path\-MTU discovery on new TCP connections
                
                .. attribute:: age_timer
                
                	Set PMTU aging timer
                	**type**\: union of the below types:
                
                		**type**\:  :py:class:`AgeTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tcp.PathMtuDiscovery.AgeTimer>`
                
                		**type**\: int
                
                			**range:** 10..30
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Tcp.PathMtuDiscovery, self).__init__()

                    self.yang_name = "path-mtu-discovery"
                    self.yang_parent_name = "tcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('age_timer', (YLeaf(YType.str, 'age-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Tcp.PathMtuDiscovery.AgeTimer'),'int'])),
                    ])
                    self.age_timer = None
                    self._segment_path = lambda: "path-mtu-discovery"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/tcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Tcp.PathMtuDiscovery, [u'age_timer'], name, value)

                class AgeTimer(Enum):
                    """
                    AgeTimer (Enum Class)

                    Set PMTU aging timer

                    .. data:: infinite = 0

                    """

                    infinite = Enum.YLeaf(0, "infinite")



        class Tftp(Entity):
            """
            tftp configuration commands
            
            .. attribute:: boot_interface
            
            	Force interface to use for TFTP booting
            	**type**\:  :py:class:`BootInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tftp.BootInterface>`
            
            .. attribute:: source_interface
            
            	Specify interface for source address in TFTP connections
            	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tftp.SourceInterface>`
            
            .. attribute:: blocksize
            
            	Specify TFTP client blocksize
            	**type**\: int
            
            	**range:** 512..8192
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Tftp, self).__init__()

                self.yang_name = "tftp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("boot-interface", ("boot_interface", Native.Ip.Tftp.BootInterface)), ("source-interface", ("source_interface", Native.Ip.Tftp.SourceInterface))])
                self._leafs = OrderedDict([
                    ('blocksize', (YLeaf(YType.uint16, 'blocksize'), ['int'])),
                ])
                self.blocksize = None

                self.boot_interface = Native.Ip.Tftp.BootInterface()
                self.boot_interface.parent = self
                self._children_name_map["boot_interface"] = "boot-interface"

                self.source_interface = Native.Ip.Tftp.SourceInterface()
                self.source_interface.parent = self
                self._children_name_map["source_interface"] = "source-interface"
                self._segment_path = lambda: "tftp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Tftp, [u'blocksize'], name, value)


            class BootInterface(Entity):
                """
                Force interface to use for TFTP booting
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tftp.BootInterface.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tftp.BootInterface.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tftp.BootInterface.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tftp.BootInterface.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Tftp.BootInterface, self).__init__()

                    self.yang_name = "boot-interface"
                    self.yang_parent_name = "tftp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Ip.Tftp.BootInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Ip.Tftp.BootInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Ip.Tftp.BootInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Ip.Tftp.BootInterface.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.Ip.Tftp.BootInterface.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.Ip.Tftp.BootInterface.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.Ip.Tftp.BootInterface.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.Ip.Tftp.BootInterface.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "boot-interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/tftp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Tftp.BootInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Tftp.BootInterface.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "boot-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/tftp/boot-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tftp.BootInterface.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Tftp.BootInterface.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "boot-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/tftp/boot-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tftp.BootInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Tftp.BootInterface.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "boot-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/tftp/boot-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tftp.BootInterface.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Tftp.BootInterface.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "boot-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/tftp/boot-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tftp.BootInterface.PortChannelSubinterface, [u'port_channel'], name, value)


            class SourceInterface(Entity):
                """
                Specify interface for source address in TFTP connections
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tftp.SourceInterface.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tftp.SourceInterface.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tftp.SourceInterface.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tftp.SourceInterface.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ip.Tftp.SourceInterface, self).__init__()

                    self.yang_name = "source-interface"
                    self.yang_parent_name = "tftp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Ip.Tftp.SourceInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Ip.Tftp.SourceInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Ip.Tftp.SourceInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Ip.Tftp.SourceInterface.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.Ip.Tftp.SourceInterface.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.Ip.Tftp.SourceInterface.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.Ip.Tftp.SourceInterface.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.Ip.Tftp.SourceInterface.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "source-interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/tftp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Tftp.SourceInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Tftp.SourceInterface.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/tftp/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tftp.SourceInterface.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Tftp.SourceInterface.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/tftp/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tftp.SourceInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Tftp.SourceInterface.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/tftp/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tftp.SourceInterface.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ip.Tftp.SourceInterface.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/tftp/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tftp.SourceInterface.PortChannelSubinterface, [u'port_channel'], name, value)


        class AccessList(Entity):
            """
            IOS Named access list
            
            .. attribute:: standard
            
            	Standard Access List
            	**type**\: list of  		 :py:class:`Standard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard>`
            
            .. attribute:: role_based
            
            	Role\-based Access List
            	**type**\: list of  		 :py:class:`RoleBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased>`
            
            .. attribute:: extended
            
            	Extended Access List
            	**type**\: list of  		 :py:class:`Extended <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended>`
            
            .. attribute:: helper
            
            	Access List acts on helper\-address
            	**type**\:  :py:class:`Helper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Helper>`
            
            .. attribute:: log_update
            
            	Control access list log updates
            	**type**\:  :py:class:`LogUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.LogUpdate>`
            
            .. attribute:: logging
            
            	Control access list logging
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Logging>`
            
            .. attribute:: match_local_traffic
            
            	Enable ACL matching for locally generated traffic
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: persistent
            
            	enable persistency across reload
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: resequence
            
            	Resequence Access List
            	**type**\:  :py:class:`Resequence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Resequence>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.AccessList, self).__init__()

                self.yang_name = "access-list"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-acl:standard", ("standard", Native.Ip.AccessList.Standard)), ("Cisco-IOS-XE-acl:role-based", ("role_based", Native.Ip.AccessList.RoleBased)), ("Cisco-IOS-XE-acl:extended", ("extended", Native.Ip.AccessList.Extended)), ("Cisco-IOS-XE-acl:helper", ("helper", Native.Ip.AccessList.Helper)), ("Cisco-IOS-XE-acl:log-update", ("log_update", Native.Ip.AccessList.LogUpdate)), ("Cisco-IOS-XE-acl:logging", ("logging", Native.Ip.AccessList.Logging)), ("Cisco-IOS-XE-acl:resequence", ("resequence", Native.Ip.AccessList.Resequence))])
                self._leafs = OrderedDict([
                    ('match_local_traffic', (YLeaf(YType.empty, 'Cisco-IOS-XE-acl:match-local-traffic'), ['Empty'])),
                    ('persistent', (YLeaf(YType.empty, 'Cisco-IOS-XE-acl:persistent'), ['Empty'])),
                ])
                self.match_local_traffic = None
                self.persistent = None

                self.helper = Native.Ip.AccessList.Helper()
                self.helper.parent = self
                self._children_name_map["helper"] = "Cisco-IOS-XE-acl:helper"

                self.log_update = Native.Ip.AccessList.LogUpdate()
                self.log_update.parent = self
                self._children_name_map["log_update"] = "Cisco-IOS-XE-acl:log-update"

                self.logging = Native.Ip.AccessList.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "Cisco-IOS-XE-acl:logging"

                self.resequence = Native.Ip.AccessList.Resequence()
                self.resequence.parent = self
                self._children_name_map["resequence"] = "Cisco-IOS-XE-acl:resequence"

                self.standard = YList(self)
                self.role_based = YList(self)
                self.extended = YList(self)
                self._segment_path = lambda: "access-list"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.AccessList, ['match_local_traffic', 'persistent'], name, value)


            class Standard(Entity):
                """
                Standard Access List
                
                .. attribute:: name  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: int
                
                			**range:** 1300..1999
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: access_list_seq_rule
                
                	
                	**type**\: list of  		 :py:class:`AccessListSeqRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard.AccessListSeqRule>`
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard.Default>`
                
                

                """

                _prefix = 'ios-acl'
                _revision = '2018-05-31'

                def __init__(self):
                    super(Native.Ip.AccessList.Standard, self).__init__()

                    self.yang_name = "standard"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("access-list-seq-rule", ("access_list_seq_rule", Native.Ip.AccessList.Standard.AccessListSeqRule)), ("default", ("default", Native.Ip.AccessList.Standard.Default))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['int','int','str'])),
                    ])
                    self.name = None

                    self.default = Native.Ip.AccessList.Standard.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.access_list_seq_rule = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-acl:standard" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/access-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.AccessList.Standard, ['name'], name, value)


                class AccessListSeqRule(Entity):
                    """
                    
                    
                    .. attribute:: sequence  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: deny
                    
                    	Specify packets to reject
                    	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard.AccessListSeqRule.Deny>`
                    
                    .. attribute:: permit
                    
                    	Specify packets to forward
                    	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard.AccessListSeqRule.Permit>`
                    
                    .. attribute:: remark
                    
                    	Access list entry comment
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    

                    """

                    _prefix = 'ios-acl'
                    _revision = '2018-05-31'

                    def __init__(self):
                        super(Native.Ip.AccessList.Standard.AccessListSeqRule, self).__init__()

                        self.yang_name = "access-list-seq-rule"
                        self.yang_parent_name = "standard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['sequence']
                        self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.AccessList.Standard.AccessListSeqRule.Deny)), ("permit", ("permit", Native.Ip.AccessList.Standard.AccessListSeqRule.Permit))])
                        self._leafs = OrderedDict([
                            ('sequence', (YLeaf(YType.uint64, 'sequence'), ['int'])),
                            ('remark', (YLeaf(YType.str, 'remark'), ['str'])),
                        ])
                        self.sequence = None
                        self.remark = None

                        self.deny = Native.Ip.AccessList.Standard.AccessListSeqRule.Deny()
                        self.deny.parent = self
                        self._children_name_map["deny"] = "deny"

                        self.permit = Native.Ip.AccessList.Standard.AccessListSeqRule.Permit()
                        self.permit.parent = self
                        self._children_name_map["permit"] = "permit"
                        self._segment_path = lambda: "access-list-seq-rule" + "[sequence='" + str(self.sequence) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.AccessList.Standard.AccessListSeqRule, ['sequence', 'remark'], name, value)


                    class Deny(Entity):
                        """
                        Specify packets to reject
                        
                        .. attribute:: std_ace
                        
                        	
                        	**type**\:  :py:class:`StdAce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard.AccessListSeqRule.Deny.StdAce>`
                        
                        

                        """

                        _prefix = 'ios-acl'
                        _revision = '2018-05-31'

                        def __init__(self):
                            super(Native.Ip.AccessList.Standard.AccessListSeqRule.Deny, self).__init__()

                            self.yang_name = "deny"
                            self.yang_parent_name = "access-list-seq-rule"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("std-ace", ("std_ace", Native.Ip.AccessList.Standard.AccessListSeqRule.Deny.StdAce))])
                            self._leafs = OrderedDict()

                            self.std_ace = Native.Ip.AccessList.Standard.AccessListSeqRule.Deny.StdAce()
                            self.std_ace.parent = self
                            self._children_name_map["std_ace"] = "std-ace"
                            self._segment_path = lambda: "deny"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.AccessList.Standard.AccessListSeqRule.Deny, [], name, value)


                        class StdAce(Entity):
                            """
                            
                            
                            .. attribute:: ipv4_prefix
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: any
                            
                            	Any source prefix
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: host
                            
                            	A single source host
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: log
                            
                            	Log matches against this entry
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.Standard.AccessListSeqRule.Deny.StdAce, self).__init__()

                                self.yang_name = "std-ace"
                                self.yang_parent_name = "deny"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_prefix', (YLeaf(YType.str, 'ipv4-prefix'), ['str','str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                    ('host', (YLeaf(YType.str, 'host'), ['str','str'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ])
                                self.ipv4_prefix = None
                                self.mask = None
                                self.any = None
                                self.host = None
                                self.log = None
                                self._segment_path = lambda: "std-ace"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.Standard.AccessListSeqRule.Deny.StdAce, ['ipv4_prefix', 'mask', 'any', 'host', 'log'], name, value)


                    class Permit(Entity):
                        """
                        Specify packets to forward
                        
                        .. attribute:: std_ace
                        
                        	
                        	**type**\:  :py:class:`StdAce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard.AccessListSeqRule.Permit.StdAce>`
                        
                        

                        """

                        _prefix = 'ios-acl'
                        _revision = '2018-05-31'

                        def __init__(self):
                            super(Native.Ip.AccessList.Standard.AccessListSeqRule.Permit, self).__init__()

                            self.yang_name = "permit"
                            self.yang_parent_name = "access-list-seq-rule"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("std-ace", ("std_ace", Native.Ip.AccessList.Standard.AccessListSeqRule.Permit.StdAce))])
                            self._leafs = OrderedDict()

                            self.std_ace = Native.Ip.AccessList.Standard.AccessListSeqRule.Permit.StdAce()
                            self.std_ace.parent = self
                            self._children_name_map["std_ace"] = "std-ace"
                            self._segment_path = lambda: "permit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.AccessList.Standard.AccessListSeqRule.Permit, [], name, value)


                        class StdAce(Entity):
                            """
                            
                            
                            .. attribute:: ipv4_prefix
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: any
                            
                            	Any source prefix
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: host
                            
                            	A single source host
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: log
                            
                            	Log matches against this entry
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.Standard.AccessListSeqRule.Permit.StdAce, self).__init__()

                                self.yang_name = "std-ace"
                                self.yang_parent_name = "permit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_prefix', (YLeaf(YType.str, 'ipv4-prefix'), ['str','str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                    ('host', (YLeaf(YType.str, 'host'), ['str','str'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ])
                                self.ipv4_prefix = None
                                self.mask = None
                                self.any = None
                                self.host = None
                                self.log = None
                                self._segment_path = lambda: "std-ace"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.Standard.AccessListSeqRule.Permit.StdAce, ['ipv4_prefix', 'mask', 'any', 'host', 'log'], name, value)


                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: access_list_seq_rule
                    
                    	
                    	**type**\: list of  		 :py:class:`AccessListSeqRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard.Default.AccessListSeqRule>`
                    
                    

                    """

                    _prefix = 'ios-acl'
                    _revision = '2018-05-31'

                    def __init__(self):
                        super(Native.Ip.AccessList.Standard.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "standard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-list-seq-rule", ("access_list_seq_rule", Native.Ip.AccessList.Standard.Default.AccessListSeqRule))])
                        self._leafs = OrderedDict()

                        self.access_list_seq_rule = YList(self)
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.AccessList.Standard.Default, [], name, value)


                    class AccessListSeqRule(Entity):
                        """
                        
                        
                        .. attribute:: sequence  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..2147483647
                        
                        .. attribute:: deny
                        
                        	Specify packets to reject
                        	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Deny>`
                        
                        .. attribute:: permit
                        
                        	Specify packets to forward
                        	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Permit>`
                        
                        .. attribute:: remark
                        
                        	Access list entry comment
                        	**type**\: str
                        
                        	**length:** 1..100
                        
                        

                        """

                        _prefix = 'ios-acl'
                        _revision = '2018-05-31'

                        def __init__(self):
                            super(Native.Ip.AccessList.Standard.Default.AccessListSeqRule, self).__init__()

                            self.yang_name = "access-list-seq-rule"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['sequence']
                            self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Deny)), ("permit", ("permit", Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Permit))])
                            self._leafs = OrderedDict([
                                ('sequence', (YLeaf(YType.uint64, 'sequence'), ['int'])),
                                ('remark', (YLeaf(YType.str, 'remark'), ['str'])),
                            ])
                            self.sequence = None
                            self.remark = None

                            self.deny = Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Deny()
                            self.deny.parent = self
                            self._children_name_map["deny"] = "deny"

                            self.permit = Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Permit()
                            self.permit.parent = self
                            self._children_name_map["permit"] = "permit"
                            self._segment_path = lambda: "access-list-seq-rule" + "[sequence='" + str(self.sequence) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.AccessList.Standard.Default.AccessListSeqRule, ['sequence', 'remark'], name, value)


                        class Deny(Entity):
                            """
                            Specify packets to reject
                            
                            .. attribute:: std_ace
                            
                            	
                            	**type**\:  :py:class:`StdAce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Deny.StdAce>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Deny, self).__init__()

                                self.yang_name = "deny"
                                self.yang_parent_name = "access-list-seq-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("std-ace", ("std_ace", Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Deny.StdAce))])
                                self._leafs = OrderedDict()

                                self.std_ace = Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Deny.StdAce()
                                self.std_ace.parent = self
                                self._children_name_map["std_ace"] = "std-ace"
                                self._segment_path = lambda: "deny"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Deny, [], name, value)


                            class StdAce(Entity):
                                """
                                
                                
                                .. attribute:: ipv4_prefix
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                .. attribute:: mask
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: any
                                
                                	Any source prefix
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: host
                                
                                	A single source host
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                .. attribute:: log
                                
                                	Log matches against this entry
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Deny.StdAce, self).__init__()

                                    self.yang_name = "std-ace"
                                    self.yang_parent_name = "deny"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_prefix', (YLeaf(YType.str, 'ipv4-prefix'), ['str','str'])),
                                        ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                        ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                        ('host', (YLeaf(YType.str, 'host'), ['str','str'])),
                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ])
                                    self.ipv4_prefix = None
                                    self.mask = None
                                    self.any = None
                                    self.host = None
                                    self.log = None
                                    self._segment_path = lambda: "std-ace"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Deny.StdAce, ['ipv4_prefix', 'mask', 'any', 'host', 'log'], name, value)


                        class Permit(Entity):
                            """
                            Specify packets to forward
                            
                            .. attribute:: std_ace
                            
                            	
                            	**type**\:  :py:class:`StdAce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Permit.StdAce>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Permit, self).__init__()

                                self.yang_name = "permit"
                                self.yang_parent_name = "access-list-seq-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("std-ace", ("std_ace", Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Permit.StdAce))])
                                self._leafs = OrderedDict()

                                self.std_ace = Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Permit.StdAce()
                                self.std_ace.parent = self
                                self._children_name_map["std_ace"] = "std-ace"
                                self._segment_path = lambda: "permit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Permit, [], name, value)


                            class StdAce(Entity):
                                """
                                
                                
                                .. attribute:: ipv4_prefix
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                .. attribute:: mask
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: any
                                
                                	Any source prefix
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: host
                                
                                	A single source host
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                .. attribute:: log
                                
                                	Log matches against this entry
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Permit.StdAce, self).__init__()

                                    self.yang_name = "std-ace"
                                    self.yang_parent_name = "permit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_prefix', (YLeaf(YType.str, 'ipv4-prefix'), ['str','str'])),
                                        ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                        ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                        ('host', (YLeaf(YType.str, 'host'), ['str','str'])),
                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ])
                                    self.ipv4_prefix = None
                                    self.mask = None
                                    self.any = None
                                    self.host = None
                                    self.log = None
                                    self._segment_path = lambda: "std-ace"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.Standard.Default.AccessListSeqRule.Permit.StdAce, ['ipv4_prefix', 'mask', 'any', 'host', 'log'], name, value)


            class RoleBased(Entity):
                """
                Role\-based Access List
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: access_list_seq_rule
                
                	
                	**type**\: list of  		 :py:class:`AccessListSeqRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.AccessListSeqRule>`
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default>`
                
                

                """

                _prefix = 'ios-acl'
                _revision = '2018-05-31'

                def __init__(self):
                    super(Native.Ip.AccessList.RoleBased, self).__init__()

                    self.yang_name = "role-based"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("access-list-seq-rule", ("access_list_seq_rule", Native.Ip.AccessList.RoleBased.AccessListSeqRule)), ("default", ("default", Native.Ip.AccessList.RoleBased.Default))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.default = Native.Ip.AccessList.RoleBased.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.access_list_seq_rule = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-acl:role-based" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/access-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.AccessList.RoleBased, ['name'], name, value)


                class AccessListSeqRule(Entity):
                    """
                    
                    
                    .. attribute:: sequence  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: ace_rule
                    
                    	
                    	**type**\:  :py:class:`AceRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule>`
                    
                    .. attribute:: remark
                    
                    	Access list entry comment
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    

                    """

                    _prefix = 'ios-acl'
                    _revision = '2018-05-31'

                    def __init__(self):
                        super(Native.Ip.AccessList.RoleBased.AccessListSeqRule, self).__init__()

                        self.yang_name = "access-list-seq-rule"
                        self.yang_parent_name = "role-based"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['sequence']
                        self._child_classes = OrderedDict([("ace-rule", ("ace_rule", Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule))])
                        self._leafs = OrderedDict([
                            ('sequence', (YLeaf(YType.uint64, 'sequence'), ['int'])),
                            ('remark', (YLeaf(YType.str, 'remark'), ['str'])),
                        ])
                        self.sequence = None
                        self.remark = None

                        self.ace_rule = Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule()
                        self.ace_rule.parent = self
                        self._children_name_map["ace_rule"] = "ace-rule"
                        self._segment_path = lambda: "access-list-seq-rule" + "[sequence='" + str(self.sequence) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.AccessList.RoleBased.AccessListSeqRule, ['sequence', 'remark'], name, value)


                    class AceRule(Entity):
                        """
                        
                        
                        .. attribute:: action
                        
                        	
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Action>`
                        
                        .. attribute:: protocol
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..255
                        
                        		**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Protocol>`
                        
                        .. attribute:: object_group_str
                        
                        	Service object group name
                        	**type**\: str
                        
                        .. attribute:: dscp
                        
                        	Match packets with given dscp value
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..63
                        
                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                        
                        .. attribute:: fragments
                        
                        	Check non\-initial fragments
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: log
                        
                        	Log matches against this entry
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: log_input
                        
                        	Log matches against this entry, including input interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: option
                        
                        	Match packets with given IP Options value
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..255
                        
                        		**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Option>`
                        
                        .. attribute:: precedence
                        
                        	Match packets with given precedence value
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..7
                        
                        		**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Precedence>`
                        
                        .. attribute:: time_range
                        
                        	Specify a time\-range
                        	**type**\: str
                        
                        .. attribute:: tos
                        
                        	Match packets with given TOS value
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..15
                        
                        		**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Tos>`
                        
                        .. attribute:: ttl
                        
                        	Match packets with given TTL value
                        	**type**\:  :py:class:`Ttl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Ttl>`
                        
                        .. attribute:: match_all
                        
                        	Match if all specified flags are present
                        	**type**\:  :py:class:`MatchAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.MatchAll>`
                        
                        .. attribute:: match_any
                        
                        	Match if any specified flags is present
                        	**type**\:  :py:class:`MatchAny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.MatchAny>`
                        
                        .. attribute:: ack
                        
                        	Match on the ACK bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fin
                        
                        	Match on the FIN bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: psh
                        
                        	Match on the PSH bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rst
                        
                        	Match on the RST bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: syn
                        
                        	Match on the SYN bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: urg
                        
                        	Match on the URG bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: established
                        
                        	Match established connections
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: msg_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: msg_code
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: named_msg_type
                        
                        	
                        	**type**\:  :py:class:`NamedMsgType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.NamedMsgType>`
                        
                        .. attribute:: src
                        
                        	Source port conditions
                        	**type**\:  :py:class:`Src <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Src>`
                        
                        .. attribute:: dst
                        
                        	Destination port conditions
                        	**type**\:  :py:class:`Dst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Dst>`
                        
                        

                        """

                        _prefix = 'ios-acl'
                        _revision = '2018-05-31'

                        def __init__(self):
                            super(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule, self).__init__()

                            self.yang_name = "ace-rule"
                            self.yang_parent_name = "access-list-seq-rule"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ttl", ("ttl", Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Ttl)), ("match-all", ("match_all", Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.MatchAll)), ("match-any", ("match_any", Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.MatchAny)), ("src", ("src", Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Src)), ("dst", ("dst", Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Dst))])
                            self._leafs = OrderedDict([
                                ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Action')])),
                                ('protocol', (YLeaf(YType.str, 'protocol'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Protocol')])),
                                ('object_group_str', (YLeaf(YType.str, 'object-group-str'), ['str'])),
                                ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                ('fragments', (YLeaf(YType.empty, 'fragments'), ['Empty'])),
                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ('log_input', (YLeaf(YType.empty, 'log-input'), ['Empty'])),
                                ('option', (YLeaf(YType.str, 'option'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Option')])),
                                ('precedence', (YLeaf(YType.str, 'precedence'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Precedence')])),
                                ('time_range', (YLeaf(YType.str, 'time-range'), ['str'])),
                                ('tos', (YLeaf(YType.str, 'tos'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Tos')])),
                                ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                ('established', (YLeaf(YType.empty, 'established'), ['Empty'])),
                                ('msg_type', (YLeaf(YType.uint8, 'msg-type'), ['int'])),
                                ('msg_code', (YLeaf(YType.uint8, 'msg-code'), ['int'])),
                                ('named_msg_type', (YLeaf(YType.enumeration, 'named-msg-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.NamedMsgType')])),
                            ])
                            self.action = None
                            self.protocol = None
                            self.object_group_str = None
                            self.dscp = None
                            self.fragments = None
                            self.log = None
                            self.log_input = None
                            self.option = None
                            self.precedence = None
                            self.time_range = None
                            self.tos = None
                            self.ack = None
                            self.fin = None
                            self.psh = None
                            self.rst = None
                            self.syn = None
                            self.urg = None
                            self.established = None
                            self.msg_type = None
                            self.msg_code = None
                            self.named_msg_type = None

                            self.ttl = Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Ttl()
                            self.ttl.parent = self
                            self._children_name_map["ttl"] = "ttl"

                            self.match_all = Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.MatchAll()
                            self.match_all.parent = self
                            self._children_name_map["match_all"] = "match-all"

                            self.match_any = Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.MatchAny()
                            self.match_any.parent = self
                            self._children_name_map["match_any"] = "match-any"

                            self.src = Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Src()
                            self.src.parent = self
                            self._children_name_map["src"] = "src"

                            self.dst = Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Dst()
                            self.dst.parent = self
                            self._children_name_map["dst"] = "dst"
                            self._segment_path = lambda: "ace-rule"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule, ['action', 'protocol', 'object_group_str', 'dscp', 'fragments', 'log', 'log_input', 'option', 'precedence', 'time_range', 'tos', 'ack', 'fin', 'psh', 'rst', 'syn', 'urg', 'established', 'msg_type', 'msg_code', 'named_msg_type'], name, value)

                        class Action(Enum):
                            """
                            Action (Enum Class)

                            .. data:: deny = 0

                            .. data:: permit = 1

                            """

                            deny = Enum.YLeaf(0, "deny")

                            permit = Enum.YLeaf(1, "permit")


                        class NamedMsgType(Enum):
                            """
                            NamedMsgType (Enum Class)

                            .. data:: administratively_prohibited = 0

                            .. data:: alternate_address = 1

                            .. data:: conversion_error = 2

                            .. data:: dod_host_prohibited = 3

                            .. data:: dod_net_prohibited = 4

                            .. data:: echo = 5

                            .. data:: echo_reply = 6

                            .. data:: general_parameter_problem = 7

                            .. data:: host_isolated = 8

                            .. data:: host_precedence_unreachable = 9

                            .. data:: host_redirect = 10

                            .. data:: host_tos_redirect = 11

                            .. data:: host_tos_unreachable = 12

                            .. data:: host_unknown = 13

                            .. data:: host_unreachable = 14

                            .. data:: information_reply = 15

                            .. data:: information_request = 16

                            .. data:: mask_reply = 17

                            .. data:: mask_request = 18

                            .. data:: mobile_redirect = 19

                            .. data:: net_redirect = 20

                            .. data:: net_tos_redirect = 21

                            .. data:: net_tos_unreachable = 22

                            .. data:: net_unreachable = 23

                            .. data:: network_unknown = 24

                            .. data:: no_room_for_option = 25

                            .. data:: option_missing = 26

                            .. data:: packet_too_big = 27

                            .. data:: parameter_problem = 28

                            .. data:: port_unreachable = 29

                            .. data:: precedence_unreachable = 30

                            .. data:: protocol_unreachable = 31

                            .. data:: reassembly_timeout = 32

                            .. data:: redirect = 33

                            .. data:: router_advertisement = 34

                            .. data:: router_solicitation = 35

                            .. data:: source_quench = 36

                            .. data:: source_route_failed = 37

                            .. data:: time_exceeded = 38

                            .. data:: timestamp_reply = 39

                            .. data:: timestamp_request = 40

                            .. data:: traceroute = 41

                            .. data:: ttl_exceeded = 42

                            .. data:: unreachable = 43

                            """

                            administratively_prohibited = Enum.YLeaf(0, "administratively-prohibited")

                            alternate_address = Enum.YLeaf(1, "alternate-address")

                            conversion_error = Enum.YLeaf(2, "conversion-error")

                            dod_host_prohibited = Enum.YLeaf(3, "dod-host-prohibited")

                            dod_net_prohibited = Enum.YLeaf(4, "dod-net-prohibited")

                            echo = Enum.YLeaf(5, "echo")

                            echo_reply = Enum.YLeaf(6, "echo-reply")

                            general_parameter_problem = Enum.YLeaf(7, "general-parameter-problem")

                            host_isolated = Enum.YLeaf(8, "host-isolated")

                            host_precedence_unreachable = Enum.YLeaf(9, "host-precedence-unreachable")

                            host_redirect = Enum.YLeaf(10, "host-redirect")

                            host_tos_redirect = Enum.YLeaf(11, "host-tos-redirect")

                            host_tos_unreachable = Enum.YLeaf(12, "host-tos-unreachable")

                            host_unknown = Enum.YLeaf(13, "host-unknown")

                            host_unreachable = Enum.YLeaf(14, "host-unreachable")

                            information_reply = Enum.YLeaf(15, "information-reply")

                            information_request = Enum.YLeaf(16, "information-request")

                            mask_reply = Enum.YLeaf(17, "mask-reply")

                            mask_request = Enum.YLeaf(18, "mask-request")

                            mobile_redirect = Enum.YLeaf(19, "mobile-redirect")

                            net_redirect = Enum.YLeaf(20, "net-redirect")

                            net_tos_redirect = Enum.YLeaf(21, "net-tos-redirect")

                            net_tos_unreachable = Enum.YLeaf(22, "net-tos-unreachable")

                            net_unreachable = Enum.YLeaf(23, "net-unreachable")

                            network_unknown = Enum.YLeaf(24, "network-unknown")

                            no_room_for_option = Enum.YLeaf(25, "no-room-for-option")

                            option_missing = Enum.YLeaf(26, "option-missing")

                            packet_too_big = Enum.YLeaf(27, "packet-too-big")

                            parameter_problem = Enum.YLeaf(28, "parameter-problem")

                            port_unreachable = Enum.YLeaf(29, "port-unreachable")

                            precedence_unreachable = Enum.YLeaf(30, "precedence-unreachable")

                            protocol_unreachable = Enum.YLeaf(31, "protocol-unreachable")

                            reassembly_timeout = Enum.YLeaf(32, "reassembly-timeout")

                            redirect = Enum.YLeaf(33, "redirect")

                            router_advertisement = Enum.YLeaf(34, "router-advertisement")

                            router_solicitation = Enum.YLeaf(35, "router-solicitation")

                            source_quench = Enum.YLeaf(36, "source-quench")

                            source_route_failed = Enum.YLeaf(37, "source-route-failed")

                            time_exceeded = Enum.YLeaf(38, "time-exceeded")

                            timestamp_reply = Enum.YLeaf(39, "timestamp-reply")

                            timestamp_request = Enum.YLeaf(40, "timestamp-request")

                            traceroute = Enum.YLeaf(41, "traceroute")

                            ttl_exceeded = Enum.YLeaf(42, "ttl-exceeded")

                            unreachable = Enum.YLeaf(43, "unreachable")


                        class Option(Enum):
                            """
                            Option (Enum Class)

                            Match packets with given IP Options value

                            .. data:: add_ext = 0

                            .. data:: any_options = 1

                            .. data:: com_security = 2

                            .. data:: dps = 3

                            .. data:: encode = 4

                            .. data:: eool = 5

                            .. data:: ext_ip = 6

                            .. data:: ext_security = 7

                            .. data:: finn = 8

                            .. data:: imitd = 9

                            .. data:: lsr = 10

                            .. data:: mtup = 11

                            .. data:: mtur = 12

                            .. data:: no_op = 13

                            .. data:: nsapa = 14

                            .. data:: record_route = 15

                            .. data:: router_alert = 16

                            .. data:: sdb = 17

                            .. data:: security = 18

                            .. data:: ssr = 19

                            .. data:: stream_id = 20

                            .. data:: timestamp = 21

                            .. data:: traceroute = 22

                            .. data:: ump = 23

                            .. data:: visa = 24

                            .. data:: zsu = 25

                            """

                            add_ext = Enum.YLeaf(0, "add-ext")

                            any_options = Enum.YLeaf(1, "any-options")

                            com_security = Enum.YLeaf(2, "com-security")

                            dps = Enum.YLeaf(3, "dps")

                            encode = Enum.YLeaf(4, "encode")

                            eool = Enum.YLeaf(5, "eool")

                            ext_ip = Enum.YLeaf(6, "ext-ip")

                            ext_security = Enum.YLeaf(7, "ext-security")

                            finn = Enum.YLeaf(8, "finn")

                            imitd = Enum.YLeaf(9, "imitd")

                            lsr = Enum.YLeaf(10, "lsr")

                            mtup = Enum.YLeaf(11, "mtup")

                            mtur = Enum.YLeaf(12, "mtur")

                            no_op = Enum.YLeaf(13, "no-op")

                            nsapa = Enum.YLeaf(14, "nsapa")

                            record_route = Enum.YLeaf(15, "record-route")

                            router_alert = Enum.YLeaf(16, "router-alert")

                            sdb = Enum.YLeaf(17, "sdb")

                            security = Enum.YLeaf(18, "security")

                            ssr = Enum.YLeaf(19, "ssr")

                            stream_id = Enum.YLeaf(20, "stream-id")

                            timestamp = Enum.YLeaf(21, "timestamp")

                            traceroute = Enum.YLeaf(22, "traceroute")

                            ump = Enum.YLeaf(23, "ump")

                            visa = Enum.YLeaf(24, "visa")

                            zsu = Enum.YLeaf(25, "zsu")


                        class Precedence(Enum):
                            """
                            Precedence (Enum Class)

                            Match packets with given precedence value

                            .. data:: critical = 0

                            .. data:: flash = 1

                            .. data:: flash_override = 2

                            .. data:: immediate = 3

                            .. data:: internet = 4

                            .. data:: network = 5

                            .. data:: priority = 6

                            .. data:: routine = 7

                            """

                            critical = Enum.YLeaf(0, "critical")

                            flash = Enum.YLeaf(1, "flash")

                            flash_override = Enum.YLeaf(2, "flash-override")

                            immediate = Enum.YLeaf(3, "immediate")

                            internet = Enum.YLeaf(4, "internet")

                            network = Enum.YLeaf(5, "network")

                            priority = Enum.YLeaf(6, "priority")

                            routine = Enum.YLeaf(7, "routine")


                        class Protocol(Enum):
                            """
                            Protocol (Enum Class)

                            .. data:: ahp = 0

                            .. data:: eigrp = 1

                            .. data:: esp = 2

                            .. data:: gre = 3

                            .. data:: icmp = 4

                            .. data:: igmp = 5

                            .. data:: ip = 6

                            .. data:: ipinip = 7

                            .. data:: nos = 8

                            .. data:: object_group = 9

                            .. data:: ospf = 10

                            .. data:: pcp = 11

                            .. data:: pim = 12

                            .. data:: tcp = 13

                            .. data:: udp = 14

                            """

                            ahp = Enum.YLeaf(0, "ahp")

                            eigrp = Enum.YLeaf(1, "eigrp")

                            esp = Enum.YLeaf(2, "esp")

                            gre = Enum.YLeaf(3, "gre")

                            icmp = Enum.YLeaf(4, "icmp")

                            igmp = Enum.YLeaf(5, "igmp")

                            ip = Enum.YLeaf(6, "ip")

                            ipinip = Enum.YLeaf(7, "ipinip")

                            nos = Enum.YLeaf(8, "nos")

                            object_group = Enum.YLeaf(9, "object-group")

                            ospf = Enum.YLeaf(10, "ospf")

                            pcp = Enum.YLeaf(11, "pcp")

                            pim = Enum.YLeaf(12, "pim")

                            tcp = Enum.YLeaf(13, "tcp")

                            udp = Enum.YLeaf(14, "udp")


                        class Tos(Enum):
                            """
                            Tos (Enum Class)

                            Match packets with given TOS value

                            .. data:: max_reliability = 0

                            .. data:: max_throughput = 1

                            .. data:: min_delay = 2

                            .. data:: min_monetary_cost = 3

                            .. data:: normal = 4

                            """

                            max_reliability = Enum.YLeaf(0, "max-reliability")

                            max_throughput = Enum.YLeaf(1, "max-throughput")

                            min_delay = Enum.YLeaf(2, "min-delay")

                            min_monetary_cost = Enum.YLeaf(3, "min-monetary-cost")

                            normal = Enum.YLeaf(4, "normal")



                        class Ttl(Entity):
                            """
                            Match packets with given TTL value
                            
                            .. attribute:: eq
                            
                            	Match only packets on a given TTL number
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: gt
                            
                            	Match only packets on a given TTL number
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: lt
                            
                            	Match only packets on a given TTL number
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neq
                            
                            	Match only packets on a given TTL number
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: range
                            
                            	Match only packets in the range of TTLs
                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Ttl.Range>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Ttl, self).__init__()

                                self.yang_name = "ttl"
                                self.yang_parent_name = "ace-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("range", ("range", Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Ttl.Range))])
                                self._leafs = OrderedDict([
                                    ('eq', (YLeaf(YType.uint8, 'eq'), ['int'])),
                                    ('gt', (YLeaf(YType.uint8, 'gt'), ['int'])),
                                    ('lt', (YLeaf(YType.uint8, 'lt'), ['int'])),
                                    ('neq', (YLeaf(YType.uint8, 'neq'), ['int'])),
                                ])
                                self.eq = None
                                self.gt = None
                                self.lt = None
                                self.neq = None

                                self.range = Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Ttl.Range()
                                self.range.parent = self
                                self._children_name_map["range"] = "range"
                                self._segment_path = lambda: "ttl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Ttl, ['eq', 'gt', 'lt', 'neq'], name, value)


                            class Range(Entity):
                                """
                                Match only packets in the range of TTLs
                                
                                .. attribute:: value1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: value2
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Ttl.Range, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "ttl"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('value1', (YLeaf(YType.uint8, 'value1'), ['int'])),
                                        ('value2', (YLeaf(YType.uint8, 'value2'), ['int'])),
                                    ])
                                    self.value1 = None
                                    self.value2 = None
                                    self._segment_path = lambda: "range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Ttl.Range, ['value1', 'value2'], name, value)


                        class MatchAll(Entity):
                            """
                            Match if all specified flags are present
                            
                            .. attribute:: plusack
                            
                            	Match on ACK set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusfin
                            
                            	Match on FIN set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: pluspsh
                            
                            	Match on PSH set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusrst
                            
                            	Match on RST set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plussyn
                            
                            	Match on SYN set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusurg
                            
                            	Match on URG set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusack
                            
                            	Match on ACK not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusfin
                            
                            	Match on FIN not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minuspsh
                            
                            	Match on PSH not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusrst
                            
                            	Match on RST not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minussyn
                            
                            	Match on SYN not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusurg
                            
                            	Match on URG not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.MatchAll, self).__init__()

                                self.yang_name = "match-all"
                                self.yang_parent_name = "ace-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('plusack', (YLeaf(YType.empty, 'plusack'), ['Empty'])),
                                    ('plusfin', (YLeaf(YType.empty, 'plusfin'), ['Empty'])),
                                    ('pluspsh', (YLeaf(YType.empty, 'pluspsh'), ['Empty'])),
                                    ('plusrst', (YLeaf(YType.empty, 'plusrst'), ['Empty'])),
                                    ('plussyn', (YLeaf(YType.empty, 'plussyn'), ['Empty'])),
                                    ('plusurg', (YLeaf(YType.empty, 'plusurg'), ['Empty'])),
                                    ('minusack', (YLeaf(YType.empty, 'minusack'), ['Empty'])),
                                    ('minusfin', (YLeaf(YType.empty, 'minusfin'), ['Empty'])),
                                    ('minuspsh', (YLeaf(YType.empty, 'minuspsh'), ['Empty'])),
                                    ('minusrst', (YLeaf(YType.empty, 'minusrst'), ['Empty'])),
                                    ('minussyn', (YLeaf(YType.empty, 'minussyn'), ['Empty'])),
                                    ('minusurg', (YLeaf(YType.empty, 'minusurg'), ['Empty'])),
                                ])
                                self.plusack = None
                                self.plusfin = None
                                self.pluspsh = None
                                self.plusrst = None
                                self.plussyn = None
                                self.plusurg = None
                                self.minusack = None
                                self.minusfin = None
                                self.minuspsh = None
                                self.minusrst = None
                                self.minussyn = None
                                self.minusurg = None
                                self._segment_path = lambda: "match-all"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.MatchAll, ['plusack', 'plusfin', 'pluspsh', 'plusrst', 'plussyn', 'plusurg', 'minusack', 'minusfin', 'minuspsh', 'minusrst', 'minussyn', 'minusurg'], name, value)


                        class MatchAny(Entity):
                            """
                            Match if any specified flags is present
                            
                            .. attribute:: plusack
                            
                            	Match on ACK set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusfin
                            
                            	Match on FIN set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: pluspsh
                            
                            	Match on PSH set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusrst
                            
                            	Match on RST set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plussyn
                            
                            	Match on SYN set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusurg
                            
                            	Match on URG set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusack
                            
                            	Match on ACK not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusfin
                            
                            	Match on FIN not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minuspsh
                            
                            	Match on PSH not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusrst
                            
                            	Match on RST not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minussyn
                            
                            	Match on SYN not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusurg
                            
                            	Match on URG not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.MatchAny, self).__init__()

                                self.yang_name = "match-any"
                                self.yang_parent_name = "ace-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('plusack', (YLeaf(YType.empty, 'plusack'), ['Empty'])),
                                    ('plusfin', (YLeaf(YType.empty, 'plusfin'), ['Empty'])),
                                    ('pluspsh', (YLeaf(YType.empty, 'pluspsh'), ['Empty'])),
                                    ('plusrst', (YLeaf(YType.empty, 'plusrst'), ['Empty'])),
                                    ('plussyn', (YLeaf(YType.empty, 'plussyn'), ['Empty'])),
                                    ('plusurg', (YLeaf(YType.empty, 'plusurg'), ['Empty'])),
                                    ('minusack', (YLeaf(YType.empty, 'minusack'), ['Empty'])),
                                    ('minusfin', (YLeaf(YType.empty, 'minusfin'), ['Empty'])),
                                    ('minuspsh', (YLeaf(YType.empty, 'minuspsh'), ['Empty'])),
                                    ('minusrst', (YLeaf(YType.empty, 'minusrst'), ['Empty'])),
                                    ('minussyn', (YLeaf(YType.empty, 'minussyn'), ['Empty'])),
                                    ('minusurg', (YLeaf(YType.empty, 'minusurg'), ['Empty'])),
                                ])
                                self.plusack = None
                                self.plusfin = None
                                self.pluspsh = None
                                self.plusrst = None
                                self.plussyn = None
                                self.plusurg = None
                                self.minusack = None
                                self.minusfin = None
                                self.minuspsh = None
                                self.minusrst = None
                                self.minussyn = None
                                self.minusurg = None
                                self._segment_path = lambda: "match-any"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.MatchAny, ['plusack', 'plusfin', 'pluspsh', 'plusrst', 'plussyn', 'plusurg', 'minusack', 'minusfin', 'minuspsh', 'minusrst', 'minussyn', 'minusurg'], name, value)


                        class Src(Entity):
                            """
                            Source port conditions
                            
                            .. attribute:: source_host
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: source_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_wildcard_bits
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_prefix
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: any
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: src_eq
                            
                            	Match only packets on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_gt
                            
                            	Match only packets with a greater port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_lt
                            
                            	Match only packets with a lower port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_neq
                            
                            	Match only packets not on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_range1
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_range2
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst
                            
                            	Destination port conditions
                            	**type**\:  :py:class:`Dst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Src.Dst>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Src, self).__init__()

                                self.yang_name = "src"
                                self.yang_parent_name = "ace-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dst", ("dst", Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Src.Dst))])
                                self._leafs = OrderedDict([
                                    ('source_host', (YLeaf(YType.str, 'source-host'), ['str','str','str'])),
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                    ('source_wildcard_bits', (YLeaf(YType.str, 'source-wildcard-bits'), ['str'])),
                                    ('source_prefix', (YLeaf(YType.str, 'source-prefix'), ['str'])),
                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                    ('src_eq', (YLeaf(YType.str, 'src-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_gt', (YLeaf(YType.str, 'src-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_lt', (YLeaf(YType.str, 'src-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_neq', (YLeaf(YType.str, 'src-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_range1', (YLeaf(YType.str, 'src-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_range2', (YLeaf(YType.str, 'src-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ])
                                self.source_host = None
                                self.source_address = None
                                self.source_wildcard_bits = None
                                self.source_prefix = None
                                self.any = None
                                self.src_eq = None
                                self.src_gt = None
                                self.src_lt = None
                                self.src_neq = None
                                self.src_range1 = None
                                self.src_range2 = None

                                self.dst = Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Src.Dst()
                                self.dst.parent = self
                                self._children_name_map["dst"] = "dst"
                                self._segment_path = lambda: "src"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Src, ['source_host', 'source_address', 'source_wildcard_bits', 'source_prefix', 'any', 'src_eq', 'src_gt', 'src_lt', 'src_neq', 'src_range1', 'src_range2'], name, value)


                            class Dst(Entity):
                                """
                                Destination port conditions
                                
                                .. attribute:: destination_host
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                .. attribute:: destination_address
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: destination_wildcard_bits
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: destination_prefix
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: destination_any
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: dst_eq
                                
                                	Match only packets on a given port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: dst_gt
                                
                                	Match only packets with a greater port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: dst_lt
                                
                                	Match only packets with a lower port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: dst_neq
                                
                                	Match only packets not on a given port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: dst_range1
                                
                                	Match only packets in the range of port numbers
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: dst_range2
                                
                                	Match only packets in the range of port numbers
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Src.Dst, self).__init__()

                                    self.yang_name = "dst"
                                    self.yang_parent_name = "src"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('destination_host', (YLeaf(YType.str, 'destination-host'), ['str','str','str'])),
                                        ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str'])),
                                        ('destination_wildcard_bits', (YLeaf(YType.str, 'destination-wildcard-bits'), ['str'])),
                                        ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                        ('destination_any', (YLeaf(YType.empty, 'destination-any'), ['Empty'])),
                                        ('dst_eq', (YLeaf(YType.str, 'dst-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('dst_gt', (YLeaf(YType.str, 'dst-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('dst_lt', (YLeaf(YType.str, 'dst-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('dst_neq', (YLeaf(YType.str, 'dst-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('dst_range1', (YLeaf(YType.str, 'dst-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('dst_range2', (YLeaf(YType.str, 'dst-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ])
                                    self.destination_host = None
                                    self.destination_address = None
                                    self.destination_wildcard_bits = None
                                    self.destination_prefix = None
                                    self.destination_any = None
                                    self.dst_eq = None
                                    self.dst_gt = None
                                    self.dst_lt = None
                                    self.dst_neq = None
                                    self.dst_range1 = None
                                    self.dst_range2 = None
                                    self._segment_path = lambda: "dst"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Src.Dst, ['destination_host', 'destination_address', 'destination_wildcard_bits', 'destination_prefix', 'destination_any', 'dst_eq', 'dst_gt', 'dst_lt', 'dst_neq', 'dst_range1', 'dst_range2'], name, value)


                        class Dst(Entity):
                            """
                            Destination port conditions
                            
                            .. attribute:: destination_host
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: destination_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_wildcard_bits
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_prefix
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: destination_any
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dst_eq
                            
                            	Match only packets on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_gt
                            
                            	Match only packets with a greater port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_lt
                            
                            	Match only packets with a lower port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_neq
                            
                            	Match only packets not on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_range1
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_range2
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Dst, self).__init__()

                                self.yang_name = "dst"
                                self.yang_parent_name = "ace-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('destination_host', (YLeaf(YType.str, 'destination-host'), ['str','str','str'])),
                                    ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str'])),
                                    ('destination_wildcard_bits', (YLeaf(YType.str, 'destination-wildcard-bits'), ['str'])),
                                    ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                    ('destination_any', (YLeaf(YType.empty, 'destination-any'), ['Empty'])),
                                    ('dst_eq', (YLeaf(YType.str, 'dst-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_gt', (YLeaf(YType.str, 'dst-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_lt', (YLeaf(YType.str, 'dst-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_neq', (YLeaf(YType.str, 'dst-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_range1', (YLeaf(YType.str, 'dst-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_range2', (YLeaf(YType.str, 'dst-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ])
                                self.destination_host = None
                                self.destination_address = None
                                self.destination_wildcard_bits = None
                                self.destination_prefix = None
                                self.destination_any = None
                                self.dst_eq = None
                                self.dst_gt = None
                                self.dst_lt = None
                                self.dst_neq = None
                                self.dst_range1 = None
                                self.dst_range2 = None
                                self._segment_path = lambda: "dst"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.RoleBased.AccessListSeqRule.AceRule.Dst, ['destination_host', 'destination_address', 'destination_wildcard_bits', 'destination_prefix', 'destination_any', 'dst_eq', 'dst_gt', 'dst_lt', 'dst_neq', 'dst_range1', 'dst_range2'], name, value)


                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: access_list_seq_rule
                    
                    	
                    	**type**\: list of  		 :py:class:`AccessListSeqRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule>`
                    
                    

                    """

                    _prefix = 'ios-acl'
                    _revision = '2018-05-31'

                    def __init__(self):
                        super(Native.Ip.AccessList.RoleBased.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "role-based"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-list-seq-rule", ("access_list_seq_rule", Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule))])
                        self._leafs = OrderedDict()

                        self.access_list_seq_rule = YList(self)
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.AccessList.RoleBased.Default, [], name, value)


                    class AccessListSeqRule(Entity):
                        """
                        
                        
                        .. attribute:: sequence  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..2147483647
                        
                        .. attribute:: ace_rule
                        
                        	
                        	**type**\:  :py:class:`AceRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule>`
                        
                        .. attribute:: remark
                        
                        	Access list entry comment
                        	**type**\: str
                        
                        	**length:** 1..100
                        
                        

                        """

                        _prefix = 'ios-acl'
                        _revision = '2018-05-31'

                        def __init__(self):
                            super(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule, self).__init__()

                            self.yang_name = "access-list-seq-rule"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['sequence']
                            self._child_classes = OrderedDict([("ace-rule", ("ace_rule", Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule))])
                            self._leafs = OrderedDict([
                                ('sequence', (YLeaf(YType.uint64, 'sequence'), ['int'])),
                                ('remark', (YLeaf(YType.str, 'remark'), ['str'])),
                            ])
                            self.sequence = None
                            self.remark = None

                            self.ace_rule = Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule()
                            self.ace_rule.parent = self
                            self._children_name_map["ace_rule"] = "ace-rule"
                            self._segment_path = lambda: "access-list-seq-rule" + "[sequence='" + str(self.sequence) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule, ['sequence', 'remark'], name, value)


                        class AceRule(Entity):
                            """
                            
                            
                            .. attribute:: action
                            
                            	
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Action>`
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..255
                            
                            		**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Protocol>`
                            
                            .. attribute:: object_group_str
                            
                            	Service object group name
                            	**type**\: str
                            
                            .. attribute:: dscp
                            
                            	Match packets with given dscp value
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..63
                            
                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                            
                            .. attribute:: fragments
                            
                            	Check non\-initial fragments
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log matches against this entry
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log_input
                            
                            	Log matches against this entry, including input interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: option
                            
                            	Match packets with given IP Options value
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..255
                            
                            		**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Option>`
                            
                            .. attribute:: precedence
                            
                            	Match packets with given precedence value
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..7
                            
                            		**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Precedence>`
                            
                            .. attribute:: time_range
                            
                            	Specify a time\-range
                            	**type**\: str
                            
                            .. attribute:: tos
                            
                            	Match packets with given TOS value
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..15
                            
                            		**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Tos>`
                            
                            .. attribute:: ttl
                            
                            	Match packets with given TTL value
                            	**type**\:  :py:class:`Ttl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Ttl>`
                            
                            .. attribute:: match_all
                            
                            	Match if all specified flags are present
                            	**type**\:  :py:class:`MatchAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.MatchAll>`
                            
                            .. attribute:: match_any
                            
                            	Match if any specified flags is present
                            	**type**\:  :py:class:`MatchAny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.MatchAny>`
                            
                            .. attribute:: ack
                            
                            	Match on the ACK bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: fin
                            
                            	Match on the FIN bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: psh
                            
                            	Match on the PSH bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rst
                            
                            	Match on the RST bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: syn
                            
                            	Match on the SYN bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: urg
                            
                            	Match on the URG bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: established
                            
                            	Match established connections
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: msg_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msg_code
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: named_msg_type
                            
                            	
                            	**type**\:  :py:class:`NamedMsgType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.NamedMsgType>`
                            
                            .. attribute:: src
                            
                            	Source port conditions
                            	**type**\:  :py:class:`Src <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Src>`
                            
                            .. attribute:: dst
                            
                            	Destination port conditions
                            	**type**\:  :py:class:`Dst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Dst>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule, self).__init__()

                                self.yang_name = "ace-rule"
                                self.yang_parent_name = "access-list-seq-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ttl", ("ttl", Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Ttl)), ("match-all", ("match_all", Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.MatchAll)), ("match-any", ("match_any", Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.MatchAny)), ("src", ("src", Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Src)), ("dst", ("dst", Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Dst))])
                                self._leafs = OrderedDict([
                                    ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Action')])),
                                    ('protocol', (YLeaf(YType.str, 'protocol'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Protocol')])),
                                    ('object_group_str', (YLeaf(YType.str, 'object-group-str'), ['str'])),
                                    ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                    ('fragments', (YLeaf(YType.empty, 'fragments'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ('log_input', (YLeaf(YType.empty, 'log-input'), ['Empty'])),
                                    ('option', (YLeaf(YType.str, 'option'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Option')])),
                                    ('precedence', (YLeaf(YType.str, 'precedence'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Precedence')])),
                                    ('time_range', (YLeaf(YType.str, 'time-range'), ['str'])),
                                    ('tos', (YLeaf(YType.str, 'tos'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Tos')])),
                                    ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                    ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                    ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                    ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                    ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                    ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                    ('established', (YLeaf(YType.empty, 'established'), ['Empty'])),
                                    ('msg_type', (YLeaf(YType.uint8, 'msg-type'), ['int'])),
                                    ('msg_code', (YLeaf(YType.uint8, 'msg-code'), ['int'])),
                                    ('named_msg_type', (YLeaf(YType.enumeration, 'named-msg-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.NamedMsgType')])),
                                ])
                                self.action = None
                                self.protocol = None
                                self.object_group_str = None
                                self.dscp = None
                                self.fragments = None
                                self.log = None
                                self.log_input = None
                                self.option = None
                                self.precedence = None
                                self.time_range = None
                                self.tos = None
                                self.ack = None
                                self.fin = None
                                self.psh = None
                                self.rst = None
                                self.syn = None
                                self.urg = None
                                self.established = None
                                self.msg_type = None
                                self.msg_code = None
                                self.named_msg_type = None

                                self.ttl = Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Ttl()
                                self.ttl.parent = self
                                self._children_name_map["ttl"] = "ttl"

                                self.match_all = Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.MatchAll()
                                self.match_all.parent = self
                                self._children_name_map["match_all"] = "match-all"

                                self.match_any = Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.MatchAny()
                                self.match_any.parent = self
                                self._children_name_map["match_any"] = "match-any"

                                self.src = Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Src()
                                self.src.parent = self
                                self._children_name_map["src"] = "src"

                                self.dst = Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Dst()
                                self.dst.parent = self
                                self._children_name_map["dst"] = "dst"
                                self._segment_path = lambda: "ace-rule"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule, ['action', 'protocol', 'object_group_str', 'dscp', 'fragments', 'log', 'log_input', 'option', 'precedence', 'time_range', 'tos', 'ack', 'fin', 'psh', 'rst', 'syn', 'urg', 'established', 'msg_type', 'msg_code', 'named_msg_type'], name, value)

                            class Action(Enum):
                                """
                                Action (Enum Class)

                                .. data:: deny = 0

                                .. data:: permit = 1

                                """

                                deny = Enum.YLeaf(0, "deny")

                                permit = Enum.YLeaf(1, "permit")


                            class NamedMsgType(Enum):
                                """
                                NamedMsgType (Enum Class)

                                .. data:: administratively_prohibited = 0

                                .. data:: alternate_address = 1

                                .. data:: conversion_error = 2

                                .. data:: dod_host_prohibited = 3

                                .. data:: dod_net_prohibited = 4

                                .. data:: echo = 5

                                .. data:: echo_reply = 6

                                .. data:: general_parameter_problem = 7

                                .. data:: host_isolated = 8

                                .. data:: host_precedence_unreachable = 9

                                .. data:: host_redirect = 10

                                .. data:: host_tos_redirect = 11

                                .. data:: host_tos_unreachable = 12

                                .. data:: host_unknown = 13

                                .. data:: host_unreachable = 14

                                .. data:: information_reply = 15

                                .. data:: information_request = 16

                                .. data:: mask_reply = 17

                                .. data:: mask_request = 18

                                .. data:: mobile_redirect = 19

                                .. data:: net_redirect = 20

                                .. data:: net_tos_redirect = 21

                                .. data:: net_tos_unreachable = 22

                                .. data:: net_unreachable = 23

                                .. data:: network_unknown = 24

                                .. data:: no_room_for_option = 25

                                .. data:: option_missing = 26

                                .. data:: packet_too_big = 27

                                .. data:: parameter_problem = 28

                                .. data:: port_unreachable = 29

                                .. data:: precedence_unreachable = 30

                                .. data:: protocol_unreachable = 31

                                .. data:: reassembly_timeout = 32

                                .. data:: redirect = 33

                                .. data:: router_advertisement = 34

                                .. data:: router_solicitation = 35

                                .. data:: source_quench = 36

                                .. data:: source_route_failed = 37

                                .. data:: time_exceeded = 38

                                .. data:: timestamp_reply = 39

                                .. data:: timestamp_request = 40

                                .. data:: traceroute = 41

                                .. data:: ttl_exceeded = 42

                                .. data:: unreachable = 43

                                """

                                administratively_prohibited = Enum.YLeaf(0, "administratively-prohibited")

                                alternate_address = Enum.YLeaf(1, "alternate-address")

                                conversion_error = Enum.YLeaf(2, "conversion-error")

                                dod_host_prohibited = Enum.YLeaf(3, "dod-host-prohibited")

                                dod_net_prohibited = Enum.YLeaf(4, "dod-net-prohibited")

                                echo = Enum.YLeaf(5, "echo")

                                echo_reply = Enum.YLeaf(6, "echo-reply")

                                general_parameter_problem = Enum.YLeaf(7, "general-parameter-problem")

                                host_isolated = Enum.YLeaf(8, "host-isolated")

                                host_precedence_unreachable = Enum.YLeaf(9, "host-precedence-unreachable")

                                host_redirect = Enum.YLeaf(10, "host-redirect")

                                host_tos_redirect = Enum.YLeaf(11, "host-tos-redirect")

                                host_tos_unreachable = Enum.YLeaf(12, "host-tos-unreachable")

                                host_unknown = Enum.YLeaf(13, "host-unknown")

                                host_unreachable = Enum.YLeaf(14, "host-unreachable")

                                information_reply = Enum.YLeaf(15, "information-reply")

                                information_request = Enum.YLeaf(16, "information-request")

                                mask_reply = Enum.YLeaf(17, "mask-reply")

                                mask_request = Enum.YLeaf(18, "mask-request")

                                mobile_redirect = Enum.YLeaf(19, "mobile-redirect")

                                net_redirect = Enum.YLeaf(20, "net-redirect")

                                net_tos_redirect = Enum.YLeaf(21, "net-tos-redirect")

                                net_tos_unreachable = Enum.YLeaf(22, "net-tos-unreachable")

                                net_unreachable = Enum.YLeaf(23, "net-unreachable")

                                network_unknown = Enum.YLeaf(24, "network-unknown")

                                no_room_for_option = Enum.YLeaf(25, "no-room-for-option")

                                option_missing = Enum.YLeaf(26, "option-missing")

                                packet_too_big = Enum.YLeaf(27, "packet-too-big")

                                parameter_problem = Enum.YLeaf(28, "parameter-problem")

                                port_unreachable = Enum.YLeaf(29, "port-unreachable")

                                precedence_unreachable = Enum.YLeaf(30, "precedence-unreachable")

                                protocol_unreachable = Enum.YLeaf(31, "protocol-unreachable")

                                reassembly_timeout = Enum.YLeaf(32, "reassembly-timeout")

                                redirect = Enum.YLeaf(33, "redirect")

                                router_advertisement = Enum.YLeaf(34, "router-advertisement")

                                router_solicitation = Enum.YLeaf(35, "router-solicitation")

                                source_quench = Enum.YLeaf(36, "source-quench")

                                source_route_failed = Enum.YLeaf(37, "source-route-failed")

                                time_exceeded = Enum.YLeaf(38, "time-exceeded")

                                timestamp_reply = Enum.YLeaf(39, "timestamp-reply")

                                timestamp_request = Enum.YLeaf(40, "timestamp-request")

                                traceroute = Enum.YLeaf(41, "traceroute")

                                ttl_exceeded = Enum.YLeaf(42, "ttl-exceeded")

                                unreachable = Enum.YLeaf(43, "unreachable")


                            class Option(Enum):
                                """
                                Option (Enum Class)

                                Match packets with given IP Options value

                                .. data:: add_ext = 0

                                .. data:: any_options = 1

                                .. data:: com_security = 2

                                .. data:: dps = 3

                                .. data:: encode = 4

                                .. data:: eool = 5

                                .. data:: ext_ip = 6

                                .. data:: ext_security = 7

                                .. data:: finn = 8

                                .. data:: imitd = 9

                                .. data:: lsr = 10

                                .. data:: mtup = 11

                                .. data:: mtur = 12

                                .. data:: no_op = 13

                                .. data:: nsapa = 14

                                .. data:: record_route = 15

                                .. data:: router_alert = 16

                                .. data:: sdb = 17

                                .. data:: security = 18

                                .. data:: ssr = 19

                                .. data:: stream_id = 20

                                .. data:: timestamp = 21

                                .. data:: traceroute = 22

                                .. data:: ump = 23

                                .. data:: visa = 24

                                .. data:: zsu = 25

                                """

                                add_ext = Enum.YLeaf(0, "add-ext")

                                any_options = Enum.YLeaf(1, "any-options")

                                com_security = Enum.YLeaf(2, "com-security")

                                dps = Enum.YLeaf(3, "dps")

                                encode = Enum.YLeaf(4, "encode")

                                eool = Enum.YLeaf(5, "eool")

                                ext_ip = Enum.YLeaf(6, "ext-ip")

                                ext_security = Enum.YLeaf(7, "ext-security")

                                finn = Enum.YLeaf(8, "finn")

                                imitd = Enum.YLeaf(9, "imitd")

                                lsr = Enum.YLeaf(10, "lsr")

                                mtup = Enum.YLeaf(11, "mtup")

                                mtur = Enum.YLeaf(12, "mtur")

                                no_op = Enum.YLeaf(13, "no-op")

                                nsapa = Enum.YLeaf(14, "nsapa")

                                record_route = Enum.YLeaf(15, "record-route")

                                router_alert = Enum.YLeaf(16, "router-alert")

                                sdb = Enum.YLeaf(17, "sdb")

                                security = Enum.YLeaf(18, "security")

                                ssr = Enum.YLeaf(19, "ssr")

                                stream_id = Enum.YLeaf(20, "stream-id")

                                timestamp = Enum.YLeaf(21, "timestamp")

                                traceroute = Enum.YLeaf(22, "traceroute")

                                ump = Enum.YLeaf(23, "ump")

                                visa = Enum.YLeaf(24, "visa")

                                zsu = Enum.YLeaf(25, "zsu")


                            class Precedence(Enum):
                                """
                                Precedence (Enum Class)

                                Match packets with given precedence value

                                .. data:: critical = 0

                                .. data:: flash = 1

                                .. data:: flash_override = 2

                                .. data:: immediate = 3

                                .. data:: internet = 4

                                .. data:: network = 5

                                .. data:: priority = 6

                                .. data:: routine = 7

                                """

                                critical = Enum.YLeaf(0, "critical")

                                flash = Enum.YLeaf(1, "flash")

                                flash_override = Enum.YLeaf(2, "flash-override")

                                immediate = Enum.YLeaf(3, "immediate")

                                internet = Enum.YLeaf(4, "internet")

                                network = Enum.YLeaf(5, "network")

                                priority = Enum.YLeaf(6, "priority")

                                routine = Enum.YLeaf(7, "routine")


                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: ahp = 0

                                .. data:: eigrp = 1

                                .. data:: esp = 2

                                .. data:: gre = 3

                                .. data:: icmp = 4

                                .. data:: igmp = 5

                                .. data:: ip = 6

                                .. data:: ipinip = 7

                                .. data:: nos = 8

                                .. data:: object_group = 9

                                .. data:: ospf = 10

                                .. data:: pcp = 11

                                .. data:: pim = 12

                                .. data:: tcp = 13

                                .. data:: udp = 14

                                """

                                ahp = Enum.YLeaf(0, "ahp")

                                eigrp = Enum.YLeaf(1, "eigrp")

                                esp = Enum.YLeaf(2, "esp")

                                gre = Enum.YLeaf(3, "gre")

                                icmp = Enum.YLeaf(4, "icmp")

                                igmp = Enum.YLeaf(5, "igmp")

                                ip = Enum.YLeaf(6, "ip")

                                ipinip = Enum.YLeaf(7, "ipinip")

                                nos = Enum.YLeaf(8, "nos")

                                object_group = Enum.YLeaf(9, "object-group")

                                ospf = Enum.YLeaf(10, "ospf")

                                pcp = Enum.YLeaf(11, "pcp")

                                pim = Enum.YLeaf(12, "pim")

                                tcp = Enum.YLeaf(13, "tcp")

                                udp = Enum.YLeaf(14, "udp")


                            class Tos(Enum):
                                """
                                Tos (Enum Class)

                                Match packets with given TOS value

                                .. data:: max_reliability = 0

                                .. data:: max_throughput = 1

                                .. data:: min_delay = 2

                                .. data:: min_monetary_cost = 3

                                .. data:: normal = 4

                                """

                                max_reliability = Enum.YLeaf(0, "max-reliability")

                                max_throughput = Enum.YLeaf(1, "max-throughput")

                                min_delay = Enum.YLeaf(2, "min-delay")

                                min_monetary_cost = Enum.YLeaf(3, "min-monetary-cost")

                                normal = Enum.YLeaf(4, "normal")



                            class Ttl(Entity):
                                """
                                Match packets with given TTL value
                                
                                .. attribute:: eq
                                
                                	Match only packets on a given TTL number
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: gt
                                
                                	Match only packets on a given TTL number
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: lt
                                
                                	Match only packets on a given TTL number
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neq
                                
                                	Match only packets on a given TTL number
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: range
                                
                                	Match only packets in the range of TTLs
                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Ttl.Range>`
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Ttl, self).__init__()

                                    self.yang_name = "ttl"
                                    self.yang_parent_name = "ace-rule"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Ttl.Range))])
                                    self._leafs = OrderedDict([
                                        ('eq', (YLeaf(YType.uint8, 'eq'), ['int'])),
                                        ('gt', (YLeaf(YType.uint8, 'gt'), ['int'])),
                                        ('lt', (YLeaf(YType.uint8, 'lt'), ['int'])),
                                        ('neq', (YLeaf(YType.uint8, 'neq'), ['int'])),
                                    ])
                                    self.eq = None
                                    self.gt = None
                                    self.lt = None
                                    self.neq = None

                                    self.range = Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Ttl.Range()
                                    self.range.parent = self
                                    self._children_name_map["range"] = "range"
                                    self._segment_path = lambda: "ttl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Ttl, ['eq', 'gt', 'lt', 'neq'], name, value)


                                class Range(Entity):
                                    """
                                    Match only packets in the range of TTLs
                                    
                                    .. attribute:: value1
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: value2
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-acl'
                                    _revision = '2018-05-31'

                                    def __init__(self):
                                        super(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Ttl.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "ttl"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('value1', (YLeaf(YType.uint8, 'value1'), ['int'])),
                                            ('value2', (YLeaf(YType.uint8, 'value2'), ['int'])),
                                        ])
                                        self.value1 = None
                                        self.value2 = None
                                        self._segment_path = lambda: "range"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Ttl.Range, ['value1', 'value2'], name, value)


                            class MatchAll(Entity):
                                """
                                Match if all specified flags are present
                                
                                .. attribute:: plusack
                                
                                	Match on ACK set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusfin
                                
                                	Match on FIN set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: pluspsh
                                
                                	Match on PSH set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusrst
                                
                                	Match on RST set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plussyn
                                
                                	Match on SYN set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusurg
                                
                                	Match on URG set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusack
                                
                                	Match on ACK not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusfin
                                
                                	Match on FIN not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minuspsh
                                
                                	Match on PSH not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusrst
                                
                                	Match on RST not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minussyn
                                
                                	Match on SYN not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusurg
                                
                                	Match on URG not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.MatchAll, self).__init__()

                                    self.yang_name = "match-all"
                                    self.yang_parent_name = "ace-rule"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('plusack', (YLeaf(YType.empty, 'plusack'), ['Empty'])),
                                        ('plusfin', (YLeaf(YType.empty, 'plusfin'), ['Empty'])),
                                        ('pluspsh', (YLeaf(YType.empty, 'pluspsh'), ['Empty'])),
                                        ('plusrst', (YLeaf(YType.empty, 'plusrst'), ['Empty'])),
                                        ('plussyn', (YLeaf(YType.empty, 'plussyn'), ['Empty'])),
                                        ('plusurg', (YLeaf(YType.empty, 'plusurg'), ['Empty'])),
                                        ('minusack', (YLeaf(YType.empty, 'minusack'), ['Empty'])),
                                        ('minusfin', (YLeaf(YType.empty, 'minusfin'), ['Empty'])),
                                        ('minuspsh', (YLeaf(YType.empty, 'minuspsh'), ['Empty'])),
                                        ('minusrst', (YLeaf(YType.empty, 'minusrst'), ['Empty'])),
                                        ('minussyn', (YLeaf(YType.empty, 'minussyn'), ['Empty'])),
                                        ('minusurg', (YLeaf(YType.empty, 'minusurg'), ['Empty'])),
                                    ])
                                    self.plusack = None
                                    self.plusfin = None
                                    self.pluspsh = None
                                    self.plusrst = None
                                    self.plussyn = None
                                    self.plusurg = None
                                    self.minusack = None
                                    self.minusfin = None
                                    self.minuspsh = None
                                    self.minusrst = None
                                    self.minussyn = None
                                    self.minusurg = None
                                    self._segment_path = lambda: "match-all"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.MatchAll, ['plusack', 'plusfin', 'pluspsh', 'plusrst', 'plussyn', 'plusurg', 'minusack', 'minusfin', 'minuspsh', 'minusrst', 'minussyn', 'minusurg'], name, value)


                            class MatchAny(Entity):
                                """
                                Match if any specified flags is present
                                
                                .. attribute:: plusack
                                
                                	Match on ACK set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusfin
                                
                                	Match on FIN set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: pluspsh
                                
                                	Match on PSH set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusrst
                                
                                	Match on RST set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plussyn
                                
                                	Match on SYN set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusurg
                                
                                	Match on URG set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusack
                                
                                	Match on ACK not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusfin
                                
                                	Match on FIN not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minuspsh
                                
                                	Match on PSH not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusrst
                                
                                	Match on RST not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minussyn
                                
                                	Match on SYN not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusurg
                                
                                	Match on URG not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.MatchAny, self).__init__()

                                    self.yang_name = "match-any"
                                    self.yang_parent_name = "ace-rule"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('plusack', (YLeaf(YType.empty, 'plusack'), ['Empty'])),
                                        ('plusfin', (YLeaf(YType.empty, 'plusfin'), ['Empty'])),
                                        ('pluspsh', (YLeaf(YType.empty, 'pluspsh'), ['Empty'])),
                                        ('plusrst', (YLeaf(YType.empty, 'plusrst'), ['Empty'])),
                                        ('plussyn', (YLeaf(YType.empty, 'plussyn'), ['Empty'])),
                                        ('plusurg', (YLeaf(YType.empty, 'plusurg'), ['Empty'])),
                                        ('minusack', (YLeaf(YType.empty, 'minusack'), ['Empty'])),
                                        ('minusfin', (YLeaf(YType.empty, 'minusfin'), ['Empty'])),
                                        ('minuspsh', (YLeaf(YType.empty, 'minuspsh'), ['Empty'])),
                                        ('minusrst', (YLeaf(YType.empty, 'minusrst'), ['Empty'])),
                                        ('minussyn', (YLeaf(YType.empty, 'minussyn'), ['Empty'])),
                                        ('minusurg', (YLeaf(YType.empty, 'minusurg'), ['Empty'])),
                                    ])
                                    self.plusack = None
                                    self.plusfin = None
                                    self.pluspsh = None
                                    self.plusrst = None
                                    self.plussyn = None
                                    self.plusurg = None
                                    self.minusack = None
                                    self.minusfin = None
                                    self.minuspsh = None
                                    self.minusrst = None
                                    self.minussyn = None
                                    self.minusurg = None
                                    self._segment_path = lambda: "match-any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.MatchAny, ['plusack', 'plusfin', 'pluspsh', 'plusrst', 'plussyn', 'plusurg', 'minusack', 'minusfin', 'minuspsh', 'minusrst', 'minussyn', 'minusurg'], name, value)


                            class Src(Entity):
                                """
                                Source port conditions
                                
                                .. attribute:: source_host
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                .. attribute:: source_address
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_wildcard_bits
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_prefix
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: any
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: src_eq
                                
                                	Match only packets on a given port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: src_gt
                                
                                	Match only packets with a greater port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: src_lt
                                
                                	Match only packets with a lower port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: src_neq
                                
                                	Match only packets not on a given port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: src_range1
                                
                                	Match only packets in the range of port numbers
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: src_range2
                                
                                	Match only packets in the range of port numbers
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: dst
                                
                                	Destination port conditions
                                	**type**\:  :py:class:`Dst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Src.Dst>`
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Src, self).__init__()

                                    self.yang_name = "src"
                                    self.yang_parent_name = "ace-rule"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dst", ("dst", Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Src.Dst))])
                                    self._leafs = OrderedDict([
                                        ('source_host', (YLeaf(YType.str, 'source-host'), ['str','str','str'])),
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                        ('source_wildcard_bits', (YLeaf(YType.str, 'source-wildcard-bits'), ['str'])),
                                        ('source_prefix', (YLeaf(YType.str, 'source-prefix'), ['str'])),
                                        ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                        ('src_eq', (YLeaf(YType.str, 'src-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('src_gt', (YLeaf(YType.str, 'src-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('src_lt', (YLeaf(YType.str, 'src-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('src_neq', (YLeaf(YType.str, 'src-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('src_range1', (YLeaf(YType.str, 'src-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('src_range2', (YLeaf(YType.str, 'src-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ])
                                    self.source_host = None
                                    self.source_address = None
                                    self.source_wildcard_bits = None
                                    self.source_prefix = None
                                    self.any = None
                                    self.src_eq = None
                                    self.src_gt = None
                                    self.src_lt = None
                                    self.src_neq = None
                                    self.src_range1 = None
                                    self.src_range2 = None

                                    self.dst = Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Src.Dst()
                                    self.dst.parent = self
                                    self._children_name_map["dst"] = "dst"
                                    self._segment_path = lambda: "src"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Src, ['source_host', 'source_address', 'source_wildcard_bits', 'source_prefix', 'any', 'src_eq', 'src_gt', 'src_lt', 'src_neq', 'src_range1', 'src_range2'], name, value)


                                class Dst(Entity):
                                    """
                                    Destination port conditions
                                    
                                    .. attribute:: destination_host
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                    
                                    .. attribute:: destination_address
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: destination_wildcard_bits
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: destination_prefix
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: destination_any
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dst_eq
                                    
                                    	Match only packets on a given port number
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..65535
                                    
                                    		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                    
                                    .. attribute:: dst_gt
                                    
                                    	Match only packets with a greater port number
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..65535
                                    
                                    		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                    
                                    .. attribute:: dst_lt
                                    
                                    	Match only packets with a lower port number
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..65535
                                    
                                    		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                    
                                    .. attribute:: dst_neq
                                    
                                    	Match only packets not on a given port number
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..65535
                                    
                                    		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                    
                                    .. attribute:: dst_range1
                                    
                                    	Match only packets in the range of port numbers
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..65535
                                    
                                    		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                    
                                    .. attribute:: dst_range2
                                    
                                    	Match only packets in the range of port numbers
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..65535
                                    
                                    		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-acl'
                                    _revision = '2018-05-31'

                                    def __init__(self):
                                        super(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Src.Dst, self).__init__()

                                        self.yang_name = "dst"
                                        self.yang_parent_name = "src"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('destination_host', (YLeaf(YType.str, 'destination-host'), ['str','str','str'])),
                                            ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str'])),
                                            ('destination_wildcard_bits', (YLeaf(YType.str, 'destination-wildcard-bits'), ['str'])),
                                            ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                            ('destination_any', (YLeaf(YType.empty, 'destination-any'), ['Empty'])),
                                            ('dst_eq', (YLeaf(YType.str, 'dst-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                            ('dst_gt', (YLeaf(YType.str, 'dst-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                            ('dst_lt', (YLeaf(YType.str, 'dst-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                            ('dst_neq', (YLeaf(YType.str, 'dst-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                            ('dst_range1', (YLeaf(YType.str, 'dst-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                            ('dst_range2', (YLeaf(YType.str, 'dst-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ])
                                        self.destination_host = None
                                        self.destination_address = None
                                        self.destination_wildcard_bits = None
                                        self.destination_prefix = None
                                        self.destination_any = None
                                        self.dst_eq = None
                                        self.dst_gt = None
                                        self.dst_lt = None
                                        self.dst_neq = None
                                        self.dst_range1 = None
                                        self.dst_range2 = None
                                        self._segment_path = lambda: "dst"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Src.Dst, ['destination_host', 'destination_address', 'destination_wildcard_bits', 'destination_prefix', 'destination_any', 'dst_eq', 'dst_gt', 'dst_lt', 'dst_neq', 'dst_range1', 'dst_range2'], name, value)


                            class Dst(Entity):
                                """
                                Destination port conditions
                                
                                .. attribute:: destination_host
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                .. attribute:: destination_address
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: destination_wildcard_bits
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: destination_prefix
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: destination_any
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: dst_eq
                                
                                	Match only packets on a given port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: dst_gt
                                
                                	Match only packets with a greater port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: dst_lt
                                
                                	Match only packets with a lower port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: dst_neq
                                
                                	Match only packets not on a given port number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: dst_range1
                                
                                	Match only packets in the range of port numbers
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                .. attribute:: dst_range2
                                
                                	Match only packets in the range of port numbers
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Dst, self).__init__()

                                    self.yang_name = "dst"
                                    self.yang_parent_name = "ace-rule"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('destination_host', (YLeaf(YType.str, 'destination-host'), ['str','str','str'])),
                                        ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str'])),
                                        ('destination_wildcard_bits', (YLeaf(YType.str, 'destination-wildcard-bits'), ['str'])),
                                        ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                        ('destination_any', (YLeaf(YType.empty, 'destination-any'), ['Empty'])),
                                        ('dst_eq', (YLeaf(YType.str, 'dst-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('dst_gt', (YLeaf(YType.str, 'dst-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('dst_lt', (YLeaf(YType.str, 'dst-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('dst_neq', (YLeaf(YType.str, 'dst-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('dst_range1', (YLeaf(YType.str, 'dst-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                        ('dst_range2', (YLeaf(YType.str, 'dst-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ])
                                    self.destination_host = None
                                    self.destination_address = None
                                    self.destination_wildcard_bits = None
                                    self.destination_prefix = None
                                    self.destination_any = None
                                    self.dst_eq = None
                                    self.dst_gt = None
                                    self.dst_lt = None
                                    self.dst_neq = None
                                    self.dst_range1 = None
                                    self.dst_range2 = None
                                    self._segment_path = lambda: "dst"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.RoleBased.Default.AccessListSeqRule.AceRule.Dst, ['destination_host', 'destination_address', 'destination_wildcard_bits', 'destination_prefix', 'destination_any', 'dst_eq', 'dst_gt', 'dst_lt', 'dst_neq', 'dst_range1', 'dst_range2'], name, value)


            class Extended(Entity):
                """
                Extended Access List
                
                .. attribute:: name  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 100..199
                
                		**type**\: int
                
                			**range:** 2000..2699
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: access_list_seq_rule
                
                	
                	**type**\: list of  		 :py:class:`AccessListSeqRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.AccessListSeqRule>`
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default>`
                
                

                """

                _prefix = 'ios-acl'
                _revision = '2018-05-31'

                def __init__(self):
                    super(Native.Ip.AccessList.Extended, self).__init__()

                    self.yang_name = "extended"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("access-list-seq-rule", ("access_list_seq_rule", Native.Ip.AccessList.Extended.AccessListSeqRule)), ("default", ("default", Native.Ip.AccessList.Extended.Default))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['int','int','str'])),
                    ])
                    self.name = None

                    self.default = Native.Ip.AccessList.Extended.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.access_list_seq_rule = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-acl:extended" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/access-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.AccessList.Extended, ['name'], name, value)


                class AccessListSeqRule(Entity):
                    """
                    
                    
                    .. attribute:: sequence  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: ace_rule
                    
                    	
                    	**type**\:  :py:class:`AceRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule>`
                    
                    .. attribute:: remark
                    
                    	Access list entry comment
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    

                    """

                    _prefix = 'ios-acl'
                    _revision = '2018-05-31'

                    def __init__(self):
                        super(Native.Ip.AccessList.Extended.AccessListSeqRule, self).__init__()

                        self.yang_name = "access-list-seq-rule"
                        self.yang_parent_name = "extended"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['sequence']
                        self._child_classes = OrderedDict([("ace-rule", ("ace_rule", Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule))])
                        self._leafs = OrderedDict([
                            ('sequence', (YLeaf(YType.uint64, 'sequence'), ['int'])),
                            ('remark', (YLeaf(YType.str, 'remark'), ['str'])),
                        ])
                        self.sequence = None
                        self.remark = None

                        self.ace_rule = Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule()
                        self.ace_rule.parent = self
                        self._children_name_map["ace_rule"] = "ace-rule"
                        self._segment_path = lambda: "access-list-seq-rule" + "[sequence='" + str(self.sequence) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.AccessList.Extended.AccessListSeqRule, ['sequence', 'remark'], name, value)


                    class AceRule(Entity):
                        """
                        
                        
                        .. attribute:: action
                        
                        	
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.Action>`
                        
                        .. attribute:: protocol
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..255
                        
                        		**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Protocol>`
                        
                        .. attribute:: object_group_str
                        
                        	Service object group name
                        	**type**\: str
                        
                        .. attribute:: ipv4_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: any
                        
                        	Any source host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: host
                        
                        	A single source host
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: object_group
                        
                        	Source network object group
                        	**type**\: str
                        
                        .. attribute:: src_eq
                        
                        	Match only packets on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_gt
                        
                        	Match only packets with a greater port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_lt
                        
                        	Match only packets with a lower port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_neq
                        
                        	Match only packets not on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_range1
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_range2
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dest_ipv4_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: dest_mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: dst_any
                        
                        	Any destination host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dst_host
                        
                        	A single destination host
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: dst_object_group
                        
                        	Destination network object group
                        	**type**\: str
                        
                        .. attribute:: dst_eq
                        
                        	Match only packets on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_gt
                        
                        	Match only packets with a greater port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_lt
                        
                        	Match only packets with a lower port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_neq
                        
                        	Match only packets not on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_range1
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_range2
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dscp
                        
                        	Match packets with given dscp value
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..63
                        
                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                        
                        .. attribute:: fragments
                        
                        	Check non\-initial fragments
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: log
                        
                        	Log matches against this entry
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: log_input
                        
                        	Log matches against this entry, including input interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: option
                        
                        	Match packets with given IP Options value
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..255
                        
                        		**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Option>`
                        
                        .. attribute:: precedence
                        
                        	Match packets with given precedence value
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..7
                        
                        		**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Precedence>`
                        
                        .. attribute:: time_range
                        
                        	Specify a time\-range
                        	**type**\: str
                        
                        .. attribute:: tos
                        
                        	Match packets with given TOS value
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..15
                        
                        		**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Tos>`
                        
                        .. attribute:: ttl
                        
                        	Match packets with given TTL value
                        	**type**\:  :py:class:`Ttl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.Ttl>`
                        
                        .. attribute:: match_all
                        
                        	Match if all specified flags are present
                        	**type**\:  :py:class:`MatchAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.MatchAll>`
                        
                        .. attribute:: match_any
                        
                        	Match if any specified flags is present
                        	**type**\:  :py:class:`MatchAny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.MatchAny>`
                        
                        .. attribute:: ack
                        
                        	Match on the ACK bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fin
                        
                        	Match on the FIN bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: psh
                        
                        	Match on the PSH bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rst
                        
                        	Match on the RST bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: syn
                        
                        	Match on the SYN bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: urg
                        
                        	Match on the URG bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: established
                        
                        	Match established connections
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: msg_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: msg_code
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: named_msg_type
                        
                        	
                        	**type**\:  :py:class:`NamedMsgType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.NamedMsgType>`
                        
                        

                        """

                        _prefix = 'ios-acl'
                        _revision = '2018-05-31'

                        def __init__(self):
                            super(Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule, self).__init__()

                            self.yang_name = "ace-rule"
                            self.yang_parent_name = "access-list-seq-rule"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ttl", ("ttl", Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.Ttl)), ("match-all", ("match_all", Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.MatchAll)), ("match-any", ("match_any", Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.MatchAny))])
                            self._leafs = OrderedDict([
                                ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.AccessListSeqRule.AceRule.Action')])),
                                ('protocol', (YLeaf(YType.str, 'protocol'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Protocol')])),
                                ('object_group_str', (YLeaf(YType.str, 'object-group-str'), ['str'])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                ('host', (YLeaf(YType.str, 'host'), ['str','str'])),
                                ('object_group', (YLeaf(YType.str, 'object-group'), ['str'])),
                                ('src_eq', (YLeaf(YType.str, 'src-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_gt', (YLeaf(YType.str, 'src-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_lt', (YLeaf(YType.str, 'src-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_neq', (YLeaf(YType.str, 'src-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_range1', (YLeaf(YType.str, 'src-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_range2', (YLeaf(YType.str, 'src-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dest_ipv4_address', (YLeaf(YType.str, 'dest-ipv4-address'), ['str'])),
                                ('dest_mask', (YLeaf(YType.str, 'dest-mask'), ['str'])),
                                ('dst_any', (YLeaf(YType.empty, 'dst-any'), ['Empty'])),
                                ('dst_host', (YLeaf(YType.str, 'dst-host'), ['str','str'])),
                                ('dst_object_group', (YLeaf(YType.str, 'dst-object-group'), ['str'])),
                                ('dst_eq', (YLeaf(YType.str, 'dst-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_gt', (YLeaf(YType.str, 'dst-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_lt', (YLeaf(YType.str, 'dst-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_neq', (YLeaf(YType.str, 'dst-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_range1', (YLeaf(YType.str, 'dst-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_range2', (YLeaf(YType.str, 'dst-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                ('fragments', (YLeaf(YType.empty, 'fragments'), ['Empty'])),
                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ('log_input', (YLeaf(YType.empty, 'log-input'), ['Empty'])),
                                ('option', (YLeaf(YType.str, 'option'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Option')])),
                                ('precedence', (YLeaf(YType.str, 'precedence'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Precedence')])),
                                ('time_range', (YLeaf(YType.str, 'time-range'), ['str'])),
                                ('tos', (YLeaf(YType.str, 'tos'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Tos')])),
                                ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                ('established', (YLeaf(YType.empty, 'established'), ['Empty'])),
                                ('msg_type', (YLeaf(YType.uint8, 'msg-type'), ['int'])),
                                ('msg_code', (YLeaf(YType.uint8, 'msg-code'), ['int'])),
                                ('named_msg_type', (YLeaf(YType.enumeration, 'named-msg-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.AccessListSeqRule.AceRule.NamedMsgType')])),
                            ])
                            self.action = None
                            self.protocol = None
                            self.object_group_str = None
                            self.ipv4_address = None
                            self.mask = None
                            self.any = None
                            self.host = None
                            self.object_group = None
                            self.src_eq = None
                            self.src_gt = None
                            self.src_lt = None
                            self.src_neq = None
                            self.src_range1 = None
                            self.src_range2 = None
                            self.dest_ipv4_address = None
                            self.dest_mask = None
                            self.dst_any = None
                            self.dst_host = None
                            self.dst_object_group = None
                            self.dst_eq = None
                            self.dst_gt = None
                            self.dst_lt = None
                            self.dst_neq = None
                            self.dst_range1 = None
                            self.dst_range2 = None
                            self.dscp = None
                            self.fragments = None
                            self.log = None
                            self.log_input = None
                            self.option = None
                            self.precedence = None
                            self.time_range = None
                            self.tos = None
                            self.ack = None
                            self.fin = None
                            self.psh = None
                            self.rst = None
                            self.syn = None
                            self.urg = None
                            self.established = None
                            self.msg_type = None
                            self.msg_code = None
                            self.named_msg_type = None

                            self.ttl = Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.Ttl()
                            self.ttl.parent = self
                            self._children_name_map["ttl"] = "ttl"

                            self.match_all = Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.MatchAll()
                            self.match_all.parent = self
                            self._children_name_map["match_all"] = "match-all"

                            self.match_any = Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.MatchAny()
                            self.match_any.parent = self
                            self._children_name_map["match_any"] = "match-any"
                            self._segment_path = lambda: "ace-rule"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule, ['action', 'protocol', 'object_group_str', 'ipv4_address', 'mask', 'any', 'host', 'object_group', 'src_eq', 'src_gt', 'src_lt', 'src_neq', 'src_range1', 'src_range2', 'dest_ipv4_address', 'dest_mask', 'dst_any', 'dst_host', 'dst_object_group', 'dst_eq', 'dst_gt', 'dst_lt', 'dst_neq', 'dst_range1', 'dst_range2', 'dscp', 'fragments', 'log', 'log_input', 'option', 'precedence', 'time_range', 'tos', 'ack', 'fin', 'psh', 'rst', 'syn', 'urg', 'established', 'msg_type', 'msg_code', 'named_msg_type'], name, value)

                        class Action(Enum):
                            """
                            Action (Enum Class)

                            .. data:: deny = 0

                            .. data:: permit = 1

                            """

                            deny = Enum.YLeaf(0, "deny")

                            permit = Enum.YLeaf(1, "permit")


                        class NamedMsgType(Enum):
                            """
                            NamedMsgType (Enum Class)

                            .. data:: administratively_prohibited = 0

                            .. data:: alternate_address = 1

                            .. data:: conversion_error = 2

                            .. data:: dod_host_prohibited = 3

                            .. data:: dod_net_prohibited = 4

                            .. data:: echo = 5

                            .. data:: echo_reply = 6

                            .. data:: general_parameter_problem = 7

                            .. data:: host_isolated = 8

                            .. data:: host_precedence_unreachable = 9

                            .. data:: host_redirect = 10

                            .. data:: host_tos_redirect = 11

                            .. data:: host_tos_unreachable = 12

                            .. data:: host_unknown = 13

                            .. data:: host_unreachable = 14

                            .. data:: information_reply = 15

                            .. data:: information_request = 16

                            .. data:: mask_reply = 17

                            .. data:: mask_request = 18

                            .. data:: mobile_redirect = 19

                            .. data:: net_redirect = 20

                            .. data:: net_tos_redirect = 21

                            .. data:: net_tos_unreachable = 22

                            .. data:: net_unreachable = 23

                            .. data:: network_unknown = 24

                            .. data:: no_room_for_option = 25

                            .. data:: option_missing = 26

                            .. data:: packet_too_big = 27

                            .. data:: parameter_problem = 28

                            .. data:: port_unreachable = 29

                            .. data:: precedence_unreachable = 30

                            .. data:: protocol_unreachable = 31

                            .. data:: reassembly_timeout = 32

                            .. data:: redirect = 33

                            .. data:: router_advertisement = 34

                            .. data:: router_solicitation = 35

                            .. data:: source_quench = 36

                            .. data:: source_route_failed = 37

                            .. data:: time_exceeded = 38

                            .. data:: timestamp_reply = 39

                            .. data:: timestamp_request = 40

                            .. data:: traceroute = 41

                            .. data:: ttl_exceeded = 42

                            .. data:: unreachable = 43

                            """

                            administratively_prohibited = Enum.YLeaf(0, "administratively-prohibited")

                            alternate_address = Enum.YLeaf(1, "alternate-address")

                            conversion_error = Enum.YLeaf(2, "conversion-error")

                            dod_host_prohibited = Enum.YLeaf(3, "dod-host-prohibited")

                            dod_net_prohibited = Enum.YLeaf(4, "dod-net-prohibited")

                            echo = Enum.YLeaf(5, "echo")

                            echo_reply = Enum.YLeaf(6, "echo-reply")

                            general_parameter_problem = Enum.YLeaf(7, "general-parameter-problem")

                            host_isolated = Enum.YLeaf(8, "host-isolated")

                            host_precedence_unreachable = Enum.YLeaf(9, "host-precedence-unreachable")

                            host_redirect = Enum.YLeaf(10, "host-redirect")

                            host_tos_redirect = Enum.YLeaf(11, "host-tos-redirect")

                            host_tos_unreachable = Enum.YLeaf(12, "host-tos-unreachable")

                            host_unknown = Enum.YLeaf(13, "host-unknown")

                            host_unreachable = Enum.YLeaf(14, "host-unreachable")

                            information_reply = Enum.YLeaf(15, "information-reply")

                            information_request = Enum.YLeaf(16, "information-request")

                            mask_reply = Enum.YLeaf(17, "mask-reply")

                            mask_request = Enum.YLeaf(18, "mask-request")

                            mobile_redirect = Enum.YLeaf(19, "mobile-redirect")

                            net_redirect = Enum.YLeaf(20, "net-redirect")

                            net_tos_redirect = Enum.YLeaf(21, "net-tos-redirect")

                            net_tos_unreachable = Enum.YLeaf(22, "net-tos-unreachable")

                            net_unreachable = Enum.YLeaf(23, "net-unreachable")

                            network_unknown = Enum.YLeaf(24, "network-unknown")

                            no_room_for_option = Enum.YLeaf(25, "no-room-for-option")

                            option_missing = Enum.YLeaf(26, "option-missing")

                            packet_too_big = Enum.YLeaf(27, "packet-too-big")

                            parameter_problem = Enum.YLeaf(28, "parameter-problem")

                            port_unreachable = Enum.YLeaf(29, "port-unreachable")

                            precedence_unreachable = Enum.YLeaf(30, "precedence-unreachable")

                            protocol_unreachable = Enum.YLeaf(31, "protocol-unreachable")

                            reassembly_timeout = Enum.YLeaf(32, "reassembly-timeout")

                            redirect = Enum.YLeaf(33, "redirect")

                            router_advertisement = Enum.YLeaf(34, "router-advertisement")

                            router_solicitation = Enum.YLeaf(35, "router-solicitation")

                            source_quench = Enum.YLeaf(36, "source-quench")

                            source_route_failed = Enum.YLeaf(37, "source-route-failed")

                            time_exceeded = Enum.YLeaf(38, "time-exceeded")

                            timestamp_reply = Enum.YLeaf(39, "timestamp-reply")

                            timestamp_request = Enum.YLeaf(40, "timestamp-request")

                            traceroute = Enum.YLeaf(41, "traceroute")

                            ttl_exceeded = Enum.YLeaf(42, "ttl-exceeded")

                            unreachable = Enum.YLeaf(43, "unreachable")


                        class Option(Enum):
                            """
                            Option (Enum Class)

                            Match packets with given IP Options value

                            .. data:: add_ext = 0

                            .. data:: any_options = 1

                            .. data:: com_security = 2

                            .. data:: dps = 3

                            .. data:: encode = 4

                            .. data:: eool = 5

                            .. data:: ext_ip = 6

                            .. data:: ext_security = 7

                            .. data:: finn = 8

                            .. data:: imitd = 9

                            .. data:: lsr = 10

                            .. data:: mtup = 11

                            .. data:: mtur = 12

                            .. data:: no_op = 13

                            .. data:: nsapa = 14

                            .. data:: record_route = 15

                            .. data:: router_alert = 16

                            .. data:: sdb = 17

                            .. data:: security = 18

                            .. data:: ssr = 19

                            .. data:: stream_id = 20

                            .. data:: timestamp = 21

                            .. data:: traceroute = 22

                            .. data:: ump = 23

                            .. data:: visa = 24

                            .. data:: zsu = 25

                            """

                            add_ext = Enum.YLeaf(0, "add-ext")

                            any_options = Enum.YLeaf(1, "any-options")

                            com_security = Enum.YLeaf(2, "com-security")

                            dps = Enum.YLeaf(3, "dps")

                            encode = Enum.YLeaf(4, "encode")

                            eool = Enum.YLeaf(5, "eool")

                            ext_ip = Enum.YLeaf(6, "ext-ip")

                            ext_security = Enum.YLeaf(7, "ext-security")

                            finn = Enum.YLeaf(8, "finn")

                            imitd = Enum.YLeaf(9, "imitd")

                            lsr = Enum.YLeaf(10, "lsr")

                            mtup = Enum.YLeaf(11, "mtup")

                            mtur = Enum.YLeaf(12, "mtur")

                            no_op = Enum.YLeaf(13, "no-op")

                            nsapa = Enum.YLeaf(14, "nsapa")

                            record_route = Enum.YLeaf(15, "record-route")

                            router_alert = Enum.YLeaf(16, "router-alert")

                            sdb = Enum.YLeaf(17, "sdb")

                            security = Enum.YLeaf(18, "security")

                            ssr = Enum.YLeaf(19, "ssr")

                            stream_id = Enum.YLeaf(20, "stream-id")

                            timestamp = Enum.YLeaf(21, "timestamp")

                            traceroute = Enum.YLeaf(22, "traceroute")

                            ump = Enum.YLeaf(23, "ump")

                            visa = Enum.YLeaf(24, "visa")

                            zsu = Enum.YLeaf(25, "zsu")


                        class Precedence(Enum):
                            """
                            Precedence (Enum Class)

                            Match packets with given precedence value

                            .. data:: critical = 0

                            .. data:: flash = 1

                            .. data:: flash_override = 2

                            .. data:: immediate = 3

                            .. data:: internet = 4

                            .. data:: network = 5

                            .. data:: priority = 6

                            .. data:: routine = 7

                            """

                            critical = Enum.YLeaf(0, "critical")

                            flash = Enum.YLeaf(1, "flash")

                            flash_override = Enum.YLeaf(2, "flash-override")

                            immediate = Enum.YLeaf(3, "immediate")

                            internet = Enum.YLeaf(4, "internet")

                            network = Enum.YLeaf(5, "network")

                            priority = Enum.YLeaf(6, "priority")

                            routine = Enum.YLeaf(7, "routine")


                        class Protocol(Enum):
                            """
                            Protocol (Enum Class)

                            .. data:: ahp = 0

                            .. data:: eigrp = 1

                            .. data:: esp = 2

                            .. data:: gre = 3

                            .. data:: icmp = 4

                            .. data:: igmp = 5

                            .. data:: ip = 6

                            .. data:: ipinip = 7

                            .. data:: nos = 8

                            .. data:: object_group = 9

                            .. data:: ospf = 10

                            .. data:: pcp = 11

                            .. data:: pim = 12

                            .. data:: tcp = 13

                            .. data:: udp = 14

                            """

                            ahp = Enum.YLeaf(0, "ahp")

                            eigrp = Enum.YLeaf(1, "eigrp")

                            esp = Enum.YLeaf(2, "esp")

                            gre = Enum.YLeaf(3, "gre")

                            icmp = Enum.YLeaf(4, "icmp")

                            igmp = Enum.YLeaf(5, "igmp")

                            ip = Enum.YLeaf(6, "ip")

                            ipinip = Enum.YLeaf(7, "ipinip")

                            nos = Enum.YLeaf(8, "nos")

                            object_group = Enum.YLeaf(9, "object-group")

                            ospf = Enum.YLeaf(10, "ospf")

                            pcp = Enum.YLeaf(11, "pcp")

                            pim = Enum.YLeaf(12, "pim")

                            tcp = Enum.YLeaf(13, "tcp")

                            udp = Enum.YLeaf(14, "udp")


                        class Tos(Enum):
                            """
                            Tos (Enum Class)

                            Match packets with given TOS value

                            .. data:: max_reliability = 0

                            .. data:: max_throughput = 1

                            .. data:: min_delay = 2

                            .. data:: min_monetary_cost = 3

                            .. data:: normal = 4

                            """

                            max_reliability = Enum.YLeaf(0, "max-reliability")

                            max_throughput = Enum.YLeaf(1, "max-throughput")

                            min_delay = Enum.YLeaf(2, "min-delay")

                            min_monetary_cost = Enum.YLeaf(3, "min-monetary-cost")

                            normal = Enum.YLeaf(4, "normal")



                        class Ttl(Entity):
                            """
                            Match packets with given TTL value
                            
                            .. attribute:: eq
                            
                            	Match only packets on a given TTL number
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: gt
                            
                            	Match only packets on a given TTL number
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: lt
                            
                            	Match only packets on a given TTL number
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neq
                            
                            	Match only packets on a given TTL number
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: range
                            
                            	Match only packets in the range of TTLs
                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.Ttl.Range>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.Ttl, self).__init__()

                                self.yang_name = "ttl"
                                self.yang_parent_name = "ace-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("range", ("range", Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.Ttl.Range))])
                                self._leafs = OrderedDict([
                                    ('eq', (YLeaf(YType.uint8, 'eq'), ['int'])),
                                    ('gt', (YLeaf(YType.uint8, 'gt'), ['int'])),
                                    ('lt', (YLeaf(YType.uint8, 'lt'), ['int'])),
                                    ('neq', (YLeaf(YType.uint8, 'neq'), ['int'])),
                                ])
                                self.eq = None
                                self.gt = None
                                self.lt = None
                                self.neq = None

                                self.range = Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.Ttl.Range()
                                self.range.parent = self
                                self._children_name_map["range"] = "range"
                                self._segment_path = lambda: "ttl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.Ttl, ['eq', 'gt', 'lt', 'neq'], name, value)


                            class Range(Entity):
                                """
                                Match only packets in the range of TTLs
                                
                                .. attribute:: value1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: value2
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.Ttl.Range, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "ttl"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('value1', (YLeaf(YType.uint8, 'value1'), ['int'])),
                                        ('value2', (YLeaf(YType.uint8, 'value2'), ['int'])),
                                    ])
                                    self.value1 = None
                                    self.value2 = None
                                    self._segment_path = lambda: "range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.Ttl.Range, ['value1', 'value2'], name, value)


                        class MatchAll(Entity):
                            """
                            Match if all specified flags are present
                            
                            .. attribute:: plusack
                            
                            	Match on ACK set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusfin
                            
                            	Match on FIN set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: pluspsh
                            
                            	Match on PSH set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusrst
                            
                            	Match on RST set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plussyn
                            
                            	Match on SYN set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusurg
                            
                            	Match on URG set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusack
                            
                            	Match on ACK not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusfin
                            
                            	Match on FIN not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minuspsh
                            
                            	Match on PSH not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusrst
                            
                            	Match on RST not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minussyn
                            
                            	Match on SYN not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusurg
                            
                            	Match on URG not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.MatchAll, self).__init__()

                                self.yang_name = "match-all"
                                self.yang_parent_name = "ace-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('plusack', (YLeaf(YType.empty, 'plusack'), ['Empty'])),
                                    ('plusfin', (YLeaf(YType.empty, 'plusfin'), ['Empty'])),
                                    ('pluspsh', (YLeaf(YType.empty, 'pluspsh'), ['Empty'])),
                                    ('plusrst', (YLeaf(YType.empty, 'plusrst'), ['Empty'])),
                                    ('plussyn', (YLeaf(YType.empty, 'plussyn'), ['Empty'])),
                                    ('plusurg', (YLeaf(YType.empty, 'plusurg'), ['Empty'])),
                                    ('minusack', (YLeaf(YType.empty, 'minusack'), ['Empty'])),
                                    ('minusfin', (YLeaf(YType.empty, 'minusfin'), ['Empty'])),
                                    ('minuspsh', (YLeaf(YType.empty, 'minuspsh'), ['Empty'])),
                                    ('minusrst', (YLeaf(YType.empty, 'minusrst'), ['Empty'])),
                                    ('minussyn', (YLeaf(YType.empty, 'minussyn'), ['Empty'])),
                                    ('minusurg', (YLeaf(YType.empty, 'minusurg'), ['Empty'])),
                                ])
                                self.plusack = None
                                self.plusfin = None
                                self.pluspsh = None
                                self.plusrst = None
                                self.plussyn = None
                                self.plusurg = None
                                self.minusack = None
                                self.minusfin = None
                                self.minuspsh = None
                                self.minusrst = None
                                self.minussyn = None
                                self.minusurg = None
                                self._segment_path = lambda: "match-all"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.MatchAll, ['plusack', 'plusfin', 'pluspsh', 'plusrst', 'plussyn', 'plusurg', 'minusack', 'minusfin', 'minuspsh', 'minusrst', 'minussyn', 'minusurg'], name, value)


                        class MatchAny(Entity):
                            """
                            Match if any specified flags is present
                            
                            .. attribute:: plusack
                            
                            	Match on ACK set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusfin
                            
                            	Match on FIN set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: pluspsh
                            
                            	Match on PSH set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusrst
                            
                            	Match on RST set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plussyn
                            
                            	Match on SYN set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: plusurg
                            
                            	Match on URG set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusack
                            
                            	Match on ACK not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusfin
                            
                            	Match on FIN not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minuspsh
                            
                            	Match on PSH not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusrst
                            
                            	Match on RST not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minussyn
                            
                            	Match on SYN not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: minusurg
                            
                            	Match on URG not set
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.MatchAny, self).__init__()

                                self.yang_name = "match-any"
                                self.yang_parent_name = "ace-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('plusack', (YLeaf(YType.empty, 'plusack'), ['Empty'])),
                                    ('plusfin', (YLeaf(YType.empty, 'plusfin'), ['Empty'])),
                                    ('pluspsh', (YLeaf(YType.empty, 'pluspsh'), ['Empty'])),
                                    ('plusrst', (YLeaf(YType.empty, 'plusrst'), ['Empty'])),
                                    ('plussyn', (YLeaf(YType.empty, 'plussyn'), ['Empty'])),
                                    ('plusurg', (YLeaf(YType.empty, 'plusurg'), ['Empty'])),
                                    ('minusack', (YLeaf(YType.empty, 'minusack'), ['Empty'])),
                                    ('minusfin', (YLeaf(YType.empty, 'minusfin'), ['Empty'])),
                                    ('minuspsh', (YLeaf(YType.empty, 'minuspsh'), ['Empty'])),
                                    ('minusrst', (YLeaf(YType.empty, 'minusrst'), ['Empty'])),
                                    ('minussyn', (YLeaf(YType.empty, 'minussyn'), ['Empty'])),
                                    ('minusurg', (YLeaf(YType.empty, 'minusurg'), ['Empty'])),
                                ])
                                self.plusack = None
                                self.plusfin = None
                                self.pluspsh = None
                                self.plusrst = None
                                self.plussyn = None
                                self.plusurg = None
                                self.minusack = None
                                self.minusfin = None
                                self.minuspsh = None
                                self.minusrst = None
                                self.minussyn = None
                                self.minusurg = None
                                self._segment_path = lambda: "match-any"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.Extended.AccessListSeqRule.AceRule.MatchAny, ['plusack', 'plusfin', 'pluspsh', 'plusrst', 'plussyn', 'plusurg', 'minusack', 'minusfin', 'minuspsh', 'minusrst', 'minussyn', 'minusurg'], name, value)


                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: access_list_seq_rule
                    
                    	
                    	**type**\: list of  		 :py:class:`AccessListSeqRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule>`
                    
                    

                    """

                    _prefix = 'ios-acl'
                    _revision = '2018-05-31'

                    def __init__(self):
                        super(Native.Ip.AccessList.Extended.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "extended"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-list-seq-rule", ("access_list_seq_rule", Native.Ip.AccessList.Extended.Default.AccessListSeqRule))])
                        self._leafs = OrderedDict()

                        self.access_list_seq_rule = YList(self)
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.AccessList.Extended.Default, [], name, value)


                    class AccessListSeqRule(Entity):
                        """
                        
                        
                        .. attribute:: sequence  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..2147483647
                        
                        .. attribute:: ace_rule
                        
                        	
                        	**type**\:  :py:class:`AceRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule>`
                        
                        .. attribute:: remark
                        
                        	Access list entry comment
                        	**type**\: str
                        
                        	**length:** 1..100
                        
                        

                        """

                        _prefix = 'ios-acl'
                        _revision = '2018-05-31'

                        def __init__(self):
                            super(Native.Ip.AccessList.Extended.Default.AccessListSeqRule, self).__init__()

                            self.yang_name = "access-list-seq-rule"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['sequence']
                            self._child_classes = OrderedDict([("ace-rule", ("ace_rule", Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule))])
                            self._leafs = OrderedDict([
                                ('sequence', (YLeaf(YType.uint64, 'sequence'), ['int'])),
                                ('remark', (YLeaf(YType.str, 'remark'), ['str'])),
                            ])
                            self.sequence = None
                            self.remark = None

                            self.ace_rule = Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule()
                            self.ace_rule.parent = self
                            self._children_name_map["ace_rule"] = "ace-rule"
                            self._segment_path = lambda: "access-list-seq-rule" + "[sequence='" + str(self.sequence) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.AccessList.Extended.Default.AccessListSeqRule, ['sequence', 'remark'], name, value)


                        class AceRule(Entity):
                            """
                            
                            
                            .. attribute:: action
                            
                            	
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Action>`
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..255
                            
                            		**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Protocol>`
                            
                            .. attribute:: object_group_str
                            
                            	Service object group name
                            	**type**\: str
                            
                            .. attribute:: ipv4_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**mandatory**\: True
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**mandatory**\: True
                            
                            .. attribute:: any
                            
                            	Any source host
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: host
                            
                            	A single source host
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: object_group
                            
                            	Source network object group
                            	**type**\: str
                            
                            .. attribute:: src_eq
                            
                            	Match only packets on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_gt
                            
                            	Match only packets with a greater port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_lt
                            
                            	Match only packets with a lower port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_neq
                            
                            	Match only packets not on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_range1
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_range2
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dest_ipv4_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**mandatory**\: True
                            
                            .. attribute:: dest_mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**mandatory**\: True
                            
                            .. attribute:: dst_any
                            
                            	Any destination host
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dst_host
                            
                            	A single destination host
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: dst_object_group
                            
                            	Destination network object group
                            	**type**\: str
                            
                            .. attribute:: dst_eq
                            
                            	Match only packets on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_gt
                            
                            	Match only packets with a greater port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_lt
                            
                            	Match only packets with a lower port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_neq
                            
                            	Match only packets not on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_range1
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_range2
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dscp
                            
                            	Match packets with given dscp value
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..63
                            
                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                            
                            .. attribute:: fragments
                            
                            	Check non\-initial fragments
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log matches against this entry
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log_input
                            
                            	Log matches against this entry, including input interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: option
                            
                            	Match packets with given IP Options value
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..255
                            
                            		**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Option>`
                            
                            .. attribute:: precedence
                            
                            	Match packets with given precedence value
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..7
                            
                            		**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Precedence>`
                            
                            .. attribute:: time_range
                            
                            	Specify a time\-range
                            	**type**\: str
                            
                            .. attribute:: tos
                            
                            	Match packets with given TOS value
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..15
                            
                            		**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Tos>`
                            
                            .. attribute:: ttl
                            
                            	Match packets with given TTL value
                            	**type**\:  :py:class:`Ttl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Ttl>`
                            
                            .. attribute:: match_all
                            
                            	Match if all specified flags are present
                            	**type**\:  :py:class:`MatchAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.MatchAll>`
                            
                            .. attribute:: match_any
                            
                            	Match if any specified flags is present
                            	**type**\:  :py:class:`MatchAny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.MatchAny>`
                            
                            .. attribute:: ack
                            
                            	Match on the ACK bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: fin
                            
                            	Match on the FIN bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: psh
                            
                            	Match on the PSH bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rst
                            
                            	Match on the RST bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: syn
                            
                            	Match on the SYN bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: urg
                            
                            	Match on the URG bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: established
                            
                            	Match established connections
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: msg_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msg_code
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: named_msg_type
                            
                            	
                            	**type**\:  :py:class:`NamedMsgType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.NamedMsgType>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule, self).__init__()

                                self.yang_name = "ace-rule"
                                self.yang_parent_name = "access-list-seq-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ttl", ("ttl", Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Ttl)), ("match-all", ("match_all", Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.MatchAll)), ("match-any", ("match_any", Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.MatchAny))])
                                self._leafs = OrderedDict([
                                    ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Action')])),
                                    ('protocol', (YLeaf(YType.str, 'protocol'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Protocol')])),
                                    ('object_group_str', (YLeaf(YType.str, 'object-group-str'), ['str'])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                    ('host', (YLeaf(YType.str, 'host'), ['str','str'])),
                                    ('object_group', (YLeaf(YType.str, 'object-group'), ['str'])),
                                    ('src_eq', (YLeaf(YType.str, 'src-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_gt', (YLeaf(YType.str, 'src-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_lt', (YLeaf(YType.str, 'src-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_neq', (YLeaf(YType.str, 'src-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_range1', (YLeaf(YType.str, 'src-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_range2', (YLeaf(YType.str, 'src-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dest_ipv4_address', (YLeaf(YType.str, 'dest-ipv4-address'), ['str'])),
                                    ('dest_mask', (YLeaf(YType.str, 'dest-mask'), ['str'])),
                                    ('dst_any', (YLeaf(YType.empty, 'dst-any'), ['Empty'])),
                                    ('dst_host', (YLeaf(YType.str, 'dst-host'), ['str','str'])),
                                    ('dst_object_group', (YLeaf(YType.str, 'dst-object-group'), ['str'])),
                                    ('dst_eq', (YLeaf(YType.str, 'dst-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_gt', (YLeaf(YType.str, 'dst-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_lt', (YLeaf(YType.str, 'dst-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_neq', (YLeaf(YType.str, 'dst-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_range1', (YLeaf(YType.str, 'dst-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_range2', (YLeaf(YType.str, 'dst-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                    ('fragments', (YLeaf(YType.empty, 'fragments'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ('log_input', (YLeaf(YType.empty, 'log-input'), ['Empty'])),
                                    ('option', (YLeaf(YType.str, 'option'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Option')])),
                                    ('precedence', (YLeaf(YType.str, 'precedence'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Precedence')])),
                                    ('time_range', (YLeaf(YType.str, 'time-range'), ['str'])),
                                    ('tos', (YLeaf(YType.str, 'tos'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Tos')])),
                                    ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                    ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                    ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                    ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                    ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                    ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                    ('established', (YLeaf(YType.empty, 'established'), ['Empty'])),
                                    ('msg_type', (YLeaf(YType.uint8, 'msg-type'), ['int'])),
                                    ('msg_code', (YLeaf(YType.uint8, 'msg-code'), ['int'])),
                                    ('named_msg_type', (YLeaf(YType.enumeration, 'named-msg-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.NamedMsgType')])),
                                ])
                                self.action = None
                                self.protocol = None
                                self.object_group_str = None
                                self.ipv4_address = None
                                self.mask = None
                                self.any = None
                                self.host = None
                                self.object_group = None
                                self.src_eq = None
                                self.src_gt = None
                                self.src_lt = None
                                self.src_neq = None
                                self.src_range1 = None
                                self.src_range2 = None
                                self.dest_ipv4_address = None
                                self.dest_mask = None
                                self.dst_any = None
                                self.dst_host = None
                                self.dst_object_group = None
                                self.dst_eq = None
                                self.dst_gt = None
                                self.dst_lt = None
                                self.dst_neq = None
                                self.dst_range1 = None
                                self.dst_range2 = None
                                self.dscp = None
                                self.fragments = None
                                self.log = None
                                self.log_input = None
                                self.option = None
                                self.precedence = None
                                self.time_range = None
                                self.tos = None
                                self.ack = None
                                self.fin = None
                                self.psh = None
                                self.rst = None
                                self.syn = None
                                self.urg = None
                                self.established = None
                                self.msg_type = None
                                self.msg_code = None
                                self.named_msg_type = None

                                self.ttl = Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Ttl()
                                self.ttl.parent = self
                                self._children_name_map["ttl"] = "ttl"

                                self.match_all = Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.MatchAll()
                                self.match_all.parent = self
                                self._children_name_map["match_all"] = "match-all"

                                self.match_any = Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.MatchAny()
                                self.match_any.parent = self
                                self._children_name_map["match_any"] = "match-any"
                                self._segment_path = lambda: "ace-rule"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule, ['action', 'protocol', 'object_group_str', 'ipv4_address', 'mask', 'any', 'host', 'object_group', 'src_eq', 'src_gt', 'src_lt', 'src_neq', 'src_range1', 'src_range2', 'dest_ipv4_address', 'dest_mask', 'dst_any', 'dst_host', 'dst_object_group', 'dst_eq', 'dst_gt', 'dst_lt', 'dst_neq', 'dst_range1', 'dst_range2', 'dscp', 'fragments', 'log', 'log_input', 'option', 'precedence', 'time_range', 'tos', 'ack', 'fin', 'psh', 'rst', 'syn', 'urg', 'established', 'msg_type', 'msg_code', 'named_msg_type'], name, value)

                            class Action(Enum):
                                """
                                Action (Enum Class)

                                .. data:: deny = 0

                                .. data:: permit = 1

                                """

                                deny = Enum.YLeaf(0, "deny")

                                permit = Enum.YLeaf(1, "permit")


                            class NamedMsgType(Enum):
                                """
                                NamedMsgType (Enum Class)

                                .. data:: administratively_prohibited = 0

                                .. data:: alternate_address = 1

                                .. data:: conversion_error = 2

                                .. data:: dod_host_prohibited = 3

                                .. data:: dod_net_prohibited = 4

                                .. data:: echo = 5

                                .. data:: echo_reply = 6

                                .. data:: general_parameter_problem = 7

                                .. data:: host_isolated = 8

                                .. data:: host_precedence_unreachable = 9

                                .. data:: host_redirect = 10

                                .. data:: host_tos_redirect = 11

                                .. data:: host_tos_unreachable = 12

                                .. data:: host_unknown = 13

                                .. data:: host_unreachable = 14

                                .. data:: information_reply = 15

                                .. data:: information_request = 16

                                .. data:: mask_reply = 17

                                .. data:: mask_request = 18

                                .. data:: mobile_redirect = 19

                                .. data:: net_redirect = 20

                                .. data:: net_tos_redirect = 21

                                .. data:: net_tos_unreachable = 22

                                .. data:: net_unreachable = 23

                                .. data:: network_unknown = 24

                                .. data:: no_room_for_option = 25

                                .. data:: option_missing = 26

                                .. data:: packet_too_big = 27

                                .. data:: parameter_problem = 28

                                .. data:: port_unreachable = 29

                                .. data:: precedence_unreachable = 30

                                .. data:: protocol_unreachable = 31

                                .. data:: reassembly_timeout = 32

                                .. data:: redirect = 33

                                .. data:: router_advertisement = 34

                                .. data:: router_solicitation = 35

                                .. data:: source_quench = 36

                                .. data:: source_route_failed = 37

                                .. data:: time_exceeded = 38

                                .. data:: timestamp_reply = 39

                                .. data:: timestamp_request = 40

                                .. data:: traceroute = 41

                                .. data:: ttl_exceeded = 42

                                .. data:: unreachable = 43

                                """

                                administratively_prohibited = Enum.YLeaf(0, "administratively-prohibited")

                                alternate_address = Enum.YLeaf(1, "alternate-address")

                                conversion_error = Enum.YLeaf(2, "conversion-error")

                                dod_host_prohibited = Enum.YLeaf(3, "dod-host-prohibited")

                                dod_net_prohibited = Enum.YLeaf(4, "dod-net-prohibited")

                                echo = Enum.YLeaf(5, "echo")

                                echo_reply = Enum.YLeaf(6, "echo-reply")

                                general_parameter_problem = Enum.YLeaf(7, "general-parameter-problem")

                                host_isolated = Enum.YLeaf(8, "host-isolated")

                                host_precedence_unreachable = Enum.YLeaf(9, "host-precedence-unreachable")

                                host_redirect = Enum.YLeaf(10, "host-redirect")

                                host_tos_redirect = Enum.YLeaf(11, "host-tos-redirect")

                                host_tos_unreachable = Enum.YLeaf(12, "host-tos-unreachable")

                                host_unknown = Enum.YLeaf(13, "host-unknown")

                                host_unreachable = Enum.YLeaf(14, "host-unreachable")

                                information_reply = Enum.YLeaf(15, "information-reply")

                                information_request = Enum.YLeaf(16, "information-request")

                                mask_reply = Enum.YLeaf(17, "mask-reply")

                                mask_request = Enum.YLeaf(18, "mask-request")

                                mobile_redirect = Enum.YLeaf(19, "mobile-redirect")

                                net_redirect = Enum.YLeaf(20, "net-redirect")

                                net_tos_redirect = Enum.YLeaf(21, "net-tos-redirect")

                                net_tos_unreachable = Enum.YLeaf(22, "net-tos-unreachable")

                                net_unreachable = Enum.YLeaf(23, "net-unreachable")

                                network_unknown = Enum.YLeaf(24, "network-unknown")

                                no_room_for_option = Enum.YLeaf(25, "no-room-for-option")

                                option_missing = Enum.YLeaf(26, "option-missing")

                                packet_too_big = Enum.YLeaf(27, "packet-too-big")

                                parameter_problem = Enum.YLeaf(28, "parameter-problem")

                                port_unreachable = Enum.YLeaf(29, "port-unreachable")

                                precedence_unreachable = Enum.YLeaf(30, "precedence-unreachable")

                                protocol_unreachable = Enum.YLeaf(31, "protocol-unreachable")

                                reassembly_timeout = Enum.YLeaf(32, "reassembly-timeout")

                                redirect = Enum.YLeaf(33, "redirect")

                                router_advertisement = Enum.YLeaf(34, "router-advertisement")

                                router_solicitation = Enum.YLeaf(35, "router-solicitation")

                                source_quench = Enum.YLeaf(36, "source-quench")

                                source_route_failed = Enum.YLeaf(37, "source-route-failed")

                                time_exceeded = Enum.YLeaf(38, "time-exceeded")

                                timestamp_reply = Enum.YLeaf(39, "timestamp-reply")

                                timestamp_request = Enum.YLeaf(40, "timestamp-request")

                                traceroute = Enum.YLeaf(41, "traceroute")

                                ttl_exceeded = Enum.YLeaf(42, "ttl-exceeded")

                                unreachable = Enum.YLeaf(43, "unreachable")


                            class Option(Enum):
                                """
                                Option (Enum Class)

                                Match packets with given IP Options value

                                .. data:: add_ext = 0

                                .. data:: any_options = 1

                                .. data:: com_security = 2

                                .. data:: dps = 3

                                .. data:: encode = 4

                                .. data:: eool = 5

                                .. data:: ext_ip = 6

                                .. data:: ext_security = 7

                                .. data:: finn = 8

                                .. data:: imitd = 9

                                .. data:: lsr = 10

                                .. data:: mtup = 11

                                .. data:: mtur = 12

                                .. data:: no_op = 13

                                .. data:: nsapa = 14

                                .. data:: record_route = 15

                                .. data:: router_alert = 16

                                .. data:: sdb = 17

                                .. data:: security = 18

                                .. data:: ssr = 19

                                .. data:: stream_id = 20

                                .. data:: timestamp = 21

                                .. data:: traceroute = 22

                                .. data:: ump = 23

                                .. data:: visa = 24

                                .. data:: zsu = 25

                                """

                                add_ext = Enum.YLeaf(0, "add-ext")

                                any_options = Enum.YLeaf(1, "any-options")

                                com_security = Enum.YLeaf(2, "com-security")

                                dps = Enum.YLeaf(3, "dps")

                                encode = Enum.YLeaf(4, "encode")

                                eool = Enum.YLeaf(5, "eool")

                                ext_ip = Enum.YLeaf(6, "ext-ip")

                                ext_security = Enum.YLeaf(7, "ext-security")

                                finn = Enum.YLeaf(8, "finn")

                                imitd = Enum.YLeaf(9, "imitd")

                                lsr = Enum.YLeaf(10, "lsr")

                                mtup = Enum.YLeaf(11, "mtup")

                                mtur = Enum.YLeaf(12, "mtur")

                                no_op = Enum.YLeaf(13, "no-op")

                                nsapa = Enum.YLeaf(14, "nsapa")

                                record_route = Enum.YLeaf(15, "record-route")

                                router_alert = Enum.YLeaf(16, "router-alert")

                                sdb = Enum.YLeaf(17, "sdb")

                                security = Enum.YLeaf(18, "security")

                                ssr = Enum.YLeaf(19, "ssr")

                                stream_id = Enum.YLeaf(20, "stream-id")

                                timestamp = Enum.YLeaf(21, "timestamp")

                                traceroute = Enum.YLeaf(22, "traceroute")

                                ump = Enum.YLeaf(23, "ump")

                                visa = Enum.YLeaf(24, "visa")

                                zsu = Enum.YLeaf(25, "zsu")


                            class Precedence(Enum):
                                """
                                Precedence (Enum Class)

                                Match packets with given precedence value

                                .. data:: critical = 0

                                .. data:: flash = 1

                                .. data:: flash_override = 2

                                .. data:: immediate = 3

                                .. data:: internet = 4

                                .. data:: network = 5

                                .. data:: priority = 6

                                .. data:: routine = 7

                                """

                                critical = Enum.YLeaf(0, "critical")

                                flash = Enum.YLeaf(1, "flash")

                                flash_override = Enum.YLeaf(2, "flash-override")

                                immediate = Enum.YLeaf(3, "immediate")

                                internet = Enum.YLeaf(4, "internet")

                                network = Enum.YLeaf(5, "network")

                                priority = Enum.YLeaf(6, "priority")

                                routine = Enum.YLeaf(7, "routine")


                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: ahp = 0

                                .. data:: eigrp = 1

                                .. data:: esp = 2

                                .. data:: gre = 3

                                .. data:: icmp = 4

                                .. data:: igmp = 5

                                .. data:: ip = 6

                                .. data:: ipinip = 7

                                .. data:: nos = 8

                                .. data:: object_group = 9

                                .. data:: ospf = 10

                                .. data:: pcp = 11

                                .. data:: pim = 12

                                .. data:: tcp = 13

                                .. data:: udp = 14

                                """

                                ahp = Enum.YLeaf(0, "ahp")

                                eigrp = Enum.YLeaf(1, "eigrp")

                                esp = Enum.YLeaf(2, "esp")

                                gre = Enum.YLeaf(3, "gre")

                                icmp = Enum.YLeaf(4, "icmp")

                                igmp = Enum.YLeaf(5, "igmp")

                                ip = Enum.YLeaf(6, "ip")

                                ipinip = Enum.YLeaf(7, "ipinip")

                                nos = Enum.YLeaf(8, "nos")

                                object_group = Enum.YLeaf(9, "object-group")

                                ospf = Enum.YLeaf(10, "ospf")

                                pcp = Enum.YLeaf(11, "pcp")

                                pim = Enum.YLeaf(12, "pim")

                                tcp = Enum.YLeaf(13, "tcp")

                                udp = Enum.YLeaf(14, "udp")


                            class Tos(Enum):
                                """
                                Tos (Enum Class)

                                Match packets with given TOS value

                                .. data:: max_reliability = 0

                                .. data:: max_throughput = 1

                                .. data:: min_delay = 2

                                .. data:: min_monetary_cost = 3

                                .. data:: normal = 4

                                """

                                max_reliability = Enum.YLeaf(0, "max-reliability")

                                max_throughput = Enum.YLeaf(1, "max-throughput")

                                min_delay = Enum.YLeaf(2, "min-delay")

                                min_monetary_cost = Enum.YLeaf(3, "min-monetary-cost")

                                normal = Enum.YLeaf(4, "normal")



                            class Ttl(Entity):
                                """
                                Match packets with given TTL value
                                
                                .. attribute:: eq
                                
                                	Match only packets on a given TTL number
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: gt
                                
                                	Match only packets on a given TTL number
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: lt
                                
                                	Match only packets on a given TTL number
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neq
                                
                                	Match only packets on a given TTL number
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: range
                                
                                	Match only packets in the range of TTLs
                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Ttl.Range>`
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Ttl, self).__init__()

                                    self.yang_name = "ttl"
                                    self.yang_parent_name = "ace-rule"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Ttl.Range))])
                                    self._leafs = OrderedDict([
                                        ('eq', (YLeaf(YType.uint8, 'eq'), ['int'])),
                                        ('gt', (YLeaf(YType.uint8, 'gt'), ['int'])),
                                        ('lt', (YLeaf(YType.uint8, 'lt'), ['int'])),
                                        ('neq', (YLeaf(YType.uint8, 'neq'), ['int'])),
                                    ])
                                    self.eq = None
                                    self.gt = None
                                    self.lt = None
                                    self.neq = None

                                    self.range = Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Ttl.Range()
                                    self.range.parent = self
                                    self._children_name_map["range"] = "range"
                                    self._segment_path = lambda: "ttl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Ttl, ['eq', 'gt', 'lt', 'neq'], name, value)


                                class Range(Entity):
                                    """
                                    Match only packets in the range of TTLs
                                    
                                    .. attribute:: value1
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: value2
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-acl'
                                    _revision = '2018-05-31'

                                    def __init__(self):
                                        super(Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Ttl.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "ttl"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('value1', (YLeaf(YType.uint8, 'value1'), ['int'])),
                                            ('value2', (YLeaf(YType.uint8, 'value2'), ['int'])),
                                        ])
                                        self.value1 = None
                                        self.value2 = None
                                        self._segment_path = lambda: "range"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.Ttl.Range, ['value1', 'value2'], name, value)


                            class MatchAll(Entity):
                                """
                                Match if all specified flags are present
                                
                                .. attribute:: plusack
                                
                                	Match on ACK set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusfin
                                
                                	Match on FIN set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: pluspsh
                                
                                	Match on PSH set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusrst
                                
                                	Match on RST set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plussyn
                                
                                	Match on SYN set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusurg
                                
                                	Match on URG set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusack
                                
                                	Match on ACK not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusfin
                                
                                	Match on FIN not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minuspsh
                                
                                	Match on PSH not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusrst
                                
                                	Match on RST not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minussyn
                                
                                	Match on SYN not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusurg
                                
                                	Match on URG not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.MatchAll, self).__init__()

                                    self.yang_name = "match-all"
                                    self.yang_parent_name = "ace-rule"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('plusack', (YLeaf(YType.empty, 'plusack'), ['Empty'])),
                                        ('plusfin', (YLeaf(YType.empty, 'plusfin'), ['Empty'])),
                                        ('pluspsh', (YLeaf(YType.empty, 'pluspsh'), ['Empty'])),
                                        ('plusrst', (YLeaf(YType.empty, 'plusrst'), ['Empty'])),
                                        ('plussyn', (YLeaf(YType.empty, 'plussyn'), ['Empty'])),
                                        ('plusurg', (YLeaf(YType.empty, 'plusurg'), ['Empty'])),
                                        ('minusack', (YLeaf(YType.empty, 'minusack'), ['Empty'])),
                                        ('minusfin', (YLeaf(YType.empty, 'minusfin'), ['Empty'])),
                                        ('minuspsh', (YLeaf(YType.empty, 'minuspsh'), ['Empty'])),
                                        ('minusrst', (YLeaf(YType.empty, 'minusrst'), ['Empty'])),
                                        ('minussyn', (YLeaf(YType.empty, 'minussyn'), ['Empty'])),
                                        ('minusurg', (YLeaf(YType.empty, 'minusurg'), ['Empty'])),
                                    ])
                                    self.plusack = None
                                    self.plusfin = None
                                    self.pluspsh = None
                                    self.plusrst = None
                                    self.plussyn = None
                                    self.plusurg = None
                                    self.minusack = None
                                    self.minusfin = None
                                    self.minuspsh = None
                                    self.minusrst = None
                                    self.minussyn = None
                                    self.minusurg = None
                                    self._segment_path = lambda: "match-all"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.MatchAll, ['plusack', 'plusfin', 'pluspsh', 'plusrst', 'plussyn', 'plusurg', 'minusack', 'minusfin', 'minuspsh', 'minusrst', 'minussyn', 'minusurg'], name, value)


                            class MatchAny(Entity):
                                """
                                Match if any specified flags is present
                                
                                .. attribute:: plusack
                                
                                	Match on ACK set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusfin
                                
                                	Match on FIN set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: pluspsh
                                
                                	Match on PSH set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusrst
                                
                                	Match on RST set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plussyn
                                
                                	Match on SYN set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: plusurg
                                
                                	Match on URG set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusack
                                
                                	Match on ACK not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusfin
                                
                                	Match on FIN not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minuspsh
                                
                                	Match on PSH not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusrst
                                
                                	Match on RST not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minussyn
                                
                                	Match on SYN not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: minusurg
                                
                                	Match on URG not set
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-acl'
                                _revision = '2018-05-31'

                                def __init__(self):
                                    super(Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.MatchAny, self).__init__()

                                    self.yang_name = "match-any"
                                    self.yang_parent_name = "ace-rule"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('plusack', (YLeaf(YType.empty, 'plusack'), ['Empty'])),
                                        ('plusfin', (YLeaf(YType.empty, 'plusfin'), ['Empty'])),
                                        ('pluspsh', (YLeaf(YType.empty, 'pluspsh'), ['Empty'])),
                                        ('plusrst', (YLeaf(YType.empty, 'plusrst'), ['Empty'])),
                                        ('plussyn', (YLeaf(YType.empty, 'plussyn'), ['Empty'])),
                                        ('plusurg', (YLeaf(YType.empty, 'plusurg'), ['Empty'])),
                                        ('minusack', (YLeaf(YType.empty, 'minusack'), ['Empty'])),
                                        ('minusfin', (YLeaf(YType.empty, 'minusfin'), ['Empty'])),
                                        ('minuspsh', (YLeaf(YType.empty, 'minuspsh'), ['Empty'])),
                                        ('minusrst', (YLeaf(YType.empty, 'minusrst'), ['Empty'])),
                                        ('minussyn', (YLeaf(YType.empty, 'minussyn'), ['Empty'])),
                                        ('minusurg', (YLeaf(YType.empty, 'minusurg'), ['Empty'])),
                                    ])
                                    self.plusack = None
                                    self.plusfin = None
                                    self.pluspsh = None
                                    self.plusrst = None
                                    self.plussyn = None
                                    self.plusurg = None
                                    self.minusack = None
                                    self.minusfin = None
                                    self.minuspsh = None
                                    self.minusrst = None
                                    self.minussyn = None
                                    self.minusurg = None
                                    self._segment_path = lambda: "match-any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.AccessList.Extended.Default.AccessListSeqRule.AceRule.MatchAny, ['plusack', 'plusfin', 'pluspsh', 'plusrst', 'plussyn', 'plusurg', 'minusack', 'minusfin', 'minuspsh', 'minusrst', 'minussyn', 'minusurg'], name, value)


            class Helper(Entity):
                """
                Access List acts on helper\-address
                
                .. attribute:: egress
                
                	Outbound
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: check
                
                	Enable filtering on helper\-address destined
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-acl'
                _revision = '2018-05-31'

                def __init__(self):
                    super(Native.Ip.AccessList.Helper, self).__init__()

                    self.yang_name = "helper"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ('check', (YLeaf(YType.empty, 'check'), ['Empty'])),
                    ])
                    self.egress = None
                    self.check = None
                    self._segment_path = lambda: "Cisco-IOS-XE-acl:helper"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/access-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.AccessList.Helper, ['egress', 'check'], name, value)


            class LogUpdate(Entity):
                """
                Control access list log updates
                
                .. attribute:: threshold
                
                	Set access\-list logging threshold
                	**type**\: int
                
                	**range:** 0..2147483647
                
                

                """

                _prefix = 'ios-acl'
                _revision = '2018-05-31'

                def __init__(self):
                    super(Native.Ip.AccessList.LogUpdate, self).__init__()

                    self.yang_name = "log-update"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                    ])
                    self.threshold = None
                    self._segment_path = lambda: "Cisco-IOS-XE-acl:log-update"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/access-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.AccessList.LogUpdate, ['threshold'], name, value)


            class Logging(Entity):
                """
                Control access list logging
                
                .. attribute:: hash_generation
                
                	Enable syslog hash code generation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interval
                
                	Set access list logging interval
                	**type**\: int
                
                	**range:** 0..2147483647
                
                

                """

                _prefix = 'ios-acl'
                _revision = '2018-05-31'

                def __init__(self):
                    super(Native.Ip.AccessList.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('hash_generation', (YLeaf(YType.empty, 'hash-generation'), ['Empty'])),
                        ('interval', (YLeaf(YType.uint64, 'interval'), ['int'])),
                    ])
                    self.hash_generation = None
                    self.interval = None
                    self._segment_path = lambda: "Cisco-IOS-XE-acl:logging"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/access-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.AccessList.Logging, ['hash_generation', 'interval'], name, value)


            class Resequence(Entity):
                """
                Resequence Access List
                
                .. attribute:: numbers
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: int
                
                			**range:** 1300..1999
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                		**type**\: int
                
                			**range:** 100..199
                
                		**type**\: int
                
                			**range:** 2000..2699
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: start_seq_no
                
                	
                	**type**\: int
                
                	**range:** 1..2147483647
                
                .. attribute:: step_seq_no
                
                	
                	**type**\: int
                
                	**range:** 1..2147483647
                
                

                """

                _prefix = 'ios-acl'
                _revision = '2018-05-31'

                def __init__(self):
                    super(Native.Ip.AccessList.Resequence, self).__init__()

                    self.yang_name = "resequence"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('numbers', (YLeaf(YType.str, 'numbers'), ['int','int','str','int','int','str'])),
                        ('start_seq_no', (YLeaf(YType.uint64, 'start-seq-no'), ['int'])),
                        ('step_seq_no', (YLeaf(YType.uint64, 'step-seq-no'), ['int'])),
                    ])
                    self.numbers = None
                    self.start_seq_no = None
                    self.step_seq_no = None
                    self._segment_path = lambda: "Cisco-IOS-XE-acl:resequence"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/access-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.AccessList.Resequence, ['numbers', 'start_seq_no', 'step_seq_no'], name, value)


        class Device(Entity):
            """
            Device tracking
            
            .. attribute:: tracking
            
            	Device tracking
            	**type**\:  :py:class:`Tracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Device.Tracking>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ip.Device, self).__init__()

                self.yang_name = "device"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-device-tracking:tracking", ("tracking", Native.Ip.Device.Tracking))])
                self._leafs = OrderedDict()

                self.tracking = None
                self._children_name_map["tracking"] = "Cisco-IOS-XE-device-tracking:tracking"
                self._segment_path = lambda: "device"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Device, [], name, value)


            class Tracking(Entity):
                """
                Device tracking
                
                .. attribute:: probe
                
                	Probe
                	**type**\:  :py:class:`Probe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Device.Tracking.Probe>`
                
                .. attribute:: trace_buffer
                
                	Enable Tracing Support
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-dt'
                _revision = '2017-06-07'

                def __init__(self):
                    super(Native.Ip.Device.Tracking, self).__init__()

                    self.yang_name = "tracking"
                    self.yang_parent_name = "device"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("probe", ("probe", Native.Ip.Device.Tracking.Probe))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('trace_buffer', (YLeaf(YType.empty, 'trace-buffer'), ['Empty'])),
                    ])
                    self.trace_buffer = None

                    self.probe = Native.Ip.Device.Tracking.Probe()
                    self.probe.parent = self
                    self._children_name_map["probe"] = "probe"
                    self._segment_path = lambda: "Cisco-IOS-XE-device-tracking:tracking"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/device/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Device.Tracking, [u'trace_buffer'], name, value)


                class Probe(Entity):
                    """
                    Probe
                    
                    .. attribute:: auto_source
                    
                    	Probe source selection algorithm
                    	**type**\:  :py:class:`AutoSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Device.Tracking.Probe.AutoSource>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: count
                    
                    	Probe count
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: delay
                    
                    	Probe delay
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    .. attribute:: interval
                    
                    	Probe interval
                    	**type**\: int
                    
                    	**range:** 30..1814400
                    
                    

                    """

                    _prefix = 'ios-dt'
                    _revision = '2017-06-07'

                    def __init__(self):
                        super(Native.Ip.Device.Tracking.Probe, self).__init__()

                        self.yang_name = "probe"
                        self.yang_parent_name = "tracking"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto-source", ("auto_source", Native.Ip.Device.Tracking.Probe.AutoSource))])
                        self._leafs = OrderedDict([
                            ('count', (YLeaf(YType.uint8, 'count'), ['int'])),
                            ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                        ])
                        self.count = None
                        self.delay = None
                        self.interval = None

                        self.auto_source = None
                        self._children_name_map["auto_source"] = "auto-source"
                        self._segment_path = lambda: "probe"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/device/Cisco-IOS-XE-device-tracking:tracking/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Device.Tracking.Probe, [u'count', u'delay', u'interval'], name, value)


                    class AutoSource(Entity):
                        """
                        Probe source selection algorithm
                        
                        .. attribute:: fallback
                        
                        	Specify IP and MASK to use as last resort
                        	**type**\:  :py:class:`Fallback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Device.Tracking.Probe.AutoSource.Fallback>`
                        
                        .. attribute:: override
                        
                        	Do not select source address from device track table
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dt'
                        _revision = '2017-06-07'

                        def __init__(self):
                            super(Native.Ip.Device.Tracking.Probe.AutoSource, self).__init__()

                            self.yang_name = "auto-source"
                            self.yang_parent_name = "probe"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fallback", ("fallback", Native.Ip.Device.Tracking.Probe.AutoSource.Fallback))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('override', (YLeaf(YType.empty, 'override'), ['Empty'])),
                            ])
                            self.override = None

                            self.fallback = Native.Ip.Device.Tracking.Probe.AutoSource.Fallback()
                            self.fallback.parent = self
                            self._children_name_map["fallback"] = "fallback"
                            self._segment_path = lambda: "auto-source"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/device/Cisco-IOS-XE-device-tracking:tracking/probe/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Device.Tracking.Probe.AutoSource, [u'override'], name, value)


                        class Fallback(Entity):
                            """
                            Specify IP and MASK to use as last resort
                            
                            .. attribute:: src_ip
                            
                            	IP and MASK of fallback source
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	IP prefix mask
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-dt'
                            _revision = '2017-06-07'

                            def __init__(self):
                                super(Native.Ip.Device.Tracking.Probe.AutoSource.Fallback, self).__init__()

                                self.yang_name = "fallback"
                                self.yang_parent_name = "auto-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('src_ip', (YLeaf(YType.str, 'src-ip'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.src_ip = None
                                self.mask = None
                                self._segment_path = lambda: "fallback"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/device/Cisco-IOS-XE-device-tracking:tracking/probe/auto-source/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Device.Tracking.Probe.AutoSource.Fallback, [u'src_ip', u'mask'], name, value)


        class Igmp(Entity):
            """
            IGMP global configuration
            
            .. attribute:: snooping_conf
            
            	
            	**type**\:  :py:class:`SnoopingConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.SnoopingConf>`
            
            .. attribute:: snooping
            
            	Global IGMP Snooping enable for Catalyst Vlans
            	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping>`
            
            .. attribute:: ssm_map
            
            	SSM mapping commands
            	**type**\:  :py:class:`SsmMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.SsmMap>`
            
            .. attribute:: vrf
            
            	Select VPN Routing/Forwarding instance
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Vrf>`
            
            

            """

            _prefix = 'ios-igmp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Ip.Igmp, self).__init__()

                self.yang_name = "igmp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("snooping-conf", ("snooping_conf", Native.Ip.Igmp.SnoopingConf)), ("snooping", ("snooping", Native.Ip.Igmp.Snooping)), ("ssm-map", ("ssm_map", Native.Ip.Igmp.SsmMap)), ("vrf", ("vrf", Native.Ip.Igmp.Vrf))])
                self._leafs = OrderedDict()

                self.snooping_conf = Native.Ip.Igmp.SnoopingConf()
                self.snooping_conf.parent = self
                self._children_name_map["snooping_conf"] = "snooping-conf"

                self.snooping = Native.Ip.Igmp.Snooping()
                self.snooping.parent = self
                self._children_name_map["snooping"] = "snooping"

                self.ssm_map = Native.Ip.Igmp.SsmMap()
                self.ssm_map.parent = self
                self._children_name_map["ssm_map"] = "ssm-map"

                self.vrf = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Igmp, [], name, value)


            class SnoopingConf(Entity):
                """
                
                
                .. attribute:: snooping
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios-igmp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ip.Igmp.SnoopingConf, self).__init__()

                    self.yang_name = "snooping-conf"
                    self.yang_parent_name = "igmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('snooping', (YLeaf(YType.boolean, 'snooping'), ['bool'])),
                    ])
                    self.snooping = None
                    self._segment_path = lambda: "snooping-conf"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Igmp.SnoopingConf, [u'snooping'], name, value)


            class Snooping(Entity):
                """
                Global IGMP Snooping enable for Catalyst Vlans
                
                .. attribute:: check
                
                	enforce TTL or Rtr\-Alert Option checking
                	**type**\:  :py:class:`Check <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Check>`
                
                .. attribute:: explicit_tracking
                
                	Explicit tracking DB configuration
                	**type**\:  :py:class:`ExplicitTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.ExplicitTracking>`
                
                .. attribute:: l2_entry_limit
                
                	limit on the l2 entry that can be installed by IGMP snooping
                	**type**\: int
                
                	**range:** 1..100000
                
                .. attribute:: last_member_query_count
                
                	Last member query count
                	**type**\: int
                
                	**range:** 1..7
                
                .. attribute:: last_member_query_interval
                
                	Interval (milliseconds)
                	**type**\: int
                
                	**range:** 100..32767
                
                .. attribute:: querier
                
                	IGMP querier configuration
                	**type**\:  :py:class:`Querier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Querier>`
                
                	**presence node**\: True
                
                .. attribute:: report_suppression
                
                	Report suppression
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: robustness_variable
                
                	Robustness Variable number
                	**type**\: int
                
                	**range:** 1..3
                
                .. attribute:: tcn
                
                	Topology change notification configuration
                	**type**\:  :py:class:`Tcn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Tcn>`
                
                .. attribute:: vlan
                
                	IGMP Snooping enable for Catalyst VLAN
                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Vlan>`
                
                

                """

                _prefix = 'ios-igmp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ip.Igmp.Snooping, self).__init__()

                    self.yang_name = "snooping"
                    self.yang_parent_name = "igmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("check", ("check", Native.Ip.Igmp.Snooping.Check)), ("explicit-tracking", ("explicit_tracking", Native.Ip.Igmp.Snooping.ExplicitTracking)), ("querier", ("querier", Native.Ip.Igmp.Snooping.Querier)), ("tcn", ("tcn", Native.Ip.Igmp.Snooping.Tcn)), ("Cisco-IOS-XE-switch:vlan", ("vlan", Native.Ip.Igmp.Snooping.Vlan))])
                    self._leafs = OrderedDict([
                        ('l2_entry_limit', (YLeaf(YType.uint32, 'l2-entry-limit'), ['int'])),
                        ('last_member_query_count', (YLeaf(YType.uint8, 'last-member-query-count'), ['int'])),
                        ('last_member_query_interval', (YLeaf(YType.uint16, 'last-member-query-interval'), ['int'])),
                        ('report_suppression', (YLeaf(YType.empty, 'report-suppression'), ['Empty'])),
                        ('robustness_variable', (YLeaf(YType.uint8, 'robustness-variable'), ['int'])),
                    ])
                    self.l2_entry_limit = None
                    self.last_member_query_count = None
                    self.last_member_query_interval = None
                    self.report_suppression = None
                    self.robustness_variable = None

                    self.check = Native.Ip.Igmp.Snooping.Check()
                    self.check.parent = self
                    self._children_name_map["check"] = "check"

                    self.explicit_tracking = Native.Ip.Igmp.Snooping.ExplicitTracking()
                    self.explicit_tracking.parent = self
                    self._children_name_map["explicit_tracking"] = "explicit-tracking"

                    self.querier = None
                    self._children_name_map["querier"] = "querier"

                    self.tcn = Native.Ip.Igmp.Snooping.Tcn()
                    self.tcn.parent = self
                    self._children_name_map["tcn"] = "tcn"

                    self.vlan = Native.Ip.Igmp.Snooping.Vlan()
                    self.vlan.parent = self
                    self._children_name_map["vlan"] = "Cisco-IOS-XE-switch:vlan"
                    self._segment_path = lambda: "snooping"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Igmp.Snooping, [u'l2_entry_limit', u'last_member_query_count', u'last_member_query_interval', u'report_suppression', u'robustness_variable'], name, value)


                class Check(Entity):
                    """
                    enforce TTL or Rtr\-Alert Option checking
                    
                    .. attribute:: rtr_alert_option
                    
                    	Only accept IGMP packets with router\-alert option
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ttl
                    
                    	Only accept IGMP packets with TTL=1
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Igmp.Snooping.Check, self).__init__()

                        self.yang_name = "check"
                        self.yang_parent_name = "snooping"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('rtr_alert_option', (YLeaf(YType.empty, 'rtr-alert-option'), ['Empty'])),
                            ('ttl', (YLeaf(YType.empty, 'ttl'), ['Empty'])),
                        ])
                        self.rtr_alert_option = None
                        self.ttl = None
                        self._segment_path = lambda: "check"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Igmp.Snooping.Check, [u'rtr_alert_option', u'ttl'], name, value)


                class ExplicitTracking(Entity):
                    """
                    Explicit tracking DB configuration
                    
                    .. attribute:: limit
                    
                    	Explicit tracking DB limit
                    	**type**\: int
                    
                    	**range:** 0..128000
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Igmp.Snooping.ExplicitTracking, self).__init__()

                        self.yang_name = "explicit-tracking"
                        self.yang_parent_name = "snooping"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                        ])
                        self.limit = None
                        self._segment_path = lambda: "explicit-tracking"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Igmp.Snooping.ExplicitTracking, [u'limit'], name, value)


                class Querier(Entity):
                    """
                    IGMP querier configuration
                    
                    .. attribute:: address
                    
                    	IGMP querier source IP address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: max_response_time
                    
                    	IGMP querier maximum response time (sec)
                    	**type**\: int
                    
                    	**range:** 1..25
                    
                    .. attribute:: query_interval
                    
                    	IGMP querier query interval (sec)
                    	**type**\: int
                    
                    	**range:** 1..18000
                    
                    .. attribute:: tcn
                    
                    	IGMP querier TCN related parameters
                    	**type**\:  :py:class:`Tcn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Querier.Tcn>`
                    
                    .. attribute:: timer
                    
                    	IGMP other querier timer
                    	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Querier.Timer>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..2
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Igmp.Snooping.Querier, self).__init__()

                        self.yang_name = "querier"
                        self.yang_parent_name = "snooping"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tcn", ("tcn", Native.Ip.Igmp.Snooping.Querier.Tcn)), ("timer", ("timer", Native.Ip.Igmp.Snooping.Querier.Timer))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('max_response_time', (YLeaf(YType.uint8, 'max-response-time'), ['int'])),
                            ('query_interval', (YLeaf(YType.uint16, 'query-interval'), ['int'])),
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.address = None
                        self.max_response_time = None
                        self.query_interval = None
                        self.version = None

                        self.tcn = Native.Ip.Igmp.Snooping.Querier.Tcn()
                        self.tcn.parent = self
                        self._children_name_map["tcn"] = "tcn"

                        self.timer = Native.Ip.Igmp.Snooping.Querier.Timer()
                        self.timer.parent = self
                        self._children_name_map["timer"] = "timer"
                        self._segment_path = lambda: "querier"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Igmp.Snooping.Querier, [u'address', u'max_response_time', u'query_interval', u'version'], name, value)


                    class Tcn(Entity):
                        """
                        IGMP querier TCN related parameters
                        
                        .. attribute:: query
                        
                        	
                        	**type**\:  :py:class:`Query <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Querier.Tcn.Query>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Igmp.Snooping.Querier.Tcn, self).__init__()

                            self.yang_name = "tcn"
                            self.yang_parent_name = "querier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("query", ("query", Native.Ip.Igmp.Snooping.Querier.Tcn.Query))])
                            self._leafs = OrderedDict()

                            self.query = Native.Ip.Igmp.Snooping.Querier.Tcn.Query()
                            self.query.parent = self
                            self._children_name_map["query"] = "query"
                            self._segment_path = lambda: "tcn"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/querier/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Igmp.Snooping.Querier.Tcn, [], name, value)


                        class Query(Entity):
                            """
                            
                            
                            .. attribute:: count
                            
                            	IGMP querier TCN query count
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            .. attribute:: interval
                            
                            	IGMP querier TCN query interval (sec)
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Ip.Igmp.Snooping.Querier.Tcn.Query, self).__init__()

                                self.yang_name = "query"
                                self.yang_parent_name = "tcn"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('count', (YLeaf(YType.uint8, 'count'), ['int'])),
                                    ('interval', (YLeaf(YType.uint8, 'interval'), ['int'])),
                                ])
                                self.count = None
                                self.interval = None
                                self._segment_path = lambda: "query"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/querier/tcn/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Igmp.Snooping.Querier.Tcn.Query, [u'count', u'interval'], name, value)


                    class Timer(Entity):
                        """
                        IGMP other querier timer
                        
                        .. attribute:: expiry
                        
                        	IGMP querier other querier time out (sec)
                        	**type**\: int
                        
                        	**range:** 60..300
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Igmp.Snooping.Querier.Timer, self).__init__()

                            self.yang_name = "timer"
                            self.yang_parent_name = "querier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('expiry', (YLeaf(YType.uint16, 'expiry'), ['int'])),
                            ])
                            self.expiry = None
                            self._segment_path = lambda: "timer"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/querier/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Igmp.Snooping.Querier.Timer, [u'expiry'], name, value)


                class Tcn(Entity):
                    """
                    Topology change notification configuration
                    
                    .. attribute:: flood
                    
                    	TCN flooding configuration
                    	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Tcn.Flood>`
                    
                    .. attribute:: query
                    
                    	TCN query configuration
                    	**type**\:  :py:class:`Query <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Tcn.Query>`
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Igmp.Snooping.Tcn, self).__init__()

                        self.yang_name = "tcn"
                        self.yang_parent_name = "snooping"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("flood", ("flood", Native.Ip.Igmp.Snooping.Tcn.Flood)), ("query", ("query", Native.Ip.Igmp.Snooping.Tcn.Query))])
                        self._leafs = OrderedDict()

                        self.flood = Native.Ip.Igmp.Snooping.Tcn.Flood()
                        self.flood.parent = self
                        self._children_name_map["flood"] = "flood"

                        self.query = Native.Ip.Igmp.Snooping.Tcn.Query()
                        self.query.parent = self
                        self._children_name_map["query"] = "query"
                        self._segment_path = lambda: "tcn"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Igmp.Snooping.Tcn, [], name, value)


                    class Flood(Entity):
                        """
                        TCN flooding configuration
                        
                        .. attribute:: query
                        
                        	TCN flooding query configuration
                        	**type**\:  :py:class:`Query <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Tcn.Flood.Query>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Igmp.Snooping.Tcn.Flood, self).__init__()

                            self.yang_name = "flood"
                            self.yang_parent_name = "tcn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("query", ("query", Native.Ip.Igmp.Snooping.Tcn.Flood.Query))])
                            self._leafs = OrderedDict()

                            self.query = Native.Ip.Igmp.Snooping.Tcn.Flood.Query()
                            self.query.parent = self
                            self._children_name_map["query"] = "query"
                            self._segment_path = lambda: "flood"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/tcn/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Igmp.Snooping.Tcn.Flood, [], name, value)


                        class Query(Entity):
                            """
                            TCN flooding query configuration
                            
                            .. attribute:: count
                            
                            	Count
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Ip.Igmp.Snooping.Tcn.Flood.Query, self).__init__()

                                self.yang_name = "query"
                                self.yang_parent_name = "flood"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('count', (YLeaf(YType.uint8, 'count'), ['int'])),
                                ])
                                self.count = None
                                self._segment_path = lambda: "query"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/tcn/flood/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Igmp.Snooping.Tcn.Flood.Query, [u'count'], name, value)


                    class Query(Entity):
                        """
                        TCN query configuration
                        
                        .. attribute:: solicit
                        
                        	Solicit an IGMP general query
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Igmp.Snooping.Tcn.Query, self).__init__()

                            self.yang_name = "query"
                            self.yang_parent_name = "tcn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('solicit', (YLeaf(YType.empty, 'solicit'), ['Empty'])),
                            ])
                            self.solicit = None
                            self._segment_path = lambda: "query"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/tcn/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Igmp.Snooping.Tcn.Query, [u'solicit'], name, value)


                class Vlan(Entity):
                    """
                    IGMP Snooping enable for Catalyst VLAN
                    
                    .. attribute:: range
                    
                    	
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Vlan.Range>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Ip.Igmp.Snooping.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "snooping"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Native.Ip.Igmp.Snooping.Vlan.Range))])
                        self._leafs = OrderedDict()

                        self.range = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:vlan"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Igmp.Snooping.Vlan, [], name, value)


                    class Range(Entity):
                        """
                        
                        
                        .. attribute:: range  (key)
                        
                        	Vlan number
                        	**type**\: int
                        
                        	**range:** 1..1001 \| 1006..4094
                        
                        .. attribute:: immediate_leave
                        
                        	Enable IGMPv2 immediate leave processing
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: last_member_query_count
                        
                        	Interval (milliseconds)
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: last_member_query_interval
                        
                        	Interval (milliseconds)
                        	**type**\: int
                        
                        	**range:** 100..32767
                        
                        .. attribute:: mrouter
                        
                        	Configure an L2 port as a multicast router port
                        	**type**\:  :py:class:`Mrouter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Vlan.Range.Mrouter>`
                        
                        .. attribute:: querier
                        
                        	Enable IGMP querier for this Vlan
                        	**type**\:  :py:class:`Querier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Vlan.Range.Querier>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: robustness_variable
                        
                        	Robustness variable
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: static
                        
                        	Configure an L2 port as a member of a group
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Vlan.Range.Static>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Ip.Igmp.Snooping.Vlan.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['range']
                            self._child_classes = OrderedDict([("mrouter", ("mrouter", Native.Ip.Igmp.Snooping.Vlan.Range.Mrouter)), ("querier", ("querier", Native.Ip.Igmp.Snooping.Vlan.Range.Querier)), ("static", ("static", Native.Ip.Igmp.Snooping.Vlan.Range.Static))])
                            self._leafs = OrderedDict([
                                ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ('immediate_leave', (YLeaf(YType.empty, 'immediate-leave'), ['Empty'])),
                                ('last_member_query_count', (YLeaf(YType.uint8, 'last-member-query-count'), ['int'])),
                                ('last_member_query_interval', (YLeaf(YType.uint16, 'last-member-query-interval'), ['int'])),
                                ('robustness_variable', (YLeaf(YType.uint8, 'robustness-variable'), ['int'])),
                            ])
                            self.range = None
                            self.immediate_leave = None
                            self.last_member_query_count = None
                            self.last_member_query_interval = None
                            self.robustness_variable = None

                            self.mrouter = Native.Ip.Igmp.Snooping.Vlan.Range.Mrouter()
                            self.mrouter.parent = self
                            self._children_name_map["mrouter"] = "mrouter"

                            self.querier = None
                            self._children_name_map["querier"] = "querier"

                            self.static = Native.Ip.Igmp.Snooping.Vlan.Range.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/snooping/Cisco-IOS-XE-switch:vlan/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Igmp.Snooping.Vlan.Range, [u'range', u'immediate_leave', u'last_member_query_count', u'last_member_query_interval', u'robustness_variable'], name, value)


                        class Mrouter(Entity):
                            """
                            Configure an L2 port as a multicast router port
                            
                            .. attribute:: interface
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: learn
                            
                            	Set the multicast router learning method
                            	**type**\:  :py:class:`Learn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Vlan.Range.Mrouter.Learn>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Ip.Igmp.Snooping.Vlan.Range.Mrouter, self).__init__()

                                self.yang_name = "mrouter"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("learn", ("learn", Native.Ip.Igmp.Snooping.Vlan.Range.Mrouter.Learn))])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ])
                                self.interface = None

                                self.learn = Native.Ip.Igmp.Snooping.Vlan.Range.Mrouter.Learn()
                                self.learn.parent = self
                                self._children_name_map["learn"] = "learn"
                                self._segment_path = lambda: "mrouter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Igmp.Snooping.Vlan.Range.Mrouter, [u'interface'], name, value)


                            class Learn(Entity):
                                """
                                Set the multicast router learning method
                                
                                .. attribute:: cgmp
                                
                                	Learn the multicast router snooping CGMP packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: pim_dvmrp
                                
                                	Learn the multicast router snooping PIM\-DVMRP packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Ip.Igmp.Snooping.Vlan.Range.Mrouter.Learn, self).__init__()

                                    self.yang_name = "learn"
                                    self.yang_parent_name = "mrouter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cgmp', (YLeaf(YType.empty, 'cgmp'), ['Empty'])),
                                        ('pim_dvmrp', (YLeaf(YType.empty, 'pim-dvmrp'), ['Empty'])),
                                    ])
                                    self.cgmp = None
                                    self.pim_dvmrp = None
                                    self._segment_path = lambda: "learn"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Igmp.Snooping.Vlan.Range.Mrouter.Learn, [u'cgmp', u'pim_dvmrp'], name, value)


                        class Querier(Entity):
                            """
                            Enable IGMP querier for this Vlan
                            
                            .. attribute:: address
                            
                            	IGMP querier source IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: max_response_time
                            
                            	IGMP querier maximum response time (sec)
                            	**type**\: int
                            
                            	**range:** 1..25
                            
                            .. attribute:: query_interval
                            
                            	IGMP querier query interval (sec)
                            	**type**\: int
                            
                            	**range:** 1..18000
                            
                            .. attribute:: tcn
                            
                            	IGMP querier TCN related parameters
                            	**type**\:  :py:class:`Tcn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Tcn>`
                            
                            .. attribute:: timer
                            
                            	IGMP other querier timer
                            	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Timer>`
                            
                            .. attribute:: version
                            
                            	IGMP version
                            	**type**\: int
                            
                            	**range:** 1..2
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Ip.Igmp.Snooping.Vlan.Range.Querier, self).__init__()

                                self.yang_name = "querier"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tcn", ("tcn", Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Tcn)), ("timer", ("timer", Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Timer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('max_response_time', (YLeaf(YType.uint8, 'max-response-time'), ['int'])),
                                    ('query_interval', (YLeaf(YType.uint16, 'query-interval'), ['int'])),
                                    ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                                ])
                                self.address = None
                                self.max_response_time = None
                                self.query_interval = None
                                self.version = None

                                self.tcn = Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Tcn()
                                self.tcn.parent = self
                                self._children_name_map["tcn"] = "tcn"

                                self.timer = Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Timer()
                                self.timer.parent = self
                                self._children_name_map["timer"] = "timer"
                                self._segment_path = lambda: "querier"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Igmp.Snooping.Vlan.Range.Querier, [u'address', u'max_response_time', u'query_interval', u'version'], name, value)


                            class Tcn(Entity):
                                """
                                IGMP querier TCN related parameters
                                
                                .. attribute:: query
                                
                                	IGMP querier TCN query related parameters
                                	**type**\:  :py:class:`Query <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Tcn.Query>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Tcn, self).__init__()

                                    self.yang_name = "tcn"
                                    self.yang_parent_name = "querier"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("query", ("query", Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Tcn.Query))])
                                    self._leafs = OrderedDict()

                                    self.query = Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Tcn.Query()
                                    self.query.parent = self
                                    self._children_name_map["query"] = "query"
                                    self._segment_path = lambda: "tcn"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Tcn, [], name, value)


                                class Query(Entity):
                                    """
                                    IGMP querier TCN query related parameters
                                    
                                    .. attribute:: count
                                    
                                    	IGMP querier TCN query count
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    .. attribute:: interval
                                    
                                    	IGMP querier TCN query interval (sec)
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Tcn.Query, self).__init__()

                                        self.yang_name = "query"
                                        self.yang_parent_name = "tcn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('count', (YLeaf(YType.uint8, 'count'), ['int'])),
                                            ('interval', (YLeaf(YType.uint8, 'interval'), ['int'])),
                                        ])
                                        self.count = None
                                        self.interval = None
                                        self._segment_path = lambda: "query"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Tcn.Query, [u'count', u'interval'], name, value)


                            class Timer(Entity):
                                """
                                IGMP other querier timer
                                
                                .. attribute:: expiry
                                
                                	IGMP querier other querier time out (sec)
                                	**type**\: int
                                
                                	**range:** 60..300
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Timer, self).__init__()

                                    self.yang_name = "timer"
                                    self.yang_parent_name = "querier"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('expiry', (YLeaf(YType.uint16, 'expiry'), ['int'])),
                                    ])
                                    self.expiry = None
                                    self._segment_path = lambda: "timer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Igmp.Snooping.Vlan.Range.Querier.Timer, [u'expiry'], name, value)


                        class Static(Entity):
                            """
                            Configure an L2 port as a member of a group
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Snooping.Vlan.Range.Static.Ipv4>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Ip.Igmp.Snooping.Vlan.Range.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Ip.Igmp.Snooping.Vlan.Range.Static.Ipv4))])
                                self._leafs = OrderedDict()

                                self.ipv4 = YList(self)
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Igmp.Snooping.Vlan.Range.Static, [], name, value)


                            class Ipv4(Entity):
                                """
                                
                                
                                .. attribute:: ipv4  (key)
                                
                                	IP address of the group
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Ip.Igmp.Snooping.Vlan.Range.Static.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv4']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ])
                                    self.ipv4 = None
                                    self.interface = None
                                    self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Igmp.Snooping.Vlan.Range.Static.Ipv4, [u'ipv4', u'interface'], name, value)


            class SsmMap(Entity):
                """
                SSM mapping commands
                
                .. attribute:: enable
                
                	Enable SSM group to source mapping
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: query
                
                	Which database should we query for the source
                	**type**\:  :py:class:`Query <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.SsmMap.Query>`
                
                .. attribute:: static
                
                	SSM static group to source mapping
                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.SsmMap.Static>`
                
                

                """

                _prefix = 'ios-igmp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ip.Igmp.SsmMap, self).__init__()

                    self.yang_name = "ssm-map"
                    self.yang_parent_name = "igmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("query", ("query", Native.Ip.Igmp.SsmMap.Query)), ("static", ("static", Native.Ip.Igmp.SsmMap.Static))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None

                    self.query = Native.Ip.Igmp.SsmMap.Query()
                    self.query.parent = self
                    self._children_name_map["query"] = "query"

                    self.static = Native.Ip.Igmp.SsmMap.Static()
                    self.static.parent = self
                    self._children_name_map["static"] = "static"
                    self._segment_path = lambda: "ssm-map"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Igmp.SsmMap, [u'enable'], name, value)


                class Query(Entity):
                    """
                    Which database should we query for the source
                    
                    .. attribute:: dns
                    
                    	Use DNS for source lookup
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Igmp.SsmMap.Query, self).__init__()

                        self.yang_name = "query"
                        self.yang_parent_name = "ssm-map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dns', (YLeaf(YType.empty, 'dns'), ['Empty'])),
                        ])
                        self.dns = None
                        self._segment_path = lambda: "query"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/ssm-map/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Igmp.SsmMap.Query, [u'dns'], name, value)


                class Static(Entity):
                    """
                    SSM static group to source mapping
                    
                    .. attribute:: acl
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: str
                    
                    .. attribute:: source_ip
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Igmp.SsmMap.Static, self).__init__()

                        self.yang_name = "static"
                        self.yang_parent_name = "ssm-map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acl', (YLeaf(YType.str, 'acl'), ['int','str'])),
                            ('source_ip', (YLeaf(YType.str, 'source-ip'), ['str'])),
                        ])
                        self.acl = None
                        self.source_ip = None
                        self._segment_path = lambda: "static"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/ssm-map/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Igmp.SsmMap.Static, [u'acl', u'source_ip'], name, value)


            class Vrf(Entity):
                """
                Select VPN Routing/Forwarding instance
                
                .. attribute:: name  (key)
                
                	VPN Routing/Forwarding instance name
                	**type**\: str
                
                .. attribute:: ssm_map
                
                	SSM mapping commands
                	**type**\:  :py:class:`SsmMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Vrf.SsmMap>`
                
                

                """

                _prefix = 'ios-igmp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ip.Igmp.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "igmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("ssm-map", ("ssm_map", Native.Ip.Igmp.Vrf.SsmMap))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.ssm_map = Native.Ip.Igmp.Vrf.SsmMap()
                    self.ssm_map.parent = self
                    self._children_name_map["ssm_map"] = "ssm-map"
                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-igmp:igmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Igmp.Vrf, [u'name'], name, value)


                class SsmMap(Entity):
                    """
                    SSM mapping commands
                    
                    .. attribute:: enable
                    
                    	Enable SSM group to source mapping
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: static
                    
                    	SSM static group to source mapping
                    	**type**\: list of  		 :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Igmp.Vrf.SsmMap.Static>`
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Igmp.Vrf.SsmMap, self).__init__()

                        self.yang_name = "ssm-map"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static", ("static", Native.Ip.Igmp.Vrf.SsmMap.Static))])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None

                        self.static = YList(self)
                        self._segment_path = lambda: "ssm-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Igmp.Vrf.SsmMap, [u'enable'], name, value)


                    class Static(Entity):
                        """
                        SSM static group to source mapping
                        
                        .. attribute:: srcaddress  (key)
                        
                        	SSM source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: aclname
                        
                        	SSM group named access list
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Igmp.Vrf.SsmMap.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "ssm-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['srcaddress']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('srcaddress', (YLeaf(YType.str, 'srcaddress'), ['str'])),
                                ('aclname', (YLeaf(YType.str, 'aclname'), ['str'])),
                            ])
                            self.srcaddress = None
                            self.aclname = None
                            self._segment_path = lambda: "static" + "[srcaddress='" + str(self.srcaddress) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Igmp.Vrf.SsmMap.Static, [u'srcaddress', u'aclname'], name, value)


        class Radius(Entity):
            """
            RADIUS configuration commands
            
            .. attribute:: source_interface
            
            	Specify interface for source address in RADIUS packets
            	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Radius.SourceInterface>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Ip.Radius, self).__init__()

                self.yang_name = "radius"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("source-interface", ("source_interface", Native.Ip.Radius.SourceInterface))])
                self._leafs = OrderedDict()

                self.source_interface = Native.Ip.Radius.SourceInterface()
                self.source_interface.parent = self
                self._children_name_map["source_interface"] = "source-interface"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:radius"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Radius, [], name, value)


            class SourceInterface(Entity):
                """
                Specify interface for source address in RADIUS packets
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Radius.SourceInterface.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Radius.SourceInterface.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Radius.SourceInterface.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Radius.SourceInterface.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Ip.Radius.SourceInterface, self).__init__()

                    self.yang_name = "source-interface"
                    self.yang_parent_name = "radius"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Ip.Radius.SourceInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Ip.Radius.SourceInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Ip.Radius.SourceInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Ip.Radius.SourceInterface.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.Ip.Radius.SourceInterface.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.Ip.Radius.SourceInterface.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.Ip.Radius.SourceInterface.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.Ip.Radius.SourceInterface.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "source-interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-aaa:radius/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Radius.SourceInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Ip.Radius.SourceInterface.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-aaa:radius/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Radius.SourceInterface.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Ip.Radius.SourceInterface.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-aaa:radius/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Radius.SourceInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Ip.Radius.SourceInterface.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-aaa:radius/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Radius.SourceInterface.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Ip.Radius.SourceInterface.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-aaa:radius/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Radius.SourceInterface.PortChannelSubinterface, [u'port_channel'], name, value)


        class Tacacs(Entity):
            """
            TACACS configuration commands
            
            .. attribute:: source_interface
            
            	Specify interface for source address in TACACS packets
            	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tacacs.SourceInterface>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Ip.Tacacs, self).__init__()

                self.yang_name = "tacacs"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("source-interface", ("source_interface", Native.Ip.Tacacs.SourceInterface))])
                self._leafs = OrderedDict()

                self.source_interface = Native.Ip.Tacacs.SourceInterface()
                self.source_interface.parent = self
                self._children_name_map["source_interface"] = "source-interface"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:tacacs"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Tacacs, [], name, value)


            class SourceInterface(Entity):
                """
                Specify interface for source address in TACACS packets
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tacacs.SourceInterface.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tacacs.SourceInterface.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tacacs.SourceInterface.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Tacacs.SourceInterface.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Ip.Tacacs.SourceInterface, self).__init__()

                    self.yang_name = "source-interface"
                    self.yang_parent_name = "tacacs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Ip.Tacacs.SourceInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Ip.Tacacs.SourceInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Ip.Tacacs.SourceInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Ip.Tacacs.SourceInterface.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.Ip.Tacacs.SourceInterface.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.Ip.Tacacs.SourceInterface.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.Ip.Tacacs.SourceInterface.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.Ip.Tacacs.SourceInterface.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "source-interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-aaa:tacacs/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Tacacs.SourceInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Ip.Tacacs.SourceInterface.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-aaa:tacacs/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tacacs.SourceInterface.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Ip.Tacacs.SourceInterface.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-aaa:tacacs/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tacacs.SourceInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Ip.Tacacs.SourceInterface.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-aaa:tacacs/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tacacs.SourceInterface.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Ip.Tacacs.SourceInterface.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-aaa:tacacs/source-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Tacacs.SourceInterface.PortChannelSubinterface, [u'port_channel'], name, value)


        class Nbar(Entity):
            """
            NBAR \- Network Based Application Recognition
            
            .. attribute:: attribute
            
            	Attribute for which custom group value can be created
            	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Attribute>`
            
            .. attribute:: attribute_map
            
            	Attribute Map
            	**type**\: list of  		 :py:class:`AttributeMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.AttributeMap>`
            
            .. attribute:: attribute_set
            
            	Set attribute Map
            	**type**\: list of  		 :py:class:`AttributeSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.AttributeSet>`
            
            .. attribute:: classification
            
            	NBAR Classification
            	**type**\:  :py:class:`Classification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification>`
            
            .. attribute:: custom
            
            	Custom PDL (protocol description language) Module
            	**type**\: list of  		 :py:class:`Custom <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom>`
            
            .. attribute:: protocol_pack
            
            	Protocol Pack
            	**type**\:  :py:class:`ProtocolPack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.ProtocolPack>`
            
            .. attribute:: http_services
            
            	Enable HTTP services
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-nbar'
            _revision = '2018-06-06'

            def __init__(self):
                super(Native.Ip.Nbar, self).__init__()

                self.yang_name = "nbar"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("attribute", ("attribute", Native.Ip.Nbar.Attribute)), ("attribute-map", ("attribute_map", Native.Ip.Nbar.AttributeMap)), ("attribute-set", ("attribute_set", Native.Ip.Nbar.AttributeSet)), ("classification", ("classification", Native.Ip.Nbar.Classification)), ("custom", ("custom", Native.Ip.Nbar.Custom)), ("protocol-pack", ("protocol_pack", Native.Ip.Nbar.ProtocolPack))])
                self._leafs = OrderedDict([
                    ('http_services', (YLeaf(YType.empty, 'http-services'), ['Empty'])),
                ])
                self.http_services = None

                self.attribute = Native.Ip.Nbar.Attribute()
                self.attribute.parent = self
                self._children_name_map["attribute"] = "attribute"

                self.classification = Native.Ip.Nbar.Classification()
                self.classification.parent = self
                self._children_name_map["classification"] = "classification"

                self.protocol_pack = Native.Ip.Nbar.ProtocolPack()
                self.protocol_pack.parent = self
                self._children_name_map["protocol_pack"] = "protocol-pack"

                self.attribute_map = YList(self)
                self.attribute_set = YList(self)
                self.custom = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Nbar, ['http_services'], name, value)


            class Attribute(Entity):
                """
                Attribute for which custom group value can be created
                
                .. attribute:: application_group
                
                	Application\-group attribute
                	**type**\:  :py:class:`ApplicationGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Attribute.ApplicationGroup>`
                
                .. attribute:: application_set
                
                	Application\-set attribute
                	**type**\:  :py:class:`ApplicationSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Attribute.ApplicationSet>`
                
                .. attribute:: category
                
                	Category attribute
                	**type**\:  :py:class:`Category <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Attribute.Category>`
                
                .. attribute:: sub_category
                
                	Sub\-category attribute
                	**type**\:  :py:class:`SubCategory <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Attribute.SubCategory>`
                
                

                """

                _prefix = 'ios-nbar'
                _revision = '2018-06-06'

                def __init__(self):
                    super(Native.Ip.Nbar.Attribute, self).__init__()

                    self.yang_name = "attribute"
                    self.yang_parent_name = "nbar"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("application-group", ("application_group", Native.Ip.Nbar.Attribute.ApplicationGroup)), ("application-set", ("application_set", Native.Ip.Nbar.Attribute.ApplicationSet)), ("category", ("category", Native.Ip.Nbar.Attribute.Category)), ("sub-category", ("sub_category", Native.Ip.Nbar.Attribute.SubCategory))])
                    self._leafs = OrderedDict()

                    self.application_group = Native.Ip.Nbar.Attribute.ApplicationGroup()
                    self.application_group.parent = self
                    self._children_name_map["application_group"] = "application-group"

                    self.application_set = Native.Ip.Nbar.Attribute.ApplicationSet()
                    self.application_set.parent = self
                    self._children_name_map["application_set"] = "application-set"

                    self.category = Native.Ip.Nbar.Attribute.Category()
                    self.category.parent = self
                    self._children_name_map["category"] = "category"

                    self.sub_category = Native.Ip.Nbar.Attribute.SubCategory()
                    self.sub_category.parent = self
                    self._children_name_map["sub_category"] = "sub-category"
                    self._segment_path = lambda: "attribute"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Nbar.Attribute, [], name, value)


                class ApplicationGroup(Entity):
                    """
                    Application\-group attribute
                    
                    .. attribute:: custom
                    
                    	Custom group to be created for this attribute
                    	**type**\: list of  		 :py:class:`Custom <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Attribute.ApplicationGroup.Custom>`
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Attribute.ApplicationGroup, self).__init__()

                        self.yang_name = "application-group"
                        self.yang_parent_name = "attribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("custom", ("custom", Native.Ip.Nbar.Attribute.ApplicationGroup.Custom))])
                        self._leafs = OrderedDict()

                        self.custom = YList(self)
                        self._segment_path = lambda: "application-group"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/attribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Attribute.ApplicationGroup, [], name, value)


                    class Custom(Entity):
                        """
                        Custom group to be created for this attribute
                        
                        .. attribute:: name  (key)
                        
                        	Custom group value
                        	**type**\: str
                        
                        .. attribute:: help
                        
                        	Help string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Attribute.ApplicationGroup.Custom, self).__init__()

                            self.yang_name = "custom"
                            self.yang_parent_name = "application-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('help', (YLeaf(YType.str, 'help'), ['str'])),
                            ])
                            self.name = None
                            self.help = None
                            self._segment_path = lambda: "custom" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/attribute/application-group/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Attribute.ApplicationGroup.Custom, ['name', 'help'], name, value)


                class ApplicationSet(Entity):
                    """
                    Application\-set attribute
                    
                    .. attribute:: custom
                    
                    	Custom group to be created for this attribute
                    	**type**\: list of  		 :py:class:`Custom <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Attribute.ApplicationSet.Custom>`
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Attribute.ApplicationSet, self).__init__()

                        self.yang_name = "application-set"
                        self.yang_parent_name = "attribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("custom", ("custom", Native.Ip.Nbar.Attribute.ApplicationSet.Custom))])
                        self._leafs = OrderedDict()

                        self.custom = YList(self)
                        self._segment_path = lambda: "application-set"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/attribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Attribute.ApplicationSet, [], name, value)


                    class Custom(Entity):
                        """
                        Custom group to be created for this attribute
                        
                        .. attribute:: name  (key)
                        
                        	Custom group value
                        	**type**\: str
                        
                        .. attribute:: help
                        
                        	Help string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Attribute.ApplicationSet.Custom, self).__init__()

                            self.yang_name = "custom"
                            self.yang_parent_name = "application-set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('help', (YLeaf(YType.str, 'help'), ['str'])),
                            ])
                            self.name = None
                            self.help = None
                            self._segment_path = lambda: "custom" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/attribute/application-set/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Attribute.ApplicationSet.Custom, ['name', 'help'], name, value)


                class Category(Entity):
                    """
                    Category attribute
                    
                    .. attribute:: custom
                    
                    	Custom group to be created for this attribute
                    	**type**\: list of  		 :py:class:`Custom <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Attribute.Category.Custom>`
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Attribute.Category, self).__init__()

                        self.yang_name = "category"
                        self.yang_parent_name = "attribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("custom", ("custom", Native.Ip.Nbar.Attribute.Category.Custom))])
                        self._leafs = OrderedDict()

                        self.custom = YList(self)
                        self._segment_path = lambda: "category"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/attribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Attribute.Category, [], name, value)


                    class Custom(Entity):
                        """
                        Custom group to be created for this attribute
                        
                        .. attribute:: name  (key)
                        
                        	Custom group value
                        	**type**\: str
                        
                        .. attribute:: help
                        
                        	Help string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Attribute.Category.Custom, self).__init__()

                            self.yang_name = "custom"
                            self.yang_parent_name = "category"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('help', (YLeaf(YType.str, 'help'), ['str'])),
                            ])
                            self.name = None
                            self.help = None
                            self._segment_path = lambda: "custom" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/attribute/category/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Attribute.Category.Custom, ['name', 'help'], name, value)


                class SubCategory(Entity):
                    """
                    Sub\-category attribute
                    
                    .. attribute:: custom
                    
                    	Custom group to be created for this attribute
                    	**type**\: list of  		 :py:class:`Custom <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Attribute.SubCategory.Custom>`
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Attribute.SubCategory, self).__init__()

                        self.yang_name = "sub-category"
                        self.yang_parent_name = "attribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("custom", ("custom", Native.Ip.Nbar.Attribute.SubCategory.Custom))])
                        self._leafs = OrderedDict()

                        self.custom = YList(self)
                        self._segment_path = lambda: "sub-category"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/attribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Attribute.SubCategory, [], name, value)


                    class Custom(Entity):
                        """
                        Custom group to be created for this attribute
                        
                        .. attribute:: name  (key)
                        
                        	Custom group value
                        	**type**\: str
                        
                        .. attribute:: help
                        
                        	Help string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Attribute.SubCategory.Custom, self).__init__()

                            self.yang_name = "custom"
                            self.yang_parent_name = "sub-category"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('help', (YLeaf(YType.str, 'help'), ['str'])),
                            ])
                            self.name = None
                            self.help = None
                            self._segment_path = lambda: "custom" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/attribute/sub-category/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Attribute.SubCategory.Custom, ['name', 'help'], name, value)


            class AttributeMap(Entity):
                """
                Attribute Map
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: attribute
                
                	Attribute Name
                	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.AttributeMap.Attribute>`
                
                

                """

                _prefix = 'ios-nbar'
                _revision = '2018-06-06'

                def __init__(self):
                    super(Native.Ip.Nbar.AttributeMap, self).__init__()

                    self.yang_name = "attribute-map"
                    self.yang_parent_name = "nbar"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("attribute", ("attribute", Native.Ip.Nbar.AttributeMap.Attribute))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.attribute = Native.Ip.Nbar.AttributeMap.Attribute()
                    self.attribute.parent = self
                    self._children_name_map["attribute"] = "attribute"
                    self._segment_path = lambda: "attribute-map" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Nbar.AttributeMap, ['name'], name, value)


                class Attribute(Entity):
                    """
                    Attribute Name
                    
                    .. attribute:: application_group
                    
                    	Application\-group attribute
                    	**type**\: str
                    
                    .. attribute:: application_set
                    
                    	Application\-set attribute
                    	**type**\: str
                    
                    .. attribute:: business_relevance
                    
                    	Application business\-relevance
                    	**type**\: str
                    
                    .. attribute:: category
                    
                    	Category attribute
                    	**type**\: str
                    
                    .. attribute:: encrypted
                    
                    	Encrypted applications
                    	**type**\: str
                    
                    .. attribute:: sub_category
                    
                    	Sub\-category attribute
                    	**type**\: str
                    
                    .. attribute:: traffic_class
                    
                    	SRND class
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnelled applications
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.AttributeMap.Attribute, self).__init__()

                        self.yang_name = "attribute"
                        self.yang_parent_name = "attribute-map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('application_group', (YLeaf(YType.str, 'application-group'), ['str'])),
                            ('application_set', (YLeaf(YType.str, 'application-set'), ['str'])),
                            ('business_relevance', (YLeaf(YType.str, 'business-relevance'), ['str'])),
                            ('category', (YLeaf(YType.str, 'category'), ['str'])),
                            ('encrypted', (YLeaf(YType.str, 'encrypted'), ['str'])),
                            ('sub_category', (YLeaf(YType.str, 'sub-category'), ['str'])),
                            ('traffic_class', (YLeaf(YType.str, 'traffic-class'), ['str'])),
                            ('tunnel', (YLeaf(YType.str, 'tunnel'), ['str'])),
                        ])
                        self.application_group = None
                        self.application_set = None
                        self.business_relevance = None
                        self.category = None
                        self.encrypted = None
                        self.sub_category = None
                        self.traffic_class = None
                        self.tunnel = None
                        self._segment_path = lambda: "attribute"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.AttributeMap.Attribute, ['application_group', 'application_set', 'business_relevance', 'category', 'encrypted', 'sub_category', 'traffic_class', 'tunnel'], name, value)


            class AttributeSet(Entity):
                """
                Set attribute Map
                
                .. attribute:: protocol_name  (key)
                
                	Protocol Name
                	**type**\: str
                
                .. attribute:: profile_name
                
                	Attribute Profile Name
                	**type**\: str
                
                

                """

                _prefix = 'ios-nbar'
                _revision = '2018-06-06'

                def __init__(self):
                    super(Native.Ip.Nbar.AttributeSet, self).__init__()

                    self.yang_name = "attribute-set"
                    self.yang_parent_name = "nbar"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['protocol_name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                        ('profile_name', (YLeaf(YType.str, 'profile-name'), ['str'])),
                    ])
                    self.protocol_name = None
                    self.profile_name = None
                    self._segment_path = lambda: "attribute-set" + "[protocol-name='" + str(self.protocol_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Nbar.AttributeSet, ['protocol_name', 'profile_name'], name, value)


            class Classification(Entity):
                """
                NBAR Classification
                
                .. attribute:: auto_learn
                
                	Statistics on unknown or generic traffic
                	**type**\:  :py:class:`AutoLearn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.AutoLearn>`
                
                	**presence node**\: True
                
                .. attribute:: dns
                
                	dns classification
                	**type**\:  :py:class:`Dns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Dns>`
                
                .. attribute:: granularity
                
                	Force granularity mode
                	**type**\:  :py:class:`Granularity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity>`
                
                .. attribute:: tunneled_traffic
                
                	Classify IPv6 Tunneled traffic
                	**type**\:  :py:class:`TunneledTraffic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.TunneledTraffic>`
                
                

                """

                _prefix = 'ios-nbar'
                _revision = '2018-06-06'

                def __init__(self):
                    super(Native.Ip.Nbar.Classification, self).__init__()

                    self.yang_name = "classification"
                    self.yang_parent_name = "nbar"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("auto-learn", ("auto_learn", Native.Ip.Nbar.Classification.AutoLearn)), ("dns", ("dns", Native.Ip.Nbar.Classification.Dns)), ("granularity", ("granularity", Native.Ip.Nbar.Classification.Granularity)), ("tunneled-traffic", ("tunneled_traffic", Native.Ip.Nbar.Classification.TunneledTraffic))])
                    self._leafs = OrderedDict()

                    self.auto_learn = None
                    self._children_name_map["auto_learn"] = "auto-learn"

                    self.dns = Native.Ip.Nbar.Classification.Dns()
                    self.dns.parent = self
                    self._children_name_map["dns"] = "dns"

                    self.granularity = Native.Ip.Nbar.Classification.Granularity()
                    self.granularity.parent = self
                    self._children_name_map["granularity"] = "granularity"

                    self.tunneled_traffic = Native.Ip.Nbar.Classification.TunneledTraffic()
                    self.tunneled_traffic.parent = self
                    self._children_name_map["tunneled_traffic"] = "tunneled-traffic"
                    self._segment_path = lambda: "classification"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Nbar.Classification, [], name, value)


                class AutoLearn(Entity):
                    """
                    Statistics on unknown or generic traffic
                    
                    .. attribute:: top_asymmetric_socket
                    
                    	Statistics on asymmetric socket
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: top_hosts
                    
                    	Statistics on generic traffic per host
                    	**type**\:  :py:class:`TopHosts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.AutoLearn.TopHosts>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: top_ports
                    
                    	Statistics on unknown traffic per port
                    	**type**\:  :py:class:`TopPorts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.AutoLearn.TopPorts>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Classification.AutoLearn, self).__init__()

                        self.yang_name = "auto-learn"
                        self.yang_parent_name = "classification"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("top-hosts", ("top_hosts", Native.Ip.Nbar.Classification.AutoLearn.TopHosts)), ("top-ports", ("top_ports", Native.Ip.Nbar.Classification.AutoLearn.TopPorts))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('top_asymmetric_socket', (YLeaf(YType.empty, 'top-asymmetric-socket'), ['Empty'])),
                        ])
                        self.top_asymmetric_socket = None

                        self.top_hosts = None
                        self._children_name_map["top_hosts"] = "top-hosts"

                        self.top_ports = None
                        self._children_name_map["top_ports"] = "top-ports"
                        self._segment_path = lambda: "auto-learn"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Classification.AutoLearn, ['top_asymmetric_socket'], name, value)


                    class TopHosts(Entity):
                        """
                        Statistics on generic traffic per host
                        
                        .. attribute:: sample_rate
                        
                        	configure sampling rate
                        	**type**\: int
                        
                        	**range:** 1..8192
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Classification.AutoLearn.TopHosts, self).__init__()

                            self.yang_name = "top-hosts"
                            self.yang_parent_name = "auto-learn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('sample_rate', (YLeaf(YType.uint16, 'sample-rate'), ['int'])),
                            ])
                            self.sample_rate = None
                            self._segment_path = lambda: "top-hosts"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/auto-learn/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Classification.AutoLearn.TopHosts, ['sample_rate'], name, value)


                    class TopPorts(Entity):
                        """
                        Statistics on unknown traffic per port
                        
                        .. attribute:: sample_rate
                        
                        	configure sampling rate
                        	**type**\: int
                        
                        	**range:** 1..8192
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Classification.AutoLearn.TopPorts, self).__init__()

                            self.yang_name = "top-ports"
                            self.yang_parent_name = "auto-learn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('sample_rate', (YLeaf(YType.uint16, 'sample-rate'), ['int'])),
                            ])
                            self.sample_rate = None
                            self._segment_path = lambda: "top-ports"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/auto-learn/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Classification.AutoLearn.TopPorts, ['sample_rate'], name, value)


                class Dns(Entity):
                    """
                    dns classification
                    
                    .. attribute:: classify_by_domain
                    
                    	dns classification by domain
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: learning
                    
                    	dns learning
                    	**type**\:  :py:class:`Learning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Dns.Learning>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Classification.Dns, self).__init__()

                        self.yang_name = "dns"
                        self.yang_parent_name = "classification"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("learning", ("learning", Native.Ip.Nbar.Classification.Dns.Learning))])
                        self._leafs = OrderedDict([
                            ('classify_by_domain', (YLeaf(YType.empty, 'classify-by-domain'), ['Empty'])),
                        ])
                        self.classify_by_domain = None

                        self.learning = None
                        self._children_name_map["learning"] = "learning"
                        self._segment_path = lambda: "dns"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Classification.Dns, ['classify_by_domain'], name, value)


                    class Learning(Entity):
                        """
                        dns learning
                        
                        .. attribute:: guard
                        
                        	dns guard prevents learning from responses only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Classification.Dns.Learning, self).__init__()

                            self.yang_name = "learning"
                            self.yang_parent_name = "dns"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('guard', (YLeaf(YType.empty, 'guard'), ['Empty'])),
                            ])
                            self.guard = None
                            self._segment_path = lambda: "learning"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/dns/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Classification.Dns.Learning, ['guard'], name, value)


                class Granularity(Entity):
                    """
                    Force granularity mode
                    
                    .. attribute:: coarse_grain
                    
                    	Force coarse\-grain classification mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: fine_grain
                    
                    	Force fine\-grain classification mode
                    	**type**\:  :py:class:`FineGrain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Classification.Granularity, self).__init__()

                        self.yang_name = "granularity"
                        self.yang_parent_name = "classification"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("fine-grain", ("fine_grain", Native.Ip.Nbar.Classification.Granularity.FineGrain))])
                        self._leafs = OrderedDict([
                            ('coarse_grain', (YLeaf(YType.empty, 'coarse-grain'), ['Empty'])),
                        ])
                        self.coarse_grain = None

                        self.fine_grain = None
                        self._children_name_map["fine_grain"] = "fine-grain"
                        self._segment_path = lambda: "granularity"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Classification.Granularity, ['coarse_grain'], name, value)


                    class FineGrain(Entity):
                        """
                        Force fine\-grain classification mode
                        
                        .. attribute:: attribute
                        
                        	Force granularity for a single attribute
                        	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute>`
                        
                        .. attribute:: protocol
                        
                        	Force granularity for a single protocol
                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain.Protocol>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Classification.Granularity.FineGrain, self).__init__()

                            self.yang_name = "fine-grain"
                            self.yang_parent_name = "granularity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("attribute", ("attribute", Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute)), ("protocol", ("protocol", Native.Ip.Nbar.Classification.Granularity.FineGrain.Protocol))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.attribute = Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute()
                            self.attribute.parent = self
                            self._children_name_map["attribute"] = "attribute"

                            self.protocol = Native.Ip.Nbar.Classification.Granularity.FineGrain.Protocol()
                            self.protocol.parent = self
                            self._children_name_map["protocol"] = "protocol"
                            self._segment_path = lambda: "fine-grain"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain, [], name, value)


                        class Attribute(Entity):
                            """
                            Force granularity for a single attribute
                            
                            .. attribute:: application_group
                            
                            	Application\-group attribute
                            	**type**\: list of  		 :py:class:`ApplicationGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.ApplicationGroup>`
                            
                            .. attribute:: application_set
                            
                            	Application\-set attribute
                            	**type**\: list of  		 :py:class:`ApplicationSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.ApplicationSet>`
                            
                            .. attribute:: business_relevance
                            
                            	Application business\-relevance
                            	**type**\: list of  		 :py:class:`BusinessRelevance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.BusinessRelevance>`
                            
                            .. attribute:: category
                            
                            	Category attribute
                            	**type**\: list of  		 :py:class:`Category <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Category>`
                            
                            .. attribute:: encrypted
                            
                            	Encrypted applications
                            	**type**\: list of  		 :py:class:`Encrypted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Encrypted>`
                            
                            .. attribute:: sub_category
                            
                            	Sub\-category attribute
                            	**type**\: list of  		 :py:class:`SubCategory <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.SubCategory>`
                            
                            .. attribute:: traffic_class
                            
                            	SRND class
                            	**type**\: list of  		 :py:class:`TrafficClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.TrafficClass>`
                            
                            .. attribute:: tunnel
                            
                            	Tunnelled applications
                            	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Tunnel>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute, self).__init__()

                                self.yang_name = "attribute"
                                self.yang_parent_name = "fine-grain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("application-group", ("application_group", Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.ApplicationGroup)), ("application-set", ("application_set", Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.ApplicationSet)), ("business-relevance", ("business_relevance", Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.BusinessRelevance)), ("category", ("category", Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Category)), ("encrypted", ("encrypted", Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Encrypted)), ("sub-category", ("sub_category", Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.SubCategory)), ("traffic-class", ("traffic_class", Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.TrafficClass)), ("tunnel", ("tunnel", Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Tunnel))])
                                self._leafs = OrderedDict()

                                self.application_group = YList(self)
                                self.application_set = YList(self)
                                self.business_relevance = YList(self)
                                self.category = YList(self)
                                self.encrypted = YList(self)
                                self.sub_category = YList(self)
                                self.traffic_class = YList(self)
                                self.tunnel = YList(self)
                                self._segment_path = lambda: "attribute"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/fine-grain/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute, [], name, value)


                            class ApplicationGroup(Entity):
                                """
                                Application\-group attribute
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.ApplicationGroup, self).__init__()

                                    self.yang_name = "application-group"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "application-group" + "[name='" + str(self.name) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/fine-grain/attribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.ApplicationGroup, ['name'], name, value)


                            class ApplicationSet(Entity):
                                """
                                Application\-set attribute
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.ApplicationSet, self).__init__()

                                    self.yang_name = "application-set"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "application-set" + "[name='" + str(self.name) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/fine-grain/attribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.ApplicationSet, ['name'], name, value)


                            class BusinessRelevance(Entity):
                                """
                                Application business\-relevance
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.BusinessRelevance, self).__init__()

                                    self.yang_name = "business-relevance"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "business-relevance" + "[name='" + str(self.name) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/fine-grain/attribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.BusinessRelevance, ['name'], name, value)


                            class Category(Entity):
                                """
                                Category attribute
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Category, self).__init__()

                                    self.yang_name = "category"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "category" + "[name='" + str(self.name) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/fine-grain/attribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Category, ['name'], name, value)


                            class Encrypted(Entity):
                                """
                                Encrypted applications
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Encrypted, self).__init__()

                                    self.yang_name = "encrypted"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "encrypted" + "[name='" + str(self.name) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/fine-grain/attribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Encrypted, ['name'], name, value)


                            class SubCategory(Entity):
                                """
                                Sub\-category attribute
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.SubCategory, self).__init__()

                                    self.yang_name = "sub-category"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "sub-category" + "[name='" + str(self.name) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/fine-grain/attribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.SubCategory, ['name'], name, value)


                            class TrafficClass(Entity):
                                """
                                SRND class
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.TrafficClass, self).__init__()

                                    self.yang_name = "traffic-class"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "traffic-class" + "[name='" + str(self.name) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/fine-grain/attribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.TrafficClass, ['name'], name, value)


                            class Tunnel(Entity):
                                """
                                Tunnelled applications
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Tunnel, self).__init__()

                                    self.yang_name = "tunnel"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "tunnel" + "[name='" + str(self.name) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/fine-grain/attribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain.Attribute.Tunnel, ['name'], name, value)


                        class Protocol(Entity):
                            """
                            Force granularity for a single protocol
                            
                            .. attribute:: protocols_list
                            
                            	
                            	**type**\: list of  		 :py:class:`ProtocolsList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Classification.Granularity.FineGrain.Protocol.ProtocolsList>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Classification.Granularity.FineGrain.Protocol, self).__init__()

                                self.yang_name = "protocol"
                                self.yang_parent_name = "fine-grain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("protocols-list", ("protocols_list", Native.Ip.Nbar.Classification.Granularity.FineGrain.Protocol.ProtocolsList))])
                                self._leafs = OrderedDict()

                                self.protocols_list = YList(self)
                                self._segment_path = lambda: "protocol"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/fine-grain/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain.Protocol, [], name, value)


                            class ProtocolsList(Entity):
                                """
                                
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Classification.Granularity.FineGrain.Protocol.ProtocolsList, self).__init__()

                                    self.yang_name = "protocols-list"
                                    self.yang_parent_name = "protocol"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "protocols-list" + "[name='" + str(self.name) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/granularity/fine-grain/protocol/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Classification.Granularity.FineGrain.Protocol.ProtocolsList, ['name'], name, value)


                class TunneledTraffic(Entity):
                    """
                    Classify IPv6 Tunneled traffic
                    
                    .. attribute:: capwap
                    
                    	Tunnel type CAPWAP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipv6inip
                    
                    	Tunnel type IPv6 in IPv4
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: teredo
                    
                    	Tunnel type TEREDO
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Classification.TunneledTraffic, self).__init__()

                        self.yang_name = "tunneled-traffic"
                        self.yang_parent_name = "classification"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('capwap', (YLeaf(YType.empty, 'capwap'), ['Empty'])),
                            ('ipv6inip', (YLeaf(YType.empty, 'ipv6inip'), ['Empty'])),
                            ('teredo', (YLeaf(YType.empty, 'teredo'), ['Empty'])),
                        ])
                        self.capwap = None
                        self.ipv6inip = None
                        self.teredo = None
                        self._segment_path = lambda: "tunneled-traffic"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/classification/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Classification.TunneledTraffic, ['capwap', 'ipv6inip', 'teredo'], name, value)


            class Custom(Entity):
                """
                Custom PDL (protocol description language) Module
                
                .. attribute:: name  (key)
                
                	Name of the User defined Protocol
                	**type**\: str
                
                .. attribute:: composite
                
                	Custom protocols based on multiple underlying protocols
                	**type**\:  :py:class:`Composite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Composite>`
                
                .. attribute:: dns
                
                	Custom protocols based on dns parameters
                	**type**\:  :py:class:`Dns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Dns>`
                
                .. attribute:: http
                
                	Custom protocols based on http parameters
                	**type**\:  :py:class:`Http <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Http>`
                
                .. attribute:: ssl
                
                	Custom protocols based on ssl parameters
                	**type**\:  :py:class:`Ssl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ssl>`
                
                .. attribute:: transport
                
                	Custom protocols based on the transport layer and below
                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport>`
                
                .. attribute:: ip
                
                	Custom protocols based on the transport layer and below
                	**type**\:  :py:class:`Ip_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_>`
                
                

                """

                _prefix = 'ios-nbar'
                _revision = '2018-06-06'

                def __init__(self):
                    super(Native.Ip.Nbar.Custom, self).__init__()

                    self.yang_name = "custom"
                    self.yang_parent_name = "nbar"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("composite", ("composite", Native.Ip.Nbar.Custom.Composite)), ("dns", ("dns", Native.Ip.Nbar.Custom.Dns)), ("http", ("http", Native.Ip.Nbar.Custom.Http)), ("ssl", ("ssl", Native.Ip.Nbar.Custom.Ssl)), ("transport", ("transport", Native.Ip.Nbar.Custom.Transport)), ("ip", ("ip", Native.Ip.Nbar.Custom.Ip_))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.composite = Native.Ip.Nbar.Custom.Composite()
                    self.composite.parent = self
                    self._children_name_map["composite"] = "composite"

                    self.dns = Native.Ip.Nbar.Custom.Dns()
                    self.dns.parent = self
                    self._children_name_map["dns"] = "dns"

                    self.http = Native.Ip.Nbar.Custom.Http()
                    self.http.parent = self
                    self._children_name_map["http"] = "http"

                    self.ssl = Native.Ip.Nbar.Custom.Ssl()
                    self.ssl.parent = self
                    self._children_name_map["ssl"] = "ssl"

                    self.transport = Native.Ip.Nbar.Custom.Transport()
                    self.transport.parent = self
                    self._children_name_map["transport"] = "transport"

                    self.ip = Native.Ip.Nbar.Custom.Ip_()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "custom" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Nbar.Custom, ['name'], name, value)


                class Composite(Entity):
                    """
                    Custom protocols based on multiple underlying protocols
                    
                    .. attribute:: server_name
                    
                    	Match the server name based on various protocols
                    	**type**\: list of  		 :py:class:`ServerName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Composite.ServerName>`
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Custom.Composite, self).__init__()

                        self.yang_name = "composite"
                        self.yang_parent_name = "custom"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("server-name", ("server_name", Native.Ip.Nbar.Custom.Composite.ServerName))])
                        self._leafs = OrderedDict()

                        self.server_name = YList(self)
                        self._segment_path = lambda: "composite"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Custom.Composite, [], name, value)


                    class ServerName(Entity):
                        """
                        Match the server name based on various protocols
                        
                        .. attribute:: name  (key)
                        
                        	Enter String Format \- cannot exceed 30 characters
                        	**type**\: str
                        
                        .. attribute:: id
                        
                        	Enter Selector ID
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: extends
                        
                        	Extend existing protocol
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Custom.Composite.ServerName, self).__init__()

                            self.yang_name = "server-name"
                            self.yang_parent_name = "composite"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('extends', (YLeaf(YType.str, 'extends'), ['str'])),
                            ])
                            self.name = None
                            self.id = None
                            self.extends = None
                            self._segment_path = lambda: "server-name" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Custom.Composite.ServerName, ['name', 'id', 'extends'], name, value)


                class Dns(Entity):
                    """
                    Custom protocols based on dns parameters
                    
                    .. attribute:: domain_name
                    
                    	Domain name
                    	**type**\: list of  		 :py:class:`DomainName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Dns.DomainName>`
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Custom.Dns, self).__init__()

                        self.yang_name = "dns"
                        self.yang_parent_name = "custom"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("domain-name", ("domain_name", Native.Ip.Nbar.Custom.Dns.DomainName))])
                        self._leafs = OrderedDict()

                        self.domain_name = YList(self)
                        self._segment_path = lambda: "dns"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Custom.Dns, [], name, value)


                    class DomainName(Entity):
                        """
                        Domain name
                        
                        .. attribute:: name  (key)
                        
                        	Enter String Format \- cannot exceed 30 characters
                        	**type**\: str
                        
                        .. attribute:: id
                        
                        	Selector ID
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: extends
                        
                        	Extend existing protocol
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Custom.Dns.DomainName, self).__init__()

                            self.yang_name = "domain-name"
                            self.yang_parent_name = "dns"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('extends', (YLeaf(YType.str, 'extends'), ['str'])),
                            ])
                            self.name = None
                            self.id = None
                            self.extends = None
                            self._segment_path = lambda: "domain-name" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Custom.Dns.DomainName, ['name', 'id', 'extends'], name, value)


                class Http(Entity):
                    """
                    Custom protocols based on http parameters
                    
                    .. attribute:: cookie
                    
                    	HTTP Cookie
                    	**type**\: str
                    
                    .. attribute:: host
                    
                    	Host name of Origin Server containing resource
                    	**type**\: str
                    
                    .. attribute:: method
                    
                    	HTTP method
                    	**type**\: str
                    
                    .. attribute:: referer
                    
                    	Address the resource request was obtained from
                    	**type**\: str
                    
                    .. attribute:: url
                    
                    	Uniform Resource Locator path
                    	**type**\: str
                    
                    .. attribute:: user_agent
                    
                    	Software used by agent sending the request
                    	**type**\: str
                    
                    .. attribute:: version
                    
                    	HTTP version
                    	**type**\: str
                    
                    .. attribute:: via
                    
                    	HTTP via field
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	Selector ID
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Custom.Http, self).__init__()

                        self.yang_name = "http"
                        self.yang_parent_name = "custom"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('cookie', (YLeaf(YType.str, 'cookie'), ['str'])),
                            ('host', (YLeaf(YType.str, 'host'), ['str'])),
                            ('method', (YLeaf(YType.str, 'method'), ['str'])),
                            ('referer', (YLeaf(YType.str, 'referer'), ['str'])),
                            ('url', (YLeaf(YType.str, 'url'), ['str'])),
                            ('user_agent', (YLeaf(YType.str, 'user-agent'), ['str'])),
                            ('version', (YLeaf(YType.str, 'version'), ['str'])),
                            ('via', (YLeaf(YType.str, 'via'), ['str'])),
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                        ])
                        self.cookie = None
                        self.host = None
                        self.method = None
                        self.referer = None
                        self.url = None
                        self.user_agent = None
                        self.version = None
                        self.via = None
                        self.id = None
                        self._segment_path = lambda: "http"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Custom.Http, ['cookie', 'host', 'method', 'referer', 'url', 'user_agent', 'version', 'via', 'id'], name, value)


                class Ssl(Entity):
                    """
                    Custom protocols based on ssl parameters
                    
                    .. attribute:: unique_name
                    
                    	SSL Server Name Indication (SNI) or Common Name (CN)
                    	**type**\: list of  		 :py:class:`UniqueName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ssl.UniqueName>`
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Custom.Ssl, self).__init__()

                        self.yang_name = "ssl"
                        self.yang_parent_name = "custom"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("unique-name", ("unique_name", Native.Ip.Nbar.Custom.Ssl.UniqueName))])
                        self._leafs = OrderedDict()

                        self.unique_name = YList(self)
                        self._segment_path = lambda: "ssl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Custom.Ssl, [], name, value)


                    class UniqueName(Entity):
                        """
                        SSL Server Name Indication (SNI) or Common Name (CN)
                        
                        .. attribute:: name  (key)
                        
                        	Enter String Format \- cannot exceed 30 characters
                        	**type**\: str
                        
                        .. attribute:: id
                        
                        	Enter Selector ID
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Custom.Ssl.UniqueName, self).__init__()

                            self.yang_name = "unique-name"
                            self.yang_parent_name = "ssl"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ])
                            self.name = None
                            self.id = None
                            self._segment_path = lambda: "unique-name" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Custom.Ssl.UniqueName, ['name', 'id'], name, value)


                class Transport(Entity):
                    """
                    Custom protocols based on the transport layer and below
                    
                    .. attribute:: tcp
                    
                    	TCP transport
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: udp
                    
                    	UDP transport
                    	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: udp_tcp
                    
                    	UDP or TCP transport
                    	**type**\:  :py:class:`UdpTcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Custom.Transport, self).__init__()

                        self.yang_name = "transport"
                        self.yang_parent_name = "custom"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tcp", ("tcp", Native.Ip.Nbar.Custom.Transport.Tcp)), ("udp", ("udp", Native.Ip.Nbar.Custom.Transport.Udp)), ("udp-tcp", ("udp_tcp", Native.Ip.Nbar.Custom.Transport.UdpTcp))])
                        self._leafs = OrderedDict()

                        self.tcp = None
                        self._children_name_map["tcp"] = "tcp"

                        self.udp = None
                        self._children_name_map["udp"] = "udp"

                        self.udp_tcp = None
                        self._children_name_map["udp_tcp"] = "udp-tcp"
                        self._segment_path = lambda: "transport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Custom.Transport, [], name, value)


                    class Tcp(Entity):
                        """
                        TCP transport
                        
                        .. attribute:: id
                        
                        	Selector ID
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dscp
                        
                        	DSCP in IPv4 and IPv6 packets
                        	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp.Dscp>`
                        
                        .. attribute:: ip
                        
                        	ip address
                        	**type**\:  :py:class:`Ip_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp.Ip_>`
                        
                        .. attribute:: ipv6
                        
                        	ipv6 address
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6>`
                        
                        .. attribute:: direction
                        
                        	Flow direction
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp.Direction>`
                        
                        .. attribute:: port
                        
                        	ports
                        	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp.Port>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Custom.Transport.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dscp", ("dscp", Native.Ip.Nbar.Custom.Transport.Tcp.Dscp)), ("ip", ("ip", Native.Ip.Nbar.Custom.Transport.Tcp.Ip_)), ("ipv6", ("ipv6", Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6)), ("direction", ("direction", Native.Ip.Nbar.Custom.Transport.Tcp.Direction)), ("port", ("port", Native.Ip.Nbar.Custom.Transport.Tcp.Port))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.dscp = Native.Ip.Nbar.Custom.Transport.Tcp.Dscp()
                            self.dscp.parent = self
                            self._children_name_map["dscp"] = "dscp"

                            self.ip = Native.Ip.Nbar.Custom.Transport.Tcp.Ip_()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"

                            self.ipv6 = Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.direction = Native.Ip.Nbar.Custom.Transport.Tcp.Direction()
                            self.direction.parent = self
                            self._children_name_map["direction"] = "direction"

                            self.port = Native.Ip.Nbar.Custom.Transport.Tcp.Port()
                            self.port.parent = self
                            self._children_name_map["port"] = "port"
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp, ['id'], name, value)


                        class Dscp(Entity):
                            """
                            DSCP in IPv4 and IPv6 packets
                            
                            .. attribute:: range
                            
                            	Differentiated services codepoint value
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: af11
                            
                            	Match packets with AF11 dscp (001010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af12
                            
                            	Match packets with AF12 dscp (001100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af13
                            
                            	Match packets with AF13 dscp (001110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af21
                            
                            	Match packets with AF21 dscp (010010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af22
                            
                            	Match packets with AF22 dscp (010100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af23
                            
                            	Match packets with AF23 dscp (010110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af31
                            
                            	Match packets with AF31 dscp (011010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af32
                            
                            	Match packets with AF32 dscp (011100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af33
                            
                            	Match packets with AF33 dscp (011110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af41
                            
                            	Match packets with AF41 dscp (100010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af42
                            
                            	Match packets with AF42 dscp (100100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af43
                            
                            	Match packets with AF43 dscp (100110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs1
                            
                            	Match packets with CS1(precedence 1) dscp (001000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs2
                            
                            	Match packets with CS2(precedence 2) dscp (010000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs3
                            
                            	Match packets with CS3(precedence 3) dscp (011000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs4
                            
                            	Match packets with CS4(precedence 4) dscp (100000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs5
                            
                            	Match packets with CS5(precedence 5) dscp (101000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs6
                            
                            	Match packets with CS6(precedence 6) dscp (110000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs7
                            
                            	Match packets with CS7(precedence 7) dscp (111000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: default
                            
                            	Match packets with default dscp (000000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ef
                            
                            	Match packets with EF dscp (101110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.Tcp.Dscp, self).__init__()

                                self.yang_name = "dscp"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                    ('af11', (YLeaf(YType.empty, 'af11'), ['Empty'])),
                                    ('af12', (YLeaf(YType.empty, 'af12'), ['Empty'])),
                                    ('af13', (YLeaf(YType.empty, 'af13'), ['Empty'])),
                                    ('af21', (YLeaf(YType.empty, 'af21'), ['Empty'])),
                                    ('af22', (YLeaf(YType.empty, 'af22'), ['Empty'])),
                                    ('af23', (YLeaf(YType.empty, 'af23'), ['Empty'])),
                                    ('af31', (YLeaf(YType.empty, 'af31'), ['Empty'])),
                                    ('af32', (YLeaf(YType.empty, 'af32'), ['Empty'])),
                                    ('af33', (YLeaf(YType.empty, 'af33'), ['Empty'])),
                                    ('af41', (YLeaf(YType.empty, 'af41'), ['Empty'])),
                                    ('af42', (YLeaf(YType.empty, 'af42'), ['Empty'])),
                                    ('af43', (YLeaf(YType.empty, 'af43'), ['Empty'])),
                                    ('cs1', (YLeaf(YType.empty, 'cs1'), ['Empty'])),
                                    ('cs2', (YLeaf(YType.empty, 'cs2'), ['Empty'])),
                                    ('cs3', (YLeaf(YType.empty, 'cs3'), ['Empty'])),
                                    ('cs4', (YLeaf(YType.empty, 'cs4'), ['Empty'])),
                                    ('cs5', (YLeaf(YType.empty, 'cs5'), ['Empty'])),
                                    ('cs6', (YLeaf(YType.empty, 'cs6'), ['Empty'])),
                                    ('cs7', (YLeaf(YType.empty, 'cs7'), ['Empty'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ('ef', (YLeaf(YType.empty, 'ef'), ['Empty'])),
                                ])
                                self.range = None
                                self.af11 = None
                                self.af12 = None
                                self.af13 = None
                                self.af21 = None
                                self.af22 = None
                                self.af23 = None
                                self.af31 = None
                                self.af32 = None
                                self.af33 = None
                                self.af41 = None
                                self.af42 = None
                                self.af43 = None
                                self.cs1 = None
                                self.cs2 = None
                                self.cs3 = None
                                self.cs4 = None
                                self.cs5 = None
                                self.cs6 = None
                                self.cs7 = None
                                self.default = None
                                self.ef = None
                                self._segment_path = lambda: "dscp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp.Dscp, ['range', 'af11', 'af12', 'af13', 'af21', 'af22', 'af23', 'af31', 'af32', 'af33', 'af41', 'af42', 'af43', 'cs1', 'cs2', 'cs3', 'cs4', 'cs5', 'cs6', 'cs7', 'default', 'ef'], name, value)


                        class Ip_(Entity):
                            """
                            ip address
                            
                            .. attribute:: address
                            
                            	ip address list
                            	**type**\: list of  		 :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp.Ip_.Address>`
                            
                            .. attribute:: subnet
                            
                            	Subnet IP/mask length
                            	**type**\:  :py:class:`Subnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp.Ip_.Subnet>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.Tcp.Ip_, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Ip.Nbar.Custom.Transport.Tcp.Ip_.Address)), ("subnet", ("subnet", Native.Ip.Nbar.Custom.Transport.Tcp.Ip_.Subnet))])
                                self._leafs = OrderedDict()

                                self.subnet = Native.Ip.Nbar.Custom.Transport.Tcp.Ip_.Subnet()
                                self.subnet.parent = self
                                self._children_name_map["subnet"] = "subnet"

                                self.address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp.Ip_, [], name, value)


                            class Address(Entity):
                                """
                                ip address list
                                
                                .. attribute:: address0  (key)
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address1
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address2
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address3
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address4
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address5
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address6
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address7
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Tcp.Ip_.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['address0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address0', (YLeaf(YType.str, 'address0'), ['str'])),
                                        ('address1', (YLeaf(YType.str, 'address1'), ['str'])),
                                        ('address2', (YLeaf(YType.str, 'address2'), ['str'])),
                                        ('address3', (YLeaf(YType.str, 'address3'), ['str'])),
                                        ('address4', (YLeaf(YType.str, 'address4'), ['str'])),
                                        ('address5', (YLeaf(YType.str, 'address5'), ['str'])),
                                        ('address6', (YLeaf(YType.str, 'address6'), ['str'])),
                                        ('address7', (YLeaf(YType.str, 'address7'), ['str'])),
                                    ])
                                    self.address0 = None
                                    self.address1 = None
                                    self.address2 = None
                                    self.address3 = None
                                    self.address4 = None
                                    self.address5 = None
                                    self.address6 = None
                                    self.address7 = None
                                    self._segment_path = lambda: "address" + "[address0='" + str(self.address0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp.Ip_.Address, ['address0', 'address1', 'address2', 'address3', 'address4', 'address5', 'address6', 'address7'], name, value)


                            class Subnet(Entity):
                                """
                                Subnet IP/mask length
                                
                                .. attribute:: subnet
                                
                                	Subnet IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..32
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Tcp.Ip_.Subnet, self).__init__()

                                    self.yang_name = "subnet"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subnet', (YLeaf(YType.str, 'subnet'), ['str'])),
                                        ('mask', (YLeaf(YType.uint8, 'mask'), ['int'])),
                                    ])
                                    self.subnet = None
                                    self.mask = None
                                    self._segment_path = lambda: "subnet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp.Ip_.Subnet, ['subnet', 'mask'], name, value)


                        class Ipv6(Entity):
                            """
                            ipv6 address
                            
                            .. attribute:: address
                            
                            	ipv6 address list
                            	**type**\: list of  		 :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6.Address>`
                            
                            .. attribute:: subnet
                            
                            	Subnet IP/mask length
                            	**type**\:  :py:class:`Subnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6.Subnet>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6.Address)), ("subnet", ("subnet", Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6.Subnet))])
                                self._leafs = OrderedDict()

                                self.subnet = Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6.Subnet()
                                self.subnet.parent = self
                                self._children_name_map["subnet"] = "subnet"

                                self.address = YList(self)
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6, [], name, value)


                            class Address(Entity):
                                """
                                ipv6 address list
                                
                                .. attribute:: address0  (key)
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address1
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address2
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address3
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address4
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address5
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address6
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address7
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['address0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address0', (YLeaf(YType.str, 'address0'), ['str'])),
                                        ('address1', (YLeaf(YType.str, 'address1'), ['str'])),
                                        ('address2', (YLeaf(YType.str, 'address2'), ['str'])),
                                        ('address3', (YLeaf(YType.str, 'address3'), ['str'])),
                                        ('address4', (YLeaf(YType.str, 'address4'), ['str'])),
                                        ('address5', (YLeaf(YType.str, 'address5'), ['str'])),
                                        ('address6', (YLeaf(YType.str, 'address6'), ['str'])),
                                        ('address7', (YLeaf(YType.str, 'address7'), ['str'])),
                                    ])
                                    self.address0 = None
                                    self.address1 = None
                                    self.address2 = None
                                    self.address3 = None
                                    self.address4 = None
                                    self.address5 = None
                                    self.address6 = None
                                    self.address7 = None
                                    self._segment_path = lambda: "address" + "[address0='" + str(self.address0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6.Address, ['address0', 'address1', 'address2', 'address3', 'address4', 'address5', 'address6', 'address7'], name, value)


                            class Subnet(Entity):
                                """
                                Subnet IP/mask length
                                
                                .. attribute:: subnet
                                
                                	Subnet IP
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6.Subnet, self).__init__()

                                    self.yang_name = "subnet"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subnet', (YLeaf(YType.str, 'subnet'), ['str'])),
                                        ('mask', (YLeaf(YType.uint8, 'mask'), ['int'])),
                                    ])
                                    self.subnet = None
                                    self.mask = None
                                    self._segment_path = lambda: "subnet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp.Ipv6.Subnet, ['subnet', 'mask'], name, value)


                        class Direction(Entity):
                            """
                            Flow direction
                            
                            .. attribute:: any
                            
                            	Any Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: destination
                            
                            	Destination Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: source
                            
                            	Source Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.Tcp.Direction, self).__init__()

                                self.yang_name = "direction"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                    ('destination', (YLeaf(YType.empty, 'destination'), ['Empty'])),
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                ])
                                self.any = None
                                self.destination = None
                                self.source = None
                                self._segment_path = lambda: "direction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp.Direction, ['any', 'destination', 'source'], name, value)


                        class Port(Entity):
                            """
                            ports
                            
                            .. attribute:: port_numbers
                            
                            	
                            	**type**\: list of  		 :py:class:`PortNumbers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp.Port.PortNumbers>`
                            
                            .. attribute:: range
                            
                            	Range of maximum 1000 Ports. With IP option use maximum range of 8
                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Tcp.Port.Range>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.Tcp.Port, self).__init__()

                                self.yang_name = "port"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port-numbers", ("port_numbers", Native.Ip.Nbar.Custom.Transport.Tcp.Port.PortNumbers)), ("range", ("range", Native.Ip.Nbar.Custom.Transport.Tcp.Port.Range))])
                                self._leafs = OrderedDict()

                                self.range = Native.Ip.Nbar.Custom.Transport.Tcp.Port.Range()
                                self.range.parent = self
                                self._children_name_map["range"] = "range"

                                self.port_numbers = YList(self)
                                self._segment_path = lambda: "port"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp.Port, [], name, value)


                            class PortNumbers(Entity):
                                """
                                
                                
                                .. attribute:: port_number0  (key)
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number1
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number2
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number3
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number4
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number5
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number6
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number7
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Tcp.Port.PortNumbers, self).__init__()

                                    self.yang_name = "port-numbers"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['port_number0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_number0', (YLeaf(YType.uint16, 'port-number0'), ['int'])),
                                        ('port_number1', (YLeaf(YType.uint16, 'port-number1'), ['int'])),
                                        ('port_number2', (YLeaf(YType.uint16, 'port-number2'), ['int'])),
                                        ('port_number3', (YLeaf(YType.uint16, 'port-number3'), ['int'])),
                                        ('port_number4', (YLeaf(YType.uint16, 'port-number4'), ['int'])),
                                        ('port_number5', (YLeaf(YType.uint16, 'port-number5'), ['int'])),
                                        ('port_number6', (YLeaf(YType.uint16, 'port-number6'), ['int'])),
                                        ('port_number7', (YLeaf(YType.uint16, 'port-number7'), ['int'])),
                                    ])
                                    self.port_number0 = None
                                    self.port_number1 = None
                                    self.port_number2 = None
                                    self.port_number3 = None
                                    self.port_number4 = None
                                    self.port_number5 = None
                                    self.port_number6 = None
                                    self.port_number7 = None
                                    self._segment_path = lambda: "port-numbers" + "[port-number0='" + str(self.port_number0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp.Port.PortNumbers, ['port_number0', 'port_number1', 'port_number2', 'port_number3', 'port_number4', 'port_number5', 'port_number6', 'port_number7'], name, value)


                            class Range(Entity):
                                """
                                Range of maximum 1000 Ports. With IP option use maximum range of 8.
                                
                                .. attribute:: start_range
                                
                                	Enter Start port number for Range
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: end_range
                                
                                	Enter Start port number for Range
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Tcp.Port.Range, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('start_range', (YLeaf(YType.uint16, 'start-range'), ['int'])),
                                        ('end_range', (YLeaf(YType.uint16, 'end-range'), ['int'])),
                                    ])
                                    self.start_range = None
                                    self.end_range = None
                                    self._segment_path = lambda: "range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Tcp.Port.Range, ['start_range', 'end_range'], name, value)


                    class Udp(Entity):
                        """
                        UDP transport
                        
                        .. attribute:: id
                        
                        	Selector ID
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dscp
                        
                        	DSCP in IPv4 and IPv6 packets
                        	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp.Dscp>`
                        
                        .. attribute:: ip
                        
                        	ip address
                        	**type**\:  :py:class:`Ip_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp.Ip_>`
                        
                        .. attribute:: ipv6
                        
                        	ipv6 address
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp.Ipv6>`
                        
                        .. attribute:: direction
                        
                        	Flow direction
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp.Direction>`
                        
                        .. attribute:: port
                        
                        	ports
                        	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp.Port>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Custom.Transport.Udp, self).__init__()

                            self.yang_name = "udp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dscp", ("dscp", Native.Ip.Nbar.Custom.Transport.Udp.Dscp)), ("ip", ("ip", Native.Ip.Nbar.Custom.Transport.Udp.Ip_)), ("ipv6", ("ipv6", Native.Ip.Nbar.Custom.Transport.Udp.Ipv6)), ("direction", ("direction", Native.Ip.Nbar.Custom.Transport.Udp.Direction)), ("port", ("port", Native.Ip.Nbar.Custom.Transport.Udp.Port))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.dscp = Native.Ip.Nbar.Custom.Transport.Udp.Dscp()
                            self.dscp.parent = self
                            self._children_name_map["dscp"] = "dscp"

                            self.ip = Native.Ip.Nbar.Custom.Transport.Udp.Ip_()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"

                            self.ipv6 = Native.Ip.Nbar.Custom.Transport.Udp.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.direction = Native.Ip.Nbar.Custom.Transport.Udp.Direction()
                            self.direction.parent = self
                            self._children_name_map["direction"] = "direction"

                            self.port = Native.Ip.Nbar.Custom.Transport.Udp.Port()
                            self.port.parent = self
                            self._children_name_map["port"] = "port"
                            self._segment_path = lambda: "udp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp, ['id'], name, value)


                        class Dscp(Entity):
                            """
                            DSCP in IPv4 and IPv6 packets
                            
                            .. attribute:: range
                            
                            	Differentiated services codepoint value
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: af11
                            
                            	Match packets with AF11 dscp (001010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af12
                            
                            	Match packets with AF12 dscp (001100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af13
                            
                            	Match packets with AF13 dscp (001110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af21
                            
                            	Match packets with AF21 dscp (010010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af22
                            
                            	Match packets with AF22 dscp (010100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af23
                            
                            	Match packets with AF23 dscp (010110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af31
                            
                            	Match packets with AF31 dscp (011010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af32
                            
                            	Match packets with AF32 dscp (011100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af33
                            
                            	Match packets with AF33 dscp (011110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af41
                            
                            	Match packets with AF41 dscp (100010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af42
                            
                            	Match packets with AF42 dscp (100100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af43
                            
                            	Match packets with AF43 dscp (100110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs1
                            
                            	Match packets with CS1(precedence 1) dscp (001000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs2
                            
                            	Match packets with CS2(precedence 2) dscp (010000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs3
                            
                            	Match packets with CS3(precedence 3) dscp (011000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs4
                            
                            	Match packets with CS4(precedence 4) dscp (100000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs5
                            
                            	Match packets with CS5(precedence 5) dscp (101000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs6
                            
                            	Match packets with CS6(precedence 6) dscp (110000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs7
                            
                            	Match packets with CS7(precedence 7) dscp (111000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: default
                            
                            	Match packets with default dscp (000000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ef
                            
                            	Match packets with EF dscp (101110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.Udp.Dscp, self).__init__()

                                self.yang_name = "dscp"
                                self.yang_parent_name = "udp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                    ('af11', (YLeaf(YType.empty, 'af11'), ['Empty'])),
                                    ('af12', (YLeaf(YType.empty, 'af12'), ['Empty'])),
                                    ('af13', (YLeaf(YType.empty, 'af13'), ['Empty'])),
                                    ('af21', (YLeaf(YType.empty, 'af21'), ['Empty'])),
                                    ('af22', (YLeaf(YType.empty, 'af22'), ['Empty'])),
                                    ('af23', (YLeaf(YType.empty, 'af23'), ['Empty'])),
                                    ('af31', (YLeaf(YType.empty, 'af31'), ['Empty'])),
                                    ('af32', (YLeaf(YType.empty, 'af32'), ['Empty'])),
                                    ('af33', (YLeaf(YType.empty, 'af33'), ['Empty'])),
                                    ('af41', (YLeaf(YType.empty, 'af41'), ['Empty'])),
                                    ('af42', (YLeaf(YType.empty, 'af42'), ['Empty'])),
                                    ('af43', (YLeaf(YType.empty, 'af43'), ['Empty'])),
                                    ('cs1', (YLeaf(YType.empty, 'cs1'), ['Empty'])),
                                    ('cs2', (YLeaf(YType.empty, 'cs2'), ['Empty'])),
                                    ('cs3', (YLeaf(YType.empty, 'cs3'), ['Empty'])),
                                    ('cs4', (YLeaf(YType.empty, 'cs4'), ['Empty'])),
                                    ('cs5', (YLeaf(YType.empty, 'cs5'), ['Empty'])),
                                    ('cs6', (YLeaf(YType.empty, 'cs6'), ['Empty'])),
                                    ('cs7', (YLeaf(YType.empty, 'cs7'), ['Empty'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ('ef', (YLeaf(YType.empty, 'ef'), ['Empty'])),
                                ])
                                self.range = None
                                self.af11 = None
                                self.af12 = None
                                self.af13 = None
                                self.af21 = None
                                self.af22 = None
                                self.af23 = None
                                self.af31 = None
                                self.af32 = None
                                self.af33 = None
                                self.af41 = None
                                self.af42 = None
                                self.af43 = None
                                self.cs1 = None
                                self.cs2 = None
                                self.cs3 = None
                                self.cs4 = None
                                self.cs5 = None
                                self.cs6 = None
                                self.cs7 = None
                                self.default = None
                                self.ef = None
                                self._segment_path = lambda: "dscp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp.Dscp, ['range', 'af11', 'af12', 'af13', 'af21', 'af22', 'af23', 'af31', 'af32', 'af33', 'af41', 'af42', 'af43', 'cs1', 'cs2', 'cs3', 'cs4', 'cs5', 'cs6', 'cs7', 'default', 'ef'], name, value)


                        class Ip_(Entity):
                            """
                            ip address
                            
                            .. attribute:: address
                            
                            	ip address list
                            	**type**\: list of  		 :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp.Ip_.Address>`
                            
                            .. attribute:: subnet
                            
                            	Subnet IP/mask length
                            	**type**\:  :py:class:`Subnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp.Ip_.Subnet>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.Udp.Ip_, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "udp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Ip.Nbar.Custom.Transport.Udp.Ip_.Address)), ("subnet", ("subnet", Native.Ip.Nbar.Custom.Transport.Udp.Ip_.Subnet))])
                                self._leafs = OrderedDict()

                                self.subnet = Native.Ip.Nbar.Custom.Transport.Udp.Ip_.Subnet()
                                self.subnet.parent = self
                                self._children_name_map["subnet"] = "subnet"

                                self.address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp.Ip_, [], name, value)


                            class Address(Entity):
                                """
                                ip address list
                                
                                .. attribute:: address0  (key)
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address1
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address2
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address3
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address4
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address5
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address6
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address7
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Udp.Ip_.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['address0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address0', (YLeaf(YType.str, 'address0'), ['str'])),
                                        ('address1', (YLeaf(YType.str, 'address1'), ['str'])),
                                        ('address2', (YLeaf(YType.str, 'address2'), ['str'])),
                                        ('address3', (YLeaf(YType.str, 'address3'), ['str'])),
                                        ('address4', (YLeaf(YType.str, 'address4'), ['str'])),
                                        ('address5', (YLeaf(YType.str, 'address5'), ['str'])),
                                        ('address6', (YLeaf(YType.str, 'address6'), ['str'])),
                                        ('address7', (YLeaf(YType.str, 'address7'), ['str'])),
                                    ])
                                    self.address0 = None
                                    self.address1 = None
                                    self.address2 = None
                                    self.address3 = None
                                    self.address4 = None
                                    self.address5 = None
                                    self.address6 = None
                                    self.address7 = None
                                    self._segment_path = lambda: "address" + "[address0='" + str(self.address0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp.Ip_.Address, ['address0', 'address1', 'address2', 'address3', 'address4', 'address5', 'address6', 'address7'], name, value)


                            class Subnet(Entity):
                                """
                                Subnet IP/mask length
                                
                                .. attribute:: subnet
                                
                                	Subnet IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..32
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Udp.Ip_.Subnet, self).__init__()

                                    self.yang_name = "subnet"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subnet', (YLeaf(YType.str, 'subnet'), ['str'])),
                                        ('mask', (YLeaf(YType.uint8, 'mask'), ['int'])),
                                    ])
                                    self.subnet = None
                                    self.mask = None
                                    self._segment_path = lambda: "subnet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp.Ip_.Subnet, ['subnet', 'mask'], name, value)


                        class Ipv6(Entity):
                            """
                            ipv6 address
                            
                            .. attribute:: address
                            
                            	ipv6 address list
                            	**type**\: list of  		 :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp.Ipv6.Address>`
                            
                            .. attribute:: subnet
                            
                            	Subnet IP/mask length
                            	**type**\:  :py:class:`Subnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp.Ipv6.Subnet>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.Udp.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "udp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Ip.Nbar.Custom.Transport.Udp.Ipv6.Address)), ("subnet", ("subnet", Native.Ip.Nbar.Custom.Transport.Udp.Ipv6.Subnet))])
                                self._leafs = OrderedDict()

                                self.subnet = Native.Ip.Nbar.Custom.Transport.Udp.Ipv6.Subnet()
                                self.subnet.parent = self
                                self._children_name_map["subnet"] = "subnet"

                                self.address = YList(self)
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp.Ipv6, [], name, value)


                            class Address(Entity):
                                """
                                ipv6 address list
                                
                                .. attribute:: address0  (key)
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address1
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address2
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address3
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address4
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address5
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address6
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address7
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Udp.Ipv6.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['address0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address0', (YLeaf(YType.str, 'address0'), ['str'])),
                                        ('address1', (YLeaf(YType.str, 'address1'), ['str'])),
                                        ('address2', (YLeaf(YType.str, 'address2'), ['str'])),
                                        ('address3', (YLeaf(YType.str, 'address3'), ['str'])),
                                        ('address4', (YLeaf(YType.str, 'address4'), ['str'])),
                                        ('address5', (YLeaf(YType.str, 'address5'), ['str'])),
                                        ('address6', (YLeaf(YType.str, 'address6'), ['str'])),
                                        ('address7', (YLeaf(YType.str, 'address7'), ['str'])),
                                    ])
                                    self.address0 = None
                                    self.address1 = None
                                    self.address2 = None
                                    self.address3 = None
                                    self.address4 = None
                                    self.address5 = None
                                    self.address6 = None
                                    self.address7 = None
                                    self._segment_path = lambda: "address" + "[address0='" + str(self.address0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp.Ipv6.Address, ['address0', 'address1', 'address2', 'address3', 'address4', 'address5', 'address6', 'address7'], name, value)


                            class Subnet(Entity):
                                """
                                Subnet IP/mask length
                                
                                .. attribute:: subnet
                                
                                	Subnet IP
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Udp.Ipv6.Subnet, self).__init__()

                                    self.yang_name = "subnet"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subnet', (YLeaf(YType.str, 'subnet'), ['str'])),
                                        ('mask', (YLeaf(YType.uint8, 'mask'), ['int'])),
                                    ])
                                    self.subnet = None
                                    self.mask = None
                                    self._segment_path = lambda: "subnet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp.Ipv6.Subnet, ['subnet', 'mask'], name, value)


                        class Direction(Entity):
                            """
                            Flow direction
                            
                            .. attribute:: any
                            
                            	Any Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: destination
                            
                            	Destination Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: source
                            
                            	Source Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.Udp.Direction, self).__init__()

                                self.yang_name = "direction"
                                self.yang_parent_name = "udp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                    ('destination', (YLeaf(YType.empty, 'destination'), ['Empty'])),
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                ])
                                self.any = None
                                self.destination = None
                                self.source = None
                                self._segment_path = lambda: "direction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp.Direction, ['any', 'destination', 'source'], name, value)


                        class Port(Entity):
                            """
                            ports
                            
                            .. attribute:: port_numbers
                            
                            	
                            	**type**\: list of  		 :py:class:`PortNumbers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp.Port.PortNumbers>`
                            
                            .. attribute:: range
                            
                            	Range of maximum 1000 Ports. With IP option use maximum range of 8
                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.Udp.Port.Range>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.Udp.Port, self).__init__()

                                self.yang_name = "port"
                                self.yang_parent_name = "udp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port-numbers", ("port_numbers", Native.Ip.Nbar.Custom.Transport.Udp.Port.PortNumbers)), ("range", ("range", Native.Ip.Nbar.Custom.Transport.Udp.Port.Range))])
                                self._leafs = OrderedDict()

                                self.range = Native.Ip.Nbar.Custom.Transport.Udp.Port.Range()
                                self.range.parent = self
                                self._children_name_map["range"] = "range"

                                self.port_numbers = YList(self)
                                self._segment_path = lambda: "port"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp.Port, [], name, value)


                            class PortNumbers(Entity):
                                """
                                
                                
                                .. attribute:: port_number0  (key)
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number1
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number2
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number3
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number4
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number5
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number6
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number7
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Udp.Port.PortNumbers, self).__init__()

                                    self.yang_name = "port-numbers"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['port_number0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_number0', (YLeaf(YType.uint16, 'port-number0'), ['int'])),
                                        ('port_number1', (YLeaf(YType.uint16, 'port-number1'), ['int'])),
                                        ('port_number2', (YLeaf(YType.uint16, 'port-number2'), ['int'])),
                                        ('port_number3', (YLeaf(YType.uint16, 'port-number3'), ['int'])),
                                        ('port_number4', (YLeaf(YType.uint16, 'port-number4'), ['int'])),
                                        ('port_number5', (YLeaf(YType.uint16, 'port-number5'), ['int'])),
                                        ('port_number6', (YLeaf(YType.uint16, 'port-number6'), ['int'])),
                                        ('port_number7', (YLeaf(YType.uint16, 'port-number7'), ['int'])),
                                    ])
                                    self.port_number0 = None
                                    self.port_number1 = None
                                    self.port_number2 = None
                                    self.port_number3 = None
                                    self.port_number4 = None
                                    self.port_number5 = None
                                    self.port_number6 = None
                                    self.port_number7 = None
                                    self._segment_path = lambda: "port-numbers" + "[port-number0='" + str(self.port_number0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp.Port.PortNumbers, ['port_number0', 'port_number1', 'port_number2', 'port_number3', 'port_number4', 'port_number5', 'port_number6', 'port_number7'], name, value)


                            class Range(Entity):
                                """
                                Range of maximum 1000 Ports. With IP option use maximum range of 8.
                                
                                .. attribute:: start_range
                                
                                	Enter Start port number for Range
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: end_range
                                
                                	Enter Start port number for Range
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.Udp.Port.Range, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('start_range', (YLeaf(YType.uint16, 'start-range'), ['int'])),
                                        ('end_range', (YLeaf(YType.uint16, 'end-range'), ['int'])),
                                    ])
                                    self.start_range = None
                                    self.end_range = None
                                    self._segment_path = lambda: "range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.Udp.Port.Range, ['start_range', 'end_range'], name, value)


                    class UdpTcp(Entity):
                        """
                        UDP or TCP transport
                        
                        .. attribute:: id
                        
                        	Selector ID
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dscp
                        
                        	DSCP in IPv4 and IPv6 packets
                        	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp.Dscp>`
                        
                        .. attribute:: ip
                        
                        	ip address
                        	**type**\:  :py:class:`Ip_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_>`
                        
                        .. attribute:: ipv6
                        
                        	ipv6 address
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6>`
                        
                        .. attribute:: direction
                        
                        	Flow direction
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp.Direction>`
                        
                        .. attribute:: port
                        
                        	ports
                        	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp.Port>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Custom.Transport.UdpTcp, self).__init__()

                            self.yang_name = "udp-tcp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dscp", ("dscp", Native.Ip.Nbar.Custom.Transport.UdpTcp.Dscp)), ("ip", ("ip", Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_)), ("ipv6", ("ipv6", Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6)), ("direction", ("direction", Native.Ip.Nbar.Custom.Transport.UdpTcp.Direction)), ("port", ("port", Native.Ip.Nbar.Custom.Transport.UdpTcp.Port))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.dscp = Native.Ip.Nbar.Custom.Transport.UdpTcp.Dscp()
                            self.dscp.parent = self
                            self._children_name_map["dscp"] = "dscp"

                            self.ip = Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"

                            self.ipv6 = Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.direction = Native.Ip.Nbar.Custom.Transport.UdpTcp.Direction()
                            self.direction.parent = self
                            self._children_name_map["direction"] = "direction"

                            self.port = Native.Ip.Nbar.Custom.Transport.UdpTcp.Port()
                            self.port.parent = self
                            self._children_name_map["port"] = "port"
                            self._segment_path = lambda: "udp-tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp, ['id'], name, value)


                        class Dscp(Entity):
                            """
                            DSCP in IPv4 and IPv6 packets
                            
                            .. attribute:: range
                            
                            	Differentiated services codepoint value
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: af11
                            
                            	Match packets with AF11 dscp (001010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af12
                            
                            	Match packets with AF12 dscp (001100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af13
                            
                            	Match packets with AF13 dscp (001110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af21
                            
                            	Match packets with AF21 dscp (010010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af22
                            
                            	Match packets with AF22 dscp (010100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af23
                            
                            	Match packets with AF23 dscp (010110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af31
                            
                            	Match packets with AF31 dscp (011010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af32
                            
                            	Match packets with AF32 dscp (011100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af33
                            
                            	Match packets with AF33 dscp (011110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af41
                            
                            	Match packets with AF41 dscp (100010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af42
                            
                            	Match packets with AF42 dscp (100100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af43
                            
                            	Match packets with AF43 dscp (100110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs1
                            
                            	Match packets with CS1(precedence 1) dscp (001000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs2
                            
                            	Match packets with CS2(precedence 2) dscp (010000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs3
                            
                            	Match packets with CS3(precedence 3) dscp (011000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs4
                            
                            	Match packets with CS4(precedence 4) dscp (100000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs5
                            
                            	Match packets with CS5(precedence 5) dscp (101000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs6
                            
                            	Match packets with CS6(precedence 6) dscp (110000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs7
                            
                            	Match packets with CS7(precedence 7) dscp (111000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: default
                            
                            	Match packets with default dscp (000000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ef
                            
                            	Match packets with EF dscp (101110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.UdpTcp.Dscp, self).__init__()

                                self.yang_name = "dscp"
                                self.yang_parent_name = "udp-tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                    ('af11', (YLeaf(YType.empty, 'af11'), ['Empty'])),
                                    ('af12', (YLeaf(YType.empty, 'af12'), ['Empty'])),
                                    ('af13', (YLeaf(YType.empty, 'af13'), ['Empty'])),
                                    ('af21', (YLeaf(YType.empty, 'af21'), ['Empty'])),
                                    ('af22', (YLeaf(YType.empty, 'af22'), ['Empty'])),
                                    ('af23', (YLeaf(YType.empty, 'af23'), ['Empty'])),
                                    ('af31', (YLeaf(YType.empty, 'af31'), ['Empty'])),
                                    ('af32', (YLeaf(YType.empty, 'af32'), ['Empty'])),
                                    ('af33', (YLeaf(YType.empty, 'af33'), ['Empty'])),
                                    ('af41', (YLeaf(YType.empty, 'af41'), ['Empty'])),
                                    ('af42', (YLeaf(YType.empty, 'af42'), ['Empty'])),
                                    ('af43', (YLeaf(YType.empty, 'af43'), ['Empty'])),
                                    ('cs1', (YLeaf(YType.empty, 'cs1'), ['Empty'])),
                                    ('cs2', (YLeaf(YType.empty, 'cs2'), ['Empty'])),
                                    ('cs3', (YLeaf(YType.empty, 'cs3'), ['Empty'])),
                                    ('cs4', (YLeaf(YType.empty, 'cs4'), ['Empty'])),
                                    ('cs5', (YLeaf(YType.empty, 'cs5'), ['Empty'])),
                                    ('cs6', (YLeaf(YType.empty, 'cs6'), ['Empty'])),
                                    ('cs7', (YLeaf(YType.empty, 'cs7'), ['Empty'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ('ef', (YLeaf(YType.empty, 'ef'), ['Empty'])),
                                ])
                                self.range = None
                                self.af11 = None
                                self.af12 = None
                                self.af13 = None
                                self.af21 = None
                                self.af22 = None
                                self.af23 = None
                                self.af31 = None
                                self.af32 = None
                                self.af33 = None
                                self.af41 = None
                                self.af42 = None
                                self.af43 = None
                                self.cs1 = None
                                self.cs2 = None
                                self.cs3 = None
                                self.cs4 = None
                                self.cs5 = None
                                self.cs6 = None
                                self.cs7 = None
                                self.default = None
                                self.ef = None
                                self._segment_path = lambda: "dscp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp.Dscp, ['range', 'af11', 'af12', 'af13', 'af21', 'af22', 'af23', 'af31', 'af32', 'af33', 'af41', 'af42', 'af43', 'cs1', 'cs2', 'cs3', 'cs4', 'cs5', 'cs6', 'cs7', 'default', 'ef'], name, value)


                        class Ip_(Entity):
                            """
                            ip address
                            
                            .. attribute:: address
                            
                            	ip address list
                            	**type**\: list of  		 :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_.Address>`
                            
                            .. attribute:: subnet
                            
                            	Subnet IP/mask length
                            	**type**\:  :py:class:`Subnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_.Subnet>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "udp-tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_.Address)), ("subnet", ("subnet", Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_.Subnet))])
                                self._leafs = OrderedDict()

                                self.subnet = Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_.Subnet()
                                self.subnet.parent = self
                                self._children_name_map["subnet"] = "subnet"

                                self.address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_, [], name, value)


                            class Address(Entity):
                                """
                                ip address list
                                
                                .. attribute:: address0  (key)
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address1
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address2
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address3
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address4
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address5
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address6
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address7
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['address0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address0', (YLeaf(YType.str, 'address0'), ['str'])),
                                        ('address1', (YLeaf(YType.str, 'address1'), ['str'])),
                                        ('address2', (YLeaf(YType.str, 'address2'), ['str'])),
                                        ('address3', (YLeaf(YType.str, 'address3'), ['str'])),
                                        ('address4', (YLeaf(YType.str, 'address4'), ['str'])),
                                        ('address5', (YLeaf(YType.str, 'address5'), ['str'])),
                                        ('address6', (YLeaf(YType.str, 'address6'), ['str'])),
                                        ('address7', (YLeaf(YType.str, 'address7'), ['str'])),
                                    ])
                                    self.address0 = None
                                    self.address1 = None
                                    self.address2 = None
                                    self.address3 = None
                                    self.address4 = None
                                    self.address5 = None
                                    self.address6 = None
                                    self.address7 = None
                                    self._segment_path = lambda: "address" + "[address0='" + str(self.address0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_.Address, ['address0', 'address1', 'address2', 'address3', 'address4', 'address5', 'address6', 'address7'], name, value)


                            class Subnet(Entity):
                                """
                                Subnet IP/mask length
                                
                                .. attribute:: subnet
                                
                                	Subnet IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..32
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_.Subnet, self).__init__()

                                    self.yang_name = "subnet"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subnet', (YLeaf(YType.str, 'subnet'), ['str'])),
                                        ('mask', (YLeaf(YType.uint8, 'mask'), ['int'])),
                                    ])
                                    self.subnet = None
                                    self.mask = None
                                    self._segment_path = lambda: "subnet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ip_.Subnet, ['subnet', 'mask'], name, value)


                        class Ipv6(Entity):
                            """
                            ipv6 address
                            
                            .. attribute:: address
                            
                            	ipv6 address list
                            	**type**\: list of  		 :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6.Address>`
                            
                            .. attribute:: subnet
                            
                            	Subnet IP/mask length
                            	**type**\:  :py:class:`Subnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6.Subnet>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "udp-tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6.Address)), ("subnet", ("subnet", Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6.Subnet))])
                                self._leafs = OrderedDict()

                                self.subnet = Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6.Subnet()
                                self.subnet.parent = self
                                self._children_name_map["subnet"] = "subnet"

                                self.address = YList(self)
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6, [], name, value)


                            class Address(Entity):
                                """
                                ipv6 address list
                                
                                .. attribute:: address0  (key)
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address1
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address2
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address3
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address4
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address5
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address6
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address7
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['address0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address0', (YLeaf(YType.str, 'address0'), ['str'])),
                                        ('address1', (YLeaf(YType.str, 'address1'), ['str'])),
                                        ('address2', (YLeaf(YType.str, 'address2'), ['str'])),
                                        ('address3', (YLeaf(YType.str, 'address3'), ['str'])),
                                        ('address4', (YLeaf(YType.str, 'address4'), ['str'])),
                                        ('address5', (YLeaf(YType.str, 'address5'), ['str'])),
                                        ('address6', (YLeaf(YType.str, 'address6'), ['str'])),
                                        ('address7', (YLeaf(YType.str, 'address7'), ['str'])),
                                    ])
                                    self.address0 = None
                                    self.address1 = None
                                    self.address2 = None
                                    self.address3 = None
                                    self.address4 = None
                                    self.address5 = None
                                    self.address6 = None
                                    self.address7 = None
                                    self._segment_path = lambda: "address" + "[address0='" + str(self.address0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6.Address, ['address0', 'address1', 'address2', 'address3', 'address4', 'address5', 'address6', 'address7'], name, value)


                            class Subnet(Entity):
                                """
                                Subnet IP/mask length
                                
                                .. attribute:: subnet
                                
                                	Subnet IP
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6.Subnet, self).__init__()

                                    self.yang_name = "subnet"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subnet', (YLeaf(YType.str, 'subnet'), ['str'])),
                                        ('mask', (YLeaf(YType.uint8, 'mask'), ['int'])),
                                    ])
                                    self.subnet = None
                                    self.mask = None
                                    self._segment_path = lambda: "subnet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp.Ipv6.Subnet, ['subnet', 'mask'], name, value)


                        class Direction(Entity):
                            """
                            Flow direction
                            
                            .. attribute:: any
                            
                            	Any Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: destination
                            
                            	Destination Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: source
                            
                            	Source Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.UdpTcp.Direction, self).__init__()

                                self.yang_name = "direction"
                                self.yang_parent_name = "udp-tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                    ('destination', (YLeaf(YType.empty, 'destination'), ['Empty'])),
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                ])
                                self.any = None
                                self.destination = None
                                self.source = None
                                self._segment_path = lambda: "direction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp.Direction, ['any', 'destination', 'source'], name, value)


                        class Port(Entity):
                            """
                            ports
                            
                            .. attribute:: port_numbers
                            
                            	
                            	**type**\: list of  		 :py:class:`PortNumbers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp.Port.PortNumbers>`
                            
                            .. attribute:: range
                            
                            	Range of maximum 1000 Ports. With IP option use maximum range of 8
                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Transport.UdpTcp.Port.Range>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Transport.UdpTcp.Port, self).__init__()

                                self.yang_name = "port"
                                self.yang_parent_name = "udp-tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port-numbers", ("port_numbers", Native.Ip.Nbar.Custom.Transport.UdpTcp.Port.PortNumbers)), ("range", ("range", Native.Ip.Nbar.Custom.Transport.UdpTcp.Port.Range))])
                                self._leafs = OrderedDict()

                                self.range = Native.Ip.Nbar.Custom.Transport.UdpTcp.Port.Range()
                                self.range.parent = self
                                self._children_name_map["range"] = "range"

                                self.port_numbers = YList(self)
                                self._segment_path = lambda: "port"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp.Port, [], name, value)


                            class PortNumbers(Entity):
                                """
                                
                                
                                .. attribute:: port_number0  (key)
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number1
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number2
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number3
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number4
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number5
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number6
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number7
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.UdpTcp.Port.PortNumbers, self).__init__()

                                    self.yang_name = "port-numbers"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['port_number0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_number0', (YLeaf(YType.uint16, 'port-number0'), ['int'])),
                                        ('port_number1', (YLeaf(YType.uint16, 'port-number1'), ['int'])),
                                        ('port_number2', (YLeaf(YType.uint16, 'port-number2'), ['int'])),
                                        ('port_number3', (YLeaf(YType.uint16, 'port-number3'), ['int'])),
                                        ('port_number4', (YLeaf(YType.uint16, 'port-number4'), ['int'])),
                                        ('port_number5', (YLeaf(YType.uint16, 'port-number5'), ['int'])),
                                        ('port_number6', (YLeaf(YType.uint16, 'port-number6'), ['int'])),
                                        ('port_number7', (YLeaf(YType.uint16, 'port-number7'), ['int'])),
                                    ])
                                    self.port_number0 = None
                                    self.port_number1 = None
                                    self.port_number2 = None
                                    self.port_number3 = None
                                    self.port_number4 = None
                                    self.port_number5 = None
                                    self.port_number6 = None
                                    self.port_number7 = None
                                    self._segment_path = lambda: "port-numbers" + "[port-number0='" + str(self.port_number0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp.Port.PortNumbers, ['port_number0', 'port_number1', 'port_number2', 'port_number3', 'port_number4', 'port_number5', 'port_number6', 'port_number7'], name, value)


                            class Range(Entity):
                                """
                                Range of maximum 1000 Ports. With IP option use maximum range of 8.
                                
                                .. attribute:: start_range
                                
                                	Enter Start port number for Range
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: end_range
                                
                                	Enter Start port number for Range
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Transport.UdpTcp.Port.Range, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('start_range', (YLeaf(YType.uint16, 'start-range'), ['int'])),
                                        ('end_range', (YLeaf(YType.uint16, 'end-range'), ['int'])),
                                    ])
                                    self.start_range = None
                                    self.end_range = None
                                    self._segment_path = lambda: "range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Transport.UdpTcp.Port.Range, ['start_range', 'end_range'], name, value)


                class Ip_(Entity):
                    """
                    Custom protocols based on the transport layer and below
                    
                    .. attribute:: any
                    
                    	TCP transport
                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.Custom.Ip_, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "custom"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("any", ("any", Native.Ip.Nbar.Custom.Ip_.Any))])
                        self._leafs = OrderedDict()

                        self.any = None
                        self._children_name_map["any"] = "any"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.Custom.Ip_, [], name, value)


                    class Any(Entity):
                        """
                        TCP transport
                        
                        .. attribute:: id
                        
                        	Selector ID
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dscp
                        
                        	DSCP in IPv4 and IPv6 packets
                        	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any.Dscp>`
                        
                        .. attribute:: ip
                        
                        	ip address
                        	**type**\:  :py:class:`Ip_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any.Ip_>`
                        
                        .. attribute:: ipv6
                        
                        	ipv6 address
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any.Ipv6>`
                        
                        .. attribute:: direction
                        
                        	Flow direction
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any.Direction>`
                        
                        .. attribute:: port
                        
                        	ports
                        	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any.Port>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Ip.Nbar.Custom.Ip_.Any, self).__init__()

                            self.yang_name = "any"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dscp", ("dscp", Native.Ip.Nbar.Custom.Ip_.Any.Dscp)), ("ip", ("ip", Native.Ip.Nbar.Custom.Ip_.Any.Ip_)), ("ipv6", ("ipv6", Native.Ip.Nbar.Custom.Ip_.Any.Ipv6)), ("direction", ("direction", Native.Ip.Nbar.Custom.Ip_.Any.Direction)), ("port", ("port", Native.Ip.Nbar.Custom.Ip_.Any.Port))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.dscp = Native.Ip.Nbar.Custom.Ip_.Any.Dscp()
                            self.dscp.parent = self
                            self._children_name_map["dscp"] = "dscp"

                            self.ip = Native.Ip.Nbar.Custom.Ip_.Any.Ip_()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"

                            self.ipv6 = Native.Ip.Nbar.Custom.Ip_.Any.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.direction = Native.Ip.Nbar.Custom.Ip_.Any.Direction()
                            self.direction.parent = self
                            self._children_name_map["direction"] = "direction"

                            self.port = Native.Ip.Nbar.Custom.Ip_.Any.Port()
                            self.port.parent = self
                            self._children_name_map["port"] = "port"
                            self._segment_path = lambda: "any"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any, ['id'], name, value)


                        class Dscp(Entity):
                            """
                            DSCP in IPv4 and IPv6 packets
                            
                            .. attribute:: range
                            
                            	Differentiated services codepoint value
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: af11
                            
                            	Match packets with AF11 dscp (001010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af12
                            
                            	Match packets with AF12 dscp (001100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af13
                            
                            	Match packets with AF13 dscp (001110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af21
                            
                            	Match packets with AF21 dscp (010010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af22
                            
                            	Match packets with AF22 dscp (010100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af23
                            
                            	Match packets with AF23 dscp (010110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af31
                            
                            	Match packets with AF31 dscp (011010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af32
                            
                            	Match packets with AF32 dscp (011100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af33
                            
                            	Match packets with AF33 dscp (011110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af41
                            
                            	Match packets with AF41 dscp (100010)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af42
                            
                            	Match packets with AF42 dscp (100100)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: af43
                            
                            	Match packets with AF43 dscp (100110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs1
                            
                            	Match packets with CS1(precedence 1) dscp (001000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs2
                            
                            	Match packets with CS2(precedence 2) dscp (010000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs3
                            
                            	Match packets with CS3(precedence 3) dscp (011000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs4
                            
                            	Match packets with CS4(precedence 4) dscp (100000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs5
                            
                            	Match packets with CS5(precedence 5) dscp (101000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs6
                            
                            	Match packets with CS6(precedence 6) dscp (110000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cs7
                            
                            	Match packets with CS7(precedence 7) dscp (111000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: default
                            
                            	Match packets with default dscp (000000)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ef
                            
                            	Match packets with EF dscp (101110)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Ip_.Any.Dscp, self).__init__()

                                self.yang_name = "dscp"
                                self.yang_parent_name = "any"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                    ('af11', (YLeaf(YType.empty, 'af11'), ['Empty'])),
                                    ('af12', (YLeaf(YType.empty, 'af12'), ['Empty'])),
                                    ('af13', (YLeaf(YType.empty, 'af13'), ['Empty'])),
                                    ('af21', (YLeaf(YType.empty, 'af21'), ['Empty'])),
                                    ('af22', (YLeaf(YType.empty, 'af22'), ['Empty'])),
                                    ('af23', (YLeaf(YType.empty, 'af23'), ['Empty'])),
                                    ('af31', (YLeaf(YType.empty, 'af31'), ['Empty'])),
                                    ('af32', (YLeaf(YType.empty, 'af32'), ['Empty'])),
                                    ('af33', (YLeaf(YType.empty, 'af33'), ['Empty'])),
                                    ('af41', (YLeaf(YType.empty, 'af41'), ['Empty'])),
                                    ('af42', (YLeaf(YType.empty, 'af42'), ['Empty'])),
                                    ('af43', (YLeaf(YType.empty, 'af43'), ['Empty'])),
                                    ('cs1', (YLeaf(YType.empty, 'cs1'), ['Empty'])),
                                    ('cs2', (YLeaf(YType.empty, 'cs2'), ['Empty'])),
                                    ('cs3', (YLeaf(YType.empty, 'cs3'), ['Empty'])),
                                    ('cs4', (YLeaf(YType.empty, 'cs4'), ['Empty'])),
                                    ('cs5', (YLeaf(YType.empty, 'cs5'), ['Empty'])),
                                    ('cs6', (YLeaf(YType.empty, 'cs6'), ['Empty'])),
                                    ('cs7', (YLeaf(YType.empty, 'cs7'), ['Empty'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ('ef', (YLeaf(YType.empty, 'ef'), ['Empty'])),
                                ])
                                self.range = None
                                self.af11 = None
                                self.af12 = None
                                self.af13 = None
                                self.af21 = None
                                self.af22 = None
                                self.af23 = None
                                self.af31 = None
                                self.af32 = None
                                self.af33 = None
                                self.af41 = None
                                self.af42 = None
                                self.af43 = None
                                self.cs1 = None
                                self.cs2 = None
                                self.cs3 = None
                                self.cs4 = None
                                self.cs5 = None
                                self.cs6 = None
                                self.cs7 = None
                                self.default = None
                                self.ef = None
                                self._segment_path = lambda: "dscp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any.Dscp, ['range', 'af11', 'af12', 'af13', 'af21', 'af22', 'af23', 'af31', 'af32', 'af33', 'af41', 'af42', 'af43', 'cs1', 'cs2', 'cs3', 'cs4', 'cs5', 'cs6', 'cs7', 'default', 'ef'], name, value)


                        class Ip_(Entity):
                            """
                            ip address
                            
                            .. attribute:: address
                            
                            	ip address list
                            	**type**\: list of  		 :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any.Ip_.Address>`
                            
                            .. attribute:: subnet
                            
                            	Subnet IP/mask length
                            	**type**\:  :py:class:`Subnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any.Ip_.Subnet>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Ip_.Any.Ip_, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "any"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Ip.Nbar.Custom.Ip_.Any.Ip_.Address)), ("subnet", ("subnet", Native.Ip.Nbar.Custom.Ip_.Any.Ip_.Subnet))])
                                self._leafs = OrderedDict()

                                self.subnet = Native.Ip.Nbar.Custom.Ip_.Any.Ip_.Subnet()
                                self.subnet.parent = self
                                self._children_name_map["subnet"] = "subnet"

                                self.address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any.Ip_, [], name, value)


                            class Address(Entity):
                                """
                                ip address list
                                
                                .. attribute:: address0  (key)
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address1
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address2
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address3
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address4
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address5
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address6
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address7
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Ip_.Any.Ip_.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['address0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address0', (YLeaf(YType.str, 'address0'), ['str'])),
                                        ('address1', (YLeaf(YType.str, 'address1'), ['str'])),
                                        ('address2', (YLeaf(YType.str, 'address2'), ['str'])),
                                        ('address3', (YLeaf(YType.str, 'address3'), ['str'])),
                                        ('address4', (YLeaf(YType.str, 'address4'), ['str'])),
                                        ('address5', (YLeaf(YType.str, 'address5'), ['str'])),
                                        ('address6', (YLeaf(YType.str, 'address6'), ['str'])),
                                        ('address7', (YLeaf(YType.str, 'address7'), ['str'])),
                                    ])
                                    self.address0 = None
                                    self.address1 = None
                                    self.address2 = None
                                    self.address3 = None
                                    self.address4 = None
                                    self.address5 = None
                                    self.address6 = None
                                    self.address7 = None
                                    self._segment_path = lambda: "address" + "[address0='" + str(self.address0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any.Ip_.Address, ['address0', 'address1', 'address2', 'address3', 'address4', 'address5', 'address6', 'address7'], name, value)


                            class Subnet(Entity):
                                """
                                Subnet IP/mask length
                                
                                .. attribute:: subnet
                                
                                	Subnet IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..32
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Ip_.Any.Ip_.Subnet, self).__init__()

                                    self.yang_name = "subnet"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subnet', (YLeaf(YType.str, 'subnet'), ['str'])),
                                        ('mask', (YLeaf(YType.uint8, 'mask'), ['int'])),
                                    ])
                                    self.subnet = None
                                    self.mask = None
                                    self._segment_path = lambda: "subnet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any.Ip_.Subnet, ['subnet', 'mask'], name, value)


                        class Ipv6(Entity):
                            """
                            ipv6 address
                            
                            .. attribute:: address
                            
                            	ipv6 address list
                            	**type**\: list of  		 :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any.Ipv6.Address>`
                            
                            .. attribute:: subnet
                            
                            	Subnet IP/mask length
                            	**type**\:  :py:class:`Subnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any.Ipv6.Subnet>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Ip_.Any.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "any"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Ip.Nbar.Custom.Ip_.Any.Ipv6.Address)), ("subnet", ("subnet", Native.Ip.Nbar.Custom.Ip_.Any.Ipv6.Subnet))])
                                self._leafs = OrderedDict()

                                self.subnet = Native.Ip.Nbar.Custom.Ip_.Any.Ipv6.Subnet()
                                self.subnet.parent = self
                                self._children_name_map["subnet"] = "subnet"

                                self.address = YList(self)
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any.Ipv6, [], name, value)


                            class Address(Entity):
                                """
                                ipv6 address list
                                
                                .. attribute:: address0  (key)
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address1
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address2
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address3
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address4
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address5
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address6
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address7
                                
                                	List of up to 8 IPs separated by white\-spaces
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Ip_.Any.Ipv6.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['address0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address0', (YLeaf(YType.str, 'address0'), ['str'])),
                                        ('address1', (YLeaf(YType.str, 'address1'), ['str'])),
                                        ('address2', (YLeaf(YType.str, 'address2'), ['str'])),
                                        ('address3', (YLeaf(YType.str, 'address3'), ['str'])),
                                        ('address4', (YLeaf(YType.str, 'address4'), ['str'])),
                                        ('address5', (YLeaf(YType.str, 'address5'), ['str'])),
                                        ('address6', (YLeaf(YType.str, 'address6'), ['str'])),
                                        ('address7', (YLeaf(YType.str, 'address7'), ['str'])),
                                    ])
                                    self.address0 = None
                                    self.address1 = None
                                    self.address2 = None
                                    self.address3 = None
                                    self.address4 = None
                                    self.address5 = None
                                    self.address6 = None
                                    self.address7 = None
                                    self._segment_path = lambda: "address" + "[address0='" + str(self.address0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any.Ipv6.Address, ['address0', 'address1', 'address2', 'address3', 'address4', 'address5', 'address6', 'address7'], name, value)


                            class Subnet(Entity):
                                """
                                Subnet IP/mask length
                                
                                .. attribute:: subnet
                                
                                	Subnet IP
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Ip_.Any.Ipv6.Subnet, self).__init__()

                                    self.yang_name = "subnet"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subnet', (YLeaf(YType.str, 'subnet'), ['str'])),
                                        ('mask', (YLeaf(YType.uint8, 'mask'), ['int'])),
                                    ])
                                    self.subnet = None
                                    self.mask = None
                                    self._segment_path = lambda: "subnet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any.Ipv6.Subnet, ['subnet', 'mask'], name, value)


                        class Direction(Entity):
                            """
                            Flow direction
                            
                            .. attribute:: any
                            
                            	Any Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: destination
                            
                            	Destination Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: source
                            
                            	Source Direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Ip_.Any.Direction, self).__init__()

                                self.yang_name = "direction"
                                self.yang_parent_name = "any"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                    ('destination', (YLeaf(YType.empty, 'destination'), ['Empty'])),
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                ])
                                self.any = None
                                self.destination = None
                                self.source = None
                                self._segment_path = lambda: "direction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any.Direction, ['any', 'destination', 'source'], name, value)


                        class Port(Entity):
                            """
                            ports
                            
                            .. attribute:: port_numbers
                            
                            	
                            	**type**\: list of  		 :py:class:`PortNumbers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any.Port.PortNumbers>`
                            
                            .. attribute:: range
                            
                            	Range of maximum 1000 Ports. With IP option use maximum range of 8
                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.Custom.Ip_.Any.Port.Range>`
                            
                            

                            """

                            _prefix = 'ios-nbar'
                            _revision = '2018-06-06'

                            def __init__(self):
                                super(Native.Ip.Nbar.Custom.Ip_.Any.Port, self).__init__()

                                self.yang_name = "port"
                                self.yang_parent_name = "any"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port-numbers", ("port_numbers", Native.Ip.Nbar.Custom.Ip_.Any.Port.PortNumbers)), ("range", ("range", Native.Ip.Nbar.Custom.Ip_.Any.Port.Range))])
                                self._leafs = OrderedDict()

                                self.range = Native.Ip.Nbar.Custom.Ip_.Any.Port.Range()
                                self.range.parent = self
                                self._children_name_map["range"] = "range"

                                self.port_numbers = YList(self)
                                self._segment_path = lambda: "port"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any.Port, [], name, value)


                            class PortNumbers(Entity):
                                """
                                
                                
                                .. attribute:: port_number0  (key)
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number1
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number2
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number3
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number4
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number5
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number6
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: port_number7
                                
                                	Up to 8 port numbers separated by white\-spaces
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Ip_.Any.Port.PortNumbers, self).__init__()

                                    self.yang_name = "port-numbers"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['port_number0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_number0', (YLeaf(YType.uint16, 'port-number0'), ['int'])),
                                        ('port_number1', (YLeaf(YType.uint16, 'port-number1'), ['int'])),
                                        ('port_number2', (YLeaf(YType.uint16, 'port-number2'), ['int'])),
                                        ('port_number3', (YLeaf(YType.uint16, 'port-number3'), ['int'])),
                                        ('port_number4', (YLeaf(YType.uint16, 'port-number4'), ['int'])),
                                        ('port_number5', (YLeaf(YType.uint16, 'port-number5'), ['int'])),
                                        ('port_number6', (YLeaf(YType.uint16, 'port-number6'), ['int'])),
                                        ('port_number7', (YLeaf(YType.uint16, 'port-number7'), ['int'])),
                                    ])
                                    self.port_number0 = None
                                    self.port_number1 = None
                                    self.port_number2 = None
                                    self.port_number3 = None
                                    self.port_number4 = None
                                    self.port_number5 = None
                                    self.port_number6 = None
                                    self.port_number7 = None
                                    self._segment_path = lambda: "port-numbers" + "[port-number0='" + str(self.port_number0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any.Port.PortNumbers, ['port_number0', 'port_number1', 'port_number2', 'port_number3', 'port_number4', 'port_number5', 'port_number6', 'port_number7'], name, value)


                            class Range(Entity):
                                """
                                Range of maximum 1000 Ports. With IP option use maximum range of 8.
                                
                                .. attribute:: start_range
                                
                                	Enter Start port number for Range
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: end_range
                                
                                	Enter Start port number for Range
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-nbar'
                                _revision = '2018-06-06'

                                def __init__(self):
                                    super(Native.Ip.Nbar.Custom.Ip_.Any.Port.Range, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('start_range', (YLeaf(YType.uint16, 'start-range'), ['int'])),
                                        ('end_range', (YLeaf(YType.uint16, 'end-range'), ['int'])),
                                    ])
                                    self.start_range = None
                                    self.end_range = None
                                    self._segment_path = lambda: "range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nbar.Custom.Ip_.Any.Port.Range, ['start_range', 'end_range'], name, value)


            class ProtocolPack(Entity):
                """
                Protocol Pack
                
                .. attribute:: filepath
                
                	
                	**type**\: list of  		 :py:class:`Filepath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nbar.ProtocolPack.Filepath>`
                
                

                """

                _prefix = 'ios-nbar'
                _revision = '2018-06-06'

                def __init__(self):
                    super(Native.Ip.Nbar.ProtocolPack, self).__init__()

                    self.yang_name = "protocol-pack"
                    self.yang_parent_name = "nbar"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("filepath", ("filepath", Native.Ip.Nbar.ProtocolPack.Filepath))])
                    self._leafs = OrderedDict()

                    self.filepath = YList(self)
                    self._segment_path = lambda: "protocol-pack"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Nbar.ProtocolPack, [], name, value)


                class Filepath(Entity):
                    """
                    
                    
                    .. attribute:: filepath  (key)
                    
                    	Path of protocol pack to load
                    	**type**\: str
                    
                    .. attribute:: force
                    
                    	Force
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Ip.Nbar.ProtocolPack.Filepath, self).__init__()

                        self.yang_name = "filepath"
                        self.yang_parent_name = "protocol-pack"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['filepath']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('filepath', (YLeaf(YType.str, 'filepath'), ['str'])),
                            ('force', (YLeaf(YType.empty, 'force'), ['Empty'])),
                        ])
                        self.filepath = None
                        self.force = None
                        self._segment_path = lambda: "filepath" + "[filepath='" + str(self.filepath) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nbar:nbar/protocol-pack/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nbar.ProtocolPack.Filepath, ['filepath', 'force'], name, value)


        class Msdp(Entity):
            """
            MSDP global commands
            
            .. attribute:: peer
            
            	Configure an MSDP peer
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Peer>`
            
            .. attribute:: cache_rejected_sa
            
            	Store rejected SAs from all peers
            	**type**\: int
            
            	**range:** 1..32766
            
            .. attribute:: cache_sa_state
            
            	Configure this system to cache SA state
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: default_peer
            
            	Default MSDP peer to accept SA messages from
            	**type**\:  :py:class:`DefaultPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.DefaultPeer>`
            
            .. attribute:: description
            
            	Peer specific description
            	**type**\:  :py:class:`Description <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Description>`
            
            .. attribute:: filter_sa_request
            
            	Filter SA\-Requests from peer
            	**type**\:  :py:class:`FilterSaRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.FilterSaRequest>`
            
            .. attribute:: keepalive
            
            	Configure keepalive parameters for a peer
            	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Keepalive>`
            
            .. attribute:: mesh_group
            
            	Configure an MSDP mesh\-group
            	**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.MeshGroup>`
            
            .. attribute:: originator_id
            
            	Configure MSDP Originator ID
            	**type**\: str
            
            .. attribute:: password
            
            	Configure an MSDP password
            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Password>`
            
            .. attribute:: redistribute
            
            	Inject multicast route entries into MSDP
            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Redistribute>`
            
            .. attribute:: rpf
            
            	MSDP rpf
            	**type**\:  :py:class:`Rpf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Rpf>`
            
            .. attribute:: sa_filter
            
            	Filter SA messages from peer
            	**type**\:  :py:class:`SaFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.SaFilter>`
            
            .. attribute:: sa_limit
            
            	Configure SA limit for a peer
            	**type**\:  :py:class:`SaLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.SaLimit>`
            
            .. attribute:: shutdown
            
            	Administratively shutdown MSDP peer
            	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Shutdown>`
            
            .. attribute:: timer
            
            	MSDP timer
            	**type**\: int
            
            	**range:** 1..60
            
            .. attribute:: ttl_threshold
            
            	Configure TTL Threshold for MSDP Peer
            	**type**\:  :py:class:`TtlThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.TtlThreshold>`
            
            .. attribute:: vrf
            
            	Select VPN Routing/Forwarding instance
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf>`
            
            

            """

            _prefix = 'ios-mc'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ip.Msdp, self).__init__()

                self.yang_name = "msdp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("peer", ("peer", Native.Ip.Msdp.Peer)), ("default-peer", ("default_peer", Native.Ip.Msdp.DefaultPeer)), ("description", ("description", Native.Ip.Msdp.Description)), ("filter-sa-request", ("filter_sa_request", Native.Ip.Msdp.FilterSaRequest)), ("keepalive", ("keepalive", Native.Ip.Msdp.Keepalive)), ("mesh-group", ("mesh_group", Native.Ip.Msdp.MeshGroup)), ("password", ("password", Native.Ip.Msdp.Password)), ("redistribute", ("redistribute", Native.Ip.Msdp.Redistribute)), ("sa-filter", ("sa_filter", Native.Ip.Msdp.SaFilter)), ("sa-limit", ("sa_limit", Native.Ip.Msdp.SaLimit)), ("shutdown", ("shutdown", Native.Ip.Msdp.Shutdown)), ("ttl-threshold", ("ttl_threshold", Native.Ip.Msdp.TtlThreshold)), ("vrf", ("vrf", Native.Ip.Msdp.Vrf))])
                self._leafs = OrderedDict([
                    ('cache_rejected_sa', (YLeaf(YType.uint32, 'cache-rejected-sa'), ['int'])),
                    ('cache_sa_state', (YLeaf(YType.empty, 'cache-sa-state'), ['Empty'])),
                    ('originator_id', (YLeaf(YType.str, 'originator-id'), ['str'])),
                    ('rpf', (YLeaf(YType.enumeration, 'rpf'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Msdp.Rpf')])),
                    ('timer', (YLeaf(YType.uint8, 'timer'), ['int'])),
                ])
                self.cache_rejected_sa = None
                self.cache_sa_state = None
                self.originator_id = None
                self.rpf = None
                self.timer = None

                self.peer = Native.Ip.Msdp.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.default_peer = Native.Ip.Msdp.DefaultPeer()
                self.default_peer.parent = self
                self._children_name_map["default_peer"] = "default-peer"

                self.description = Native.Ip.Msdp.Description()
                self.description.parent = self
                self._children_name_map["description"] = "description"

                self.filter_sa_request = Native.Ip.Msdp.FilterSaRequest()
                self.filter_sa_request.parent = self
                self._children_name_map["filter_sa_request"] = "filter-sa-request"

                self.keepalive = Native.Ip.Msdp.Keepalive()
                self.keepalive.parent = self
                self._children_name_map["keepalive"] = "keepalive"

                self.mesh_group = Native.Ip.Msdp.MeshGroup()
                self.mesh_group.parent = self
                self._children_name_map["mesh_group"] = "mesh-group"

                self.password = Native.Ip.Msdp.Password()
                self.password.parent = self
                self._children_name_map["password"] = "password"

                self.redistribute = Native.Ip.Msdp.Redistribute()
                self.redistribute.parent = self
                self._children_name_map["redistribute"] = "redistribute"

                self.sa_filter = Native.Ip.Msdp.SaFilter()
                self.sa_filter.parent = self
                self._children_name_map["sa_filter"] = "sa-filter"

                self.sa_limit = Native.Ip.Msdp.SaLimit()
                self.sa_limit.parent = self
                self._children_name_map["sa_limit"] = "sa-limit"

                self.shutdown = Native.Ip.Msdp.Shutdown()
                self.shutdown.parent = self
                self._children_name_map["shutdown"] = "shutdown"

                self.ttl_threshold = Native.Ip.Msdp.TtlThreshold()
                self.ttl_threshold.parent = self
                self._children_name_map["ttl_threshold"] = "ttl-threshold"

                self.vrf = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-multicast:msdp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Msdp, ['cache_rejected_sa', 'cache_sa_state', 'originator_id', 'rpf', 'timer'], name, value)

            class Rpf(Enum):
                """
                Rpf (Enum Class)

                MSDP rpf

                .. data:: rfc3618 = 0

                """

                rfc3618 = Enum.YLeaf(0, "rfc3618")



            class Peer(Entity):
                """
                Configure an MSDP peer
                
                .. attribute:: addr
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: connect_source
                
                	Configure source address used for MSDP connection
                	**type**\: str
                
                .. attribute:: remote_as
                
                	Configured AS number
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('addr', (YLeaf(YType.str, 'addr'), ['str','str'])),
                        ('connect_source', (YLeaf(YType.str, 'connect-source'), ['str'])),
                        ('remote_as', (YLeaf(YType.uint16, 'remote-as'), ['int'])),
                    ])
                    self.addr = None
                    self.connect_source = None
                    self.remote_as = None
                    self._segment_path = lambda: "peer"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.Peer, ['addr', 'connect_source', 'remote_as'], name, value)


            class DefaultPeer(Entity):
                """
                Default MSDP peer to accept SA messages from
                
                .. attribute:: name_addr
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: prefix_list
                
                	Prefix list
                	**type**\: str
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.DefaultPeer, self).__init__()

                    self.yang_name = "default-peer"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                    ])
                    self.name_addr = None
                    self.prefix_list = None
                    self._segment_path = lambda: "default-peer"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.DefaultPeer, ['name_addr', 'prefix_list'], name, value)


            class Description(Entity):
                """
                Peer specific description
                
                .. attribute:: name_addr
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: description
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.Description, self).__init__()

                    self.yang_name = "description"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.name_addr = None
                    self.description = None
                    self._segment_path = lambda: "description"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.Description, ['name_addr', 'description'], name, value)


            class FilterSaRequest(Entity):
                """
                Filter SA\-Requests from peer
                
                .. attribute:: name_addr
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: list
                
                	Access\-list
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: int
                
                			**range:** 1300..1999
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.FilterSaRequest, self).__init__()

                    self.yang_name = "filter-sa-request"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                        ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                    ])
                    self.name_addr = None
                    self.list = None
                    self._segment_path = lambda: "filter-sa-request"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.FilterSaRequest, ['name_addr', 'list'], name, value)


            class Keepalive(Entity):
                """
                Configure keepalive parameters for a peer
                
                .. attribute:: name_addr
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: keepalive
                
                	Send keepalive period in seconds
                	**type**\: int
                
                	**range:** 1..60
                
                .. attribute:: max_wait
                
                	Maximum time in seconds to wait for a message
                	**type**\: int
                
                	**range:** 1..75
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.Keepalive, self).__init__()

                    self.yang_name = "keepalive"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                        ('keepalive', (YLeaf(YType.uint8, 'keepalive'), ['int'])),
                        ('max_wait', (YLeaf(YType.uint8, 'max-wait'), ['int'])),
                    ])
                    self.name_addr = None
                    self.keepalive = None
                    self.max_wait = None
                    self._segment_path = lambda: "keepalive"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.Keepalive, ['name_addr', 'keepalive', 'max_wait'], name, value)


            class MeshGroup(Entity):
                """
                Configure an MSDP mesh\-group
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: addr
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.MeshGroup, self).__init__()

                    self.yang_name = "mesh-group"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('addr', (YLeaf(YType.str, 'addr'), ['str','str'])),
                    ])
                    self.name = None
                    self.addr = None
                    self._segment_path = lambda: "mesh-group"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.MeshGroup, ['name', 'addr'], name, value)


            class Password(Entity):
                """
                Configure an MSDP password
                
                .. attribute:: peer
                
                	MSDP peer on which the password is to be set
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Password.Peer>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.Password, self).__init__()

                    self.yang_name = "password"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("peer", ("peer", Native.Ip.Msdp.Password.Peer))])
                    self._leafs = OrderedDict()

                    self.peer = Native.Ip.Msdp.Password.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"
                    self._segment_path = lambda: "password"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.Password, [], name, value)


                class Peer(Entity):
                    """
                    MSDP peer on which the password is to be set
                    
                    .. attribute:: addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: encryption
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Password.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "password"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('addr', (YLeaf(YType.str, 'addr'), ['str','str'])),
                            ('encryption', (YLeaf(YType.uint8, 'encryption'), ['int'])),
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.addr = None
                        self.encryption = None
                        self.password = None
                        self._segment_path = lambda: "peer"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/password/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Password.Peer, ['addr', 'encryption', 'password'], name, value)


            class Redistribute(Entity):
                """
                Inject multicast route entries into MSDP
                
                .. attribute:: list
                
                	Access\-list
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 100..199
                
                		**type**\: int
                
                			**range:** 2000..2699
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: asn
                
                	AS access\-list
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: route_map
                
                	Route\-map
                	**type**\: str
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.Redistribute, self).__init__()

                    self.yang_name = "redistribute"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                        ('asn', (YLeaf(YType.uint16, 'asn'), ['int'])),
                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                    ])
                    self.list = None
                    self.asn = None
                    self.route_map = None
                    self._segment_path = lambda: "redistribute"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.Redistribute, ['list', 'asn', 'route_map'], name, value)


            class SaFilter(Entity):
                """
                Filter SA messages from peer
                
                .. attribute:: in_
                
                	Enable incoming SA filtering
                	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.SaFilter.In>`
                
                .. attribute:: out
                
                	Enable outgoing SA filtering
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.SaFilter.Out>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.SaFilter, self).__init__()

                    self.yang_name = "sa-filter"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("in", ("in_", Native.Ip.Msdp.SaFilter.In)), ("out", ("out", Native.Ip.Msdp.SaFilter.Out))])
                    self._leafs = OrderedDict()

                    self.in_ = Native.Ip.Msdp.SaFilter.In()
                    self.in_.parent = self
                    self._children_name_map["in_"] = "in"

                    self.out = Native.Ip.Msdp.SaFilter.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "sa-filter"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.SaFilter, [], name, value)


                class In(Entity):
                    """
                    Enable incoming SA filtering
                    
                    .. attribute:: addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: list
                    
                    	Access list
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 100..199
                    
                    		**type**\: int
                    
                    			**range:** 2000..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: route_map
                    
                    	Route map
                    	**type**\: str
                    
                    .. attribute:: rp_list
                    
                    	Access\-list for originating RP
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: str
                    
                    .. attribute:: rp_route_map
                    
                    	Route map for originating RP
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.SaFilter.In, self).__init__()

                        self.yang_name = "in"
                        self.yang_parent_name = "sa-filter"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('addr', (YLeaf(YType.str, 'addr'), ['str','str'])),
                            ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ('rp_list', (YLeaf(YType.str, 'rp-list'), ['int','str'])),
                            ('rp_route_map', (YLeaf(YType.str, 'rp-route-map'), ['str'])),
                        ])
                        self.addr = None
                        self.list = None
                        self.route_map = None
                        self.rp_list = None
                        self.rp_route_map = None
                        self._segment_path = lambda: "in"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/sa-filter/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.SaFilter.In, ['addr', 'list', 'route_map', 'rp_list', 'rp_route_map'], name, value)


                class Out(Entity):
                    """
                    Enable outgoing SA filtering
                    
                    .. attribute:: addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: list
                    
                    	Access list
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 100..199
                    
                    		**type**\: int
                    
                    			**range:** 2000..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: route_map
                    
                    	Route map
                    	**type**\: str
                    
                    .. attribute:: rp_list
                    
                    	Access\-list for originating RP
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: str
                    
                    .. attribute:: rp_route_map
                    
                    	Route map for originating RP
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.SaFilter.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "sa-filter"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('addr', (YLeaf(YType.str, 'addr'), ['str','str'])),
                            ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ('rp_list', (YLeaf(YType.str, 'rp-list'), ['int','str'])),
                            ('rp_route_map', (YLeaf(YType.str, 'rp-route-map'), ['str'])),
                        ])
                        self.addr = None
                        self.list = None
                        self.route_map = None
                        self.rp_list = None
                        self.rp_route_map = None
                        self._segment_path = lambda: "out"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/sa-filter/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.SaFilter.Out, ['addr', 'list', 'route_map', 'rp_list', 'rp_route_map'], name, value)


            class SaLimit(Entity):
                """
                Configure SA limit for a peer
                
                .. attribute:: name_addr
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: limit
                
                	Limit of SAs
                	**type**\: int
                
                	**range:** 1..2147483646
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.SaLimit, self).__init__()

                    self.yang_name = "sa-limit"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                    ])
                    self.name_addr = None
                    self.limit = None
                    self._segment_path = lambda: "sa-limit"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.SaLimit, ['name_addr', 'limit'], name, value)


            class Shutdown(Entity):
                """
                Administratively shutdown MSDP peer
                
                .. attribute:: name_addr
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.Shutdown, self).__init__()

                    self.yang_name = "shutdown"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                    ])
                    self.name_addr = None
                    self._segment_path = lambda: "shutdown"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.Shutdown, ['name_addr'], name, value)


            class TtlThreshold(Entity):
                """
                Configure TTL Threshold for MSDP Peer
                
                .. attribute:: name_addr
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: threshold
                
                	TTL Threshold Value
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.TtlThreshold, self).__init__()

                    self.yang_name = "ttl-threshold"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                    ])
                    self.name_addr = None
                    self.threshold = None
                    self._segment_path = lambda: "ttl-threshold"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.TtlThreshold, ['name_addr', 'threshold'], name, value)


            class Vrf(Entity):
                """
                Select VPN Routing/Forwarding instance
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: peer
                
                	Configure an MSDP peer
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.Peer>`
                
                .. attribute:: cache_rejected_sa
                
                	Store rejected SAs from all peers
                	**type**\: int
                
                	**range:** 1..32766
                
                .. attribute:: cache_sa_state
                
                	Configure this system to cache SA state
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: default_peer
                
                	Default MSDP peer to accept SA messages from
                	**type**\:  :py:class:`DefaultPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.DefaultPeer>`
                
                .. attribute:: description
                
                	Peer specific description
                	**type**\:  :py:class:`Description <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.Description>`
                
                .. attribute:: filter_sa_request
                
                	Filter SA\-Requests from peer
                	**type**\:  :py:class:`FilterSaRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.FilterSaRequest>`
                
                .. attribute:: keepalive
                
                	Configure keepalive parameters for a peer
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.Keepalive>`
                
                .. attribute:: mesh_group
                
                	Configure an MSDP mesh\-group
                	**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.MeshGroup>`
                
                .. attribute:: originator_id
                
                	Configure MSDP Originator ID
                	**type**\: str
                
                .. attribute:: password
                
                	Configure an MSDP password
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.Password>`
                
                .. attribute:: redistribute
                
                	Inject multicast route entries into MSDP
                	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.Redistribute>`
                
                .. attribute:: rpf
                
                	MSDP rpf
                	**type**\:  :py:class:`Rpf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.Rpf>`
                
                .. attribute:: sa_filter
                
                	Filter SA messages from peer
                	**type**\:  :py:class:`SaFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.SaFilter>`
                
                .. attribute:: sa_limit
                
                	Configure SA limit for a peer
                	**type**\:  :py:class:`SaLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.SaLimit>`
                
                .. attribute:: shutdown
                
                	Administratively shutdown MSDP peer
                	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.Shutdown>`
                
                .. attribute:: timer
                
                	MSDP timer
                	**type**\: int
                
                	**range:** 1..60
                
                .. attribute:: ttl_threshold
                
                	Configure TTL Threshold for MSDP Peer
                	**type**\:  :py:class:`TtlThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.TtlThreshold>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Msdp.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "msdp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("peer", ("peer", Native.Ip.Msdp.Vrf.Peer)), ("default-peer", ("default_peer", Native.Ip.Msdp.Vrf.DefaultPeer)), ("description", ("description", Native.Ip.Msdp.Vrf.Description)), ("filter-sa-request", ("filter_sa_request", Native.Ip.Msdp.Vrf.FilterSaRequest)), ("keepalive", ("keepalive", Native.Ip.Msdp.Vrf.Keepalive)), ("mesh-group", ("mesh_group", Native.Ip.Msdp.Vrf.MeshGroup)), ("password", ("password", Native.Ip.Msdp.Vrf.Password)), ("redistribute", ("redistribute", Native.Ip.Msdp.Vrf.Redistribute)), ("sa-filter", ("sa_filter", Native.Ip.Msdp.Vrf.SaFilter)), ("sa-limit", ("sa_limit", Native.Ip.Msdp.Vrf.SaLimit)), ("shutdown", ("shutdown", Native.Ip.Msdp.Vrf.Shutdown)), ("ttl-threshold", ("ttl_threshold", Native.Ip.Msdp.Vrf.TtlThreshold))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('cache_rejected_sa', (YLeaf(YType.uint32, 'cache-rejected-sa'), ['int'])),
                        ('cache_sa_state', (YLeaf(YType.empty, 'cache-sa-state'), ['Empty'])),
                        ('originator_id', (YLeaf(YType.str, 'originator-id'), ['str'])),
                        ('rpf', (YLeaf(YType.enumeration, 'rpf'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Msdp.Vrf.Rpf')])),
                        ('timer', (YLeaf(YType.uint8, 'timer'), ['int'])),
                    ])
                    self.name = None
                    self.cache_rejected_sa = None
                    self.cache_sa_state = None
                    self.originator_id = None
                    self.rpf = None
                    self.timer = None

                    self.peer = Native.Ip.Msdp.Vrf.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"

                    self.default_peer = Native.Ip.Msdp.Vrf.DefaultPeer()
                    self.default_peer.parent = self
                    self._children_name_map["default_peer"] = "default-peer"

                    self.description = Native.Ip.Msdp.Vrf.Description()
                    self.description.parent = self
                    self._children_name_map["description"] = "description"

                    self.filter_sa_request = Native.Ip.Msdp.Vrf.FilterSaRequest()
                    self.filter_sa_request.parent = self
                    self._children_name_map["filter_sa_request"] = "filter-sa-request"

                    self.keepalive = Native.Ip.Msdp.Vrf.Keepalive()
                    self.keepalive.parent = self
                    self._children_name_map["keepalive"] = "keepalive"

                    self.mesh_group = Native.Ip.Msdp.Vrf.MeshGroup()
                    self.mesh_group.parent = self
                    self._children_name_map["mesh_group"] = "mesh-group"

                    self.password = Native.Ip.Msdp.Vrf.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "password"

                    self.redistribute = Native.Ip.Msdp.Vrf.Redistribute()
                    self.redistribute.parent = self
                    self._children_name_map["redistribute"] = "redistribute"

                    self.sa_filter = Native.Ip.Msdp.Vrf.SaFilter()
                    self.sa_filter.parent = self
                    self._children_name_map["sa_filter"] = "sa-filter"

                    self.sa_limit = Native.Ip.Msdp.Vrf.SaLimit()
                    self.sa_limit.parent = self
                    self._children_name_map["sa_limit"] = "sa-limit"

                    self.shutdown = Native.Ip.Msdp.Vrf.Shutdown()
                    self.shutdown.parent = self
                    self._children_name_map["shutdown"] = "shutdown"

                    self.ttl_threshold = Native.Ip.Msdp.Vrf.TtlThreshold()
                    self.ttl_threshold.parent = self
                    self._children_name_map["ttl_threshold"] = "ttl-threshold"
                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:msdp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Msdp.Vrf, ['name', 'cache_rejected_sa', 'cache_sa_state', 'originator_id', 'rpf', 'timer'], name, value)

                class Rpf(Enum):
                    """
                    Rpf (Enum Class)

                    MSDP rpf

                    .. data:: rfc3618 = 0

                    """

                    rfc3618 = Enum.YLeaf(0, "rfc3618")



                class Peer(Entity):
                    """
                    Configure an MSDP peer
                    
                    .. attribute:: addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: connect_source
                    
                    	Configure source address used for MSDP connection
                    	**type**\: str
                    
                    .. attribute:: remote_as
                    
                    	Configured AS number
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('addr', (YLeaf(YType.str, 'addr'), ['str','str'])),
                            ('connect_source', (YLeaf(YType.str, 'connect-source'), ['str'])),
                            ('remote_as', (YLeaf(YType.uint16, 'remote-as'), ['int'])),
                        ])
                        self.addr = None
                        self.connect_source = None
                        self.remote_as = None
                        self._segment_path = lambda: "peer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.Peer, ['addr', 'connect_source', 'remote_as'], name, value)


                class DefaultPeer(Entity):
                    """
                    Default MSDP peer to accept SA messages from
                    
                    .. attribute:: name_addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_list
                    
                    	Prefix list
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.DefaultPeer, self).__init__()

                        self.yang_name = "default-peer"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                        ])
                        self.name_addr = None
                        self.prefix_list = None
                        self._segment_path = lambda: "default-peer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.DefaultPeer, ['name_addr', 'prefix_list'], name, value)


                class Description(Entity):
                    """
                    Peer specific description
                    
                    .. attribute:: name_addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: description
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.Description, self).__init__()

                        self.yang_name = "description"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ])
                        self.name_addr = None
                        self.description = None
                        self._segment_path = lambda: "description"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.Description, ['name_addr', 'description'], name, value)


                class FilterSaRequest(Entity):
                    """
                    Filter SA\-Requests from peer
                    
                    .. attribute:: name_addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: list
                    
                    	Access\-list
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.FilterSaRequest, self).__init__()

                        self.yang_name = "filter-sa-request"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                            ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                        ])
                        self.name_addr = None
                        self.list = None
                        self._segment_path = lambda: "filter-sa-request"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.FilterSaRequest, ['name_addr', 'list'], name, value)


                class Keepalive(Entity):
                    """
                    Configure keepalive parameters for a peer
                    
                    .. attribute:: name_addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: keepalive
                    
                    	Send keepalive period in seconds
                    	**type**\: int
                    
                    	**range:** 1..60
                    
                    .. attribute:: max_wait
                    
                    	Maximum time in seconds to wait for a message
                    	**type**\: int
                    
                    	**range:** 1..75
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                            ('keepalive', (YLeaf(YType.uint8, 'keepalive'), ['int'])),
                            ('max_wait', (YLeaf(YType.uint8, 'max-wait'), ['int'])),
                        ])
                        self.name_addr = None
                        self.keepalive = None
                        self.max_wait = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.Keepalive, ['name_addr', 'keepalive', 'max_wait'], name, value)


                class MeshGroup(Entity):
                    """
                    Configure an MSDP mesh\-group
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.MeshGroup, self).__init__()

                        self.yang_name = "mesh-group"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('addr', (YLeaf(YType.str, 'addr'), ['str','str'])),
                        ])
                        self.name = None
                        self.addr = None
                        self._segment_path = lambda: "mesh-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.MeshGroup, ['name', 'addr'], name, value)


                class Password(Entity):
                    """
                    Configure an MSDP password
                    
                    .. attribute:: peer
                    
                    	MSDP peer on which the password is to be set
                    	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.Password.Peer>`
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peer", ("peer", Native.Ip.Msdp.Vrf.Password.Peer))])
                        self._leafs = OrderedDict()

                        self.peer = Native.Ip.Msdp.Vrf.Password.Peer()
                        self.peer.parent = self
                        self._children_name_map["peer"] = "peer"
                        self._segment_path = lambda: "password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.Password, [], name, value)


                    class Peer(Entity):
                        """
                        MSDP peer on which the password is to be set
                        
                        .. attribute:: addr
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: encryption
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Msdp.Vrf.Password.Peer, self).__init__()

                            self.yang_name = "peer"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('addr', (YLeaf(YType.str, 'addr'), ['str','str'])),
                                ('encryption', (YLeaf(YType.uint8, 'encryption'), ['int'])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.addr = None
                            self.encryption = None
                            self.password = None
                            self._segment_path = lambda: "peer"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Msdp.Vrf.Password.Peer, ['addr', 'encryption', 'password'], name, value)


                class Redistribute(Entity):
                    """
                    Inject multicast route entries into MSDP
                    
                    .. attribute:: list
                    
                    	Access\-list
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 100..199
                    
                    		**type**\: int
                    
                    			**range:** 2000..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: asn
                    
                    	AS access\-list
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: route_map
                    
                    	Route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.Redistribute, self).__init__()

                        self.yang_name = "redistribute"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                            ('asn', (YLeaf(YType.uint16, 'asn'), ['int'])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.list = None
                        self.asn = None
                        self.route_map = None
                        self._segment_path = lambda: "redistribute"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.Redistribute, ['list', 'asn', 'route_map'], name, value)


                class SaFilter(Entity):
                    """
                    Filter SA messages from peer
                    
                    .. attribute:: in_
                    
                    	Enable incoming SA filtering
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.SaFilter.In>`
                    
                    .. attribute:: out
                    
                    	Enable outgoing SA filtering
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Msdp.Vrf.SaFilter.Out>`
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.SaFilter, self).__init__()

                        self.yang_name = "sa-filter"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Ip.Msdp.Vrf.SaFilter.In)), ("out", ("out", Native.Ip.Msdp.Vrf.SaFilter.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Ip.Msdp.Vrf.SaFilter.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Ip.Msdp.Vrf.SaFilter.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "sa-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.SaFilter, [], name, value)


                    class In(Entity):
                        """
                        Enable incoming SA filtering
                        
                        .. attribute:: addr
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: list
                        
                        	Access list
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 100..199
                        
                        		**type**\: int
                        
                        			**range:** 2000..2699
                        
                        		**type**\: str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: route_map
                        
                        	Route map
                        	**type**\: str
                        
                        .. attribute:: rp_list
                        
                        	Access\-list for originating RP
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..99
                        
                        		**type**\: str
                        
                        .. attribute:: rp_route_map
                        
                        	Route map for originating RP
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Msdp.Vrf.SaFilter.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "sa-filter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('addr', (YLeaf(YType.str, 'addr'), ['str','str'])),
                                ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('rp_list', (YLeaf(YType.str, 'rp-list'), ['int','str'])),
                                ('rp_route_map', (YLeaf(YType.str, 'rp-route-map'), ['str'])),
                            ])
                            self.addr = None
                            self.list = None
                            self.route_map = None
                            self.rp_list = None
                            self.rp_route_map = None
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Msdp.Vrf.SaFilter.In, ['addr', 'list', 'route_map', 'rp_list', 'rp_route_map'], name, value)


                    class Out(Entity):
                        """
                        Enable outgoing SA filtering
                        
                        .. attribute:: addr
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: list
                        
                        	Access list
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 100..199
                        
                        		**type**\: int
                        
                        			**range:** 2000..2699
                        
                        		**type**\: str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: route_map
                        
                        	Route map
                        	**type**\: str
                        
                        .. attribute:: rp_list
                        
                        	Access\-list for originating RP
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..99
                        
                        		**type**\: str
                        
                        .. attribute:: rp_route_map
                        
                        	Route map for originating RP
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Msdp.Vrf.SaFilter.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "sa-filter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('addr', (YLeaf(YType.str, 'addr'), ['str','str'])),
                                ('list', (YLeaf(YType.str, 'list'), ['int','int','str'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('rp_list', (YLeaf(YType.str, 'rp-list'), ['int','str'])),
                                ('rp_route_map', (YLeaf(YType.str, 'rp-route-map'), ['str'])),
                            ])
                            self.addr = None
                            self.list = None
                            self.route_map = None
                            self.rp_list = None
                            self.rp_route_map = None
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Msdp.Vrf.SaFilter.Out, ['addr', 'list', 'route_map', 'rp_list', 'rp_route_map'], name, value)


                class SaLimit(Entity):
                    """
                    Configure SA limit for a peer
                    
                    .. attribute:: name_addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: limit
                    
                    	Limit of SAs
                    	**type**\: int
                    
                    	**range:** 1..2147483646
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.SaLimit, self).__init__()

                        self.yang_name = "sa-limit"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                        ])
                        self.name_addr = None
                        self.limit = None
                        self._segment_path = lambda: "sa-limit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.SaLimit, ['name_addr', 'limit'], name, value)


                class Shutdown(Entity):
                    """
                    Administratively shutdown MSDP peer
                    
                    .. attribute:: name_addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.Shutdown, self).__init__()

                        self.yang_name = "shutdown"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                        ])
                        self.name_addr = None
                        self._segment_path = lambda: "shutdown"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.Shutdown, ['name_addr'], name, value)


                class TtlThreshold(Entity):
                    """
                    Configure TTL Threshold for MSDP Peer
                    
                    .. attribute:: name_addr
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: threshold
                    
                    	TTL Threshold Value
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Msdp.Vrf.TtlThreshold, self).__init__()

                        self.yang_name = "ttl-threshold"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name_addr', (YLeaf(YType.str, 'name-addr'), ['str','str'])),
                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                        ])
                        self.name_addr = None
                        self.threshold = None
                        self._segment_path = lambda: "ttl-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Msdp.Vrf.TtlThreshold, ['name_addr', 'threshold'], name, value)


        class McrConf(Entity):
            """
            
            
            .. attribute:: multicast_routing
            
            	Enable IP multicast forwarding
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-mc'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ip.McrConf, self).__init__()

                self.yang_name = "mcr-conf"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('multicast_routing', (YLeaf(YType.empty, 'multicast-routing'), ['Empty'])),
                ])
                self.multicast_routing = None
                self._segment_path = lambda: "Cisco-IOS-XE-multicast:mcr-conf"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.McrConf, ['multicast_routing'], name, value)


        class MulticastRouting(Entity):
            """
            Enable IP multicast forwarding
            
            .. attribute:: vrf
            
            	Select VPN Routing/Forwarding instance
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.MulticastRouting.Vrf>`
            
            .. attribute:: distributed
            
            	Distributed multicast switching
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-mc'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ip.MulticastRouting, self).__init__()

                self.yang_name = "multicast-routing"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ip.MulticastRouting.Vrf))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('distributed', (YLeaf(YType.empty, 'distributed'), ['Empty'])),
                ])
                self.distributed = None

                self.vrf = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-multicast:multicast-routing"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.MulticastRouting, ['distributed'], name, value)


            class Vrf(Entity):
                """
                Select VPN Routing/Forwarding instance
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: distributed
                
                	Distributed multicast switching
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.MulticastRouting.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "multicast-routing"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('distributed', (YLeaf(YType.empty, 'distributed'), ['Empty'])),
                    ])
                    self.name = None
                    self.distributed = None
                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-multicast:multicast-routing/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.MulticastRouting.Vrf, ['name', 'distributed'], name, value)


        class Mroute(Entity):
            """
            Configure static multicast routes
            
            .. attribute:: source_address
            
            	
            	**type**\: str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: subnet_mask
            
            	
            	**type**\: str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: tunnel
            
            	Tunnel interface
            	**type**\: int
            
            	**range:** 0..2147483647
            
            

            """

            _prefix = 'ios-mc'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ip.Mroute, self).__init__()

                self.yang_name = "mroute"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                    ('subnet_mask', (YLeaf(YType.str, 'subnet-mask'), ['str'])),
                    ('tunnel', (YLeaf(YType.int32, 'Tunnel'), ['int'])),
                ])
                self.source_address = None
                self.subnet_mask = None
                self.tunnel = None
                self._segment_path = lambda: "Cisco-IOS-XE-multicast:mroute"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Mroute, ['source_address', 'subnet_mask', 'tunnel'], name, value)


        class Rsvp(Entity):
            """
            IP RSVP
            
            .. attribute:: authentication
            
            	Enables RSVP neighbor authentication (RFC 2747)
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication>`
            
            	**presence node**\: True
            
            .. attribute:: signalling
            
            	IP RSVP signalling
            	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling>`
            
            

            """

            _prefix = 'ios-rsvp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Ip.Rsvp, self).__init__()

                self.yang_name = "rsvp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Ip.Rsvp.Authentication)), ("signalling", ("signalling", Native.Ip.Rsvp.Signalling))])
                self._leafs = OrderedDict()

                self.authentication = None
                self._children_name_map["authentication"] = "authentication"

                self.signalling = Native.Ip.Rsvp.Signalling()
                self.signalling.parent = self
                self._children_name_map["signalling"] = "signalling"
                self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Rsvp, [], name, value)


            class Authentication(Entity):
                """
                Enables RSVP neighbor authentication (RFC 2747)
                
                .. attribute:: neighbor
                
                	Specific neighbor(s) to authenticate
                	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor>`
                
                .. attribute:: challenge
                
                	Perform challenge/response handshake with new neighbor(s)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: key_chain
                
                	Name of key chain to use (as created by global 'key chain' command)
                	**type**\: str
                
                .. attribute:: lifetime
                
                	Maximum lifetime of neighbor authentication state
                	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Lifetime>`
                
                .. attribute:: type
                
                	Type of authentication algorithm (default = md5)
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Type>`
                
                .. attribute:: window_size
                
                	Maximum number of messages allowed in receive window (default = 1)
                	**type**\: int
                
                	**range:** 1..64
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-rsvp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ip.Rsvp.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "rsvp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Ip.Rsvp.Authentication.Neighbor)), ("lifetime", ("lifetime", Native.Ip.Rsvp.Authentication.Lifetime))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                        ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Rsvp.Authentication.Type')])),
                        ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                    ])
                    self.challenge = None
                    self.key_chain = None
                    self.type = None
                    self.window_size = None

                    self.neighbor = Native.Ip.Rsvp.Authentication.Neighbor()
                    self.neighbor.parent = self
                    self._children_name_map["neighbor"] = "neighbor"

                    self.lifetime = Native.Ip.Rsvp.Authentication.Lifetime()
                    self.lifetime.parent = self
                    self._children_name_map["lifetime"] = "lifetime"
                    self._segment_path = lambda: "authentication"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Rsvp.Authentication, ['challenge', 'key_chain', 'type', 'window_size'], name, value)

                class Type(Enum):
                    """
                    Type (Enum Class)

                    Type of authentication algorithm (default = md5)

                    .. data:: md5 = 0

                    .. data:: sha_1 = 1

                    """

                    md5 = Enum.YLeaf(0, "md5")

                    sha_1 = Enum.YLeaf(1, "sha-1")



                class Neighbor(Entity):
                    """
                    Specific neighbor(s) to authenticate
                    
                    .. attribute:: access_list
                    
                    	Specify neighbor by IP access list
                    	**type**\:  :py:class:`AccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor.AccessList>`
                    
                    .. attribute:: address
                    
                    	Specify neighbor by IP address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor.Address>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Rsvp.Authentication.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-list", ("access_list", Native.Ip.Rsvp.Authentication.Neighbor.AccessList)), ("address", ("address", Native.Ip.Rsvp.Authentication.Neighbor.Address))])
                        self._leafs = OrderedDict()

                        self.access_list = Native.Ip.Rsvp.Authentication.Neighbor.AccessList()
                        self.access_list.parent = self
                        self._children_name_map["access_list"] = "access-list"

                        self.address = Native.Ip.Rsvp.Authentication.Neighbor.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/authentication/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Rsvp.Authentication.Neighbor, [], name, value)


                    class AccessList(Entity):
                        """
                        Specify neighbor by IP access list
                        
                        .. attribute:: number
                        
                        	
                        	**type**\: list of  		 :py:class:`Number <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Number>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Name>`
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Rsvp.Authentication.Neighbor.AccessList, self).__init__()

                            self.yang_name = "access-list"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("number", ("number", Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Number)), ("name", ("name", Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Name))])
                            self._leafs = OrderedDict()

                            self.number = YList(self)
                            self.name = YList(self)
                            self._segment_path = lambda: "access-list"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/authentication/neighbor/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Rsvp.Authentication.Neighbor.AccessList, [], name, value)


                        class Number(Entity):
                            """
                            
                            
                            .. attribute:: acl_number  (key)
                            
                            	standard IP access list number
                            	**type**\: int
                            
                            	**range:** 1..99
                            
                            .. attribute:: challenge
                            
                            	Perform challenge/response handshake with new neighbor(s)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: key_chain
                            
                            	Name of key chain to use (as created by global 'key chain' command)
                            	**type**\: str
                            
                            .. attribute:: lifetime
                            
                            	Maximum lifetime of neighbor authentication state
                            	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Number.Lifetime>`
                            
                            .. attribute:: type
                            
                            	Type of authentication algorithm (default = md5)
                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Number.Type>`
                            
                            .. attribute:: window_size
                            
                            	Maximum number of messages allowed in receive window (default = 1)
                            	**type**\: int
                            
                            	**range:** 1..64
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Number, self).__init__()

                                self.yang_name = "number"
                                self.yang_parent_name = "access-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['acl_number']
                                self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Number.Lifetime))])
                                self._leafs = OrderedDict([
                                    ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                                    ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Rsvp.Authentication.Neighbor.AccessList.Number.Type')])),
                                    ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                                ])
                                self.acl_number = None
                                self.challenge = None
                                self.key_chain = None
                                self.type = None
                                self.window_size = None

                                self.lifetime = Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Number.Lifetime()
                                self.lifetime.parent = self
                                self._children_name_map["lifetime"] = "lifetime"
                                self._segment_path = lambda: "number" + "[acl-number='" + str(self.acl_number) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/authentication/neighbor/access-list/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Number, ['acl_number', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                            class Type(Enum):
                                """
                                Type (Enum Class)

                                Type of authentication algorithm (default = md5)

                                .. data:: md5 = 0

                                .. data:: sha_1 = 1

                                """

                                md5 = Enum.YLeaf(0, "md5")

                                sha_1 = Enum.YLeaf(1, "sha-1")



                            class Lifetime(Entity):
                                """
                                Maximum lifetime of neighbor authentication state
                                
                                .. attribute:: hh_mm_ss
                                
                                	Lifetime (default = 30 mins) in hh\:mm\:ss format
                                	**type**\: str
                                
                                	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Number.Lifetime, self).__init__()

                                    self.yang_name = "lifetime"
                                    self.yang_parent_name = "number"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                    ])
                                    self.hh_mm_ss = None
                                    self._segment_path = lambda: "lifetime"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Number.Lifetime, ['hh_mm_ss'], name, value)


                        class Name(Entity):
                            """
                            
                            
                            .. attribute:: acl_name  (key)
                            
                            	standard IP access list name
                            	**type**\: str
                            
                            .. attribute:: challenge
                            
                            	Perform challenge/response handshake with new neighbor(s)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: key_chain
                            
                            	Name of key chain to use (as created by global 'key chain' command)
                            	**type**\: str
                            
                            .. attribute:: lifetime
                            
                            	Maximum lifetime of neighbor authentication state
                            	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Name.Lifetime>`
                            
                            .. attribute:: type
                            
                            	Type of authentication algorithm (default = md5)
                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Name.Type>`
                            
                            .. attribute:: window_size
                            
                            	Maximum number of messages allowed in receive window (default = 1)
                            	**type**\: int
                            
                            	**range:** 1..64
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Name, self).__init__()

                                self.yang_name = "name"
                                self.yang_parent_name = "access-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Name.Lifetime))])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Rsvp.Authentication.Neighbor.AccessList.Name.Type')])),
                                    ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                                ])
                                self.acl_name = None
                                self.challenge = None
                                self.key_chain = None
                                self.type = None
                                self.window_size = None

                                self.lifetime = Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Name.Lifetime()
                                self.lifetime.parent = self
                                self._children_name_map["lifetime"] = "lifetime"
                                self._segment_path = lambda: "name" + "[acl-name='" + str(self.acl_name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/authentication/neighbor/access-list/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Name, ['acl_name', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                            class Type(Enum):
                                """
                                Type (Enum Class)

                                Type of authentication algorithm (default = md5)

                                .. data:: md5 = 0

                                .. data:: sha_1 = 1

                                """

                                md5 = Enum.YLeaf(0, "md5")

                                sha_1 = Enum.YLeaf(1, "sha-1")



                            class Lifetime(Entity):
                                """
                                Maximum lifetime of neighbor authentication state
                                
                                .. attribute:: hh_mm_ss
                                
                                	Lifetime (default = 30 mins) in hh\:mm\:ss format
                                	**type**\: str
                                
                                	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Name.Lifetime, self).__init__()

                                    self.yang_name = "lifetime"
                                    self.yang_parent_name = "name"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                    ])
                                    self.hh_mm_ss = None
                                    self._segment_path = lambda: "lifetime"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Rsvp.Authentication.Neighbor.AccessList.Name.Lifetime, ['hh_mm_ss'], name, value)


                    class Address(Entity):
                        """
                        Specify neighbor by IP address
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor.Address.Ipv4>`
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Rsvp.Authentication.Neighbor.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Ip.Rsvp.Authentication.Neighbor.Address.Ipv4))])
                            self._leafs = OrderedDict()

                            self.ipv4 = YList(self)
                            self._segment_path = lambda: "address"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/authentication/neighbor/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Rsvp.Authentication.Neighbor.Address, [], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4_address  (key)
                            
                            	Neighbor's IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: challenge
                            
                            	Perform challenge/response handshake with new neighbor(s)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: key_chain
                            
                            	Name of key chain to use (as created by global 'key chain' command)
                            	**type**\: str
                            
                            .. attribute:: lifetime
                            
                            	Maximum lifetime of neighbor authentication state
                            	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor.Address.Ipv4.Lifetime>`
                            
                            .. attribute:: type
                            
                            	Type of authentication algorithm (default = md5)
                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Authentication.Neighbor.Address.Ipv4.Type>`
                            
                            .. attribute:: window_size
                            
                            	Maximum number of messages allowed in receive window (default = 1)
                            	**type**\: int
                            
                            	**range:** 1..64
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Ip.Rsvp.Authentication.Neighbor.Address.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ipv4_address']
                                self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Ip.Rsvp.Authentication.Neighbor.Address.Ipv4.Lifetime))])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Rsvp.Authentication.Neighbor.Address.Ipv4.Type')])),
                                    ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                                ])
                                self.ipv4_address = None
                                self.challenge = None
                                self.key_chain = None
                                self.type = None
                                self.window_size = None

                                self.lifetime = Native.Ip.Rsvp.Authentication.Neighbor.Address.Ipv4.Lifetime()
                                self.lifetime.parent = self
                                self._children_name_map["lifetime"] = "lifetime"
                                self._segment_path = lambda: "ipv4" + "[ipv4-address='" + str(self.ipv4_address) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/authentication/neighbor/address/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Rsvp.Authentication.Neighbor.Address.Ipv4, ['ipv4_address', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                            class Type(Enum):
                                """
                                Type (Enum Class)

                                Type of authentication algorithm (default = md5)

                                .. data:: md5 = 0

                                .. data:: sha_1 = 1

                                """

                                md5 = Enum.YLeaf(0, "md5")

                                sha_1 = Enum.YLeaf(1, "sha-1")



                            class Lifetime(Entity):
                                """
                                Maximum lifetime of neighbor authentication state
                                
                                .. attribute:: hh_mm_ss
                                
                                	Lifetime (default = 30 mins) in hh\:mm\:ss format
                                	**type**\: str
                                
                                	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Ip.Rsvp.Authentication.Neighbor.Address.Ipv4.Lifetime, self).__init__()

                                    self.yang_name = "lifetime"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                    ])
                                    self.hh_mm_ss = None
                                    self._segment_path = lambda: "lifetime"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Rsvp.Authentication.Neighbor.Address.Ipv4.Lifetime, ['hh_mm_ss'], name, value)


                class Lifetime(Entity):
                    """
                    Maximum lifetime of neighbor authentication state
                    
                    .. attribute:: hh_mm_ss
                    
                    	Lifetime (default = 30 mins) in hh\:mm\:ss format
                    	**type**\: str
                    
                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                        self.yang_name = "lifetime"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                        ])
                        self.hh_mm_ss = None
                        self._segment_path = lambda: "lifetime"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/authentication/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


            class Signalling(Entity):
                """
                IP RSVP signalling
                
                .. attribute:: fast_local_repair
                
                	Configure RSVP Fast Local Repair
                	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling.FastLocalRepair>`
                
                .. attribute:: hello
                
                	Enable neighbor\-down detection
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling.Hello>`
                
                	**presence node**\: True
                
                .. attribute:: initial_retransmit_delay
                
                	Initial retransmit delay (msecs)
                	**type**\: int
                
                	**range:** 500..30000
                
                .. attribute:: patherr
                
                	Path Error State Removal for LSP sessions
                	**type**\:  :py:class:`Patherr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling.Patherr>`
                
                .. attribute:: rate_limit
                
                	Limit rate at which RSVP msgs are sent to neighbors
                	**type**\:  :py:class:`RateLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling.RateLimit>`
                
                	**presence node**\: True
                
                .. attribute:: refresh
                
                	Configure RSVP refresh behavior
                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling.Refresh>`
                
                

                """

                _prefix = 'ios-rsvp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ip.Rsvp.Signalling, self).__init__()

                    self.yang_name = "signalling"
                    self.yang_parent_name = "rsvp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Ip.Rsvp.Signalling.Hello)), ("patherr", ("patherr", Native.Ip.Rsvp.Signalling.Patherr)), ("rate-limit", ("rate_limit", Native.Ip.Rsvp.Signalling.RateLimit)), ("refresh", ("refresh", Native.Ip.Rsvp.Signalling.Refresh))])
                    self._leafs = OrderedDict([
                        ('initial_retransmit_delay', (YLeaf(YType.uint16, 'initial-retransmit-delay'), ['int'])),
                    ])
                    self.initial_retransmit_delay = None

                    self.fast_local_repair = Native.Ip.Rsvp.Signalling.FastLocalRepair()
                    self.fast_local_repair.parent = self
                    self._children_name_map["fast_local_repair"] = "fast-local-repair"

                    self.hello = None
                    self._children_name_map["hello"] = "hello"

                    self.patherr = Native.Ip.Rsvp.Signalling.Patherr()
                    self.patherr.parent = self
                    self._children_name_map["patherr"] = "patherr"

                    self.rate_limit = None
                    self._children_name_map["rate_limit"] = "rate-limit"

                    self.refresh = Native.Ip.Rsvp.Signalling.Refresh()
                    self.refresh.parent = self
                    self._children_name_map["refresh"] = "refresh"
                    self._segment_path = lambda: "signalling"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Rsvp.Signalling, ['initial_retransmit_delay'], name, value)


                class FastLocalRepair(Entity):
                    """
                    Configure RSVP Fast Local Repair
                    
                    .. attribute:: notifications
                    
                    	Number of notifications to process before suspend
                    	**type**\: int
                    
                    	**range:** 10..10000
                    
                    .. attribute:: rate
                    
                    	Fast Local Repair state refresh/repair rate in messages/sec
                    	**type**\: int
                    
                    	**range:** 1..2500
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                        self.yang_name = "fast-local-repair"
                        self.yang_parent_name = "signalling"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('notifications', (YLeaf(YType.uint16, 'notifications'), ['int'])),
                            ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                        ])
                        self.notifications = None
                        self.rate = None
                        self._segment_path = lambda: "fast-local-repair"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/signalling/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Rsvp.Signalling.FastLocalRepair, ['notifications', 'rate'], name, value)


                class Hello(Entity):
                    """
                    Enable neighbor\-down detection
                    
                    .. attribute:: bfd
                    
                    	Enable BFD detection for fast\-reroute
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: graceful_restart
                    
                    	Configure RSVP Graceful Restart
                    	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling.Hello.GracefulRestart>`
                    
                    .. attribute:: statistics
                    
                    	Enables Hello extensions statistics
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Rsvp.Signalling.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "signalling"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Ip.Rsvp.Signalling.Hello.GracefulRestart))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('statistics', (YLeaf(YType.empty, 'statistics'), ['Empty'])),
                        ])
                        self.bfd = None
                        self.statistics = None

                        self.graceful_restart = Native.Ip.Rsvp.Signalling.Hello.GracefulRestart()
                        self.graceful_restart.parent = self
                        self._children_name_map["graceful_restart"] = "graceful-restart"
                        self._segment_path = lambda: "hello"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/signalling/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Rsvp.Signalling.Hello, ['bfd', 'statistics'], name, value)


                    class GracefulRestart(Entity):
                        """
                        Configure RSVP Graceful Restart
                        
                        .. attribute:: dscp
                        
                        	RSVP Graceful Restart Hello Messages DSCP value
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: mode
                        
                        	Select Graceful Restart capabilities
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Mode>`
                        
                        .. attribute:: refresh
                        
                        	Configure RSVP Hello refresh behavior for Graceful Restart
                        	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Refresh>`
                        
                        .. attribute:: send
                        
                        	Configure parameters in outgoing Hello msgs
                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Send>`
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Rsvp.Signalling.Hello.GracefulRestart, self).__init__()

                            self.yang_name = "graceful-restart"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Mode)), ("refresh", ("refresh", Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Refresh)), ("send", ("send", Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Send))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.mode = Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"

                            self.refresh = Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Refresh()
                            self.refresh.parent = self
                            self._children_name_map["refresh"] = "refresh"

                            self.send = Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Send()
                            self.send.parent = self
                            self._children_name_map["send"] = "send"
                            self._segment_path = lambda: "graceful-restart"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/signalling/hello/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Rsvp.Signalling.Hello.GracefulRestart, ['dscp'], name, value)


                        class Mode(Entity):
                            """
                            Select Graceful Restart capabilities
                            
                            .. attribute:: full
                            
                            	Capable of recovering self, and helping neighbor recover
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: help_neighbor
                            
                            	Capable of helping neighbor recover
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('full', (YLeaf(YType.empty, 'full'), ['Empty'])),
                                    ('help_neighbor', (YLeaf(YType.empty, 'help-neighbor'), ['Empty'])),
                                ])
                                self.full = None
                                self.help_neighbor = None
                                self._segment_path = lambda: "mode"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/signalling/hello/graceful-restart/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Mode, ['full', 'help_neighbor'], name, value)


                        class Refresh(Entity):
                            """
                            Configure RSVP Hello refresh behavior for Graceful Restart
                            
                            .. attribute:: interval
                            
                            	Hello interval in msec
                            	**type**\: int
                            
                            	**range:** 1000..30000
                            
                            .. attribute:: misses
                            
                            	Number of missed Hello Acks which triggers neighbor down
                            	**type**\: int
                            
                            	**range:** 4..10
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Refresh, self).__init__()

                                self.yang_name = "refresh"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                ])
                                self.interval = None
                                self.misses = None
                                self._segment_path = lambda: "refresh"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/signalling/hello/graceful-restart/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Refresh, ['interval', 'misses'], name, value)


                        class Send(Entity):
                            """
                            Configure parameters in outgoing Hello msgs
                            
                            .. attribute:: recovery_time
                            
                            	recovery\-time in msec
                            	**type**\: int
                            
                            	**range:** 0..3600000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Send, self).__init__()

                                self.yang_name = "send"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('recovery_time', (YLeaf(YType.uint32, 'recovery-time'), ['int'])),
                                ])
                                self.recovery_time = None
                                self._segment_path = lambda: "send"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/signalling/hello/graceful-restart/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Rsvp.Signalling.Hello.GracefulRestart.Send, ['recovery_time'], name, value)


                class Patherr(Entity):
                    """
                    Path Error State Removal for LSP sessions
                    
                    .. attribute:: state_removal
                    
                    	Enable state removal
                    	**type**\:  :py:class:`StateRemoval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling.Patherr.StateRemoval>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Rsvp.Signalling.Patherr, self).__init__()

                        self.yang_name = "patherr"
                        self.yang_parent_name = "signalling"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("state-removal", ("state_removal", Native.Ip.Rsvp.Signalling.Patherr.StateRemoval))])
                        self._leafs = OrderedDict()

                        self.state_removal = None
                        self._children_name_map["state_removal"] = "state-removal"
                        self._segment_path = lambda: "patherr"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/signalling/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Rsvp.Signalling.Patherr, [], name, value)


                    class StateRemoval(Entity):
                        """
                        Enable state removal
                        
                        .. attribute:: neighbor
                        
                        	Access list number identifying neighbor(s)
                        	**type**\: int
                        
                        	**range:** 1..99
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Rsvp.Signalling.Patherr.StateRemoval, self).__init__()

                            self.yang_name = "state-removal"
                            self.yang_parent_name = "patherr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('neighbor', (YLeaf(YType.uint8, 'neighbor'), ['int'])),
                            ])
                            self.neighbor = None
                            self._segment_path = lambda: "state-removal"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/signalling/patherr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Rsvp.Signalling.Patherr.StateRemoval, ['neighbor'], name, value)


                class RateLimit(Entity):
                    """
                    Limit rate at which RSVP msgs are sent to neighbors
                    
                    .. attribute:: burst
                    
                    	Number of messages sent each period from the queue, normally
                    	**type**\: int
                    
                    	**range:** 1..5000
                    
                    .. attribute:: limit
                    
                    	Max number of msgs sent each period from the queue, when behind
                    	**type**\: int
                    
                    	**range:** 1..5000
                    
                    .. attribute:: maxsize
                    
                    	Maximum queue depth
                    	**type**\: int
                    
                    	**range:** 1..5000
                    
                    .. attribute:: period
                    
                    	Every interval (msec) send burst number of messages
                    	**type**\: int
                    
                    	**range:** 10..5000
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Rsvp.Signalling.RateLimit, self).__init__()

                        self.yang_name = "rate-limit"
                        self.yang_parent_name = "signalling"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('burst', (YLeaf(YType.uint16, 'burst'), ['int'])),
                            ('limit', (YLeaf(YType.uint16, 'limit'), ['int'])),
                            ('maxsize', (YLeaf(YType.uint16, 'maxsize'), ['int'])),
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                        ])
                        self.burst = None
                        self.limit = None
                        self.maxsize = None
                        self.period = None
                        self._segment_path = lambda: "rate-limit"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/signalling/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Rsvp.Signalling.RateLimit, ['burst', 'limit', 'maxsize', 'period'], name, value)


                class Refresh(Entity):
                    """
                    Configure RSVP refresh behavior
                    
                    .. attribute:: interval
                    
                    	Refresh interval in milliseconds
                    	**type**\: int
                    
                    	**range:** 5000..4294967295
                    
                    .. attribute:: misses
                    
                    	Number of missed refreshes which trigger state timeout
                    	**type**\: int
                    
                    	**range:** 2..10
                    
                    .. attribute:: reduction
                    
                    	Configure refresh reduction
                    	**type**\:  :py:class:`Reduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Rsvp.Signalling.Refresh.Reduction>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Rsvp.Signalling.Refresh, self).__init__()

                        self.yang_name = "refresh"
                        self.yang_parent_name = "signalling"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reduction", ("reduction", Native.Ip.Rsvp.Signalling.Refresh.Reduction))])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                        ])
                        self.interval = None
                        self.misses = None

                        self.reduction = None
                        self._children_name_map["reduction"] = "reduction"
                        self._segment_path = lambda: "refresh"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/signalling/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Rsvp.Signalling.Refresh, ['interval', 'misses'], name, value)


                    class Reduction(Entity):
                        """
                        Configure refresh reduction
                        
                        .. attribute:: ack_delay
                        
                        	Time to wait to accumulate ACKs (msecs)
                        	**type**\: int
                        
                        	**range:** 100..10000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Rsvp.Signalling.Refresh.Reduction, self).__init__()

                            self.yang_name = "reduction"
                            self.yang_parent_name = "refresh"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ack_delay', (YLeaf(YType.uint16, 'ack-delay'), ['int'])),
                            ])
                            self.ack_delay = None
                            self._segment_path = lambda: "reduction"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-rsvp:rsvp/signalling/refresh/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Rsvp.Signalling.Refresh.Reduction, ['ack_delay'], name, value)


        class Http(Entity):
            """
            HTTP server configuration
            
            .. attribute:: access_class
            
            	Restrict http server access by access\-class
            	**type**\: int
            
            	**range:** 1..99
            
            .. attribute:: authentication
            
            	Set http server authentication method
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Http.Authentication>`
            
            .. attribute:: server
            
            	Enable http server
            	**type**\: bool
            
            .. attribute:: secure_server
            
            	Enable HTTP secure server
            	**type**\: bool
            
            .. attribute:: secure_trustpoint
            
            	Set http secure server certificate trustpoint
            	**type**\: str
            
            .. attribute:: timeout_policy
            
            	Set http server time\-out policy parameters
            	**type**\:  :py:class:`TimeoutPolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Http.TimeoutPolicy>`
            
            .. attribute:: client
            
            	Set http client parameters
            	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Http.Client>`
            
            .. attribute:: port
            
            	http port number
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: max_connections
            
            	max http connections
            	**type**\: int
            
            	**range:** 1..50
            
            .. attribute:: active_session_modules
            
            	Set active session modules
            	**type**\: union of the below types:
            
            		**type**\:  :py:class:`ActiveSessionModules <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Http.ActiveSessionModules>`
            
            		**type**\: str
            
            .. attribute:: secure_active_session_modules
            
            	Set secure active session modules
            	**type**\: union of the below types:
            
            		**type**\:  :py:class:`SecureActiveSessionModules <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Http.SecureActiveSessionModules>`
            
            		**type**\: str
            
            .. attribute:: secure_client_auth
            
            	Set http secure server with client authentication
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-http'
            _revision = '2018-01-24'

            def __init__(self):
                super(Native.Ip.Http, self).__init__()

                self.yang_name = "http"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Ip.Http.Authentication)), ("timeout-policy", ("timeout_policy", Native.Ip.Http.TimeoutPolicy)), ("client", ("client", Native.Ip.Http.Client))])
                self._leafs = OrderedDict([
                    ('access_class', (YLeaf(YType.uint8, 'access-class'), ['int'])),
                    ('server', (YLeaf(YType.boolean, 'server'), ['bool'])),
                    ('secure_server', (YLeaf(YType.boolean, 'secure-server'), ['bool'])),
                    ('secure_trustpoint', (YLeaf(YType.str, 'secure-trustpoint'), ['str'])),
                    ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                    ('max_connections', (YLeaf(YType.uint16, 'max-connections'), ['int'])),
                    ('active_session_modules', (YLeaf(YType.str, 'active-session-modules'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Http.ActiveSessionModules'),'str'])),
                    ('secure_active_session_modules', (YLeaf(YType.str, 'secure-active-session-modules'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Http.SecureActiveSessionModules'),'str'])),
                    ('secure_client_auth', (YLeaf(YType.empty, 'secure-client-auth'), ['Empty'])),
                ])
                self.access_class = None
                self.server = None
                self.secure_server = None
                self.secure_trustpoint = None
                self.port = None
                self.max_connections = None
                self.active_session_modules = None
                self.secure_active_session_modules = None
                self.secure_client_auth = None

                self.authentication = Native.Ip.Http.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "authentication"

                self.timeout_policy = Native.Ip.Http.TimeoutPolicy()
                self.timeout_policy.parent = self
                self._children_name_map["timeout_policy"] = "timeout-policy"

                self.client = Native.Ip.Http.Client()
                self.client.parent = self
                self._children_name_map["client"] = "client"
                self._segment_path = lambda: "Cisco-IOS-XE-http:http"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Http, ['access_class', 'server', 'secure_server', 'secure_trustpoint', 'port', 'max_connections', 'active_session_modules', 'secure_active_session_modules', 'secure_client_auth'], name, value)

            class ActiveSessionModules(Enum):
                """
                ActiveSessionModules (Enum Class)

                Set active session modules

                .. data:: none = 0

                .. data:: all = 1

                """

                none = Enum.YLeaf(0, "none")

                all = Enum.YLeaf(1, "all")


            class SecureActiveSessionModules(Enum):
                """
                SecureActiveSessionModules (Enum Class)

                Set secure active session modules

                .. data:: none = 0

                .. data:: all = 1

                """

                none = Enum.YLeaf(0, "none")

                all = Enum.YLeaf(1, "all")



            class Authentication(Entity):
                """
                Set http server authentication method
                
                .. attribute:: aaa
                
                	Use AAA access control methods
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: local
                
                	Use local username and passwords
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-http'
                _revision = '2018-01-24'

                def __init__(self):
                    super(Native.Ip.Http.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "http"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('aaa', (YLeaf(YType.empty, 'aaa'), ['Empty'])),
                        ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                    ])
                    self.aaa = None
                    self.local = None
                    self._segment_path = lambda: "authentication"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-http:http/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Http.Authentication, ['aaa', 'local'], name, value)


            class TimeoutPolicy(Entity):
                """
                Set http server time\-out policy parameters
                
                .. attribute:: idle
                
                	Idle time\-out of a http server connection in seconds
                	**type**\: int
                
                	**range:** 1..600
                
                .. attribute:: life
                
                	Life time of a http server connection in seconds
                	**type**\: int
                
                	**range:** 1..86400
                
                .. attribute:: requests
                
                	Maximum number of requests allowed on a http server connection
                	**type**\: int
                
                	**range:** 1..86400
                
                

                """

                _prefix = 'ios-http'
                _revision = '2018-01-24'

                def __init__(self):
                    super(Native.Ip.Http.TimeoutPolicy, self).__init__()

                    self.yang_name = "timeout-policy"
                    self.yang_parent_name = "http"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('idle', (YLeaf(YType.uint16, 'idle'), ['int'])),
                        ('life', (YLeaf(YType.uint32, 'life'), ['int'])),
                        ('requests', (YLeaf(YType.uint32, 'requests'), ['int'])),
                    ])
                    self.idle = None
                    self.life = None
                    self.requests = None
                    self._segment_path = lambda: "timeout-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-http:http/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Http.TimeoutPolicy, ['idle', 'life', 'requests'], name, value)


            class Client(Entity):
                """
                Set http client parameters
                
                .. attribute:: secure_trustpoint
                
                	Set http client certificate secure trustpoint
                	**type**\: str
                
                .. attribute:: source_interface
                
                	Specify interface for source address in all HTTP(S) client connections
                	**type**\: str
                
                .. attribute:: proxy_server
                
                	Specify proxy server name for HTTP file system client connections
                	**type**\:  :py:class:`ProxyServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Http.Client.ProxyServer>`
                
                

                """

                _prefix = 'ios-http'
                _revision = '2018-01-24'

                def __init__(self):
                    super(Native.Ip.Http.Client, self).__init__()

                    self.yang_name = "client"
                    self.yang_parent_name = "http"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("proxy-server", ("proxy_server", Native.Ip.Http.Client.ProxyServer))])
                    self._leafs = OrderedDict([
                        ('secure_trustpoint', (YLeaf(YType.str, 'secure-trustpoint'), ['str'])),
                        ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                    ])
                    self.secure_trustpoint = None
                    self.source_interface = None

                    self.proxy_server = Native.Ip.Http.Client.ProxyServer()
                    self.proxy_server.parent = self
                    self._children_name_map["proxy_server"] = "proxy-server"
                    self._segment_path = lambda: "client"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-http:http/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Http.Client, ['secure_trustpoint', 'source_interface'], name, value)


                class ProxyServer(Entity):
                    """
                    Specify proxy server name for HTTP file system client connections
                    
                    .. attribute:: proxy_server_name
                    
                    	Proxy server name
                    	**type**\: str
                    
                    .. attribute:: proxy_port
                    
                    	Proxy port number
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-http'
                    _revision = '2018-01-24'

                    def __init__(self):
                        super(Native.Ip.Http.Client.ProxyServer, self).__init__()

                        self.yang_name = "proxy-server"
                        self.yang_parent_name = "client"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('proxy_server_name', (YLeaf(YType.str, 'proxy-server-name'), ['str'])),
                            ('proxy_port', (YLeaf(YType.uint16, 'proxy-port'), ['int'])),
                        ])
                        self.proxy_server_name = None
                        self.proxy_port = None
                        self._segment_path = lambda: "proxy-server"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-http:http/client/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Http.Client.ProxyServer, ['proxy_server_name', 'proxy_port'], name, value)


        class Nat(Entity):
            """
            NAT configuration commands
            
            .. attribute:: pool
            
            	Define pool of addresses
            	**type**\: list of  		 :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Pool>`
            
            .. attribute:: inside
            
            	Inside address translation
            	**type**\:  :py:class:`Inside <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside>`
            
            .. attribute:: outside
            
            	Outside address translation
            	**type**\:  :py:class:`Outside <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Outside>`
            
            .. attribute:: translation
            
            	
            	**type**\:  :py:class:`Translation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation>`
            
            

            """

            _prefix = 'ios-nat'
            _revision = '2018-06-30'

            def __init__(self):
                super(Native.Ip.Nat, self).__init__()

                self.yang_name = "nat"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("pool", ("pool", Native.Ip.Nat.Pool)), ("inside", ("inside", Native.Ip.Nat.Inside)), ("outside", ("outside", Native.Ip.Nat.Outside)), ("translation", ("translation", Native.Ip.Nat.Translation))])
                self._leafs = OrderedDict()

                self.inside = Native.Ip.Nat.Inside()
                self.inside.parent = self
                self._children_name_map["inside"] = "inside"

                self.outside = Native.Ip.Nat.Outside()
                self.outside.parent = self
                self._children_name_map["outside"] = "outside"

                self.translation = Native.Ip.Nat.Translation()
                self.translation.parent = self
                self._children_name_map["translation"] = "translation"

                self.pool = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Nat, [], name, value)


            class Pool(Entity):
                """
                Define pool of addresses
                
                .. attribute:: id  (key)
                
                	
                	**type**\: str
                
                .. attribute:: start_address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: end_address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: netmask
                
                	Specify the network mask
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: prefix_length
                
                	Specify the prefix length
                	**type**\: int
                
                	**range:** 1..32
                
                .. attribute:: accounting
                
                	Specify the accounting
                	**type**\: str
                
                .. attribute:: arp_ping
                
                	WLAN ARP Ping
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: type
                
                	Specify the pool type
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Pool.Type>`
                
                .. attribute:: add_route
                
                	Add special route to Virtual Interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-nat'
                _revision = '2018-06-30'

                def __init__(self):
                    super(Native.Ip.Nat.Pool, self).__init__()

                    self.yang_name = "pool"
                    self.yang_parent_name = "nat"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                        ('start_address', (YLeaf(YType.str, 'start-address'), ['str'])),
                        ('end_address', (YLeaf(YType.str, 'end-address'), ['str'])),
                        ('netmask', (YLeaf(YType.str, 'netmask'), ['str'])),
                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                        ('accounting', (YLeaf(YType.str, 'accounting'), ['str'])),
                        ('arp_ping', (YLeaf(YType.empty, 'arp-ping'), ['Empty'])),
                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Nat.Pool.Type')])),
                        ('add_route', (YLeaf(YType.empty, 'add-route'), ['Empty'])),
                    ])
                    self.id = None
                    self.start_address = None
                    self.end_address = None
                    self.netmask = None
                    self.prefix_length = None
                    self.accounting = None
                    self.arp_ping = None
                    self.type = None
                    self.add_route = None
                    self._segment_path = lambda: "pool" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Nat.Pool, ['id', 'start_address', 'end_address', 'netmask', 'prefix_length', 'accounting', 'arp_ping', 'type', 'add_route'], name, value)

                class Type(Enum):
                    """
                    Type (Enum Class)

                    Specify the pool type

                    .. data:: match_host = 0

                    .. data:: rotary = 1

                    """

                    match_host = Enum.YLeaf(0, "match-host")

                    rotary = Enum.YLeaf(1, "rotary")



            class Inside(Entity):
                """
                Inside address translation
                
                .. attribute:: source
                
                	Source address translation
                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source>`
                
                .. attribute:: destination
                
                	Destination address translation
                	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Destination>`
                
                

                """

                _prefix = 'ios-nat'
                _revision = '2018-06-30'

                def __init__(self):
                    super(Native.Ip.Nat.Inside, self).__init__()

                    self.yang_name = "inside"
                    self.yang_parent_name = "nat"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("source", ("source", Native.Ip.Nat.Inside.Source)), ("destination", ("destination", Native.Ip.Nat.Inside.Destination))])
                    self._leafs = OrderedDict()

                    self.source = Native.Ip.Nat.Inside.Source()
                    self.source.parent = self
                    self._children_name_map["source"] = "source"

                    self.destination = Native.Ip.Nat.Inside.Destination()
                    self.destination.parent = self
                    self._children_name_map["destination"] = "destination"
                    self._segment_path = lambda: "inside"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Nat.Inside, [], name, value)


                class Source(Entity):
                    """
                    Source address translation
                    
                    .. attribute:: list
                    
                    	Specify access list describing local addresses
                    	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List>`
                    
                    .. attribute:: route_map
                    
                    	Specify route\-map
                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap>`
                    
                    .. attribute:: static
                    
                    	Specify static local\->global mapping
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Inside.Source, self).__init__()

                        self.yang_name = "source"
                        self.yang_parent_name = "inside"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("list", ("list", Native.Ip.Nat.Inside.Source.List)), ("route-map", ("route_map", Native.Ip.Nat.Inside.Source.RouteMap)), ("static", ("static", Native.Ip.Nat.Inside.Source.Static))])
                        self._leafs = OrderedDict()

                        self.static = Native.Ip.Nat.Inside.Source.Static()
                        self.static.parent = self
                        self._children_name_map["static"] = "static"

                        self.list = YList(self)
                        self.route_map = YList(self)
                        self._segment_path = lambda: "source"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/inside/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Inside.Source, [], name, value)


                    class List(Entity):
                        """
                        Specify access list describing local addresses
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..2699
                        
                        		**type**\: str
                        
                        .. attribute:: pool
                        
                        	Name pool of global addresses
                        	**type**\: list of  		 :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.Pool>`
                        
                        .. attribute:: pool_with_vrf
                        
                        	
                        	**type**\:  :py:class:`PoolWithVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.PoolWithVrf>`
                        
                        .. attribute:: interface
                        
                        	Specify interface for global address
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.Interface>`
                        
                        .. attribute:: interface_with_vrf
                        
                        	
                        	**type**\:  :py:class:`InterfaceWithVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf>`
                        
                        

                        """

                        _prefix = 'ios-nat'
                        _revision = '2018-06-30'

                        def __init__(self):
                            super(Native.Ip.Nat.Inside.Source.List, self).__init__()

                            self.yang_name = "list"
                            self.yang_parent_name = "source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("pool", ("pool", Native.Ip.Nat.Inside.Source.List.Pool)), ("pool-with-vrf", ("pool_with_vrf", Native.Ip.Nat.Inside.Source.List.PoolWithVrf)), ("interface", ("interface", Native.Ip.Nat.Inside.Source.List.Interface)), ("interface-with-vrf", ("interface_with_vrf", Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ])
                            self.id = None

                            self.pool_with_vrf = Native.Ip.Nat.Inside.Source.List.PoolWithVrf()
                            self.pool_with_vrf.parent = self
                            self._children_name_map["pool_with_vrf"] = "pool-with-vrf"

                            self.interface_with_vrf = Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf()
                            self.interface_with_vrf.parent = self
                            self._children_name_map["interface_with_vrf"] = "interface-with-vrf"

                            self.pool = YList(self)
                            self.interface = YList(self)
                            self._segment_path = lambda: "list" + "[id='" + str(self.id) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/inside/source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nat.Inside.Source.List, ['id'], name, value)


                        class Pool(Entity):
                            """
                            Name pool of global addresses
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: redundancy
                            
                            	
                            	**type**\: list of  		 :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.Pool.Redundancy>`
                            
                            .. attribute:: overload
                            
                            	Overload an address translation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: extended
                            
                            	Overload extended
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: oer
                            
                            	Use with vtemplate only. On new translation, if OER BR is UP, OER will select IP from outgoing Interface. All packets matching translation are forwarded over Interface for duration of translation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Inside.Source.List.Pool, self).__init__()

                                self.yang_name = "pool"
                                self.yang_parent_name = "list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("redundancy", ("redundancy", Native.Ip.Nat.Inside.Source.List.Pool.Redundancy))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                    ('extended', (YLeaf(YType.empty, 'extended'), ['Empty'])),
                                    ('oer', (YLeaf(YType.empty, 'oer'), ['Empty'])),
                                ])
                                self.name = None
                                self.overload = None
                                self.extended = None
                                self.oer = None

                                self.redundancy = YList(self)
                                self._segment_path = lambda: "pool" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Inside.Source.List.Pool, ['name', 'overload', 'extended', 'oer'], name, value)


                            class Redundancy(Entity):
                                """
                                
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..2
                                
                                .. attribute:: mapping_id
                                
                                	Associate a mapping id to this mapping
                                	**type**\: list of  		 :py:class:`MappingId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.Pool.Redundancy.MappingId>`
                                
                                

                                """

                                _prefix = 'ios-nat'
                                _revision = '2018-06-30'

                                def __init__(self):
                                    super(Native.Ip.Nat.Inside.Source.List.Pool.Redundancy, self).__init__()

                                    self.yang_name = "redundancy"
                                    self.yang_parent_name = "pool"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("mapping-id", ("mapping_id", Native.Ip.Nat.Inside.Source.List.Pool.Redundancy.MappingId))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.uint8, 'name'), ['int'])),
                                    ])
                                    self.name = None

                                    self.mapping_id = YList(self)
                                    self._segment_path = lambda: "redundancy" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nat.Inside.Source.List.Pool.Redundancy, ['name'], name, value)


                                class MappingId(Entity):
                                    """
                                    Associate a mapping id to this mapping
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: overload
                                    
                                    	Overload an address translation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: extended
                                    
                                    	Overload extended
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: oer
                                    
                                    	Use with vtemplate only. On new translation, if OER BR is UP, OER will select IP from outgoing Interface. All packets matching translation are forwarded over Interface for duration of translation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.List.Pool.Redundancy.MappingId, self).__init__()

                                        self.yang_name = "mapping-id"
                                        self.yang_parent_name = "redundancy"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.uint32, 'name'), ['int'])),
                                            ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                            ('extended', (YLeaf(YType.empty, 'extended'), ['Empty'])),
                                            ('oer', (YLeaf(YType.empty, 'oer'), ['Empty'])),
                                        ])
                                        self.name = None
                                        self.overload = None
                                        self.extended = None
                                        self.oer = None
                                        self._segment_path = lambda: "mapping-id" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.List.Pool.Redundancy.MappingId, ['name', 'overload', 'extended', 'oer'], name, value)


                        class PoolWithVrf(Entity):
                            """
                            
                            
                            .. attribute:: pool
                            
                            	Name pool of global addresses
                            	**type**\: list of  		 :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Inside.Source.List.PoolWithVrf, self).__init__()

                                self.yang_name = "pool-with-vrf"
                                self.yang_parent_name = "list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pool", ("pool", Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool))])
                                self._leafs = OrderedDict()

                                self.pool = YList(self)
                                self._segment_path = lambda: "pool-with-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Inside.Source.List.PoolWithVrf, [], name, value)


                            class Pool(Entity):
                                """
                                Name pool of global addresses
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: redundancy
                                
                                	
                                	**type**\: list of  		 :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy>`
                                
                                .. attribute:: vrf
                                
                                	Specify vrf
                                	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Vrf>`
                                
                                

                                """

                                _prefix = 'ios-nat'
                                _revision = '2018-06-30'

                                def __init__(self):
                                    super(Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "pool-with-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("redundancy", ("redundancy", Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy)), ("vrf", ("vrf", Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Vrf))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.redundancy = YList(self)
                                    self.vrf = YList(self)
                                    self._segment_path = lambda: "pool" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool, ['name'], name, value)


                                class Redundancy(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2
                                    
                                    .. attribute:: mapping_id
                                    
                                    	Associate a mapping id to this mapping
                                    	**type**\: list of  		 :py:class:`MappingId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy.MappingId>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy, self).__init__()

                                        self.yang_name = "redundancy"
                                        self.yang_parent_name = "pool"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("mapping-id", ("mapping_id", Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy.MappingId))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.uint8, 'name'), ['int'])),
                                        ])
                                        self.name = None

                                        self.mapping_id = YList(self)
                                        self._segment_path = lambda: "redundancy" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy, ['name'], name, value)


                                    class MappingId(Entity):
                                        """
                                        Associate a mapping id to this mapping
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: vrf
                                        
                                        	Specify vrf
                                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy.MappingId.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-nat'
                                        _revision = '2018-06-30'

                                        def __init__(self):
                                            super(Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy.MappingId, self).__init__()

                                            self.yang_name = "mapping-id"
                                            self.yang_parent_name = "redundancy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy.MappingId.Vrf))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.uint32, 'name'), ['int'])),
                                            ])
                                            self.name = None

                                            self.vrf = YList(self)
                                            self._segment_path = lambda: "mapping-id" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy.MappingId, ['name'], name, value)


                                        class Vrf(Entity):
                                            """
                                            Specify vrf
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: match_in_vrf
                                            
                                            	Match incoming vrf
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: overload
                                            
                                            	Overload an address translation
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-nat'
                                            _revision = '2018-06-30'

                                            def __init__(self):
                                                super(Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy.MappingId.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "mapping-id"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('match_in_vrf', (YLeaf(YType.empty, 'match-in-vrf'), ['Empty'])),
                                                    ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                                ])
                                                self.name = None
                                                self.match_in_vrf = None
                                                self.overload = None
                                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Redundancy.MappingId.Vrf, ['name', 'match_in_vrf', 'overload'], name, value)


                                class Vrf(Entity):
                                    """
                                    Specify vrf
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: match_in_vrf
                                    
                                    	Match incoming vrf
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: overload
                                    
                                    	Overload an address translation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "pool"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('match_in_vrf', (YLeaf(YType.empty, 'match-in-vrf'), ['Empty'])),
                                            ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                        ])
                                        self.name = None
                                        self.match_in_vrf = None
                                        self.overload = None
                                        self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.List.PoolWithVrf.Pool.Vrf, ['name', 'match_in_vrf', 'overload'], name, value)


                        class Interface(Entity):
                            """
                            Specify interface for global address
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: overload
                            
                            	Overload an address translation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: extended
                            
                            	Overload extended
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: oer
                            
                            	Use with vtemplate only.  On new translation, if OER BR is UP, OER will select IP from outgoing Interface.  All packets matching translation are forwarded over Interface for duration of translation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Inside.Source.List.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                    ('extended', (YLeaf(YType.empty, 'extended'), ['Empty'])),
                                    ('oer', (YLeaf(YType.empty, 'oer'), ['Empty'])),
                                ])
                                self.name = None
                                self.overload = None
                                self.extended = None
                                self.oer = None
                                self._segment_path = lambda: "interface" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Inside.Source.List.Interface, ['name', 'overload', 'extended', 'oer'], name, value)


                        class InterfaceWithVrf(Entity):
                            """
                            
                            
                            .. attribute:: interface
                            
                            	Specify interface for global address
                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf.Interface>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf, self).__init__()

                                self.yang_name = "interface-with-vrf"
                                self.yang_parent_name = "list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf.Interface))])
                                self._leafs = OrderedDict()

                                self.interface = YList(self)
                                self._segment_path = lambda: "interface-with-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf, [], name, value)


                            class Interface(Entity):
                                """
                                Specify interface for global address
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	Specify vrf
                                	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf.Interface.Vrf>`
                                
                                

                                """

                                _prefix = 'ios-nat'
                                _revision = '2018-06-30'

                                def __init__(self):
                                    super(Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interface-with-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf.Interface.Vrf))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.vrf = YList(self)
                                    self._segment_path = lambda: "interface" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf.Interface, ['name'], name, value)


                                class Vrf(Entity):
                                    """
                                    Specify vrf
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: overload
                                    
                                    	Overload an address translation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: extended
                                    
                                    	Overload extended
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: oer
                                    
                                    	Use with vtemplate only.  On new translation, if OER BR is UP, OER will select IP from outgoing Interface.  All packets matching translation are forwarded over Interface for duration of translation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf.Interface.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                            ('extended', (YLeaf(YType.empty, 'extended'), ['Empty'])),
                                            ('oer', (YLeaf(YType.empty, 'oer'), ['Empty'])),
                                        ])
                                        self.name = None
                                        self.overload = None
                                        self.extended = None
                                        self.oer = None
                                        self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.List.InterfaceWithVrf.Interface.Vrf, ['name', 'overload', 'extended', 'oer'], name, value)


                    class RouteMap(Entity):
                        """
                        Specify route\-map
                        
                        .. attribute:: route_map_name  (key)
                        
                        	Route\-map name
                        	**type**\: str
                        
                        .. attribute:: pool
                        
                        	Name pool of global addresses
                        	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.Pool>`
                        
                        .. attribute:: pool_with_vrf
                        
                        	
                        	**type**\:  :py:class:`PoolWithVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf>`
                        
                        .. attribute:: interface
                        
                        	Specify interface for global address
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.Interface>`
                        
                        .. attribute:: interface_with_vrf
                        
                        	
                        	**type**\:  :py:class:`InterfaceWithVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf>`
                        
                        

                        """

                        _prefix = 'ios-nat'
                        _revision = '2018-06-30'

                        def __init__(self):
                            super(Native.Ip.Nat.Inside.Source.RouteMap, self).__init__()

                            self.yang_name = "route-map"
                            self.yang_parent_name = "source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['route_map_name']
                            self._child_classes = OrderedDict([("pool", ("pool", Native.Ip.Nat.Inside.Source.RouteMap.Pool)), ("pool-with-vrf", ("pool_with_vrf", Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf)), ("interface", ("interface", Native.Ip.Nat.Inside.Source.RouteMap.Interface)), ("interface-with-vrf", ("interface_with_vrf", Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf))])
                            self._leafs = OrderedDict([
                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                            ])
                            self.route_map_name = None

                            self.pool = Native.Ip.Nat.Inside.Source.RouteMap.Pool()
                            self.pool.parent = self
                            self._children_name_map["pool"] = "pool"

                            self.pool_with_vrf = Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf()
                            self.pool_with_vrf.parent = self
                            self._children_name_map["pool_with_vrf"] = "pool-with-vrf"

                            self.interface = Native.Ip.Nat.Inside.Source.RouteMap.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"

                            self.interface_with_vrf = Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf()
                            self.interface_with_vrf.parent = self
                            self._children_name_map["interface_with_vrf"] = "interface-with-vrf"
                            self._segment_path = lambda: "route-map" + "[route-map-name='" + str(self.route_map_name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/inside/source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap, ['route_map_name'], name, value)


                        class Pool(Entity):
                            """
                            Name pool of global addresses
                            
                            .. attribute:: pool_name
                            
                            	Pool name for global addresses
                            	**type**\: str
                            
                            .. attribute:: redundancy
                            
                            	
                            	**type**\: list of  		 :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.Pool.Redundancy>`
                            
                            .. attribute:: overload
                            
                            	Overload an address translation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: extended
                            
                            	Overload extended
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: oer
                            
                            	Use with vtemplate only. On new translation, if OER BR is UP, OER will select IP from outgoing Interface. All packets matching translation are forwarded over Interface for duration of translation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: reversible
                            
                            	Allow out\->in traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Inside.Source.RouteMap.Pool, self).__init__()

                                self.yang_name = "pool"
                                self.yang_parent_name = "route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redundancy", ("redundancy", Native.Ip.Nat.Inside.Source.RouteMap.Pool.Redundancy))])
                                self._leafs = OrderedDict([
                                    ('pool_name', (YLeaf(YType.str, 'pool-name'), ['str'])),
                                    ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                    ('extended', (YLeaf(YType.empty, 'extended'), ['Empty'])),
                                    ('oer', (YLeaf(YType.empty, 'oer'), ['Empty'])),
                                    ('reversible', (YLeaf(YType.empty, 'reversible'), ['Empty'])),
                                ])
                                self.pool_name = None
                                self.overload = None
                                self.extended = None
                                self.oer = None
                                self.reversible = None

                                self.redundancy = YList(self)
                                self._segment_path = lambda: "pool"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.Pool, ['pool_name', 'overload', 'extended', 'oer', 'reversible'], name, value)


                            class Redundancy(Entity):
                                """
                                
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..2
                                
                                .. attribute:: mapping_id
                                
                                	Associate a mapping id to this mapping
                                	**type**\: list of  		 :py:class:`MappingId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.Pool.Redundancy.MappingId>`
                                
                                

                                """

                                _prefix = 'ios-nat'
                                _revision = '2018-06-30'

                                def __init__(self):
                                    super(Native.Ip.Nat.Inside.Source.RouteMap.Pool.Redundancy, self).__init__()

                                    self.yang_name = "redundancy"
                                    self.yang_parent_name = "pool"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("mapping-id", ("mapping_id", Native.Ip.Nat.Inside.Source.RouteMap.Pool.Redundancy.MappingId))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.uint8, 'name'), ['int'])),
                                    ])
                                    self.name = None

                                    self.mapping_id = YList(self)
                                    self._segment_path = lambda: "redundancy" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.Pool.Redundancy, ['name'], name, value)


                                class MappingId(Entity):
                                    """
                                    Associate a mapping id to this mapping
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: overload
                                    
                                    	Overload an address translation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: extended
                                    
                                    	Overload extended
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: oer
                                    
                                    	Use with vtemplate only. On new translation, if OER BR is UP, OER will select IP from outgoing Interface. All packets matching translation are forwarded over Interface for duration of translation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: reversible
                                    
                                    	Allow out\->in traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.RouteMap.Pool.Redundancy.MappingId, self).__init__()

                                        self.yang_name = "mapping-id"
                                        self.yang_parent_name = "redundancy"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.uint32, 'name'), ['int'])),
                                            ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                            ('extended', (YLeaf(YType.empty, 'extended'), ['Empty'])),
                                            ('oer', (YLeaf(YType.empty, 'oer'), ['Empty'])),
                                            ('reversible', (YLeaf(YType.empty, 'reversible'), ['Empty'])),
                                        ])
                                        self.name = None
                                        self.overload = None
                                        self.extended = None
                                        self.oer = None
                                        self.reversible = None
                                        self._segment_path = lambda: "mapping-id" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.Pool.Redundancy.MappingId, ['name', 'overload', 'extended', 'oer', 'reversible'], name, value)


                        class PoolWithVrf(Entity):
                            """
                            
                            
                            .. attribute:: pool
                            
                            	Specify interface for global address
                            	**type**\: list of  		 :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf, self).__init__()

                                self.yang_name = "pool-with-vrf"
                                self.yang_parent_name = "route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pool", ("pool", Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool))])
                                self._leafs = OrderedDict()

                                self.pool = YList(self)
                                self._segment_path = lambda: "pool-with-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf, [], name, value)


                            class Pool(Entity):
                                """
                                Specify interface for global address
                                
                                .. attribute:: pool_name  (key)
                                
                                	Pool name for global addresses
                                	**type**\: str
                                
                                .. attribute:: redundancy
                                
                                	
                                	**type**\: list of  		 :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy>`
                                
                                .. attribute:: vrf
                                
                                	Specify vrf
                                	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Vrf>`
                                
                                

                                """

                                _prefix = 'ios-nat'
                                _revision = '2018-06-30'

                                def __init__(self):
                                    super(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "pool-with-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['pool_name']
                                    self._child_classes = OrderedDict([("redundancy", ("redundancy", Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy)), ("vrf", ("vrf", Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Vrf))])
                                    self._leafs = OrderedDict([
                                        ('pool_name', (YLeaf(YType.str, 'pool-name'), ['str'])),
                                    ])
                                    self.pool_name = None

                                    self.redundancy = YList(self)
                                    self.vrf = YList(self)
                                    self._segment_path = lambda: "pool" + "[pool-name='" + str(self.pool_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool, ['pool_name'], name, value)


                                class Redundancy(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2
                                    
                                    .. attribute:: mapping_id
                                    
                                    	Associate a mapping id to this mapping
                                    	**type**\: list of  		 :py:class:`MappingId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy.MappingId>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy, self).__init__()

                                        self.yang_name = "redundancy"
                                        self.yang_parent_name = "pool"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("mapping-id", ("mapping_id", Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy.MappingId))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.uint8, 'name'), ['int'])),
                                        ])
                                        self.name = None

                                        self.mapping_id = YList(self)
                                        self._segment_path = lambda: "redundancy" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy, ['name'], name, value)


                                    class MappingId(Entity):
                                        """
                                        Associate a mapping id to this mapping
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: vrf
                                        
                                        	Specify vrf
                                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy.MappingId.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-nat'
                                        _revision = '2018-06-30'

                                        def __init__(self):
                                            super(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy.MappingId, self).__init__()

                                            self.yang_name = "mapping-id"
                                            self.yang_parent_name = "redundancy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy.MappingId.Vrf))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.uint32, 'name'), ['int'])),
                                            ])
                                            self.name = None

                                            self.vrf = YList(self)
                                            self._segment_path = lambda: "mapping-id" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy.MappingId, ['name'], name, value)


                                        class Vrf(Entity):
                                            """
                                            Specify vrf
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: match_in_vrf
                                            
                                            	Match incoming vrf
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: overload
                                            
                                            	Overload an address translation
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-nat'
                                            _revision = '2018-06-30'

                                            def __init__(self):
                                                super(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy.MappingId.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "mapping-id"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('match_in_vrf', (YLeaf(YType.empty, 'match-in-vrf'), ['Empty'])),
                                                    ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                                ])
                                                self.name = None
                                                self.match_in_vrf = None
                                                self.overload = None
                                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Redundancy.MappingId.Vrf, ['name', 'match_in_vrf', 'overload'], name, value)


                                class Vrf(Entity):
                                    """
                                    Specify vrf
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: match_in_vrf
                                    
                                    	Match incoming vrf
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: overload
                                    
                                    	Overload an address translation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "pool"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('match_in_vrf', (YLeaf(YType.empty, 'match-in-vrf'), ['Empty'])),
                                            ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                        ])
                                        self.name = None
                                        self.match_in_vrf = None
                                        self.overload = None
                                        self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.PoolWithVrf.Pool.Vrf, ['name', 'match_in_vrf', 'overload'], name, value)


                        class Interface(Entity):
                            """
                            Specify interface for global address
                            
                            .. attribute:: interface_name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: overload
                            
                            	Overload an address translation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: extended
                            
                            	Overload extended
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: oer
                            
                            	Use with vtemplate only.  On new translation, if OER BR is UP, OER will select IP from outgoing Interface.  All packets matching translation are forwarded over Interface for duration of translation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Inside.Source.RouteMap.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                    ('extended', (YLeaf(YType.empty, 'extended'), ['Empty'])),
                                    ('oer', (YLeaf(YType.empty, 'oer'), ['Empty'])),
                                ])
                                self.interface_name = None
                                self.overload = None
                                self.extended = None
                                self.oer = None
                                self._segment_path = lambda: "interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.Interface, ['interface_name', 'overload', 'extended', 'oer'], name, value)


                        class InterfaceWithVrf(Entity):
                            """
                            
                            
                            .. attribute:: interface
                            
                            	Specify interface for global address
                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf.Interface>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf, self).__init__()

                                self.yang_name = "interface-with-vrf"
                                self.yang_parent_name = "route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf.Interface))])
                                self._leafs = OrderedDict()

                                self.interface = YList(self)
                                self._segment_path = lambda: "interface-with-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf, [], name, value)


                            class Interface(Entity):
                                """
                                Specify interface for global address
                                
                                .. attribute:: interface_name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	Specify vrf
                                	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf.Interface.Vrf>`
                                
                                

                                """

                                _prefix = 'ios-nat'
                                _revision = '2018-06-30'

                                def __init__(self):
                                    super(Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interface-with-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface_name']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf.Interface.Vrf))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ])
                                    self.interface_name = None

                                    self.vrf = YList(self)
                                    self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf.Interface, ['interface_name'], name, value)


                                class Vrf(Entity):
                                    """
                                    Specify vrf
                                    
                                    .. attribute:: vrf_name  (key)
                                    
                                    	vrf name
                                    	**type**\: str
                                    
                                    .. attribute:: overload
                                    
                                    	Overload an address translation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: extended
                                    
                                    	Overload extended
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: oer
                                    
                                    	Use with vtemplate only.  On new translation, if OER BR is UP, OER will select IP from outgoing Interface.  All packets matching translation are forwarded over Interface for duration of translation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf.Interface.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['vrf_name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                            ('extended', (YLeaf(YType.empty, 'extended'), ['Empty'])),
                                            ('oer', (YLeaf(YType.empty, 'oer'), ['Empty'])),
                                        ])
                                        self.vrf_name = None
                                        self.overload = None
                                        self.extended = None
                                        self.oer = None
                                        self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.RouteMap.InterfaceWithVrf.Interface.Vrf, ['vrf_name', 'overload', 'extended', 'oer'], name, value)


                    class Static(Entity):
                        """
                        Specify static local\->global mapping
                        
                        .. attribute:: nat_static_transport_list
                        
                        	
                        	**type**\: list of  		 :py:class:`NatStaticTransportList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticTransportList>`
                        
                        .. attribute:: nat_static_proto_transport_interface_list
                        
                        	
                        	**type**\: list of  		 :py:class:`NatStaticProtoTransportInterfaceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList>`
                        
                        .. attribute:: nat_static_transport_interface_list
                        
                        	
                        	**type**\: list of  		 :py:class:`NatStaticTransportInterfaceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList>`
                        
                        

                        """

                        _prefix = 'ios-nat'
                        _revision = '2018-06-30'

                        def __init__(self):
                            super(Native.Ip.Nat.Inside.Source.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nat-static-transport-list", ("nat_static_transport_list", Native.Ip.Nat.Inside.Source.Static.NatStaticTransportList)), ("nat-static-proto-transport-interface-list", ("nat_static_proto_transport_interface_list", Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList)), ("nat-static-transport-interface-list", ("nat_static_transport_interface_list", Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList))])
                            self._leafs = OrderedDict()

                            self.nat_static_transport_list = YList(self)
                            self.nat_static_proto_transport_interface_list = YList(self)
                            self.nat_static_transport_interface_list = YList(self)
                            self._segment_path = lambda: "static"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/inside/source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nat.Inside.Source.Static, [], name, value)


                        class NatStaticTransportList(Entity):
                            """
                            
                            
                            .. attribute:: local_ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: global_ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: proto
                            
                            	
                            	**type**\:  :py:class:`Proto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticTransportList.Proto>`
                            
                            .. attribute:: network
                            
                            	Subnet translation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: local_port
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: global_port
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: vrf
                            
                            	Specify vrf
                            	**type**\: str
                            
                            .. attribute:: extendable
                            
                            	Extend this translation when used
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: no_alias
                            
                            	Do not create an alias for the global address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: no_payload
                            
                            	No translation of embedded address/port in the payload
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Specify route\-map
                            	**type**\: str
                            
                            .. attribute:: reversible
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redundancy
                            
                            	NAT redundancy operation
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..255
                            
                            		**type**\: str
                            
                            .. attribute:: mapping_id
                            
                            	Associate a mapping id to this mapping
                            	**type**\: int
                            
                            	**range:** 1..2147483647
                            
                            .. attribute:: match_in_vrf
                            
                            	Match incoming vrf
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: forced
                            
                            	Delete this entry and its children, even if in use
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: overload
                            
                            	Overload an address translation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportList, self).__init__()

                                self.yang_name = "nat-static-transport-list"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['local_ip','global_ip']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_ip', (YLeaf(YType.str, 'local-ip'), ['str'])),
                                    ('global_ip', (YLeaf(YType.str, 'global-ip'), ['str'])),
                                    ('proto', (YLeaf(YType.enumeration, 'proto'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Nat.Inside.Source.Static.NatStaticTransportList.Proto')])),
                                    ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                                    ('local_port', (YLeaf(YType.uint16, 'local-port'), ['int'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str','str'])),
                                    ('global_port', (YLeaf(YType.uint16, 'global-port'), ['int'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ('extendable', (YLeaf(YType.empty, 'extendable'), ['Empty'])),
                                    ('no_alias', (YLeaf(YType.empty, 'no-alias'), ['Empty'])),
                                    ('no_payload', (YLeaf(YType.empty, 'no-payload'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('reversible', (YLeaf(YType.empty, 'reversible'), ['Empty'])),
                                    ('redundancy', (YLeaf(YType.str, 'redundancy'), ['int','str'])),
                                    ('mapping_id', (YLeaf(YType.uint32, 'mapping-id'), ['int'])),
                                    ('match_in_vrf', (YLeaf(YType.empty, 'match-in-vrf'), ['Empty'])),
                                    ('forced', (YLeaf(YType.empty, 'forced'), ['Empty'])),
                                    ('overload', (YLeaf(YType.empty, 'overload'), ['Empty'])),
                                ])
                                self.local_ip = None
                                self.global_ip = None
                                self.proto = None
                                self.network = None
                                self.local_port = None
                                self.mask = None
                                self.global_port = None
                                self.vrf = None
                                self.extendable = None
                                self.no_alias = None
                                self.no_payload = None
                                self.route_map = None
                                self.reversible = None
                                self.redundancy = None
                                self.mapping_id = None
                                self.match_in_vrf = None
                                self.forced = None
                                self.overload = None
                                self._segment_path = lambda: "nat-static-transport-list" + "[local-ip='" + str(self.local_ip) + "']" + "[global-ip='" + str(self.global_ip) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/inside/source/static/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportList, ['local_ip', 'global_ip', 'proto', 'network', 'local_port', 'mask', 'global_port', 'vrf', 'extendable', 'no_alias', 'no_payload', 'route_map', 'reversible', 'redundancy', 'mapping_id', 'match_in_vrf', 'forced', 'overload'], name, value)

                            class Proto(Enum):
                                """
                                Proto (Enum Class)

                                .. data:: tcp = 0

                                .. data:: udp = 1

                                """

                                tcp = Enum.YLeaf(0, "tcp")

                                udp = Enum.YLeaf(1, "udp")



                        class NatStaticProtoTransportInterfaceList(Entity):
                            """
                            
                            
                            .. attribute:: proto  (key)
                            
                            	
                            	**type**\:  :py:class:`Proto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Proto>`
                            
                            .. attribute:: local_ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_port  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: interface
                            
                            	Specify interface for global address
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface>`
                            
                            .. attribute:: global_port
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList, self).__init__()

                                self.yang_name = "nat-static-proto-transport-interface-list"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['proto','local_ip','local_port']
                                self._child_classes = OrderedDict([("interface", ("interface", Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface))])
                                self._leafs = OrderedDict([
                                    ('proto', (YLeaf(YType.enumeration, 'proto'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Proto')])),
                                    ('local_ip', (YLeaf(YType.str, 'local-ip'), ['str'])),
                                    ('local_port', (YLeaf(YType.uint16, 'local-port'), ['int'])),
                                    ('global_port', (YLeaf(YType.uint16, 'global-port'), ['int'])),
                                ])
                                self.proto = None
                                self.local_ip = None
                                self.local_port = None
                                self.global_port = None

                                self.interface = Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._segment_path = lambda: "nat-static-proto-transport-interface-list" + "[proto='" + str(self.proto) + "']" + "[local-ip='" + str(self.local_ip) + "']" + "[local-port='" + str(self.local_port) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/inside/source/static/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList, ['proto', 'local_ip', 'local_port', 'global_port'], name, value)

                            class Proto(Enum):
                                """
                                Proto (Enum Class)

                                .. data:: tcp = 0

                                .. data:: udp = 1

                                """

                                tcp = Enum.YLeaf(0, "tcp")

                                udp = Enum.YLeaf(1, "udp")



                            class Interface(Entity):
                                """
                                Specify interface for global address
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-nat'
                                _revision = '2018-06-30'

                                def __init__(self):
                                    super(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "nat-static-proto-transport-interface-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticProtoTransportInterfaceList.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                        class NatStaticTransportInterfaceList(Entity):
                            """
                            
                            
                            .. attribute:: local_ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface
                            
                            	Specify interface for global address
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList, self).__init__()

                                self.yang_name = "nat-static-transport-interface-list"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['local_ip']
                                self._child_classes = OrderedDict([("interface", ("interface", Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface))])
                                self._leafs = OrderedDict([
                                    ('local_ip', (YLeaf(YType.str, 'local-ip'), ['str'])),
                                ])
                                self.local_ip = None

                                self.interface = Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._segment_path = lambda: "nat-static-transport-interface-list" + "[local-ip='" + str(self.local_ip) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/inside/source/static/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList, ['local_ip'], name, value)


                            class Interface(Entity):
                                """
                                Specify interface for global address
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-nat'
                                _revision = '2018-06-30'

                                def __init__(self):
                                    super(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "nat-static-transport-interface-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-nat'
                                    _revision = '2018-06-30'

                                    def __init__(self):
                                        super(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ip.Nat.Inside.Source.Static.NatStaticTransportInterfaceList.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                class Destination(Entity):
                    """
                    Destination address translation
                    
                    .. attribute:: list
                    
                    	Specify access list describing global addresses
                    	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Inside.Destination.List>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Inside.Destination, self).__init__()

                        self.yang_name = "destination"
                        self.yang_parent_name = "inside"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("list", ("list", Native.Ip.Nat.Inside.Destination.List))])
                        self._leafs = OrderedDict()

                        self.list = YList(self)
                        self._segment_path = lambda: "destination"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/inside/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Inside.Destination, [], name, value)


                    class List(Entity):
                        """
                        Specify access list describing global addresses
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..2699
                        
                        		**type**\: str
                        
                        .. attribute:: pool
                        
                        	Name pool of local addresses
                        	**type**\: str
                        
                        .. attribute:: redundancy
                        
                        	NAT redundancy operation
                        	**type**\: int
                        
                        	**range:** 1..2
                        
                        .. attribute:: mapping_id
                        
                        	Associate a mapping id to this mapping
                        	**type**\: int
                        
                        	**range:** 1..2147483647
                        
                        

                        """

                        _prefix = 'ios-nat'
                        _revision = '2018-06-30'

                        def __init__(self):
                            super(Native.Ip.Nat.Inside.Destination.List, self).__init__()

                            self.yang_name = "list"
                            self.yang_parent_name = "destination"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('pool', (YLeaf(YType.str, 'pool'), ['str'])),
                                ('redundancy', (YLeaf(YType.uint8, 'redundancy'), ['int'])),
                                ('mapping_id', (YLeaf(YType.uint32, 'mapping-id'), ['int'])),
                            ])
                            self.id = None
                            self.pool = None
                            self.redundancy = None
                            self.mapping_id = None
                            self._segment_path = lambda: "list" + "[id='" + str(self.id) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/inside/destination/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nat.Inside.Destination.List, ['id', 'pool', 'redundancy', 'mapping_id'], name, value)


            class Outside(Entity):
                """
                Outside address translation
                
                .. attribute:: source
                
                	Source address translation
                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Outside.Source>`
                
                .. attribute:: list
                
                	Specify access list describing global addresses
                	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Outside.List>`
                
                .. attribute:: route_map
                
                	Specify route\-map
                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Outside.RouteMap>`
                
                

                """

                _prefix = 'ios-nat'
                _revision = '2018-06-30'

                def __init__(self):
                    super(Native.Ip.Nat.Outside, self).__init__()

                    self.yang_name = "outside"
                    self.yang_parent_name = "nat"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("source", ("source", Native.Ip.Nat.Outside.Source)), ("list", ("list", Native.Ip.Nat.Outside.List)), ("route-map", ("route_map", Native.Ip.Nat.Outside.RouteMap))])
                    self._leafs = OrderedDict()

                    self.source = Native.Ip.Nat.Outside.Source()
                    self.source.parent = self
                    self._children_name_map["source"] = "source"

                    self.list = YList(self)
                    self.route_map = YList(self)
                    self._segment_path = lambda: "outside"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Nat.Outside, [], name, value)


                class Source(Entity):
                    """
                    Source address translation
                    
                    .. attribute:: static
                    
                    	Specify static global\->local mapping
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Outside.Source.Static>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Outside.Source, self).__init__()

                        self.yang_name = "source"
                        self.yang_parent_name = "outside"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static", ("static", Native.Ip.Nat.Outside.Source.Static))])
                        self._leafs = OrderedDict()

                        self.static = Native.Ip.Nat.Outside.Source.Static()
                        self.static.parent = self
                        self._children_name_map["static"] = "static"
                        self._segment_path = lambda: "source"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/outside/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Outside.Source, [], name, value)


                    class Static(Entity):
                        """
                        Specify static global\->local mapping
                        
                        .. attribute:: nat_static_transport_list
                        
                        	
                        	**type**\: list of  		 :py:class:`NatStaticTransportList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Outside.Source.Static.NatStaticTransportList>`
                        
                        

                        """

                        _prefix = 'ios-nat'
                        _revision = '2018-06-30'

                        def __init__(self):
                            super(Native.Ip.Nat.Outside.Source.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nat-static-transport-list", ("nat_static_transport_list", Native.Ip.Nat.Outside.Source.Static.NatStaticTransportList))])
                            self._leafs = OrderedDict()

                            self.nat_static_transport_list = YList(self)
                            self._segment_path = lambda: "static"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/outside/source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nat.Outside.Source.Static, [], name, value)


                        class NatStaticTransportList(Entity):
                            """
                            
                            
                            .. attribute:: global_ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vrf
                            
                            	Specify vrf
                            	**type**\: str
                            
                            .. attribute:: extendable
                            
                            	Extend this translation when used
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: no_payload
                            
                            	No translation of embedded address/port in the payload
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Outside.Source.Static.NatStaticTransportList, self).__init__()

                                self.yang_name = "nat-static-transport-list"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['global_ip','local_ip']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('global_ip', (YLeaf(YType.str, 'global-ip'), ['str'])),
                                    ('local_ip', (YLeaf(YType.str, 'local-ip'), ['str'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ('extendable', (YLeaf(YType.empty, 'extendable'), ['Empty'])),
                                    ('no_payload', (YLeaf(YType.empty, 'no-payload'), ['Empty'])),
                                ])
                                self.global_ip = None
                                self.local_ip = None
                                self.vrf = None
                                self.extendable = None
                                self.no_payload = None
                                self._segment_path = lambda: "nat-static-transport-list" + "[global-ip='" + str(self.global_ip) + "']" + "[local-ip='" + str(self.local_ip) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/outside/source/static/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Outside.Source.Static.NatStaticTransportList, ['global_ip', 'local_ip', 'vrf', 'extendable', 'no_payload'], name, value)


                class List(Entity):
                    """
                    Specify access list describing global addresses
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..2699
                    
                    		**type**\: str
                    
                    .. attribute:: pool
                    
                    	Name pool of local addresses
                    	**type**\: str
                    
                    .. attribute:: mapping_id
                    
                    	Associate a mapping id to this mapping
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: vrf
                    
                    	Specify vrf
                    	**type**\: str
                    
                    .. attribute:: add_route
                    
                    	Add a static route for outside local address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Outside.List, self).__init__()

                        self.yang_name = "list"
                        self.yang_parent_name = "outside"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('pool', (YLeaf(YType.str, 'pool'), ['str'])),
                            ('mapping_id', (YLeaf(YType.uint32, 'mapping-id'), ['int'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ('add_route', (YLeaf(YType.empty, 'add-route'), ['Empty'])),
                        ])
                        self.id = None
                        self.pool = None
                        self.mapping_id = None
                        self.vrf = None
                        self.add_route = None
                        self._segment_path = lambda: "list" + "[id='" + str(self.id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/outside/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Outside.List, ['id', 'pool', 'mapping_id', 'vrf', 'add_route'], name, value)


                class RouteMap(Entity):
                    """
                    Specify route\-map
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: pool
                    
                    	Name pool of local addresses
                    	**type**\: str
                    
                    .. attribute:: mapping_id
                    
                    	Associate a mapping id to this mapping
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: vrf
                    
                    	Specify vrf
                    	**type**\: str
                    
                    .. attribute:: add_route
                    
                    	Add a static route for outside local address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Outside.RouteMap, self).__init__()

                        self.yang_name = "route-map"
                        self.yang_parent_name = "outside"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('pool', (YLeaf(YType.str, 'pool'), ['str'])),
                            ('mapping_id', (YLeaf(YType.uint32, 'mapping-id'), ['int'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ('add_route', (YLeaf(YType.empty, 'add-route'), ['Empty'])),
                        ])
                        self.id = None
                        self.pool = None
                        self.mapping_id = None
                        self.vrf = None
                        self.add_route = None
                        self._segment_path = lambda: "route-map" + "[id='" + str(self.id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/outside/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Outside.RouteMap, ['id', 'pool', 'mapping_id', 'vrf', 'add_route'], name, value)


            class Translation(Entity):
                """
                
                
                .. attribute:: dns_timeout
                
                	Specify timeout for NAT DNS flows
                	**type**\:  :py:class:`DnsTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.DnsTimeout>`
                
                .. attribute:: finrst_timeout
                
                	Specify timeout for NAT TCP flows after a FIN or RST
                	**type**\:  :py:class:`FinrstTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.FinrstTimeout>`
                
                .. attribute:: icmp_timeout
                
                	Specify timeout for NAT ICMP flows
                	**type**\:  :py:class:`IcmpTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.IcmpTimeout>`
                
                .. attribute:: routemap_entry_timeout
                
                	Specify timeout for routemap created half entry
                	**type**\:  :py:class:`RoutemapEntryTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.RoutemapEntryTimeout>`
                
                .. attribute:: syn_timeout
                
                	Specify timeout for NAT TCP flows after a SYN \\ and no further data
                	**type**\:  :py:class:`SynTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.SynTimeout>`
                
                .. attribute:: tcp_timeout
                
                	Specify timeout for NAT TCP/UDP port specific flows
                	**type**\:  :py:class:`TcpTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.TcpTimeout>`
                
                .. attribute:: timeout
                
                	Specify timeout for dynamic NAT translations
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.Timeout>`
                
                .. attribute:: udp_timeout
                
                	Specify timeout for NAT UDP flows
                	**type**\:  :py:class:`UdpTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.UdpTimeout>`
                
                .. attribute:: port_timeout
                
                	Specify timeout for NAT TCP/UDP port specific flows
                	**type**\:  :py:class:`PortTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.PortTimeout>`
                
                .. attribute:: max_entries
                
                	Specify maximum number of NAT entries
                	**type**\:  :py:class:`MaxEntries <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.MaxEntries>`
                
                

                """

                _prefix = 'ios-nat'
                _revision = '2018-06-30'

                def __init__(self):
                    super(Native.Ip.Nat.Translation, self).__init__()

                    self.yang_name = "translation"
                    self.yang_parent_name = "nat"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dns-timeout", ("dns_timeout", Native.Ip.Nat.Translation.DnsTimeout)), ("finrst-timeout", ("finrst_timeout", Native.Ip.Nat.Translation.FinrstTimeout)), ("icmp-timeout", ("icmp_timeout", Native.Ip.Nat.Translation.IcmpTimeout)), ("routemap-entry-timeout", ("routemap_entry_timeout", Native.Ip.Nat.Translation.RoutemapEntryTimeout)), ("syn-timeout", ("syn_timeout", Native.Ip.Nat.Translation.SynTimeout)), ("tcp-timeout", ("tcp_timeout", Native.Ip.Nat.Translation.TcpTimeout)), ("timeout", ("timeout", Native.Ip.Nat.Translation.Timeout)), ("udp-timeout", ("udp_timeout", Native.Ip.Nat.Translation.UdpTimeout)), ("port-timeout", ("port_timeout", Native.Ip.Nat.Translation.PortTimeout)), ("max-entries", ("max_entries", Native.Ip.Nat.Translation.MaxEntries))])
                    self._leafs = OrderedDict()

                    self.dns_timeout = Native.Ip.Nat.Translation.DnsTimeout()
                    self.dns_timeout.parent = self
                    self._children_name_map["dns_timeout"] = "dns-timeout"

                    self.finrst_timeout = Native.Ip.Nat.Translation.FinrstTimeout()
                    self.finrst_timeout.parent = self
                    self._children_name_map["finrst_timeout"] = "finrst-timeout"

                    self.icmp_timeout = Native.Ip.Nat.Translation.IcmpTimeout()
                    self.icmp_timeout.parent = self
                    self._children_name_map["icmp_timeout"] = "icmp-timeout"

                    self.routemap_entry_timeout = Native.Ip.Nat.Translation.RoutemapEntryTimeout()
                    self.routemap_entry_timeout.parent = self
                    self._children_name_map["routemap_entry_timeout"] = "routemap-entry-timeout"

                    self.syn_timeout = Native.Ip.Nat.Translation.SynTimeout()
                    self.syn_timeout.parent = self
                    self._children_name_map["syn_timeout"] = "syn-timeout"

                    self.tcp_timeout = Native.Ip.Nat.Translation.TcpTimeout()
                    self.tcp_timeout.parent = self
                    self._children_name_map["tcp_timeout"] = "tcp-timeout"

                    self.timeout = Native.Ip.Nat.Translation.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"

                    self.udp_timeout = Native.Ip.Nat.Translation.UdpTimeout()
                    self.udp_timeout.parent = self
                    self._children_name_map["udp_timeout"] = "udp-timeout"

                    self.port_timeout = Native.Ip.Nat.Translation.PortTimeout()
                    self.port_timeout.parent = self
                    self._children_name_map["port_timeout"] = "port-timeout"

                    self.max_entries = Native.Ip.Nat.Translation.MaxEntries()
                    self.max_entries.parent = self
                    self._children_name_map["max_entries"] = "max-entries"
                    self._segment_path = lambda: "translation"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Nat.Translation, [], name, value)


                class DnsTimeout(Entity):
                    """
                    Specify timeout for NAT DNS flows
                    
                    .. attribute:: time_val
                    
                    	Timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..536870
                    
                    .. attribute:: never
                    
                    	Never timeout
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Translation.DnsTimeout, self).__init__()

                        self.yang_name = "dns-timeout"
                        self.yang_parent_name = "translation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('time_val', (YLeaf(YType.uint32, 'time-val'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.time_val = None
                        self.never = None
                        self._segment_path = lambda: "dns-timeout"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Translation.DnsTimeout, ['time_val', 'never'], name, value)


                class FinrstTimeout(Entity):
                    """
                    Specify timeout for NAT TCP flows after a FIN or RST
                    
                    .. attribute:: time_val
                    
                    	Timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..536870
                    
                    .. attribute:: never
                    
                    	Never timeout
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Translation.FinrstTimeout, self).__init__()

                        self.yang_name = "finrst-timeout"
                        self.yang_parent_name = "translation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('time_val', (YLeaf(YType.uint32, 'time-val'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.time_val = None
                        self.never = None
                        self._segment_path = lambda: "finrst-timeout"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Translation.FinrstTimeout, ['time_val', 'never'], name, value)


                class IcmpTimeout(Entity):
                    """
                    Specify timeout for NAT ICMP flows
                    
                    .. attribute:: time_val
                    
                    	Timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..536870
                    
                    .. attribute:: never
                    
                    	Never timeout
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Translation.IcmpTimeout, self).__init__()

                        self.yang_name = "icmp-timeout"
                        self.yang_parent_name = "translation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('time_val', (YLeaf(YType.uint32, 'time-val'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.time_val = None
                        self.never = None
                        self._segment_path = lambda: "icmp-timeout"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Translation.IcmpTimeout, ['time_val', 'never'], name, value)


                class RoutemapEntryTimeout(Entity):
                    """
                    Specify timeout for routemap created half entry
                    
                    .. attribute:: time_val
                    
                    	Timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..536870
                    
                    .. attribute:: never
                    
                    	Never timeout
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Translation.RoutemapEntryTimeout, self).__init__()

                        self.yang_name = "routemap-entry-timeout"
                        self.yang_parent_name = "translation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('time_val', (YLeaf(YType.uint32, 'time-val'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.time_val = None
                        self.never = None
                        self._segment_path = lambda: "routemap-entry-timeout"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Translation.RoutemapEntryTimeout, ['time_val', 'never'], name, value)


                class SynTimeout(Entity):
                    """
                    Specify timeout for NAT TCP flows after a SYN \\
                    and no further data
                    
                    .. attribute:: time_val
                    
                    	Timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..536870
                    
                    .. attribute:: never
                    
                    	Never timeout
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Translation.SynTimeout, self).__init__()

                        self.yang_name = "syn-timeout"
                        self.yang_parent_name = "translation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('time_val', (YLeaf(YType.uint32, 'time-val'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.time_val = None
                        self.never = None
                        self._segment_path = lambda: "syn-timeout"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Translation.SynTimeout, ['time_val', 'never'], name, value)


                class TcpTimeout(Entity):
                    """
                    Specify timeout for NAT TCP/UDP port specific flows
                    
                    .. attribute:: time_val
                    
                    	Timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..536870
                    
                    .. attribute:: never
                    
                    	Never timeout
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Translation.TcpTimeout, self).__init__()

                        self.yang_name = "tcp-timeout"
                        self.yang_parent_name = "translation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('time_val', (YLeaf(YType.uint32, 'time-val'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.time_val = None
                        self.never = None
                        self._segment_path = lambda: "tcp-timeout"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Translation.TcpTimeout, ['time_val', 'never'], name, value)


                class Timeout(Entity):
                    """
                    Specify timeout for dynamic NAT translations
                    
                    .. attribute:: time_val
                    
                    	Timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..536870
                    
                    .. attribute:: never
                    
                    	Never timeout
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Translation.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "translation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('time_val', (YLeaf(YType.uint32, 'time-val'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.time_val = None
                        self.never = None
                        self._segment_path = lambda: "timeout"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Translation.Timeout, ['time_val', 'never'], name, value)


                class UdpTimeout(Entity):
                    """
                    Specify timeout for NAT UDP flows
                    
                    .. attribute:: time_val
                    
                    	Timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..536870
                    
                    .. attribute:: never
                    
                    	Never timeout
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Translation.UdpTimeout, self).__init__()

                        self.yang_name = "udp-timeout"
                        self.yang_parent_name = "translation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('time_val', (YLeaf(YType.uint32, 'time-val'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.time_val = None
                        self.never = None
                        self._segment_path = lambda: "udp-timeout"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Translation.UdpTimeout, ['time_val', 'never'], name, value)


                class PortTimeout(Entity):
                    """
                    Specify timeout for NAT TCP/UDP port specific flows
                    
                    .. attribute:: tcp
                    
                    	TCP protocol
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.PortTimeout.Tcp>`
                    
                    .. attribute:: udp
                    
                    	UDP protocol
                    	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.PortTimeout.Udp>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Translation.PortTimeout, self).__init__()

                        self.yang_name = "port-timeout"
                        self.yang_parent_name = "translation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tcp", ("tcp", Native.Ip.Nat.Translation.PortTimeout.Tcp)), ("udp", ("udp", Native.Ip.Nat.Translation.PortTimeout.Udp))])
                        self._leafs = OrderedDict()

                        self.tcp = Native.Ip.Nat.Translation.PortTimeout.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"

                        self.udp = Native.Ip.Nat.Translation.PortTimeout.Udp()
                        self.udp.parent = self
                        self._children_name_map["udp"] = "udp"
                        self._segment_path = lambda: "port-timeout"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Translation.PortTimeout, [], name, value)


                    class Tcp(Entity):
                        """
                        TCP protocol
                        
                        .. attribute:: protocol
                        
                        	
                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.PortTimeout.Tcp.Protocol>`
                        
                        

                        """

                        _prefix = 'ios-nat'
                        _revision = '2018-06-30'

                        def __init__(self):
                            super(Native.Ip.Nat.Translation.PortTimeout.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "port-timeout"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol", ("protocol", Native.Ip.Nat.Translation.PortTimeout.Tcp.Protocol))])
                            self._leafs = OrderedDict()

                            self.protocol = Native.Ip.Nat.Translation.PortTimeout.Tcp.Protocol()
                            self.protocol.parent = self
                            self._children_name_map["protocol"] = "protocol"
                            self._segment_path = lambda: "tcp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/port-timeout/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nat.Translation.PortTimeout.Tcp, [], name, value)


                        class Protocol(Entity):
                            """
                            
                            
                            .. attribute:: port_numer
                            
                            	Port number
                            	**type**\: int
                            
                            	**range:** 1..63535
                            
                            .. attribute:: time_val
                            
                            	Timeout in seconds
                            	**type**\: int
                            
                            	**range:** 0..536870
                            
                            .. attribute:: never
                            
                            	Never timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Translation.PortTimeout.Tcp.Protocol, self).__init__()

                                self.yang_name = "protocol"
                                self.yang_parent_name = "tcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_numer', (YLeaf(YType.uint16, 'port-numer'), ['int'])),
                                    ('time_val', (YLeaf(YType.uint32, 'time-val'), ['int'])),
                                    ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                                ])
                                self.port_numer = None
                                self.time_val = None
                                self.never = None
                                self._segment_path = lambda: "protocol"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/port-timeout/tcp/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Translation.PortTimeout.Tcp.Protocol, ['port_numer', 'time_val', 'never'], name, value)


                    class Udp(Entity):
                        """
                        UDP protocol
                        
                        .. attribute:: protocol
                        
                        	
                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.PortTimeout.Udp.Protocol>`
                        
                        

                        """

                        _prefix = 'ios-nat'
                        _revision = '2018-06-30'

                        def __init__(self):
                            super(Native.Ip.Nat.Translation.PortTimeout.Udp, self).__init__()

                            self.yang_name = "udp"
                            self.yang_parent_name = "port-timeout"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol", ("protocol", Native.Ip.Nat.Translation.PortTimeout.Udp.Protocol))])
                            self._leafs = OrderedDict()

                            self.protocol = Native.Ip.Nat.Translation.PortTimeout.Udp.Protocol()
                            self.protocol.parent = self
                            self._children_name_map["protocol"] = "protocol"
                            self._segment_path = lambda: "udp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/port-timeout/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nat.Translation.PortTimeout.Udp, [], name, value)


                        class Protocol(Entity):
                            """
                            
                            
                            .. attribute:: port_numer
                            
                            	Port number
                            	**type**\: int
                            
                            	**range:** 1..63535
                            
                            .. attribute:: time_val
                            
                            	Timeout in seconds
                            	**type**\: int
                            
                            	**range:** 0..536870
                            
                            .. attribute:: never
                            
                            	Never timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nat'
                            _revision = '2018-06-30'

                            def __init__(self):
                                super(Native.Ip.Nat.Translation.PortTimeout.Udp.Protocol, self).__init__()

                                self.yang_name = "protocol"
                                self.yang_parent_name = "udp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_numer', (YLeaf(YType.uint16, 'port-numer'), ['int'])),
                                    ('time_val', (YLeaf(YType.uint32, 'time-val'), ['int'])),
                                    ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                                ])
                                self.port_numer = None
                                self.time_val = None
                                self.never = None
                                self._segment_path = lambda: "protocol"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/port-timeout/udp/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Nat.Translation.PortTimeout.Udp.Protocol, ['port_numer', 'time_val', 'never'], name, value)


                class MaxEntries(Entity):
                    """
                    Specify maximum number of NAT entries
                    
                    .. attribute:: host
                    
                    	Specify per\-host NAT entry limit
                    	**type**\: list of  		 :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Nat.Translation.MaxEntries.Host>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Ip.Nat.Translation.MaxEntries, self).__init__()

                        self.yang_name = "max-entries"
                        self.yang_parent_name = "translation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("host", ("host", Native.Ip.Nat.Translation.MaxEntries.Host))])
                        self._leafs = OrderedDict()

                        self.host = YList(self)
                        self._segment_path = lambda: "max-entries"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Nat.Translation.MaxEntries, [], name, value)


                    class Host(Entity):
                        """
                        Specify per\-host NAT entry limit
                        
                        .. attribute:: host_ip  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: number_of_entries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..2147483647
                        
                        

                        """

                        _prefix = 'ios-nat'
                        _revision = '2018-06-30'

                        def __init__(self):
                            super(Native.Ip.Nat.Translation.MaxEntries.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "max-entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['host_ip']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host_ip', (YLeaf(YType.str, 'host-ip'), ['str'])),
                                ('number_of_entries', (YLeaf(YType.uint32, 'number-of-entries'), ['int'])),
                            ])
                            self.host_ip = None
                            self.number_of_entries = None
                            self._segment_path = lambda: "host" + "[host-ip='" + str(self.host_ip) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-nat:nat/translation/max-entries/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Nat.Translation.MaxEntries.Host, ['host_ip', 'number_of_entries'], name, value)


        class Icmp(Entity):
            """
            ICMP options
            
            .. attribute:: rate_limit
            
            	rate limit ICMP messages generated
            	**type**\:  :py:class:`RateLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Icmp.RateLimit>`
            
            

            """

            _prefix = 'ios-icmp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Ip.Icmp, self).__init__()

                self.yang_name = "icmp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("rate-limit", ("rate_limit", Native.Ip.Icmp.RateLimit))])
                self._leafs = OrderedDict()

                self.rate_limit = Native.Ip.Icmp.RateLimit()
                self.rate_limit.parent = self
                self._children_name_map["rate_limit"] = "rate-limit"
                self._segment_path = lambda: "Cisco-IOS-XE-icmp:icmp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Icmp, [], name, value)


            class RateLimit(Entity):
                """
                rate limit ICMP messages generated
                
                .. attribute:: unreachable
                
                	ICMP type 3, Destination Unreachable
                	**type**\:  :py:class:`Unreachable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Icmp.RateLimit.Unreachable>`
                
                .. attribute:: redirect
                
                	description
                	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Icmp.RateLimit.Redirect>`
                
                

                """

                _prefix = 'ios-icmp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ip.Icmp.RateLimit, self).__init__()

                    self.yang_name = "rate-limit"
                    self.yang_parent_name = "icmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("unreachable", ("unreachable", Native.Ip.Icmp.RateLimit.Unreachable))])
                    self._leafs = OrderedDict([
                        ('redirect', (YLeaf(YType.enumeration, 'redirect'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Icmp.RateLimit.Redirect')])),
                    ])
                    self.redirect = None

                    self.unreachable = Native.Ip.Icmp.RateLimit.Unreachable()
                    self.unreachable.parent = self
                    self._children_name_map["unreachable"] = "unreachable"
                    self._segment_path = lambda: "rate-limit"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-icmp:icmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Icmp.RateLimit, ['redirect'], name, value)

                class Redirect(Enum):
                    """
                    Redirect (Enum Class)

                    description

                    .. data:: host = 0

                    .. data:: subnet = 1

                    """

                    host = Enum.YLeaf(0, "host")

                    subnet = Enum.YLeaf(1, "subnet")



                class Unreachable(Entity):
                    """
                    ICMP type 3, Destination Unreachable
                    
                    .. attribute:: time
                    
                    	Once per milliseconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: df
                    
                    	code 4, fragmentation needed and DF set
                    	**type**\:  :py:class:`DF <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Icmp.RateLimit.Unreachable.DF>`
                    
                    .. attribute:: log
                    
                    	log message if rate limiting is excessive
                    	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Icmp.RateLimit.Unreachable.Log>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-icmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Icmp.RateLimit.Unreachable, self).__init__()

                        self.yang_name = "unreachable"
                        self.yang_parent_name = "rate-limit"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("DF", ("df", Native.Ip.Icmp.RateLimit.Unreachable.DF)), ("log", ("log", Native.Ip.Icmp.RateLimit.Unreachable.Log))])
                        self._leafs = OrderedDict([
                            ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                        ])
                        self.time = None

                        self.df = Native.Ip.Icmp.RateLimit.Unreachable.DF()
                        self.df.parent = self
                        self._children_name_map["df"] = "DF"

                        self.log = None
                        self._children_name_map["log"] = "log"
                        self._segment_path = lambda: "unreachable"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-icmp:icmp/rate-limit/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Icmp.RateLimit.Unreachable, ['time'], name, value)


                    class DF(Entity):
                        """
                        code 4, fragmentation needed and DF set
                        
                        .. attribute:: time
                        
                        	Once per milliseconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-icmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Icmp.RateLimit.Unreachable.DF, self).__init__()

                            self.yang_name = "DF"
                            self.yang_parent_name = "unreachable"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                            ])
                            self.time = None
                            self._segment_path = lambda: "DF"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-icmp:icmp/rate-limit/unreachable/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Icmp.RateLimit.Unreachable.DF, ['time'], name, value)


                    class Log(Entity):
                        """
                        log message if rate limiting is excessive
                        
                        .. attribute:: number_unreachables
                        
                        	number of unreachables within interval to trigger a message
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: log_message
                        
                        	log message once per milliseconds
                        	**type**\: int
                        
                        	**range:** 10000..4294967295
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-icmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Icmp.RateLimit.Unreachable.Log, self).__init__()

                            self.yang_name = "log"
                            self.yang_parent_name = "unreachable"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('number_unreachables', (YLeaf(YType.uint32, 'number-unreachables'), ['int'])),
                                ('log_message', (YLeaf(YType.uint32, 'log-message'), ['int'])),
                            ])
                            self.number_unreachables = None
                            self.log_message = None
                            self._segment_path = lambda: "log"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-icmp:icmp/rate-limit/unreachable/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Icmp.RateLimit.Unreachable.Log, ['number_unreachables', 'log_message'], name, value)


        class CommunityList(Entity):
            """
            Add a community list entry
            
            .. attribute:: number_standard
            
            	
            	**type**\: list of  		 :py:class:`NumberStandard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.NumberStandard>`
            
            .. attribute:: number_expanded
            
            	
            	**type**\: list of  		 :py:class:`NumberExpanded <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.NumberExpanded>`
            
            .. attribute:: expanded
            
            	Add an expanded community\-list entry
            	**type**\: list of  		 :py:class:`Expanded <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.Expanded>`
            
            .. attribute:: standard
            
            	Add a standard community\-list entry
            	**type**\: list of  		 :py:class:`Standard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.Standard>`
            
            

            """

            _prefix = 'ios-bgp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ip.CommunityList, self).__init__()

                self.yang_name = "community-list"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("number-standard", ("number_standard", Native.Ip.CommunityList.NumberStandard)), ("number-expanded", ("number_expanded", Native.Ip.CommunityList.NumberExpanded)), ("expanded", ("expanded", Native.Ip.CommunityList.Expanded)), ("standard", ("standard", Native.Ip.CommunityList.Standard))])
                self._leafs = OrderedDict()

                self.number_standard = YList(self)
                self.number_expanded = YList(self)
                self.expanded = YList(self)
                self.standard = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-bgp:community-list"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.CommunityList, [], name, value)


            class NumberStandard(Entity):
                """
                
                
                .. attribute:: no  (key)
                
                	
                	**type**\: int
                
                	**range:** 1..99
                
                .. attribute:: deny
                
                	Specify community to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.NumberStandard.Deny>`
                
                .. attribute:: permit
                
                	Specify community to accept
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.NumberStandard.Permit>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.CommunityList.NumberStandard, self).__init__()

                    self.yang_name = "number-standard"
                    self.yang_parent_name = "community-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['no']
                    self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.CommunityList.NumberStandard.Deny)), ("permit", ("permit", Native.Ip.CommunityList.NumberStandard.Permit))])
                    self._leafs = OrderedDict([
                        ('no', (YLeaf(YType.uint16, 'no'), ['int'])),
                    ])
                    self.no = None

                    self.deny = Native.Ip.CommunityList.NumberStandard.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.permit = Native.Ip.CommunityList.NumberStandard.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._segment_path = lambda: "number-standard" + "[no='" + str(self.no) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-bgp:community-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.CommunityList.NumberStandard, ['no'], name, value)


                class Deny(Entity):
                    """
                    Specify community to reject
                    
                    .. attribute:: deny_list
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: list of str
                    
                    			**pattern:** (\\d+\:\\d+)
                    
                    		**type**\: list of   :py:class:`CommunityWellKnownType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CommunityWellKnownType>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.CommunityList.NumberStandard.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "number-standard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('deny_list', (YLeafList(YType.str, 'deny-list'), ['int','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CommunityWellKnownType', '')])),
                        ])
                        self.deny_list = []
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.CommunityList.NumberStandard.Deny, ['deny_list'], name, value)


                class Permit(Entity):
                    """
                    Specify community to accept
                    
                    .. attribute:: permit_list
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: list of str
                    
                    			**pattern:** (\\d+\:\\d+)
                    
                    		**type**\: list of   :py:class:`CommunityWellKnownType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CommunityWellKnownType>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.CommunityList.NumberStandard.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "number-standard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('permit_list', (YLeafList(YType.str, 'permit-list'), ['int','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CommunityWellKnownType', '')])),
                        ])
                        self.permit_list = []
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.CommunityList.NumberStandard.Permit, ['permit_list'], name, value)


            class NumberExpanded(Entity):
                """
                
                
                .. attribute:: no  (key)
                
                	
                	**type**\: int
                
                	**range:** 100..500
                
                .. attribute:: deny
                
                	Specify community to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.NumberExpanded.Deny>`
                
                .. attribute:: permit
                
                	Specify community to accept
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.NumberExpanded.Permit>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.CommunityList.NumberExpanded, self).__init__()

                    self.yang_name = "number-expanded"
                    self.yang_parent_name = "community-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['no']
                    self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.CommunityList.NumberExpanded.Deny)), ("permit", ("permit", Native.Ip.CommunityList.NumberExpanded.Permit))])
                    self._leafs = OrderedDict([
                        ('no', (YLeaf(YType.uint16, 'no'), ['int'])),
                    ])
                    self.no = None

                    self.deny = Native.Ip.CommunityList.NumberExpanded.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.permit = Native.Ip.CommunityList.NumberExpanded.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._segment_path = lambda: "number-expanded" + "[no='" + str(self.no) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-bgp:community-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.CommunityList.NumberExpanded, ['no'], name, value)


                class Deny(Entity):
                    """
                    Specify community to reject
                    
                    .. attribute:: deny_list
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.CommunityList.NumberExpanded.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "number-expanded"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('deny_list', (YLeafList(YType.str, 'deny-list'), ['str'])),
                        ])
                        self.deny_list = []
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.CommunityList.NumberExpanded.Deny, ['deny_list'], name, value)


                class Permit(Entity):
                    """
                    Specify community to accept
                    
                    .. attribute:: permit_list
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.CommunityList.NumberExpanded.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "number-expanded"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('permit_list', (YLeafList(YType.str, 'permit-list'), ['str'])),
                        ])
                        self.permit_list = []
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.CommunityList.NumberExpanded.Permit, ['permit_list'], name, value)


            class Expanded(Entity):
                """
                Add an expanded community\-list entry
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: deny
                
                	Specify community to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.Expanded.Deny>`
                
                .. attribute:: permit
                
                	Specify community to accept
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.Expanded.Permit>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.CommunityList.Expanded, self).__init__()

                    self.yang_name = "expanded"
                    self.yang_parent_name = "community-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.CommunityList.Expanded.Deny)), ("permit", ("permit", Native.Ip.CommunityList.Expanded.Permit))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.deny = Native.Ip.CommunityList.Expanded.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.permit = Native.Ip.CommunityList.Expanded.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._segment_path = lambda: "expanded" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-bgp:community-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.CommunityList.Expanded, ['name'], name, value)


                class Deny(Entity):
                    """
                    Specify community to reject
                    
                    .. attribute:: deny_list
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.CommunityList.Expanded.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "expanded"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('deny_list', (YLeafList(YType.str, 'deny-list'), ['str'])),
                        ])
                        self.deny_list = []
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.CommunityList.Expanded.Deny, ['deny_list'], name, value)


                class Permit(Entity):
                    """
                    Specify community to accept
                    
                    .. attribute:: permit_list
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.CommunityList.Expanded.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "expanded"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('permit_list', (YLeafList(YType.str, 'permit-list'), ['str'])),
                        ])
                        self.permit_list = []
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.CommunityList.Expanded.Permit, ['permit_list'], name, value)


            class Standard(Entity):
                """
                Add a standard community\-list entry
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: deny
                
                	Specify community to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.Standard.Deny>`
                
                .. attribute:: permit
                
                	Specify community to accept
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.CommunityList.Standard.Permit>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.CommunityList.Standard, self).__init__()

                    self.yang_name = "standard"
                    self.yang_parent_name = "community-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.CommunityList.Standard.Deny)), ("permit", ("permit", Native.Ip.CommunityList.Standard.Permit))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.deny = Native.Ip.CommunityList.Standard.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.permit = Native.Ip.CommunityList.Standard.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._segment_path = lambda: "standard" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-bgp:community-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.CommunityList.Standard, ['name'], name, value)


                class Deny(Entity):
                    """
                    Specify community to reject
                    
                    .. attribute:: deny_list
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: list of str
                    
                    			**pattern:** (\\d+\:\\d+)
                    
                    		**type**\: list of   :py:class:`CommunityWellKnownType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CommunityWellKnownType>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.CommunityList.Standard.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "standard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('deny_list', (YLeafList(YType.str, 'deny-list'), ['int','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CommunityWellKnownType', '')])),
                        ])
                        self.deny_list = []
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.CommunityList.Standard.Deny, ['deny_list'], name, value)


                class Permit(Entity):
                    """
                    Specify community to accept
                    
                    .. attribute:: permit_list
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: list of str
                    
                    			**pattern:** (\\d+\:\\d+)
                    
                    		**type**\: list of   :py:class:`CommunityWellKnownType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CommunityWellKnownType>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.CommunityList.Standard.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "standard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('permit_list', (YLeafList(YType.str, 'permit-list'), ['int','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CommunityWellKnownType', '')])),
                        ])
                        self.permit_list = []
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.CommunityList.Standard.Permit, ['permit_list'], name, value)


        class ExtcommunityList(Entity):
            """
            Extended a community list entry
            
            .. attribute:: number_standard
            
            	
            	**type**\: list of  		 :py:class:`NumberStandard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberStandard>`
            
            .. attribute:: number_expanded
            
            	
            	**type**\: list of  		 :py:class:`NumberExpanded <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberExpanded>`
            
            .. attribute:: expanded
            
            	Extended an expanded community\-list entry
            	**type**\: list of  		 :py:class:`Expanded <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Expanded>`
            
            .. attribute:: standard
            
            	Extended a standard community\-list entry
            	**type**\: list of  		 :py:class:`Standard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Standard>`
            
            

            """

            _prefix = 'ios-bgp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ip.ExtcommunityList, self).__init__()

                self.yang_name = "extcommunity-list"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("number-standard", ("number_standard", Native.Ip.ExtcommunityList.NumberStandard)), ("number-expanded", ("number_expanded", Native.Ip.ExtcommunityList.NumberExpanded)), ("expanded", ("expanded", Native.Ip.ExtcommunityList.Expanded)), ("standard", ("standard", Native.Ip.ExtcommunityList.Standard))])
                self._leafs = OrderedDict()

                self.number_standard = YList(self)
                self.number_expanded = YList(self)
                self.expanded = YList(self)
                self.standard = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-bgp:extcommunity-list"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.ExtcommunityList, [], name, value)


            class NumberStandard(Entity):
                """
                
                
                .. attribute:: no  (key)
                
                	
                	**type**\: int
                
                	**range:** 1..99
                
                .. attribute:: deny
                
                	Specify community to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberStandard.Deny>`
                
                .. attribute:: permit
                
                	Specify community to accept
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberStandard.Permit>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.ExtcommunityList.NumberStandard, self).__init__()

                    self.yang_name = "number-standard"
                    self.yang_parent_name = "extcommunity-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['no']
                    self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.ExtcommunityList.NumberStandard.Deny)), ("permit", ("permit", Native.Ip.ExtcommunityList.NumberStandard.Permit))])
                    self._leafs = OrderedDict([
                        ('no', (YLeaf(YType.uint16, 'no'), ['int'])),
                    ])
                    self.no = None

                    self.deny = Native.Ip.ExtcommunityList.NumberStandard.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.permit = Native.Ip.ExtcommunityList.NumberStandard.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._segment_path = lambda: "number-standard" + "[no='" + str(self.no) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-bgp:extcommunity-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.ExtcommunityList.NumberStandard, ['no'], name, value)


                class Deny(Entity):
                    """
                    Specify community to reject
                    
                    .. attribute:: rt
                    
                    	Route Target extended community
                    	**type**\: list of  		 :py:class:`Rt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberStandard.Deny.Rt>`
                    
                    .. attribute:: soo
                    
                    	Site\-of\-Origin extended community
                    	**type**\: list of  		 :py:class:`Soo <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberStandard.Deny.Soo>`
                    
                    .. attribute:: vpn_distinguisher
                    
                    	VPN Distinguisher extcomm
                    	**type**\: list of  		 :py:class:`VpnDistinguisher <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberStandard.Deny.VpnDistinguisher>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.ExtcommunityList.NumberStandard.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "number-standard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rt", ("rt", Native.Ip.ExtcommunityList.NumberStandard.Deny.Rt)), ("soo", ("soo", Native.Ip.ExtcommunityList.NumberStandard.Deny.Soo)), ("vpn-distinguisher", ("vpn_distinguisher", Native.Ip.ExtcommunityList.NumberStandard.Deny.VpnDistinguisher))])
                        self._leafs = OrderedDict()

                        self.rt = YList(self)
                        self.soo = YList(self)
                        self.vpn_distinguisher = YList(self)
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.ExtcommunityList.NumberStandard.Deny, [], name, value)


                    class Rt(Entity):
                        """
                        Route Target extended community
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.NumberStandard.Deny.Rt, self).__init__()

                            self.yang_name = "rt"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "rt" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.NumberStandard.Deny.Rt, ['name'], name, value)


                    class Soo(Entity):
                        """
                        Site\-of\-Origin extended community
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.NumberStandard.Deny.Soo, self).__init__()

                            self.yang_name = "soo"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "soo" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.NumberStandard.Deny.Soo, ['name'], name, value)


                    class VpnDistinguisher(Entity):
                        """
                        VPN Distinguisher extcomm
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.NumberStandard.Deny.VpnDistinguisher, self).__init__()

                            self.yang_name = "vpn-distinguisher"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "vpn-distinguisher" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.NumberStandard.Deny.VpnDistinguisher, ['name'], name, value)


                class Permit(Entity):
                    """
                    Specify community to accept
                    
                    .. attribute:: rt
                    
                    	Route Target extended community
                    	**type**\: list of  		 :py:class:`Rt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberStandard.Permit.Rt>`
                    
                    .. attribute:: soo
                    
                    	Site\-of\-Origin extended community
                    	**type**\: list of  		 :py:class:`Soo <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberStandard.Permit.Soo>`
                    
                    .. attribute:: vpn_distinguisher
                    
                    	VPN Distinguisher extcomm
                    	**type**\: list of  		 :py:class:`VpnDistinguisher <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberStandard.Permit.VpnDistinguisher>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.ExtcommunityList.NumberStandard.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "number-standard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rt", ("rt", Native.Ip.ExtcommunityList.NumberStandard.Permit.Rt)), ("soo", ("soo", Native.Ip.ExtcommunityList.NumberStandard.Permit.Soo)), ("vpn-distinguisher", ("vpn_distinguisher", Native.Ip.ExtcommunityList.NumberStandard.Permit.VpnDistinguisher))])
                        self._leafs = OrderedDict()

                        self.rt = YList(self)
                        self.soo = YList(self)
                        self.vpn_distinguisher = YList(self)
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.ExtcommunityList.NumberStandard.Permit, [], name, value)


                    class Rt(Entity):
                        """
                        Route Target extended community
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.NumberStandard.Permit.Rt, self).__init__()

                            self.yang_name = "rt"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "rt" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.NumberStandard.Permit.Rt, ['name'], name, value)


                    class Soo(Entity):
                        """
                        Site\-of\-Origin extended community
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.NumberStandard.Permit.Soo, self).__init__()

                            self.yang_name = "soo"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "soo" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.NumberStandard.Permit.Soo, ['name'], name, value)


                    class VpnDistinguisher(Entity):
                        """
                        VPN Distinguisher extcomm
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.NumberStandard.Permit.VpnDistinguisher, self).__init__()

                            self.yang_name = "vpn-distinguisher"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "vpn-distinguisher" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.NumberStandard.Permit.VpnDistinguisher, ['name'], name, value)


            class NumberExpanded(Entity):
                """
                
                
                .. attribute:: no  (key)
                
                	
                	**type**\: int
                
                	**range:** 100..500
                
                .. attribute:: deny
                
                	Specify community to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberExpanded.Deny>`
                
                .. attribute:: permit
                
                	Specify community to accept
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.NumberExpanded.Permit>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.ExtcommunityList.NumberExpanded, self).__init__()

                    self.yang_name = "number-expanded"
                    self.yang_parent_name = "extcommunity-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['no']
                    self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.ExtcommunityList.NumberExpanded.Deny)), ("permit", ("permit", Native.Ip.ExtcommunityList.NumberExpanded.Permit))])
                    self._leafs = OrderedDict([
                        ('no', (YLeaf(YType.uint16, 'no'), ['int'])),
                    ])
                    self.no = None

                    self.deny = Native.Ip.ExtcommunityList.NumberExpanded.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.permit = Native.Ip.ExtcommunityList.NumberExpanded.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._segment_path = lambda: "number-expanded" + "[no='" + str(self.no) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-bgp:extcommunity-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.ExtcommunityList.NumberExpanded, ['no'], name, value)


                class Deny(Entity):
                    """
                    Specify community to reject
                    
                    .. attribute:: deny_list
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.ExtcommunityList.NumberExpanded.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "number-expanded"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('deny_list', (YLeafList(YType.str, 'deny-list'), ['str'])),
                        ])
                        self.deny_list = []
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.ExtcommunityList.NumberExpanded.Deny, ['deny_list'], name, value)


                class Permit(Entity):
                    """
                    Specify community to accept
                    
                    .. attribute:: permit_list
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.ExtcommunityList.NumberExpanded.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "number-expanded"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('permit_list', (YLeafList(YType.str, 'permit-list'), ['str'])),
                        ])
                        self.permit_list = []
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.ExtcommunityList.NumberExpanded.Permit, ['permit_list'], name, value)


            class Expanded(Entity):
                """
                Extended an expanded community\-list entry
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: deny
                
                	Specify community to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Expanded.Deny>`
                
                .. attribute:: permit
                
                	Specify community to accept
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Expanded.Permit>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.ExtcommunityList.Expanded, self).__init__()

                    self.yang_name = "expanded"
                    self.yang_parent_name = "extcommunity-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.ExtcommunityList.Expanded.Deny)), ("permit", ("permit", Native.Ip.ExtcommunityList.Expanded.Permit))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.deny = Native.Ip.ExtcommunityList.Expanded.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.permit = Native.Ip.ExtcommunityList.Expanded.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._segment_path = lambda: "expanded" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-bgp:extcommunity-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.ExtcommunityList.Expanded, ['name'], name, value)


                class Deny(Entity):
                    """
                    Specify community to reject
                    
                    .. attribute:: deny_list
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.ExtcommunityList.Expanded.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "expanded"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('deny_list', (YLeafList(YType.str, 'deny-list'), ['str'])),
                        ])
                        self.deny_list = []
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.ExtcommunityList.Expanded.Deny, ['deny_list'], name, value)


                class Permit(Entity):
                    """
                    Specify community to accept
                    
                    .. attribute:: permit_list
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.ExtcommunityList.Expanded.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "expanded"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('permit_list', (YLeafList(YType.str, 'permit-list'), ['str'])),
                        ])
                        self.permit_list = []
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.ExtcommunityList.Expanded.Permit, ['permit_list'], name, value)


            class Standard(Entity):
                """
                Extended a standard community\-list entry
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: deny
                
                	Specify community to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Standard.Deny>`
                
                .. attribute:: permit
                
                	Specify community to accept
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Standard.Permit>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.ExtcommunityList.Standard, self).__init__()

                    self.yang_name = "standard"
                    self.yang_parent_name = "extcommunity-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("deny", ("deny", Native.Ip.ExtcommunityList.Standard.Deny)), ("permit", ("permit", Native.Ip.ExtcommunityList.Standard.Permit))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.deny = Native.Ip.ExtcommunityList.Standard.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.permit = Native.Ip.ExtcommunityList.Standard.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._segment_path = lambda: "standard" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-bgp:extcommunity-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.ExtcommunityList.Standard, ['name'], name, value)


                class Deny(Entity):
                    """
                    Specify community to reject
                    
                    .. attribute:: rt
                    
                    	Route Target extended community
                    	**type**\: list of  		 :py:class:`Rt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Standard.Deny.Rt>`
                    
                    .. attribute:: soo
                    
                    	Site\-of\-Origin extended community
                    	**type**\: list of  		 :py:class:`Soo <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Standard.Deny.Soo>`
                    
                    .. attribute:: vpn_distinguisher
                    
                    	VPN Distinguisher extcomm
                    	**type**\: list of  		 :py:class:`VpnDistinguisher <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Standard.Deny.VpnDistinguisher>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.ExtcommunityList.Standard.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "standard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rt", ("rt", Native.Ip.ExtcommunityList.Standard.Deny.Rt)), ("soo", ("soo", Native.Ip.ExtcommunityList.Standard.Deny.Soo)), ("vpn-distinguisher", ("vpn_distinguisher", Native.Ip.ExtcommunityList.Standard.Deny.VpnDistinguisher))])
                        self._leafs = OrderedDict()

                        self.rt = YList(self)
                        self.soo = YList(self)
                        self.vpn_distinguisher = YList(self)
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.ExtcommunityList.Standard.Deny, [], name, value)


                    class Rt(Entity):
                        """
                        Route Target extended community
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.Standard.Deny.Rt, self).__init__()

                            self.yang_name = "rt"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "rt" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.Standard.Deny.Rt, ['name'], name, value)


                    class Soo(Entity):
                        """
                        Site\-of\-Origin extended community
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.Standard.Deny.Soo, self).__init__()

                            self.yang_name = "soo"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "soo" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.Standard.Deny.Soo, ['name'], name, value)


                    class VpnDistinguisher(Entity):
                        """
                        VPN Distinguisher extcomm
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.Standard.Deny.VpnDistinguisher, self).__init__()

                            self.yang_name = "vpn-distinguisher"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "vpn-distinguisher" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.Standard.Deny.VpnDistinguisher, ['name'], name, value)


                class Permit(Entity):
                    """
                    Specify community to accept
                    
                    .. attribute:: rt
                    
                    	Route Target extended community
                    	**type**\: list of  		 :py:class:`Rt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Standard.Permit.Rt>`
                    
                    .. attribute:: soo
                    
                    	Site\-of\-Origin extended community
                    	**type**\: list of  		 :py:class:`Soo <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Standard.Permit.Soo>`
                    
                    .. attribute:: vpn_distinguisher
                    
                    	VPN Distinguisher extcomm
                    	**type**\: list of  		 :py:class:`VpnDistinguisher <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.ExtcommunityList.Standard.Permit.VpnDistinguisher>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.ExtcommunityList.Standard.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "standard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rt", ("rt", Native.Ip.ExtcommunityList.Standard.Permit.Rt)), ("soo", ("soo", Native.Ip.ExtcommunityList.Standard.Permit.Soo)), ("vpn-distinguisher", ("vpn_distinguisher", Native.Ip.ExtcommunityList.Standard.Permit.VpnDistinguisher))])
                        self._leafs = OrderedDict()

                        self.rt = YList(self)
                        self.soo = YList(self)
                        self.vpn_distinguisher = YList(self)
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.ExtcommunityList.Standard.Permit, [], name, value)


                    class Rt(Entity):
                        """
                        Route Target extended community
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.Standard.Permit.Rt, self).__init__()

                            self.yang_name = "rt"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "rt" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.Standard.Permit.Rt, ['name'], name, value)


                    class Soo(Entity):
                        """
                        Site\-of\-Origin extended community
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.Standard.Permit.Soo, self).__init__()

                            self.yang_name = "soo"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "soo" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.Standard.Permit.Soo, ['name'], name, value)


                    class VpnDistinguisher(Entity):
                        """
                        VPN Distinguisher extcomm
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.ExtcommunityList.Standard.Permit.VpnDistinguisher, self).__init__()

                            self.yang_name = "vpn-distinguisher"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "vpn-distinguisher" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.ExtcommunityList.Standard.Permit.VpnDistinguisher, ['name'], name, value)


        class Sla(Entity):
            """
            IP Service Level Agreement
            
            .. attribute:: entry
            
            	
            	**type**\: list of  		 :py:class:`Entry <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry>`
            
            .. attribute:: enable
            
            	
            	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Enable>`
            
            .. attribute:: responder
            
            	Enable IP SLAs Responder
            	**type**\:  :py:class:`Responder <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Responder>`
            
            	**presence node**\: True
            
            .. attribute:: logging
            
            	low\-memory
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Logging>`
            
            .. attribute:: group
            
            	Group Configuration or Group Scheduling
            	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Group>`
            
            .. attribute:: schedule
            
            	Entry Scheduling
            	**type**\: list of  		 :py:class:`Schedule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Schedule>`
            
            .. attribute:: reaction_configuration
            
            	IP SLA's reaction configuration
            	**type**\: list of  		 :py:class:`ReactionConfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.ReactionConfiguration>`
            
            .. attribute:: server
            
            	IPPM server configuration
            	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Server>`
            
            

            """

            _prefix = 'ios-sla'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ip.Sla, self).__init__()

                self.yang_name = "sla"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("entry", ("entry", Native.Ip.Sla.Entry)), ("enable", ("enable", Native.Ip.Sla.Enable)), ("responder", ("responder", Native.Ip.Sla.Responder)), ("logging", ("logging", Native.Ip.Sla.Logging)), ("group", ("group", Native.Ip.Sla.Group)), ("schedule", ("schedule", Native.Ip.Sla.Schedule)), ("reaction-configuration", ("reaction_configuration", Native.Ip.Sla.ReactionConfiguration)), ("server", ("server", Native.Ip.Sla.Server))])
                self._leafs = OrderedDict()

                self.enable = Native.Ip.Sla.Enable()
                self.enable.parent = self
                self._children_name_map["enable"] = "enable"

                self.responder = None
                self._children_name_map["responder"] = "responder"

                self.logging = Native.Ip.Sla.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.group = Native.Ip.Sla.Group()
                self.group.parent = self
                self._children_name_map["group"] = "group"

                self.server = Native.Ip.Sla.Server()
                self.server.parent = self
                self._children_name_map["server"] = "server"

                self.entry = YList(self)
                self.schedule = YList(self)
                self.reaction_configuration = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-sla:sla"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Sla, [], name, value)


            class Entry(Entity):
                """
                
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: icmp_echo
                
                	ICMP Echo Operation
                	**type**\:  :py:class:`IcmpEcho <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.IcmpEcho>`
                
                .. attribute:: path_echo
                
                	Path Discovered ICMP Echo Operation
                	**type**\:  :py:class:`PathEcho <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.PathEcho>`
                
                .. attribute:: path_jitter
                
                	Path Discovered ICMP Jitter Operation
                	**type**\:  :py:class:`PathJitter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.PathJitter>`
                
                .. attribute:: udp_echo
                
                	UDP echo operation
                	**type**\:  :py:class:`UdpEcho <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.UdpEcho>`
                
                .. attribute:: udp_jitter
                
                	UDP jitter operation
                	**type**\:  :py:class:`UdpJitter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.UdpJitter>`
                
                .. attribute:: http
                
                	HTTP Operation
                	**type**\:  :py:class:`Http <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.Http>`
                
                .. attribute:: dhcp
                
                	DHCP Operation
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.Dhcp>`
                
                .. attribute:: ethernet
                
                	Ethernet Operations
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.Ethernet>`
                
                

                """

                _prefix = 'ios-sla'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Sla.Entry, self).__init__()

                    self.yang_name = "entry"
                    self.yang_parent_name = "sla"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("icmp-echo", ("icmp_echo", Native.Ip.Sla.Entry.IcmpEcho)), ("path-echo", ("path_echo", Native.Ip.Sla.Entry.PathEcho)), ("path-jitter", ("path_jitter", Native.Ip.Sla.Entry.PathJitter)), ("udp-echo", ("udp_echo", Native.Ip.Sla.Entry.UdpEcho)), ("udp-jitter", ("udp_jitter", Native.Ip.Sla.Entry.UdpJitter)), ("http", ("http", Native.Ip.Sla.Entry.Http)), ("dhcp", ("dhcp", Native.Ip.Sla.Entry.Dhcp)), ("ethernet", ("ethernet", Native.Ip.Sla.Entry.Ethernet))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                    ])
                    self.number = None

                    self.icmp_echo = Native.Ip.Sla.Entry.IcmpEcho()
                    self.icmp_echo.parent = self
                    self._children_name_map["icmp_echo"] = "icmp-echo"

                    self.path_echo = Native.Ip.Sla.Entry.PathEcho()
                    self.path_echo.parent = self
                    self._children_name_map["path_echo"] = "path-echo"

                    self.path_jitter = Native.Ip.Sla.Entry.PathJitter()
                    self.path_jitter.parent = self
                    self._children_name_map["path_jitter"] = "path-jitter"

                    self.udp_echo = Native.Ip.Sla.Entry.UdpEcho()
                    self.udp_echo.parent = self
                    self._children_name_map["udp_echo"] = "udp-echo"

                    self.udp_jitter = Native.Ip.Sla.Entry.UdpJitter()
                    self.udp_jitter.parent = self
                    self._children_name_map["udp_jitter"] = "udp-jitter"

                    self.http = Native.Ip.Sla.Entry.Http()
                    self.http.parent = self
                    self._children_name_map["http"] = "http"

                    self.dhcp = Native.Ip.Sla.Entry.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.ethernet = Native.Ip.Sla.Entry.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"
                    self._segment_path = lambda: "entry" + "[number='" + str(self.number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Sla.Entry, ['number'], name, value)


                class IcmpEcho(Entity):
                    """
                    ICMP Echo Operation
                    
                    .. attribute:: destination
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_interface
                    
                    	Source Interface (ingress icmp packet interface)
                    	**type**\: str
                    
                    .. attribute:: source_ip
                    
                    	Source Address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: data_pattern
                    
                    	Data Pattern
                    	**type**\: str
                    
                    .. attribute:: frequency
                    
                    	Frequency of an operation
                    	**type**\: int
                    
                    	**range:** 1..604800
                    
                    .. attribute:: history
                    
                    	History and Distribution Data
                    	**type**\:  :py:class:`History <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.IcmpEcho.History>`
                    
                    .. attribute:: owner
                    
                    	Owner of Entry
                    	**type**\: str
                    
                    .. attribute:: request_data_size
                    
                    	Request data size
                    	**type**\: int
                    
                    	**range:** 0..16384
                    
                    .. attribute:: tag
                    
                    	User defined tag
                    	**type**\: str
                    
                    .. attribute:: threshold
                    
                    	Operation threshold in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..60000
                    
                    .. attribute:: timeout
                    
                    	Timeout of an operation
                    	**type**\: int
                    
                    	**range:** 0..604800000
                    
                    .. attribute:: tos
                    
                    	Type Of Service
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: verify_data
                    
                    	Verify data
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	Configure IP SLAs for a VPN Routing/Forwarding instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Entry.IcmpEcho, self).__init__()

                        self.yang_name = "icmp-echo"
                        self.yang_parent_name = "entry"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("history", ("history", Native.Ip.Sla.Entry.IcmpEcho.History))])
                        self._leafs = OrderedDict([
                            ('destination', (YLeaf(YType.str, 'destination'), ['str','str'])),
                            ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ('source_ip', (YLeaf(YType.str, 'source-ip'), ['str','str'])),
                            ('data_pattern', (YLeaf(YType.str, 'data-pattern'), ['str'])),
                            ('frequency', (YLeaf(YType.uint32, 'frequency'), ['int'])),
                            ('owner', (YLeaf(YType.str, 'owner'), ['str'])),
                            ('request_data_size', (YLeaf(YType.uint32, 'request-data-size'), ['int'])),
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                            ('timeout', (YLeaf(YType.uint64, 'timeout'), ['int'])),
                            ('tos', (YLeaf(YType.uint8, 'tos'), ['int'])),
                            ('verify_data', (YLeaf(YType.empty, 'verify-data'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.destination = None
                        self.source_interface = None
                        self.source_ip = None
                        self.data_pattern = None
                        self.frequency = None
                        self.owner = None
                        self.request_data_size = None
                        self.tag = None
                        self.threshold = None
                        self.timeout = None
                        self.tos = None
                        self.verify_data = None
                        self.vrf = None

                        self.history = Native.Ip.Sla.Entry.IcmpEcho.History()
                        self.history.parent = self
                        self._children_name_map["history"] = "history"
                        self._segment_path = lambda: "icmp-echo"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Entry.IcmpEcho, ['destination', 'source_interface', 'source_ip', 'data_pattern', 'frequency', 'owner', 'request_data_size', 'tag', 'threshold', 'timeout', 'tos', 'verify_data', 'vrf'], name, value)


                    class History(Entity):
                        """
                        History and Distribution Data
                        
                        .. attribute:: buckets_kept
                        
                        	Maximum number of history buckets to collect
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: distributions_of_statistics_kept
                        
                        	Maximum number of statistics distribution buckets to capture
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: enhanced
                        
                        	Enable enhanced history collection
                        	**type**\:  :py:class:`Enhanced <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.IcmpEcho.History.Enhanced>`
                        
                        .. attribute:: filter
                        
                        	Add operation to History when..
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.IcmpEcho.History.Filter>`
                        
                        .. attribute:: hours_of_statistics_kept
                        
                        	Maximum number of statistics hour groups to capture
                        	**type**\: int
                        
                        	**range:** 0..25
                        
                        .. attribute:: lives_kept
                        
                        	Maximum number of history lives to collect
                        	**type**\: int
                        
                        	**range:** 0..2
                        
                        .. attribute:: statistics_distribution_interval
                        
                        	Statistics distribution interval size
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.Entry.IcmpEcho.History, self).__init__()

                            self.yang_name = "history"
                            self.yang_parent_name = "icmp-echo"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("enhanced", ("enhanced", Native.Ip.Sla.Entry.IcmpEcho.History.Enhanced))])
                            self._leafs = OrderedDict([
                                ('buckets_kept', (YLeaf(YType.uint8, 'buckets-kept'), ['int'])),
                                ('distributions_of_statistics_kept', (YLeaf(YType.uint8, 'distributions-of-statistics-kept'), ['int'])),
                                ('filter', (YLeaf(YType.enumeration, 'filter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Sla.Entry.IcmpEcho.History.Filter')])),
                                ('hours_of_statistics_kept', (YLeaf(YType.uint8, 'hours-of-statistics-kept'), ['int'])),
                                ('lives_kept', (YLeaf(YType.uint8, 'lives-kept'), ['int'])),
                                ('statistics_distribution_interval', (YLeaf(YType.uint8, 'statistics-distribution-interval'), ['int'])),
                            ])
                            self.buckets_kept = None
                            self.distributions_of_statistics_kept = None
                            self.filter = None
                            self.hours_of_statistics_kept = None
                            self.lives_kept = None
                            self.statistics_distribution_interval = None

                            self.enhanced = Native.Ip.Sla.Entry.IcmpEcho.History.Enhanced()
                            self.enhanced.parent = self
                            self._children_name_map["enhanced"] = "enhanced"
                            self._segment_path = lambda: "history"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.Entry.IcmpEcho.History, ['buckets_kept', 'distributions_of_statistics_kept', 'filter', 'hours_of_statistics_kept', 'lives_kept', 'statistics_distribution_interval'], name, value)

                        class Filter(Enum):
                            """
                            Filter (Enum Class)

                            Add operation to History when...

                            .. data:: all = 0

                            .. data:: failures = 1

                            .. data:: none = 2

                            .. data:: overThreshold = 3

                            """

                            all = Enum.YLeaf(0, "all")

                            failures = Enum.YLeaf(1, "failures")

                            none = Enum.YLeaf(2, "none")

                            overThreshold = Enum.YLeaf(3, "overThreshold")



                        class Enhanced(Entity):
                            """
                            Enable enhanced history collection
                            
                            .. attribute:: interval
                            
                            	Aggregation interval
                            	**type**\: int
                            
                            	**range:** 1..3600
                            
                            .. attribute:: buckets
                            
                            	Number of buckets to collect data
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-sla'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ip.Sla.Entry.IcmpEcho.History.Enhanced, self).__init__()

                                self.yang_name = "enhanced"
                                self.yang_parent_name = "history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                    ('buckets', (YLeaf(YType.uint8, 'buckets'), ['int'])),
                                ])
                                self.interval = None
                                self.buckets = None
                                self._segment_path = lambda: "enhanced"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Sla.Entry.IcmpEcho.History.Enhanced, ['interval', 'buckets'], name, value)


                class PathEcho(Entity):
                    """
                    Path Discovered ICMP Echo Operation
                    
                    .. attribute:: dst_ip
                    
                    	Destination IP address or hostname, broadcast disallowed
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_ip
                    
                    	IP address or hostname, broadcast disallowed
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: paths_of_statistics_kept
                    
                    	Maximum number of statistics paths to capture
                    	**type**\: int
                    
                    	**range:** 1..128
                    
                    .. attribute:: samples_of_history_kept
                    
                    	Maximum number of history samples to collect
                    	**type**\: int
                    
                    	**range:** 1..30
                    
                    .. attribute:: hops_of_statistics_kept
                    
                    	Maximum number of statistics hops to capture
                    	**type**\: int
                    
                    	**range:** 1..30
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Entry.PathEcho, self).__init__()

                        self.yang_name = "path-echo"
                        self.yang_parent_name = "entry"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dst_ip', (YLeaf(YType.str, 'dst-ip'), ['str','str'])),
                            ('source_ip', (YLeaf(YType.str, 'source-ip'), ['str','str'])),
                            ('paths_of_statistics_kept', (YLeaf(YType.uint8, 'paths-of-statistics-kept'), ['int'])),
                            ('samples_of_history_kept', (YLeaf(YType.uint8, 'samples-of-history-kept'), ['int'])),
                            ('hops_of_statistics_kept', (YLeaf(YType.uint8, 'hops-of-statistics-kept'), ['int'])),
                        ])
                        self.dst_ip = None
                        self.source_ip = None
                        self.paths_of_statistics_kept = None
                        self.samples_of_history_kept = None
                        self.hops_of_statistics_kept = None
                        self._segment_path = lambda: "path-echo"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Entry.PathEcho, ['dst_ip', 'source_ip', 'paths_of_statistics_kept', 'samples_of_history_kept', 'hops_of_statistics_kept'], name, value)


                class PathJitter(Entity):
                    """
                    Path Discovered ICMP Jitter Operation
                    
                    .. attribute:: dst_ip
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_ip
                    
                    	Source IP Address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: default
                    
                    	Set a command to its defaults
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.PathJitter.Default>`
                    
                    .. attribute:: frequency
                    
                    	Frequency of an operation
                    	**type**\: int
                    
                    	**range:** 1..604800
                    
                    .. attribute:: lsr_path
                    
                    	Loose Source Routing Path
                    	**type**\: union of the below types:
                    
                    		**type**\: list of str
                    
                    		**type**\: list of str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: owner
                    
                    	Owner of Entry
                    	**type**\: str
                    
                    .. attribute:: request_data_size
                    
                    	Request data size
                    	**type**\: int
                    
                    	**range:** 0..16384
                    
                    .. attribute:: tag
                    
                    	User defined tag
                    	**type**\: str
                    
                    .. attribute:: threshold
                    
                    	Operation threshold in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..60000
                    
                    .. attribute:: timeout
                    
                    	Timeout of an operation
                    	**type**\: int
                    
                    	**range:** 0..604800000
                    
                    .. attribute:: tos
                    
                    	Type Of Service
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: verify_data
                    
                    	Verify data
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	Configure IP SLAs for a VPN Routing/Forwarding instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Entry.PathJitter, self).__init__()

                        self.yang_name = "path-jitter"
                        self.yang_parent_name = "entry"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default", ("default", Native.Ip.Sla.Entry.PathJitter.Default))])
                        self._leafs = OrderedDict([
                            ('dst_ip', (YLeaf(YType.str, 'dst-ip'), ['str','str','str'])),
                            ('source_ip', (YLeaf(YType.str, 'source-ip'), ['str','str'])),
                            ('frequency', (YLeaf(YType.uint32, 'frequency'), ['int'])),
                            ('lsr_path', (YLeafList(YType.str, 'lsr-path'), ['str','str'])),
                            ('owner', (YLeaf(YType.str, 'owner'), ['str'])),
                            ('request_data_size', (YLeaf(YType.uint32, 'request-data-size'), ['int'])),
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('tos', (YLeaf(YType.uint8, 'tos'), ['int'])),
                            ('verify_data', (YLeaf(YType.empty, 'verify-data'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.dst_ip = None
                        self.source_ip = None
                        self.frequency = None
                        self.lsr_path = []
                        self.owner = None
                        self.request_data_size = None
                        self.tag = None
                        self.threshold = None
                        self.timeout = None
                        self.tos = None
                        self.verify_data = None
                        self.vrf = None

                        self.default = Native.Ip.Sla.Entry.PathJitter.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"
                        self._segment_path = lambda: "path-jitter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Entry.PathJitter, ['dst_ip', 'source_ip', 'frequency', 'lsr_path', 'owner', 'request_data_size', 'tag', 'threshold', 'timeout', 'tos', 'verify_data', 'vrf'], name, value)


                    class Default(Entity):
                        """
                        Set a command to its defaults
                        
                        .. attribute:: frequency
                        
                        	Frequency of an operation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: lsr_path
                        
                        	Loose Source Routing Path
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: owner
                        
                        	Owner of Entry
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: request_data_size
                        
                        	Request data size
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tag
                        
                        	User defined tag
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: threshold
                        
                        	Operation threshold in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Timeout of an operation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tos
                        
                        	Type Of Service
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: verify_data
                        
                        	Verify data
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vrf
                        
                        	Configure IP SLAs for a VPN Routing/Forwarding instance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.Entry.PathJitter.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "path-jitter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('frequency', (YLeaf(YType.empty, 'frequency'), ['Empty'])),
                                ('lsr_path', (YLeaf(YType.empty, 'lsr-path'), ['Empty'])),
                                ('owner', (YLeaf(YType.empty, 'owner'), ['Empty'])),
                                ('request_data_size', (YLeaf(YType.empty, 'request-data-size'), ['Empty'])),
                                ('tag', (YLeaf(YType.empty, 'tag'), ['Empty'])),
                                ('threshold', (YLeaf(YType.empty, 'threshold'), ['Empty'])),
                                ('timeout', (YLeaf(YType.empty, 'timeout'), ['Empty'])),
                                ('tos', (YLeaf(YType.empty, 'tos'), ['Empty'])),
                                ('verify_data', (YLeaf(YType.empty, 'verify-data'), ['Empty'])),
                                ('vrf', (YLeaf(YType.empty, 'vrf'), ['Empty'])),
                            ])
                            self.frequency = None
                            self.lsr_path = None
                            self.owner = None
                            self.request_data_size = None
                            self.tag = None
                            self.threshold = None
                            self.timeout = None
                            self.tos = None
                            self.verify_data = None
                            self.vrf = None
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.Entry.PathJitter.Default, ['frequency', 'lsr_path', 'owner', 'request_data_size', 'tag', 'threshold', 'timeout', 'tos', 'verify_data', 'vrf'], name, value)


                class UdpEcho(Entity):
                    """
                    UDP echo operation
                    
                    .. attribute:: dest_addr
                    
                    	Hostname or A.B.C.D  Destination IP address or hostname, broadcast disallowed
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    .. attribute:: dest_port
                    
                    	Port Number (Recommended ports greater than 1023)
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: source_ip
                    
                    	Source address\: Hostname or A.B.C.D IP address or hostname, broadcast disallowed
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    .. attribute:: source_port
                    
                    	Source Port\: Port Number (Recommended ports greater than 1023)
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Entry.UdpEcho, self).__init__()

                        self.yang_name = "udp-echo"
                        self.yang_parent_name = "entry"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dest_addr', (YLeaf(YType.str, 'dest-addr'), ['str','str','str'])),
                            ('dest_port', (YLeaf(YType.uint16, 'dest-port'), ['int'])),
                            ('source_ip', (YLeaf(YType.str, 'source-ip'), ['str','str','str'])),
                            ('source_port', (YLeaf(YType.uint16, 'source-port'), ['int'])),
                        ])
                        self.dest_addr = None
                        self.dest_port = None
                        self.source_ip = None
                        self.source_port = None
                        self._segment_path = lambda: "udp-echo"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Entry.UdpEcho, ['dest_addr', 'dest_port', 'source_ip', 'source_port'], name, value)


                class UdpJitter(Entity):
                    """
                    UDP jitter operation
                    
                    .. attribute:: dest_addr
                    
                    	Hostname or A.B.C.D/X\:X\:X\:X\:\:X  Destination IP/IPv6 address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    .. attribute:: portno
                    
                    	Port Number
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: codec
                    
                    	codec type to be configured
                    	**type**\:  :py:class:`Codec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.UdpJitter.Codec>`
                    
                    .. attribute:: advantage_factor
                    
                    	Advantage Factor
                    	**type**\: int
                    
                    	**range:** 0..20
                    
                    .. attribute:: codec_interval
                    
                    	Inter Packet Interval
                    	**type**\: int
                    
                    	**range:** 4..60000
                    
                    .. attribute:: codec_numpackets
                    
                    	Number of Packets
                    	**type**\: int
                    
                    	**range:** 1..60000
                    
                    .. attribute:: codec_size
                    
                    	Number of Packets
                    	**type**\: int
                    
                    	**range:** 16..16384
                    
                    .. attribute:: num_packets
                    
                    	Number of Packets (default 10)
                    	**type**\: int
                    
                    	**range:** 1..60000
                    
                    .. attribute:: interval
                    
                    	Delay (default 20)
                    	**type**\: int
                    
                    	**range:** 4..60000
                    
                    .. attribute:: source_ip
                    
                    	Hostname or A.B.C.D/X\:X\:X\:X\:\:X Source IP/IPv6 address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    .. attribute:: source_port
                    
                    	Source port
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: control
                    
                    	Enable or disable control packets
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.UdpJitter.Control>`
                    
                    .. attribute:: history
                    
                    	History and Distribution Data
                    	**type**\:  :py:class:`History <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.UdpJitter.History>`
                    
                    .. attribute:: owner
                    
                    	Owner of Entry
                    	**type**\: str
                    
                    .. attribute:: request_data_size
                    
                    	Number of bytes in payload
                    	**type**\: int
                    
                    	**range:** 16..17512
                    
                    .. attribute:: tag
                    
                    	User defined tag
                    	**type**\: str
                    
                    .. attribute:: threshold
                    
                    	Operation threshold in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..60000
                    
                    .. attribute:: timeout
                    
                    	Timeout of an operation
                    	**type**\: int
                    
                    	**range:** 0..604800000
                    
                    .. attribute:: tos
                    
                    	Type Of Service
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: traffic_class
                    
                    	Traffic class
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: vrf
                    
                    	Configure IP SLAs for a VPN Routing/Forwarding instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Entry.UdpJitter, self).__init__()

                        self.yang_name = "udp-jitter"
                        self.yang_parent_name = "entry"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("history", ("history", Native.Ip.Sla.Entry.UdpJitter.History))])
                        self._leafs = OrderedDict([
                            ('dest_addr', (YLeaf(YType.str, 'dest-addr'), ['str','str','str','str'])),
                            ('portno', (YLeaf(YType.uint16, 'portno'), ['int'])),
                            ('codec', (YLeaf(YType.enumeration, 'codec'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Sla.Entry.UdpJitter.Codec')])),
                            ('advantage_factor', (YLeaf(YType.uint16, 'advantage-factor'), ['int'])),
                            ('codec_interval', (YLeaf(YType.uint32, 'codec-interval'), ['int'])),
                            ('codec_numpackets', (YLeaf(YType.uint32, 'codec-numpackets'), ['int'])),
                            ('codec_size', (YLeaf(YType.uint16, 'codec-size'), ['int'])),
                            ('num_packets', (YLeaf(YType.uint16, 'num-packets'), ['int'])),
                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ('source_ip', (YLeaf(YType.str, 'source-ip'), ['str','str','str','str'])),
                            ('source_port', (YLeaf(YType.uint16, 'source-port'), ['int'])),
                            ('control', (YLeaf(YType.enumeration, 'control'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Sla.Entry.UdpJitter.Control')])),
                            ('owner', (YLeaf(YType.str, 'owner'), ['str'])),
                            ('request_data_size', (YLeaf(YType.uint16, 'request-data-size'), ['int'])),
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('tos', (YLeaf(YType.uint8, 'tos'), ['int'])),
                            ('traffic_class', (YLeaf(YType.uint8, 'traffic-class'), ['int'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.dest_addr = None
                        self.portno = None
                        self.codec = None
                        self.advantage_factor = None
                        self.codec_interval = None
                        self.codec_numpackets = None
                        self.codec_size = None
                        self.num_packets = None
                        self.interval = None
                        self.source_ip = None
                        self.source_port = None
                        self.control = None
                        self.owner = None
                        self.request_data_size = None
                        self.tag = None
                        self.threshold = None
                        self.timeout = None
                        self.tos = None
                        self.traffic_class = None
                        self.vrf = None

                        self.history = Native.Ip.Sla.Entry.UdpJitter.History()
                        self.history.parent = self
                        self._children_name_map["history"] = "history"
                        self._segment_path = lambda: "udp-jitter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Entry.UdpJitter, ['dest_addr', 'portno', 'codec', 'advantage_factor', 'codec_interval', 'codec_numpackets', 'codec_size', 'num_packets', 'interval', 'source_ip', 'source_port', 'control', 'owner', 'request_data_size', 'tag', 'threshold', 'timeout', 'tos', 'traffic_class', 'vrf'], name, value)

                    class Codec(Enum):
                        """
                        Codec (Enum Class)

                        codec type to be configured

                        .. data:: g711alaw = 0

                        .. data:: g711ulaw = 1

                        .. data:: g729a = 2

                        """

                        g711alaw = Enum.YLeaf(0, "g711alaw")

                        g711ulaw = Enum.YLeaf(1, "g711ulaw")

                        g729a = Enum.YLeaf(2, "g729a")


                    class Control(Enum):
                        """
                        Control (Enum Class)

                        Enable or disable control packets

                        .. data:: enable = 0

                        .. data:: disable = 1

                        """

                        enable = Enum.YLeaf(0, "enable")

                        disable = Enum.YLeaf(1, "disable")



                    class History(Entity):
                        """
                        History and Distribution Data
                        
                        .. attribute:: distributions_of_statistics_kept
                        
                        	Maximum number of statistics distribution buckets to capture
                        	**type**\: int
                        
                        	**range:** 1..20
                        
                        .. attribute:: enhanced
                        
                        	Enable enhanced history collection
                        	**type**\:  :py:class:`Enhanced <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.UdpJitter.History.Enhanced>`
                        
                        .. attribute:: hours_of_statistics_kept
                        
                        	Maximum number of statistics hour groups to capture
                        	**type**\: int
                        
                        	**range:** 0..25
                        
                        .. attribute:: statistics_distribution_interval
                        
                        	Statistics distribution interval size
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.Entry.UdpJitter.History, self).__init__()

                            self.yang_name = "history"
                            self.yang_parent_name = "udp-jitter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("enhanced", ("enhanced", Native.Ip.Sla.Entry.UdpJitter.History.Enhanced))])
                            self._leafs = OrderedDict([
                                ('distributions_of_statistics_kept', (YLeaf(YType.uint8, 'distributions-of-statistics-kept'), ['int'])),
                                ('hours_of_statistics_kept', (YLeaf(YType.uint8, 'hours-of-statistics-kept'), ['int'])),
                                ('statistics_distribution_interval', (YLeaf(YType.uint8, 'statistics-distribution-interval'), ['int'])),
                            ])
                            self.distributions_of_statistics_kept = None
                            self.hours_of_statistics_kept = None
                            self.statistics_distribution_interval = None

                            self.enhanced = Native.Ip.Sla.Entry.UdpJitter.History.Enhanced()
                            self.enhanced.parent = self
                            self._children_name_map["enhanced"] = "enhanced"
                            self._segment_path = lambda: "history"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.Entry.UdpJitter.History, ['distributions_of_statistics_kept', 'hours_of_statistics_kept', 'statistics_distribution_interval'], name, value)


                        class Enhanced(Entity):
                            """
                            Enable enhanced history collection
                            
                            .. attribute:: interval
                            
                            	Aggregation interval
                            	**type**\: int
                            
                            	**range:** 1..3600
                            
                            .. attribute:: buckets
                            
                            	Number of buckets to collect data
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-sla'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ip.Sla.Entry.UdpJitter.History.Enhanced, self).__init__()

                                self.yang_name = "enhanced"
                                self.yang_parent_name = "history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ('buckets', (YLeaf(YType.uint8, 'buckets'), ['int'])),
                                ])
                                self.interval = None
                                self.buckets = None
                                self._segment_path = lambda: "enhanced"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Sla.Entry.UdpJitter.History.Enhanced, ['interval', 'buckets'], name, value)


                class Http(Entity):
                    """
                    HTTP Operation
                    
                    .. attribute:: get
                    
                    	HTTP get operation
                    	**type**\:  :py:class:`Get <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.Http.Get>`
                    
                    .. attribute:: raw
                    
                    	HTTP raw operation
                    	**type**\:  :py:class:`Raw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.Http.Raw>`
                    
                    .. attribute:: owner
                    
                    	Owner of Entry
                    	**type**\: str
                    
                    .. attribute:: tag
                    
                    	User defined tag
                    	**type**\: str
                    
                    .. attribute:: vrf
                    
                    	Configure IP SLAs for a new VPN Routing/Forwarding instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Entry.Http, self).__init__()

                        self.yang_name = "http"
                        self.yang_parent_name = "entry"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("get", ("get", Native.Ip.Sla.Entry.Http.Get)), ("raw", ("raw", Native.Ip.Sla.Entry.Http.Raw))])
                        self._leafs = OrderedDict([
                            ('owner', (YLeaf(YType.str, 'owner'), ['str'])),
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.owner = None
                        self.tag = None
                        self.vrf = None

                        self.get = Native.Ip.Sla.Entry.Http.Get()
                        self.get.parent = self
                        self._children_name_map["get"] = "get"

                        self.raw = Native.Ip.Sla.Entry.Http.Raw()
                        self.raw.parent = self
                        self._children_name_map["raw"] = "raw"
                        self._segment_path = lambda: "http"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Entry.Http, ['owner', 'tag', 'vrf'], name, value)


                    class Get(Entity):
                        """
                        HTTP get operation
                        
                        .. attribute:: url
                        
                        	URL
                        	**type**\: str
                        
                        .. attribute:: source_ip
                        
                        	Source Address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        .. attribute:: source_port
                        
                        	Source port
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: name_server
                        
                        	Name server
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.Entry.Http.Get, self).__init__()

                            self.yang_name = "get"
                            self.yang_parent_name = "http"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('url', (YLeaf(YType.str, 'url'), ['str'])),
                                ('source_ip', (YLeaf(YType.str, 'source-ip'), ['str','str','str'])),
                                ('source_port', (YLeaf(YType.uint16, 'source-port'), ['int'])),
                                ('name_server', (YLeaf(YType.str, 'name-server'), ['str','str','str'])),
                            ])
                            self.url = None
                            self.source_ip = None
                            self.source_port = None
                            self.name_server = None
                            self._segment_path = lambda: "get"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.Entry.Http.Get, ['url', 'source_ip', 'source_port', 'name_server'], name, value)


                    class Raw(Entity):
                        """
                        HTTP raw operation
                        
                        .. attribute:: url
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: source_ip
                        
                        	Source Address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        .. attribute:: source_port
                        
                        	Source port
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: name_server
                        
                        	Name server
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.Entry.Http.Raw, self).__init__()

                            self.yang_name = "raw"
                            self.yang_parent_name = "http"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('url', (YLeaf(YType.str, 'url'), ['str'])),
                                ('source_ip', (YLeaf(YType.str, 'source-ip'), ['str','str','str'])),
                                ('source_port', (YLeaf(YType.uint16, 'source-port'), ['int'])),
                                ('name_server', (YLeaf(YType.str, 'name-server'), ['str','str','str'])),
                            ])
                            self.url = None
                            self.source_ip = None
                            self.source_port = None
                            self.name_server = None
                            self._segment_path = lambda: "raw"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.Entry.Http.Raw, ['url', 'source_ip', 'source_port', 'name_server'], name, value)


                class Dhcp(Entity):
                    """
                    DHCP Operation
                    
                    .. attribute:: dst_ip
                    
                    	Destination IP address or hostname, broadcast disallowed
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_ip
                    
                    	IP address or hostname, broadcast disallowed
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Entry.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "entry"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dst_ip', (YLeaf(YType.str, 'dst-ip'), ['str','str'])),
                            ('source_ip', (YLeaf(YType.str, 'source-ip'), ['str','str'])),
                        ])
                        self.dst_ip = None
                        self.source_ip = None
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Entry.Dhcp, ['dst_ip', 'source_ip'], name, value)


                class Ethernet(Entity):
                    """
                    Ethernet Operations
                    
                    .. attribute:: y1731
                    
                    	Y1731 Ethernet OAM Performance Measurement Operations
                    	**type**\:  :py:class:`Y1731 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.Ethernet.Y1731>`
                    
                    .. attribute:: aggregate
                    
                    	Aggregate parameters
                    	**type**\:  :py:class:`Aggregate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.Ethernet.Aggregate>`
                    
                    .. attribute:: history
                    
                    	History parameters
                    	**type**\:  :py:class:`History <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.Ethernet.History>`
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Entry.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "entry"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("y1731", ("y1731", Native.Ip.Sla.Entry.Ethernet.Y1731)), ("aggregate", ("aggregate", Native.Ip.Sla.Entry.Ethernet.Aggregate)), ("history", ("history", Native.Ip.Sla.Entry.Ethernet.History))])
                        self._leafs = OrderedDict()

                        self.y1731 = Native.Ip.Sla.Entry.Ethernet.Y1731()
                        self.y1731.parent = self
                        self._children_name_map["y1731"] = "y1731"

                        self.aggregate = Native.Ip.Sla.Entry.Ethernet.Aggregate()
                        self.aggregate.parent = self
                        self._children_name_map["aggregate"] = "aggregate"

                        self.history = Native.Ip.Sla.Entry.Ethernet.History()
                        self.history.parent = self
                        self._children_name_map["history"] = "history"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Entry.Ethernet, [], name, value)


                    class Y1731(Entity):
                        """
                        Y1731 Ethernet OAM Performance Measurement Operations
                        
                        .. attribute:: delay
                        
                        	Y1731 Delay and Delay Variation Operation
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.Ethernet.Y1731.Delay>`
                        
                        

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.Entry.Ethernet.Y1731, self).__init__()

                            self.yang_name = "y1731"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Ip.Sla.Entry.Ethernet.Y1731.Delay))])
                            self._leafs = OrderedDict()

                            self.delay = Native.Ip.Sla.Entry.Ethernet.Y1731.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "y1731"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.Entry.Ethernet.Y1731, [], name, value)


                        class Delay(Entity):
                            """
                            Y1731 Delay and Delay Variation Operation
                            
                            .. attribute:: name
                            
                            	Y1731 Delay option
                            	**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.Ethernet.Y1731.Delay.Name>`
                            
                            .. attribute:: burst
                            
                            	Enable bursting of delay frames
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: domain
                            
                            	Specify the Ethernet OAM domain
                            	**type**\: str
                            
                            .. attribute:: evc
                            
                            	Specify the Ethernet Virtual Circuit Identifier
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Specify the VLAN
                            	**type**\: int
                            
                            	**range:** 1..4096
                            
                            .. attribute:: mac_address
                            
                            	Specify the remote mac\-address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                            
                            .. attribute:: mpid
                            
                            	Specify the remote MPID
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            .. attribute:: cos
                            
                            	Specify the Class of Service
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: source
                            
                            	Specify the local MPID or MAC\-Address
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry.Ethernet.Y1731.Delay.Source>`
                            
                            

                            """

                            _prefix = 'ios-sla'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ip.Sla.Entry.Ethernet.Y1731.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "y1731"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source", ("source", Native.Ip.Sla.Entry.Ethernet.Y1731.Delay.Source))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.enumeration, 'name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Sla.Entry.Ethernet.Y1731.Delay.Name')])),
                                    ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('evc', (YLeaf(YType.str, 'evc'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                    ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                ])
                                self.name = None
                                self.burst = None
                                self.domain = None
                                self.evc = None
                                self.vlan = None
                                self.mac_address = None
                                self.mpid = None
                                self.cos = None

                                self.source = Native.Ip.Sla.Entry.Ethernet.Y1731.Delay.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Sla.Entry.Ethernet.Y1731.Delay, ['name', 'burst', 'domain', 'evc', 'vlan', 'mac_address', 'mpid', 'cos'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                Y1731 Delay option

                                .. data:: Y_1DM = 0

                                .. data:: DMM = 1

                                .. data:: DMMv1 = 2

                                """

                                Y_1DM = Enum.YLeaf(0, "1DM")

                                DMM = Enum.YLeaf(1, "DMM")

                                DMMv1 = Enum.YLeaf(2, "DMMv1")



                            class Source(Entity):
                                """
                                Specify the local MPID or MAC\-Address
                                
                                .. attribute:: mac_address
                                
                                	Specify the local mac\-address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                
                                .. attribute:: mpid
                                
                                	Specify the local MPID
                                	**type**\: int
                                
                                	**range:** 1..8191
                                
                                

                                """

                                _prefix = 'ios-sla'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ip.Sla.Entry.Ethernet.Y1731.Delay.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "delay"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                        ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                    ])
                                    self.mac_address = None
                                    self.mpid = None
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Sla.Entry.Ethernet.Y1731.Delay.Source, ['mac_address', 'mpid'], name, value)


                    class Aggregate(Entity):
                        """
                        Aggregate parameters
                        
                        .. attribute:: interval
                        
                        	Specify interval period
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.Entry.Ethernet.Aggregate, self).__init__()

                            self.yang_name = "aggregate"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "aggregate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.Entry.Ethernet.Aggregate, ['interval'], name, value)


                    class History(Entity):
                        """
                        History parameters
                        
                        .. attribute:: interval
                        
                        	Specify number of intervals
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.Entry.Ethernet.History, self).__init__()

                            self.yang_name = "history"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint8, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "history"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.Entry.Ethernet.History, ['interval'], name, value)


            class Enable(Entity):
                """
                
                
                .. attribute:: reaction_alerts
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sla'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Sla.Enable, self).__init__()

                    self.yang_name = "enable"
                    self.yang_parent_name = "sla"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('reaction_alerts', (YLeaf(YType.empty, 'reaction-alerts'), ['Empty'])),
                    ])
                    self.reaction_alerts = None
                    self._segment_path = lambda: "enable"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Sla.Enable, ['reaction_alerts'], name, value)


            class Responder(Entity):
                """
                Enable IP SLAs Responder
                
                .. attribute:: udp_echo
                
                	Setup udp\-echo responder
                	**type**\:  :py:class:`UdpEcho <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Responder.UdpEcho>`
                
                .. attribute:: tcp_connect
                
                	Setup tcp\-connect responder
                	**type**\:  :py:class:`TcpConnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Responder.TcpConnect>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sla'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Sla.Responder, self).__init__()

                    self.yang_name = "responder"
                    self.yang_parent_name = "sla"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("udp-echo", ("udp_echo", Native.Ip.Sla.Responder.UdpEcho)), ("tcp-connect", ("tcp_connect", Native.Ip.Sla.Responder.TcpConnect))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.udp_echo = Native.Ip.Sla.Responder.UdpEcho()
                    self.udp_echo.parent = self
                    self._children_name_map["udp_echo"] = "udp-echo"

                    self.tcp_connect = Native.Ip.Sla.Responder.TcpConnect()
                    self.tcp_connect.parent = self
                    self._children_name_map["tcp_connect"] = "tcp-connect"
                    self._segment_path = lambda: "responder"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Sla.Responder, [], name, value)


                class UdpEcho(Entity):
                    """
                    Setup udp\-echo responder
                    
                    .. attribute:: port
                    
                    	Permanent port
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipaddress
                    
                    	Permanent address
                    	**type**\: list of  		 :py:class:`Ipaddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Responder.UdpEcho.Ipaddress>`
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Responder.UdpEcho, self).__init__()

                        self.yang_name = "udp-echo"
                        self.yang_parent_name = "responder"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipaddress", ("ipaddress", Native.Ip.Sla.Responder.UdpEcho.Ipaddress))])
                        self._leafs = OrderedDict([
                            ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                        ])
                        self.port = None

                        self.ipaddress = YList(self)
                        self._segment_path = lambda: "udp-echo"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/responder/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Responder.UdpEcho, ['port'], name, value)


                    class Ipaddress(Entity):
                        """
                        Permanent address
                        
                        .. attribute:: host  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: port
                        
                        	Permanent port
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.Responder.UdpEcho.Ipaddress, self).__init__()

                            self.yang_name = "ipaddress"
                            self.yang_parent_name = "udp-echo"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['host']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.str, 'host'), ['str','str'])),
                                ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                            ])
                            self.host = None
                            self.port = None
                            self._segment_path = lambda: "ipaddress" + "[host='" + str(self.host) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/responder/udp-echo/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.Responder.UdpEcho.Ipaddress, ['host', 'port'], name, value)


                class TcpConnect(Entity):
                    """
                    Setup tcp\-connect responder
                    
                    .. attribute:: port
                    
                    	Permanent port
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipaddress
                    
                    	Permanent address
                    	**type**\: list of  		 :py:class:`Ipaddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Responder.TcpConnect.Ipaddress>`
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Responder.TcpConnect, self).__init__()

                        self.yang_name = "tcp-connect"
                        self.yang_parent_name = "responder"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipaddress", ("ipaddress", Native.Ip.Sla.Responder.TcpConnect.Ipaddress))])
                        self._leafs = OrderedDict([
                            ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                        ])
                        self.port = None

                        self.ipaddress = YList(self)
                        self._segment_path = lambda: "tcp-connect"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/responder/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Responder.TcpConnect, ['port'], name, value)


                    class Ipaddress(Entity):
                        """
                        Permanent address
                        
                        .. attribute:: host  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: port
                        
                        	Permanent port
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.Responder.TcpConnect.Ipaddress, self).__init__()

                            self.yang_name = "ipaddress"
                            self.yang_parent_name = "tcp-connect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['host']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.str, 'host'), ['str','str'])),
                                ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                            ])
                            self.host = None
                            self.port = None
                            self._segment_path = lambda: "ipaddress" + "[host='" + str(self.host) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/responder/tcp-connect/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.Responder.TcpConnect.Ipaddress, ['host', 'port'], name, value)


            class Logging(Entity):
                """
                low\-memory
                
                .. attribute:: traps
                
                	Enable syslog traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sla'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Sla.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "sla"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('traps', (YLeaf(YType.empty, 'traps'), ['Empty'])),
                    ])
                    self.traps = None
                    self._segment_path = lambda: "logging"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Sla.Logging, ['traps'], name, value)


            class Group(Entity):
                """
                Group Configuration or Group Scheduling
                
                .. attribute:: schedule
                
                	Group scheduling
                	**type**\: list of  		 :py:class:`Schedule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Group.Schedule>`
                
                

                """

                _prefix = 'ios-sla'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Sla.Group, self).__init__()

                    self.yang_name = "group"
                    self.yang_parent_name = "sla"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("schedule", ("schedule", Native.Ip.Sla.Group.Schedule))])
                    self._leafs = OrderedDict()

                    self.schedule = YList(self)
                    self._segment_path = lambda: "group"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Sla.Group, [], name, value)


                class Schedule(Entity):
                    """
                    Group scheduling
                    
                    .. attribute:: entry_number  (key)
                    
                    	Group schedule entry number
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: probe_ids
                    
                    	
                    	**type**\: list of  		 :py:class:`ProbeIds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Group.Schedule.ProbeIds>`
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Group.Schedule, self).__init__()

                        self.yang_name = "schedule"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['entry_number']
                        self._child_classes = OrderedDict([("probe-ids", ("probe_ids", Native.Ip.Sla.Group.Schedule.ProbeIds))])
                        self._leafs = OrderedDict([
                            ('entry_number', (YLeaf(YType.uint32, 'entry-number'), ['int'])),
                        ])
                        self.entry_number = None

                        self.probe_ids = YList(self)
                        self._segment_path = lambda: "schedule" + "[entry-number='" + str(self.entry_number) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/group/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Group.Schedule, ['entry_number'], name, value)


                    class ProbeIds(Entity):
                        """
                        
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: schedule_period
                        
                        	Group schedule period range
                        	**type**\:  :py:class:`SchedulePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod>`
                        
                        

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.Group.Schedule.ProbeIds, self).__init__()

                            self.yang_name = "probe-ids"
                            self.yang_parent_name = "schedule"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([("schedule-period", ("schedule_period", Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.word = None

                            self.schedule_period = Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod()
                            self.schedule_period.parent = self
                            self._children_name_map["schedule_period"] = "schedule-period"
                            self._segment_path = lambda: "probe-ids" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.Group.Schedule.ProbeIds, ['word'], name, value)


                        class SchedulePeriod(Entity):
                            """
                            Group schedule period range
                            
                            .. attribute:: seconds
                            
                            	seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: frequency
                            
                            	Group operation frequency
                            	**type**\:  :py:class:`Frequency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.Frequency>`
                            
                            .. attribute:: start_time
                            
                            	When to start this entry
                            	**type**\:  :py:class:`StartTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.StartTime>`
                            
                            .. attribute:: life
                            
                            	Length of time to execute in seconds
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\:  :py:class:`Life <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.Life>`
                            
                            

                            """

                            _prefix = 'ios-sla'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod, self).__init__()

                                self.yang_name = "schedule-period"
                                self.yang_parent_name = "probe-ids"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("frequency", ("frequency", Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.Frequency)), ("start-time", ("start_time", Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.StartTime))])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('life', (YLeaf(YType.str, 'life'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.Life')])),
                                ])
                                self.seconds = None
                                self.life = None

                                self.frequency = Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.Frequency()
                                self.frequency.parent = self
                                self._children_name_map["frequency"] = "frequency"

                                self.start_time = Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.StartTime()
                                self.start_time.parent = self
                                self._children_name_map["start_time"] = "start-time"
                                self._segment_path = lambda: "schedule-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod, ['seconds', 'life'], name, value)

                            class Life(Enum):
                                """
                                Life (Enum Class)

                                Length of time to execute in seconds

                                .. data:: forever = 0

                                """

                                forever = Enum.YLeaf(0, "forever")



                            class Frequency(Entity):
                                """
                                Group operation frequency
                                
                                .. attribute:: frequency_val
                                
                                	Specify frequency in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range
                                
                                	Group operation frequency\-range for random scheduling
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-sla'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.Frequency, self).__init__()

                                    self.yang_name = "frequency"
                                    self.yang_parent_name = "schedule-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('frequency_val', (YLeaf(YType.uint32, 'frequency-val'), ['int'])),
                                        ('range', (YLeaf(YType.str, 'range'), ['str'])),
                                    ])
                                    self.frequency_val = None
                                    self.range = None
                                    self._segment_path = lambda: "frequency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.Frequency, ['frequency_val', 'range'], name, value)


                            class StartTime(Entity):
                                """
                                When to start this entry
                                
                                .. attribute:: now
                                
                                	Start now
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sla'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.StartTime, self).__init__()

                                    self.yang_name = "start-time"
                                    self.yang_parent_name = "schedule-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('now', (YLeaf(YType.empty, 'now'), ['Empty'])),
                                    ])
                                    self.now = None
                                    self._segment_path = lambda: "start-time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Sla.Group.Schedule.ProbeIds.SchedulePeriod.StartTime, ['now'], name, value)


            class Schedule(Entity):
                """
                Entry Scheduling
                
                .. attribute:: entry_number  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**refers to**\:  :py:class:`number <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Entry>`
                
                .. attribute:: ageout
                
                	How long to keep this Entry when inactive
                	**type**\: int
                
                	**range:** 0..2073600
                
                .. attribute:: life
                
                	Length of time to execute in seconds
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..4294967295
                
                		**type**\:  :py:class:`Life <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Schedule.Life>`
                
                .. attribute:: recurring
                
                	Probe to be scheduled automatically every day
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: start_time
                
                	When to start this entry
                	**type**\:  :py:class:`StartTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Schedule.StartTime>`
                
                

                """

                _prefix = 'ios-sla'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Sla.Schedule, self).__init__()

                    self.yang_name = "schedule"
                    self.yang_parent_name = "sla"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['entry_number']
                    self._child_classes = OrderedDict([("start-time", ("start_time", Native.Ip.Sla.Schedule.StartTime))])
                    self._leafs = OrderedDict([
                        ('entry_number', (YLeaf(YType.str, 'entry-number'), ['int'])),
                        ('ageout', (YLeaf(YType.uint32, 'ageout'), ['int'])),
                        ('life', (YLeaf(YType.str, 'life'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Sla.Schedule.Life')])),
                        ('recurring', (YLeaf(YType.empty, 'recurring'), ['Empty'])),
                    ])
                    self.entry_number = None
                    self.ageout = None
                    self.life = None
                    self.recurring = None

                    self.start_time = Native.Ip.Sla.Schedule.StartTime()
                    self.start_time.parent = self
                    self._children_name_map["start_time"] = "start-time"
                    self._segment_path = lambda: "schedule" + "[entry-number='" + str(self.entry_number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Sla.Schedule, ['entry_number', 'ageout', 'life', 'recurring'], name, value)

                class Life(Enum):
                    """
                    Life (Enum Class)

                    Length of time to execute in seconds

                    .. data:: forever = 0

                    """

                    forever = Enum.YLeaf(0, "forever")



                class StartTime(Entity):
                    """
                    When to start this entry
                    
                    .. attribute:: after
                    
                    	Start after a certain amount of time from now
                    	**type**\: str
                    
                    .. attribute:: hour_min
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: hour_min_sec
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: now
                    
                    	Start now
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pending
                    
                    	Start pending
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: random
                    
                    	Start after random time (range)
                    	**type**\: int
                    
                    	**range:** 500..10000
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Schedule.StartTime, self).__init__()

                        self.yang_name = "start-time"
                        self.yang_parent_name = "schedule"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('after', (YLeaf(YType.str, 'after'), ['str'])),
                            ('hour_min', (YLeaf(YType.str, 'hour-min'), ['str'])),
                            ('hour_min_sec', (YLeaf(YType.str, 'hour-min-sec'), ['str'])),
                            ('now', (YLeaf(YType.empty, 'now'), ['Empty'])),
                            ('pending', (YLeaf(YType.empty, 'pending'), ['Empty'])),
                            ('random', (YLeaf(YType.uint32, 'random'), ['int'])),
                        ])
                        self.after = None
                        self.hour_min = None
                        self.hour_min_sec = None
                        self.now = None
                        self.pending = None
                        self.random = None
                        self._segment_path = lambda: "start-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.Schedule.StartTime, ['after', 'hour_min', 'hour_min_sec', 'now', 'pending', 'random'], name, value)


            class ReactionConfiguration(Entity):
                """
                IP SLA's reaction configuration
                
                .. attribute:: entry_number  (key)
                
                	Entry number
                	**type**\: int
                
                	**range:** 1..2147483647
                
                .. attribute:: react
                
                	
                	**type**\:  :py:class:`React <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.ReactionConfiguration.React>`
                
                

                """

                _prefix = 'ios-sla'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Sla.ReactionConfiguration, self).__init__()

                    self.yang_name = "reaction-configuration"
                    self.yang_parent_name = "sla"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['entry_number']
                    self._child_classes = OrderedDict([("react", ("react", Native.Ip.Sla.ReactionConfiguration.React))])
                    self._leafs = OrderedDict([
                        ('entry_number', (YLeaf(YType.uint64, 'entry-number'), ['int'])),
                    ])
                    self.entry_number = None

                    self.react = Native.Ip.Sla.ReactionConfiguration.React()
                    self.react.parent = self
                    self._children_name_map["react"] = "react"
                    self._segment_path = lambda: "reaction-configuration" + "[entry-number='" + str(self.entry_number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Sla.ReactionConfiguration, ['entry_number'], name, value)


                class React(Entity):
                    """
                    
                    
                    .. attribute:: connectionloss
                    
                    	
                    	**type**\:  :py:class:`ConnectionLoss <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: rtt
                    
                    	
                    	**type**\:  :py:class:`Rtt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.ReactionConfiguration.React.Rtt>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.ReactionConfiguration.React, self).__init__()

                        self.yang_name = "react"
                        self.yang_parent_name = "reaction-configuration"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("connectionLoss", ("connectionloss", Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss)), ("rtt", ("rtt", Native.Ip.Sla.ReactionConfiguration.React.Rtt))])
                        self._leafs = OrderedDict()

                        self.connectionloss = None
                        self._children_name_map["connectionloss"] = "connectionLoss"

                        self.rtt = None
                        self._children_name_map["rtt"] = "rtt"
                        self._segment_path = lambda: "react"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Sla.ReactionConfiguration.React, [], name, value)


                    class ConnectionLoss(Entity):
                        """
                        
                        
                        .. attribute:: threshold_type
                        
                        	
                        	**type**\:  :py:class:`ThresholdType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss, self).__init__()

                            self.yang_name = "connectionLoss"
                            self.yang_parent_name = "react"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold-type", ("threshold_type", Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.threshold_type = Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType()
                            self.threshold_type.parent = self
                            self._children_name_map["threshold_type"] = "threshold-type"
                            self._segment_path = lambda: "connectionLoss"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss, [], name, value)


                        class ThresholdType(Entity):
                            """
                            
                            
                            .. attribute:: xofy
                            
                            	
                            	**type**\:  :py:class:`XOfy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType.XOfy>`
                            
                            

                            """

                            _prefix = 'ios-sla'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType, self).__init__()

                                self.yang_name = "threshold-type"
                                self.yang_parent_name = "connectionLoss"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("xOfy", ("xofy", Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType.XOfy))])
                                self._leafs = OrderedDict()

                                self.xofy = Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType.XOfy()
                                self.xofy.parent = self
                                self._children_name_map["xofy"] = "xOfy"
                                self._segment_path = lambda: "threshold-type"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType, [], name, value)


                            class XOfy(Entity):
                                """
                                
                                
                                .. attribute:: x_val
                                
                                	X value
                                	**type**\: int
                                
                                	**range:** 1..16
                                
                                .. attribute:: y_val
                                
                                	Y value
                                	**type**\: int
                                
                                	**range:** 1..16
                                
                                .. attribute:: action_type
                                
                                	
                                	**type**\:  :py:class:`ActionType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType.XOfy.ActionType>`
                                
                                

                                """

                                _prefix = 'ios-sla'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType.XOfy, self).__init__()

                                    self.yang_name = "xOfy"
                                    self.yang_parent_name = "threshold-type"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('x_val', (YLeaf(YType.uint8, 'x-val'), ['int'])),
                                        ('y_val', (YLeaf(YType.uint8, 'y-val'), ['int'])),
                                        ('action_type', (YLeaf(YType.enumeration, 'action-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType.XOfy.ActionType')])),
                                    ])
                                    self.x_val = None
                                    self.y_val = None
                                    self.action_type = None
                                    self._segment_path = lambda: "xOfy"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ip.Sla.ReactionConfiguration.React.ConnectionLoss.ThresholdType.XOfy, ['x_val', 'y_val', 'action_type'], name, value)

                                class ActionType(Enum):
                                    """
                                    ActionType (Enum Class)

                                    .. data:: none = 0

                                    .. data:: trapAndTrigger = 1

                                    .. data:: trapOnly = 2

                                    .. data:: triggerOnly = 3

                                    """

                                    none = Enum.YLeaf(0, "none")

                                    trapAndTrigger = Enum.YLeaf(1, "trapAndTrigger")

                                    trapOnly = Enum.YLeaf(2, "trapOnly")

                                    triggerOnly = Enum.YLeaf(3, "triggerOnly")



                    class Rtt(Entity):
                        """
                        
                        
                        .. attribute:: threshold_value
                        
                        	
                        	**type**\:  :py:class:`ThresholdValue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.ReactionConfiguration.React.Rtt.ThresholdValue>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sla'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ip.Sla.ReactionConfiguration.React.Rtt, self).__init__()

                            self.yang_name = "rtt"
                            self.yang_parent_name = "react"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold-value", ("threshold_value", Native.Ip.Sla.ReactionConfiguration.React.Rtt.ThresholdValue))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.threshold_value = Native.Ip.Sla.ReactionConfiguration.React.Rtt.ThresholdValue()
                            self.threshold_value.parent = self
                            self._children_name_map["threshold_value"] = "threshold-value"
                            self._segment_path = lambda: "rtt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Sla.ReactionConfiguration.React.Rtt, [], name, value)


                        class ThresholdValue(Entity):
                            """
                            
                            
                            .. attribute:: upper_limit_val
                            
                            	Upper limit
                            	**type**\: int
                            
                            	**range:** 1..60000
                            
                            .. attribute:: lower_limit_val
                            
                            	Lower limit
                            	**type**\: int
                            
                            	**range:** 1..60000
                            
                            .. attribute:: threshold_type
                            
                            	Threshold type
                            	**type**\:  :py:class:`ThresholdType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.ReactionConfiguration.React.Rtt.ThresholdValue.ThresholdType>`
                            
                            .. attribute:: action_type
                            
                            	
                            	**type**\:  :py:class:`ActionType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.ReactionConfiguration.React.Rtt.ThresholdValue.ActionType>`
                            
                            

                            """

                            _prefix = 'ios-sla'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ip.Sla.ReactionConfiguration.React.Rtt.ThresholdValue, self).__init__()

                                self.yang_name = "threshold-value"
                                self.yang_parent_name = "rtt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('upper_limit_val', (YLeaf(YType.uint32, 'upper-limit-val'), ['int'])),
                                    ('lower_limit_val', (YLeaf(YType.uint32, 'lower-limit-val'), ['int'])),
                                    ('threshold_type', (YLeaf(YType.enumeration, 'threshold-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Sla.ReactionConfiguration.React.Rtt.ThresholdValue.ThresholdType')])),
                                    ('action_type', (YLeaf(YType.enumeration, 'action-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Sla.ReactionConfiguration.React.Rtt.ThresholdValue.ActionType')])),
                                ])
                                self.upper_limit_val = None
                                self.lower_limit_val = None
                                self.threshold_type = None
                                self.action_type = None
                                self._segment_path = lambda: "threshold-value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ip.Sla.ReactionConfiguration.React.Rtt.ThresholdValue, ['upper_limit_val', 'lower_limit_val', 'threshold_type', 'action_type'], name, value)

                            class ActionType(Enum):
                                """
                                ActionType (Enum Class)

                                .. data:: none = 0

                                .. data:: trapAndTrigger = 1

                                .. data:: trapOnly = 2

                                .. data:: triggerOnly = 3

                                """

                                none = Enum.YLeaf(0, "none")

                                trapAndTrigger = Enum.YLeaf(1, "trapAndTrigger")

                                trapOnly = Enum.YLeaf(2, "trapOnly")

                                triggerOnly = Enum.YLeaf(3, "triggerOnly")


                            class ThresholdType(Enum):
                                """
                                ThresholdType (Enum Class)

                                Threshold type

                                .. data:: immediate = 0

                                """

                                immediate = Enum.YLeaf(0, "immediate")



            class Server(Entity):
                """
                IPPM server configuration
                
                .. attribute:: twamp
                
                	IPPM TWAMP server configuration
                	**type**\:  :py:class:`Twamp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Sla.Server.Twamp>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-sla'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ip.Sla.Server, self).__init__()

                    self.yang_name = "server"
                    self.yang_parent_name = "sla"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("twamp", ("twamp", Native.Ip.Sla.Server.Twamp))])
                    self._leafs = OrderedDict()

                    self.twamp = None
                    self._children_name_map["twamp"] = "twamp"
                    self._segment_path = lambda: "server"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Sla.Server, [], name, value)


                class Twamp(Entity):
                    """
                    IPPM TWAMP server configuration
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sla'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ip.Sla.Server.Twamp, self).__init__()

                        self.yang_name = "twamp"
                        self.yang_parent_name = "server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "twamp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-sla:sla/server/%s" % self._segment_path()
                        self._is_frozen = True


        class Wccp(Entity):
            """
            Web\-Cache Coordination Protocol IPv4 Commands
            
            .. attribute:: wccp_list
            
            	
            	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.WccpList>`
            
            .. attribute:: source_interface
            
            	Set source interface for Router ID
            	**type**\: str
            
            .. attribute:: web_cache
            
            	Standard web caching service
            	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.WebCache>`
            
            .. attribute:: check
            
            	Enable a WCCP check
            	**type**\:  :py:class:`Check <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Check>`
            
            .. attribute:: vrf
            
            	Configure WCCP for a VRF
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Vrf>`
            
            

            """

            _prefix = 'ios-wccp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Ip.Wccp, self).__init__()

                self.yang_name = "wccp"
                self.yang_parent_name = "ip"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Ip.Wccp.WebCache)), ("check", ("check", Native.Ip.Wccp.Check)), ("vrf", ("vrf", Native.Ip.Wccp.Vrf))])
                self._leafs = OrderedDict([
                    ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                ])
                self.source_interface = None

                self.web_cache = Native.Ip.Wccp.WebCache()
                self.web_cache.parent = self
                self._children_name_map["web_cache"] = "web-cache"

                self.check = Native.Ip.Wccp.Check()
                self.check.parent = self
                self._children_name_map["check"] = "check"

                self.wccp_list = YList(self)
                self.vrf = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ip.Wccp, ['source_interface'], name, value)


            class WccpList(Entity):
                """
                
                
                .. attribute:: id  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..254
                
                .. attribute:: group_address
                
                	Set the multicast group
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: group_list
                
                	Set the access\-list used to permit group membership
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..199 \| 1300..2699
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: mode
                
                	Set the service mode
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.WccpList.Mode>`
                
                .. attribute:: password
                
                	Set the authentication password
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.WccpList.Password>`
                
                .. attribute:: redirect_list
                
                	Set the access\-list used to permit redirection
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..199 \| 1300..2699
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: snmp_disabled
                
                	Disable SNMP for WCCP GRE Tunnel
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-wccp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ip.Wccp.WccpList, self).__init__()

                    self.yang_name = "wccp-list"
                    self.yang_parent_name = "wccp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("password", ("password", Native.Ip.Wccp.WccpList.Password))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                        ('group_address', (YLeaf(YType.str, 'group-address'), ['str'])),
                        ('group_list', (YLeaf(YType.str, 'group-list'), ['int','str'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Wccp.WccpList.Mode')])),
                        ('redirect_list', (YLeaf(YType.str, 'redirect-list'), ['int','str'])),
                        ('snmp_disabled', (YLeaf(YType.empty, 'snmp-disabled'), ['Empty'])),
                    ])
                    self.id = None
                    self.group_address = None
                    self.group_list = None
                    self.mode = None
                    self.redirect_list = None
                    self.snmp_disabled = None

                    self.password = Native.Ip.Wccp.WccpList.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "password"
                    self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-wccp:wccp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Wccp.WccpList, ['id', 'group_address', 'group_list', 'mode', 'redirect_list', 'snmp_disabled'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Set the service mode

                    .. data:: closed = 0

                    .. data:: open = 1

                    """

                    closed = Enum.YLeaf(0, "closed")

                    open = Enum.YLeaf(1, "open")



                class Password(Entity):
                    """
                    Set the authentication password
                    
                    .. attribute:: encryption
                    
                    	
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.WccpList.Password.Encryption>`
                    
                    .. attribute:: clear_key
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Wccp.WccpList.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "wccp-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Wccp.WccpList.Password.Encryption')])),
                            ('clear_key', (YLeaf(YType.str, 'clear-key'), ['str'])),
                        ])
                        self.encryption = None
                        self.clear_key = None
                        self._segment_path = lambda: "password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Wccp.WccpList.Password, ['encryption', 'clear_key'], name, value)

                    class Encryption(Enum):
                        """
                        Encryption (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_7 = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_7 = Enum.YLeaf(1, "7")



            class WebCache(Entity):
                """
                Standard web caching service
                
                .. attribute:: group_address
                
                	Set the multicast group
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: group_list
                
                	Set the access\-list used to permit group membership
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..199 \| 1300..2699
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: mode
                
                	Set the service mode
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.WebCache.Mode>`
                
                .. attribute:: password
                
                	Set the authentication password
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.WebCache.Password>`
                
                .. attribute:: redirect_list
                
                	Set the access\-list used to permit redirection
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..199 \| 1300..2699
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: snmp_disabled
                
                	Disable SNMP for WCCP GRE Tunnel
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-wccp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ip.Wccp.WebCache, self).__init__()

                    self.yang_name = "web-cache"
                    self.yang_parent_name = "wccp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("password", ("password", Native.Ip.Wccp.WebCache.Password))])
                    self._leafs = OrderedDict([
                        ('group_address', (YLeaf(YType.str, 'group-address'), ['str'])),
                        ('group_list', (YLeaf(YType.str, 'group-list'), ['int','str'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Wccp.WebCache.Mode')])),
                        ('redirect_list', (YLeaf(YType.str, 'redirect-list'), ['int','str'])),
                        ('snmp_disabled', (YLeaf(YType.empty, 'snmp-disabled'), ['Empty'])),
                    ])
                    self.group_address = None
                    self.group_list = None
                    self.mode = None
                    self.redirect_list = None
                    self.snmp_disabled = None

                    self.password = Native.Ip.Wccp.WebCache.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "password"
                    self._segment_path = lambda: "web-cache"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-wccp:wccp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Wccp.WebCache, ['group_address', 'group_list', 'mode', 'redirect_list', 'snmp_disabled'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Set the service mode

                    .. data:: closed = 0

                    .. data:: open = 1

                    """

                    closed = Enum.YLeaf(0, "closed")

                    open = Enum.YLeaf(1, "open")



                class Password(Entity):
                    """
                    Set the authentication password
                    
                    .. attribute:: encryption
                    
                    	
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.WebCache.Password.Encryption>`
                    
                    .. attribute:: clear_key
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Wccp.WebCache.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "web-cache"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Wccp.WebCache.Password.Encryption')])),
                            ('clear_key', (YLeaf(YType.str, 'clear-key'), ['str'])),
                        ])
                        self.encryption = None
                        self.clear_key = None
                        self._segment_path = lambda: "password"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-wccp:wccp/web-cache/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Wccp.WebCache.Password, ['encryption', 'clear_key'], name, value)

                    class Encryption(Enum):
                        """
                        Encryption (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_7 = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_7 = Enum.YLeaf(1, "7")



            class Check(Entity):
                """
                Enable a WCCP check
                
                .. attribute:: acl
                
                	Enable acl check
                	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Check.Acl>`
                
                .. attribute:: services
                
                	Enable services check
                	**type**\:  :py:class:`Services <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Check.Services>`
                
                

                """

                _prefix = 'ios-wccp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ip.Wccp.Check, self).__init__()

                    self.yang_name = "check"
                    self.yang_parent_name = "wccp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("acl", ("acl", Native.Ip.Wccp.Check.Acl)), ("services", ("services", Native.Ip.Wccp.Check.Services))])
                    self._leafs = OrderedDict()

                    self.acl = Native.Ip.Wccp.Check.Acl()
                    self.acl.parent = self
                    self._children_name_map["acl"] = "acl"

                    self.services = Native.Ip.Wccp.Check.Services()
                    self.services.parent = self
                    self._children_name_map["services"] = "services"
                    self._segment_path = lambda: "check"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-wccp:wccp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Wccp.Check, [], name, value)


                class Acl(Entity):
                    """
                    Enable acl check
                    
                    .. attribute:: outbound
                    
                    	Enable acl check on original outbound interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Wccp.Check.Acl, self).__init__()

                        self.yang_name = "acl"
                        self.yang_parent_name = "check"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('outbound', (YLeaf(YType.empty, 'outbound'), ['Empty'])),
                        ])
                        self.outbound = None
                        self._segment_path = lambda: "acl"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-wccp:wccp/check/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Wccp.Check.Acl, ['outbound'], name, value)


                class Services(Entity):
                    """
                    Enable services check
                    
                    .. attribute:: all
                    
                    	Enable all services check for redirection
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Wccp.Check.Services, self).__init__()

                        self.yang_name = "services"
                        self.yang_parent_name = "check"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "services"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-wccp:wccp/check/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Wccp.Check.Services, ['all'], name, value)


            class Vrf(Entity):
                """
                Configure WCCP for a VRF
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: wccp_list
                
                	
                	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Vrf.WccpList>`
                
                .. attribute:: source_interface
                
                	Set source interface for Router ID
                	**type**\: str
                
                .. attribute:: web_cache
                
                	Standard web caching service
                	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Vrf.WebCache>`
                
                

                """

                _prefix = 'ios-wccp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ip.Wccp.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "wccp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Ip.Wccp.Vrf.WebCache))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                    ])
                    self.name = None
                    self.source_interface = None

                    self.web_cache = Native.Ip.Wccp.Vrf.WebCache()
                    self.web_cache.parent = self
                    self._children_name_map["web_cache"] = "web-cache"

                    self.wccp_list = YList(self)
                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ip/Cisco-IOS-XE-wccp:wccp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ip.Wccp.Vrf, ['name', 'source_interface'], name, value)


                class WccpList(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..254
                    
                    .. attribute:: group_address
                    
                    	Set the multicast group
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_list
                    
                    	Set the access\-list used to permit group membership
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: mode
                    
                    	Set the service mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Vrf.WccpList.Mode>`
                    
                    .. attribute:: password
                    
                    	Set the authentication password
                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Vrf.WccpList.Password>`
                    
                    .. attribute:: redirect_list
                    
                    	Set the access\-list used to permit redirection
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: snmp_disabled
                    
                    	Disable SNMP for WCCP GRE Tunnel
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Wccp.Vrf.WccpList, self).__init__()

                        self.yang_name = "wccp-list"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("password", ("password", Native.Ip.Wccp.Vrf.WccpList.Password))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str'])),
                            ('group_list', (YLeaf(YType.str, 'group-list'), ['int','str'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Wccp.Vrf.WccpList.Mode')])),
                            ('redirect_list', (YLeaf(YType.str, 'redirect-list'), ['int','str'])),
                            ('snmp_disabled', (YLeaf(YType.empty, 'snmp-disabled'), ['Empty'])),
                        ])
                        self.id = None
                        self.group_address = None
                        self.group_list = None
                        self.mode = None
                        self.redirect_list = None
                        self.snmp_disabled = None

                        self.password = Native.Ip.Wccp.Vrf.WccpList.Password()
                        self.password.parent = self
                        self._children_name_map["password"] = "password"
                        self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Wccp.Vrf.WccpList, ['id', 'group_address', 'group_list', 'mode', 'redirect_list', 'snmp_disabled'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        Set the service mode

                        .. data:: closed = 0

                        .. data:: open = 1

                        """

                        closed = Enum.YLeaf(0, "closed")

                        open = Enum.YLeaf(1, "open")



                    class Password(Entity):
                        """
                        Set the authentication password
                        
                        .. attribute:: encryption
                        
                        	
                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Vrf.WccpList.Password.Encryption>`
                        
                        .. attribute:: clear_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Wccp.Vrf.WccpList.Password, self).__init__()

                            self.yang_name = "password"
                            self.yang_parent_name = "wccp-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Wccp.Vrf.WccpList.Password.Encryption')])),
                                ('clear_key', (YLeaf(YType.str, 'clear-key'), ['str'])),
                            ])
                            self.encryption = None
                            self.clear_key = None
                            self._segment_path = lambda: "password"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Wccp.Vrf.WccpList.Password, ['encryption', 'clear_key'], name, value)

                        class Encryption(Enum):
                            """
                            Encryption (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: Y_7 = 1

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_7 = Enum.YLeaf(1, "7")



                class WebCache(Entity):
                    """
                    Standard web caching service
                    
                    .. attribute:: group_address
                    
                    	Set the multicast group
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_list
                    
                    	Set the access\-list used to permit group membership
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: mode
                    
                    	Set the service mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Vrf.WebCache.Mode>`
                    
                    .. attribute:: password
                    
                    	Set the authentication password
                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Vrf.WebCache.Password>`
                    
                    .. attribute:: redirect_list
                    
                    	Set the access\-list used to permit redirection
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: snmp_disabled
                    
                    	Disable SNMP for WCCP GRE Tunnel
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ip.Wccp.Vrf.WebCache, self).__init__()

                        self.yang_name = "web-cache"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password", ("password", Native.Ip.Wccp.Vrf.WebCache.Password))])
                        self._leafs = OrderedDict([
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str'])),
                            ('group_list', (YLeaf(YType.str, 'group-list'), ['int','str'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Wccp.Vrf.WebCache.Mode')])),
                            ('redirect_list', (YLeaf(YType.str, 'redirect-list'), ['int','str'])),
                            ('snmp_disabled', (YLeaf(YType.empty, 'snmp-disabled'), ['Empty'])),
                        ])
                        self.group_address = None
                        self.group_list = None
                        self.mode = None
                        self.redirect_list = None
                        self.snmp_disabled = None

                        self.password = Native.Ip.Wccp.Vrf.WebCache.Password()
                        self.password.parent = self
                        self._children_name_map["password"] = "password"
                        self._segment_path = lambda: "web-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ip.Wccp.Vrf.WebCache, ['group_address', 'group_list', 'mode', 'redirect_list', 'snmp_disabled'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        Set the service mode

                        .. data:: closed = 0

                        .. data:: open = 1

                        """

                        closed = Enum.YLeaf(0, "closed")

                        open = Enum.YLeaf(1, "open")



                    class Password(Entity):
                        """
                        Set the authentication password
                        
                        .. attribute:: encryption
                        
                        	
                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ip.Wccp.Vrf.WebCache.Password.Encryption>`
                        
                        .. attribute:: clear_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ip.Wccp.Vrf.WebCache.Password, self).__init__()

                            self.yang_name = "password"
                            self.yang_parent_name = "web-cache"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ip.Wccp.Vrf.WebCache.Password.Encryption')])),
                                ('clear_key', (YLeaf(YType.str, 'clear-key'), ['str'])),
                            ])
                            self.encryption = None
                            self.clear_key = None
                            self._segment_path = lambda: "password"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ip.Wccp.Vrf.WebCache.Password, ['encryption', 'clear_key'], name, value)

                        class Encryption(Enum):
                            """
                            Encryption (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: Y_7 = 1

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_7 = Enum.YLeaf(1, "7")



    class Mka(Entity):
        """
        MACsec Key Agreement (MKA) configuration
        
        .. attribute:: policy
        
        	Configure MKA Policy
        	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mka.Policy>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Mka, self).__init__()

            self.yang_name = "mka"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-mka:policy", ("policy", Native.Mka.Policy))])
            self._leafs = OrderedDict()

            self.policy = YList(self)
            self._segment_path = lambda: "mka"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Mka, [], name, value)


        class Policy(Entity):
            """
            Configure MKA Policy
            
            .. attribute:: name  (key)
            
            	MKA Policy NAME
            	**type**\: str
            
            .. attribute:: key_server
            
            	Configure MKA key\-server options
            	**type**\:  :py:class:`KeyServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mka.Policy.KeyServer>`
            
            .. attribute:: macsec_cipher_suite
            
            	Cipher Suite for SAK derivation
            	**type**\:  :py:class:`MacsecCipherSuite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mka.Policy.MacsecCipherSuite>`
            
            .. attribute:: confidentiality_offset
            
            	Set the confidentiality offset for MACsec operation
            	**type**\:  :py:class:`ConfidentialityOffset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mka.Policy.ConfidentialityOffset>`
            
            

            """

            _prefix = 'ios-mka'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Mka.Policy, self).__init__()

                self.yang_name = "policy"
                self.yang_parent_name = "mka"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("key-server", ("key_server", Native.Mka.Policy.KeyServer)), ("macsec-cipher-suite", ("macsec_cipher_suite", Native.Mka.Policy.MacsecCipherSuite))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('confidentiality_offset', (YLeaf(YType.enumeration, 'confidentiality-offset'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mka.Policy.ConfidentialityOffset')])),
                ])
                self.name = None
                self.confidentiality_offset = None

                self.key_server = Native.Mka.Policy.KeyServer()
                self.key_server.parent = self
                self._children_name_map["key_server"] = "key-server"

                self.macsec_cipher_suite = Native.Mka.Policy.MacsecCipherSuite()
                self.macsec_cipher_suite.parent = self
                self._children_name_map["macsec_cipher_suite"] = "macsec-cipher-suite"
                self._segment_path = lambda: "Cisco-IOS-XE-mka:policy" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mka/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mka.Policy, ['name', 'confidentiality_offset'], name, value)

            class ConfidentialityOffset(Enum):
                """
                ConfidentialityOffset (Enum Class)

                Set the confidentiality offset for MACsec operation

                .. data:: Y_0 = 0

                .. data:: Y_30 = 1

                .. data:: Y_50 = 2

                """

                Y_0 = Enum.YLeaf(0, "0")

                Y_30 = Enum.YLeaf(1, "30")

                Y_50 = Enum.YLeaf(2, "50")



            class KeyServer(Entity):
                """
                Configure MKA key\-server options
                
                .. attribute:: priority
                
                	Set MKA key\-server priority
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-mka'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Mka.Policy.KeyServer, self).__init__()

                    self.yang_name = "key-server"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                    ])
                    self.priority = None
                    self._segment_path = lambda: "key-server"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mka.Policy.KeyServer, ['priority'], name, value)


            class MacsecCipherSuite(Entity):
                """
                Cipher Suite for SAK derivation
                
                .. attribute:: gcm_aes_128
                
                	GCM\-AES\-128 Cipher Suite
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: gcm_aes_256
                
                	GCM\-AES\-256 Cipher Suite
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-mka'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Mka.Policy.MacsecCipherSuite, self).__init__()

                    self.yang_name = "macsec-cipher-suite"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('gcm_aes_128', (YLeaf(YType.empty, 'gcm-aes-128'), ['Empty'])),
                        ('gcm_aes_256', (YLeaf(YType.empty, 'gcm-aes-256'), ['Empty'])),
                    ])
                    self.gcm_aes_128 = None
                    self.gcm_aes_256 = None
                    self._segment_path = lambda: "macsec-cipher-suite"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mka.Policy.MacsecCipherSuite, ['gcm_aes_128', 'gcm_aes_256'], name, value)


    class Macro(Entity):
        """
        Macro configuration
        
        .. attribute:: global_
        
        	Enter global macro configuration
        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Macro.Global>`
        
        .. attribute:: auto
        
        	Macro autoexecution settings
        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Macro.Auto>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Macro, self).__init__()

            self.yang_name = "macro"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("global", ("global_", Native.Macro.Global)), ("auto", ("auto", Native.Macro.Auto))])
            self._leafs = OrderedDict()

            self.global_ = Native.Macro.Global()
            self.global_.parent = self
            self._children_name_map["global_"] = "global"

            self.auto = Native.Macro.Auto()
            self.auto.parent = self
            self._children_name_map["auto"] = "auto"
            self._segment_path = lambda: "macro"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Macro, [], name, value)


        class Global(Entity):
            """
            Enter global macro configuration
            
            .. attribute:: description
            
            	Macro description of this device
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Macro.Global, self).__init__()

                self.yang_name = "global"
                self.yang_parent_name = "macro"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                ])
                self.description = None
                self._segment_path = lambda: "global"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/macro/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Macro.Global, [u'description'], name, value)


        class Auto(Entity):
            """
            Macro autoexecution settings
            
            .. attribute:: execute
            
            	Map event trigger to macro
            	**type**\: list of  		 :py:class:`Execute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Macro.Auto.Execute>`
            
            .. attribute:: device
            
            	 auto execution configuration
            	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Macro.Auto.Device>`
            
            .. attribute:: global_
            
            	Macro auto execution configuration
            	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Macro.Auto.Global>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Macro.Auto, self).__init__()

                self.yang_name = "auto"
                self.yang_parent_name = "macro"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:execute", ("execute", Native.Macro.Auto.Execute)), ("Cisco-IOS-XE-switch:device", ("device", Native.Macro.Auto.Device)), ("Cisco-IOS-XE-switch:global", ("global_", Native.Macro.Auto.Global))])
                self._leafs = OrderedDict()

                self.device = Native.Macro.Auto.Device()
                self.device.parent = self
                self._children_name_map["device"] = "Cisco-IOS-XE-switch:device"

                self.global_ = Native.Macro.Auto.Global()
                self.global_.parent = self
                self._children_name_map["global_"] = "Cisco-IOS-XE-switch:global"

                self.execute = YList(self)
                self._segment_path = lambda: "auto"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/macro/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Macro.Auto, [], name, value)


            class Execute(Entity):
                """
                Map event trigger to macro
                
                .. attribute:: trigger_event  (key)
                
                	
                	**type**\: str
                
                .. attribute:: builtin
                
                	Display builtin shell functions
                	**type**\:  :py:class:`Builtin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Macro.Auto.Execute.Builtin>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Macro.Auto.Execute, self).__init__()

                    self.yang_name = "execute"
                    self.yang_parent_name = "auto"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['trigger_event']
                    self._child_classes = OrderedDict([("builtin", ("builtin", Native.Macro.Auto.Execute.Builtin))])
                    self._leafs = OrderedDict([
                        ('trigger_event', (YLeaf(YType.str, 'trigger-event'), ['str'])),
                    ])
                    self.trigger_event = None

                    self.builtin = Native.Macro.Auto.Execute.Builtin()
                    self.builtin.parent = self
                    self._children_name_map["builtin"] = "builtin"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:execute" + "[trigger-event='" + str(self.trigger_event) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/macro/auto/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Macro.Auto.Execute, [u'trigger_event'], name, value)


                class Builtin(Entity):
                    """
                    Display builtin shell functions
                    
                    .. attribute:: smart_port_configuration
                    
                    	
                    	**type**\:  :py:class:`SmartPortConfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Macro.Auto.Execute.Builtin.SmartPortConfiguration>`
                    
                    .. attribute:: parameters
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Macro.Auto.Execute.Builtin, self).__init__()

                        self.yang_name = "builtin"
                        self.yang_parent_name = "execute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('smart_port_configuration', (YLeaf(YType.enumeration, 'smart-port-configuration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Macro.Auto.Execute.Builtin.SmartPortConfiguration')])),
                            ('parameters', (YLeaf(YType.str, 'parameters'), ['str'])),
                        ])
                        self.smart_port_configuration = None
                        self.parameters = None
                        self._segment_path = lambda: "builtin"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Macro.Auto.Execute.Builtin, [u'smart_port_configuration', u'parameters'], name, value)

                    class SmartPortConfiguration(Enum):
                        """
                        SmartPortConfiguration (Enum Class)

                        .. data:: CISCO_AP_AUTO_SMARTPORT = 0

                        .. data:: CISCO_DMP_AUTO_SMARTPORT = 1

                        .. data:: CISCO_DMP_AUTO_SMARTPORT_V1 = 2

                        .. data:: CISCO_IP_CAMERA_AUTO_SMARTPORT = 3

                        .. data:: CISCO_LAST_RESORT_SMARTPORT = 4

                        .. data:: CISCO_LIGHT_AUTO_SMARTPORT = 5

                        .. data:: CISCO_LWAP_AUTO_SMARTPORT = 6

                        .. data:: CISCO_PHONE_AUTO_SMARTPORT = 7

                        .. data:: CISCO_PHONE_AUTO_SMARTPORT_V1 = 8

                        .. data:: CISCO_ROUTER_AUTO_SMARTPORT = 9

                        .. data:: CISCO_SWITCH_AUTO_SMARTPORT = 10

                        .. data:: MS_IP_CAMERA_AUTO_SMARTPORT = 11

                        .. data:: MS_VIDEO_CONF_AUTO_SMARTPORT = 12

                        """

                        CISCO_AP_AUTO_SMARTPORT = Enum.YLeaf(0, "CISCO_AP_AUTO_SMARTPORT")

                        CISCO_DMP_AUTO_SMARTPORT = Enum.YLeaf(1, "CISCO_DMP_AUTO_SMARTPORT")

                        CISCO_DMP_AUTO_SMARTPORT_V1 = Enum.YLeaf(2, "CISCO_DMP_AUTO_SMARTPORT_V1")

                        CISCO_IP_CAMERA_AUTO_SMARTPORT = Enum.YLeaf(3, "CISCO_IP_CAMERA_AUTO_SMARTPORT")

                        CISCO_LAST_RESORT_SMARTPORT = Enum.YLeaf(4, "CISCO_LAST_RESORT_SMARTPORT")

                        CISCO_LIGHT_AUTO_SMARTPORT = Enum.YLeaf(5, "CISCO_LIGHT_AUTO_SMARTPORT")

                        CISCO_LWAP_AUTO_SMARTPORT = Enum.YLeaf(6, "CISCO_LWAP_AUTO_SMARTPORT")

                        CISCO_PHONE_AUTO_SMARTPORT = Enum.YLeaf(7, "CISCO_PHONE_AUTO_SMARTPORT")

                        CISCO_PHONE_AUTO_SMARTPORT_V1 = Enum.YLeaf(8, "CISCO_PHONE_AUTO_SMARTPORT_V1")

                        CISCO_ROUTER_AUTO_SMARTPORT = Enum.YLeaf(9, "CISCO_ROUTER_AUTO_SMARTPORT")

                        CISCO_SWITCH_AUTO_SMARTPORT = Enum.YLeaf(10, "CISCO_SWITCH_AUTO_SMARTPORT")

                        MS_IP_CAMERA_AUTO_SMARTPORT = Enum.YLeaf(11, "MS_IP_CAMERA_AUTO_SMARTPORT")

                        MS_VIDEO_CONF_AUTO_SMARTPORT = Enum.YLeaf(12, "MS_VIDEO_CONF_AUTO_SMARTPORT")



            class Device(Entity):
                """
                 auto execution configuration
                
                .. attribute:: media_player
                
                	digital media player for auto config
                	**type**\: str
                
                .. attribute:: ip_camera
                
                	video surveillance camera for auto config
                	**type**\: str
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Macro.Auto.Device, self).__init__()

                    self.yang_name = "device"
                    self.yang_parent_name = "auto"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('media_player', (YLeaf(YType.str, 'media-player'), ['str'])),
                        ('ip_camera', (YLeaf(YType.str, 'ip-camera'), ['str'])),
                    ])
                    self.media_player = None
                    self.ip_camera = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:device"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/macro/auto/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Macro.Auto.Device, [u'media_player', u'ip_camera'], name, value)


            class Global(Entity):
                """
                Macro auto execution configuration
                
                .. attribute:: processing
                
                	Enable auto smartports, all ports enabled by default
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Macro.Auto.Global, self).__init__()

                    self.yang_name = "global"
                    self.yang_parent_name = "auto"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('processing', (YLeaf(YType.empty, 'processing'), ['Empty'])),
                    ])
                    self.processing = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:global"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/macro/auto/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Macro.Auto.Global, [u'processing'], name, value)


    class Ipv6(Entity):
        """
        Global IPv6 configuration commands
        
        .. attribute:: source_guard
        
        	Configure IPv6 sourceguard
        	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.SourceGuard>`
        
        .. attribute:: destination_guard
        
        	Configure Destination guard
        	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.DestinationGuard>`
        
        .. attribute:: dhcp
        
        	IPv6 DHCP
        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp>`
        
        .. attribute:: access_list
        
        	Configure access lists
        	**type**\:  :py:class:`AccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList>`
        
        .. attribute:: flowset
        
        	Set flow label random for originated packets
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: unicast_routing
        
        	Enable unicast routing
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: multicast
        
        	Configure multicast related commands
        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Multicast>`
        
        .. attribute:: cef
        
        	Cisco Express Forwarding
        	**type**\:  :py:class:`Cef <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef>`
        
        	**presence node**\: True
        
        .. attribute:: nd
        
        	Configure IPv6 ND
        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd>`
        
        .. attribute:: pim
        
        	Configure Protocol Independent Multicast
        	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Pim>`
        
        .. attribute:: route
        
        	Configure static routes
        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Route>`
        
        .. attribute:: router
        
        	Enable an IPV6 routing process
        	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router>`
        
        .. attribute:: source_route
        
        	Process packets with source routing header options
        	**type**\: bool
        
        .. attribute:: spd
        
        	spd
        	**type**\:  :py:class:`Spd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Spd>`
        
        .. attribute:: prefix_list
        
        	Build a prefix list
        	**type**\:  :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.PrefixList>`
        
        .. attribute:: neighbor
        
        	Neighbor
        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Neighbor>`
        
        .. attribute:: mld
        
        	Global mld commands
        	**type**\:  :py:class:`Mld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Mld>`
        
        .. attribute:: multicast_routing
        
        	Enable IPv6 multicast
        	**type**\:  :py:class:`MulticastRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.MulticastRouting>`
        
        	**presence node**\: True
        
        .. attribute:: rip
        
        	Configure ipv6 RIP settings
        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Rip>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Ipv6, self).__init__()

            self.yang_name = "ipv6"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("source-guard", ("source_guard", Native.Ipv6.SourceGuard)), ("destination-guard", ("destination_guard", Native.Ipv6.DestinationGuard)), ("dhcp", ("dhcp", Native.Ipv6.Dhcp)), ("access-list", ("access_list", Native.Ipv6.AccessList)), ("multicast", ("multicast", Native.Ipv6.Multicast)), ("cef", ("cef", Native.Ipv6.Cef)), ("nd", ("nd", Native.Ipv6.Nd)), ("pim", ("pim", Native.Ipv6.Pim)), ("route", ("route", Native.Ipv6.Route)), ("router", ("router", Native.Ipv6.Router)), ("spd", ("spd", Native.Ipv6.Spd)), ("prefix-list", ("prefix_list", Native.Ipv6.PrefixList)), ("neighbor", ("neighbor", Native.Ipv6.Neighbor)), ("Cisco-IOS-XE-mld:mld", ("mld", Native.Ipv6.Mld)), ("Cisco-IOS-XE-multicast:multicast-routing", ("multicast_routing", Native.Ipv6.MulticastRouting)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Ipv6.Rip))])
            self._leafs = OrderedDict([
                ('flowset', (YLeaf(YType.empty, 'flowset'), ['Empty'])),
                ('unicast_routing', (YLeaf(YType.empty, 'unicast-routing'), ['Empty'])),
                ('source_route', (YLeaf(YType.boolean, 'source-route'), ['bool'])),
            ])
            self.flowset = None
            self.unicast_routing = None
            self.source_route = None

            self.source_guard = Native.Ipv6.SourceGuard()
            self.source_guard.parent = self
            self._children_name_map["source_guard"] = "source-guard"

            self.destination_guard = Native.Ipv6.DestinationGuard()
            self.destination_guard.parent = self
            self._children_name_map["destination_guard"] = "destination-guard"

            self.dhcp = Native.Ipv6.Dhcp()
            self.dhcp.parent = self
            self._children_name_map["dhcp"] = "dhcp"

            self.access_list = Native.Ipv6.AccessList()
            self.access_list.parent = self
            self._children_name_map["access_list"] = "access-list"

            self.multicast = Native.Ipv6.Multicast()
            self.multicast.parent = self
            self._children_name_map["multicast"] = "multicast"

            self.cef = None
            self._children_name_map["cef"] = "cef"

            self.nd = Native.Ipv6.Nd()
            self.nd.parent = self
            self._children_name_map["nd"] = "nd"

            self.pim = Native.Ipv6.Pim()
            self.pim.parent = self
            self._children_name_map["pim"] = "pim"

            self.route = Native.Ipv6.Route()
            self.route.parent = self
            self._children_name_map["route"] = "route"

            self.router = Native.Ipv6.Router()
            self.router.parent = self
            self._children_name_map["router"] = "router"

            self.spd = Native.Ipv6.Spd()
            self.spd.parent = self
            self._children_name_map["spd"] = "spd"

            self.prefix_list = Native.Ipv6.PrefixList()
            self.prefix_list.parent = self
            self._children_name_map["prefix_list"] = "prefix-list"

            self.mld = Native.Ipv6.Mld()
            self.mld.parent = self
            self._children_name_map["mld"] = "Cisco-IOS-XE-mld:mld"

            self.multicast_routing = None
            self._children_name_map["multicast_routing"] = "Cisco-IOS-XE-multicast:multicast-routing"

            self.rip = Native.Ipv6.Rip()
            self.rip.parent = self
            self._children_name_map["rip"] = "Cisco-IOS-XE-rip:rip"

            self.neighbor = YList(self)
            self._segment_path = lambda: "ipv6"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Ipv6, [u'flowset', u'unicast_routing', u'source_route'], name, value)


        class SourceGuard(Entity):
            """
            Configure IPv6 sourceguard
            
            .. attribute:: policy
            
            	Configure a policy for feature sourceguard
            	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.SourceGuard.Policy>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.SourceGuard, self).__init__()

                self.yang_name = "source-guard"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("policy", ("policy", Native.Ipv6.SourceGuard.Policy))])
                self._leafs = OrderedDict()

                self.policy = YList(self)
                self._segment_path = lambda: "source-guard"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.SourceGuard, [], name, value)


            class Policy(Entity):
                """
                Configure a policy for feature sourceguard
                
                .. attribute:: source_guard_policy_name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: validate
                
                	Validate the src of the received data traffic
                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.SourceGuard.Policy.Validate>`
                
                .. attribute:: deny
                
                	Block data traffic
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.SourceGuard.Policy.Deny>`
                
                .. attribute:: permit
                
                	Allow data traffic
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.SourceGuard.Policy.Permit>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ipv6.SourceGuard.Policy, self).__init__()

                    self.yang_name = "policy"
                    self.yang_parent_name = "source-guard"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['source_guard_policy_name']
                    self._child_classes = OrderedDict([("validate", ("validate", Native.Ipv6.SourceGuard.Policy.Validate)), ("deny", ("deny", Native.Ipv6.SourceGuard.Policy.Deny)), ("permit", ("permit", Native.Ipv6.SourceGuard.Policy.Permit))])
                    self._leafs = OrderedDict([
                        ('source_guard_policy_name', (YLeaf(YType.str, 'source-guard-policy-name'), ['str'])),
                    ])
                    self.source_guard_policy_name = None

                    self.validate = Native.Ipv6.SourceGuard.Policy.Validate()
                    self.validate.parent = self
                    self._children_name_map["validate"] = "validate"

                    self.deny = Native.Ipv6.SourceGuard.Policy.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.permit = Native.Ipv6.SourceGuard.Policy.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._segment_path = lambda: "policy" + "[source-guard-policy-name='" + str(self.source_guard_policy_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/source-guard/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.SourceGuard.Policy, [u'source_guard_policy_name'], name, value)


                class Validate(Entity):
                    """
                    Validate the src of the received data traffic
                    
                    .. attribute:: address
                    
                    	Validate against addresses learned in NDP/DHCP traffic (default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: prefix
                    
                    	Validate against prefixes learned in RA or DHCP\-PD traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ipv6.SourceGuard.Policy.Validate, self).__init__()

                        self.yang_name = "validate"
                        self.yang_parent_name = "policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.address = None
                        self.prefix = None
                        self._segment_path = lambda: "validate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.SourceGuard.Policy.Validate, [u'address', u'prefix'], name, value)


                class Deny(Entity):
                    """
                    Block data traffic
                    
                    .. attribute:: global_autoconf
                    
                    	Drop data traffic from global autoconfigued addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ipv6.SourceGuard.Policy.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('global_autoconf', (YLeaf(YType.empty, 'global-autoconf'), ['Empty'])),
                        ])
                        self.global_autoconf = None
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.SourceGuard.Policy.Deny, [u'global_autoconf'], name, value)


                class Permit(Entity):
                    """
                    Allow data traffic
                    
                    .. attribute:: link_local
                    
                    	Allow data traffic from all Link\-local addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ipv6.SourceGuard.Policy.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                        ])
                        self.link_local = None
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.SourceGuard.Policy.Permit, [u'link_local'], name, value)


        class DestinationGuard(Entity):
            """
            Configure Destination guard
            
            .. attribute:: policy
            
            	Configure a policy for feature destguard
            	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.DestinationGuard.Policy>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.DestinationGuard, self).__init__()

                self.yang_name = "destination-guard"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("policy", ("policy", Native.Ipv6.DestinationGuard.Policy))])
                self._leafs = OrderedDict()

                self.policy = YList(self)
                self._segment_path = lambda: "destination-guard"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.DestinationGuard, [], name, value)


            class Policy(Entity):
                """
                Configure a policy for feature destguard
                
                .. attribute:: destination_guard_policy_name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: enforcement
                
                	Sets the enforcement level
                	**type**\:  :py:class:`Enforcement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.DestinationGuard.Policy.Enforcement>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ipv6.DestinationGuard.Policy, self).__init__()

                    self.yang_name = "policy"
                    self.yang_parent_name = "destination-guard"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['destination_guard_policy_name']
                    self._child_classes = OrderedDict([("enforcement", ("enforcement", Native.Ipv6.DestinationGuard.Policy.Enforcement))])
                    self._leafs = OrderedDict([
                        ('destination_guard_policy_name', (YLeaf(YType.str, 'destination-guard-policy-name'), ['str'])),
                    ])
                    self.destination_guard_policy_name = None

                    self.enforcement = Native.Ipv6.DestinationGuard.Policy.Enforcement()
                    self.enforcement.parent = self
                    self._children_name_map["enforcement"] = "enforcement"
                    self._segment_path = lambda: "policy" + "[destination-guard-policy-name='" + str(self.destination_guard_policy_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/destination-guard/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.DestinationGuard.Policy, [u'destination_guard_policy_name'], name, value)


                class Enforcement(Entity):
                    """
                    Sets the enforcement level
                    
                    .. attribute:: always
                    
                    	Enforced under all conditions (default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: stressed
                    
                    	Enforced when system is under stress
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ipv6.DestinationGuard.Policy.Enforcement, self).__init__()

                        self.yang_name = "enforcement"
                        self.yang_parent_name = "policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ('stressed', (YLeaf(YType.empty, 'stressed'), ['Empty'])),
                        ])
                        self.always = None
                        self.stressed = None
                        self._segment_path = lambda: "enforcement"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.DestinationGuard.Policy.Enforcement, [u'always', u'stressed'], name, value)


        class Dhcp(Entity):
            """
            IPv6 DHCP
            
            .. attribute:: server
            
            	Configure IPv6 DHCP server
            	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Server>`
            
            .. attribute:: guard
            
            	Configure IPv6 DHCP guard
            	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Guard>`
            
            .. attribute:: pool
            
            	Configure IPv6 DHCP pool
            	**type**\: list of  		 :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.Dhcp, self).__init__()

                self.yang_name = "dhcp"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:server", ("server", Native.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Ipv6.Dhcp.Guard)), ("Cisco-IOS-XE-dhcp:pool", ("pool", Native.Ipv6.Dhcp.Pool))])
                self._leafs = OrderedDict()

                self.server = Native.Ipv6.Dhcp.Server()
                self.server.parent = self
                self._children_name_map["server"] = "Cisco-IOS-XE-dhcp:server"

                self.guard = Native.Ipv6.Dhcp.Guard()
                self.guard.parent = self
                self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                self.pool = YList(self)
                self._segment_path = lambda: "dhcp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.Dhcp, [], name, value)


            class Server(Entity):
                """
                Configure IPv6 DHCP server
                
                .. attribute:: vrf
                
                	Enable VRF Awareness on server
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Server.Vrf>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ipv6.Dhcp.Server, self).__init__()

                    self.yang_name = "server"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ipv6.Dhcp.Server.Vrf))])
                    self._leafs = OrderedDict()

                    self.vrf = Native.Ipv6.Dhcp.Server.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Dhcp.Server, [], name, value)


                class Vrf(Entity):
                    """
                    Enable VRF Awareness on server
                    
                    .. attribute:: enable
                    
                    	Enable Address/PD allocation based on VRF
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ipv6.Dhcp.Server.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/dhcp/Cisco-IOS-XE-dhcp:server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Dhcp.Server.Vrf, ['enable'], name, value)


            class Guard(Entity):
                """
                Configure IPv6 DHCP guard
                
                .. attribute:: policy
                
                	Configure a policy for feature dhcp guard
                	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Guard.Policy>`
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ipv6.Dhcp.Guard, self).__init__()

                    self.yang_name = "guard"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Ipv6.Dhcp.Guard.Policy))])
                    self._leafs = OrderedDict()

                    self.policy = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Dhcp.Guard, [], name, value)


                class Policy(Entity):
                    """
                    Configure a policy for feature dhcp guard
                    
                    .. attribute:: dhcp_guard_policy_name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: device_role
                    
                    	Sets the role of the device attached to the port
                    	**type**\:  :py:class:`DeviceRole <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Guard.Policy.DeviceRole>`
                    
                    .. attribute:: match
                    
                    	dhcp filtering
                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Guard.Policy.Match>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ipv6.Dhcp.Guard.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "guard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['dhcp_guard_policy_name']
                        self._child_classes = OrderedDict([("device-role", ("device_role", Native.Ipv6.Dhcp.Guard.Policy.DeviceRole)), ("match", ("match", Native.Ipv6.Dhcp.Guard.Policy.Match))])
                        self._leafs = OrderedDict([
                            ('dhcp_guard_policy_name', (YLeaf(YType.str, 'dhcp-guard-policy-name'), ['str'])),
                        ])
                        self.dhcp_guard_policy_name = None

                        self.device_role = Native.Ipv6.Dhcp.Guard.Policy.DeviceRole()
                        self.device_role.parent = self
                        self._children_name_map["device_role"] = "device-role"

                        self.match = Native.Ipv6.Dhcp.Guard.Policy.Match()
                        self.match.parent = self
                        self._children_name_map["match"] = "match"
                        self._segment_path = lambda: "policy" + "[dhcp-guard-policy-name='" + str(self.dhcp_guard_policy_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/dhcp/Cisco-IOS-XE-dhcp:guard/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Dhcp.Guard.Policy, ['dhcp_guard_policy_name'], name, value)


                    class DeviceRole(Entity):
                        """
                        Sets the role of the device attached to the port
                        
                        .. attribute:: server
                        
                        	Attached device is a dhcp server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: client
                        
                        	Attached device is a client (default)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ipv6.Dhcp.Guard.Policy.DeviceRole, self).__init__()

                            self.yang_name = "device-role"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.server = None
                            self.client = None
                            self._segment_path = lambda: "device-role"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Dhcp.Guard.Policy.DeviceRole, ['server', 'client'], name, value)


                    class Match(Entity):
                        """
                        dhcp filtering
                        
                        .. attribute:: server
                        
                        	permitted server source addresses
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Guard.Policy.Match.Server>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ipv6.Dhcp.Guard.Policy.Match, self).__init__()

                            self.yang_name = "match"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("server", ("server", Native.Ipv6.Dhcp.Guard.Policy.Match.Server))])
                            self._leafs = OrderedDict()

                            self.server = Native.Ipv6.Dhcp.Guard.Policy.Match.Server()
                            self.server.parent = self
                            self._children_name_map["server"] = "server"
                            self._segment_path = lambda: "match"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Dhcp.Guard.Policy.Match, [], name, value)


                        class Server(Entity):
                            """
                            permitted server source addresses
                            
                            .. attribute:: access_list
                            
                            	specify access\-list for match
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Ipv6.Dhcp.Guard.Policy.Match.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                ])
                                self.access_list = None
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Dhcp.Guard.Policy.Match.Server, ['access_list'], name, value)


            class Pool(Entity):
                """
                Configure IPv6 DHCP pool
                
                .. attribute:: name  (key)
                
                	DHCP pool name
                	**type**\: str
                
                .. attribute:: vrf
                
                	VRF name
                	**type**\: str
                
                .. attribute:: address
                
                	IPv6 address allocation
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.Address>`
                
                .. attribute:: dns_server
                
                	Server's name or IPv6 addres
                	**type**\: union of the below types:
                
                		**type**\: list of str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                		**type**\: list of str
                
                .. attribute:: domain_name
                
                	Domain name to complete unqualified host names
                	**type**\: str
                
                .. attribute:: import_
                
                	Programatically importing DHCP option parameters
                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.Import>`
                
                .. attribute:: link_address
                
                	Link\-address to match
                	**type**\: list of  		 :py:class:`LinkAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.LinkAddress>`
                
                .. attribute:: bootfile_url
                
                	Boot file url
                	**type**\: str
                
                

                """

                _prefix = 'ios-dhcp'
                _revision = '2018-06-16'

                def __init__(self):
                    super(Native.Ipv6.Dhcp.Pool, self).__init__()

                    self.yang_name = "pool"
                    self.yang_parent_name = "dhcp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("address", ("address", Native.Ipv6.Dhcp.Pool.Address)), ("import", ("import_", Native.Ipv6.Dhcp.Pool.Import)), ("link-address", ("link_address", Native.Ipv6.Dhcp.Pool.LinkAddress))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ('dns_server', (YLeafList(YType.str, 'dns-server'), ['str','str'])),
                        ('domain_name', (YLeaf(YType.str, 'domain-name'), ['str'])),
                        ('bootfile_url', (YLeaf(YType.str, 'bootfile-url'), ['str'])),
                    ])
                    self.name = None
                    self.vrf = None
                    self.dns_server = []
                    self.domain_name = None
                    self.bootfile_url = None

                    self.address = Native.Ipv6.Dhcp.Pool.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.import_ = Native.Ipv6.Dhcp.Pool.Import()
                    self.import_.parent = self
                    self._children_name_map["import_"] = "import"

                    self.link_address = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-dhcp:pool" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/dhcp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Dhcp.Pool, ['name', 'vrf', 'dns_server', 'domain_name', 'bootfile_url'], name, value)


                class Address(Entity):
                    """
                    IPv6 address allocation
                    
                    .. attribute:: prefix
                    
                    	IPv6 address allocation prefix
                    	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.Address.Prefix>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ipv6.Dhcp.Pool.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "pool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix", ("prefix", Native.Ipv6.Dhcp.Pool.Address.Prefix))])
                        self._leafs = OrderedDict()

                        self.prefix = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Dhcp.Pool.Address, [], name, value)


                    class Prefix(Entity):
                        """
                        IPv6 address allocation prefix
                        
                        .. attribute:: ipv6_address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: lifetime
                        
                        	Configure prefix lifetimes
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.Address.Prefix.Lifetime>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ipv6.Dhcp.Pool.Address.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv6_address']
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Ipv6.Dhcp.Pool.Address.Prefix.Lifetime))])
                            self._leafs = OrderedDict([
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.ipv6_address = None

                            self.lifetime = Native.Ipv6.Dhcp.Pool.Address.Prefix.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "prefix" + "[ipv6-address='" + str(self.ipv6_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Dhcp.Pool.Address.Prefix, ['ipv6_address'], name, value)


                        class Lifetime(Entity):
                            """
                            Configure prefix lifetimes
                            
                            .. attribute:: valid_lifetime
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\:  :py:class:`ValidLifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.Address.Prefix.Lifetime.ValidLifetime>`
                            
                            .. attribute:: preferred_lifetime
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\:  :py:class:`PreferredLifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.Address.Prefix.Lifetime.PreferredLifetime>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Ipv6.Dhcp.Pool.Address.Prefix.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('valid_lifetime', (YLeaf(YType.str, 'valid-lifetime'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.Dhcp.Pool.Address.Prefix.Lifetime.ValidLifetime')])),
                                    ('preferred_lifetime', (YLeaf(YType.str, 'preferred-lifetime'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.Dhcp.Pool.Address.Prefix.Lifetime.PreferredLifetime')])),
                                ])
                                self.valid_lifetime = None
                                self.preferred_lifetime = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Dhcp.Pool.Address.Prefix.Lifetime, ['valid_lifetime', 'preferred_lifetime'], name, value)

                            class PreferredLifetime(Enum):
                                """
                                PreferredLifetime (Enum Class)

                                .. data:: infinite = 0

                                """

                                infinite = Enum.YLeaf(0, "infinite")


                            class ValidLifetime(Enum):
                                """
                                ValidLifetime (Enum Class)

                                .. data:: infinite = 0

                                """

                                infinite = Enum.YLeaf(0, "infinite")



                class Import(Entity):
                    """
                    Programatically importing DHCP option parameters
                    
                    .. attribute:: all
                    
                    	all DHCP options
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: interface
                    
                    	Specify interface to import options from
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.Import.Interface>`
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ipv6.Dhcp.Pool.Import, self).__init__()

                        self.yang_name = "import"
                        self.yang_parent_name = "pool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Native.Ipv6.Dhcp.Pool.Import.Interface))])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                        ])
                        self.all = None

                        self.interface = Native.Ipv6.Dhcp.Pool.Import.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._segment_path = lambda: "import"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Dhcp.Pool.Import, ['all'], name, value)


                    class Interface(Entity):
                        """
                        Specify interface to import options from
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.Import.Interface.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.Import.Interface.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.Import.Interface.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Dhcp.Pool.Import.Interface.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Ipv6.Dhcp.Pool.Import.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "import"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Ipv6.Dhcp.Pool.Import.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Ipv6.Dhcp.Pool.Import.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Ipv6.Dhcp.Pool.Import.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Ipv6.Dhcp.Pool.Import.Interface.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Ipv6.Dhcp.Pool.Import.Interface.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Ipv6.Dhcp.Pool.Import.Interface.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Ipv6.Dhcp.Pool.Import.Interface.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Ipv6.Dhcp.Pool.Import.Interface.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Dhcp.Pool.Import.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Ipv6.Dhcp.Pool.Import.Interface.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Dhcp.Pool.Import.Interface.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Ipv6.Dhcp.Pool.Import.Interface.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Dhcp.Pool.Import.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Ipv6.Dhcp.Pool.Import.Interface.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Dhcp.Pool.Import.Interface.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Ipv6.Dhcp.Pool.Import.Interface.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Dhcp.Pool.Import.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                class LinkAddress(Entity):
                    """
                    Link\-address to match
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    

                    """

                    _prefix = 'ios-dhcp'
                    _revision = '2018-06-16'

                    def __init__(self):
                        super(Native.Ipv6.Dhcp.Pool.LinkAddress, self).__init__()

                        self.yang_name = "link-address"
                        self.yang_parent_name = "pool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "link-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Dhcp.Pool.LinkAddress, ['address'], name, value)


        class AccessList(Entity):
            """
            Configure access lists
            
            .. attribute:: named_acl
            
            	
            	**type**\: list of  		 :py:class:`NamedAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedAcl>`
            
            .. attribute:: named_rb_acl
            
            	
            	**type**\: list of  		 :py:class:`NamedRbAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl>`
            
            .. attribute:: log_update
            
            	Control access list log updates
            	**type**\:  :py:class:`LogUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.LogUpdate>`
            
            .. attribute:: match_local_traffic
            
            	Match locally\-generated traffic
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.AccessList, self).__init__()

                self.yang_name = "access-list"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-acl:named-acl", ("named_acl", Native.Ipv6.AccessList.NamedAcl)), ("Cisco-IOS-XE-acl:named-rb-acl", ("named_rb_acl", Native.Ipv6.AccessList.NamedRbAcl)), ("Cisco-IOS-XE-acl:log-update", ("log_update", Native.Ipv6.AccessList.LogUpdate))])
                self._leafs = OrderedDict([
                    ('match_local_traffic', (YLeaf(YType.empty, 'Cisco-IOS-XE-acl:match-local-traffic'), ['Empty'])),
                ])
                self.match_local_traffic = None

                self.log_update = Native.Ipv6.AccessList.LogUpdate()
                self.log_update.parent = self
                self._children_name_map["log_update"] = "Cisco-IOS-XE-acl:log-update"

                self.named_acl = YList(self)
                self.named_rb_acl = YList(self)
                self._segment_path = lambda: "access-list"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.AccessList, ['match_local_traffic'], name, value)


            class NamedAcl(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: access_list_seq_rule
                
                	
                	**type**\: list of  		 :py:class:`AccessListSeqRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedAcl.AccessListSeqRule>`
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedAcl.Default>`
                
                

                """

                _prefix = 'ios-acl'
                _revision = '2018-05-31'

                def __init__(self):
                    super(Native.Ipv6.AccessList.NamedAcl, self).__init__()

                    self.yang_name = "named-acl"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("access-list-seq-rule", ("access_list_seq_rule", Native.Ipv6.AccessList.NamedAcl.AccessListSeqRule)), ("default", ("default", Native.Ipv6.AccessList.NamedAcl.Default))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.default = Native.Ipv6.AccessList.NamedAcl.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.access_list_seq_rule = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-acl:named-acl" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/access-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.AccessList.NamedAcl, ['name'], name, value)


                class AccessListSeqRule(Entity):
                    """
                    
                    
                    .. attribute:: sequence  (key)
                    
                    	Sequence number for this entry
                    	**type**\: int
                    
                    	**range:** 1..4294967294
                    
                    .. attribute:: ace_rule
                    
                    	
                    	**type**\:  :py:class:`AceRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedAcl.AccessListSeqRule.AceRule>`
                    
                    .. attribute:: remark
                    
                    	Access list entry comment
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    

                    """

                    _prefix = 'ios-acl'
                    _revision = '2018-05-31'

                    def __init__(self):
                        super(Native.Ipv6.AccessList.NamedAcl.AccessListSeqRule, self).__init__()

                        self.yang_name = "access-list-seq-rule"
                        self.yang_parent_name = "named-acl"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['sequence']
                        self._child_classes = OrderedDict([("ace-rule", ("ace_rule", Native.Ipv6.AccessList.NamedAcl.AccessListSeqRule.AceRule))])
                        self._leafs = OrderedDict([
                            ('sequence', (YLeaf(YType.uint64, 'sequence'), ['int'])),
                            ('remark', (YLeaf(YType.str, 'remark'), ['str'])),
                        ])
                        self.sequence = None
                        self.remark = None

                        self.ace_rule = Native.Ipv6.AccessList.NamedAcl.AccessListSeqRule.AceRule()
                        self.ace_rule.parent = self
                        self._children_name_map["ace_rule"] = "ace-rule"
                        self._segment_path = lambda: "access-list-seq-rule" + "[sequence='" + str(self.sequence) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.AccessList.NamedAcl.AccessListSeqRule, ['sequence', 'remark'], name, value)


                    class AceRule(Entity):
                        """
                        
                        
                        .. attribute:: action
                        
                        	
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedAcl.AccessListSeqRule.AceRule.Action>`
                        
                        .. attribute:: protocol
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..255
                        
                        		**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.Protocol>`
                        
                        .. attribute:: source_host
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: source_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_wildcard_bits
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_prefix
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: any
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: src_eq
                        
                        	Match only packets on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_gt
                        
                        	Match only packets with a greater port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_lt
                        
                        	Match only packets with a lower port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_neq
                        
                        	Match only packets not on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_range1
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_range2
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: destination_host
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: destination_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_wildcard_bits
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_prefix
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: destination_any
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dst_eq
                        
                        	Match only packets on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_gt
                        
                        	Match only packets with a greater port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_lt
                        
                        	Match only packets with a lower port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_neq
                        
                        	Match only packets not on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_range1
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_range2
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: auth
                        
                        	Match on authentication header
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dest_option
                        
                        	Destination Option header (all types)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	Match packets with given dscp value
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..63
                        
                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                        
                        .. attribute:: flow_label
                        
                        	Flow label
                        	**type**\: int
                        
                        	**range:** 0..1048575
                        
                        .. attribute:: fragments
                        
                        	Check non\-initial fragments
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hbh
                        
                        	Match on hop\-by\-hop option
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: log
                        
                        	Log matches against this entry
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: log_input
                        
                        	Log matches against this entry, including input
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mobility
                        
                        	Mobility header (all types)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mobility_type
                        
                        	Mobility header with type
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..255
                        
                        		**type**\:  :py:class:`MobilityType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MobilityType>`
                        
                        .. attribute:: routing
                        
                        	Routing header (all types)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: routing_type
                        
                        	Routing header with type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: time_range
                        
                        	Specify a time\-range
                        	**type**\: str
                        
                        .. attribute:: ack
                        
                        	Match on the ACK bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fin
                        
                        	Match on the FIN bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: psh
                        
                        	Match on the PSH bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rst
                        
                        	Match on the RST bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: syn
                        
                        	Match on the SYN bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: urg
                        
                        	Match on the URG bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: established
                        
                        	Match established connections
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: msg_type_case
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: msg_code
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: named_msg_type
                        
                        	
                        	**type**\:  :py:class:`NamedMsgType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedAcl.AccessListSeqRule.AceRule.NamedMsgType>`
                        
                        

                        """

                        _prefix = 'ios-acl'
                        _revision = '2018-05-31'

                        def __init__(self):
                            super(Native.Ipv6.AccessList.NamedAcl.AccessListSeqRule.AceRule, self).__init__()

                            self.yang_name = "ace-rule"
                            self.yang_parent_name = "access-list-seq-rule"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedAcl.AccessListSeqRule.AceRule.Action')])),
                                ('protocol', (YLeaf(YType.str, 'protocol'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.Protocol')])),
                                ('source_host', (YLeaf(YType.str, 'source-host'), ['str','str','str'])),
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                ('source_wildcard_bits', (YLeaf(YType.str, 'source-wildcard-bits'), ['str'])),
                                ('source_prefix', (YLeaf(YType.str, 'source-prefix'), ['str'])),
                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                ('src_eq', (YLeaf(YType.str, 'src-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_gt', (YLeaf(YType.str, 'src-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_lt', (YLeaf(YType.str, 'src-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_neq', (YLeaf(YType.str, 'src-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_range1', (YLeaf(YType.str, 'src-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_range2', (YLeaf(YType.str, 'src-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('destination_host', (YLeaf(YType.str, 'destination-host'), ['str','str','str'])),
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str'])),
                                ('destination_wildcard_bits', (YLeaf(YType.str, 'destination-wildcard-bits'), ['str'])),
                                ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                ('destination_any', (YLeaf(YType.empty, 'destination-any'), ['Empty'])),
                                ('dst_eq', (YLeaf(YType.str, 'dst-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_gt', (YLeaf(YType.str, 'dst-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_lt', (YLeaf(YType.str, 'dst-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_neq', (YLeaf(YType.str, 'dst-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_range1', (YLeaf(YType.str, 'dst-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_range2', (YLeaf(YType.str, 'dst-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('auth', (YLeaf(YType.empty, 'auth'), ['Empty'])),
                                ('dest_option', (YLeaf(YType.empty, 'dest-option'), ['Empty'])),
                                ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                ('flow_label', (YLeaf(YType.uint32, 'flow-label'), ['int'])),
                                ('fragments', (YLeaf(YType.empty, 'fragments'), ['Empty'])),
                                ('hbh', (YLeaf(YType.empty, 'hbh'), ['Empty'])),
                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ('log_input', (YLeaf(YType.empty, 'log-input'), ['Empty'])),
                                ('mobility', (YLeaf(YType.empty, 'mobility'), ['Empty'])),
                                ('mobility_type', (YLeaf(YType.str, 'mobility-type'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MobilityType', '')])),
                                ('routing', (YLeaf(YType.empty, 'routing'), ['Empty'])),
                                ('routing_type', (YLeaf(YType.uint8, 'routing-type'), ['int'])),
                                ('time_range', (YLeaf(YType.str, 'time-range'), ['str'])),
                                ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                ('established', (YLeaf(YType.empty, 'established'), ['Empty'])),
                                ('msg_type_case', (YLeaf(YType.uint8, 'msg-type-case'), ['int'])),
                                ('msg_code', (YLeaf(YType.uint8, 'msg-code'), ['int'])),
                                ('named_msg_type', (YLeaf(YType.enumeration, 'named-msg-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedAcl.AccessListSeqRule.AceRule.NamedMsgType')])),
                            ])
                            self.action = None
                            self.protocol = None
                            self.source_host = None
                            self.source_address = None
                            self.source_wildcard_bits = None
                            self.source_prefix = None
                            self.any = None
                            self.src_eq = None
                            self.src_gt = None
                            self.src_lt = None
                            self.src_neq = None
                            self.src_range1 = None
                            self.src_range2 = None
                            self.destination_host = None
                            self.destination_address = None
                            self.destination_wildcard_bits = None
                            self.destination_prefix = None
                            self.destination_any = None
                            self.dst_eq = None
                            self.dst_gt = None
                            self.dst_lt = None
                            self.dst_neq = None
                            self.dst_range1 = None
                            self.dst_range2 = None
                            self.auth = None
                            self.dest_option = None
                            self.dscp = None
                            self.flow_label = None
                            self.fragments = None
                            self.hbh = None
                            self.log = None
                            self.log_input = None
                            self.mobility = None
                            self.mobility_type = None
                            self.routing = None
                            self.routing_type = None
                            self.time_range = None
                            self.ack = None
                            self.fin = None
                            self.psh = None
                            self.rst = None
                            self.syn = None
                            self.urg = None
                            self.established = None
                            self.msg_type_case = None
                            self.msg_code = None
                            self.named_msg_type = None
                            self._segment_path = lambda: "ace-rule"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.AccessList.NamedAcl.AccessListSeqRule.AceRule, ['action', 'protocol', 'source_host', 'source_address', 'source_wildcard_bits', 'source_prefix', 'any', 'src_eq', 'src_gt', 'src_lt', 'src_neq', 'src_range1', 'src_range2', 'destination_host', 'destination_address', 'destination_wildcard_bits', 'destination_prefix', 'destination_any', 'dst_eq', 'dst_gt', 'dst_lt', 'dst_neq', 'dst_range1', 'dst_range2', 'auth', 'dest_option', 'dscp', 'flow_label', 'fragments', 'hbh', 'log', 'log_input', 'mobility', 'mobility_type', 'routing', 'routing_type', 'time_range', 'ack', 'fin', 'psh', 'rst', 'syn', 'urg', 'established', 'msg_type_case', 'msg_code', 'named_msg_type'], name, value)

                        class Action(Enum):
                            """
                            Action (Enum Class)

                            .. data:: deny = 0

                            .. data:: permit = 1

                            """

                            deny = Enum.YLeaf(0, "deny")

                            permit = Enum.YLeaf(1, "permit")


                        class NamedMsgType(Enum):
                            """
                            NamedMsgType (Enum Class)

                            .. data:: beyond_scope = 0

                            .. data:: destination_unreachable = 1

                            .. data:: dhaad_reply = 2

                            .. data:: dhaad_request = 3

                            .. data:: echo_reply = 4

                            .. data:: echo_request = 5

                            .. data:: header = 6

                            .. data:: hop_limit = 7

                            .. data:: mld_query = 8

                            .. data:: mld_reduction = 9

                            .. data:: mld_report = 10

                            .. data:: mpd_advertisement = 11

                            .. data:: mpd_solicitation = 12

                            .. data:: nd_na = 13

                            .. data:: nd_ns = 14

                            .. data:: next_header = 15

                            .. data:: no_admin = 16

                            .. data:: no_route = 17

                            .. data:: packet_too_big = 18

                            .. data:: parameter_option = 19

                            .. data:: parameter_problem = 20

                            .. data:: port_unreachable = 21

                            .. data:: reassembly_timeout = 22

                            .. data:: redirect = 23

                            .. data:: reject_route = 24

                            .. data:: renum_command = 25

                            .. data:: renum_result = 26

                            .. data:: renum_seq_number = 27

                            .. data:: router_advertisement = 28

                            .. data:: router_renumbering = 29

                            .. data:: router_solicitation = 30

                            .. data:: source_policy = 31

                            .. data:: time_exceeded = 32

                            .. data:: unreachable = 33

                            """

                            beyond_scope = Enum.YLeaf(0, "beyond-scope")

                            destination_unreachable = Enum.YLeaf(1, "destination-unreachable")

                            dhaad_reply = Enum.YLeaf(2, "dhaad-reply")

                            dhaad_request = Enum.YLeaf(3, "dhaad-request")

                            echo_reply = Enum.YLeaf(4, "echo-reply")

                            echo_request = Enum.YLeaf(5, "echo-request")

                            header = Enum.YLeaf(6, "header")

                            hop_limit = Enum.YLeaf(7, "hop-limit")

                            mld_query = Enum.YLeaf(8, "mld-query")

                            mld_reduction = Enum.YLeaf(9, "mld-reduction")

                            mld_report = Enum.YLeaf(10, "mld-report")

                            mpd_advertisement = Enum.YLeaf(11, "mpd-advertisement")

                            mpd_solicitation = Enum.YLeaf(12, "mpd-solicitation")

                            nd_na = Enum.YLeaf(13, "nd-na")

                            nd_ns = Enum.YLeaf(14, "nd-ns")

                            next_header = Enum.YLeaf(15, "next-header")

                            no_admin = Enum.YLeaf(16, "no-admin")

                            no_route = Enum.YLeaf(17, "no-route")

                            packet_too_big = Enum.YLeaf(18, "packet-too-big")

                            parameter_option = Enum.YLeaf(19, "parameter-option")

                            parameter_problem = Enum.YLeaf(20, "parameter-problem")

                            port_unreachable = Enum.YLeaf(21, "port-unreachable")

                            reassembly_timeout = Enum.YLeaf(22, "reassembly-timeout")

                            redirect = Enum.YLeaf(23, "redirect")

                            reject_route = Enum.YLeaf(24, "reject-route")

                            renum_command = Enum.YLeaf(25, "renum-command")

                            renum_result = Enum.YLeaf(26, "renum-result")

                            renum_seq_number = Enum.YLeaf(27, "renum-seq-number")

                            router_advertisement = Enum.YLeaf(28, "router-advertisement")

                            router_renumbering = Enum.YLeaf(29, "router-renumbering")

                            router_solicitation = Enum.YLeaf(30, "router-solicitation")

                            source_policy = Enum.YLeaf(31, "source-policy")

                            time_exceeded = Enum.YLeaf(32, "time-exceeded")

                            unreachable = Enum.YLeaf(33, "unreachable")


                        class Protocol(Enum):
                            """
                            Protocol (Enum Class)

                            .. data:: ahp = 0

                            .. data:: esp = 1

                            .. data:: hbh = 2

                            .. data:: icmp = 3

                            .. data:: ipv6 = 4

                            .. data:: pcp = 5

                            .. data:: sctp = 6

                            .. data:: tcp = 7

                            .. data:: udp = 8

                            """

                            ahp = Enum.YLeaf(0, "ahp")

                            esp = Enum.YLeaf(1, "esp")

                            hbh = Enum.YLeaf(2, "hbh")

                            icmp = Enum.YLeaf(3, "icmp")

                            ipv6 = Enum.YLeaf(4, "ipv6")

                            pcp = Enum.YLeaf(5, "pcp")

                            sctp = Enum.YLeaf(6, "sctp")

                            tcp = Enum.YLeaf(7, "tcp")

                            udp = Enum.YLeaf(8, "udp")



                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: access_list_seq_rule
                    
                    	
                    	**type**\: list of  		 :py:class:`AccessListSeqRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule>`
                    
                    

                    """

                    _prefix = 'ios-acl'
                    _revision = '2018-05-31'

                    def __init__(self):
                        super(Native.Ipv6.AccessList.NamedAcl.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "named-acl"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-list-seq-rule", ("access_list_seq_rule", Native.Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule))])
                        self._leafs = OrderedDict()

                        self.access_list_seq_rule = YList(self)
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.AccessList.NamedAcl.Default, [], name, value)


                    class AccessListSeqRule(Entity):
                        """
                        
                        
                        .. attribute:: sequence  (key)
                        
                        	Sequence number for this entry
                        	**type**\: int
                        
                        	**range:** 1..4294967294
                        
                        .. attribute:: ace_rule
                        
                        	
                        	**type**\:  :py:class:`AceRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule.AceRule>`
                        
                        .. attribute:: remark
                        
                        	Access list entry comment
                        	**type**\: str
                        
                        	**length:** 1..100
                        
                        

                        """

                        _prefix = 'ios-acl'
                        _revision = '2018-05-31'

                        def __init__(self):
                            super(Native.Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule, self).__init__()

                            self.yang_name = "access-list-seq-rule"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['sequence']
                            self._child_classes = OrderedDict([("ace-rule", ("ace_rule", Native.Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule.AceRule))])
                            self._leafs = OrderedDict([
                                ('sequence', (YLeaf(YType.uint64, 'sequence'), ['int'])),
                                ('remark', (YLeaf(YType.str, 'remark'), ['str'])),
                            ])
                            self.sequence = None
                            self.remark = None

                            self.ace_rule = Native.Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule.AceRule()
                            self.ace_rule.parent = self
                            self._children_name_map["ace_rule"] = "ace-rule"
                            self._segment_path = lambda: "access-list-seq-rule" + "[sequence='" + str(self.sequence) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule, ['sequence', 'remark'], name, value)


                        class AceRule(Entity):
                            """
                            
                            
                            .. attribute:: action
                            
                            	
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule.AceRule.Action>`
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..255
                            
                            		**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.Protocol>`
                            
                            .. attribute:: source_host
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: source_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_wildcard_bits
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_prefix
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: any
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: src_eq
                            
                            	Match only packets on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_gt
                            
                            	Match only packets with a greater port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_lt
                            
                            	Match only packets with a lower port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_neq
                            
                            	Match only packets not on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_range1
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_range2
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: destination_host
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: destination_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_wildcard_bits
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_prefix
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: destination_any
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dst_eq
                            
                            	Match only packets on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_gt
                            
                            	Match only packets with a greater port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_lt
                            
                            	Match only packets with a lower port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_neq
                            
                            	Match only packets not on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_range1
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_range2
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: auth
                            
                            	Match on authentication header
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dest_option
                            
                            	Destination Option header (all types)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	Match packets with given dscp value
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..63
                            
                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                            
                            .. attribute:: flow_label
                            
                            	Flow label
                            	**type**\: int
                            
                            	**range:** 0..1048575
                            
                            .. attribute:: fragments
                            
                            	Check non\-initial fragments
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: hbh
                            
                            	Match on hop\-by\-hop option
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log matches against this entry
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log_input
                            
                            	Log matches against this entry, including input
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mobility
                            
                            	Mobility header (all types)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mobility_type
                            
                            	Mobility header with type
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..255
                            
                            		**type**\:  :py:class:`MobilityType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MobilityType>`
                            
                            .. attribute:: routing
                            
                            	Routing header (all types)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: routing_type
                            
                            	Routing header with type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: time_range
                            
                            	Specify a time\-range
                            	**type**\: str
                            
                            .. attribute:: ack
                            
                            	Match on the ACK bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: fin
                            
                            	Match on the FIN bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: psh
                            
                            	Match on the PSH bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rst
                            
                            	Match on the RST bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: syn
                            
                            	Match on the SYN bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: urg
                            
                            	Match on the URG bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: established
                            
                            	Match established connections
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: msg_type_case
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msg_code
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: named_msg_type
                            
                            	
                            	**type**\:  :py:class:`NamedMsgType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule.AceRule.NamedMsgType>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule.AceRule, self).__init__()

                                self.yang_name = "ace-rule"
                                self.yang_parent_name = "access-list-seq-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule.AceRule.Action')])),
                                    ('protocol', (YLeaf(YType.str, 'protocol'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.Protocol')])),
                                    ('source_host', (YLeaf(YType.str, 'source-host'), ['str','str','str'])),
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                    ('source_wildcard_bits', (YLeaf(YType.str, 'source-wildcard-bits'), ['str'])),
                                    ('source_prefix', (YLeaf(YType.str, 'source-prefix'), ['str'])),
                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                    ('src_eq', (YLeaf(YType.str, 'src-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_gt', (YLeaf(YType.str, 'src-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_lt', (YLeaf(YType.str, 'src-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_neq', (YLeaf(YType.str, 'src-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_range1', (YLeaf(YType.str, 'src-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_range2', (YLeaf(YType.str, 'src-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('destination_host', (YLeaf(YType.str, 'destination-host'), ['str','str','str'])),
                                    ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str'])),
                                    ('destination_wildcard_bits', (YLeaf(YType.str, 'destination-wildcard-bits'), ['str'])),
                                    ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                    ('destination_any', (YLeaf(YType.empty, 'destination-any'), ['Empty'])),
                                    ('dst_eq', (YLeaf(YType.str, 'dst-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_gt', (YLeaf(YType.str, 'dst-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_lt', (YLeaf(YType.str, 'dst-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_neq', (YLeaf(YType.str, 'dst-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_range1', (YLeaf(YType.str, 'dst-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_range2', (YLeaf(YType.str, 'dst-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('auth', (YLeaf(YType.empty, 'auth'), ['Empty'])),
                                    ('dest_option', (YLeaf(YType.empty, 'dest-option'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                    ('flow_label', (YLeaf(YType.uint32, 'flow-label'), ['int'])),
                                    ('fragments', (YLeaf(YType.empty, 'fragments'), ['Empty'])),
                                    ('hbh', (YLeaf(YType.empty, 'hbh'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ('log_input', (YLeaf(YType.empty, 'log-input'), ['Empty'])),
                                    ('mobility', (YLeaf(YType.empty, 'mobility'), ['Empty'])),
                                    ('mobility_type', (YLeaf(YType.str, 'mobility-type'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MobilityType', '')])),
                                    ('routing', (YLeaf(YType.empty, 'routing'), ['Empty'])),
                                    ('routing_type', (YLeaf(YType.uint8, 'routing-type'), ['int'])),
                                    ('time_range', (YLeaf(YType.str, 'time-range'), ['str'])),
                                    ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                    ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                    ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                    ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                    ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                    ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                    ('established', (YLeaf(YType.empty, 'established'), ['Empty'])),
                                    ('msg_type_case', (YLeaf(YType.uint8, 'msg-type-case'), ['int'])),
                                    ('msg_code', (YLeaf(YType.uint8, 'msg-code'), ['int'])),
                                    ('named_msg_type', (YLeaf(YType.enumeration, 'named-msg-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule.AceRule.NamedMsgType')])),
                                ])
                                self.action = None
                                self.protocol = None
                                self.source_host = None
                                self.source_address = None
                                self.source_wildcard_bits = None
                                self.source_prefix = None
                                self.any = None
                                self.src_eq = None
                                self.src_gt = None
                                self.src_lt = None
                                self.src_neq = None
                                self.src_range1 = None
                                self.src_range2 = None
                                self.destination_host = None
                                self.destination_address = None
                                self.destination_wildcard_bits = None
                                self.destination_prefix = None
                                self.destination_any = None
                                self.dst_eq = None
                                self.dst_gt = None
                                self.dst_lt = None
                                self.dst_neq = None
                                self.dst_range1 = None
                                self.dst_range2 = None
                                self.auth = None
                                self.dest_option = None
                                self.dscp = None
                                self.flow_label = None
                                self.fragments = None
                                self.hbh = None
                                self.log = None
                                self.log_input = None
                                self.mobility = None
                                self.mobility_type = None
                                self.routing = None
                                self.routing_type = None
                                self.time_range = None
                                self.ack = None
                                self.fin = None
                                self.psh = None
                                self.rst = None
                                self.syn = None
                                self.urg = None
                                self.established = None
                                self.msg_type_case = None
                                self.msg_code = None
                                self.named_msg_type = None
                                self._segment_path = lambda: "ace-rule"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.AccessList.NamedAcl.Default.AccessListSeqRule.AceRule, ['action', 'protocol', 'source_host', 'source_address', 'source_wildcard_bits', 'source_prefix', 'any', 'src_eq', 'src_gt', 'src_lt', 'src_neq', 'src_range1', 'src_range2', 'destination_host', 'destination_address', 'destination_wildcard_bits', 'destination_prefix', 'destination_any', 'dst_eq', 'dst_gt', 'dst_lt', 'dst_neq', 'dst_range1', 'dst_range2', 'auth', 'dest_option', 'dscp', 'flow_label', 'fragments', 'hbh', 'log', 'log_input', 'mobility', 'mobility_type', 'routing', 'routing_type', 'time_range', 'ack', 'fin', 'psh', 'rst', 'syn', 'urg', 'established', 'msg_type_case', 'msg_code', 'named_msg_type'], name, value)

                            class Action(Enum):
                                """
                                Action (Enum Class)

                                .. data:: deny = 0

                                .. data:: permit = 1

                                """

                                deny = Enum.YLeaf(0, "deny")

                                permit = Enum.YLeaf(1, "permit")


                            class NamedMsgType(Enum):
                                """
                                NamedMsgType (Enum Class)

                                .. data:: beyond_scope = 0

                                .. data:: destination_unreachable = 1

                                .. data:: dhaad_reply = 2

                                .. data:: dhaad_request = 3

                                .. data:: echo_reply = 4

                                .. data:: echo_request = 5

                                .. data:: header = 6

                                .. data:: hop_limit = 7

                                .. data:: mld_query = 8

                                .. data:: mld_reduction = 9

                                .. data:: mld_report = 10

                                .. data:: mpd_advertisement = 11

                                .. data:: mpd_solicitation = 12

                                .. data:: nd_na = 13

                                .. data:: nd_ns = 14

                                .. data:: next_header = 15

                                .. data:: no_admin = 16

                                .. data:: no_route = 17

                                .. data:: packet_too_big = 18

                                .. data:: parameter_option = 19

                                .. data:: parameter_problem = 20

                                .. data:: port_unreachable = 21

                                .. data:: reassembly_timeout = 22

                                .. data:: redirect = 23

                                .. data:: reject_route = 24

                                .. data:: renum_command = 25

                                .. data:: renum_result = 26

                                .. data:: renum_seq_number = 27

                                .. data:: router_advertisement = 28

                                .. data:: router_renumbering = 29

                                .. data:: router_solicitation = 30

                                .. data:: source_policy = 31

                                .. data:: time_exceeded = 32

                                .. data:: unreachable = 33

                                """

                                beyond_scope = Enum.YLeaf(0, "beyond-scope")

                                destination_unreachable = Enum.YLeaf(1, "destination-unreachable")

                                dhaad_reply = Enum.YLeaf(2, "dhaad-reply")

                                dhaad_request = Enum.YLeaf(3, "dhaad-request")

                                echo_reply = Enum.YLeaf(4, "echo-reply")

                                echo_request = Enum.YLeaf(5, "echo-request")

                                header = Enum.YLeaf(6, "header")

                                hop_limit = Enum.YLeaf(7, "hop-limit")

                                mld_query = Enum.YLeaf(8, "mld-query")

                                mld_reduction = Enum.YLeaf(9, "mld-reduction")

                                mld_report = Enum.YLeaf(10, "mld-report")

                                mpd_advertisement = Enum.YLeaf(11, "mpd-advertisement")

                                mpd_solicitation = Enum.YLeaf(12, "mpd-solicitation")

                                nd_na = Enum.YLeaf(13, "nd-na")

                                nd_ns = Enum.YLeaf(14, "nd-ns")

                                next_header = Enum.YLeaf(15, "next-header")

                                no_admin = Enum.YLeaf(16, "no-admin")

                                no_route = Enum.YLeaf(17, "no-route")

                                packet_too_big = Enum.YLeaf(18, "packet-too-big")

                                parameter_option = Enum.YLeaf(19, "parameter-option")

                                parameter_problem = Enum.YLeaf(20, "parameter-problem")

                                port_unreachable = Enum.YLeaf(21, "port-unreachable")

                                reassembly_timeout = Enum.YLeaf(22, "reassembly-timeout")

                                redirect = Enum.YLeaf(23, "redirect")

                                reject_route = Enum.YLeaf(24, "reject-route")

                                renum_command = Enum.YLeaf(25, "renum-command")

                                renum_result = Enum.YLeaf(26, "renum-result")

                                renum_seq_number = Enum.YLeaf(27, "renum-seq-number")

                                router_advertisement = Enum.YLeaf(28, "router-advertisement")

                                router_renumbering = Enum.YLeaf(29, "router-renumbering")

                                router_solicitation = Enum.YLeaf(30, "router-solicitation")

                                source_policy = Enum.YLeaf(31, "source-policy")

                                time_exceeded = Enum.YLeaf(32, "time-exceeded")

                                unreachable = Enum.YLeaf(33, "unreachable")


                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: ahp = 0

                                .. data:: esp = 1

                                .. data:: hbh = 2

                                .. data:: icmp = 3

                                .. data:: ipv6 = 4

                                .. data:: pcp = 5

                                .. data:: sctp = 6

                                .. data:: tcp = 7

                                .. data:: udp = 8

                                """

                                ahp = Enum.YLeaf(0, "ahp")

                                esp = Enum.YLeaf(1, "esp")

                                hbh = Enum.YLeaf(2, "hbh")

                                icmp = Enum.YLeaf(3, "icmp")

                                ipv6 = Enum.YLeaf(4, "ipv6")

                                pcp = Enum.YLeaf(5, "pcp")

                                sctp = Enum.YLeaf(6, "sctp")

                                tcp = Enum.YLeaf(7, "tcp")

                                udp = Enum.YLeaf(8, "udp")



            class NamedRbAcl(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: role_based
                
                	Role\-based Access List
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: access_list_seq_rule
                
                	
                	**type**\: list of  		 :py:class:`AccessListSeqRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.AccessListSeqRule>`
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.Default>`
                
                

                """

                _prefix = 'ios-acl'
                _revision = '2018-05-31'

                def __init__(self):
                    super(Native.Ipv6.AccessList.NamedRbAcl, self).__init__()

                    self.yang_name = "named-rb-acl"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("access-list-seq-rule", ("access_list_seq_rule", Native.Ipv6.AccessList.NamedRbAcl.AccessListSeqRule)), ("default", ("default", Native.Ipv6.AccessList.NamedRbAcl.Default))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('role_based', (YLeaf(YType.empty, 'role-based'), ['Empty'])),
                    ])
                    self.name = None
                    self.role_based = None

                    self.default = Native.Ipv6.AccessList.NamedRbAcl.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.access_list_seq_rule = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-acl:named-rb-acl" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/access-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.AccessList.NamedRbAcl, ['name', 'role_based'], name, value)


                class AccessListSeqRule(Entity):
                    """
                    
                    
                    .. attribute:: sequence  (key)
                    
                    	Sequence number for this entry
                    	**type**\: int
                    
                    	**range:** 1..4294967294
                    
                    .. attribute:: ace_rule
                    
                    	
                    	**type**\:  :py:class:`AceRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.AccessListSeqRule.AceRule>`
                    
                    .. attribute:: remark
                    
                    	Access list entry comment
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    

                    """

                    _prefix = 'ios-acl'
                    _revision = '2018-05-31'

                    def __init__(self):
                        super(Native.Ipv6.AccessList.NamedRbAcl.AccessListSeqRule, self).__init__()

                        self.yang_name = "access-list-seq-rule"
                        self.yang_parent_name = "named-rb-acl"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['sequence']
                        self._child_classes = OrderedDict([("ace-rule", ("ace_rule", Native.Ipv6.AccessList.NamedRbAcl.AccessListSeqRule.AceRule))])
                        self._leafs = OrderedDict([
                            ('sequence', (YLeaf(YType.uint64, 'sequence'), ['int'])),
                            ('remark', (YLeaf(YType.str, 'remark'), ['str'])),
                        ])
                        self.sequence = None
                        self.remark = None

                        self.ace_rule = Native.Ipv6.AccessList.NamedRbAcl.AccessListSeqRule.AceRule()
                        self.ace_rule.parent = self
                        self._children_name_map["ace_rule"] = "ace-rule"
                        self._segment_path = lambda: "access-list-seq-rule" + "[sequence='" + str(self.sequence) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.AccessList.NamedRbAcl.AccessListSeqRule, ['sequence', 'remark'], name, value)


                    class AceRule(Entity):
                        """
                        
                        
                        .. attribute:: action
                        
                        	
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.AccessListSeqRule.AceRule.Action>`
                        
                        .. attribute:: protocol
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..255
                        
                        		**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.Protocol>`
                        
                        .. attribute:: source_host
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: source_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_wildcard_bits
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_prefix
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: any
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: src_eq
                        
                        	Match only packets on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_gt
                        
                        	Match only packets with a greater port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_lt
                        
                        	Match only packets with a lower port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_neq
                        
                        	Match only packets not on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_range1
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: src_range2
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: destination_host
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: destination_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_wildcard_bits
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_prefix
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: destination_any
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dst_eq
                        
                        	Match only packets on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_gt
                        
                        	Match only packets with a greater port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_lt
                        
                        	Match only packets with a lower port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_neq
                        
                        	Match only packets not on a given port number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_range1
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: dst_range2
                        
                        	Match only packets in the range of port numbers
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..65535
                        
                        		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                        
                        .. attribute:: auth
                        
                        	Match on authentication header
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dest_option
                        
                        	Destination Option header (all types)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	Match packets with given dscp value
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..63
                        
                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                        
                        .. attribute:: flow_label
                        
                        	Flow label
                        	**type**\: int
                        
                        	**range:** 0..1048575
                        
                        .. attribute:: fragments
                        
                        	Check non\-initial fragments
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hbh
                        
                        	Match on hop\-by\-hop option
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: log
                        
                        	Log matches against this entry
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: log_input
                        
                        	Log matches against this entry, including input
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mobility
                        
                        	Mobility header (all types)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mobility_type
                        
                        	Mobility header with type
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..255
                        
                        		**type**\:  :py:class:`MobilityType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MobilityType>`
                        
                        .. attribute:: routing
                        
                        	Routing header (all types)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: routing_type
                        
                        	Routing header with type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: time_range
                        
                        	Specify a time\-range
                        	**type**\: str
                        
                        .. attribute:: ack
                        
                        	Match on the ACK bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fin
                        
                        	Match on the FIN bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: psh
                        
                        	Match on the PSH bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rst
                        
                        	Match on the RST bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: syn
                        
                        	Match on the SYN bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: urg
                        
                        	Match on the URG bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: established
                        
                        	Match established connections
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: msg_type_case
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: msg_code
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: named_msg_type
                        
                        	
                        	**type**\:  :py:class:`NamedMsgType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.AccessListSeqRule.AceRule.NamedMsgType>`
                        
                        

                        """

                        _prefix = 'ios-acl'
                        _revision = '2018-05-31'

                        def __init__(self):
                            super(Native.Ipv6.AccessList.NamedRbAcl.AccessListSeqRule.AceRule, self).__init__()

                            self.yang_name = "ace-rule"
                            self.yang_parent_name = "access-list-seq-rule"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedRbAcl.AccessListSeqRule.AceRule.Action')])),
                                ('protocol', (YLeaf(YType.str, 'protocol'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.Protocol')])),
                                ('source_host', (YLeaf(YType.str, 'source-host'), ['str','str','str'])),
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                ('source_wildcard_bits', (YLeaf(YType.str, 'source-wildcard-bits'), ['str'])),
                                ('source_prefix', (YLeaf(YType.str, 'source-prefix'), ['str'])),
                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                ('src_eq', (YLeaf(YType.str, 'src-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_gt', (YLeaf(YType.str, 'src-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_lt', (YLeaf(YType.str, 'src-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_neq', (YLeaf(YType.str, 'src-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_range1', (YLeaf(YType.str, 'src-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('src_range2', (YLeaf(YType.str, 'src-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('destination_host', (YLeaf(YType.str, 'destination-host'), ['str','str','str'])),
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str'])),
                                ('destination_wildcard_bits', (YLeaf(YType.str, 'destination-wildcard-bits'), ['str'])),
                                ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                ('destination_any', (YLeaf(YType.empty, 'destination-any'), ['Empty'])),
                                ('dst_eq', (YLeaf(YType.str, 'dst-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_gt', (YLeaf(YType.str, 'dst-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_lt', (YLeaf(YType.str, 'dst-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_neq', (YLeaf(YType.str, 'dst-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_range1', (YLeaf(YType.str, 'dst-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('dst_range2', (YLeaf(YType.str, 'dst-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                ('auth', (YLeaf(YType.empty, 'auth'), ['Empty'])),
                                ('dest_option', (YLeaf(YType.empty, 'dest-option'), ['Empty'])),
                                ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                ('flow_label', (YLeaf(YType.uint32, 'flow-label'), ['int'])),
                                ('fragments', (YLeaf(YType.empty, 'fragments'), ['Empty'])),
                                ('hbh', (YLeaf(YType.empty, 'hbh'), ['Empty'])),
                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ('log_input', (YLeaf(YType.empty, 'log-input'), ['Empty'])),
                                ('mobility', (YLeaf(YType.empty, 'mobility'), ['Empty'])),
                                ('mobility_type', (YLeaf(YType.str, 'mobility-type'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MobilityType', '')])),
                                ('routing', (YLeaf(YType.empty, 'routing'), ['Empty'])),
                                ('routing_type', (YLeaf(YType.uint8, 'routing-type'), ['int'])),
                                ('time_range', (YLeaf(YType.str, 'time-range'), ['str'])),
                                ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                ('established', (YLeaf(YType.empty, 'established'), ['Empty'])),
                                ('msg_type_case', (YLeaf(YType.uint8, 'msg-type-case'), ['int'])),
                                ('msg_code', (YLeaf(YType.uint8, 'msg-code'), ['int'])),
                                ('named_msg_type', (YLeaf(YType.enumeration, 'named-msg-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedRbAcl.AccessListSeqRule.AceRule.NamedMsgType')])),
                            ])
                            self.action = None
                            self.protocol = None
                            self.source_host = None
                            self.source_address = None
                            self.source_wildcard_bits = None
                            self.source_prefix = None
                            self.any = None
                            self.src_eq = None
                            self.src_gt = None
                            self.src_lt = None
                            self.src_neq = None
                            self.src_range1 = None
                            self.src_range2 = None
                            self.destination_host = None
                            self.destination_address = None
                            self.destination_wildcard_bits = None
                            self.destination_prefix = None
                            self.destination_any = None
                            self.dst_eq = None
                            self.dst_gt = None
                            self.dst_lt = None
                            self.dst_neq = None
                            self.dst_range1 = None
                            self.dst_range2 = None
                            self.auth = None
                            self.dest_option = None
                            self.dscp = None
                            self.flow_label = None
                            self.fragments = None
                            self.hbh = None
                            self.log = None
                            self.log_input = None
                            self.mobility = None
                            self.mobility_type = None
                            self.routing = None
                            self.routing_type = None
                            self.time_range = None
                            self.ack = None
                            self.fin = None
                            self.psh = None
                            self.rst = None
                            self.syn = None
                            self.urg = None
                            self.established = None
                            self.msg_type_case = None
                            self.msg_code = None
                            self.named_msg_type = None
                            self._segment_path = lambda: "ace-rule"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.AccessList.NamedRbAcl.AccessListSeqRule.AceRule, ['action', 'protocol', 'source_host', 'source_address', 'source_wildcard_bits', 'source_prefix', 'any', 'src_eq', 'src_gt', 'src_lt', 'src_neq', 'src_range1', 'src_range2', 'destination_host', 'destination_address', 'destination_wildcard_bits', 'destination_prefix', 'destination_any', 'dst_eq', 'dst_gt', 'dst_lt', 'dst_neq', 'dst_range1', 'dst_range2', 'auth', 'dest_option', 'dscp', 'flow_label', 'fragments', 'hbh', 'log', 'log_input', 'mobility', 'mobility_type', 'routing', 'routing_type', 'time_range', 'ack', 'fin', 'psh', 'rst', 'syn', 'urg', 'established', 'msg_type_case', 'msg_code', 'named_msg_type'], name, value)

                        class Action(Enum):
                            """
                            Action (Enum Class)

                            .. data:: deny = 0

                            .. data:: permit = 1

                            """

                            deny = Enum.YLeaf(0, "deny")

                            permit = Enum.YLeaf(1, "permit")


                        class NamedMsgType(Enum):
                            """
                            NamedMsgType (Enum Class)

                            .. data:: beyond_scope = 0

                            .. data:: destination_unreachable = 1

                            .. data:: dhaad_reply = 2

                            .. data:: dhaad_request = 3

                            .. data:: echo_reply = 4

                            .. data:: echo_request = 5

                            .. data:: header = 6

                            .. data:: hop_limit = 7

                            .. data:: mld_query = 8

                            .. data:: mld_reduction = 9

                            .. data:: mld_report = 10

                            .. data:: mpd_advertisement = 11

                            .. data:: mpd_solicitation = 12

                            .. data:: nd_na = 13

                            .. data:: nd_ns = 14

                            .. data:: next_header = 15

                            .. data:: no_admin = 16

                            .. data:: no_route = 17

                            .. data:: packet_too_big = 18

                            .. data:: parameter_option = 19

                            .. data:: parameter_problem = 20

                            .. data:: port_unreachable = 21

                            .. data:: reassembly_timeout = 22

                            .. data:: redirect = 23

                            .. data:: reject_route = 24

                            .. data:: renum_command = 25

                            .. data:: renum_result = 26

                            .. data:: renum_seq_number = 27

                            .. data:: router_advertisement = 28

                            .. data:: router_renumbering = 29

                            .. data:: router_solicitation = 30

                            .. data:: source_policy = 31

                            .. data:: time_exceeded = 32

                            .. data:: unreachable = 33

                            """

                            beyond_scope = Enum.YLeaf(0, "beyond-scope")

                            destination_unreachable = Enum.YLeaf(1, "destination-unreachable")

                            dhaad_reply = Enum.YLeaf(2, "dhaad-reply")

                            dhaad_request = Enum.YLeaf(3, "dhaad-request")

                            echo_reply = Enum.YLeaf(4, "echo-reply")

                            echo_request = Enum.YLeaf(5, "echo-request")

                            header = Enum.YLeaf(6, "header")

                            hop_limit = Enum.YLeaf(7, "hop-limit")

                            mld_query = Enum.YLeaf(8, "mld-query")

                            mld_reduction = Enum.YLeaf(9, "mld-reduction")

                            mld_report = Enum.YLeaf(10, "mld-report")

                            mpd_advertisement = Enum.YLeaf(11, "mpd-advertisement")

                            mpd_solicitation = Enum.YLeaf(12, "mpd-solicitation")

                            nd_na = Enum.YLeaf(13, "nd-na")

                            nd_ns = Enum.YLeaf(14, "nd-ns")

                            next_header = Enum.YLeaf(15, "next-header")

                            no_admin = Enum.YLeaf(16, "no-admin")

                            no_route = Enum.YLeaf(17, "no-route")

                            packet_too_big = Enum.YLeaf(18, "packet-too-big")

                            parameter_option = Enum.YLeaf(19, "parameter-option")

                            parameter_problem = Enum.YLeaf(20, "parameter-problem")

                            port_unreachable = Enum.YLeaf(21, "port-unreachable")

                            reassembly_timeout = Enum.YLeaf(22, "reassembly-timeout")

                            redirect = Enum.YLeaf(23, "redirect")

                            reject_route = Enum.YLeaf(24, "reject-route")

                            renum_command = Enum.YLeaf(25, "renum-command")

                            renum_result = Enum.YLeaf(26, "renum-result")

                            renum_seq_number = Enum.YLeaf(27, "renum-seq-number")

                            router_advertisement = Enum.YLeaf(28, "router-advertisement")

                            router_renumbering = Enum.YLeaf(29, "router-renumbering")

                            router_solicitation = Enum.YLeaf(30, "router-solicitation")

                            source_policy = Enum.YLeaf(31, "source-policy")

                            time_exceeded = Enum.YLeaf(32, "time-exceeded")

                            unreachable = Enum.YLeaf(33, "unreachable")


                        class Protocol(Enum):
                            """
                            Protocol (Enum Class)

                            .. data:: ahp = 0

                            .. data:: esp = 1

                            .. data:: hbh = 2

                            .. data:: icmp = 3

                            .. data:: ipv6 = 4

                            .. data:: pcp = 5

                            .. data:: sctp = 6

                            .. data:: tcp = 7

                            .. data:: udp = 8

                            """

                            ahp = Enum.YLeaf(0, "ahp")

                            esp = Enum.YLeaf(1, "esp")

                            hbh = Enum.YLeaf(2, "hbh")

                            icmp = Enum.YLeaf(3, "icmp")

                            ipv6 = Enum.YLeaf(4, "ipv6")

                            pcp = Enum.YLeaf(5, "pcp")

                            sctp = Enum.YLeaf(6, "sctp")

                            tcp = Enum.YLeaf(7, "tcp")

                            udp = Enum.YLeaf(8, "udp")



                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: access_list_seq_rule
                    
                    	
                    	**type**\: list of  		 :py:class:`AccessListSeqRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule>`
                    
                    

                    """

                    _prefix = 'ios-acl'
                    _revision = '2018-05-31'

                    def __init__(self):
                        super(Native.Ipv6.AccessList.NamedRbAcl.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "named-rb-acl"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-list-seq-rule", ("access_list_seq_rule", Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule))])
                        self._leafs = OrderedDict()

                        self.access_list_seq_rule = YList(self)
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.AccessList.NamedRbAcl.Default, [], name, value)


                    class AccessListSeqRule(Entity):
                        """
                        
                        
                        .. attribute:: sequence  (key)
                        
                        	Sequence number for this entry
                        	**type**\: int
                        
                        	**range:** 1..4294967294
                        
                        .. attribute:: ace_rule
                        
                        	
                        	**type**\:  :py:class:`AceRule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule>`
                        
                        .. attribute:: remark
                        
                        	Access list entry comment
                        	**type**\: str
                        
                        	**length:** 1..100
                        
                        

                        """

                        _prefix = 'ios-acl'
                        _revision = '2018-05-31'

                        def __init__(self):
                            super(Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule, self).__init__()

                            self.yang_name = "access-list-seq-rule"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['sequence']
                            self._child_classes = OrderedDict([("ace-rule", ("ace_rule", Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule))])
                            self._leafs = OrderedDict([
                                ('sequence', (YLeaf(YType.uint64, 'sequence'), ['int'])),
                                ('remark', (YLeaf(YType.str, 'remark'), ['str'])),
                            ])
                            self.sequence = None
                            self.remark = None

                            self.ace_rule = Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule()
                            self.ace_rule.parent = self
                            self._children_name_map["ace_rule"] = "ace-rule"
                            self._segment_path = lambda: "access-list-seq-rule" + "[sequence='" + str(self.sequence) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule, ['sequence', 'remark'], name, value)


                        class AceRule(Entity):
                            """
                            
                            
                            .. attribute:: action
                            
                            	
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.Action>`
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..255
                            
                            		**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.Protocol>`
                            
                            .. attribute:: source_host
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: source_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_wildcard_bits
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_prefix
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: any
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: src_eq
                            
                            	Match only packets on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_gt
                            
                            	Match only packets with a greater port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_lt
                            
                            	Match only packets with a lower port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_neq
                            
                            	Match only packets not on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_range1
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: src_range2
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: destination_host
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: destination_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_wildcard_bits
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_prefix
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: destination_any
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dst_eq
                            
                            	Match only packets on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_gt
                            
                            	Match only packets with a greater port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_lt
                            
                            	Match only packets with a lower port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_neq
                            
                            	Match only packets not on a given port number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_range1
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: dst_range2
                            
                            	Match only packets in the range of port numbers
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\:  :py:class:`AclPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl.AclPortType>`
                            
                            .. attribute:: auth
                            
                            	Match on authentication header
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dest_option
                            
                            	Destination Option header (all types)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	Match packets with given dscp value
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..63
                            
                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                            
                            .. attribute:: flow_label
                            
                            	Flow label
                            	**type**\: int
                            
                            	**range:** 0..1048575
                            
                            .. attribute:: fragments
                            
                            	Check non\-initial fragments
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: hbh
                            
                            	Match on hop\-by\-hop option
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log matches against this entry
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log_input
                            
                            	Log matches against this entry, including input
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mobility
                            
                            	Mobility header (all types)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mobility_type
                            
                            	Mobility header with type
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..255
                            
                            		**type**\:  :py:class:`MobilityType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MobilityType>`
                            
                            .. attribute:: routing
                            
                            	Routing header (all types)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: routing_type
                            
                            	Routing header with type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: time_range
                            
                            	Specify a time\-range
                            	**type**\: str
                            
                            .. attribute:: ack
                            
                            	Match on the ACK bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: fin
                            
                            	Match on the FIN bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: psh
                            
                            	Match on the PSH bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rst
                            
                            	Match on the RST bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: syn
                            
                            	Match on the SYN bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: urg
                            
                            	Match on the URG bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: established
                            
                            	Match established connections
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: msg_type_case
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msg_code
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: named_msg_type
                            
                            	
                            	**type**\:  :py:class:`NamedMsgType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.NamedMsgType>`
                            
                            

                            """

                            _prefix = 'ios-acl'
                            _revision = '2018-05-31'

                            def __init__(self):
                                super(Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule, self).__init__()

                                self.yang_name = "ace-rule"
                                self.yang_parent_name = "access-list-seq-rule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.Action')])),
                                    ('protocol', (YLeaf(YType.str, 'protocol'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.Protocol')])),
                                    ('source_host', (YLeaf(YType.str, 'source-host'), ['str','str','str'])),
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                    ('source_wildcard_bits', (YLeaf(YType.str, 'source-wildcard-bits'), ['str'])),
                                    ('source_prefix', (YLeaf(YType.str, 'source-prefix'), ['str'])),
                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                    ('src_eq', (YLeaf(YType.str, 'src-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_gt', (YLeaf(YType.str, 'src-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_lt', (YLeaf(YType.str, 'src-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_neq', (YLeaf(YType.str, 'src-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_range1', (YLeaf(YType.str, 'src-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('src_range2', (YLeaf(YType.str, 'src-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('destination_host', (YLeaf(YType.str, 'destination-host'), ['str','str','str'])),
                                    ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str'])),
                                    ('destination_wildcard_bits', (YLeaf(YType.str, 'destination-wildcard-bits'), ['str'])),
                                    ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                    ('destination_any', (YLeaf(YType.empty, 'destination-any'), ['Empty'])),
                                    ('dst_eq', (YLeaf(YType.str, 'dst-eq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_gt', (YLeaf(YType.str, 'dst-gt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_lt', (YLeaf(YType.str, 'dst-lt'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_neq', (YLeaf(YType.str, 'dst-neq'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_range1', (YLeaf(YType.str, 'dst-range1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('dst_range2', (YLeaf(YType.str, 'dst-range2'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_acl', 'AclPortType', '')])),
                                    ('auth', (YLeaf(YType.empty, 'auth'), ['Empty'])),
                                    ('dest_option', (YLeaf(YType.empty, 'dest-option'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                    ('flow_label', (YLeaf(YType.uint32, 'flow-label'), ['int'])),
                                    ('fragments', (YLeaf(YType.empty, 'fragments'), ['Empty'])),
                                    ('hbh', (YLeaf(YType.empty, 'hbh'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ('log_input', (YLeaf(YType.empty, 'log-input'), ['Empty'])),
                                    ('mobility', (YLeaf(YType.empty, 'mobility'), ['Empty'])),
                                    ('mobility_type', (YLeaf(YType.str, 'mobility-type'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MobilityType', '')])),
                                    ('routing', (YLeaf(YType.empty, 'routing'), ['Empty'])),
                                    ('routing_type', (YLeaf(YType.uint8, 'routing-type'), ['int'])),
                                    ('time_range', (YLeaf(YType.str, 'time-range'), ['str'])),
                                    ('ack', (YLeaf(YType.empty, 'ack'), ['Empty'])),
                                    ('fin', (YLeaf(YType.empty, 'fin'), ['Empty'])),
                                    ('psh', (YLeaf(YType.empty, 'psh'), ['Empty'])),
                                    ('rst', (YLeaf(YType.empty, 'rst'), ['Empty'])),
                                    ('syn', (YLeaf(YType.empty, 'syn'), ['Empty'])),
                                    ('urg', (YLeaf(YType.empty, 'urg'), ['Empty'])),
                                    ('established', (YLeaf(YType.empty, 'established'), ['Empty'])),
                                    ('msg_type_case', (YLeaf(YType.uint8, 'msg-type-case'), ['int'])),
                                    ('msg_code', (YLeaf(YType.uint8, 'msg-code'), ['int'])),
                                    ('named_msg_type', (YLeaf(YType.enumeration, 'named-msg-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule.NamedMsgType')])),
                                ])
                                self.action = None
                                self.protocol = None
                                self.source_host = None
                                self.source_address = None
                                self.source_wildcard_bits = None
                                self.source_prefix = None
                                self.any = None
                                self.src_eq = None
                                self.src_gt = None
                                self.src_lt = None
                                self.src_neq = None
                                self.src_range1 = None
                                self.src_range2 = None
                                self.destination_host = None
                                self.destination_address = None
                                self.destination_wildcard_bits = None
                                self.destination_prefix = None
                                self.destination_any = None
                                self.dst_eq = None
                                self.dst_gt = None
                                self.dst_lt = None
                                self.dst_neq = None
                                self.dst_range1 = None
                                self.dst_range2 = None
                                self.auth = None
                                self.dest_option = None
                                self.dscp = None
                                self.flow_label = None
                                self.fragments = None
                                self.hbh = None
                                self.log = None
                                self.log_input = None
                                self.mobility = None
                                self.mobility_type = None
                                self.routing = None
                                self.routing_type = None
                                self.time_range = None
                                self.ack = None
                                self.fin = None
                                self.psh = None
                                self.rst = None
                                self.syn = None
                                self.urg = None
                                self.established = None
                                self.msg_type_case = None
                                self.msg_code = None
                                self.named_msg_type = None
                                self._segment_path = lambda: "ace-rule"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.AccessList.NamedRbAcl.Default.AccessListSeqRule.AceRule, ['action', 'protocol', 'source_host', 'source_address', 'source_wildcard_bits', 'source_prefix', 'any', 'src_eq', 'src_gt', 'src_lt', 'src_neq', 'src_range1', 'src_range2', 'destination_host', 'destination_address', 'destination_wildcard_bits', 'destination_prefix', 'destination_any', 'dst_eq', 'dst_gt', 'dst_lt', 'dst_neq', 'dst_range1', 'dst_range2', 'auth', 'dest_option', 'dscp', 'flow_label', 'fragments', 'hbh', 'log', 'log_input', 'mobility', 'mobility_type', 'routing', 'routing_type', 'time_range', 'ack', 'fin', 'psh', 'rst', 'syn', 'urg', 'established', 'msg_type_case', 'msg_code', 'named_msg_type'], name, value)

                            class Action(Enum):
                                """
                                Action (Enum Class)

                                .. data:: deny = 0

                                .. data:: permit = 1

                                """

                                deny = Enum.YLeaf(0, "deny")

                                permit = Enum.YLeaf(1, "permit")


                            class NamedMsgType(Enum):
                                """
                                NamedMsgType (Enum Class)

                                .. data:: beyond_scope = 0

                                .. data:: destination_unreachable = 1

                                .. data:: dhaad_reply = 2

                                .. data:: dhaad_request = 3

                                .. data:: echo_reply = 4

                                .. data:: echo_request = 5

                                .. data:: header = 6

                                .. data:: hop_limit = 7

                                .. data:: mld_query = 8

                                .. data:: mld_reduction = 9

                                .. data:: mld_report = 10

                                .. data:: mpd_advertisement = 11

                                .. data:: mpd_solicitation = 12

                                .. data:: nd_na = 13

                                .. data:: nd_ns = 14

                                .. data:: next_header = 15

                                .. data:: no_admin = 16

                                .. data:: no_route = 17

                                .. data:: packet_too_big = 18

                                .. data:: parameter_option = 19

                                .. data:: parameter_problem = 20

                                .. data:: port_unreachable = 21

                                .. data:: reassembly_timeout = 22

                                .. data:: redirect = 23

                                .. data:: reject_route = 24

                                .. data:: renum_command = 25

                                .. data:: renum_result = 26

                                .. data:: renum_seq_number = 27

                                .. data:: router_advertisement = 28

                                .. data:: router_renumbering = 29

                                .. data:: router_solicitation = 30

                                .. data:: source_policy = 31

                                .. data:: time_exceeded = 32

                                .. data:: unreachable = 33

                                """

                                beyond_scope = Enum.YLeaf(0, "beyond-scope")

                                destination_unreachable = Enum.YLeaf(1, "destination-unreachable")

                                dhaad_reply = Enum.YLeaf(2, "dhaad-reply")

                                dhaad_request = Enum.YLeaf(3, "dhaad-request")

                                echo_reply = Enum.YLeaf(4, "echo-reply")

                                echo_request = Enum.YLeaf(5, "echo-request")

                                header = Enum.YLeaf(6, "header")

                                hop_limit = Enum.YLeaf(7, "hop-limit")

                                mld_query = Enum.YLeaf(8, "mld-query")

                                mld_reduction = Enum.YLeaf(9, "mld-reduction")

                                mld_report = Enum.YLeaf(10, "mld-report")

                                mpd_advertisement = Enum.YLeaf(11, "mpd-advertisement")

                                mpd_solicitation = Enum.YLeaf(12, "mpd-solicitation")

                                nd_na = Enum.YLeaf(13, "nd-na")

                                nd_ns = Enum.YLeaf(14, "nd-ns")

                                next_header = Enum.YLeaf(15, "next-header")

                                no_admin = Enum.YLeaf(16, "no-admin")

                                no_route = Enum.YLeaf(17, "no-route")

                                packet_too_big = Enum.YLeaf(18, "packet-too-big")

                                parameter_option = Enum.YLeaf(19, "parameter-option")

                                parameter_problem = Enum.YLeaf(20, "parameter-problem")

                                port_unreachable = Enum.YLeaf(21, "port-unreachable")

                                reassembly_timeout = Enum.YLeaf(22, "reassembly-timeout")

                                redirect = Enum.YLeaf(23, "redirect")

                                reject_route = Enum.YLeaf(24, "reject-route")

                                renum_command = Enum.YLeaf(25, "renum-command")

                                renum_result = Enum.YLeaf(26, "renum-result")

                                renum_seq_number = Enum.YLeaf(27, "renum-seq-number")

                                router_advertisement = Enum.YLeaf(28, "router-advertisement")

                                router_renumbering = Enum.YLeaf(29, "router-renumbering")

                                router_solicitation = Enum.YLeaf(30, "router-solicitation")

                                source_policy = Enum.YLeaf(31, "source-policy")

                                time_exceeded = Enum.YLeaf(32, "time-exceeded")

                                unreachable = Enum.YLeaf(33, "unreachable")


                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: ahp = 0

                                .. data:: esp = 1

                                .. data:: hbh = 2

                                .. data:: icmp = 3

                                .. data:: ipv6 = 4

                                .. data:: pcp = 5

                                .. data:: sctp = 6

                                .. data:: tcp = 7

                                .. data:: udp = 8

                                """

                                ahp = Enum.YLeaf(0, "ahp")

                                esp = Enum.YLeaf(1, "esp")

                                hbh = Enum.YLeaf(2, "hbh")

                                icmp = Enum.YLeaf(3, "icmp")

                                ipv6 = Enum.YLeaf(4, "ipv6")

                                pcp = Enum.YLeaf(5, "pcp")

                                sctp = Enum.YLeaf(6, "sctp")

                                tcp = Enum.YLeaf(7, "tcp")

                                udp = Enum.YLeaf(8, "udp")



            class LogUpdate(Entity):
                """
                Control access list log updates
                
                .. attribute:: threshold
                
                	Set access\-list logging threshold
                	**type**\: int
                
                	**range:** 0..2147483647
                
                

                """

                _prefix = 'ios-acl'
                _revision = '2018-05-31'

                def __init__(self):
                    super(Native.Ipv6.AccessList.LogUpdate, self).__init__()

                    self.yang_name = "log-update"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                    ])
                    self.threshold = None
                    self._segment_path = lambda: "Cisco-IOS-XE-acl:log-update"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/access-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.AccessList.LogUpdate, ['threshold'], name, value)


        class Multicast(Entity):
            """
            Configure multicast related commands
            
            .. attribute:: vrf
            
            	Select VPN Routing/Forwarding instance
            	**type**\: str
            
            .. attribute:: rpf
            
            	Configure multicast RPF related commands
            	**type**\:  :py:class:`Rpf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Multicast.Rpf>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.Multicast, self).__init__()

                self.yang_name = "multicast"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:rpf", ("rpf", Native.Ipv6.Multicast.Rpf))])
                self._leafs = OrderedDict([
                    ('vrf', (YLeaf(YType.str, 'Cisco-IOS-XE-multicast:vrf'), ['str'])),
                ])
                self.vrf = None

                self.rpf = Native.Ipv6.Multicast.Rpf()
                self.rpf.parent = self
                self._children_name_map["rpf"] = "Cisco-IOS-XE-multicast:rpf"
                self._segment_path = lambda: "multicast"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.Multicast, ['vrf'], name, value)


            class Rpf(Entity):
                """
                Configure multicast RPF related commands
                
                .. attribute:: backoff
                
                	Backoff delay after unicast routing change
                	**type**\:  :py:class:`Backoff <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Multicast.Rpf.Backoff>`
                
                .. attribute:: use_bgp
                
                	Use BGP routes for multicast RPF lookup
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ipv6.Multicast.Rpf, self).__init__()

                    self.yang_name = "rpf"
                    self.yang_parent_name = "multicast"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("backoff", ("backoff", Native.Ipv6.Multicast.Rpf.Backoff))])
                    self._leafs = OrderedDict([
                        ('use_bgp', (YLeaf(YType.empty, 'use-bgp'), ['Empty'])),
                    ])
                    self.use_bgp = None

                    self.backoff = Native.Ipv6.Multicast.Rpf.Backoff()
                    self.backoff.parent = self
                    self._children_name_map["backoff"] = "backoff"
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:rpf"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/multicast/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Multicast.Rpf, ['use_bgp'], name, value)


                class Backoff(Entity):
                    """
                    Backoff delay after unicast routing change
                    
                    .. attribute:: initial_delay
                    
                    	
                    	**type**\: int
                    
                    	**range:** 200..65535
                    
                    .. attribute:: max_delay
                    
                    	
                    	**type**\: int
                    
                    	**range:** 200..65535
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ipv6.Multicast.Rpf.Backoff, self).__init__()

                        self.yang_name = "backoff"
                        self.yang_parent_name = "rpf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('initial_delay', (YLeaf(YType.uint16, 'initial-delay'), ['int'])),
                            ('max_delay', (YLeaf(YType.uint16, 'max-delay'), ['int'])),
                        ])
                        self.initial_delay = None
                        self.max_delay = None
                        self._segment_path = lambda: "backoff"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/multicast/Cisco-IOS-XE-multicast:rpf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Multicast.Rpf.Backoff, ['initial_delay', 'max_delay'], name, value)


        class Cef(Entity):
            """
            Cisco Express Forwarding
            
            .. attribute:: accounting
            
            	Enable CEF accounting
            	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.Accounting>`
            
            .. attribute:: distributed
            
            	Distributed Cisco Express Forwarding
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: optimize
            
            	Optimizations
            	**type**\:  :py:class:`Optimize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.Optimize>`
            
            .. attribute:: traffic_statistics
            
            	Enable collection of traffic statistics
            	**type**\:  :py:class:`TrafficStatistics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.TrafficStatistics>`
            
            .. attribute:: load_sharing
            
            	Load sharing
            	**type**\:  :py:class:`LoadSharing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.LoadSharing>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.Cef, self).__init__()

                self.yang_name = "cef"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-cef:accounting", ("accounting", Native.Ipv6.Cef.Accounting)), ("Cisco-IOS-XE-cef:optimize", ("optimize", Native.Ipv6.Cef.Optimize)), ("Cisco-IOS-XE-cef:traffic-statistics", ("traffic_statistics", Native.Ipv6.Cef.TrafficStatistics)), ("Cisco-IOS-XE-cef:load-sharing", ("load_sharing", Native.Ipv6.Cef.LoadSharing))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('distributed', (YLeaf(YType.empty, 'Cisco-IOS-XE-cef:distributed'), ['Empty'])),
                ])
                self.distributed = None

                self.accounting = Native.Ipv6.Cef.Accounting()
                self.accounting.parent = self
                self._children_name_map["accounting"] = "Cisco-IOS-XE-cef:accounting"

                self.optimize = Native.Ipv6.Cef.Optimize()
                self.optimize.parent = self
                self._children_name_map["optimize"] = "Cisco-IOS-XE-cef:optimize"

                self.traffic_statistics = Native.Ipv6.Cef.TrafficStatistics()
                self.traffic_statistics.parent = self
                self._children_name_map["traffic_statistics"] = "Cisco-IOS-XE-cef:traffic-statistics"

                self.load_sharing = Native.Ipv6.Cef.LoadSharing()
                self.load_sharing.parent = self
                self._children_name_map["load_sharing"] = "Cisco-IOS-XE-cef:load-sharing"
                self._segment_path = lambda: "cef"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.Cef, ['distributed'], name, value)


            class Accounting(Entity):
                """
                Enable CEF accounting
                
                .. attribute:: per_prefix
                
                	Enable per prefix accounting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: non_recursive
                
                	Enable accounting for traffic through non\-recursive prefixes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: prefix_length
                
                	Enable prefix length accounting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: load_balance_hash
                
                	Enable load balance hash accounting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-cef'
                _revision = '2017-05-19'

                def __init__(self):
                    super(Native.Ipv6.Cef.Accounting, self).__init__()

                    self.yang_name = "accounting"
                    self.yang_parent_name = "cef"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('per_prefix', (YLeaf(YType.empty, 'per-prefix'), ['Empty'])),
                        ('non_recursive', (YLeaf(YType.empty, 'non-recursive'), ['Empty'])),
                        ('prefix_length', (YLeaf(YType.empty, 'prefix-length'), ['Empty'])),
                        ('load_balance_hash', (YLeaf(YType.empty, 'load-balance-hash'), ['Empty'])),
                    ])
                    self.per_prefix = None
                    self.non_recursive = None
                    self.prefix_length = None
                    self.load_balance_hash = None
                    self._segment_path = lambda: "Cisco-IOS-XE-cef:accounting"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Cef.Accounting, ['per_prefix', 'non_recursive', 'prefix_length', 'load_balance_hash'], name, value)


            class Optimize(Entity):
                """
                Optimizations
                
                .. attribute:: neighbor
                
                	Optimizations for directly connected neighbors
                	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.Optimize.Neighbor>`
                
                

                """

                _prefix = 'ios-cef'
                _revision = '2017-05-19'

                def __init__(self):
                    super(Native.Ipv6.Cef.Optimize, self).__init__()

                    self.yang_name = "optimize"
                    self.yang_parent_name = "cef"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Ipv6.Cef.Optimize.Neighbor))])
                    self._leafs = OrderedDict()

                    self.neighbor = Native.Ipv6.Cef.Optimize.Neighbor()
                    self.neighbor.parent = self
                    self._children_name_map["neighbor"] = "neighbor"
                    self._segment_path = lambda: "Cisco-IOS-XE-cef:optimize"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Cef.Optimize, [], name, value)


                class Neighbor(Entity):
                    """
                    Optimizations for directly connected neighbors
                    
                    .. attribute:: resolution
                    
                    	Trigger layer 2 address resolution directly from CEF
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Ipv6.Cef.Optimize.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "optimize"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('resolution', (YLeaf(YType.empty, 'resolution'), ['Empty'])),
                        ])
                        self.resolution = None
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/Cisco-IOS-XE-cef:optimize/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Cef.Optimize.Neighbor, ['resolution'], name, value)


            class TrafficStatistics(Entity):
                """
                Enable collection of traffic statistics
                
                .. attribute:: load_interval
                
                	Specify interval for load calculation
                	**type**\: int
                
                	**range:** 30..600
                
                .. attribute:: update_rate
                
                	Specify update rate for non\-recursive prefix stats
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-cef'
                _revision = '2017-05-19'

                def __init__(self):
                    super(Native.Ipv6.Cef.TrafficStatistics, self).__init__()

                    self.yang_name = "traffic-statistics"
                    self.yang_parent_name = "cef"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                        ('update_rate', (YLeaf(YType.uint16, 'update-rate'), ['int'])),
                    ])
                    self.load_interval = None
                    self.update_rate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-cef:traffic-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Cef.TrafficStatistics, ['load_interval', 'update_rate'], name, value)


            class LoadSharing(Entity):
                """
                Load sharing
                
                .. attribute:: algorithm
                
                	Per\-destination load sharing algorithm selection
                	**type**\:  :py:class:`Algorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.LoadSharing.Algorithm>`
                
                .. attribute:: key_control
                
                	Configure algorithm control values
                	**type**\:  :py:class:`KeyControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.LoadSharing.KeyControl>`
                
                

                """

                _prefix = 'ios-cef'
                _revision = '2017-05-19'

                def __init__(self):
                    super(Native.Ipv6.Cef.LoadSharing, self).__init__()

                    self.yang_name = "load-sharing"
                    self.yang_parent_name = "cef"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("algorithm", ("algorithm", Native.Ipv6.Cef.LoadSharing.Algorithm)), ("key-control", ("key_control", Native.Ipv6.Cef.LoadSharing.KeyControl))])
                    self._leafs = OrderedDict()

                    self.algorithm = Native.Ipv6.Cef.LoadSharing.Algorithm()
                    self.algorithm.parent = self
                    self._children_name_map["algorithm"] = "algorithm"

                    self.key_control = Native.Ipv6.Cef.LoadSharing.KeyControl()
                    self.key_control.parent = self
                    self._children_name_map["key_control"] = "key-control"
                    self._segment_path = lambda: "Cisco-IOS-XE-cef:load-sharing"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Cef.LoadSharing, [], name, value)


                class Algorithm(Entity):
                    """
                    Per\-destination load sharing algorithm selection
                    
                    .. attribute:: tunnel
                    
                    	Algorithm for use in tunnel only environments
                    	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.LoadSharing.Algorithm.Tunnel>`
                    
                    .. attribute:: universal
                    
                    	Algorithm for use in most environments
                    	**type**\:  :py:class:`Universal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.LoadSharing.Algorithm.Universal>`
                    
                    .. attribute:: original
                    
                    	Original algorithm
                    	**type**\:  :py:class:`Original <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.LoadSharing.Algorithm.Original>`
                    
                    .. attribute:: include_ports
                    
                    	Algorithm that includes layer 4 ports
                    	**type**\:  :py:class:`IncludePorts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Ipv6.Cef.LoadSharing.Algorithm, self).__init__()

                        self.yang_name = "algorithm"
                        self.yang_parent_name = "load-sharing"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tunnel", ("tunnel", Native.Ipv6.Cef.LoadSharing.Algorithm.Tunnel)), ("universal", ("universal", Native.Ipv6.Cef.LoadSharing.Algorithm.Universal)), ("original", ("original", Native.Ipv6.Cef.LoadSharing.Algorithm.Original)), ("include-ports", ("include_ports", Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts))])
                        self._leafs = OrderedDict()

                        self.tunnel = Native.Ipv6.Cef.LoadSharing.Algorithm.Tunnel()
                        self.tunnel.parent = self
                        self._children_name_map["tunnel"] = "tunnel"

                        self.universal = Native.Ipv6.Cef.LoadSharing.Algorithm.Universal()
                        self.universal.parent = self
                        self._children_name_map["universal"] = "universal"

                        self.original = Native.Ipv6.Cef.LoadSharing.Algorithm.Original()
                        self.original.parent = self
                        self._children_name_map["original"] = "original"

                        self.include_ports = None
                        self._children_name_map["include_ports"] = "include-ports"
                        self._segment_path = lambda: "algorithm"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/Cisco-IOS-XE-cef:load-sharing/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Cef.LoadSharing.Algorithm, [], name, value)


                    class Tunnel(Entity):
                        """
                        Algorithm for use in tunnel only environments
                        
                        .. attribute:: tunnel
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fixed_id
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{1,8}
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Ipv6.Cef.LoadSharing.Algorithm.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.empty, 'tunnel'), ['Empty'])),
                                ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                            ])
                            self.tunnel = None
                            self.fixed_id = None
                            self._segment_path = lambda: "tunnel"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Cef.LoadSharing.Algorithm.Tunnel, ['tunnel', 'fixed_id'], name, value)


                    class Universal(Entity):
                        """
                        Algorithm for use in most environments
                        
                        .. attribute:: universal
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fixed_id
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{1,8}
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Ipv6.Cef.LoadSharing.Algorithm.Universal, self).__init__()

                            self.yang_name = "universal"
                            self.yang_parent_name = "algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('universal', (YLeaf(YType.empty, 'universal'), ['Empty'])),
                                ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                            ])
                            self.universal = None
                            self.fixed_id = None
                            self._segment_path = lambda: "universal"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Cef.LoadSharing.Algorithm.Universal, ['universal', 'fixed_id'], name, value)


                    class Original(Entity):
                        """
                        Original algorithm
                        
                        .. attribute:: original
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Ipv6.Cef.LoadSharing.Algorithm.Original, self).__init__()

                            self.yang_name = "original"
                            self.yang_parent_name = "algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('original', (YLeaf(YType.empty, 'original'), ['Empty'])),
                            ])
                            self.original = None
                            self._segment_path = lambda: "original"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Cef.LoadSharing.Algorithm.Original, ['original'], name, value)


                    class IncludePorts(Entity):
                        """
                        Algorithm that includes layer 4 ports
                        
                        .. attribute:: destination
                        
                        	Use destination port in hash function
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Destination>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Use source port in hash function
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts, self).__init__()

                            self.yang_name = "include-ports"
                            self.yang_parent_name = "algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Destination)), ("source", ("source", Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.destination = None
                            self._children_name_map["destination"] = "destination"

                            self.source = None
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "include-ports"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts, [], name, value)


                        class Destination(Entity):
                            """
                            Use destination port in hash function
                            
                            .. attribute:: fixed_id
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{1,8}
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-cef'
                            _revision = '2017-05-19'

                            def __init__(self):
                                super(Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "include-ports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                                ])
                                self.fixed_id = None
                                self._segment_path = lambda: "destination"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/include-ports/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Destination, ['fixed_id'], name, value)


                        class Source(Entity):
                            """
                            Use source port in hash function
                            
                            .. attribute:: destination
                            
                            	Use source and destination ports in hash function
                            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: fixed_id
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{1,8}
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-cef'
                            _revision = '2017-05-19'

                            def __init__(self):
                                super(Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "include-ports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("destination", ("destination", Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                                ])
                                self.fixed_id = None

                                self.destination = None
                                self._children_name_map["destination"] = "destination"
                                self._segment_path = lambda: "source"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/include-ports/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source, ['fixed_id'], name, value)


                            class Destination(Entity):
                                """
                                Use source and destination ports in hash function
                                
                                .. attribute:: gtp
                                
                                	Use GTP te\-id as source and destination ports in hash function
                                	**type**\:  :py:class:`Gtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination.Gtp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fixed_id
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{1,8}
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-cef'
                                _revision = '2017-05-19'

                                def __init__(self):
                                    super(Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination, self).__init__()

                                    self.yang_name = "destination"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gtp", ("gtp", Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination.Gtp))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                                    ])
                                    self.fixed_id = None

                                    self.gtp = None
                                    self._children_name_map["gtp"] = "gtp"
                                    self._segment_path = lambda: "destination"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/include-ports/source/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination, ['fixed_id'], name, value)


                                class Gtp(Entity):
                                    """
                                    Use GTP te\-id as source and destination ports in hash function
                                    
                                    .. attribute:: fixed_id
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cef'
                                    _revision = '2017-05-19'

                                    def __init__(self):
                                        super(Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination.Gtp, self).__init__()

                                        self.yang_name = "gtp"
                                        self.yang_parent_name = "destination"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('fixed_id', (YLeaf(YType.str, 'fixed-id'), ['str'])),
                                        ])
                                        self.fixed_id = None
                                        self._segment_path = lambda: "gtp"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/Cisco-IOS-XE-cef:load-sharing/algorithm/include-ports/source/destination/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Cef.LoadSharing.Algorithm.IncludePorts.Source.Destination.Gtp, ['fixed_id'], name, value)


                class KeyControl(Entity):
                    """
                    Configure algorithm control values
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Ipv6.Cef.LoadSharing.KeyControl, self).__init__()

                        self.yang_name = "key-control"
                        self.yang_parent_name = "load-sharing"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "key-control"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/cef/Cisco-IOS-XE-cef:load-sharing/%s" % self._segment_path()
                        self._is_frozen = True


        class Nd(Entity):
            """
            Configure IPv6 ND
            
            .. attribute:: inspection
            
            	Configure NDP Inspection
            	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Inspection>`
            
            .. attribute:: cache
            
            	Cache entry
            	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Cache>`
            
            .. attribute:: raguard
            
            	Configure RA guard
            	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Raguard>`
            
            .. attribute:: default_route
            
            	
            	**type**\:  :py:class:`DefaultRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.DefaultRoute>`
            
            .. attribute:: suppress
            
            	Configure ND multicast suppress
            	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Suppress>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.Nd, self).__init__()

                self.yang_name = "nd"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:inspection", ("inspection", Native.Ipv6.Nd.Inspection)), ("Cisco-IOS-XE-nd:cache", ("cache", Native.Ipv6.Nd.Cache)), ("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:default-route", ("default_route", Native.Ipv6.Nd.DefaultRoute)), ("Cisco-IOS-XE-nd:suppress", ("suppress", Native.Ipv6.Nd.Suppress))])
                self._leafs = OrderedDict()

                self.inspection = Native.Ipv6.Nd.Inspection()
                self.inspection.parent = self
                self._children_name_map["inspection"] = "Cisco-IOS-XE-nd:inspection"

                self.cache = Native.Ipv6.Nd.Cache()
                self.cache.parent = self
                self._children_name_map["cache"] = "Cisco-IOS-XE-nd:cache"

                self.raguard = Native.Ipv6.Nd.Raguard()
                self.raguard.parent = self
                self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                self.default_route = Native.Ipv6.Nd.DefaultRoute()
                self.default_route.parent = self
                self._children_name_map["default_route"] = "Cisco-IOS-XE-nd:default-route"

                self.suppress = Native.Ipv6.Nd.Suppress()
                self.suppress.parent = self
                self._children_name_map["suppress"] = "Cisco-IOS-XE-nd:suppress"
                self._segment_path = lambda: "nd"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.Nd, [], name, value)


            class Inspection(Entity):
                """
                Configure NDP Inspection
                
                .. attribute:: policy
                
                	Configure a policy for feature NDP inspection
                	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Inspection.Policy>`
                
                

                """

                _prefix = 'ios-nd'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ipv6.Nd.Inspection, self).__init__()

                    self.yang_name = "inspection"
                    self.yang_parent_name = "nd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Ipv6.Nd.Inspection.Policy))])
                    self._leafs = OrderedDict()

                    self.policy = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-nd:inspection"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/nd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Nd.Inspection, [], name, value)


                class Policy(Entity):
                    """
                    Configure a policy for feature NDP inspection
                    
                    .. attribute:: name_nd_inspection_policy  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: device_role
                    
                    	Sets the role of the device attached to the port
                    	**type**\:  :py:class:`DeviceRole <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Inspection.Policy.DeviceRole>`
                    
                    .. attribute:: drop_unsecure
                    
                    	drop unsecure (3971) messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: limit
                    
                    	Specifies a limit
                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Inspection.Policy.Limit>`
                    
                    .. attribute:: sec_level
                    
                    	Specifies a minimum sec\-level
                    	**type**\:  :py:class:`SecLevel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Inspection.Policy.SecLevel>`
                    
                    .. attribute:: tracking
                    
                    	Override default tracking behavior
                    	**type**\:  :py:class:`Tracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Inspection.Policy.Tracking>`
                    
                    .. attribute:: trusted_port
                    
                    	setup trusted port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: validate
                    
                    	specific validation
                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Inspection.Policy.Validate>`
                    
                    

                    """

                    _prefix = 'ios-nd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ipv6.Nd.Inspection.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "inspection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name_nd_inspection_policy']
                        self._child_classes = OrderedDict([("device-role", ("device_role", Native.Ipv6.Nd.Inspection.Policy.DeviceRole)), ("limit", ("limit", Native.Ipv6.Nd.Inspection.Policy.Limit)), ("sec-level", ("sec_level", Native.Ipv6.Nd.Inspection.Policy.SecLevel)), ("tracking", ("tracking", Native.Ipv6.Nd.Inspection.Policy.Tracking)), ("validate", ("validate", Native.Ipv6.Nd.Inspection.Policy.Validate))])
                        self._leafs = OrderedDict([
                            ('name_nd_inspection_policy', (YLeaf(YType.str, 'name-nd-inspection-policy'), ['str'])),
                            ('drop_unsecure', (YLeaf(YType.empty, 'drop-unsecure'), ['Empty'])),
                            ('trusted_port', (YLeaf(YType.empty, 'trusted-port'), ['Empty'])),
                        ])
                        self.name_nd_inspection_policy = None
                        self.drop_unsecure = None
                        self.trusted_port = None

                        self.device_role = Native.Ipv6.Nd.Inspection.Policy.DeviceRole()
                        self.device_role.parent = self
                        self._children_name_map["device_role"] = "device-role"

                        self.limit = Native.Ipv6.Nd.Inspection.Policy.Limit()
                        self.limit.parent = self
                        self._children_name_map["limit"] = "limit"

                        self.sec_level = Native.Ipv6.Nd.Inspection.Policy.SecLevel()
                        self.sec_level.parent = self
                        self._children_name_map["sec_level"] = "sec-level"

                        self.tracking = Native.Ipv6.Nd.Inspection.Policy.Tracking()
                        self.tracking.parent = self
                        self._children_name_map["tracking"] = "tracking"

                        self.validate = Native.Ipv6.Nd.Inspection.Policy.Validate()
                        self.validate.parent = self
                        self._children_name_map["validate"] = "validate"
                        self._segment_path = lambda: "policy" + "[name-nd-inspection-policy='" + str(self.name_nd_inspection_policy) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/nd/Cisco-IOS-XE-nd:inspection/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Nd.Inspection.Policy, ['name_nd_inspection_policy', 'drop_unsecure', 'trusted_port'], name, value)


                    class DeviceRole(Entity):
                        """
                        Sets the role of the device attached to the port
                        
                        .. attribute:: host
                        
                        	Attached device is a host (default)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: monitor
                        
                        	Attached device is a monitor/sniffer
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: router
                        
                        	Attached device is a route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: switch
                        
                        	Attached device is a switch
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ipv6.Nd.Inspection.Policy.DeviceRole, self).__init__()

                            self.yang_name = "device-role"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('monitor', (YLeaf(YType.empty, 'monitor'), ['Empty'])),
                                ('router', (YLeaf(YType.empty, 'router'), ['Empty'])),
                                ('switch', (YLeaf(YType.empty, 'switch'), ['Empty'])),
                            ])
                            self.host = None
                            self.monitor = None
                            self.router = None
                            self.switch = None
                            self._segment_path = lambda: "device-role"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Nd.Inspection.Policy.DeviceRole, ['host', 'monitor', 'router', 'switch'], name, value)


                    class Limit(Entity):
                        """
                        Specifies a limit
                        
                        .. attribute:: address_count
                        
                        	Configure maximum address per port
                        	**type**\: int
                        
                        	**range:** 1..10000
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ipv6.Nd.Inspection.Policy.Limit, self).__init__()

                            self.yang_name = "limit"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address_count', (YLeaf(YType.uint16, 'address-count'), ['int'])),
                            ])
                            self.address_count = None
                            self._segment_path = lambda: "limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Nd.Inspection.Policy.Limit, ['address_count'], name, value)


                    class SecLevel(Entity):
                        """
                        Specifies a minimum sec\-level
                        
                        .. attribute:: minimum
                        
                        	Configure minimum sec\-level
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ipv6.Nd.Inspection.Policy.SecLevel, self).__init__()

                            self.yang_name = "sec-level"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('minimum', (YLeaf(YType.uint8, 'minimum'), ['int'])),
                            ])
                            self.minimum = None
                            self._segment_path = lambda: "sec-level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Nd.Inspection.Policy.SecLevel, ['minimum'], name, value)


                    class Tracking(Entity):
                        """
                        Override default tracking behavior
                        
                        .. attribute:: disable
                        
                        	Tracking off
                        	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Inspection.Policy.Tracking.Disable>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: enable
                        
                        	Tracking on
                        	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Inspection.Policy.Tracking.Enable>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ipv6.Nd.Inspection.Policy.Tracking, self).__init__()

                            self.yang_name = "tracking"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("disable", ("disable", Native.Ipv6.Nd.Inspection.Policy.Tracking.Disable)), ("enable", ("enable", Native.Ipv6.Nd.Inspection.Policy.Tracking.Enable))])
                            self._leafs = OrderedDict()

                            self.disable = None
                            self._children_name_map["disable"] = "disable"

                            self.enable = None
                            self._children_name_map["enable"] = "enable"
                            self._segment_path = lambda: "tracking"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Nd.Inspection.Policy.Tracking, [], name, value)


                        class Disable(Entity):
                            """
                            Tracking off
                            
                            .. attribute:: stale_lifetime
                            
                            	Time entry is kept inactive before delete
                            	**type**\:  :py:class:`StaleLifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Inspection.Policy.Tracking.Disable.StaleLifetime>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Ipv6.Nd.Inspection.Policy.Tracking.Disable, self).__init__()

                                self.yang_name = "disable"
                                self.yang_parent_name = "tracking"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("stale-lifetime", ("stale_lifetime", Native.Ipv6.Nd.Inspection.Policy.Tracking.Disable.StaleLifetime))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.stale_lifetime = Native.Ipv6.Nd.Inspection.Policy.Tracking.Disable.StaleLifetime()
                                self.stale_lifetime.parent = self
                                self._children_name_map["stale_lifetime"] = "stale-lifetime"
                                self._segment_path = lambda: "disable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Nd.Inspection.Policy.Tracking.Disable, [], name, value)


                            class StaleLifetime(Entity):
                                """
                                Time entry is kept inactive before delete
                                
                                .. attribute:: seconds
                                
                                	Seconds
                                	**type**\: int
                                
                                	**range:** 1..86400
                                
                                .. attribute:: infinite
                                
                                	Keep in STALE forever
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-nd'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Ipv6.Nd.Inspection.Policy.Tracking.Disable.StaleLifetime, self).__init__()

                                    self.yang_name = "stale-lifetime"
                                    self.yang_parent_name = "disable"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('infinite', (YLeaf(YType.empty, 'infinite'), ['Empty'])),
                                    ])
                                    self.seconds = None
                                    self.infinite = None
                                    self._segment_path = lambda: "stale-lifetime"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Nd.Inspection.Policy.Tracking.Disable.StaleLifetime, ['seconds', 'infinite'], name, value)


                        class Enable(Entity):
                            """
                            Tracking on
                            
                            .. attribute:: reachable_lifetime
                            
                            	Time entry is kept REACHABLE
                            	**type**\:  :py:class:`ReachableLifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Inspection.Policy.Tracking.Enable.ReachableLifetime>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Ipv6.Nd.Inspection.Policy.Tracking.Enable, self).__init__()

                                self.yang_name = "enable"
                                self.yang_parent_name = "tracking"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("reachable-lifetime", ("reachable_lifetime", Native.Ipv6.Nd.Inspection.Policy.Tracking.Enable.ReachableLifetime))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.reachable_lifetime = Native.Ipv6.Nd.Inspection.Policy.Tracking.Enable.ReachableLifetime()
                                self.reachable_lifetime.parent = self
                                self._children_name_map["reachable_lifetime"] = "reachable-lifetime"
                                self._segment_path = lambda: "enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Nd.Inspection.Policy.Tracking.Enable, [], name, value)


                            class ReachableLifetime(Entity):
                                """
                                Time entry is kept REACHABLE
                                
                                .. attribute:: seconds
                                
                                	Seconds
                                	**type**\: int
                                
                                	**range:** 1..86400
                                
                                .. attribute:: infinite
                                
                                	Keep in REACHABLE forever
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-nd'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Ipv6.Nd.Inspection.Policy.Tracking.Enable.ReachableLifetime, self).__init__()

                                    self.yang_name = "reachable-lifetime"
                                    self.yang_parent_name = "enable"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('infinite', (YLeaf(YType.empty, 'infinite'), ['Empty'])),
                                    ])
                                    self.seconds = None
                                    self.infinite = None
                                    self._segment_path = lambda: "reachable-lifetime"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Nd.Inspection.Policy.Tracking.Enable.ReachableLifetime, ['seconds', 'infinite'], name, value)


                    class Validate(Entity):
                        """
                        specific validation
                        
                        .. attribute:: source_mac
                        
                        	check source mac against link\-layer\-address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ipv6.Nd.Inspection.Policy.Validate, self).__init__()

                            self.yang_name = "validate"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('source_mac', (YLeaf(YType.empty, 'source-mac'), ['Empty'])),
                            ])
                            self.source_mac = None
                            self._segment_path = lambda: "validate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Nd.Inspection.Policy.Validate, ['source_mac'], name, value)


            class Cache(Entity):
                """
                Cache entry
                
                .. attribute:: expire
                
                	Expiry time for ND entries
                	**type**\:  :py:class:`Expire <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Cache.Expire>`
                
                

                """

                _prefix = 'ios-nd'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ipv6.Nd.Cache, self).__init__()

                    self.yang_name = "cache"
                    self.yang_parent_name = "nd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("expire", ("expire", Native.Ipv6.Nd.Cache.Expire))])
                    self._leafs = OrderedDict()

                    self.expire = Native.Ipv6.Nd.Cache.Expire()
                    self.expire.parent = self
                    self._children_name_map["expire"] = "expire"
                    self._segment_path = lambda: "Cisco-IOS-XE-nd:cache"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/nd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Nd.Cache, [], name, value)


                class Expire(Entity):
                    """
                    Expiry time for ND entries
                    
                    .. attribute:: time
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: refresh
                    
                    	Automatically refresh entry
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ipv6.Nd.Cache.Expire, self).__init__()

                        self.yang_name = "expire"
                        self.yang_parent_name = "cache"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ('refresh', (YLeaf(YType.empty, 'refresh'), ['Empty'])),
                        ])
                        self.time = None
                        self.refresh = None
                        self._segment_path = lambda: "expire"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/nd/Cisco-IOS-XE-nd:cache/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Nd.Cache.Expire, ['time', 'refresh'], name, value)


            class Raguard(Entity):
                """
                Configure RA guard
                
                .. attribute:: policy
                
                	Configure a policy for feature RA guard
                	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Raguard.Policy>`
                
                .. attribute:: attach_policy
                
                	Configure a policy for feature RA guard
                	**type**\: str
                
                

                """

                _prefix = 'ios-nd'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ipv6.Nd.Raguard, self).__init__()

                    self.yang_name = "raguard"
                    self.yang_parent_name = "nd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Ipv6.Nd.Raguard.Policy))])
                    self._leafs = OrderedDict([
                        ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                    ])
                    self.attach_policy = None

                    self.policy = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/nd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                class Policy(Entity):
                    """
                    Configure a policy for feature RA guard
                    
                    .. attribute:: raguard_policy_name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: device_role
                    
                    	Sets the role of the device attached to the port
                    	**type**\:  :py:class:`DeviceRole <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Raguard.Policy.DeviceRole>`
                    
                    .. attribute:: hop_limit
                    
                    	Enable verification of the advertised Hop count limit
                    	**type**\:  :py:class:`HopLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Raguard.Policy.HopLimit>`
                    
                    .. attribute:: trusted_port
                    
                    	setup trusted port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ipv6.Nd.Raguard.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "raguard"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['raguard_policy_name']
                        self._child_classes = OrderedDict([("device-role", ("device_role", Native.Ipv6.Nd.Raguard.Policy.DeviceRole)), ("hop-limit", ("hop_limit", Native.Ipv6.Nd.Raguard.Policy.HopLimit))])
                        self._leafs = OrderedDict([
                            ('raguard_policy_name', (YLeaf(YType.str, 'raguard-policy-name'), ['str'])),
                            ('trusted_port', (YLeaf(YType.empty, 'trusted-port'), ['Empty'])),
                        ])
                        self.raguard_policy_name = None
                        self.trusted_port = None

                        self.device_role = Native.Ipv6.Nd.Raguard.Policy.DeviceRole()
                        self.device_role.parent = self
                        self._children_name_map["device_role"] = "device-role"

                        self.hop_limit = Native.Ipv6.Nd.Raguard.Policy.HopLimit()
                        self.hop_limit.parent = self
                        self._children_name_map["hop_limit"] = "hop-limit"
                        self._segment_path = lambda: "policy" + "[raguard-policy-name='" + str(self.raguard_policy_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/nd/Cisco-IOS-XE-nd:raguard/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Nd.Raguard.Policy, ['raguard_policy_name', 'trusted_port'], name, value)


                    class DeviceRole(Entity):
                        """
                        Sets the role of the device attached to the port
                        
                        .. attribute:: host
                        
                        	Attached device is a host (default)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: monitor
                        
                        	Attached device is a monitor/sniffer
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: router
                        
                        	Attached device is a router
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: switch
                        
                        	Attached device is a switch
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ipv6.Nd.Raguard.Policy.DeviceRole, self).__init__()

                            self.yang_name = "device-role"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('monitor', (YLeaf(YType.empty, 'monitor'), ['Empty'])),
                                ('router', (YLeaf(YType.empty, 'router'), ['Empty'])),
                                ('switch', (YLeaf(YType.empty, 'switch'), ['Empty'])),
                            ])
                            self.host = None
                            self.monitor = None
                            self.router = None
                            self.switch = None
                            self._segment_path = lambda: "device-role"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Nd.Raguard.Policy.DeviceRole, ['host', 'monitor', 'router', 'switch'], name, value)


                    class HopLimit(Entity):
                        """
                        Enable verification of the advertised Hop count limit
                        
                        .. attribute:: maximum
                        
                        	Maximum hop count value allowed
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: minimum
                        
                        	Minimum hop count value allowed
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Ipv6.Nd.Raguard.Policy.HopLimit, self).__init__()

                            self.yang_name = "hop-limit"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('maximum', (YLeaf(YType.uint8, 'maximum'), ['int'])),
                                ('minimum', (YLeaf(YType.uint8, 'minimum'), ['int'])),
                            ])
                            self.maximum = None
                            self.minimum = None
                            self._segment_path = lambda: "hop-limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Nd.Raguard.Policy.HopLimit, ['maximum', 'minimum'], name, value)


            class DefaultRoute(Entity):
                """
                
                
                .. attribute:: vrf
                
                	
                	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.DefaultRoute.Vrf>`
                
                .. attribute:: limit
                
                	
                	**type**\: int
                
                	**range:** 0..5
                
                

                """

                _prefix = 'ios-nd'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ipv6.Nd.DefaultRoute, self).__init__()

                    self.yang_name = "default-route"
                    self.yang_parent_name = "nd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ipv6.Nd.DefaultRoute.Vrf))])
                    self._leafs = OrderedDict([
                        ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                    ])
                    self.limit = None

                    self.vrf = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-nd:default-route"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/nd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Nd.DefaultRoute, ['limit'], name, value)


                class Vrf(Entity):
                    """
                    
                    
                    .. attribute:: word  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: limit
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..5
                    
                    

                    """

                    _prefix = 'ios-nd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ipv6.Nd.DefaultRoute.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "default-route"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['word']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                        ])
                        self.word = None
                        self.limit = None
                        self._segment_path = lambda: "vrf" + "[word='" + str(self.word) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/nd/Cisco-IOS-XE-nd:default-route/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Nd.DefaultRoute.Vrf, ['word', 'limit'], name, value)


            class Suppress(Entity):
                """
                Configure ND multicast suppress
                
                .. attribute:: policy
                
                	Configure a policy for feature nd suppress
                	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Nd.Suppress.Policy>`
                
                

                """

                _prefix = 'ios-nd'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Ipv6.Nd.Suppress, self).__init__()

                    self.yang_name = "suppress"
                    self.yang_parent_name = "nd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Ipv6.Nd.Suppress.Policy))])
                    self._leafs = OrderedDict()

                    self.policy = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-nd:suppress"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/nd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Nd.Suppress, [], name, value)


                class Policy(Entity):
                    """
                    Configure a policy for feature nd suppress
                    
                    .. attribute:: nd_suppress_policy_name  (key)
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Ipv6.Nd.Suppress.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "suppress"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['nd_suppress_policy_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('nd_suppress_policy_name', (YLeaf(YType.str, 'nd-suppress-policy-name'), ['str'])),
                        ])
                        self.nd_suppress_policy_name = None
                        self._segment_path = lambda: "policy" + "[nd-suppress-policy-name='" + str(self.nd_suppress_policy_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/nd/Cisco-IOS-XE-nd:suppress/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Nd.Suppress.Policy, ['nd_suppress_policy_name'], name, value)


        class Pim(Entity):
            """
            Configure Protocol Independent Multicast
            
            .. attribute:: rp_address
            
            	Configure Sparse\-Mode Rendezvous Point
            	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Pim.RpAddress>`
            
            .. attribute:: vrf
            
            	Select VPN Routing/Forwarding instance
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Pim.Vrf>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.Pim, self).__init__()

                self.yang_name = "pim"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:rp-address", ("rp_address", Native.Ipv6.Pim.RpAddress)), ("Cisco-IOS-XE-multicast:vrf", ("vrf", Native.Ipv6.Pim.Vrf))])
                self._leafs = OrderedDict()

                self.rp_address = Native.Ipv6.Pim.RpAddress()
                self.rp_address.parent = self
                self._children_name_map["rp_address"] = "Cisco-IOS-XE-multicast:rp-address"

                self.vrf = YList(self)
                self._segment_path = lambda: "pim"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.Pim, [], name, value)


            class RpAddress(Entity):
                """
                Configure Sparse\-Mode Rendezvous Point
                
                .. attribute:: address
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: access_list
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                .. attribute:: bidir
                
                	Specify keyword bidir to configure a bidir RP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ipv6.Pim.RpAddress, self).__init__()

                    self.yang_name = "rp-address"
                    self.yang_parent_name = "pim"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                        ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ('bidir', (YLeaf(YType.empty, 'bidir'), ['Empty'])),
                    ])
                    self.address = None
                    self.access_list = None
                    self.bidir = None
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:rp-address"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/pim/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Pim.RpAddress, ['address', 'access_list', 'bidir'], name, value)


            class Vrf(Entity):
                """
                Select VPN Routing/Forwarding instance
                
                .. attribute:: id  (key)
                
                	
                	**type**\: str
                
                .. attribute:: rp_address
                
                	Configure Sparse\-Mode Rendezvous Point
                	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Pim.Vrf.RpAddress>`
                
                

                """

                _prefix = 'ios-mc'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ipv6.Pim.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "pim"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("rp-address", ("rp_address", Native.Ipv6.Pim.Vrf.RpAddress))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                    ])
                    self.id = None

                    self.rp_address = Native.Ipv6.Pim.Vrf.RpAddress()
                    self.rp_address.parent = self
                    self._children_name_map["rp_address"] = "rp-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-multicast:vrf" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/pim/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Pim.Vrf, ['id'], name, value)


                class RpAddress(Entity):
                    """
                    Configure Sparse\-Mode Rendezvous Point
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    .. attribute:: bidir
                    
                    	Specify keyword bidir to configure a bidir RP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ipv6.Pim.Vrf.RpAddress, self).__init__()

                        self.yang_name = "rp-address"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                            ('bidir', (YLeaf(YType.empty, 'bidir'), ['Empty'])),
                        ])
                        self.address = None
                        self.access_list = None
                        self.bidir = None
                        self._segment_path = lambda: "rp-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Pim.Vrf.RpAddress, ['address', 'access_list', 'bidir'], name, value)


        class Route(Entity):
            """
            Configure static routes
            
            .. attribute:: ipv6_route_list
            
            	
            	**type**\: list of  		 :py:class:`Ipv6RouteList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Route.Ipv6RouteList>`
            
            .. attribute:: vrf
            
            	Configure static route for a VPN Routing/Forwarding instance
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Route.Vrf>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.Route, self).__init__()

                self.yang_name = "route"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ipv6-route-list", ("ipv6_route_list", Native.Ipv6.Route.Ipv6RouteList)), ("vrf", ("vrf", Native.Ipv6.Route.Vrf))])
                self._leafs = OrderedDict()

                self.ipv6_route_list = YList(self)
                self.vrf = YList(self)
                self._segment_path = lambda: "route"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.Route, [], name, value)


            class Ipv6RouteList(Entity):
                """
                
                
                .. attribute:: prefix  (key)
                
                	
                	**type**\: str
                
                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                
                .. attribute:: ipv6_fwd_list
                
                	
                	**type**\: list of  		 :py:class:`Ipv6FwdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Route.Ipv6RouteList.Ipv6FwdList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ipv6.Route.Ipv6RouteList, self).__init__()

                    self.yang_name = "ipv6-route-list"
                    self.yang_parent_name = "route"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['prefix']
                    self._child_classes = OrderedDict([("ipv6-fwd-list", ("ipv6_fwd_list", Native.Ipv6.Route.Ipv6RouteList.Ipv6FwdList))])
                    self._leafs = OrderedDict([
                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                    ])
                    self.prefix = None

                    self.ipv6_fwd_list = YList(self)
                    self._segment_path = lambda: "ipv6-route-list" + "[prefix='" + str(self.prefix) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/route/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Route.Ipv6RouteList, [u'prefix'], name, value)


                class Ipv6FwdList(Entity):
                    """
                    
                    
                    .. attribute:: fwd  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\:  :py:class:`Fwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList.Fwd>`
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    .. attribute:: interface_next_hop
                    
                    	IPv6 address of next\-hop
                    	**type**\: list of  		 :py:class:`InterfaceNextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Route.Ipv6RouteList.Ipv6FwdList.InterfaceNextHop>`
                    
                    .. attribute:: distance
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: multicast
                    
                    	Route only usable by multicast
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unicast
                    
                    	Route only usable by unicast
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: tag
                    
                    	Tag value
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: track
                    
                    	Tracked
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	Specify name of the next hop
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ipv6.Route.Ipv6RouteList.Ipv6FwdList, self).__init__()

                        self.yang_name = "ipv6-fwd-list"
                        self.yang_parent_name = "ipv6-route-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['fwd']
                        self._child_classes = OrderedDict([("interface-next-hop", ("interface_next_hop", Native.Ipv6.Route.Ipv6RouteList.Ipv6FwdList.InterfaceNextHop))])
                        self._leafs = OrderedDict([
                            ('fwd', (YLeaf(YType.str, 'fwd'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList.Fwd'),'str','str'])),
                            ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                            ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                            ('track', (YLeaf(YType.uint32, 'track'), ['int'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.fwd = None
                        self.distance = None
                        self.multicast = None
                        self.unicast = None
                        self.tag = None
                        self.track = None
                        self.name = None

                        self.interface_next_hop = YList(self)
                        self._segment_path = lambda: "ipv6-fwd-list" + "[fwd='" + str(self.fwd) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Route.Ipv6RouteList.Ipv6FwdList, [u'fwd', u'distance', u'multicast', u'unicast', u'tag', u'track', u'name'], name, value)

                    class Fwd(Enum):
                        """
                        Fwd (Enum Class)

                        .. data:: Null0 = 0

                        """

                        Null0 = Enum.YLeaf(0, "Null0")



                    class InterfaceNextHop(Entity):
                        """
                        IPv6 address of next\-hop
                        
                        .. attribute:: ipv6_address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: distance
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: multicast
                        
                        	Route only usable by multicast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	Route only usable by unicast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tag
                        
                        	Tag value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: track
                        
                        	Tracked
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Specify name of the next hop
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ipv6.Route.Ipv6RouteList.Ipv6FwdList.InterfaceNextHop, self).__init__()

                            self.yang_name = "interface-next-hop"
                            self.yang_parent_name = "ipv6-fwd-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv6_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('track', (YLeaf(YType.uint32, 'track'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.ipv6_address = None
                            self.distance = None
                            self.multicast = None
                            self.unicast = None
                            self.tag = None
                            self.track = None
                            self.name = None
                            self._segment_path = lambda: "interface-next-hop" + "[ipv6-address='" + str(self.ipv6_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Route.Ipv6RouteList.Ipv6FwdList.InterfaceNextHop, [u'ipv6_address', u'distance', u'multicast', u'unicast', u'tag', u'track', u'name'], name, value)


            class Vrf(Entity):
                """
                Configure static route for a VPN Routing/Forwarding instance
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: ipv6_route_list
                
                	
                	**type**\: list of  		 :py:class:`Ipv6RouteList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Route.Vrf.Ipv6RouteList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ipv6.Route.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "route"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("ipv6-route-list", ("ipv6_route_list", Native.Ipv6.Route.Vrf.Ipv6RouteList))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.ipv6_route_list = YList(self)
                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/route/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Route.Vrf, [u'name'], name, value)


                class Ipv6RouteList(Entity):
                    """
                    
                    
                    .. attribute:: prefix  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    .. attribute:: ipv6_fwd_list
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv6FwdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ipv6.Route.Vrf.Ipv6RouteList, self).__init__()

                        self.yang_name = "ipv6-route-list"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['prefix']
                        self._child_classes = OrderedDict([("ipv6-fwd-list", ("ipv6_fwd_list", Native.Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                        ])
                        self.prefix = None

                        self.ipv6_fwd_list = YList(self)
                        self._segment_path = lambda: "ipv6-route-list" + "[prefix='" + str(self.prefix) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Route.Vrf.Ipv6RouteList, [u'prefix'], name, value)


                    class Ipv6FwdList(Entity):
                        """
                        
                        
                        .. attribute:: fwd  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Fwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList.Fwd>`
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        .. attribute:: interface_next_hop
                        
                        	IPv6 address of next\-hop
                        	**type**\: list of  		 :py:class:`InterfaceNextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList.InterfaceNextHop>`
                        
                        .. attribute:: distance
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: multicast
                        
                        	Route only usable by multicast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	Route only usable by unicast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tag
                        
                        	Tag value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: track
                        
                        	Tracked
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Specify name of the next hop
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList, self).__init__()

                            self.yang_name = "ipv6-fwd-list"
                            self.yang_parent_name = "ipv6-route-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['fwd']
                            self._child_classes = OrderedDict([("interface-next-hop", ("interface_next_hop", Native.Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList.InterfaceNextHop))])
                            self._leafs = OrderedDict([
                                ('fwd', (YLeaf(YType.str, 'fwd'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList.Fwd'),'str','str'])),
                                ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('track', (YLeaf(YType.uint32, 'track'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.fwd = None
                            self.distance = None
                            self.multicast = None
                            self.unicast = None
                            self.tag = None
                            self.track = None
                            self.name = None

                            self.interface_next_hop = YList(self)
                            self._segment_path = lambda: "ipv6-fwd-list" + "[fwd='" + str(self.fwd) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList, [u'fwd', u'distance', u'multicast', u'unicast', u'tag', u'track', u'name'], name, value)

                        class Fwd(Enum):
                            """
                            Fwd (Enum Class)

                            .. data:: Null0 = 0

                            """

                            Null0 = Enum.YLeaf(0, "Null0")



                        class InterfaceNextHop(Entity):
                            """
                            IPv6 address of next\-hop
                            
                            .. attribute:: ipv6_address  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: distance
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: multicast
                            
                            	Route only usable by multicast
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: unicast
                            
                            	Route only usable by unicast
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: tag
                            
                            	Tag value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: track
                            
                            	Tracked
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Specify name of the next hop
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList.InterfaceNextHop, self).__init__()

                                self.yang_name = "interface-next-hop"
                                self.yang_parent_name = "ipv6-fwd-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv6_address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                    ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ('track', (YLeaf(YType.uint32, 'track'), ['int'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.ipv6_address = None
                                self.distance = None
                                self.multicast = None
                                self.unicast = None
                                self.tag = None
                                self.track = None
                                self.name = None
                                self._segment_path = lambda: "interface-next-hop" + "[ipv6-address='" + str(self.ipv6_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Route.Vrf.Ipv6RouteList.Ipv6FwdList.InterfaceNextHop, [u'ipv6_address', u'distance', u'multicast', u'unicast', u'tag', u'track', u'name'], name, value)


        class Router(Entity):
            """
            Enable an IPV6 routing process
            
            .. attribute:: eigrp
            
            	Enhanced Interior Gateway Routing Protocol (EIGRP)
            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Eigrp>`
            
            .. attribute:: ospf
            
            	Open Shortest Path First (OSPFv3)
            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Ospf>`
            
            .. attribute:: rip
            
            	IPv6 Routing Information Protocol (RIPv6)
            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.Router, self).__init__()

                self.yang_name = "router"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Ipv6.Router.Eigrp)), ("ospf", ("ospf", Native.Ipv6.Router.Ospf)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Ipv6.Router.Rip))])
                self._leafs = OrderedDict()

                self.eigrp = YList(self)
                self.ospf = YList(self)
                self.rip = YList(self)
                self._segment_path = lambda: "router"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.Router, [], name, value)


            class Eigrp(Entity):
                """
                Enhanced Interior Gateway Routing Protocol (EIGRP)
                
                .. attribute:: id  (key)
                
                	Autonomous System ID
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: default_metric
                
                	Set metric of redistributed routes
                	**type**\:  :py:class:`DefaultMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Eigrp.DefaultMetric>`
                
                .. attribute:: distance
                
                	Define an administrative distance
                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Eigrp.Distance>`
                
                .. attribute:: distribute_list
                
                	Filter networks in routing updates
                	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Eigrp.DistributeList>`
                
                .. attribute:: eigrp
                
                	EIGRP specific commands
                	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Eigrp.Eigrp_>`
                
                .. attribute:: passive_interface
                
                	Suppress routing updates on an interface
                	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Eigrp.PassiveInterface>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ipv6.Router.Eigrp, self).__init__()

                    self.yang_name = "eigrp"
                    self.yang_parent_name = "router"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-eigrp:default-metric", ("default_metric", Native.Ipv6.Router.Eigrp.DefaultMetric)), ("Cisco-IOS-XE-eigrp:distance", ("distance", Native.Ipv6.Router.Eigrp.Distance)), ("Cisco-IOS-XE-eigrp:distribute-list", ("distribute_list", Native.Ipv6.Router.Eigrp.DistributeList)), ("Cisco-IOS-XE-eigrp:eigrp", ("eigrp", Native.Ipv6.Router.Eigrp.Eigrp_)), ("Cisco-IOS-XE-eigrp:passive-interface", ("passive_interface", Native.Ipv6.Router.Eigrp.PassiveInterface))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                    ])
                    self.id = None

                    self.default_metric = Native.Ipv6.Router.Eigrp.DefaultMetric()
                    self.default_metric.parent = self
                    self._children_name_map["default_metric"] = "Cisco-IOS-XE-eigrp:default-metric"

                    self.distance = Native.Ipv6.Router.Eigrp.Distance()
                    self.distance.parent = self
                    self._children_name_map["distance"] = "Cisco-IOS-XE-eigrp:distance"

                    self.distribute_list = Native.Ipv6.Router.Eigrp.DistributeList()
                    self.distribute_list.parent = self
                    self._children_name_map["distribute_list"] = "Cisco-IOS-XE-eigrp:distribute-list"

                    self.eigrp = Native.Ipv6.Router.Eigrp.Eigrp_()
                    self.eigrp.parent = self
                    self._children_name_map["eigrp"] = "Cisco-IOS-XE-eigrp:eigrp"

                    self.passive_interface = YList(self)
                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/router/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Router.Eigrp, [u'id'], name, value)


                class DefaultMetric(Entity):
                    """
                    Set metric of redistributed routes
                    
                    .. attribute:: dm_rdr
                    
                    	Bandwidth in Kbits per second
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: dm_rdr0
                    
                    	delay metric in 10 microsecond units
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: dm_rdr_pct
                    
                    	Reliability metric where 255 is 100% reliable
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: effective_bandwith_metric
                    
                    	Effective bandwidth metric (Loading) where 255 is 100% loaded
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: mtu
                    
                    	Maximum Transmission Unit metric of the path 
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ipv6.Router.Eigrp.DefaultMetric, self).__init__()

                        self.yang_name = "default-metric"
                        self.yang_parent_name = "eigrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dm_rdr', (YLeaf(YType.uint32, 'dm-rdr'), ['int'])),
                            ('dm_rdr0', (YLeaf(YType.uint32, 'dm-rdr0'), ['int'])),
                            ('dm_rdr_pct', (YLeaf(YType.uint8, 'dm-rdr-pct'), ['int'])),
                            ('effective_bandwith_metric', (YLeaf(YType.uint8, 'effective-bandwith-metric'), ['int'])),
                            ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ])
                        self.dm_rdr = None
                        self.dm_rdr0 = None
                        self.dm_rdr_pct = None
                        self.effective_bandwith_metric = None
                        self.mtu = None
                        self._segment_path = lambda: "Cisco-IOS-XE-eigrp:default-metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Router.Eigrp.DefaultMetric, ['dm_rdr', 'dm_rdr0', 'dm_rdr_pct', 'effective_bandwith_metric', 'mtu'], name, value)


                class Distance(Entity):
                    """
                    Define an administrative distance
                    
                    .. attribute:: eigrp
                    
                    	EIGRP\-IPV6 distance
                    	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Eigrp.Distance.Eigrp_>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ipv6.Router.Eigrp.Distance, self).__init__()

                        self.yang_name = "distance"
                        self.yang_parent_name = "eigrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Ipv6.Router.Eigrp.Distance.Eigrp_))])
                        self._leafs = OrderedDict()

                        self.eigrp = Native.Ipv6.Router.Eigrp.Distance.Eigrp_()
                        self.eigrp.parent = self
                        self._children_name_map["eigrp"] = "eigrp"
                        self._segment_path = lambda: "Cisco-IOS-XE-eigrp:distance"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Router.Eigrp.Distance, [], name, value)


                    class Eigrp_(Entity):
                        """
                        EIGRP\-IPV6 distance
                        
                        .. attribute:: internal_route
                        
                        	Distance for internal routes
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: external_route
                        
                        	Distance for external routes
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Eigrp.Distance.Eigrp_, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "distance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('internal_route', (YLeaf(YType.uint8, 'internal-route'), ['int'])),
                                ('external_route', (YLeaf(YType.uint8, 'external-route'), ['int'])),
                            ])
                            self.internal_route = None
                            self.external_route = None
                            self._segment_path = lambda: "eigrp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Eigrp.Distance.Eigrp_, ['internal_route', 'external_route'], name, value)


                class DistributeList(Entity):
                    """
                    Filter networks in routing updates
                    
                    .. attribute:: prefix_list
                    
                    	Filter connections based on an IPv6 prefix\-list
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Eigrp.DistributeList.PrefixList>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ipv6.Router.Eigrp.DistributeList, self).__init__()

                        self.yang_name = "distribute-list"
                        self.yang_parent_name = "eigrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix-list", ("prefix_list", Native.Ipv6.Router.Eigrp.DistributeList.PrefixList))])
                        self._leafs = OrderedDict()

                        self.prefix_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-eigrp:distribute-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Router.Eigrp.DistributeList, [], name, value)


                    class PrefixList(Entity):
                        """
                        Filter connections based on an IPv6 prefix\-list
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	Filter incoming routing updates
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Filter outgoing routing updates
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Eigrp.DistributeList.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "distribute-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.name = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "prefix-list" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Eigrp.DistributeList.PrefixList, ['name', 'in_', 'out'], name, value)


                class Eigrp_(Entity):
                    """
                    EIGRP specific commands
                    
                    .. attribute:: router_id
                    
                    	router id for this EIGRP process
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ipv6.Router.Eigrp.Eigrp_, self).__init__()

                        self.yang_name = "eigrp"
                        self.yang_parent_name = "eigrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                        ])
                        self.router_id = None
                        self._segment_path = lambda: "Cisco-IOS-XE-eigrp:eigrp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Router.Eigrp.Eigrp_, ['router_id'], name, value)


                class PassiveInterface(Entity):
                    """
                    Suppress routing updates on an interface
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Eigrp.PassiveInterface.Name>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ipv6.Router.Eigrp.PassiveInterface, self).__init__()

                        self.yang_name = "passive-interface"
                        self.yang_parent_name = "eigrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.Router.Eigrp.PassiveInterface.Name')])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "Cisco-IOS-XE-eigrp:passive-interface" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Router.Eigrp.PassiveInterface, ['name'], name, value)

                    class Name(Enum):
                        """
                        Name (Enum Class)

                        .. data:: default = 0

                        """

                        default = Enum.YLeaf(0, "default")



            class Ospf(Entity):
                """
                Open Shortest Path First (OSPFv3)
                
                .. attribute:: id  (key)
                
                	Process ID
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ipv6.Router.Ospf, self).__init__()

                    self.yang_name = "ospf"
                    self.yang_parent_name = "router"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                    ])
                    self.id = None
                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/router/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Router.Ospf, [u'id'], name, value)


            class Rip(Entity):
                """
                IPv6 Routing Information Protocol (RIPv6)
                
                .. attribute:: id  (key)
                
                	
                	**type**\: str
                
                .. attribute:: address_family
                
                	Enter Address Family command mode
                	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily>`
                
                .. attribute:: distance
                
                	Administrative distance
                	**type**\: int
                
                	**range:** 1..254
                
                .. attribute:: distribute_list
                
                	Filter networks in routing updates
                	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.DistributeList>`
                
                .. attribute:: maximum_paths
                
                	Forward packets over multiple paths
                	**type**\: int
                
                	**range:** 1..32
                
                .. attribute:: poison_reverse
                
                	Poison reverse updates
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: redistribute
                
                	Redistribute IPv6 prefixes from another routing protocol
                	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute>`
                
                .. attribute:: split_horizon
                
                	Split horizon updates
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timers
                
                	Adjust routing timers
                	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Timers>`
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ipv6.Router.Rip, self).__init__()

                    self.yang_name = "rip"
                    self.yang_parent_name = "router"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("address-family", ("address_family", Native.Ipv6.Router.Rip.AddressFamily)), ("distribute-list", ("distribute_list", Native.Ipv6.Router.Rip.DistributeList)), ("redistribute", ("redistribute", Native.Ipv6.Router.Rip.Redistribute)), ("timers", ("timers", Native.Ipv6.Router.Rip.Timers))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                        ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                        ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                        ('poison_reverse', (YLeaf(YType.empty, 'poison-reverse'), ['Empty'])),
                        ('split_horizon', (YLeaf(YType.empty, 'split-horizon'), ['Empty'])),
                    ])
                    self.id = None
                    self.distance = None
                    self.maximum_paths = None
                    self.poison_reverse = None
                    self.split_horizon = None

                    self.address_family = Native.Ipv6.Router.Rip.AddressFamily()
                    self.address_family.parent = self
                    self._children_name_map["address_family"] = "address-family"

                    self.distribute_list = Native.Ipv6.Router.Rip.DistributeList()
                    self.distribute_list.parent = self
                    self._children_name_map["distribute_list"] = "distribute-list"

                    self.redistribute = Native.Ipv6.Router.Rip.Redistribute()
                    self.redistribute.parent = self
                    self._children_name_map["redistribute"] = "redistribute"

                    self.timers = Native.Ipv6.Router.Rip.Timers()
                    self.timers.parent = self
                    self._children_name_map["timers"] = "timers"
                    self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/router/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Router.Rip, ['id', 'distance', 'maximum_paths', 'poison_reverse', 'split_horizon'], name, value)


                class AddressFamily(Entity):
                    """
                    Enter Address Family command mode
                    
                    .. attribute:: ipv6
                    
                    	Address family
                    	**type**\:  :py:class:`Ipv6_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ipv6.Router.Rip.AddressFamily, self).__init__()

                        self.yang_name = "address-family"
                        self.yang_parent_name = "rip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv6", ("ipv6", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_))])
                        self._leafs = OrderedDict()

                        self.ipv6 = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"
                        self._segment_path = lambda: "address-family"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily, [], name, value)


                    class Ipv6_(Entity):
                        """
                        Address family
                        
                        .. attribute:: vrf
                        
                        	Specify parameters for a VPN Routing/Forwarding instance
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "address-family"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf))])
                            self._leafs = OrderedDict()

                            self.vrf = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_, [], name, value)


                        class Vrf(Entity):
                            """
                            Specify parameters for a VPN Routing/Forwarding instance
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: distance
                            
                            	Administrative distance
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: distribute_list
                            
                            	Filter networks in routing updates
                            	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.DistributeList>`
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\: int
                            
                            	**range:** 1..32
                            
                            .. attribute:: poison_reverse
                            
                            	Poison reverse updates
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redistribute
                            
                            	Redistribute IPv6 prefixes from another routing protocol
                            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute>`
                            
                            .. attribute:: split_horizon
                            
                            	Split horizon updates
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Adjust routing timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Timers>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("distribute-list", ("distribute_list", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.DistributeList)), ("redistribute", ("redistribute", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute)), ("timers", ("timers", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Timers))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                    ('poison_reverse', (YLeaf(YType.empty, 'poison-reverse'), ['Empty'])),
                                    ('split_horizon', (YLeaf(YType.empty, 'split-horizon'), ['Empty'])),
                                ])
                                self.name = None
                                self.distance = None
                                self.maximum_paths = None
                                self.poison_reverse = None
                                self.split_horizon = None

                                self.distribute_list = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.DistributeList()
                                self.distribute_list.parent = self
                                self._children_name_map["distribute_list"] = "distribute-list"

                                self.redistribute = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute()
                                self.redistribute.parent = self
                                self._children_name_map["redistribute"] = "redistribute"

                                self.timers = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"
                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf, ['name', 'distance', 'maximum_paths', 'poison_reverse', 'split_horizon'], name, value)


                            class DistributeList(Entity):
                                """
                                Filter networks in routing updates
                                
                                .. attribute:: prefix_list
                                
                                	Filter connections based on an IPv6 prefix\-list
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.DistributeList.PrefixList>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.DistributeList, self).__init__()

                                    self.yang_name = "distribute-list"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("prefix-list", ("prefix_list", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.DistributeList.PrefixList))])
                                    self._leafs = OrderedDict()

                                    self.prefix_list = YList(self)
                                    self._segment_path = lambda: "distribute-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.DistributeList, [], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter connections based on an IPv6 prefix\-list
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: in_
                                    
                                    	Filter incoming routing updates
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: out
                                    
                                    	Filter outgoing routing updates
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.DistributeList.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "distribute-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                            ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                        ])
                                        self.name = None
                                        self.in_ = None
                                        self.out = None
                                        self._segment_path = lambda: "prefix-list" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.DistributeList.PrefixList, ['name', 'in_', 'out'], name, value)


                            class Redistribute(Entity):
                                """
                                Redistribute IPv6 prefixes from another routing protocol
                                
                                .. attribute:: application
                                
                                	Application Protocol
                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Application>`
                                
                                .. attribute:: lisp
                                
                                	Locator ID Separation Protocol (LISP)
                                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Lisp>`
                                
                                .. attribute:: nd
                                
                                	Neighbor Discovery
                                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Nd>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp>`
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: iso_igrp
                                
                                	IGRP for OSI networks
                                	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: mobile
                                
                                	Mobile routes
                                	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: odr
                                
                                	On Demand stub Routes
                                	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf>`
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute, self).__init__()

                                    self.yang_name = "redistribute"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("application", ("application", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Application)), ("lisp", ("lisp", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Lisp)), ("nd", ("nd", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Nd)), ("connected", ("connected", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected)), ("bgp", ("bgp", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp)), ("eigrp", ("eigrp", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp)), ("isis", ("isis", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis)), ("iso-igrp", ("iso_igrp", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile)), ("odr", ("odr", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr)), ("ospf", ("ospf", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf)), ("static", ("static", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static)), ("rip", ("rip", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_))])
                                    self._leafs = OrderedDict()

                                    self.application = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Application()
                                    self.application.parent = self
                                    self._children_name_map["application"] = "application"

                                    self.lisp = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Lisp()
                                    self.lisp.parent = self
                                    self._children_name_map["lisp"] = "lisp"

                                    self.nd = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Nd()
                                    self.nd.parent = self
                                    self._children_name_map["nd"] = "nd"

                                    self.connected = None
                                    self._children_name_map["connected"] = "connected"

                                    self.isis = None
                                    self._children_name_map["isis"] = "isis"

                                    self.iso_igrp = None
                                    self._children_name_map["iso_igrp"] = "iso-igrp"

                                    self.mobile = None
                                    self._children_name_map["mobile"] = "mobile"

                                    self.odr = None
                                    self._children_name_map["odr"] = "odr"

                                    self.static = None
                                    self._children_name_map["static"] = "static"

                                    self.rip = None
                                    self._children_name_map["rip"] = "rip"

                                    self.bgp = YList(self)
                                    self.eigrp = YList(self)
                                    self.ospf = YList(self)
                                    self._segment_path = lambda: "redistribute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute, [], name, value)


                                class Application(Entity):
                                    """
                                    Application Protocol
                                    
                                    .. attribute:: include_connected
                                    
                                    	Include connected
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Application, self).__init__()

                                        self.yang_name = "application"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.include_connected = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "application"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Application, ['include_connected', 'metric', 'route_map'], name, value)


                                class Lisp(Entity):
                                    """
                                    Locator ID Separation Protocol (LISP)
                                    
                                    .. attribute:: include_connected
                                    
                                    	Include connected
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Lisp, self).__init__()

                                        self.yang_name = "lisp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.include_connected = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "lisp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                class Nd(Entity):
                                    """
                                    Neighbor Discovery
                                    
                                    .. attribute:: include_connected
                                    
                                    	Include connected
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Nd, self).__init__()

                                        self.yang_name = "nd"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.include_connected = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "nd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Nd, ['include_connected', 'metric', 'route_map'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected.RipMetricRouteMap>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected.RipMetricRouteMap))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected, [], name, value)


                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected.RipMetricRouteMap.Metric>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "connected"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Connected.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class Bgp(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: as_number  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp.RipMetricRouteMap>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['as_number']
                                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp.RipMetricRouteMap))])
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                        ])
                                        self.as_number = None

                                        self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                        self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp, ['as_number'], name, value)


                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp.RipMetricRouteMap.Metric>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Bgp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: as_number  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp.RipMetricRouteMap>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['as_number']
                                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp.RipMetricRouteMap))])
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint16, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None

                                        self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                        self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp, ['as_number'], name, value)


                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp.RipMetricRouteMap.Metric>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Eigrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: isis_area
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea>`
                                    
                                    .. attribute:: rip_isis_redist
                                    
                                    	
                                    	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea)), ("rip-isis-redist", ("rip_isis_redist", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.rip_isis_redist = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist()
                                        self.rip_isis_redist.parent = self
                                        self._children_name_map["rip_isis_redist"] = "rip-isis-redist"

                                        self.isis_area = YList(self)
                                        self._segment_path = lambda: "isis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis, [], name, value)


                                    class IsisArea(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: rip_isis_redist
                                        
                                        	
                                        	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea, self).__init__()

                                            self.yang_name = "isis-area"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("rip-isis-redist", ("rip_isis_redist", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.rip_isis_redist = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist()
                                            self.rip_isis_redist.parent = self
                                            self._children_name_map["rip_isis_redist"] = "rip-isis-redist"
                                            self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea, ['name'], name, value)


                                        class RipIsisRedist(Entity):
                                            """
                                            
                                            
                                            .. attribute:: isis_level_routes
                                            
                                            	
                                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes>`
                                            
                                            .. attribute:: rip_metric_route_map
                                            
                                            	
                                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist, self).__init__()

                                                self.yang_name = "rip-isis-redist"
                                                self.yang_parent_name = "isis-area"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap))])
                                                self._leafs = OrderedDict([
                                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes')])),
                                                ])
                                                self.isis_level_routes = None

                                                self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap()
                                                self.rip_metric_route_map.parent = self
                                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                                self._segment_path = lambda: "rip-isis-redist"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist, ['isis_level_routes'], name, value)

                                            class IsisLevelRoutes(Enum):
                                                """
                                                IsisLevelRoutes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class RipMetricRouteMap(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                                    self.yang_name = "rip-metric-route-map"
                                                    self.yang_parent_name = "rip-isis-redist"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric))])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None

                                                    self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric()
                                                    self.metric.parent = self
                                                    self._children_name_map["metric"] = "metric"
                                                    self._segment_path = lambda: "rip-metric-route-map"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                                                class Metric(Entity):
                                                    """
                                                    Metric for redistributed routes
                                                    
                                                    .. attribute:: metric_value
                                                    
                                                    	Metric for redistributed routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..16
                                                    
                                                    .. attribute:: transparent
                                                    
                                                    	Transparently redistribute metric
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-rip'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                                        self.yang_name = "metric"
                                                        self.yang_parent_name = "rip-metric-route-map"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                        ])
                                                        self.metric_value = None
                                                        self.transparent = None
                                                        self._segment_path = lambda: "metric"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                    class RipIsisRedist(Entity):
                                        """
                                        
                                        
                                        .. attribute:: isis_level_routes
                                        
                                        	
                                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes>`
                                        
                                        .. attribute:: rip_metric_route_map
                                        
                                        	
                                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist, self).__init__()

                                            self.yang_name = "rip-isis-redist"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap))])
                                            self._leafs = OrderedDict([
                                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes')])),
                                            ])
                                            self.isis_level_routes = None

                                            self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap()
                                            self.rip_metric_route_map.parent = self
                                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                            self._segment_path = lambda: "rip-isis-redist"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist, ['isis_level_routes'], name, value)

                                        class IsisLevelRoutes(Enum):
                                            """
                                            IsisLevelRoutes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class RipMetricRouteMap(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                                self.yang_name = "rip-metric-route-map"
                                                self.yang_parent_name = "rip-isis-redist"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric()
                                                self.metric.parent = self
                                                self._children_name_map["metric"] = "metric"
                                                self._segment_path = lambda: "rip-metric-route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                                            class Metric(Entity):
                                                """
                                                Metric for redistributed routes
                                                
                                                .. attribute:: metric_value
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..16
                                                
                                                .. attribute:: transparent
                                                
                                                	Transparently redistribute metric
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                                    self.yang_name = "metric"
                                                    self.yang_parent_name = "rip-metric-route-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                    ])
                                                    self.metric_value = None
                                                    self.transparent = None
                                                    self._segment_path = lambda: "metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class IsoIgrp(Entity):
                                    """
                                    IGRP for OSI networks
                                    
                                    .. attribute:: isoigrp_list
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`IsoigrpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList>`
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp, self).__init__()

                                        self.yang_name = "iso-igrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isoigrp-list", ("isoigrp_list", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                                        self.isoigrp_list = YList(self)
                                        self._segment_path = lambda: "iso-igrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp, [], name, value)


                                    class IsoigrpList(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: iso_area_tag  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: rip_metric_route_map
                                        
                                        	
                                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList, self).__init__()

                                            self.yang_name = "isoigrp-list"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['iso_area_tag']
                                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap))])
                                            self._leafs = OrderedDict([
                                                ('iso_area_tag', (YLeaf(YType.str, 'iso-area-tag'), ['str'])),
                                            ])
                                            self.iso_area_tag = None

                                            self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap()
                                            self.rip_metric_route_map.parent = self
                                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                            self._segment_path = lambda: "isoigrp-list" + "[iso-area-tag='" + str(self.iso_area_tag) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList, ['iso_area_tag'], name, value)


                                        class RipMetricRouteMap(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, self).__init__()

                                                self.yang_name = "rip-metric-route-map"
                                                self.yang_parent_name = "isoigrp-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric()
                                                self.metric.parent = self
                                                self._children_name_map["metric"] = "metric"
                                                self._segment_path = lambda: "rip-metric-route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, ['route_map'], name, value)


                                            class Metric(Entity):
                                                """
                                                Metric for redistributed routes
                                                
                                                .. attribute:: metric_value
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..16
                                                
                                                .. attribute:: transparent
                                                
                                                	Transparently redistribute metric
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, self).__init__()

                                                    self.yang_name = "metric"
                                                    self.yang_parent_name = "rip-metric-route-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                    ])
                                                    self.metric_value = None
                                                    self.transparent = None
                                                    self._segment_path = lambda: "metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap.Metric>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class Mobile(Entity):
                                    """
                                    Mobile routes
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile.RipMetricRouteMap>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile, self).__init__()

                                        self.yang_name = "mobile"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile.RipMetricRouteMap))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                        self._segment_path = lambda: "mobile"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile, [], name, value)


                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile.RipMetricRouteMap.Metric>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "mobile"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Mobile.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class Odr(Entity):
                                    """
                                    On Demand stub Routes
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr.RipMetricRouteMap>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr, self).__init__()

                                        self.yang_name = "odr"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr.RipMetricRouteMap))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                        self._segment_path = lambda: "odr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr, [], name, value)


                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr.RipMetricRouteMap.Metric>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "odr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Odr.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: process_id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: vrf
                                    
                                    	VPN Routing/Forwarding Instance
                                    	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Vrf_>`
                                    
                                    .. attribute:: match
                                    
                                    	Redistribution of OSPF routes
                                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match>`
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.RipMetricRouteMap>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['process_id']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Vrf_)), ("match", ("match", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.RipMetricRouteMap))])
                                        self._leafs = OrderedDict([
                                            ('process_id', (YLeaf(YType.uint16, 'process-id'), ['int'])),
                                        ])
                                        self.process_id = None

                                        self.match = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match()
                                        self.match.parent = self
                                        self._children_name_map["match"] = "match"

                                        self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                                        self.vrf = YList(self)
                                        self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf, ['process_id'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VPN Routing/Forwarding Instance
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None
                                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Vrf_, ['name'], name, value)


                                    class Match(Entity):
                                        """
                                        Redistribution of OSPF routes
                                        
                                        .. attribute:: internal
                                        
                                        	Redistribute OSPF internal routes
                                        	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: external
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: nssa_external
                                        
                                        	Redistribute OSPF NSSA external routes
                                        	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match, self).__init__()

                                            self.yang_name = "match"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("internal", ("internal", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal))])
                                            self._leafs = OrderedDict()

                                            self.internal = None
                                            self._children_name_map["internal"] = "internal"

                                            self.external = None
                                            self._children_name_map["external"] = "external"

                                            self.nssa_external = None
                                            self._children_name_map["nssa_external"] = "nssa-external"
                                            self._segment_path = lambda: "match"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match, [], name, value)


                                        class Internal(Entity):
                                            """
                                            Redistribute OSPF internal routes
                                            
                                            .. attribute:: rip_metric_route_map
                                            
                                            	
                                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal, self).__init__()

                                                self.yang_name = "internal"
                                                self.yang_parent_name = "match"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap()
                                                self.rip_metric_route_map.parent = self
                                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                                self._segment_path = lambda: "internal"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal, [], name, value)


                                            class RipMetricRouteMap(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, self).__init__()

                                                    self.yang_name = "rip-metric-route-map"
                                                    self.yang_parent_name = "internal"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric))])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None

                                                    self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric()
                                                    self.metric.parent = self
                                                    self._children_name_map["metric"] = "metric"
                                                    self._segment_path = lambda: "rip-metric-route-map"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, ['route_map'], name, value)


                                                class Metric(Entity):
                                                    """
                                                    Metric for redistributed routes
                                                    
                                                    .. attribute:: metric_value
                                                    
                                                    	Metric for redistributed routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..16
                                                    
                                                    .. attribute:: transparent
                                                    
                                                    	Transparently redistribute metric
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-rip'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, self).__init__()

                                                        self.yang_name = "metric"
                                                        self.yang_parent_name = "rip-metric-route-map"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                        ])
                                                        self.metric_value = None
                                                        self.transparent = None
                                                        self._segment_path = lambda: "metric"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                        class External(Entity):
                                            """
                                            Redistribute OSPF external routes
                                            
                                            .. attribute:: external_routes
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: rip_metric_route_map
                                            
                                            	
                                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External, self).__init__()

                                                self.yang_name = "external"
                                                self.yang_parent_name = "match"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ])
                                                self.external_routes = None

                                                self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap()
                                                self.rip_metric_route_map.parent = self
                                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                                self._segment_path = lambda: "external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External, ['external_routes'], name, value)


                                            class RipMetricRouteMap(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap, self).__init__()

                                                    self.yang_name = "rip-metric-route-map"
                                                    self.yang_parent_name = "external"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric))])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None

                                                    self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric()
                                                    self.metric.parent = self
                                                    self._children_name_map["metric"] = "metric"
                                                    self._segment_path = lambda: "rip-metric-route-map"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap, ['route_map'], name, value)


                                                class Metric(Entity):
                                                    """
                                                    Metric for redistributed routes
                                                    
                                                    .. attribute:: metric_value
                                                    
                                                    	Metric for redistributed routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..16
                                                    
                                                    .. attribute:: transparent
                                                    
                                                    	Transparently redistribute metric
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-rip'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, self).__init__()

                                                        self.yang_name = "metric"
                                                        self.yang_parent_name = "rip-metric-route-map"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                        ])
                                                        self.metric_value = None
                                                        self.transparent = None
                                                        self._segment_path = lambda: "metric"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                        class NssaExternal(Entity):
                                            """
                                            Redistribute OSPF NSSA external routes
                                            
                                            .. attribute:: nssa_external_routes
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: rip_metric_route_map
                                            
                                            	
                                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                                self.yang_name = "nssa-external"
                                                self.yang_parent_name = "match"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ])
                                                self.nssa_external_routes = None

                                                self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap()
                                                self.rip_metric_route_map.parent = self
                                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                                self._segment_path = lambda: "nssa-external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal, ['nssa_external_routes'], name, value)


                                            class RipMetricRouteMap(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, self).__init__()

                                                    self.yang_name = "rip-metric-route-map"
                                                    self.yang_parent_name = "nssa-external"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric))])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None

                                                    self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric()
                                                    self.metric.parent = self
                                                    self._children_name_map["metric"] = "metric"
                                                    self._segment_path = lambda: "rip-metric-route-map"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, ['route_map'], name, value)


                                                class Metric(Entity):
                                                    """
                                                    Metric for redistributed routes
                                                    
                                                    .. attribute:: metric_value
                                                    
                                                    	Metric for redistributed routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..16
                                                    
                                                    .. attribute:: transparent
                                                    
                                                    	Transparently redistribute metric
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-rip'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, self).__init__()

                                                        self.yang_name = "metric"
                                                        self.yang_parent_name = "rip-metric-route-map"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                        ])
                                                        self.metric_value = None
                                                        self.transparent = None
                                                        self._segment_path = lambda: "metric"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.RipMetricRouteMap.Metric>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Ospf.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static.RipMetricRouteMap>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static.RipMetricRouteMap))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static, [], name, value)


                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static.RipMetricRouteMap.Metric>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Static.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class Rip_(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_.RipMetricRouteMap>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_.RipMetricRouteMap))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.rip_metric_route_map = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_, [], name, value)


                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_.RipMetricRouteMap.Metric>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "rip"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Redistribute.Rip_.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Timers(Entity):
                                """
                                Adjust routing timers
                                
                                .. attribute:: update
                                
                                	Update period
                                	**type**\: int
                                
                                	**range:** 5..65535
                                
                                .. attribute:: timeout
                                
                                	Route timeout period
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: holddown
                                
                                	Route holddown period
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: garbage_collection
                                
                                	Route garbage collection period
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('update', (YLeaf(YType.uint16, 'update'), ['int'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                        ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                        ('garbage_collection', (YLeaf(YType.uint16, 'garbage-collection'), ['int'])),
                                    ])
                                    self.update = None
                                    self.timeout = None
                                    self.holddown = None
                                    self.garbage_collection = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.AddressFamily.Ipv6_.Vrf.Timers, ['update', 'timeout', 'holddown', 'garbage_collection'], name, value)


                class DistributeList(Entity):
                    """
                    Filter networks in routing updates
                    
                    .. attribute:: prefix_list
                    
                    	Filter connections based on an IPv6 prefix\-list
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.DistributeList.PrefixList>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ipv6.Router.Rip.DistributeList, self).__init__()

                        self.yang_name = "distribute-list"
                        self.yang_parent_name = "rip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix-list", ("prefix_list", Native.Ipv6.Router.Rip.DistributeList.PrefixList))])
                        self._leafs = OrderedDict()

                        self.prefix_list = YList(self)
                        self._segment_path = lambda: "distribute-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Router.Rip.DistributeList, [], name, value)


                    class PrefixList(Entity):
                        """
                        Filter connections based on an IPv6 prefix\-list
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	Filter incoming routing updates
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Filter outgoing routing updates
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.DistributeList.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "distribute-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.name = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "prefix-list" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.DistributeList.PrefixList, ['name', 'in_', 'out'], name, value)


                class Redistribute(Entity):
                    """
                    Redistribute IPv6 prefixes from another routing protocol
                    
                    .. attribute:: application
                    
                    	Application Protocol
                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Application>`
                    
                    .. attribute:: lisp
                    
                    	Locator ID Separation Protocol (LISP)
                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Lisp>`
                    
                    .. attribute:: nd
                    
                    	Neighbor Discovery
                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Nd>`
                    
                    .. attribute:: connected
                    
                    	Connected
                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Connected>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bgp
                    
                    	Border Gateway Protocol (BGP)
                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Bgp>`
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Eigrp>`
                    
                    .. attribute:: isis
                    
                    	ISO IS\-IS
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Isis>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: iso_igrp
                    
                    	IGRP for OSI networks
                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.IsoIgrp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: mobile
                    
                    	Mobile routes
                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Mobile>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: odr
                    
                    	On Demand stub Routes
                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Odr>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ospf
                    
                    	Open Shortest Path First (OSPF)
                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf>`
                    
                    .. attribute:: static
                    
                    	Static routes
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Static>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: rip
                    
                    	Routing Information Protocol (RIP)
                    	**type**\:  :py:class:`Rip_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Rip_>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ipv6.Router.Rip.Redistribute, self).__init__()

                        self.yang_name = "redistribute"
                        self.yang_parent_name = "rip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("application", ("application", Native.Ipv6.Router.Rip.Redistribute.Application)), ("lisp", ("lisp", Native.Ipv6.Router.Rip.Redistribute.Lisp)), ("nd", ("nd", Native.Ipv6.Router.Rip.Redistribute.Nd)), ("connected", ("connected", Native.Ipv6.Router.Rip.Redistribute.Connected)), ("bgp", ("bgp", Native.Ipv6.Router.Rip.Redistribute.Bgp)), ("eigrp", ("eigrp", Native.Ipv6.Router.Rip.Redistribute.Eigrp)), ("isis", ("isis", Native.Ipv6.Router.Rip.Redistribute.Isis)), ("iso-igrp", ("iso_igrp", Native.Ipv6.Router.Rip.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Ipv6.Router.Rip.Redistribute.Mobile)), ("odr", ("odr", Native.Ipv6.Router.Rip.Redistribute.Odr)), ("ospf", ("ospf", Native.Ipv6.Router.Rip.Redistribute.Ospf)), ("static", ("static", Native.Ipv6.Router.Rip.Redistribute.Static)), ("rip", ("rip", Native.Ipv6.Router.Rip.Redistribute.Rip_))])
                        self._leafs = OrderedDict()

                        self.application = Native.Ipv6.Router.Rip.Redistribute.Application()
                        self.application.parent = self
                        self._children_name_map["application"] = "application"

                        self.lisp = Native.Ipv6.Router.Rip.Redistribute.Lisp()
                        self.lisp.parent = self
                        self._children_name_map["lisp"] = "lisp"

                        self.nd = Native.Ipv6.Router.Rip.Redistribute.Nd()
                        self.nd.parent = self
                        self._children_name_map["nd"] = "nd"

                        self.connected = None
                        self._children_name_map["connected"] = "connected"

                        self.isis = None
                        self._children_name_map["isis"] = "isis"

                        self.iso_igrp = None
                        self._children_name_map["iso_igrp"] = "iso-igrp"

                        self.mobile = None
                        self._children_name_map["mobile"] = "mobile"

                        self.odr = None
                        self._children_name_map["odr"] = "odr"

                        self.static = None
                        self._children_name_map["static"] = "static"

                        self.rip = None
                        self._children_name_map["rip"] = "rip"

                        self.bgp = YList(self)
                        self.eigrp = YList(self)
                        self.ospf = YList(self)
                        self._segment_path = lambda: "redistribute"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute, [], name, value)


                    class Application(Entity):
                        """
                        Application Protocol
                        
                        .. attribute:: include_connected
                        
                        	Include connected
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Application, self).__init__()

                            self.yang_name = "application"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.include_connected = None
                            self.metric = None
                            self.route_map = None
                            self._segment_path = lambda: "application"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Application, ['include_connected', 'metric', 'route_map'], name, value)


                    class Lisp(Entity):
                        """
                        Locator ID Separation Protocol (LISP)
                        
                        .. attribute:: include_connected
                        
                        	Include connected
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Lisp, self).__init__()

                            self.yang_name = "lisp"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.include_connected = None
                            self.metric = None
                            self.route_map = None
                            self._segment_path = lambda: "lisp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                    class Nd(Entity):
                        """
                        Neighbor Discovery
                        
                        .. attribute:: include_connected
                        
                        	Include connected
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Nd, self).__init__()

                            self.yang_name = "nd"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.include_connected = None
                            self.metric = None
                            self.route_map = None
                            self._segment_path = lambda: "nd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Nd, ['include_connected', 'metric', 'route_map'], name, value)


                    class Connected(Entity):
                        """
                        Connected
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Connected.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Connected, self).__init__()

                            self.yang_name = "connected"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Connected.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Connected.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "connected"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Connected, [], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Connected.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Connected.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "connected"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Connected.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Ipv6.Router.Rip.Redistribute.Connected.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Connected.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Connected.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Connected.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Bgp(Entity):
                        """
                        Border Gateway Protocol (BGP)
                        
                        .. attribute:: as_number  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4294967295
                        
                        		**type**\: str
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Bgp.RipMetricRouteMap>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Bgp, self).__init__()

                            self.yang_name = "bgp"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['as_number']
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Bgp.RipMetricRouteMap))])
                            self._leafs = OrderedDict([
                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                            ])
                            self.as_number = None

                            self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Bgp.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Bgp, ['as_number'], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Bgp.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Bgp.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "bgp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Bgp.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Ipv6.Router.Rip.Redistribute.Bgp.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Bgp.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Bgp.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Bgp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Eigrp(Entity):
                        """
                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                        
                        .. attribute:: as_number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['as_number']
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap))])
                            self._leafs = OrderedDict([
                                ('as_number', (YLeaf(YType.uint16, 'as-number'), ['int'])),
                            ])
                            self.as_number = None

                            self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Eigrp, ['as_number'], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "eigrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Ipv6.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Isis(Entity):
                        """
                        ISO IS\-IS
                        
                        .. attribute:: isis_area
                        
                        	
                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea>`
                        
                        .. attribute:: rip_isis_redist
                        
                        	
                        	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea)), ("rip-isis-redist", ("rip_isis_redist", Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_isis_redist = Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist()
                            self.rip_isis_redist.parent = self
                            self._children_name_map["rip_isis_redist"] = "rip-isis-redist"

                            self.isis_area = YList(self)
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Isis, [], name, value)


                        class IsisArea(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: rip_isis_redist
                            
                            	
                            	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea, self).__init__()

                                self.yang_name = "isis-area"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("rip-isis-redist", ("rip_isis_redist", Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.rip_isis_redist = Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist()
                                self.rip_isis_redist.parent = self
                                self._children_name_map["rip_isis_redist"] = "rip-isis-redist"
                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea, ['name'], name, value)


                            class RipIsisRedist(Entity):
                                """
                                
                                
                                .. attribute:: isis_level_routes
                                
                                	
                                	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes>`
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist, self).__init__()

                                    self.yang_name = "rip-isis-redist"
                                    self.yang_parent_name = "isis-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap))])
                                    self._leafs = OrderedDict([
                                        ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes')])),
                                    ])
                                    self.isis_level_routes = None

                                    self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "rip-isis-redist"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist, ['isis_level_routes'], name, value)

                                class IsisLevelRoutes(Enum):
                                    """
                                    IsisLevelRoutes (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    .. data:: level_1_2 = 2

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")

                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "rip-isis-redist"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                        class RipIsisRedist(Entity):
                            """
                            
                            
                            .. attribute:: isis_level_routes
                            
                            	
                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes>`
                            
                            .. attribute:: rip_metric_route_map
                            
                            	
                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist, self).__init__()

                                self.yang_name = "rip-isis-redist"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap))])
                                self._leafs = OrderedDict([
                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes')])),
                                ])
                                self.isis_level_routes = None

                                self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap()
                                self.rip_metric_route_map.parent = self
                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                self._segment_path = lambda: "rip-isis-redist"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist, ['isis_level_routes'], name, value)

                            class IsisLevelRoutes(Enum):
                                """
                                IsisLevelRoutes (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                .. data:: level_1_2 = 2

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")

                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                            class RipMetricRouteMap(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                    self.yang_name = "rip-metric-route-map"
                                    self.yang_parent_name = "rip-isis-redist"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric))])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.metric = Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "rip-metric-route-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                                class Metric(Entity):
                                    """
                                    Metric for redistributed routes
                                    
                                    .. attribute:: metric_value
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..16
                                    
                                    .. attribute:: transparent
                                    
                                    	Transparently redistribute metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "rip-metric-route-map"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                        ])
                                        self.metric_value = None
                                        self.transparent = None
                                        self._segment_path = lambda: "metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class IsoIgrp(Entity):
                        """
                        IGRP for OSI networks
                        
                        .. attribute:: isoigrp_list
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`IsoigrpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList>`
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp, self).__init__()

                            self.yang_name = "iso-igrp"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("isoigrp-list", ("isoigrp_list", Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                            self.isoigrp_list = YList(self)
                            self._segment_path = lambda: "iso-igrp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp, [], name, value)


                        class IsoigrpList(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: iso_area_tag  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: rip_metric_route_map
                            
                            	
                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList, self).__init__()

                                self.yang_name = "isoigrp-list"
                                self.yang_parent_name = "iso-igrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['iso_area_tag']
                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap))])
                                self._leafs = OrderedDict([
                                    ('iso_area_tag', (YLeaf(YType.str, 'iso-area-tag'), ['str'])),
                                ])
                                self.iso_area_tag = None

                                self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap()
                                self.rip_metric_route_map.parent = self
                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                self._segment_path = lambda: "isoigrp-list" + "[iso-area-tag='" + str(self.iso_area_tag) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList, ['iso_area_tag'], name, value)


                            class RipMetricRouteMap(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, self).__init__()

                                    self.yang_name = "rip-metric-route-map"
                                    self.yang_parent_name = "isoigrp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric))])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.metric = Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "rip-metric-route-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, ['route_map'], name, value)


                                class Metric(Entity):
                                    """
                                    Metric for redistributed routes
                                    
                                    .. attribute:: metric_value
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..16
                                    
                                    .. attribute:: transparent
                                    
                                    	Transparently redistribute metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "rip-metric-route-map"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                        ])
                                        self.metric_value = None
                                        self.transparent = None
                                        self._segment_path = lambda: "metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap.Metric>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "iso-igrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Mobile(Entity):
                        """
                        Mobile routes
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Mobile.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Mobile, self).__init__()

                            self.yang_name = "mobile"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Mobile.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Mobile.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "mobile"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Mobile, [], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Mobile.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Mobile.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "mobile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Mobile.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Ipv6.Router.Rip.Redistribute.Mobile.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Mobile.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Mobile.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Mobile.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Odr(Entity):
                        """
                        On Demand stub Routes
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Odr.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Odr, self).__init__()

                            self.yang_name = "odr"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Odr.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Odr.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "odr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Odr, [], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Odr.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Odr.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "odr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Odr.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Ipv6.Router.Rip.Redistribute.Odr.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Odr.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Odr.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Odr.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Ospf(Entity):
                        """
                        Open Shortest Path First (OSPF)
                        
                        .. attribute:: process_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: vrf
                        
                        	VPN Routing/Forwarding Instance
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.Vrf>`
                        
                        .. attribute:: match
                        
                        	Redistribution of OSPF routes
                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.Match>`
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.RipMetricRouteMap>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Ospf, self).__init__()

                            self.yang_name = "ospf"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['process_id']
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Ipv6.Router.Rip.Redistribute.Ospf.Vrf)), ("match", ("match", Native.Ipv6.Router.Rip.Redistribute.Ospf.Match)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Ospf.RipMetricRouteMap))])
                            self._leafs = OrderedDict([
                                ('process_id', (YLeaf(YType.uint16, 'process-id'), ['int'])),
                            ])
                            self.process_id = None

                            self.match = Native.Ipv6.Router.Rip.Redistribute.Ospf.Match()
                            self.match.parent = self
                            self._children_name_map["match"] = "match"

                            self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Ospf.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                            self.vrf = YList(self)
                            self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf, ['process_id'], name, value)


                        class Vrf(Entity):
                            """
                            VPN Routing/Forwarding Instance
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Ospf.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.Vrf, ['name'], name, value)


                        class Match(Entity):
                            """
                            Redistribution of OSPF routes
                            
                            .. attribute:: internal
                            
                            	Redistribute OSPF internal routes
                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: external
                            
                            	Redistribute OSPF external routes
                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: nssa_external
                            
                            	Redistribute OSPF NSSA external routes
                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match, self).__init__()

                                self.yang_name = "match"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("internal", ("internal", Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal))])
                                self._leafs = OrderedDict()

                                self.internal = None
                                self._children_name_map["internal"] = "internal"

                                self.external = None
                                self._children_name_map["external"] = "external"

                                self.nssa_external = None
                                self._children_name_map["nssa_external"] = "nssa-external"
                                self._segment_path = lambda: "match"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match, [], name, value)


                            class Internal(Entity):
                                """
                                Redistribute OSPF internal routes
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal, self).__init__()

                                    self.yang_name = "internal"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "internal"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "internal"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class External(Entity):
                                """
                                Redistribute OSPF external routes
                                
                                .. attribute:: external_routes
                                
                                	
                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External, self).__init__()

                                    self.yang_name = "external"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                    ])
                                    self.external_routes = None

                                    self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "external"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External, ['external_routes'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "external"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class NssaExternal(Entity):
                                """
                                Redistribute OSPF NSSA external routes
                                
                                .. attribute:: nssa_external_routes
                                
                                	
                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                    self.yang_name = "nssa-external"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                    ])
                                    self.nssa_external_routes = None

                                    self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "nssa-external"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal, ['nssa_external_routes'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "nssa-external"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Ospf.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Ospf.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Ospf.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Ipv6.Router.Rip.Redistribute.Ospf.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Ospf.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Ospf.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Static(Entity):
                        """
                        Static routes
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Static.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Static.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Static.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "static"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Static, [], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Static.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Static.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Static.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Ipv6.Router.Rip.Redistribute.Static.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Static.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Static.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Static.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Rip_(Entity):
                        """
                        Routing Information Protocol (RIP)
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Rip_.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Ipv6.Router.Rip.Redistribute.Rip_, self).__init__()

                            self.yang_name = "rip"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Ipv6.Router.Rip.Redistribute.Rip_.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Ipv6.Router.Rip.Redistribute.Rip_.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "rip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Rip_, [], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Router.Rip.Redistribute.Rip_.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Ipv6.Router.Rip.Redistribute.Rip_.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "rip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Ipv6.Router.Rip.Redistribute.Rip_.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Ipv6.Router.Rip.Redistribute.Rip_.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Rip_.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Ipv6.Router.Rip.Redistribute.Rip_.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ipv6.Router.Rip.Redistribute.Rip_.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class Timers(Entity):
                    """
                    Adjust routing timers
                    
                    .. attribute:: update
                    
                    	Update period
                    	**type**\: int
                    
                    	**range:** 5..65535
                    
                    .. attribute:: timeout
                    
                    	Route timeout period
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: holddown
                    
                    	Route holddown period
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: garbage_collection
                    
                    	Route garbage collection period
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ipv6.Router.Rip.Timers, self).__init__()

                        self.yang_name = "timers"
                        self.yang_parent_name = "rip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('update', (YLeaf(YType.uint16, 'update'), ['int'])),
                            ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                            ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                            ('garbage_collection', (YLeaf(YType.uint16, 'garbage-collection'), ['int'])),
                        ])
                        self.update = None
                        self.timeout = None
                        self.holddown = None
                        self.garbage_collection = None
                        self._segment_path = lambda: "timers"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Router.Rip.Timers, ['update', 'timeout', 'holddown', 'garbage_collection'], name, value)


        class Spd(Entity):
            """
            spd
            
            .. attribute:: mode
            
            	
            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Spd.Mode>`
            
            .. attribute:: queue
            
            	queue
            	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Spd.Queue>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.Spd, self).__init__()

                self.yang_name = "spd"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("queue", ("queue", Native.Ipv6.Spd.Queue))])
                self._leafs = OrderedDict([
                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.Spd.Mode')])),
                ])
                self.mode = None

                self.queue = Native.Ipv6.Spd.Queue()
                self.queue.parent = self
                self._children_name_map["queue"] = "queue"
                self._segment_path = lambda: "spd"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.Spd, [u'mode'], name, value)

            class Mode(Enum):
                """
                Mode (Enum Class)

                .. data:: aggressive = 0

                """

                aggressive = Enum.YLeaf(0, "aggressive")



            class Queue(Entity):
                """
                queue
                
                .. attribute:: max_threshold
                
                	Max threshold
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: min_threshold
                
                	Min threshold
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ipv6.Spd.Queue, self).__init__()

                    self.yang_name = "queue"
                    self.yang_parent_name = "spd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('max_threshold', (YLeaf(YType.uint16, 'max-threshold'), ['int'])),
                        ('min_threshold', (YLeaf(YType.uint16, 'min-threshold'), ['int'])),
                    ])
                    self.max_threshold = None
                    self.min_threshold = None
                    self._segment_path = lambda: "queue"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/spd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Spd.Queue, [u'max_threshold', u'min_threshold'], name, value)


        class PrefixList(Entity):
            """
            Build a prefix list
            
            .. attribute:: prefixes
            
            	
            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.PrefixList.Prefixes>`
            
            .. attribute:: sequence_number
            
            	Include/exclude sequence numbers in NVGEN
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.PrefixList, self).__init__()

                self.yang_name = "prefix-list"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Ipv6.PrefixList.Prefixes))])
                self._leafs = OrderedDict([
                    ('sequence_number', (YLeaf(YType.empty, 'sequence-number'), ['Empty'])),
                ])
                self.sequence_number = None

                self.prefixes = YList(self)
                self._segment_path = lambda: "prefix-list"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.PrefixList, [u'sequence_number'], name, value)


            class Prefixes(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                	**pattern:** ([^s].\*)\|(s[^e].\*)\|(se[^q].\*)(seq[^u].\*)\|(sequ[^e].\*)\|(seque[^n].\*)\|(sequen[^c].\*)\|(sequenc[^e].\*)\|(sequence[^\\\-].\*)\|(sequence\\\-[^n].\*)\|(sequence\\\-n[^u].\*)\|(sequence\\\-nu[^m].\*)\|(sequence\\\-num[^b].\*)\|(sequence\\\-numb[^e].\*)\|(sequence\\\-numbe[^r].\*)\|(sequence\\\-number..\*)
                
                .. attribute:: description
                
                	Prefix\-list specific description
                	**type**\: str
                
                	**length:** 1..80
                
                .. attribute:: permit
                
                	Specify packets to forward
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.PrefixList.Prefixes.Permit>`
                
                .. attribute:: deny
                
                	Specify packets to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.PrefixList.Prefixes.Deny>`
                
                .. attribute:: seq
                
                	sequence number of an entry
                	**type**\: list of  		 :py:class:`Seq <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.PrefixList.Prefixes.Seq>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Ipv6.PrefixList.Prefixes, self).__init__()

                    self.yang_name = "prefixes"
                    self.yang_parent_name = "prefix-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("permit", ("permit", Native.Ipv6.PrefixList.Prefixes.Permit)), ("deny", ("deny", Native.Ipv6.PrefixList.Prefixes.Deny)), ("seq", ("seq", Native.Ipv6.PrefixList.Prefixes.Seq))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.name = None
                    self.description = None

                    self.permit = Native.Ipv6.PrefixList.Prefixes.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"

                    self.deny = Native.Ipv6.PrefixList.Prefixes.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.seq = YList(self)
                    self._segment_path = lambda: "prefixes" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/prefix-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.PrefixList.Prefixes, [u'name', u'description'], name, value)


                class Permit(Entity):
                    """
                    Specify packets to forward
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    .. attribute:: ge
                    
                    	Minimum prefix length to be matched
                    	**type**\: int
                    
                    	**range:** 0..128
                    
                    .. attribute:: le
                    
                    	Maximum prefix length to be matched
                    	**type**\: int
                    
                    	**range:** 0..128
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ipv6.PrefixList.Prefixes.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "prefixes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('ge', (YLeaf(YType.uint8, 'ge'), ['int'])),
                            ('le', (YLeaf(YType.uint8, 'le'), ['int'])),
                        ])
                        self.address = None
                        self.ge = None
                        self.le = None
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.PrefixList.Prefixes.Permit, [u'address', u'ge', u'le'], name, value)


                class Deny(Entity):
                    """
                    Specify packets to reject
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    .. attribute:: ge
                    
                    	Minimum prefix length to be matched
                    	**type**\: int
                    
                    	**range:** 0..128
                    
                    .. attribute:: le
                    
                    	Maximum prefix length to be matched
                    	**type**\: int
                    
                    	**range:** 0..128
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ipv6.PrefixList.Prefixes.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "prefixes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('ge', (YLeaf(YType.uint8, 'ge'), ['int'])),
                            ('le', (YLeaf(YType.uint8, 'le'), ['int'])),
                        ])
                        self.address = None
                        self.ge = None
                        self.le = None
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.PrefixList.Prefixes.Deny, [u'address', u'ge', u'le'], name, value)


                class Seq(Entity):
                    """
                    sequence number of an entry
                    
                    .. attribute:: no  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967294
                    
                    .. attribute:: deny
                    
                    	Specify packets to reject
                    	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.PrefixList.Prefixes.Seq.Deny>`
                    
                    .. attribute:: permit
                    
                    	Specify packets to forward
                    	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.PrefixList.Prefixes.Seq.Permit>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Ipv6.PrefixList.Prefixes.Seq, self).__init__()

                        self.yang_name = "seq"
                        self.yang_parent_name = "prefixes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['no']
                        self._child_classes = OrderedDict([("deny", ("deny", Native.Ipv6.PrefixList.Prefixes.Seq.Deny)), ("permit", ("permit", Native.Ipv6.PrefixList.Prefixes.Seq.Permit))])
                        self._leafs = OrderedDict([
                            ('no', (YLeaf(YType.uint32, 'no'), ['int'])),
                        ])
                        self.no = None

                        self.deny = Native.Ipv6.PrefixList.Prefixes.Seq.Deny()
                        self.deny.parent = self
                        self._children_name_map["deny"] = "deny"

                        self.permit = Native.Ipv6.PrefixList.Prefixes.Seq.Permit()
                        self.permit.parent = self
                        self._children_name_map["permit"] = "permit"
                        self._segment_path = lambda: "seq" + "[no='" + str(self.no) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.PrefixList.Prefixes.Seq, [u'no'], name, value)


                    class Deny(Entity):
                        """
                        Specify packets to reject
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: ge
                        
                        	Minimum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..128
                        
                        .. attribute:: le
                        
                        	Maximum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..128
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ipv6.PrefixList.Prefixes.Seq.Deny, self).__init__()

                            self.yang_name = "deny"
                            self.yang_parent_name = "seq"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('ge', (YLeaf(YType.uint16, 'ge'), ['int'])),
                                ('le', (YLeaf(YType.uint16, 'le'), ['int'])),
                            ])
                            self.ip = None
                            self.ge = None
                            self.le = None
                            self._segment_path = lambda: "deny"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.PrefixList.Prefixes.Seq.Deny, [u'ip', u'ge', u'le'], name, value)


                    class Permit(Entity):
                        """
                        Specify packets to forward
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: ge
                        
                        	Minimum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..128
                        
                        .. attribute:: le
                        
                        	Maximum prefix length to be matched
                        	**type**\: int
                        
                        	**range:** 1..128
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Ipv6.PrefixList.Prefixes.Seq.Permit, self).__init__()

                            self.yang_name = "permit"
                            self.yang_parent_name = "seq"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('ge', (YLeaf(YType.uint16, 'ge'), ['int'])),
                                ('le', (YLeaf(YType.uint16, 'le'), ['int'])),
                            ])
                            self.ip = None
                            self.ge = None
                            self.le = None
                            self._segment_path = lambda: "permit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ipv6.PrefixList.Prefixes.Seq.Permit, [u'ip', u'ge', u'le'], name, value)


        class Neighbor(Entity):
            """
            Neighbor
            
            .. attribute:: address  (key)
            
            	X\:X\:X\:X\:\:X  IPv6 address
            	**type**\: str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: interface  (key)
            
            	
            	**type**\: str
            
            .. attribute:: hardware_address
            
            	H.H.H  48\-bit hardware address
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Ipv6.Neighbor, self).__init__()

                self.yang_name = "neighbor"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['address','interface']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                    ('hardware_address', (YLeaf(YType.str, 'hardware-address'), ['str'])),
                ])
                self.address = None
                self.interface = None
                self.hardware_address = None
                self._segment_path = lambda: "neighbor" + "[address='" + str(self.address) + "']" + "[interface='" + str(self.interface) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.Neighbor, [u'address', u'interface', u'hardware_address'], name, value)


        class Mld(Entity):
            """
            Global mld commands
            
            .. attribute:: snooping_conf
            
            	Global MLD Snooping enable for Catalyst Vlans
            	**type**\:  :py:class:`SnoopingConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Mld.SnoopingConf>`
            
            .. attribute:: ssm_map
            
            	SSM mapping commands
            	**type**\:  :py:class:`SsmMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Mld.SsmMap>`
            
            

            """

            _prefix = 'ios-mld'
            _revision = '2018-02-12'

            def __init__(self):
                super(Native.Ipv6.Mld, self).__init__()

                self.yang_name = "mld"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("snooping-conf", ("snooping_conf", Native.Ipv6.Mld.SnoopingConf)), ("ssm-map", ("ssm_map", Native.Ipv6.Mld.SsmMap))])
                self._leafs = OrderedDict()

                self.snooping_conf = Native.Ipv6.Mld.SnoopingConf()
                self.snooping_conf.parent = self
                self._children_name_map["snooping_conf"] = "snooping-conf"

                self.ssm_map = Native.Ipv6.Mld.SsmMap()
                self.ssm_map.parent = self
                self._children_name_map["ssm_map"] = "ssm-map"
                self._segment_path = lambda: "Cisco-IOS-XE-mld:mld"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.Mld, [], name, value)


            class SnoopingConf(Entity):
                """
                Global MLD Snooping enable for Catalyst Vlans
                
                .. attribute:: snooping
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-mld'
                _revision = '2018-02-12'

                def __init__(self):
                    super(Native.Ipv6.Mld.SnoopingConf, self).__init__()

                    self.yang_name = "snooping-conf"
                    self.yang_parent_name = "mld"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('snooping', (YLeaf(YType.empty, 'snooping'), ['Empty'])),
                    ])
                    self.snooping = None
                    self._segment_path = lambda: "snooping-conf"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/Cisco-IOS-XE-mld:mld/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Mld.SnoopingConf, ['snooping'], name, value)


            class SsmMap(Entity):
                """
                SSM mapping commands
                
                .. attribute:: enable
                
                	Enable SSM mapping
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: query
                
                	Which database should we query for the source
                	**type**\:  :py:class:`Query <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Mld.SsmMap.Query>`
                
                .. attribute:: static
                
                	SSM static group to source mapping
                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Mld.SsmMap.Static>`
                
                

                """

                _prefix = 'ios-mld'
                _revision = '2018-02-12'

                def __init__(self):
                    super(Native.Ipv6.Mld.SsmMap, self).__init__()

                    self.yang_name = "ssm-map"
                    self.yang_parent_name = "mld"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("query", ("query", Native.Ipv6.Mld.SsmMap.Query)), ("static", ("static", Native.Ipv6.Mld.SsmMap.Static))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None

                    self.query = Native.Ipv6.Mld.SsmMap.Query()
                    self.query.parent = self
                    self._children_name_map["query"] = "query"

                    self.static = Native.Ipv6.Mld.SsmMap.Static()
                    self.static.parent = self
                    self._children_name_map["static"] = "static"
                    self._segment_path = lambda: "ssm-map"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/Cisco-IOS-XE-mld:mld/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ipv6.Mld.SsmMap, ['enable'], name, value)


                class Query(Entity):
                    """
                    Which database should we query for the source
                    
                    .. attribute:: dns
                    
                    	Use DNS for source lookup
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mld'
                    _revision = '2018-02-12'

                    def __init__(self):
                        super(Native.Ipv6.Mld.SsmMap.Query, self).__init__()

                        self.yang_name = "query"
                        self.yang_parent_name = "ssm-map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dns', (YLeaf(YType.empty, 'dns'), ['Empty'])),
                        ])
                        self.dns = None
                        self._segment_path = lambda: "query"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/Cisco-IOS-XE-mld:mld/ssm-map/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Mld.SsmMap.Query, ['dns'], name, value)


                class Static(Entity):
                    """
                    SSM static group to source mapping
                    
                    .. attribute:: acl
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: source_ip
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-mld'
                    _revision = '2018-02-12'

                    def __init__(self):
                        super(Native.Ipv6.Mld.SsmMap.Static, self).__init__()

                        self.yang_name = "static"
                        self.yang_parent_name = "ssm-map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acl', (YLeaf(YType.str, 'acl'), ['str'])),
                            ('source_ip', (YLeaf(YType.str, 'source-ip'), ['str'])),
                        ])
                        self.acl = None
                        self.source_ip = None
                        self._segment_path = lambda: "static"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/Cisco-IOS-XE-mld:mld/ssm-map/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ipv6.Mld.SsmMap.Static, ['acl', 'source_ip'], name, value)


        class MulticastRouting(Entity):
            """
            Enable IPv6 multicast
            
            .. attribute:: vrf
            
            	Select VPN Routing/Forwarding instance
            	**type**\: str
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-mc'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ipv6.MulticastRouting, self).__init__()

                self.yang_name = "multicast-routing"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                ])
                self.vrf = None
                self._segment_path = lambda: "Cisco-IOS-XE-multicast:multicast-routing"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.MulticastRouting, ['vrf'], name, value)


        class Rip(Entity):
            """
            Configure ipv6 RIP settings
            
            .. attribute:: vrf_mode
            
            	Enable RIPng VRF support
            	**type**\:  :py:class:`VrfMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ipv6.Rip.VrfMode>`
            
            

            """

            _prefix = 'ios-rip'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ipv6.Rip, self).__init__()

                self.yang_name = "rip"
                self.yang_parent_name = "ipv6"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('vrf_mode', (YLeaf(YType.enumeration, 'vrf-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Ipv6.Rip.VrfMode')])),
                ])
                self.vrf_mode = None
                self._segment_path = lambda: "Cisco-IOS-XE-rip:rip"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ipv6/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ipv6.Rip, ['vrf_mode'], name, value)

            class VrfMode(Enum):
                """
                VrfMode (Enum Class)

                Enable RIPng VRF support

                .. data:: enable = 0

                """

                enable = Enum.YLeaf(0, "enable")



    class Vlan(Entity):
        """
        Global vlan configuration
        
        .. attribute:: access_map
        
        	Create vlan access\-map or enter vlan access\-map command mode
        	**type**\: list of  		 :py:class:`AccessMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.AccessMap>`
        
        .. attribute:: configuration
        
        	vlan feature configuration mode
        	**type**\: list of  		 :py:class:`Configuration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Configuration>`
        
        .. attribute:: filter
        
        	Apply a VLAN Map
        	**type**\: list of  		 :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Filter>`
        
        .. attribute:: accounting
        
        	VLAN accounting configuration
        	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Accounting>`
        
        	**presence node**\: True
        
        .. attribute:: internal
        
        	internal VLAN
        	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Internal>`
        
        .. attribute:: dot1q
        
        	dot1q parameters
        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Dot1q>`
        
        .. attribute:: access_log
        
        	Configure VACL logging
        	**type**\:  :py:class:`AccessLog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.AccessLog>`
        
        .. attribute:: group
        
        	Create a vlan group
        	**type**\: list of  		 :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Group>`
        
        .. attribute:: vlan_list
        
        	
        	**type**\: list of  		 :py:class:`VlanList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.VlanList>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Vlan, self).__init__()

            self.yang_name = "vlan"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-vlan:access-map", ("access_map", Native.Vlan.AccessMap)), ("Cisco-IOS-XE-vlan:configuration", ("configuration", Native.Vlan.Configuration)), ("Cisco-IOS-XE-vlan:filter", ("filter", Native.Vlan.Filter)), ("Cisco-IOS-XE-vlan:accounting", ("accounting", Native.Vlan.Accounting)), ("Cisco-IOS-XE-vlan:internal", ("internal", Native.Vlan.Internal)), ("Cisco-IOS-XE-vlan:dot1q", ("dot1q", Native.Vlan.Dot1q)), ("Cisco-IOS-XE-vlan:access-log", ("access_log", Native.Vlan.AccessLog)), ("Cisco-IOS-XE-vlan:group", ("group", Native.Vlan.Group)), ("Cisco-IOS-XE-vlan:vlan-list", ("vlan_list", Native.Vlan.VlanList))])
            self._leafs = OrderedDict()

            self.accounting = None
            self._children_name_map["accounting"] = "Cisco-IOS-XE-vlan:accounting"

            self.internal = Native.Vlan.Internal()
            self.internal.parent = self
            self._children_name_map["internal"] = "Cisco-IOS-XE-vlan:internal"

            self.dot1q = Native.Vlan.Dot1q()
            self.dot1q.parent = self
            self._children_name_map["dot1q"] = "Cisco-IOS-XE-vlan:dot1q"

            self.access_log = Native.Vlan.AccessLog()
            self.access_log.parent = self
            self._children_name_map["access_log"] = "Cisco-IOS-XE-vlan:access-log"

            self.access_map = YList(self)
            self.configuration = YList(self)
            self.filter = YList(self)
            self.group = YList(self)
            self.vlan_list = YList(self)
            self._segment_path = lambda: "vlan"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Vlan, [], name, value)


        class AccessMap(Entity):
            """
            Create vlan access\-map or enter vlan access\-map command mode
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: value
            
            	
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: action
            
            	Take the action
            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.AccessMap.Action>`
            
            .. attribute:: match
            
            	Match values
            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.AccessMap.Match>`
            
            

            """

            _prefix = 'ios-vlan'
            _revision = '2018-03-13'

            def __init__(self):
                super(Native.Vlan.AccessMap, self).__init__()

                self.yang_name = "access-map"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("match", ("match", Native.Vlan.AccessMap.Match))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                    ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Vlan.AccessMap.Action')])),
                ])
                self.name = None
                self.value = None
                self.action = None

                self.match = Native.Vlan.AccessMap.Match()
                self.match.parent = self
                self._children_name_map["match"] = "match"
                self._segment_path = lambda: "Cisco-IOS-XE-vlan:access-map" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vlan/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vlan.AccessMap, ['name', 'value', 'action'], name, value)

            class Action(Enum):
                """
                Action (Enum Class)

                Take the action

                .. data:: drop = 0

                .. data:: forward = 1

                """

                drop = Enum.YLeaf(0, "drop")

                forward = Enum.YLeaf(1, "forward")



            class Match(Entity):
                """
                Match values.
                
                .. attribute:: ipv6
                
                	IPv6 based match
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.AccessMap.Match.Ipv6>`
                
                .. attribute:: ip
                
                	IP based match
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.AccessMap.Match.Ip>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Vlan.AccessMap.Match, self).__init__()

                    self.yang_name = "match"
                    self.yang_parent_name = "access-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv6", ("ipv6", Native.Vlan.AccessMap.Match.Ipv6)), ("ip", ("ip", Native.Vlan.AccessMap.Match.Ip))])
                    self._leafs = OrderedDict()

                    self.ipv6 = Native.Vlan.AccessMap.Match.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.ip = Native.Vlan.AccessMap.Match.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "match"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vlan.AccessMap.Match, [], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 based match
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Vlan.AccessMap.Match.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeafList(YType.str, 'address'), ['str'])),
                        ])
                        self.address = []
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Vlan.AccessMap.Match.Ipv6, ['address'], name, value)


                class Ip(Entity):
                    """
                    IP based match
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Vlan.AccessMap.Match.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeafList(YType.str, 'address'), ['str'])),
                        ])
                        self.address = []
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Vlan.AccessMap.Match.Ip, ['address'], name, value)


        class Configuration(Entity):
            """
            vlan feature configuration mode
            
            .. attribute:: vlan_id  (key)
            
            	VLAN ID List Eg. 1\-10,15
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 1..4096
            
            		**type**\: str
            
            .. attribute:: ip
            
            	ip root chain
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Configuration.Ip>`
            
            .. attribute:: ipv6
            
            	Configure ipv6 dhcp guard
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Configuration.Ipv6>`
            
            .. attribute:: member
            
            	
            	**type**\:  :py:class:`Member <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Configuration.Member>`
            
            

            """

            _prefix = 'ios-vlan'
            _revision = '2018-03-13'

            def __init__(self):
                super(Native.Vlan.Configuration, self).__init__()

                self.yang_name = "configuration"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['vlan_id']
                self._child_classes = OrderedDict([("ip", ("ip", Native.Vlan.Configuration.Ip)), ("ipv6", ("ipv6", Native.Vlan.Configuration.Ipv6)), ("member", ("member", Native.Vlan.Configuration.Member))])
                self._leafs = OrderedDict([
                    ('vlan_id', (YLeaf(YType.str, 'vlan-id'), ['int','str'])),
                ])
                self.vlan_id = None

                self.ip = Native.Vlan.Configuration.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Vlan.Configuration.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.member = Native.Vlan.Configuration.Member()
                self.member.parent = self
                self._children_name_map["member"] = "member"
                self._segment_path = lambda: "Cisco-IOS-XE-vlan:configuration" + "[vlan-id='" + str(self.vlan_id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vlan/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vlan.Configuration, ['vlan_id'], name, value)


            class Ip(Entity):
                """
                ip root chain
                
                .. attribute:: flow
                
                	vlan NetFlow configuration commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Configuration.Ip.Flow>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Vlan.Configuration.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "configuration"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flow", ("flow", Native.Vlan.Configuration.Ip.Flow))])
                    self._leafs = OrderedDict()

                    self.flow = Native.Vlan.Configuration.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vlan.Configuration.Ip, [], name, value)


                class Flow(Entity):
                    """
                    vlan NetFlow configuration commands
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Configuration.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Vlan.Configuration.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Vlan.Configuration.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict()

                        self.monitor = YList(self)
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Vlan.Configuration.Ip.Flow, [], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: flow_monitor  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: input
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Vlan.Configuration.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['flow_monitor']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('flow_monitor', (YLeaf(YType.str, 'flow-monitor'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.flow_monitor = None
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "monitor" + "[flow-monitor='" + str(self.flow_monitor) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vlan.Configuration.Ip.Flow.Monitor, ['flow_monitor', 'input', 'output'], name, value)


            class Ipv6(Entity):
                """
                Configure ipv6 dhcp guard
                
                .. attribute:: nd
                
                	IPv6 nd configuration commands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Configuration.Ipv6.Nd>`
                
                .. attribute:: dhcp
                
                	dhcp feature
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Configuration.Ipv6.Dhcp>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Vlan.Configuration.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "configuration"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("nd", ("nd", Native.Vlan.Configuration.Ipv6.Nd)), ("dhcp", ("dhcp", Native.Vlan.Configuration.Ipv6.Dhcp))])
                    self._leafs = OrderedDict()

                    self.nd = Native.Vlan.Configuration.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.dhcp = Native.Vlan.Configuration.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vlan.Configuration.Ipv6, [], name, value)


                class Nd(Entity):
                    """
                    IPv6 nd configuration commands
                    
                    .. attribute:: suppress
                    
                    	Configure ND suppress on the vlan
                    	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Configuration.Ipv6.Nd.Suppress>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Vlan.Configuration.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("suppress", ("suppress", Native.Vlan.Configuration.Ipv6.Nd.Suppress))])
                        self._leafs = OrderedDict()

                        self.suppress = None
                        self._children_name_map["suppress"] = "suppress"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Vlan.Configuration.Ipv6.Nd, [], name, value)


                    class Suppress(Entity):
                        """
                        Configure ND suppress on the vlan
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature ND suppress
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Vlan.Configuration.Ipv6.Nd.Suppress, self).__init__()

                            self.yang_name = "suppress"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "suppress"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vlan.Configuration.Ipv6.Nd.Suppress, ['attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    dhcp feature
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard for vlan configuration
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Configuration.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Vlan.Configuration.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("guard", ("guard", Native.Vlan.Configuration.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.guard = None
                        self._children_name_map["guard"] = "guard"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Vlan.Configuration.Ipv6.Dhcp, [], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard for vlan configuration
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Vlan.Configuration.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Vlan.Configuration.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


            class Member(Entity):
                """
                
                
                .. attribute:: evpn_instance
                
                	Ethernet Virtual Private Network (EVPN)
                	**type**\:  :py:class:`EvpnInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Configuration.Member.EvpnInstance>`
                
                .. attribute:: vni
                
                	VxLAN VNI value
                	**type**\: int
                
                	**range:** 4096..16777215
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Vlan.Configuration.Member, self).__init__()

                    self.yang_name = "member"
                    self.yang_parent_name = "configuration"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("evpn-instance", ("evpn_instance", Native.Vlan.Configuration.Member.EvpnInstance))])
                    self._leafs = OrderedDict([
                        ('vni', (YLeaf(YType.uint32, 'vni'), ['int'])),
                    ])
                    self.vni = None

                    self.evpn_instance = Native.Vlan.Configuration.Member.EvpnInstance()
                    self.evpn_instance.parent = self
                    self._children_name_map["evpn_instance"] = "evpn-instance"
                    self._segment_path = lambda: "member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vlan.Configuration.Member, ['vni'], name, value)


                class EvpnInstance(Entity):
                    """
                    Ethernet Virtual Private Network (EVPN)
                    
                    .. attribute:: evpn_instance
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: vni
                    
                    	VxLAN VNI value
                    	**type**\: int
                    
                    	**range:** 4096..16777215
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Vlan.Configuration.Member.EvpnInstance, self).__init__()

                        self.yang_name = "evpn-instance"
                        self.yang_parent_name = "member"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('evpn_instance', (YLeaf(YType.uint16, 'evpn-instance'), ['int'])),
                            ('vni', (YLeaf(YType.uint32, 'vni'), ['int'])),
                        ])
                        self.evpn_instance = None
                        self.vni = None
                        self._segment_path = lambda: "evpn-instance"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Vlan.Configuration.Member.EvpnInstance, ['evpn_instance', 'vni'], name, value)


        class Filter(Entity):
            """
            Apply a VLAN Map
            
            .. attribute:: word  (key)
            
            	
            	**type**\: str
            
            .. attribute:: vlan_list
            
            	VLANs to apply filter to
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 1..4094
            
            		**type**\: str
            
            

            """

            _prefix = 'ios-vlan'
            _revision = '2018-03-13'

            def __init__(self):
                super(Native.Vlan.Filter, self).__init__()

                self.yang_name = "filter"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['word']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                    ('vlan_list', (YLeaf(YType.str, 'vlan-list'), ['int','str'])),
                ])
                self.word = None
                self.vlan_list = None
                self._segment_path = lambda: "Cisco-IOS-XE-vlan:filter" + "[word='" + str(self.word) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vlan/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vlan.Filter, ['word', 'vlan_list'], name, value)


        class Accounting(Entity):
            """
            VLAN accounting configuration
            
            .. attribute:: input
            
            	Input accounting
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: output
            
            	Output accounting
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-vlan'
            _revision = '2018-03-13'

            def __init__(self):
                super(Native.Vlan.Accounting, self).__init__()

                self.yang_name = "accounting"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                    ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                ])
                self.input = None
                self.output = None
                self._segment_path = lambda: "Cisco-IOS-XE-vlan:accounting"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vlan/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vlan.Accounting, ['input', 'output'], name, value)


        class Internal(Entity):
            """
            internal VLAN
            
            .. attribute:: allocation
            
            	internal VLAN allocation
            	**type**\:  :py:class:`Allocation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Internal.Allocation>`
            
            

            """

            _prefix = 'ios-vlan'
            _revision = '2018-03-13'

            def __init__(self):
                super(Native.Vlan.Internal, self).__init__()

                self.yang_name = "internal"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("allocation", ("allocation", Native.Vlan.Internal.Allocation))])
                self._leafs = OrderedDict()

                self.allocation = Native.Vlan.Internal.Allocation()
                self.allocation.parent = self
                self._children_name_map["allocation"] = "allocation"
                self._segment_path = lambda: "Cisco-IOS-XE-vlan:internal"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vlan/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vlan.Internal, [], name, value)


            class Allocation(Entity):
                """
                internal VLAN allocation
                
                .. attribute:: policy
                
                	
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Internal.Allocation.Policy>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Vlan.Internal.Allocation, self).__init__()

                    self.yang_name = "allocation"
                    self.yang_parent_name = "internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('policy', (YLeaf(YType.enumeration, 'policy'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Vlan.Internal.Allocation.Policy')])),
                    ])
                    self.policy = None
                    self._segment_path = lambda: "allocation"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vlan/Cisco-IOS-XE-vlan:internal/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vlan.Internal.Allocation, ['policy'], name, value)

                class Policy(Enum):
                    """
                    Policy (Enum Class)

                    .. data:: ascending = 0

                    .. data:: descending = 1

                    """

                    ascending = Enum.YLeaf(0, "ascending")

                    descending = Enum.YLeaf(1, "descending")



        class Dot1q(Entity):
            """
            dot1q parameters
            
            .. attribute:: tag
            
            	tag parameters
            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Dot1q.Tag>`
            
            

            """

            _prefix = 'ios-vlan'
            _revision = '2018-03-13'

            def __init__(self):
                super(Native.Vlan.Dot1q, self).__init__()

                self.yang_name = "dot1q"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("tag", ("tag", Native.Vlan.Dot1q.Tag))])
                self._leafs = OrderedDict()

                self.tag = Native.Vlan.Dot1q.Tag()
                self.tag.parent = self
                self._children_name_map["tag"] = "tag"
                self._segment_path = lambda: "Cisco-IOS-XE-vlan:dot1q"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vlan/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vlan.Dot1q, [], name, value)


            class Tag(Entity):
                """
                tag parameters
                
                .. attribute:: native
                
                	tag native vlan
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Vlan.Dot1q.Tag, self).__init__()

                    self.yang_name = "tag"
                    self.yang_parent_name = "dot1q"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                    ])
                    self.native = None
                    self._segment_path = lambda: "tag"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vlan/Cisco-IOS-XE-vlan:dot1q/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vlan.Dot1q.Tag, ['native'], name, value)


        class AccessLog(Entity):
            """
            Configure VACL logging
            
            .. attribute:: maxflow
            
            	Set vacl logging maximum flow number
            	**type**\: int
            
            	**range:** 0..2048
            
            .. attribute:: ratelimit
            
            	Set vacl logging rate limiter
            	**type**\: int
            
            	**range:** 10..5000
            
            .. attribute:: threshold
            
            	Set vacl log\-update threshold
            	**type**\: int
            
            	**range:** 0..2147483647
            
            

            """

            _prefix = 'ios-vlan'
            _revision = '2018-03-13'

            def __init__(self):
                super(Native.Vlan.AccessLog, self).__init__()

                self.yang_name = "access-log"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('maxflow', (YLeaf(YType.uint16, 'maxflow'), ['int'])),
                    ('ratelimit', (YLeaf(YType.uint16, 'ratelimit'), ['int'])),
                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                ])
                self.maxflow = None
                self.ratelimit = None
                self.threshold = None
                self._segment_path = lambda: "Cisco-IOS-XE-vlan:access-log"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vlan/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vlan.AccessLog, ['maxflow', 'ratelimit', 'threshold'], name, value)


        class Group(Entity):
            """
            Create a vlan group
            
            .. attribute:: name  (key)
            
            	Group name starts with alphabet
            	**type**\: str
            
            .. attribute:: vlan_list
            
            	List of vlans in this group
            	**type**\: list of  		 :py:class:`VlanList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.Group.VlanList>`
            
            

            """

            _prefix = 'ios-vlan'
            _revision = '2018-03-13'

            def __init__(self):
                super(Native.Vlan.Group, self).__init__()

                self.yang_name = "group"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("vlan-list", ("vlan_list", Native.Vlan.Group.VlanList))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.vlan_list = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-vlan:group" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vlan/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vlan.Group, ['name'], name, value)


            class VlanList(Entity):
                """
                List of vlans in this group
                
                .. attribute:: vlan_id  (key)
                
                	a single VLAN id (allowed value range 1\-4094) \\ or Comma\-separated VLAN id range. \\ e.g. 99 or 1\-30 or  1\-20,30,40\-50
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4094
                
                		**type**\: str
                
                			**pattern:** ((\\d+(\-\\d+)?)(,(\\d+(\-\\d+)?))\*)
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Vlan.Group.VlanList, self).__init__()

                    self.yang_name = "vlan-list"
                    self.yang_parent_name = "group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['vlan_id']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vlan_id', (YLeaf(YType.str, 'vlan-id'), ['int','str'])),
                    ])
                    self.vlan_id = None
                    self._segment_path = lambda: "vlan-list" + "[vlan-id='" + str(self.vlan_id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vlan.Group.VlanList, ['vlan_id'], name, value)


        class VlanList(Entity):
            """
            
            
            .. attribute:: id  (key)
            
            	a single VLAN id (allowed value range 1\-4094) \\ or Comma\-separated VLAN id range. \\ e.g. 99 or 1\-30 or  1\-20,30,40\-50
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 1..4094
            
            		**type**\: str
            
            			**pattern:** ((\\d+(\-\\d+)?)(,(\\d+(\-\\d+)?))\*)
            
            .. attribute:: remote_span
            
            	Configure as Remote SPAN VLAN
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: private_vlan
            
            	Configure a private VLAN
            	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.VlanList.PrivateVlan>`
            
            .. attribute:: name
            
            	Ascii name of the VLAN
            	**type**\: str
            
            	**length:** 1..100
            
            .. attribute:: state
            
            	Operational state of the VLAN
            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.VlanList.State>`
            
            .. attribute:: lldp
            
            	
            	**type**\:  :py:class:`Lldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.VlanList.Lldp>`
            
            .. attribute:: uni_vlan
            
            	Configure a UNI VLAN
            	**type**\:  :py:class:`UniVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vlan.VlanList.UniVlan>`
            
            

            """

            _prefix = 'ios-vlan'
            _revision = '2018-03-13'

            def __init__(self):
                super(Native.Vlan.VlanList, self).__init__()

                self.yang_name = "vlan-list"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("private-vlan", ("private_vlan", Native.Vlan.VlanList.PrivateVlan)), ("lldp", ("lldp", Native.Vlan.VlanList.Lldp))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                    ('remote_span', (YLeaf(YType.empty, 'remote-span'), ['Empty'])),
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Vlan.VlanList.State')])),
                    ('uni_vlan', (YLeaf(YType.enumeration, 'uni-vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Vlan.VlanList.UniVlan')])),
                ])
                self.id = None
                self.remote_span = None
                self.name = None
                self.state = None
                self.uni_vlan = None

                self.private_vlan = Native.Vlan.VlanList.PrivateVlan()
                self.private_vlan.parent = self
                self._children_name_map["private_vlan"] = "private-vlan"

                self.lldp = Native.Vlan.VlanList.Lldp()
                self.lldp.parent = self
                self._children_name_map["lldp"] = "lldp"
                self._segment_path = lambda: "Cisco-IOS-XE-vlan:vlan-list" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vlan/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vlan.VlanList, ['id', 'remote_span', 'name', 'state', 'uni_vlan'], name, value)

            class State(Enum):
                """
                State (Enum Class)

                Operational state of the VLAN

                .. data:: active = 0

                .. data:: suspend = 1

                """

                active = Enum.YLeaf(0, "active")

                suspend = Enum.YLeaf(1, "suspend")


            class UniVlan(Enum):
                """
                UniVlan (Enum Class)

                Configure a UNI VLAN

                .. data:: community = 0

                .. data:: isolated = 1

                """

                community = Enum.YLeaf(0, "community")

                isolated = Enum.YLeaf(1, "isolated")



            class PrivateVlan(Entity):
                """
                Configure a private VLAN
                
                .. attribute:: primary
                
                	Configure the VLAN as a primary private VLAN
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: association
                
                	Configure association between private VLANs
                	**type**\: str
                
                .. attribute:: community
                
                	Configure the VLAN as a community private VLAN
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: isolated
                
                	Configure the VLAN as an isolated private VLAN
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Vlan.VlanList.PrivateVlan, self).__init__()

                    self.yang_name = "private-vlan"
                    self.yang_parent_name = "vlan-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                        ('association', (YLeaf(YType.str, 'association'), ['str'])),
                        ('community', (YLeaf(YType.empty, 'community'), ['Empty'])),
                        ('isolated', (YLeaf(YType.empty, 'isolated'), ['Empty'])),
                    ])
                    self.primary = None
                    self.association = None
                    self.community = None
                    self.isolated = None
                    self._segment_path = lambda: "private-vlan"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vlan.VlanList.PrivateVlan, ['primary', 'association', 'community', 'isolated'], name, value)


            class Lldp(Entity):
                """
                
                
                .. attribute:: run
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Vlan.VlanList.Lldp, self).__init__()

                    self.yang_name = "lldp"
                    self.yang_parent_name = "vlan-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('run', (YLeaf(YType.empty, 'run'), ['Empty'])),
                    ])
                    self.run = None
                    self._segment_path = lambda: "lldp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vlan.VlanList.Lldp, ['run'], name, value)


    class Mvrp(Entity):
        """
        Global MVRP
        
        .. attribute:: global_
        
        	
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: mac_learning
        
        	
        	**type**\:  :py:class:`MacLearning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mvrp.MacLearning>`
        
        .. attribute:: vlan
        
        	
        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mvrp.Vlan>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Mvrp, self).__init__()

            self.yang_name = "mvrp"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-mvrp:mac-learning", ("mac_learning", Native.Mvrp.MacLearning)), ("Cisco-IOS-XE-mvrp:vlan", ("vlan", Native.Mvrp.Vlan))])
            self._leafs = OrderedDict([
                ('global_', (YLeaf(YType.empty, 'Cisco-IOS-XE-mvrp:global'), ['Empty'])),
            ])
            self.global_ = None

            self.mac_learning = Native.Mvrp.MacLearning()
            self.mac_learning.parent = self
            self._children_name_map["mac_learning"] = "Cisco-IOS-XE-mvrp:mac-learning"

            self.vlan = Native.Mvrp.Vlan()
            self.vlan.parent = self
            self._children_name_map["vlan"] = "Cisco-IOS-XE-mvrp:vlan"
            self._segment_path = lambda: "mvrp"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Mvrp, ['global_'], name, value)


        class MacLearning(Entity):
            """
            
            
            .. attribute:: auto
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-mvrp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Mvrp.MacLearning, self).__init__()

                self.yang_name = "mac-learning"
                self.yang_parent_name = "mvrp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                ])
                self.auto = None
                self._segment_path = lambda: "Cisco-IOS-XE-mvrp:mac-learning"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mvrp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mvrp.MacLearning, ['auto'], name, value)


        class Vlan(Entity):
            """
            
            
            .. attribute:: create
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-mvrp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Mvrp.Vlan, self).__init__()

                self.yang_name = "vlan"
                self.yang_parent_name = "mvrp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('create', (YLeaf(YType.empty, 'create'), ['Empty'])),
                ])
                self.create = None
                self._segment_path = lambda: "Cisco-IOS-XE-mvrp:vlan"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mvrp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mvrp.Vlan, ['create'], name, value)


    class Avb(Entity):
        """
        Global AVB
        
        .. attribute:: strict
        
        	
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        This class is a :ref:`presence class<presence-class>`

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Avb, self).__init__()

            self.yang_name = "avb"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self.is_presence_container = True
            self._leafs = OrderedDict([
                ('strict', (YLeaf(YType.empty, 'Cisco-IOS-XE-avb:strict'), ['Empty'])),
            ])
            self.strict = None
            self._segment_path = lambda: "avb"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Avb, ['strict'], name, value)


    class Ptp(Entity):
        """
        Global PTP
        
        .. attribute:: domain
        
        	Clock domain number
        	**type**\: int
        
        	**range:** 0..255
        
        .. attribute:: profile
        
        	
        	**type**\:  :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ptp.Profile>`
        
        .. attribute:: neighbor_propagation_delay_threshold
        
        	in nanoseconds
        	**type**\: int
        
        	**range:** 1..2147483646
        
        .. attribute:: priority1
        
        	clock priority1 number
        	**type**\: int
        
        	**range:** 0..255
        
        .. attribute:: priority2
        
        	clock priority2 number
        	**type**\: int
        
        	**range:** 0..255
        
        .. attribute:: mode
        
        	
        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ptp.Mode>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Ptp, self).__init__()

            self.yang_name = "ptp"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-ptp:profile", ("profile", Native.Ptp.Profile)), ("Cisco-IOS-XE-ptp:mode", ("mode", Native.Ptp.Mode))])
            self._leafs = OrderedDict([
                ('domain', (YLeaf(YType.uint8, 'Cisco-IOS-XE-ptp:domain'), ['int'])),
                ('neighbor_propagation_delay_threshold', (YLeaf(YType.uint32, 'Cisco-IOS-XE-ptp:neighbor-propagation-delay-threshold'), ['int'])),
                ('priority1', (YLeaf(YType.uint8, 'Cisco-IOS-XE-ptp:priority1'), ['int'])),
                ('priority2', (YLeaf(YType.uint8, 'Cisco-IOS-XE-ptp:priority2'), ['int'])),
            ])
            self.domain = None
            self.neighbor_propagation_delay_threshold = None
            self.priority1 = None
            self.priority2 = None

            self.profile = Native.Ptp.Profile()
            self.profile.parent = self
            self._children_name_map["profile"] = "Cisco-IOS-XE-ptp:profile"

            self.mode = Native.Ptp.Mode()
            self.mode.parent = self
            self._children_name_map["mode"] = "Cisco-IOS-XE-ptp:mode"
            self._segment_path = lambda: "ptp"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Ptp, ['domain', 'neighbor_propagation_delay_threshold', 'priority1', 'priority2'], name, value)


        class Profile(Entity):
            """
            
            
            .. attribute:: dot1as
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-ptp'
            _revision = '2017-09-19'

            def __init__(self):
                super(Native.Ptp.Profile, self).__init__()

                self.yang_name = "profile"
                self.yang_parent_name = "ptp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('dot1as', (YLeaf(YType.empty, 'dot1as'), ['Empty'])),
                ])
                self.dot1as = None
                self._segment_path = lambda: "Cisco-IOS-XE-ptp:profile"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ptp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ptp.Profile, ['dot1as'], name, value)


        class Mode(Entity):
            """
            
            
            .. attribute:: boundary
            
            	
            	**type**\:  :py:class:`Boundary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ptp.Mode.Boundary>`
            
            .. attribute:: e2etransparent
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: p2ptransparent
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-ptp'
            _revision = '2017-09-19'

            def __init__(self):
                super(Native.Ptp.Mode, self).__init__()

                self.yang_name = "mode"
                self.yang_parent_name = "ptp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("boundary", ("boundary", Native.Ptp.Mode.Boundary))])
                self._leafs = OrderedDict([
                    ('e2etransparent', (YLeaf(YType.empty, 'e2etransparent'), ['Empty'])),
                    ('p2ptransparent', (YLeaf(YType.empty, 'p2ptransparent'), ['Empty'])),
                ])
                self.e2etransparent = None
                self.p2ptransparent = None

                self.boundary = Native.Ptp.Mode.Boundary()
                self.boundary.parent = self
                self._children_name_map["boundary"] = "boundary"
                self._segment_path = lambda: "Cisco-IOS-XE-ptp:mode"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ptp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ptp.Mode, ['e2etransparent', 'p2ptransparent'], name, value)


            class Boundary(Entity):
                """
                
                
                .. attribute:: delay_req
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pdelay_req
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ptp'
                _revision = '2017-09-19'

                def __init__(self):
                    super(Native.Ptp.Mode.Boundary, self).__init__()

                    self.yang_name = "boundary"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('delay_req', (YLeaf(YType.empty, 'delay-req'), ['Empty'])),
                        ('pdelay_req', (YLeaf(YType.empty, 'pdelay-req'), ['Empty'])),
                    ])
                    self.delay_req = None
                    self.pdelay_req = None
                    self._segment_path = lambda: "boundary"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ptp/Cisco-IOS-XE-ptp:mode/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ptp.Mode.Boundary, ['delay_req', 'pdelay_req'], name, value)


    class Cdp(Entity):
        """
        Global CDP configuration subcommands
        
        .. attribute:: holdtime
        
        	Specify the holdtime (in sec) to be sent in packets
        	**type**\: int
        
        	**range:** 10..255
        
        .. attribute:: timer
        
        	Specify the rate at which CDP packets are sent (in sec)
        	**type**\: int
        
        	**range:** 5..254
        
        .. attribute:: run
        
        	Enable CDP
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Cdp, self).__init__()

            self.yang_name = "cdp"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('holdtime', (YLeaf(YType.uint8, 'Cisco-IOS-XE-cdp:holdtime'), ['int'])),
                ('timer', (YLeaf(YType.uint8, 'Cisco-IOS-XE-cdp:timer'), ['int'])),
                ('run', (YLeaf(YType.empty, 'Cisco-IOS-XE-cdp:run'), ['Empty'])),
            ])
            self.holdtime = None
            self.timer = None
            self.run = None
            self._segment_path = lambda: "cdp"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Cdp, ['holdtime', 'timer', 'run'], name, value)


    class Avc(Entity):
        """
        Application visibility and control
        
        .. attribute:: sd_service
        
        	SD\-AVC service
        	**type**\:  :py:class:`SdService <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avc.SdService>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Avc, self).__init__()

            self.yang_name = "avc"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-nbar:sd-service", ("sd_service", Native.Avc.SdService))])
            self._leafs = OrderedDict()

            self.sd_service = None
            self._children_name_map["sd_service"] = "Cisco-IOS-XE-nbar:sd-service"
            self._segment_path = lambda: "avc"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Avc, [], name, value)


        class SdService(Entity):
            """
            SD\-AVC service
            
            .. attribute:: segment
            
            	Segment name identifying a group of devices sharing the same application services
            	**type**\: str
            
            .. attribute:: controller
            
            	Controller connectivity parameters
            	**type**\:  :py:class:`Controller <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avc.SdService.Controller>`
            
            	**presence node**\: True
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-nbar'
            _revision = '2018-06-06'

            def __init__(self):
                super(Native.Avc.SdService, self).__init__()

                self.yang_name = "sd-service"
                self.yang_parent_name = "avc"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("controller", ("controller", Native.Avc.SdService.Controller))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('segment', (YLeaf(YType.str, 'segment'), ['str'])),
                ])
                self.segment = None

                self.controller = None
                self._children_name_map["controller"] = "controller"
                self._segment_path = lambda: "Cisco-IOS-XE-nbar:sd-service"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/avc/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Avc.SdService, ['segment'], name, value)


            class Controller(Entity):
                """
                Controller connectivity parameters
                
                .. attribute:: address
                
                	Export destination configuration
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avc.SdService.Controller.Address>`
                
                .. attribute:: destination_ports
                
                	Ports used for communication with controller
                	**type**\:  :py:class:`DestinationPorts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avc.SdService.Controller.DestinationPorts>`
                
                .. attribute:: dscp
                
                	DSCP marking
                	**type**\: int
                
                	**range:** 0..63
                
                .. attribute:: source_interface
                
                	Interface of source address used for communication with controller
                	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avc.SdService.Controller.SourceInterface>`
                
                .. attribute:: vrf
                
                	VRF Label
                	**type**\: str
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-nbar'
                _revision = '2018-06-06'

                def __init__(self):
                    super(Native.Avc.SdService.Controller, self).__init__()

                    self.yang_name = "controller"
                    self.yang_parent_name = "sd-service"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("address", ("address", Native.Avc.SdService.Controller.Address)), ("destination-ports", ("destination_ports", Native.Avc.SdService.Controller.DestinationPorts)), ("source-interface", ("source_interface", Native.Avc.SdService.Controller.SourceInterface))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ])
                    self.dscp = None
                    self.vrf = None

                    self.address = Native.Avc.SdService.Controller.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.destination_ports = Native.Avc.SdService.Controller.DestinationPorts()
                    self.destination_ports.parent = self
                    self._children_name_map["destination_ports"] = "destination-ports"

                    self.source_interface = Native.Avc.SdService.Controller.SourceInterface()
                    self.source_interface.parent = self
                    self._children_name_map["source_interface"] = "source-interface"
                    self._segment_path = lambda: "controller"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/avc/Cisco-IOS-XE-nbar:sd-service/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Avc.SdService.Controller, ['dscp', 'vrf'], name, value)


                class Address(Entity):
                    """
                    Export destination configuration
                    
                    .. attribute:: ipv4_or_hostname
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4OrHostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avc.SdService.Controller.Address.Ipv4OrHostname>`
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Avc.SdService.Controller.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "controller"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4-or-hostname", ("ipv4_or_hostname", Native.Avc.SdService.Controller.Address.Ipv4OrHostname))])
                        self._leafs = OrderedDict()

                        self.ipv4_or_hostname = YList(self)
                        self._segment_path = lambda: "address"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/avc/Cisco-IOS-XE-nbar:sd-service/controller/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Avc.SdService.Controller.Address, [], name, value)


                    class Ipv4OrHostname(Entity):
                        """
                        
                        
                        .. attribute:: ipv4_or_hostname  (key)
                        
                        	Primary controller's IPv4 address or hostname
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: ipv4_or_hostname0
                        
                        	Secondary controller's IPv4 address or hostname
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Avc.SdService.Controller.Address.Ipv4OrHostname, self).__init__()

                            self.yang_name = "ipv4-or-hostname"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ipv4_or_hostname']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_or_hostname', (YLeaf(YType.str, 'ipv4-or-hostname'), ['str','str','str'])),
                                ('ipv4_or_hostname0', (YLeaf(YType.str, 'ipv4-or-hostname0'), ['str','str','str'])),
                            ])
                            self.ipv4_or_hostname = None
                            self.ipv4_or_hostname0 = None
                            self._segment_path = lambda: "ipv4-or-hostname" + "[ipv4-or-hostname='" + str(self.ipv4_or_hostname) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/avc/Cisco-IOS-XE-nbar:sd-service/controller/address/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Avc.SdService.Controller.Address.Ipv4OrHostname, ['ipv4_or_hostname', 'ipv4_or_hostname0'], name, value)


                class DestinationPorts(Entity):
                    """
                    Ports used for communication with controller
                    
                    .. attribute:: application_updates
                    
                    	TCP port used for application\-updates
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: sensor_exporter
                    
                    	UDP port used for sensor messages
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Avc.SdService.Controller.DestinationPorts, self).__init__()

                        self.yang_name = "destination-ports"
                        self.yang_parent_name = "controller"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('application_updates', (YLeaf(YType.uint16, 'application-updates'), ['int'])),
                            ('sensor_exporter', (YLeaf(YType.uint16, 'sensor-exporter'), ['int'])),
                        ])
                        self.application_updates = None
                        self.sensor_exporter = None
                        self._segment_path = lambda: "destination-ports"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/avc/Cisco-IOS-XE-nbar:sd-service/controller/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Avc.SdService.Controller.DestinationPorts, ['application_updates', 'sensor_exporter'], name, value)


                class SourceInterface(Entity):
                    """
                    Interface of source address used for communication with controller
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avc.SdService.Controller.SourceInterface.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avc.SdService.Controller.SourceInterface.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avc.SdService.Controller.SourceInterface.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Avc.SdService.Controller.SourceInterface.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Avc.SdService.Controller.SourceInterface, self).__init__()

                        self.yang_name = "source-interface"
                        self.yang_parent_name = "controller"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Avc.SdService.Controller.SourceInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Avc.SdService.Controller.SourceInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Avc.SdService.Controller.SourceInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Avc.SdService.Controller.SourceInterface.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Avc.SdService.Controller.SourceInterface.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Avc.SdService.Controller.SourceInterface.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Avc.SdService.Controller.SourceInterface.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Avc.SdService.Controller.SourceInterface.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "source-interface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/avc/Cisco-IOS-XE-nbar:sd-service/controller/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Avc.SdService.Controller.SourceInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Avc.SdService.Controller.SourceInterface.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "source-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/avc/Cisco-IOS-XE-nbar:sd-service/controller/source-interface/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Avc.SdService.Controller.SourceInterface.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Avc.SdService.Controller.SourceInterface.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "source-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/avc/Cisco-IOS-XE-nbar:sd-service/controller/source-interface/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Avc.SdService.Controller.SourceInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Avc.SdService.Controller.SourceInterface.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "source-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/avc/Cisco-IOS-XE-nbar:sd-service/controller/source-interface/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Avc.SdService.Controller.SourceInterface.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Avc.SdService.Controller.SourceInterface.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "source-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/avc/Cisco-IOS-XE-nbar:sd-service/controller/source-interface/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Avc.SdService.Controller.SourceInterface.PortChannelSubinterface, [u'port_channel'], name, value)


    class Policy(Entity):
        """
        
        
        .. attribute:: class_map
        
        	configure qos class map
        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
        
        .. attribute:: policy_map
        
        	Configure QoS Policy Map
        	**type**\: list of  		 :py:class:`PolicyMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Policy, self).__init__()

            self.yang_name = "policy"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-policy:class-map", ("class_map", Native.Policy.ClassMap)), ("Cisco-IOS-XE-policy:policy-map", ("policy_map", Native.Policy.PolicyMap))])
            self._leafs = OrderedDict()

            self.class_map = YList(self)
            self.policy_map = YList(self)
            self._segment_path = lambda: "policy"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Policy, [], name, value)


        class ClassMap(Entity):
            """
            configure qos class map
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            	**length:** 1..512
            
            .. attribute:: type
            
            	type of the class\-map
            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Type>`
            
            .. attribute:: subscriber
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: protocol
            
            	
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Protocol>`
            
            .. attribute:: prematch
            
            	
            	**type**\:  :py:class:`Prematch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Prematch>`
            
            	**mandatory**\: True
            
            .. attribute:: description
            
            	Class\-Map description
            	**type**\: str
            
            	**length:** 1..200
            
            .. attribute:: match
            
            	classification criteria
            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match>`
            
            .. attribute:: no_match
            
            	no\-match filter
            	**type**\:  :py:class:`NoMatch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch>`
            
            

            """

            _prefix = 'ios-policy'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Policy.ClassMap, self).__init__()

                self.yang_name = "class-map"
                self.yang_parent_name = "policy"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("match", ("match", Native.Policy.ClassMap.Match)), ("no-match", ("no_match", Native.Policy.ClassMap.NoMatch))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.ClassMap.Type')])),
                    ('subscriber', (YLeaf(YType.empty, 'subscriber'), ['Empty'])),
                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.ClassMap.Protocol')])),
                    ('prematch', (YLeaf(YType.enumeration, 'prematch'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.ClassMap.Prematch')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                ])
                self.name = None
                self.type = None
                self.subscriber = None
                self.protocol = None
                self.prematch = None
                self.description = None

                self.match = Native.Policy.ClassMap.Match()
                self.match.parent = self
                self._children_name_map["match"] = "match"

                self.no_match = Native.Policy.ClassMap.NoMatch()
                self.no_match.parent = self
                self._children_name_map["no_match"] = "no-match"
                self._segment_path = lambda: "Cisco-IOS-XE-policy:class-map" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/policy/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Policy.ClassMap, ['name', 'type', 'subscriber', 'protocol', 'prematch', 'description'], name, value)

            class Prematch(Enum):
                """
                Prematch (Enum Class)

                .. data:: match_all = 0

                .. data:: match_any = 1

                .. data:: match_none = 2

                """

                match_all = Enum.YLeaf(0, "match-all")

                match_any = Enum.YLeaf(1, "match-any")

                match_none = Enum.YLeaf(2, "match-none")


            class Protocol(Enum):
                """
                Protocol (Enum Class)

                .. data:: aol = 0

                .. data:: edonkey = 1

                .. data:: fasttrack = 2

                .. data:: gnutella = 3

                .. data:: http = 4

                .. data:: imap = 5

                .. data:: kazaa2 = 6

                .. data:: msnmsgr = 7

                .. data:: pop3 = 8

                .. data:: smtp = 9

                .. data:: sunrpc = 10

                .. data:: ymsgr = 11

                """

                aol = Enum.YLeaf(0, "aol")

                edonkey = Enum.YLeaf(1, "edonkey")

                fasttrack = Enum.YLeaf(2, "fasttrack")

                gnutella = Enum.YLeaf(3, "gnutella")

                http = Enum.YLeaf(4, "http")

                imap = Enum.YLeaf(5, "imap")

                kazaa2 = Enum.YLeaf(6, "kazaa2")

                msnmsgr = Enum.YLeaf(7, "msnmsgr")

                pop3 = Enum.YLeaf(8, "pop3")

                smtp = Enum.YLeaf(9, "smtp")

                sunrpc = Enum.YLeaf(10, "sunrpc")

                ymsgr = Enum.YLeaf(11, "ymsgr")


            class Type(Enum):
                """
                Type (Enum Class)

                type of the class\-map

                .. data:: access_control = 0

                .. data:: appnav = 1

                .. data:: control = 2

                .. data:: inspect = 3

                .. data:: multicast_flows = 4

                .. data:: stack = 5

                .. data:: traffic = 6

                """

                access_control = Enum.YLeaf(0, "access-control")

                appnav = Enum.YLeaf(1, "appnav")

                control = Enum.YLeaf(2, "control")

                inspect = Enum.YLeaf(3, "inspect")

                multicast_flows = Enum.YLeaf(4, "multicast-flows")

                stack = Enum.YLeaf(5, "stack")

                traffic = Enum.YLeaf(6, "traffic")



            class Match(Entity):
                """
                classification criteria
                
                .. attribute:: current_method_priority
                
                	match the priority against the current method's priority
                	**type**\:  :py:class:`CurrentMethodPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.CurrentMethodPriority>`
                
                .. attribute:: application
                
                	Application to match
                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Application>`
                
                .. attribute:: access_group
                
                	Access group
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.AccessGroup>`
                
                .. attribute:: any
                
                	Any packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: class_map
                
                	Class map
                	**type**\: list of str
                
                	**length:** 1..512
                
                .. attribute:: cos
                
                	IEEE 802.1Q/ISL class of service/user priority values
                	**type**\: list of int
                
                	**range:** 0..7
                
                .. attribute:: destination_address
                
                	Destination address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.DestinationAddress>`
                
                .. attribute:: discard_class
                
                	Discard behavior identifier
                	**type**\: list of int
                
                	**range:** 0..7
                
                .. attribute:: dscp
                
                	Match DSCP in IP(v4) and IPv6 packets
                	**type**\: union of the below types:
                
                		**type**\: list of int
                
                			**range:** 0..63
                
                		**type**\: list of   :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                
                .. attribute:: fr_de
                
                	Match on Frame\-relay DE bit
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: fr_dlci
                
                	Match on fr\-dlci
                	**type**\: list of int
                
                	**range:** 16..1007
                
                .. attribute:: group_object
                
                	Match object\-group
                	**type**\:  :py:class:`GroupObject <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.GroupObject>`
                
                .. attribute:: input_interface
                
                	Select an input interface to match
                	**type**\: list of str
                
                .. attribute:: ip
                
                	IP specific values
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Ip>`
                
                .. attribute:: non_client_nrt
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mpls
                
                	Multi Protocol Label Switching specific values
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Mpls>`
                
                .. attribute:: packet
                
                	Layer 3 Packet length
                	**type**\:  :py:class:`Packet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Packet>`
                
                .. attribute:: precedence
                
                	Match Precedence in IP(v4) and IPv6 packets
                	**type**\: union of the below types:
                
                		**type**\: list of int
                
                			**range:** 0..7
                
                		**type**\: list of   :py:class:`PrecedenceType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecedenceType>`
                
                .. attribute:: protocol
                
                	Protocol
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Protocol>`
                
                .. attribute:: qos_group
                
                	Qos\-group
                	**type**\: list of int
                
                	**range:** 0..99
                
                .. attribute:: security_group
                
                	Security group
                	**type**\:  :py:class:`SecurityGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.SecurityGroup>`
                
                .. attribute:: service
                
                	Service Instance to match
                	**type**\: list of  		 :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Service>`
                
                .. attribute:: source_address
                
                	Source address
                	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.SourceAddress>`
                
                .. attribute:: vlan
                
                	VLANs to match
                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Vlan>`
                
                .. attribute:: peer
                
                	APPNAV Peer Filter
                	**type**\: str
                
                .. attribute:: activated_service_template
                
                	match name of service template activated on session
                	**type**\: list of  		 :py:class:`ActivatedServiceTemplate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.ActivatedServiceTemplate>`
                
                .. attribute:: authorization_status
                
                	match the authorization status of the session
                	**type**\:  :py:class:`AuthorizationStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.AuthorizationStatus>`
                
                .. attribute:: authorizing_method_priority
                
                	match the priority against the authorizing method's priority
                	**type**\:  :py:class:`AuthorizingMethodPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.AuthorizingMethodPriority>`
                
                .. attribute:: client_type
                
                	match the type of device from an event
                	**type**\:  :py:class:`ClientType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.ClientType>`
                
                .. attribute:: device_type
                
                	match name of the device\-type
                	**type**\: str
                
                .. attribute:: interface
                
                	match the session interface
                	**type**\: str
                
                .. attribute:: ip_address
                
                	match the IP address from an event
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ipv6_address
                
                	match the IPv6 address from an event
                	**type**\: str
                
                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mac_address
                
                	match the MAC address from an event
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                
                .. attribute:: method
                
                	match the type of authentication method from an event
                	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Method>`
                
                .. attribute:: oui
                
                	match the oui address from an event
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                
                .. attribute:: port_type
                
                	match the type interface from an event
                	**type**\:  :py:class:`PortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.PortType>`
                
                .. attribute:: result_type
                
                	match the result type, optionally for a specific method
                	**type**\:  :py:class:`ResultType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.ResultType>`
                
                .. attribute:: service_template
                
                	match name of service template from an event
                	**type**\: str
                
                .. attribute:: session_type
                
                	match the session type
                	**type**\:  :py:class:`SessionType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.SessionType>`
                
                .. attribute:: sgt
                
                	match the sgt session
                	**type**\: int
                
                	**range:** 2..65519
                
                .. attribute:: ssid
                
                	match the ssid of the session
                	**type**\: str
                
                .. attribute:: tag
                
                	match tag from an event
                	**type**\: str
                
                .. attribute:: timer
                
                	match the type of timer
                	**type**\: str
                
                .. attribute:: user_role
                
                	match the user\-role
                	**type**\: str
                
                .. attribute:: username
                
                	match the username
                	**type**\: str
                
                .. attribute:: not_
                
                	Negate this match result
                	**type**\:  :py:class:`Not <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Policy.ClassMap.Match, self).__init__()

                    self.yang_name = "match"
                    self.yang_parent_name = "class-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("current-method-priority", ("current_method_priority", Native.Policy.ClassMap.Match.CurrentMethodPriority)), ("application", ("application", Native.Policy.ClassMap.Match.Application)), ("access-group", ("access_group", Native.Policy.ClassMap.Match.AccessGroup)), ("destination-address", ("destination_address", Native.Policy.ClassMap.Match.DestinationAddress)), ("group-object", ("group_object", Native.Policy.ClassMap.Match.GroupObject)), ("ip", ("ip", Native.Policy.ClassMap.Match.Ip)), ("mpls", ("mpls", Native.Policy.ClassMap.Match.Mpls)), ("packet", ("packet", Native.Policy.ClassMap.Match.Packet)), ("protocol", ("protocol", Native.Policy.ClassMap.Match.Protocol)), ("security-group", ("security_group", Native.Policy.ClassMap.Match.SecurityGroup)), ("service", ("service", Native.Policy.ClassMap.Match.Service)), ("source-address", ("source_address", Native.Policy.ClassMap.Match.SourceAddress)), ("vlan", ("vlan", Native.Policy.ClassMap.Match.Vlan)), ("activated-service-template", ("activated_service_template", Native.Policy.ClassMap.Match.ActivatedServiceTemplate)), ("authorization-status", ("authorization_status", Native.Policy.ClassMap.Match.AuthorizationStatus)), ("authorizing-method-priority", ("authorizing_method_priority", Native.Policy.ClassMap.Match.AuthorizingMethodPriority)), ("method", ("method", Native.Policy.ClassMap.Match.Method)), ("result-type", ("result_type", Native.Policy.ClassMap.Match.ResultType)), ("not", ("not_", Native.Policy.ClassMap.Match.Not))])
                    self._leafs = OrderedDict([
                        ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                        ('class_map', (YLeafList(YType.str, 'class-map'), ['str'])),
                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                        ('discard_class', (YLeafList(YType.uint8, 'discard-class'), ['int'])),
                        ('dscp', (YLeafList(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                        ('fr_de', (YLeaf(YType.empty, 'fr-de'), ['Empty'])),
                        ('fr_dlci', (YLeafList(YType.uint16, 'fr-dlci'), ['int'])),
                        ('input_interface', (YLeafList(YType.str, 'input-interface'), ['str'])),
                        ('non_client_nrt', (YLeaf(YType.empty, 'non-client-nrt'), ['Empty'])),
                        ('precedence', (YLeafList(YType.str, 'precedence'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecedenceType', '')])),
                        ('qos_group', (YLeafList(YType.uint16, 'qos-group'), ['int'])),
                        ('peer', (YLeaf(YType.str, 'peer'), ['str'])),
                        ('client_type', (YLeaf(YType.enumeration, 'client-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.ClassMap.Match.ClientType')])),
                        ('device_type', (YLeaf(YType.str, 'device-type'), ['str'])),
                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                        ('oui', (YLeaf(YType.str, 'oui'), ['str'])),
                        ('port_type', (YLeaf(YType.enumeration, 'port-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.ClassMap.Match.PortType')])),
                        ('service_template', (YLeaf(YType.str, 'service-template'), ['str'])),
                        ('session_type', (YLeaf(YType.enumeration, 'session-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.ClassMap.Match.SessionType')])),
                        ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                        ('ssid', (YLeaf(YType.str, 'ssid'), ['str'])),
                        ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                        ('timer', (YLeaf(YType.str, 'timer'), ['str'])),
                        ('user_role', (YLeaf(YType.str, 'user-role'), ['str'])),
                        ('username', (YLeaf(YType.str, 'username'), ['str'])),
                    ])
                    self.any = None
                    self.class_map = []
                    self.cos = []
                    self.discard_class = []
                    self.dscp = []
                    self.fr_de = None
                    self.fr_dlci = []
                    self.input_interface = []
                    self.non_client_nrt = None
                    self.precedence = []
                    self.qos_group = []
                    self.peer = None
                    self.client_type = None
                    self.device_type = None
                    self.interface = None
                    self.ip_address = None
                    self.ipv6_address = None
                    self.mac_address = None
                    self.oui = None
                    self.port_type = None
                    self.service_template = None
                    self.session_type = None
                    self.sgt = None
                    self.ssid = None
                    self.tag = None
                    self.timer = None
                    self.user_role = None
                    self.username = None

                    self.current_method_priority = Native.Policy.ClassMap.Match.CurrentMethodPriority()
                    self.current_method_priority.parent = self
                    self._children_name_map["current_method_priority"] = "current-method-priority"

                    self.application = Native.Policy.ClassMap.Match.Application()
                    self.application.parent = self
                    self._children_name_map["application"] = "application"

                    self.access_group = Native.Policy.ClassMap.Match.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.destination_address = Native.Policy.ClassMap.Match.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"

                    self.group_object = Native.Policy.ClassMap.Match.GroupObject()
                    self.group_object.parent = self
                    self._children_name_map["group_object"] = "group-object"

                    self.ip = Native.Policy.ClassMap.Match.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.mpls = Native.Policy.ClassMap.Match.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"

                    self.packet = Native.Policy.ClassMap.Match.Packet()
                    self.packet.parent = self
                    self._children_name_map["packet"] = "packet"

                    self.protocol = Native.Policy.ClassMap.Match.Protocol()
                    self.protocol.parent = self
                    self._children_name_map["protocol"] = "protocol"

                    self.security_group = Native.Policy.ClassMap.Match.SecurityGroup()
                    self.security_group.parent = self
                    self._children_name_map["security_group"] = "security-group"

                    self.source_address = Native.Policy.ClassMap.Match.SourceAddress()
                    self.source_address.parent = self
                    self._children_name_map["source_address"] = "source-address"

                    self.vlan = Native.Policy.ClassMap.Match.Vlan()
                    self.vlan.parent = self
                    self._children_name_map["vlan"] = "vlan"

                    self.authorization_status = Native.Policy.ClassMap.Match.AuthorizationStatus()
                    self.authorization_status.parent = self
                    self._children_name_map["authorization_status"] = "authorization-status"

                    self.authorizing_method_priority = Native.Policy.ClassMap.Match.AuthorizingMethodPriority()
                    self.authorizing_method_priority.parent = self
                    self._children_name_map["authorizing_method_priority"] = "authorizing-method-priority"

                    self.method = Native.Policy.ClassMap.Match.Method()
                    self.method.parent = self
                    self._children_name_map["method"] = "method"

                    self.result_type = Native.Policy.ClassMap.Match.ResultType()
                    self.result_type.parent = self
                    self._children_name_map["result_type"] = "result-type"

                    self.not_ = Native.Policy.ClassMap.Match.Not()
                    self.not_.parent = self
                    self._children_name_map["not_"] = "not"

                    self.service = YList(self)
                    self.activated_service_template = YList(self)
                    self._segment_path = lambda: "match"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Policy.ClassMap.Match, ['any', 'class_map', 'cos', 'discard_class', 'dscp', 'fr_de', 'fr_dlci', 'input_interface', 'non_client_nrt', 'precedence', 'qos_group', 'peer', 'client_type', 'device_type', 'interface', 'ip_address', 'ipv6_address', 'mac_address', 'oui', 'port_type', 'service_template', 'session_type', 'sgt', 'ssid', 'tag', 'timer', 'user_role', 'username'], name, value)

                class ClientType(Enum):
                    """
                    ClientType (Enum Class)

                    match the type of device from an event

                    .. data:: data = 0

                    .. data:: switch = 1

                    .. data:: video = 2

                    .. data:: voice = 3

                    """

                    data = Enum.YLeaf(0, "data")

                    switch = Enum.YLeaf(1, "switch")

                    video = Enum.YLeaf(2, "video")

                    voice = Enum.YLeaf(3, "voice")


                class PortType(Enum):
                    """
                    PortType (Enum Class)

                    match the type interface from an event

                    .. data:: dot11_port = 0

                    .. data:: l2_port = 1

                    .. data:: l3_port = 2

                    """

                    dot11_port = Enum.YLeaf(0, "dot11-port")

                    l2_port = Enum.YLeaf(1, "l2-port")

                    l3_port = Enum.YLeaf(2, "l3-port")


                class SessionType(Enum):
                    """
                    SessionType (Enum Class)

                    match the session type

                    .. data:: wired = 0

                    .. data:: wireless = 1

                    """

                    wired = Enum.YLeaf(0, "wired")

                    wireless = Enum.YLeaf(1, "wireless")



                class CurrentMethodPriority(Entity):
                    """
                    match the priority against the current method's priority
                    
                    .. attribute:: eq
                    
                    	equal to
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: gt
                    
                    	greater than
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: lt
                    
                    	less than
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.CurrentMethodPriority, self).__init__()

                        self.yang_name = "current-method-priority"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eq', (YLeaf(YType.uint8, 'eq'), ['int'])),
                            ('gt', (YLeaf(YType.uint8, 'gt'), ['int'])),
                            ('lt', (YLeaf(YType.uint8, 'lt'), ['int'])),
                        ])
                        self.eq = None
                        self.gt = None
                        self.lt = None
                        self._segment_path = lambda: "current-method-priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.CurrentMethodPriority, ['eq', 'gt', 'lt'], name, value)


                class Application(Entity):
                    """
                    Application to match
                    
                    .. attribute:: application_group
                    
                    	Application Group to match
                    	**type**\:  :py:class:`ApplicationGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Application.ApplicationGroup>`
                    
                    .. attribute:: attribute
                    
                    	Application attribute to match
                    	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Application.Attribute>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.Application, self).__init__()

                        self.yang_name = "application"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("application-group", ("application_group", Native.Policy.ClassMap.Match.Application.ApplicationGroup)), ("attribute", ("attribute", Native.Policy.ClassMap.Match.Application.Attribute))])
                        self._leafs = OrderedDict()

                        self.application_group = Native.Policy.ClassMap.Match.Application.ApplicationGroup()
                        self.application_group.parent = self
                        self._children_name_map["application_group"] = "application-group"

                        self.attribute = Native.Policy.ClassMap.Match.Application.Attribute()
                        self.attribute.parent = self
                        self._children_name_map["attribute"] = "attribute"
                        self._segment_path = lambda: "application"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.Application, [], name, value)


                    class ApplicationGroup(Entity):
                        """
                        Application Group to match
                        
                        .. attribute:: telepresence_group
                        
                        	Telepresence Group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vmware_group
                        
                        	VMWARE Group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: webex_group
                        
                        	WebEx Group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Application.ApplicationGroup, self).__init__()

                            self.yang_name = "application-group"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('telepresence_group', (YLeaf(YType.empty, 'telepresence-group'), ['Empty'])),
                                ('vmware_group', (YLeaf(YType.empty, 'vmware-group'), ['Empty'])),
                                ('webex_group', (YLeaf(YType.empty, 'webex-group'), ['Empty'])),
                            ])
                            self.telepresence_group = None
                            self.vmware_group = None
                            self.webex_group = None
                            self._segment_path = lambda: "application-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Application.ApplicationGroup, ['telepresence_group', 'vmware_group', 'webex_group'], name, value)


                    class Attribute(Entity):
                        """
                        Application attribute to match
                        
                        .. attribute:: media_type
                        
                        	Media type attribute to match
                        	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Application.Attribute.MediaType>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Application.Attribute, self).__init__()

                            self.yang_name = "attribute"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('media_type', (YLeaf(YType.enumeration, 'media-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.ClassMap.Match.Application.Attribute.MediaType')])),
                            ])
                            self.media_type = None
                            self._segment_path = lambda: "attribute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Application.Attribute, ['media_type'], name, value)

                        class MediaType(Enum):
                            """
                            MediaType (Enum Class)

                            Media type attribute to match

                            .. data:: audio = 0

                            .. data:: audio_video = 1

                            .. data:: control = 2

                            .. data:: data = 3

                            .. data:: video = 4

                            """

                            audio = Enum.YLeaf(0, "audio")

                            audio_video = Enum.YLeaf(1, "audio-video")

                            control = Enum.YLeaf(2, "control")

                            data = Enum.YLeaf(3, "data")

                            video = Enum.YLeaf(4, "video")



                class AccessGroup(Entity):
                    """
                    Access group
                    
                    .. attribute:: index
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..2699
                    
                    .. attribute:: name
                    
                    	Named Access List
                    	**type**\: list of str
                    
                    	**length:** 1..64
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                            ('name', (YLeafList(YType.str, 'name'), ['str'])),
                        ])
                        self.index = None
                        self.name = []
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.AccessGroup, ['index', 'name'], name, value)


                class DestinationAddress(Entity):
                    """
                    Destination address
                    
                    .. attribute:: mac
                    
                    	MAC address
                    	**type**\: list of str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mac', (YLeafList(YType.str, 'mac'), ['str'])),
                        ])
                        self.mac = []
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.DestinationAddress, ['mac'], name, value)


                class GroupObject(Entity):
                    """
                    Match object\-group
                    
                    .. attribute:: security
                    
                    	Match object\-group security
                    	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.GroupObject.Security>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.GroupObject, self).__init__()

                        self.yang_name = "group-object"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("security", ("security", Native.Policy.ClassMap.Match.GroupObject.Security))])
                        self._leafs = OrderedDict()

                        self.security = Native.Policy.ClassMap.Match.GroupObject.Security()
                        self.security.parent = self
                        self._children_name_map["security"] = "security"
                        self._segment_path = lambda: "group-object"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.GroupObject, [], name, value)


                    class Security(Entity):
                        """
                        Match object\-group security
                        
                        .. attribute:: source
                        
                        	Match source object\-group security
                        	**type**\: list of str
                        
                        .. attribute:: destination
                        
                        	Match destination object\-group security
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.GroupObject.Security, self).__init__()

                            self.yang_name = "security"
                            self.yang_parent_name = "group-object"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('source', (YLeafList(YType.str, 'source'), ['str'])),
                                ('destination', (YLeafList(YType.str, 'destination'), ['str'])),
                            ])
                            self.source = []
                            self.destination = []
                            self._segment_path = lambda: "security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.GroupObject.Security, ['source', 'destination'], name, value)


                class Ip(Entity):
                    """
                    IP specific values
                    
                    .. attribute:: dscp
                    
                    	Match IP DSCP (DiffServ CodePoints)
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 0..63
                    
                    		**type**\: list of   :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                    
                    .. attribute:: precedence
                    
                    	Match IP precedence
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 0..7
                    
                    		**type**\: list of   :py:class:`PrecedenceType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecedenceType>`
                    
                    .. attribute:: rtp
                    
                    	Match RTP port nos
                    	**type**\: list of  		 :py:class:`Rtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Ip.Rtp>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rtp", ("rtp", Native.Policy.ClassMap.Match.Ip.Rtp))])
                        self._leafs = OrderedDict([
                            ('dscp', (YLeafList(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                            ('precedence', (YLeafList(YType.str, 'precedence'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecedenceType', '')])),
                        ])
                        self.dscp = []
                        self.precedence = []

                        self.rtp = YList(self)
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.Ip, ['dscp', 'precedence'], name, value)


                    class Rtp(Entity):
                        """
                        Match RTP port nos
                        
                        .. attribute:: port1  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 2000..65535
                        
                        .. attribute:: port2  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..16383
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Ip.Rtp, self).__init__()

                            self.yang_name = "rtp"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['port1','port2']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port1', (YLeaf(YType.uint16, 'port1'), ['int'])),
                                ('port2', (YLeaf(YType.uint16, 'port2'), ['int'])),
                            ])
                            self.port1 = None
                            self.port2 = None
                            self._segment_path = lambda: "rtp" + "[port1='" + str(self.port1) + "']" + "[port2='" + str(self.port2) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Ip.Rtp, ['port1', 'port2'], name, value)


                class Mpls(Entity):
                    """
                    Multi Protocol Label Switching specific values
                    
                    .. attribute:: experimental
                    
                    	Match MPLS experimental
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Mpls.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Policy.ClassMap.Match.Mpls.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Policy.ClassMap.Match.Mpls.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "mpls"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.Mpls, [], name, value)


                    class Experimental(Entity):
                        """
                        Match MPLS experimental
                        
                        .. attribute:: topmost
                        
                        	Match MPLS experimental value on topmost label
                        	**type**\: list of int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Mpls.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "mpls"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('topmost', (YLeafList(YType.uint8, 'topmost'), ['int'])),
                            ])
                            self.topmost = []
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Mpls.Experimental, ['topmost'], name, value)


                class Packet(Entity):
                    """
                    Layer 3 Packet length
                    
                    .. attribute:: length
                    
                    	Layer 3 Packet length
                    	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Packet.Length>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.Packet, self).__init__()

                        self.yang_name = "packet"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("length", ("length", Native.Policy.ClassMap.Match.Packet.Length))])
                        self._leafs = OrderedDict()

                        self.length = Native.Policy.ClassMap.Match.Packet.Length()
                        self.length.parent = self
                        self._children_name_map["length"] = "length"
                        self._segment_path = lambda: "packet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.Packet, [], name, value)


                    class Length(Entity):
                        """
                        Layer 3 Packet length
                        
                        .. attribute:: max
                        
                        	Maximum length of packet
                        	**type**\: int
                        
                        	**range:** 1..2000
                        
                        .. attribute:: min
                        
                        	Minimum length of packet
                        	**type**\: int
                        
                        	**range:** 1..2000
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Packet.Length, self).__init__()

                            self.yang_name = "length"
                            self.yang_parent_name = "packet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                            ])
                            self.max = None
                            self.min = None
                            self._segment_path = lambda: "length"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Packet.Length, ['max', 'min'], name, value)


                class Protocol(Entity):
                    """
                    Protocol
                    
                    .. attribute:: protocols_list
                    
                    	
                    	**type**\: list of  		 :py:class:`ProtocolsList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Protocol.ProtocolsList>`
                    
                    .. attribute:: attribute
                    
                    	Attribute based protocol match
                    	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Protocol.Attribute>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.Protocol, self).__init__()

                        self.yang_name = "protocol"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocols-list", ("protocols_list", Native.Policy.ClassMap.Match.Protocol.ProtocolsList)), ("attribute", ("attribute", Native.Policy.ClassMap.Match.Protocol.Attribute))])
                        self._leafs = OrderedDict()

                        self.attribute = Native.Policy.ClassMap.Match.Protocol.Attribute()
                        self.attribute.parent = self
                        self._children_name_map["attribute"] = "attribute"

                        self.protocols_list = YList(self)
                        self._segment_path = lambda: "protocol"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.Protocol, [], name, value)


                    class ProtocolsList(Entity):
                        """
                        
                        
                        .. attribute:: protocols  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Protocol.ProtocolsList, self).__init__()

                            self.yang_name = "protocols-list"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['protocols']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protocols', (YLeaf(YType.str, 'protocols'), ['str'])),
                            ])
                            self.protocols = None
                            self._segment_path = lambda: "protocols-list" + "[protocols='" + str(self.protocols) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Protocol.ProtocolsList, ['protocols'], name, value)


                    class Attribute(Entity):
                        """
                        Attribute based protocol match
                        
                        .. attribute:: application_group
                        
                        	Application\-group attribute
                        	**type**\: list of  		 :py:class:`ApplicationGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Protocol.Attribute.ApplicationGroup>`
                        
                        .. attribute:: application_set
                        
                        	Application\-set attribute
                        	**type**\: list of  		 :py:class:`ApplicationSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Protocol.Attribute.ApplicationSet>`
                        
                        .. attribute:: business_relevance
                        
                        	Application business\-relevance
                        	**type**\: list of  		 :py:class:`BusinessRelevance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Protocol.Attribute.BusinessRelevance>`
                        
                        .. attribute:: category
                        
                        	Category attribute
                        	**type**\: list of  		 :py:class:`Category <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Protocol.Attribute.Category>`
                        
                        .. attribute:: encrypted
                        
                        	Encrypted applications
                        	**type**\: list of  		 :py:class:`Encrypted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Protocol.Attribute.Encrypted>`
                        
                        .. attribute:: sub_category
                        
                        	Sub\-category attribute
                        	**type**\: list of  		 :py:class:`SubCategory <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Protocol.Attribute.SubCategory>`
                        
                        .. attribute:: traffic_class
                        
                        	SRND class
                        	**type**\: list of  		 :py:class:`TrafficClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Protocol.Attribute.TrafficClass>`
                        
                        .. attribute:: tunnel
                        
                        	Tunnelled applications
                        	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Protocol.Attribute.Tunnel>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Protocol.Attribute, self).__init__()

                            self.yang_name = "attribute"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("application-group", ("application_group", Native.Policy.ClassMap.Match.Protocol.Attribute.ApplicationGroup)), ("application-set", ("application_set", Native.Policy.ClassMap.Match.Protocol.Attribute.ApplicationSet)), ("business-relevance", ("business_relevance", Native.Policy.ClassMap.Match.Protocol.Attribute.BusinessRelevance)), ("category", ("category", Native.Policy.ClassMap.Match.Protocol.Attribute.Category)), ("encrypted", ("encrypted", Native.Policy.ClassMap.Match.Protocol.Attribute.Encrypted)), ("sub-category", ("sub_category", Native.Policy.ClassMap.Match.Protocol.Attribute.SubCategory)), ("traffic-class", ("traffic_class", Native.Policy.ClassMap.Match.Protocol.Attribute.TrafficClass)), ("tunnel", ("tunnel", Native.Policy.ClassMap.Match.Protocol.Attribute.Tunnel))])
                            self._leafs = OrderedDict()

                            self.application_group = YList(self)
                            self.application_set = YList(self)
                            self.business_relevance = YList(self)
                            self.category = YList(self)
                            self.encrypted = YList(self)
                            self.sub_category = YList(self)
                            self.traffic_class = YList(self)
                            self.tunnel = YList(self)
                            self._segment_path = lambda: "attribute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Protocol.Attribute, [], name, value)


                        class ApplicationGroup(Entity):
                            """
                            Application\-group attribute
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Protocol.Attribute.ApplicationGroup, self).__init__()

                                self.yang_name = "application-group"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "application-group" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Protocol.Attribute.ApplicationGroup, ['name'], name, value)


                        class ApplicationSet(Entity):
                            """
                            Application\-set attribute
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Protocol.Attribute.ApplicationSet, self).__init__()

                                self.yang_name = "application-set"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "application-set" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Protocol.Attribute.ApplicationSet, ['name'], name, value)


                        class BusinessRelevance(Entity):
                            """
                            Application business\-relevance
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Protocol.Attribute.BusinessRelevance, self).__init__()

                                self.yang_name = "business-relevance"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "business-relevance" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Protocol.Attribute.BusinessRelevance, ['name'], name, value)


                        class Category(Entity):
                            """
                            Category attribute
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Protocol.Attribute.Category, self).__init__()

                                self.yang_name = "category"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "category" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Protocol.Attribute.Category, ['name'], name, value)


                        class Encrypted(Entity):
                            """
                            Encrypted applications
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Protocol.Attribute.Encrypted, self).__init__()

                                self.yang_name = "encrypted"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "encrypted" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Protocol.Attribute.Encrypted, ['name'], name, value)


                        class SubCategory(Entity):
                            """
                            Sub\-category attribute
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Protocol.Attribute.SubCategory, self).__init__()

                                self.yang_name = "sub-category"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "sub-category" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Protocol.Attribute.SubCategory, ['name'], name, value)


                        class TrafficClass(Entity):
                            """
                            SRND class
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Protocol.Attribute.TrafficClass, self).__init__()

                                self.yang_name = "traffic-class"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "traffic-class" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Protocol.Attribute.TrafficClass, ['name'], name, value)


                        class Tunnel(Entity):
                            """
                            Tunnelled applications
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Protocol.Attribute.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "tunnel" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Protocol.Attribute.Tunnel, ['name'], name, value)


                class SecurityGroup(Entity):
                    """
                    Security group
                    
                    .. attribute:: destination
                    
                    	Destination security group
                    	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.SecurityGroup.Destination>`
                    
                    .. attribute:: source
                    
                    	Source security group
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.SecurityGroup.Source>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.SecurityGroup, self).__init__()

                        self.yang_name = "security-group"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination", ("destination", Native.Policy.ClassMap.Match.SecurityGroup.Destination)), ("source", ("source", Native.Policy.ClassMap.Match.SecurityGroup.Source))])
                        self._leafs = OrderedDict()

                        self.destination = Native.Policy.ClassMap.Match.SecurityGroup.Destination()
                        self.destination.parent = self
                        self._children_name_map["destination"] = "destination"

                        self.source = Native.Policy.ClassMap.Match.SecurityGroup.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                        self._segment_path = lambda: "security-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.SecurityGroup, [], name, value)


                    class Destination(Entity):
                        """
                        Destination security group
                        
                        .. attribute:: tag
                        
                        	Security group tag
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.SecurityGroup.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "security-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.uint16, 'tag'), ['int'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "destination"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.SecurityGroup.Destination, ['tag'], name, value)


                    class Source(Entity):
                        """
                        Source security group
                        
                        .. attribute:: tag
                        
                        	Security group tag
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.SecurityGroup.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "security-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.uint16, 'tag'), ['int'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.SecurityGroup.Source, ['tag'], name, value)


                class Service(Entity):
                    """
                    Service Instance to match
                    
                    .. attribute:: efp  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4000
                    
                    .. attribute:: instance
                    
                    	Service Instance to match
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Service Instance to match
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.Service, self).__init__()

                        self.yang_name = "service"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['efp']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('efp', (YLeaf(YType.uint16, 'efp'), ['int'])),
                            ('instance', (YLeaf(YType.empty, 'instance'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                        ])
                        self.efp = None
                        self.instance = None
                        self.ethernet = None
                        self._segment_path = lambda: "service" + "[efp='" + str(self.efp) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.Service, ['efp', 'instance', 'ethernet'], name, value)


                class SourceAddress(Entity):
                    """
                    Source address
                    
                    .. attribute:: mac
                    
                    	MAC address
                    	**type**\: list of str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.SourceAddress, self).__init__()

                        self.yang_name = "source-address"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mac', (YLeafList(YType.str, 'mac'), ['str'])),
                        ])
                        self.mac = []
                        self._segment_path = lambda: "source-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.SourceAddress, ['mac'], name, value)


                class Vlan(Entity):
                    """
                    VLANs to match
                    
                    .. attribute:: inner
                    
                    	Inner tag to match
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 1..4094
                    
                    		**type**\: list of str
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 1..4094
                    
                    		**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inner', (YLeafList(YType.str, 'inner'), ['int','str'])),
                            ('value', (YLeafList(YType.str, 'value'), ['int','str'])),
                        ])
                        self.inner = []
                        self.value = []
                        self._segment_path = lambda: "vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.Vlan, ['inner', 'value'], name, value)


                class ActivatedServiceTemplate(Entity):
                    """
                    match name of service template activated on session
                    
                    .. attribute:: service_name  (key)
                    
                    	Enter service name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.ActivatedServiceTemplate, self).__init__()

                        self.yang_name = "activated-service-template"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['service_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('service_name', (YLeaf(YType.str, 'service-name'), ['str'])),
                        ])
                        self.service_name = None
                        self._segment_path = lambda: "activated-service-template" + "[service-name='" + str(self.service_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.ActivatedServiceTemplate, ['service_name'], name, value)


                class AuthorizationStatus(Entity):
                    """
                    match the authorization status of the session
                    
                    .. attribute:: authorized
                    
                    	authorized
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unauthorized
                    
                    	unauthorized
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.AuthorizationStatus, self).__init__()

                        self.yang_name = "authorization-status"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('authorized', (YLeaf(YType.empty, 'authorized'), ['Empty'])),
                            ('unauthorized', (YLeaf(YType.empty, 'unauthorized'), ['Empty'])),
                        ])
                        self.authorized = None
                        self.unauthorized = None
                        self._segment_path = lambda: "authorization-status"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.AuthorizationStatus, ['authorized', 'unauthorized'], name, value)


                class AuthorizingMethodPriority(Entity):
                    """
                    match the priority against the authorizing method's priority
                    
                    .. attribute:: eq
                    
                    	equal to
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: gt
                    
                    	greater than
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: lt
                    
                    	less than
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.AuthorizingMethodPriority, self).__init__()

                        self.yang_name = "authorizing-method-priority"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eq', (YLeaf(YType.uint8, 'eq'), ['int'])),
                            ('gt', (YLeaf(YType.uint8, 'gt'), ['int'])),
                            ('lt', (YLeaf(YType.uint8, 'lt'), ['int'])),
                        ])
                        self.eq = None
                        self.gt = None
                        self.lt = None
                        self._segment_path = lambda: "authorizing-method-priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.AuthorizingMethodPriority, ['eq', 'gt', 'lt'], name, value)


                class Method(Entity):
                    """
                    match the type of authentication method from an event
                    
                    .. attribute:: dot1x
                    
                    	dot1x
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	mab
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	webauth
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.Method, self).__init__()

                        self.yang_name = "method"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "method"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.Method, ['dot1x', 'mab', 'webauth'], name, value)


                class ResultType(Entity):
                    """
                    match the result type, optionally for a specific method
                    
                    .. attribute:: method
                    
                    	match the result of a particular method
                    	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.ResultType.Method>`
                    
                    .. attribute:: aaa_timeout
                    
                    	aaa timeout type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: agent_not_found
                    
                    	agent not found type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: authoritative
                    
                    	failure type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: method_timeout
                    
                    	method\_timeout type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: none
                    
                    	no type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: success
                    
                    	success type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.ResultType, self).__init__()

                        self.yang_name = "result-type"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("method", ("method", Native.Policy.ClassMap.Match.ResultType.Method))])
                        self._leafs = OrderedDict([
                            ('aaa_timeout', (YLeaf(YType.empty, 'aaa-timeout'), ['Empty'])),
                            ('agent_not_found', (YLeaf(YType.empty, 'agent-not-found'), ['Empty'])),
                            ('authoritative', (YLeaf(YType.empty, 'authoritative'), ['Empty'])),
                            ('method_timeout', (YLeaf(YType.empty, 'method-timeout'), ['Empty'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('success', (YLeaf(YType.empty, 'success'), ['Empty'])),
                        ])
                        self.aaa_timeout = None
                        self.agent_not_found = None
                        self.authoritative = None
                        self.method_timeout = None
                        self.none = None
                        self.success = None

                        self.method = Native.Policy.ClassMap.Match.ResultType.Method()
                        self.method.parent = self
                        self._children_name_map["method"] = "method"
                        self._segment_path = lambda: "result-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.ResultType, ['aaa_timeout', 'agent_not_found', 'authoritative', 'method_timeout', 'none', 'success'], name, value)


                    class Method(Entity):
                        """
                        match the result of a particular method
                        
                        .. attribute:: dot1x
                        
                        	dot1x result
                        	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.ResultType.Method.Dot1x>`
                        
                        .. attribute:: mab
                        
                        	mab result
                        	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.ResultType.Method.Mab>`
                        
                        .. attribute:: webauth
                        
                        	webauth result
                        	**type**\:  :py:class:`Webauth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.ResultType.Method.Webauth>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.ResultType.Method, self).__init__()

                            self.yang_name = "method"
                            self.yang_parent_name = "result-type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1x", ("dot1x", Native.Policy.ClassMap.Match.ResultType.Method.Dot1x)), ("mab", ("mab", Native.Policy.ClassMap.Match.ResultType.Method.Mab)), ("webauth", ("webauth", Native.Policy.ClassMap.Match.ResultType.Method.Webauth))])
                            self._leafs = OrderedDict()

                            self.dot1x = Native.Policy.ClassMap.Match.ResultType.Method.Dot1x()
                            self.dot1x.parent = self
                            self._children_name_map["dot1x"] = "dot1x"

                            self.mab = Native.Policy.ClassMap.Match.ResultType.Method.Mab()
                            self.mab.parent = self
                            self._children_name_map["mab"] = "mab"

                            self.webauth = Native.Policy.ClassMap.Match.ResultType.Method.Webauth()
                            self.webauth.parent = self
                            self._children_name_map["webauth"] = "webauth"
                            self._segment_path = lambda: "method"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.ResultType.Method, [], name, value)


                        class Dot1x(Entity):
                            """
                            dot1x result
                            
                            .. attribute:: aaa_timeout
                            
                            	aaa timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: agent_not_found
                            
                            	agent not found type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: authoritative
                            
                            	failure type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: method_timeout
                            
                            	method\_timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: none
                            
                            	no type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: success
                            
                            	success type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.ResultType.Method.Dot1x, self).__init__()

                                self.yang_name = "dot1x"
                                self.yang_parent_name = "method"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('aaa_timeout', (YLeaf(YType.empty, 'aaa-timeout'), ['Empty'])),
                                    ('agent_not_found', (YLeaf(YType.empty, 'agent-not-found'), ['Empty'])),
                                    ('authoritative', (YLeaf(YType.empty, 'authoritative'), ['Empty'])),
                                    ('method_timeout', (YLeaf(YType.empty, 'method-timeout'), ['Empty'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('success', (YLeaf(YType.empty, 'success'), ['Empty'])),
                                ])
                                self.aaa_timeout = None
                                self.agent_not_found = None
                                self.authoritative = None
                                self.method_timeout = None
                                self.none = None
                                self.success = None
                                self._segment_path = lambda: "dot1x"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.ResultType.Method.Dot1x, ['aaa_timeout', 'agent_not_found', 'authoritative', 'method_timeout', 'none', 'success'], name, value)


                        class Mab(Entity):
                            """
                            mab result
                            
                            .. attribute:: aaa_timeout
                            
                            	aaa timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: agent_not_found
                            
                            	agent not found type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: authoritative
                            
                            	failure type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: method_timeout
                            
                            	method\_timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: none
                            
                            	no type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: success
                            
                            	success type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.ResultType.Method.Mab, self).__init__()

                                self.yang_name = "mab"
                                self.yang_parent_name = "method"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('aaa_timeout', (YLeaf(YType.empty, 'aaa-timeout'), ['Empty'])),
                                    ('agent_not_found', (YLeaf(YType.empty, 'agent-not-found'), ['Empty'])),
                                    ('authoritative', (YLeaf(YType.empty, 'authoritative'), ['Empty'])),
                                    ('method_timeout', (YLeaf(YType.empty, 'method-timeout'), ['Empty'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('success', (YLeaf(YType.empty, 'success'), ['Empty'])),
                                ])
                                self.aaa_timeout = None
                                self.agent_not_found = None
                                self.authoritative = None
                                self.method_timeout = None
                                self.none = None
                                self.success = None
                                self._segment_path = lambda: "mab"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.ResultType.Method.Mab, ['aaa_timeout', 'agent_not_found', 'authoritative', 'method_timeout', 'none', 'success'], name, value)


                        class Webauth(Entity):
                            """
                            webauth result
                            
                            .. attribute:: aaa_timeout
                            
                            	aaa timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: agent_not_found
                            
                            	agent not found type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: authoritative
                            
                            	failure type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: method_timeout
                            
                            	method\_timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: none
                            
                            	no type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: success
                            
                            	success type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.ResultType.Method.Webauth, self).__init__()

                                self.yang_name = "webauth"
                                self.yang_parent_name = "method"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('aaa_timeout', (YLeaf(YType.empty, 'aaa-timeout'), ['Empty'])),
                                    ('agent_not_found', (YLeaf(YType.empty, 'agent-not-found'), ['Empty'])),
                                    ('authoritative', (YLeaf(YType.empty, 'authoritative'), ['Empty'])),
                                    ('method_timeout', (YLeaf(YType.empty, 'method-timeout'), ['Empty'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('success', (YLeaf(YType.empty, 'success'), ['Empty'])),
                                ])
                                self.aaa_timeout = None
                                self.agent_not_found = None
                                self.authoritative = None
                                self.method_timeout = None
                                self.none = None
                                self.success = None
                                self._segment_path = lambda: "webauth"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.ResultType.Method.Webauth, ['aaa_timeout', 'agent_not_found', 'authoritative', 'method_timeout', 'none', 'success'], name, value)


                class Not(Entity):
                    """
                    Negate this match result
                    
                    .. attribute:: current_method_priority
                    
                    	match the priority against the current method's priority
                    	**type**\:  :py:class:`CurrentMethodPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.CurrentMethodPriority>`
                    
                    .. attribute:: application
                    
                    	Application to match
                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Application>`
                    
                    .. attribute:: access_group
                    
                    	Access group
                    	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.AccessGroup>`
                    
                    .. attribute:: any
                    
                    	Any packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: class_map
                    
                    	Class map
                    	**type**\: list of str
                    
                    	**length:** 1..512
                    
                    .. attribute:: cos
                    
                    	IEEE 802.1Q/ISL class of service/user priority values
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    .. attribute:: destination_address
                    
                    	Destination address
                    	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.DestinationAddress>`
                    
                    .. attribute:: discard_class
                    
                    	Discard behavior identifier
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    .. attribute:: dscp
                    
                    	Match DSCP in IP(v4) and IPv6 packets
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 0..63
                    
                    		**type**\: list of   :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                    
                    .. attribute:: fr_de
                    
                    	Match on Frame\-relay DE bit
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: fr_dlci
                    
                    	Match on fr\-dlci
                    	**type**\: list of int
                    
                    	**range:** 16..1007
                    
                    .. attribute:: group_object
                    
                    	Match object\-group
                    	**type**\:  :py:class:`GroupObject <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.GroupObject>`
                    
                    .. attribute:: input_interface
                    
                    	Select an input interface to match
                    	**type**\: list of str
                    
                    .. attribute:: ip
                    
                    	IP specific values
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Ip>`
                    
                    .. attribute:: non_client_nrt
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mpls
                    
                    	Multi Protocol Label Switching specific values
                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Mpls>`
                    
                    .. attribute:: packet
                    
                    	Layer 3 Packet length
                    	**type**\:  :py:class:`Packet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Packet>`
                    
                    .. attribute:: precedence
                    
                    	Match Precedence in IP(v4) and IPv6 packets
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 0..7
                    
                    		**type**\: list of   :py:class:`PrecedenceType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecedenceType>`
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Protocol>`
                    
                    .. attribute:: qos_group
                    
                    	Qos\-group
                    	**type**\: list of int
                    
                    	**range:** 0..99
                    
                    .. attribute:: security_group
                    
                    	Security group
                    	**type**\:  :py:class:`SecurityGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.SecurityGroup>`
                    
                    .. attribute:: service
                    
                    	Service Instance to match
                    	**type**\: list of  		 :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Service>`
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.SourceAddress>`
                    
                    .. attribute:: vlan
                    
                    	VLANs to match
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Vlan>`
                    
                    .. attribute:: peer
                    
                    	APPNAV Peer Filter
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.Match.Not, self).__init__()

                        self.yang_name = "not"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("current-method-priority", ("current_method_priority", Native.Policy.ClassMap.Match.Not.CurrentMethodPriority)), ("application", ("application", Native.Policy.ClassMap.Match.Not.Application)), ("access-group", ("access_group", Native.Policy.ClassMap.Match.Not.AccessGroup)), ("destination-address", ("destination_address", Native.Policy.ClassMap.Match.Not.DestinationAddress)), ("group-object", ("group_object", Native.Policy.ClassMap.Match.Not.GroupObject)), ("ip", ("ip", Native.Policy.ClassMap.Match.Not.Ip)), ("mpls", ("mpls", Native.Policy.ClassMap.Match.Not.Mpls)), ("packet", ("packet", Native.Policy.ClassMap.Match.Not.Packet)), ("protocol", ("protocol", Native.Policy.ClassMap.Match.Not.Protocol)), ("security-group", ("security_group", Native.Policy.ClassMap.Match.Not.SecurityGroup)), ("service", ("service", Native.Policy.ClassMap.Match.Not.Service)), ("source-address", ("source_address", Native.Policy.ClassMap.Match.Not.SourceAddress)), ("vlan", ("vlan", Native.Policy.ClassMap.Match.Not.Vlan))])
                        self._leafs = OrderedDict([
                            ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                            ('class_map', (YLeafList(YType.str, 'class-map'), ['str'])),
                            ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                            ('discard_class', (YLeafList(YType.uint8, 'discard-class'), ['int'])),
                            ('dscp', (YLeafList(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                            ('fr_de', (YLeaf(YType.empty, 'fr-de'), ['Empty'])),
                            ('fr_dlci', (YLeafList(YType.uint16, 'fr-dlci'), ['int'])),
                            ('input_interface', (YLeafList(YType.str, 'input-interface'), ['str'])),
                            ('non_client_nrt', (YLeaf(YType.empty, 'non-client-nrt'), ['Empty'])),
                            ('precedence', (YLeafList(YType.str, 'precedence'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecedenceType', '')])),
                            ('qos_group', (YLeafList(YType.uint16, 'qos-group'), ['int'])),
                            ('peer', (YLeaf(YType.str, 'peer'), ['str'])),
                        ])
                        self.any = None
                        self.class_map = []
                        self.cos = []
                        self.discard_class = []
                        self.dscp = []
                        self.fr_de = None
                        self.fr_dlci = []
                        self.input_interface = []
                        self.non_client_nrt = None
                        self.precedence = []
                        self.qos_group = []
                        self.peer = None

                        self.current_method_priority = Native.Policy.ClassMap.Match.Not.CurrentMethodPriority()
                        self.current_method_priority.parent = self
                        self._children_name_map["current_method_priority"] = "current-method-priority"

                        self.application = Native.Policy.ClassMap.Match.Not.Application()
                        self.application.parent = self
                        self._children_name_map["application"] = "application"

                        self.access_group = Native.Policy.ClassMap.Match.Not.AccessGroup()
                        self.access_group.parent = self
                        self._children_name_map["access_group"] = "access-group"

                        self.destination_address = Native.Policy.ClassMap.Match.Not.DestinationAddress()
                        self.destination_address.parent = self
                        self._children_name_map["destination_address"] = "destination-address"

                        self.group_object = Native.Policy.ClassMap.Match.Not.GroupObject()
                        self.group_object.parent = self
                        self._children_name_map["group_object"] = "group-object"

                        self.ip = Native.Policy.ClassMap.Match.Not.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.mpls = Native.Policy.ClassMap.Match.Not.Mpls()
                        self.mpls.parent = self
                        self._children_name_map["mpls"] = "mpls"

                        self.packet = Native.Policy.ClassMap.Match.Not.Packet()
                        self.packet.parent = self
                        self._children_name_map["packet"] = "packet"

                        self.protocol = Native.Policy.ClassMap.Match.Not.Protocol()
                        self.protocol.parent = self
                        self._children_name_map["protocol"] = "protocol"

                        self.security_group = Native.Policy.ClassMap.Match.Not.SecurityGroup()
                        self.security_group.parent = self
                        self._children_name_map["security_group"] = "security-group"

                        self.source_address = Native.Policy.ClassMap.Match.Not.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"

                        self.vlan = Native.Policy.ClassMap.Match.Not.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"

                        self.service = YList(self)
                        self._segment_path = lambda: "not"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.Match.Not, ['any', 'class_map', 'cos', 'discard_class', 'dscp', 'fr_de', 'fr_dlci', 'input_interface', 'non_client_nrt', 'precedence', 'qos_group', 'peer'], name, value)


                    class CurrentMethodPriority(Entity):
                        """
                        match the priority against the current method's priority
                        
                        .. attribute:: eq
                        
                        	equal to
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        .. attribute:: gt
                        
                        	greater than
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        .. attribute:: lt
                        
                        	less than
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.CurrentMethodPriority, self).__init__()

                            self.yang_name = "current-method-priority"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eq', (YLeaf(YType.uint8, 'eq'), ['int'])),
                                ('gt', (YLeaf(YType.uint8, 'gt'), ['int'])),
                                ('lt', (YLeaf(YType.uint8, 'lt'), ['int'])),
                            ])
                            self.eq = None
                            self.gt = None
                            self.lt = None
                            self._segment_path = lambda: "current-method-priority"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.CurrentMethodPriority, ['eq', 'gt', 'lt'], name, value)


                    class Application(Entity):
                        """
                        Application to match
                        
                        .. attribute:: application_group
                        
                        	Application Group to match
                        	**type**\:  :py:class:`ApplicationGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Application.ApplicationGroup>`
                        
                        .. attribute:: attribute
                        
                        	Application attribute to match
                        	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Application.Attribute>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.Application, self).__init__()

                            self.yang_name = "application"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("application-group", ("application_group", Native.Policy.ClassMap.Match.Not.Application.ApplicationGroup)), ("attribute", ("attribute", Native.Policy.ClassMap.Match.Not.Application.Attribute))])
                            self._leafs = OrderedDict()

                            self.application_group = Native.Policy.ClassMap.Match.Not.Application.ApplicationGroup()
                            self.application_group.parent = self
                            self._children_name_map["application_group"] = "application-group"

                            self.attribute = Native.Policy.ClassMap.Match.Not.Application.Attribute()
                            self.attribute.parent = self
                            self._children_name_map["attribute"] = "attribute"
                            self._segment_path = lambda: "application"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.Application, [], name, value)


                        class ApplicationGroup(Entity):
                            """
                            Application Group to match
                            
                            .. attribute:: telepresence_group
                            
                            	Telepresence Group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vmware_group
                            
                            	VMWARE Group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: webex_group
                            
                            	WebEx Group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Not.Application.ApplicationGroup, self).__init__()

                                self.yang_name = "application-group"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('telepresence_group', (YLeaf(YType.empty, 'telepresence-group'), ['Empty'])),
                                    ('vmware_group', (YLeaf(YType.empty, 'vmware-group'), ['Empty'])),
                                    ('webex_group', (YLeaf(YType.empty, 'webex-group'), ['Empty'])),
                                ])
                                self.telepresence_group = None
                                self.vmware_group = None
                                self.webex_group = None
                                self._segment_path = lambda: "application-group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Not.Application.ApplicationGroup, ['telepresence_group', 'vmware_group', 'webex_group'], name, value)


                        class Attribute(Entity):
                            """
                            Application attribute to match
                            
                            .. attribute:: media_type
                            
                            	Media type attribute to match
                            	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Application.Attribute.MediaType>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Not.Application.Attribute, self).__init__()

                                self.yang_name = "attribute"
                                self.yang_parent_name = "application"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('media_type', (YLeaf(YType.enumeration, 'media-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.ClassMap.Match.Not.Application.Attribute.MediaType')])),
                                ])
                                self.media_type = None
                                self._segment_path = lambda: "attribute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Not.Application.Attribute, ['media_type'], name, value)

                            class MediaType(Enum):
                                """
                                MediaType (Enum Class)

                                Media type attribute to match

                                .. data:: audio = 0

                                .. data:: audio_video = 1

                                .. data:: control = 2

                                .. data:: data = 3

                                .. data:: video = 4

                                """

                                audio = Enum.YLeaf(0, "audio")

                                audio_video = Enum.YLeaf(1, "audio-video")

                                control = Enum.YLeaf(2, "control")

                                data = Enum.YLeaf(3, "data")

                                video = Enum.YLeaf(4, "video")



                    class AccessGroup(Entity):
                        """
                        Access group
                        
                        .. attribute:: index
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..2699
                        
                        .. attribute:: name
                        
                        	Named Access List
                        	**type**\: list of str
                        
                        	**length:** 1..64
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.AccessGroup, self).__init__()

                            self.yang_name = "access-group"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                ('name', (YLeafList(YType.str, 'name'), ['str'])),
                            ])
                            self.index = None
                            self.name = []
                            self._segment_path = lambda: "access-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.AccessGroup, ['index', 'name'], name, value)


                    class DestinationAddress(Entity):
                        """
                        Destination address
                        
                        .. attribute:: mac
                        
                        	MAC address
                        	**type**\: list of str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.DestinationAddress, self).__init__()

                            self.yang_name = "destination-address"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mac', (YLeafList(YType.str, 'mac'), ['str'])),
                            ])
                            self.mac = []
                            self._segment_path = lambda: "destination-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.DestinationAddress, ['mac'], name, value)


                    class GroupObject(Entity):
                        """
                        Match object\-group
                        
                        .. attribute:: security
                        
                        	Match object\-group security
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.GroupObject.Security>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.GroupObject, self).__init__()

                            self.yang_name = "group-object"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Policy.ClassMap.Match.Not.GroupObject.Security))])
                            self._leafs = OrderedDict()

                            self.security = Native.Policy.ClassMap.Match.Not.GroupObject.Security()
                            self.security.parent = self
                            self._children_name_map["security"] = "security"
                            self._segment_path = lambda: "group-object"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.GroupObject, [], name, value)


                        class Security(Entity):
                            """
                            Match object\-group security
                            
                            .. attribute:: source
                            
                            	Match source object\-group security
                            	**type**\: list of str
                            
                            .. attribute:: destination
                            
                            	Match destination object\-group security
                            	**type**\: list of str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Not.GroupObject.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "group-object"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeafList(YType.str, 'source'), ['str'])),
                                    ('destination', (YLeafList(YType.str, 'destination'), ['str'])),
                                ])
                                self.source = []
                                self.destination = []
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Not.GroupObject.Security, ['source', 'destination'], name, value)


                    class Ip(Entity):
                        """
                        IP specific values
                        
                        .. attribute:: dscp
                        
                        	Match IP DSCP (DiffServ CodePoints)
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 0..63
                        
                        		**type**\: list of   :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                        
                        .. attribute:: precedence
                        
                        	Match IP precedence
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 0..7
                        
                        		**type**\: list of   :py:class:`PrecedenceType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecedenceType>`
                        
                        .. attribute:: rtp
                        
                        	Match RTP port nos
                        	**type**\: list of  		 :py:class:`Rtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Ip.Rtp>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rtp", ("rtp", Native.Policy.ClassMap.Match.Not.Ip.Rtp))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeafList(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                ('precedence', (YLeafList(YType.str, 'precedence'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecedenceType', '')])),
                            ])
                            self.dscp = []
                            self.precedence = []

                            self.rtp = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.Ip, ['dscp', 'precedence'], name, value)


                        class Rtp(Entity):
                            """
                            Match RTP port nos
                            
                            .. attribute:: port1  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 2000..65535
                            
                            .. attribute:: port2  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..16383
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Not.Ip.Rtp, self).__init__()

                                self.yang_name = "rtp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['port1','port2']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port1', (YLeaf(YType.uint16, 'port1'), ['int'])),
                                    ('port2', (YLeaf(YType.uint16, 'port2'), ['int'])),
                                ])
                                self.port1 = None
                                self.port2 = None
                                self._segment_path = lambda: "rtp" + "[port1='" + str(self.port1) + "']" + "[port2='" + str(self.port2) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Not.Ip.Rtp, ['port1', 'port2'], name, value)


                    class Mpls(Entity):
                        """
                        Multi Protocol Label Switching specific values
                        
                        .. attribute:: experimental
                        
                        	Match MPLS experimental
                        	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Mpls.Experimental>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.Mpls, self).__init__()

                            self.yang_name = "mpls"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("experimental", ("experimental", Native.Policy.ClassMap.Match.Not.Mpls.Experimental))])
                            self._leafs = OrderedDict()

                            self.experimental = Native.Policy.ClassMap.Match.Not.Mpls.Experimental()
                            self.experimental.parent = self
                            self._children_name_map["experimental"] = "experimental"
                            self._segment_path = lambda: "mpls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.Mpls, [], name, value)


                        class Experimental(Entity):
                            """
                            Match MPLS experimental
                            
                            .. attribute:: topmost
                            
                            	Match MPLS experimental value on topmost label
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Not.Mpls.Experimental, self).__init__()

                                self.yang_name = "experimental"
                                self.yang_parent_name = "mpls"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('topmost', (YLeafList(YType.uint8, 'topmost'), ['int'])),
                                ])
                                self.topmost = []
                                self._segment_path = lambda: "experimental"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Not.Mpls.Experimental, ['topmost'], name, value)


                    class Packet(Entity):
                        """
                        Layer 3 Packet length
                        
                        .. attribute:: length
                        
                        	Layer 3 Packet length
                        	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Packet.Length>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.Packet, self).__init__()

                            self.yang_name = "packet"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("length", ("length", Native.Policy.ClassMap.Match.Not.Packet.Length))])
                            self._leafs = OrderedDict()

                            self.length = Native.Policy.ClassMap.Match.Not.Packet.Length()
                            self.length.parent = self
                            self._children_name_map["length"] = "length"
                            self._segment_path = lambda: "packet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.Packet, [], name, value)


                        class Length(Entity):
                            """
                            Layer 3 Packet length
                            
                            .. attribute:: max
                            
                            	Maximum length of packet
                            	**type**\: int
                            
                            	**range:** 1..2000
                            
                            .. attribute:: min
                            
                            	Minimum length of packet
                            	**type**\: int
                            
                            	**range:** 1..2000
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Not.Packet.Length, self).__init__()

                                self.yang_name = "length"
                                self.yang_parent_name = "packet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                    ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                ])
                                self.max = None
                                self.min = None
                                self._segment_path = lambda: "length"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Not.Packet.Length, ['max', 'min'], name, value)


                    class Protocol(Entity):
                        """
                        Protocol
                        
                        .. attribute:: protocols_list
                        
                        	
                        	**type**\: list of  		 :py:class:`ProtocolsList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Protocol.ProtocolsList>`
                        
                        .. attribute:: attribute
                        
                        	Attribute based protocol match
                        	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Protocol.Attribute>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.Protocol, self).__init__()

                            self.yang_name = "protocol"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocols-list", ("protocols_list", Native.Policy.ClassMap.Match.Not.Protocol.ProtocolsList)), ("attribute", ("attribute", Native.Policy.ClassMap.Match.Not.Protocol.Attribute))])
                            self._leafs = OrderedDict()

                            self.attribute = Native.Policy.ClassMap.Match.Not.Protocol.Attribute()
                            self.attribute.parent = self
                            self._children_name_map["attribute"] = "attribute"

                            self.protocols_list = YList(self)
                            self._segment_path = lambda: "protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.Protocol, [], name, value)


                        class ProtocolsList(Entity):
                            """
                            
                            
                            .. attribute:: protocols  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Not.Protocol.ProtocolsList, self).__init__()

                                self.yang_name = "protocols-list"
                                self.yang_parent_name = "protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['protocols']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protocols', (YLeaf(YType.str, 'protocols'), ['str'])),
                                ])
                                self.protocols = None
                                self._segment_path = lambda: "protocols-list" + "[protocols='" + str(self.protocols) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Not.Protocol.ProtocolsList, ['protocols'], name, value)


                        class Attribute(Entity):
                            """
                            Attribute based protocol match
                            
                            .. attribute:: application_group
                            
                            	Application\-group attribute
                            	**type**\: list of  		 :py:class:`ApplicationGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Protocol.Attribute.ApplicationGroup>`
                            
                            .. attribute:: application_set
                            
                            	Application\-set attribute
                            	**type**\: list of  		 :py:class:`ApplicationSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Protocol.Attribute.ApplicationSet>`
                            
                            .. attribute:: business_relevance
                            
                            	Application business\-relevance
                            	**type**\: list of  		 :py:class:`BusinessRelevance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Protocol.Attribute.BusinessRelevance>`
                            
                            .. attribute:: category
                            
                            	Category attribute
                            	**type**\: list of  		 :py:class:`Category <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Category>`
                            
                            .. attribute:: encrypted
                            
                            	Encrypted applications
                            	**type**\: list of  		 :py:class:`Encrypted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Encrypted>`
                            
                            .. attribute:: sub_category
                            
                            	Sub\-category attribute
                            	**type**\: list of  		 :py:class:`SubCategory <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Protocol.Attribute.SubCategory>`
                            
                            .. attribute:: traffic_class
                            
                            	SRND class
                            	**type**\: list of  		 :py:class:`TrafficClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Protocol.Attribute.TrafficClass>`
                            
                            .. attribute:: tunnel
                            
                            	Tunnelled applications
                            	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Tunnel>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Not.Protocol.Attribute, self).__init__()

                                self.yang_name = "attribute"
                                self.yang_parent_name = "protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("application-group", ("application_group", Native.Policy.ClassMap.Match.Not.Protocol.Attribute.ApplicationGroup)), ("application-set", ("application_set", Native.Policy.ClassMap.Match.Not.Protocol.Attribute.ApplicationSet)), ("business-relevance", ("business_relevance", Native.Policy.ClassMap.Match.Not.Protocol.Attribute.BusinessRelevance)), ("category", ("category", Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Category)), ("encrypted", ("encrypted", Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Encrypted)), ("sub-category", ("sub_category", Native.Policy.ClassMap.Match.Not.Protocol.Attribute.SubCategory)), ("traffic-class", ("traffic_class", Native.Policy.ClassMap.Match.Not.Protocol.Attribute.TrafficClass)), ("tunnel", ("tunnel", Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Tunnel))])
                                self._leafs = OrderedDict()

                                self.application_group = YList(self)
                                self.application_set = YList(self)
                                self.business_relevance = YList(self)
                                self.category = YList(self)
                                self.encrypted = YList(self)
                                self.sub_category = YList(self)
                                self.traffic_class = YList(self)
                                self.tunnel = YList(self)
                                self._segment_path = lambda: "attribute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Not.Protocol.Attribute, [], name, value)


                            class ApplicationGroup(Entity):
                                """
                                Application\-group attribute
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.ApplicationGroup, self).__init__()

                                    self.yang_name = "application-group"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "application-group" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.ApplicationGroup, ['name'], name, value)


                            class ApplicationSet(Entity):
                                """
                                Application\-set attribute
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.ApplicationSet, self).__init__()

                                    self.yang_name = "application-set"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "application-set" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.ApplicationSet, ['name'], name, value)


                            class BusinessRelevance(Entity):
                                """
                                Application business\-relevance
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.BusinessRelevance, self).__init__()

                                    self.yang_name = "business-relevance"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "business-relevance" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.BusinessRelevance, ['name'], name, value)


                            class Category(Entity):
                                """
                                Category attribute
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Category, self).__init__()

                                    self.yang_name = "category"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "category" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Category, ['name'], name, value)


                            class Encrypted(Entity):
                                """
                                Encrypted applications
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Encrypted, self).__init__()

                                    self.yang_name = "encrypted"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "encrypted" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Encrypted, ['name'], name, value)


                            class SubCategory(Entity):
                                """
                                Sub\-category attribute
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.SubCategory, self).__init__()

                                    self.yang_name = "sub-category"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "sub-category" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.SubCategory, ['name'], name, value)


                            class TrafficClass(Entity):
                                """
                                SRND class
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.TrafficClass, self).__init__()

                                    self.yang_name = "traffic-class"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "traffic-class" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.TrafficClass, ['name'], name, value)


                            class Tunnel(Entity):
                                """
                                Tunnelled applications
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Tunnel, self).__init__()

                                    self.yang_name = "tunnel"
                                    self.yang_parent_name = "attribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "tunnel" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.ClassMap.Match.Not.Protocol.Attribute.Tunnel, ['name'], name, value)


                    class SecurityGroup(Entity):
                        """
                        Security group
                        
                        .. attribute:: destination
                        
                        	Destination security group
                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.SecurityGroup.Destination>`
                        
                        .. attribute:: source
                        
                        	Source security group
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.Match.Not.SecurityGroup.Source>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.SecurityGroup, self).__init__()

                            self.yang_name = "security-group"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("destination", ("destination", Native.Policy.ClassMap.Match.Not.SecurityGroup.Destination)), ("source", ("source", Native.Policy.ClassMap.Match.Not.SecurityGroup.Source))])
                            self._leafs = OrderedDict()

                            self.destination = Native.Policy.ClassMap.Match.Not.SecurityGroup.Destination()
                            self.destination.parent = self
                            self._children_name_map["destination"] = "destination"

                            self.source = Native.Policy.ClassMap.Match.Not.SecurityGroup.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "security-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.SecurityGroup, [], name, value)


                        class Destination(Entity):
                            """
                            Destination security group
                            
                            .. attribute:: tag
                            
                            	Security group tag
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Not.SecurityGroup.Destination, self).__init__()

                                self.yang_name = "destination"
                                self.yang_parent_name = "security-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('tag', (YLeaf(YType.uint16, 'tag'), ['int'])),
                                ])
                                self.tag = None
                                self._segment_path = lambda: "destination"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Not.SecurityGroup.Destination, ['tag'], name, value)


                        class Source(Entity):
                            """
                            Source security group
                            
                            .. attribute:: tag
                            
                            	Security group tag
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.Match.Not.SecurityGroup.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "security-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('tag', (YLeaf(YType.uint16, 'tag'), ['int'])),
                                ])
                                self.tag = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.Match.Not.SecurityGroup.Source, ['tag'], name, value)


                    class Service(Entity):
                        """
                        Service Instance to match
                        
                        .. attribute:: efp  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4000
                        
                        .. attribute:: instance
                        
                        	Service Instance to match
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ethernet
                        
                        	Service Instance to match
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.Service, self).__init__()

                            self.yang_name = "service"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['efp']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('efp', (YLeaf(YType.uint16, 'efp'), ['int'])),
                                ('instance', (YLeaf(YType.empty, 'instance'), ['Empty'])),
                                ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ])
                            self.efp = None
                            self.instance = None
                            self.ethernet = None
                            self._segment_path = lambda: "service" + "[efp='" + str(self.efp) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.Service, ['efp', 'instance', 'ethernet'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source address
                        
                        .. attribute:: mac
                        
                        	MAC address
                        	**type**\: list of str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mac', (YLeafList(YType.str, 'mac'), ['str'])),
                            ])
                            self.mac = []
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.SourceAddress, ['mac'], name, value)


                    class Vlan(Entity):
                        """
                        VLANs to match
                        
                        .. attribute:: inner
                        
                        	Inner tag to match
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..4094
                        
                        		**type**\: list of str
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..4094
                        
                        		**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.Match.Not.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "not"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('inner', (YLeafList(YType.str, 'inner'), ['int','str'])),
                                ('value', (YLeafList(YType.str, 'value'), ['int','str'])),
                            ])
                            self.inner = []
                            self.value = []
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.Match.Not.Vlan, ['inner', 'value'], name, value)


            class NoMatch(Entity):
                """
                no\-match filter
                
                .. attribute:: activated_service_template
                
                	match name of service template activated on session
                	**type**\: list of  		 :py:class:`ActivatedServiceTemplate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.ActivatedServiceTemplate>`
                
                .. attribute:: authorization_status
                
                	match the authorization status of the session
                	**type**\:  :py:class:`AuthorizationStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.AuthorizationStatus>`
                
                .. attribute:: authorizing_method_priority
                
                	match the priority against the authorizing method's priority
                	**type**\:  :py:class:`AuthorizingMethodPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.AuthorizingMethodPriority>`
                
                .. attribute:: client_type
                
                	match the type of device from an event
                	**type**\:  :py:class:`ClientType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.ClientType>`
                
                .. attribute:: device_type
                
                	match name of the device\-type
                	**type**\: str
                
                .. attribute:: interface
                
                	match the session interface
                	**type**\: str
                
                .. attribute:: ip_address
                
                	match the IP address from an event
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ipv6_address
                
                	match the IPv6 address from an event
                	**type**\: str
                
                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mac_address
                
                	match the MAC address from an event
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                
                .. attribute:: method
                
                	match the type of authentication method from an event
                	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.Method>`
                
                .. attribute:: oui
                
                	match the oui address from an event
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                
                .. attribute:: port_type
                
                	match the type interface from an event
                	**type**\:  :py:class:`PortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.PortType>`
                
                .. attribute:: result_type
                
                	match the result type, optionally for a specific method
                	**type**\:  :py:class:`ResultType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.ResultType>`
                
                .. attribute:: service_template
                
                	match name of service template from an event
                	**type**\: str
                
                .. attribute:: session_type
                
                	match the session type
                	**type**\:  :py:class:`SessionType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.SessionType>`
                
                .. attribute:: sgt
                
                	match the sgt session
                	**type**\: int
                
                	**range:** 2..65519
                
                .. attribute:: ssid
                
                	match the ssid of the session
                	**type**\: str
                
                .. attribute:: tag
                
                	match tag from an event
                	**type**\: str
                
                .. attribute:: timer
                
                	match the type of timer
                	**type**\: str
                
                .. attribute:: user_role
                
                	match the user\-role
                	**type**\: str
                
                .. attribute:: username
                
                	match the username
                	**type**\: str
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Policy.ClassMap.NoMatch, self).__init__()

                    self.yang_name = "no-match"
                    self.yang_parent_name = "class-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("activated-service-template", ("activated_service_template", Native.Policy.ClassMap.NoMatch.ActivatedServiceTemplate)), ("authorization-status", ("authorization_status", Native.Policy.ClassMap.NoMatch.AuthorizationStatus)), ("authorizing-method-priority", ("authorizing_method_priority", Native.Policy.ClassMap.NoMatch.AuthorizingMethodPriority)), ("method", ("method", Native.Policy.ClassMap.NoMatch.Method)), ("result-type", ("result_type", Native.Policy.ClassMap.NoMatch.ResultType))])
                    self._leafs = OrderedDict([
                        ('client_type', (YLeaf(YType.enumeration, 'client-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.ClassMap.NoMatch.ClientType')])),
                        ('device_type', (YLeaf(YType.str, 'device-type'), ['str'])),
                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                        ('oui', (YLeaf(YType.str, 'oui'), ['str'])),
                        ('port_type', (YLeaf(YType.enumeration, 'port-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.ClassMap.NoMatch.PortType')])),
                        ('service_template', (YLeaf(YType.str, 'service-template'), ['str'])),
                        ('session_type', (YLeaf(YType.enumeration, 'session-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.ClassMap.NoMatch.SessionType')])),
                        ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                        ('ssid', (YLeaf(YType.str, 'ssid'), ['str'])),
                        ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                        ('timer', (YLeaf(YType.str, 'timer'), ['str'])),
                        ('user_role', (YLeaf(YType.str, 'user-role'), ['str'])),
                        ('username', (YLeaf(YType.str, 'username'), ['str'])),
                    ])
                    self.client_type = None
                    self.device_type = None
                    self.interface = None
                    self.ip_address = None
                    self.ipv6_address = None
                    self.mac_address = None
                    self.oui = None
                    self.port_type = None
                    self.service_template = None
                    self.session_type = None
                    self.sgt = None
                    self.ssid = None
                    self.tag = None
                    self.timer = None
                    self.user_role = None
                    self.username = None

                    self.authorization_status = Native.Policy.ClassMap.NoMatch.AuthorizationStatus()
                    self.authorization_status.parent = self
                    self._children_name_map["authorization_status"] = "authorization-status"

                    self.authorizing_method_priority = Native.Policy.ClassMap.NoMatch.AuthorizingMethodPriority()
                    self.authorizing_method_priority.parent = self
                    self._children_name_map["authorizing_method_priority"] = "authorizing-method-priority"

                    self.method = Native.Policy.ClassMap.NoMatch.Method()
                    self.method.parent = self
                    self._children_name_map["method"] = "method"

                    self.result_type = Native.Policy.ClassMap.NoMatch.ResultType()
                    self.result_type.parent = self
                    self._children_name_map["result_type"] = "result-type"

                    self.activated_service_template = YList(self)
                    self._segment_path = lambda: "no-match"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Policy.ClassMap.NoMatch, ['client_type', 'device_type', 'interface', 'ip_address', 'ipv6_address', 'mac_address', 'oui', 'port_type', 'service_template', 'session_type', 'sgt', 'ssid', 'tag', 'timer', 'user_role', 'username'], name, value)

                class ClientType(Enum):
                    """
                    ClientType (Enum Class)

                    match the type of device from an event

                    .. data:: data = 0

                    .. data:: switch = 1

                    .. data:: video = 2

                    .. data:: voice = 3

                    """

                    data = Enum.YLeaf(0, "data")

                    switch = Enum.YLeaf(1, "switch")

                    video = Enum.YLeaf(2, "video")

                    voice = Enum.YLeaf(3, "voice")


                class PortType(Enum):
                    """
                    PortType (Enum Class)

                    match the type interface from an event

                    .. data:: dot11_port = 0

                    .. data:: l2_port = 1

                    .. data:: l3_port = 2

                    """

                    dot11_port = Enum.YLeaf(0, "dot11-port")

                    l2_port = Enum.YLeaf(1, "l2-port")

                    l3_port = Enum.YLeaf(2, "l3-port")


                class SessionType(Enum):
                    """
                    SessionType (Enum Class)

                    match the session type

                    .. data:: wired = 0

                    .. data:: wireless = 1

                    """

                    wired = Enum.YLeaf(0, "wired")

                    wireless = Enum.YLeaf(1, "wireless")



                class ActivatedServiceTemplate(Entity):
                    """
                    match name of service template activated on session
                    
                    .. attribute:: service_name  (key)
                    
                    	Enter service name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.NoMatch.ActivatedServiceTemplate, self).__init__()

                        self.yang_name = "activated-service-template"
                        self.yang_parent_name = "no-match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['service_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('service_name', (YLeaf(YType.str, 'service-name'), ['str'])),
                        ])
                        self.service_name = None
                        self._segment_path = lambda: "activated-service-template" + "[service-name='" + str(self.service_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.NoMatch.ActivatedServiceTemplate, ['service_name'], name, value)


                class AuthorizationStatus(Entity):
                    """
                    match the authorization status of the session
                    
                    .. attribute:: authorized
                    
                    	authorized
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unauthorized
                    
                    	unauthorized
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.NoMatch.AuthorizationStatus, self).__init__()

                        self.yang_name = "authorization-status"
                        self.yang_parent_name = "no-match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('authorized', (YLeaf(YType.empty, 'authorized'), ['Empty'])),
                            ('unauthorized', (YLeaf(YType.empty, 'unauthorized'), ['Empty'])),
                        ])
                        self.authorized = None
                        self.unauthorized = None
                        self._segment_path = lambda: "authorization-status"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.NoMatch.AuthorizationStatus, ['authorized', 'unauthorized'], name, value)


                class AuthorizingMethodPriority(Entity):
                    """
                    match the priority against the authorizing method's priority
                    
                    .. attribute:: eq
                    
                    	equal to
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: gt
                    
                    	greater than
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: lt
                    
                    	less than
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.NoMatch.AuthorizingMethodPriority, self).__init__()

                        self.yang_name = "authorizing-method-priority"
                        self.yang_parent_name = "no-match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eq', (YLeaf(YType.uint8, 'eq'), ['int'])),
                            ('gt', (YLeaf(YType.uint8, 'gt'), ['int'])),
                            ('lt', (YLeaf(YType.uint8, 'lt'), ['int'])),
                        ])
                        self.eq = None
                        self.gt = None
                        self.lt = None
                        self._segment_path = lambda: "authorizing-method-priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.NoMatch.AuthorizingMethodPriority, ['eq', 'gt', 'lt'], name, value)


                class Method(Entity):
                    """
                    match the type of authentication method from an event
                    
                    .. attribute:: dot1x
                    
                    	dot1x
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	mab
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	webauth
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.NoMatch.Method, self).__init__()

                        self.yang_name = "method"
                        self.yang_parent_name = "no-match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "method"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.NoMatch.Method, ['dot1x', 'mab', 'webauth'], name, value)


                class ResultType(Entity):
                    """
                    match the result type, optionally for a specific method
                    
                    .. attribute:: method
                    
                    	match the result of a particular method
                    	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.ResultType.Method>`
                    
                    .. attribute:: aaa_timeout
                    
                    	aaa timeout type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: agent_not_found
                    
                    	agent not found type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: authoritative
                    
                    	failure type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: method_timeout
                    
                    	method\_timeout type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: none
                    
                    	no type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: success
                    
                    	success type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.ClassMap.NoMatch.ResultType, self).__init__()

                        self.yang_name = "result-type"
                        self.yang_parent_name = "no-match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("method", ("method", Native.Policy.ClassMap.NoMatch.ResultType.Method))])
                        self._leafs = OrderedDict([
                            ('aaa_timeout', (YLeaf(YType.empty, 'aaa-timeout'), ['Empty'])),
                            ('agent_not_found', (YLeaf(YType.empty, 'agent-not-found'), ['Empty'])),
                            ('authoritative', (YLeaf(YType.empty, 'authoritative'), ['Empty'])),
                            ('method_timeout', (YLeaf(YType.empty, 'method-timeout'), ['Empty'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('success', (YLeaf(YType.empty, 'success'), ['Empty'])),
                        ])
                        self.aaa_timeout = None
                        self.agent_not_found = None
                        self.authoritative = None
                        self.method_timeout = None
                        self.none = None
                        self.success = None

                        self.method = Native.Policy.ClassMap.NoMatch.ResultType.Method()
                        self.method.parent = self
                        self._children_name_map["method"] = "method"
                        self._segment_path = lambda: "result-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.ClassMap.NoMatch.ResultType, ['aaa_timeout', 'agent_not_found', 'authoritative', 'method_timeout', 'none', 'success'], name, value)


                    class Method(Entity):
                        """
                        match the result of a particular method
                        
                        .. attribute:: dot1x
                        
                        	dot1x result
                        	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.ResultType.Method.Dot1x>`
                        
                        .. attribute:: mab
                        
                        	mab result
                        	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.ResultType.Method.Mab>`
                        
                        .. attribute:: webauth
                        
                        	webauth result
                        	**type**\:  :py:class:`Webauth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap.NoMatch.ResultType.Method.Webauth>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.ClassMap.NoMatch.ResultType.Method, self).__init__()

                            self.yang_name = "method"
                            self.yang_parent_name = "result-type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1x", ("dot1x", Native.Policy.ClassMap.NoMatch.ResultType.Method.Dot1x)), ("mab", ("mab", Native.Policy.ClassMap.NoMatch.ResultType.Method.Mab)), ("webauth", ("webauth", Native.Policy.ClassMap.NoMatch.ResultType.Method.Webauth))])
                            self._leafs = OrderedDict()

                            self.dot1x = Native.Policy.ClassMap.NoMatch.ResultType.Method.Dot1x()
                            self.dot1x.parent = self
                            self._children_name_map["dot1x"] = "dot1x"

                            self.mab = Native.Policy.ClassMap.NoMatch.ResultType.Method.Mab()
                            self.mab.parent = self
                            self._children_name_map["mab"] = "mab"

                            self.webauth = Native.Policy.ClassMap.NoMatch.ResultType.Method.Webauth()
                            self.webauth.parent = self
                            self._children_name_map["webauth"] = "webauth"
                            self._segment_path = lambda: "method"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.ClassMap.NoMatch.ResultType.Method, [], name, value)


                        class Dot1x(Entity):
                            """
                            dot1x result
                            
                            .. attribute:: aaa_timeout
                            
                            	aaa timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: agent_not_found
                            
                            	agent not found type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: authoritative
                            
                            	failure type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: method_timeout
                            
                            	method\_timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: none
                            
                            	no type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: success
                            
                            	success type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.NoMatch.ResultType.Method.Dot1x, self).__init__()

                                self.yang_name = "dot1x"
                                self.yang_parent_name = "method"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('aaa_timeout', (YLeaf(YType.empty, 'aaa-timeout'), ['Empty'])),
                                    ('agent_not_found', (YLeaf(YType.empty, 'agent-not-found'), ['Empty'])),
                                    ('authoritative', (YLeaf(YType.empty, 'authoritative'), ['Empty'])),
                                    ('method_timeout', (YLeaf(YType.empty, 'method-timeout'), ['Empty'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('success', (YLeaf(YType.empty, 'success'), ['Empty'])),
                                ])
                                self.aaa_timeout = None
                                self.agent_not_found = None
                                self.authoritative = None
                                self.method_timeout = None
                                self.none = None
                                self.success = None
                                self._segment_path = lambda: "dot1x"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.NoMatch.ResultType.Method.Dot1x, ['aaa_timeout', 'agent_not_found', 'authoritative', 'method_timeout', 'none', 'success'], name, value)


                        class Mab(Entity):
                            """
                            mab result
                            
                            .. attribute:: aaa_timeout
                            
                            	aaa timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: agent_not_found
                            
                            	agent not found type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: authoritative
                            
                            	failure type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: method_timeout
                            
                            	method\_timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: none
                            
                            	no type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: success
                            
                            	success type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.NoMatch.ResultType.Method.Mab, self).__init__()

                                self.yang_name = "mab"
                                self.yang_parent_name = "method"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('aaa_timeout', (YLeaf(YType.empty, 'aaa-timeout'), ['Empty'])),
                                    ('agent_not_found', (YLeaf(YType.empty, 'agent-not-found'), ['Empty'])),
                                    ('authoritative', (YLeaf(YType.empty, 'authoritative'), ['Empty'])),
                                    ('method_timeout', (YLeaf(YType.empty, 'method-timeout'), ['Empty'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('success', (YLeaf(YType.empty, 'success'), ['Empty'])),
                                ])
                                self.aaa_timeout = None
                                self.agent_not_found = None
                                self.authoritative = None
                                self.method_timeout = None
                                self.none = None
                                self.success = None
                                self._segment_path = lambda: "mab"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.NoMatch.ResultType.Method.Mab, ['aaa_timeout', 'agent_not_found', 'authoritative', 'method_timeout', 'none', 'success'], name, value)


                        class Webauth(Entity):
                            """
                            webauth result
                            
                            .. attribute:: aaa_timeout
                            
                            	aaa timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: agent_not_found
                            
                            	agent not found type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: authoritative
                            
                            	failure type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: method_timeout
                            
                            	method\_timeout type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: none
                            
                            	no type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: success
                            
                            	success type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.ClassMap.NoMatch.ResultType.Method.Webauth, self).__init__()

                                self.yang_name = "webauth"
                                self.yang_parent_name = "method"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('aaa_timeout', (YLeaf(YType.empty, 'aaa-timeout'), ['Empty'])),
                                    ('agent_not_found', (YLeaf(YType.empty, 'agent-not-found'), ['Empty'])),
                                    ('authoritative', (YLeaf(YType.empty, 'authoritative'), ['Empty'])),
                                    ('method_timeout', (YLeaf(YType.empty, 'method-timeout'), ['Empty'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('success', (YLeaf(YType.empty, 'success'), ['Empty'])),
                                ])
                                self.aaa_timeout = None
                                self.agent_not_found = None
                                self.authoritative = None
                                self.method_timeout = None
                                self.none = None
                                self.success = None
                                self._segment_path = lambda: "webauth"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.ClassMap.NoMatch.ResultType.Method.Webauth, ['aaa_timeout', 'agent_not_found', 'authoritative', 'method_timeout', 'none', 'success'], name, value)


        class PolicyMap(Entity):
            """
            Configure QoS Policy Map
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            	**length:** 1..512
            
            .. attribute:: type
            
            	type of the policy\-map
            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Type>`
            
            .. attribute:: subscriber
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: protocol
            
            	
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Protocol>`
            
            .. attribute:: event
            
            	The event type this control class\-map triggers upon
            	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event>`
            
            .. attribute:: class_
            
            	policy criteria
            	**type**\: list of  		 :py:class:`Class <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class>`
            
            .. attribute:: description
            
            	Policy\-Map description
            	**type**\: str
            
            	**length:** 1..200
            
            .. attribute:: sequence_interval
            
            	Enable sequence number capability
            	**type**\: int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'ios-policy'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Policy.PolicyMap, self).__init__()

                self.yang_name = "policy-map"
                self.yang_parent_name = "policy"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("event", ("event", Native.Policy.PolicyMap.Event)), ("class", ("class_", Native.Policy.PolicyMap.Class))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Type')])),
                    ('subscriber', (YLeaf(YType.empty, 'subscriber'), ['Empty'])),
                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Protocol')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('sequence_interval', (YLeaf(YType.uint16, 'sequence-interval'), ['int'])),
                ])
                self.name = None
                self.type = None
                self.subscriber = None
                self.protocol = None
                self.description = None
                self.sequence_interval = None

                self.event = YList(self)
                self.class_ = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-policy:policy-map" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/policy/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Policy.PolicyMap, ['name', 'type', 'subscriber', 'protocol', 'description', 'sequence_interval'], name, value)

            class Protocol(Enum):
                """
                Protocol (Enum Class)

                .. data:: avc = 0

                .. data:: http = 1

                .. data:: im = 2

                .. data:: imap = 3

                .. data:: p2p = 4

                .. data:: pop3 = 5

                .. data:: smtp = 6

                .. data:: sunrpc = 7

                """

                avc = Enum.YLeaf(0, "avc")

                http = Enum.YLeaf(1, "http")

                im = Enum.YLeaf(2, "im")

                imap = Enum.YLeaf(3, "imap")

                p2p = Enum.YLeaf(4, "p2p")

                pop3 = Enum.YLeaf(5, "pop3")

                smtp = Enum.YLeaf(6, "smtp")

                sunrpc = Enum.YLeaf(7, "sunrpc")


            class Type(Enum):
                """
                Type (Enum Class)

                type of the policy\-map

                .. data:: access_control = 0

                .. data:: appnav = 1

                .. data:: inspect = 2

                .. data:: control = 3

                .. data:: packet_service = 4

                .. data:: performance_monitor = 5

                .. data:: service = 6

                .. data:: service_chain = 7

                """

                access_control = Enum.YLeaf(0, "access-control")

                appnav = Enum.YLeaf(1, "appnav")

                inspect = Enum.YLeaf(2, "inspect")

                control = Enum.YLeaf(3, "control")

                packet_service = Enum.YLeaf(4, "packet-service")

                performance_monitor = Enum.YLeaf(5, "performance-monitor")

                service = Enum.YLeaf(6, "service")

                service_chain = Enum.YLeaf(7, "service-chain")



            class Event(Entity):
                """
                The event type this control class\-map triggers upon
                
                .. attribute:: event_type  (key)
                
                	
                	**type**\:  :py:class:`EventType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.EventType>`
                
                .. attribute:: match_type
                
                	
                	**type**\:  :py:class:`MatchType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.MatchType>`
                
                .. attribute:: class_number
                
                	class number, 1 for 1st class, 2 for 2nd..
                	**type**\: list of  		 :py:class:`ClassNumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Policy.PolicyMap.Event, self).__init__()

                    self.yang_name = "event"
                    self.yang_parent_name = "policy-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['event_type']
                    self._child_classes = OrderedDict([("class-number", ("class_number", Native.Policy.PolicyMap.Event.ClassNumber))])
                    self._leafs = OrderedDict([
                        ('event_type', (YLeaf(YType.enumeration, 'event-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Event.EventType')])),
                        ('match_type', (YLeaf(YType.enumeration, 'match-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Event.MatchType')])),
                    ])
                    self.event_type = None
                    self.match_type = None

                    self.class_number = YList(self)
                    self._segment_path = lambda: "event" + "[event-type='" + str(self.event_type) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Policy.PolicyMap.Event, ['event_type', 'match_type'], name, value)

                class EventType(Enum):
                    """
                    EventType (Enum Class)

                    .. data:: aaa_available = 0

                    .. data:: absolute_timeout = 1

                    .. data:: agent_found = 2

                    .. data:: authentication_failure = 3

                    .. data:: authentication_success = 4

                    .. data:: authorization_failure = 5

                    .. data:: authorization_success = 6

                    .. data:: identity_update = 7

                    .. data:: inactivity_timeout = 8

                    .. data:: remote_authentication_failure = 9

                    .. data:: remote_authentication_success = 10

                    .. data:: session_disconnected = 11

                    .. data:: session_started = 12

                    .. data:: tag_added = 13

                    .. data:: tag_removed = 14

                    .. data:: template_activated = 15

                    .. data:: template_activation_failed = 16

                    .. data:: template_deactivated = 17

                    .. data:: template_deactivation_failed = 18

                    .. data:: timer_expiry = 19

                    .. data:: violation = 20

                    """

                    aaa_available = Enum.YLeaf(0, "aaa-available")

                    absolute_timeout = Enum.YLeaf(1, "absolute-timeout")

                    agent_found = Enum.YLeaf(2, "agent-found")

                    authentication_failure = Enum.YLeaf(3, "authentication-failure")

                    authentication_success = Enum.YLeaf(4, "authentication-success")

                    authorization_failure = Enum.YLeaf(5, "authorization-failure")

                    authorization_success = Enum.YLeaf(6, "authorization-success")

                    identity_update = Enum.YLeaf(7, "identity-update")

                    inactivity_timeout = Enum.YLeaf(8, "inactivity-timeout")

                    remote_authentication_failure = Enum.YLeaf(9, "remote-authentication-failure")

                    remote_authentication_success = Enum.YLeaf(10, "remote-authentication-success")

                    session_disconnected = Enum.YLeaf(11, "session-disconnected")

                    session_started = Enum.YLeaf(12, "session-started")

                    tag_added = Enum.YLeaf(13, "tag-added")

                    tag_removed = Enum.YLeaf(14, "tag-removed")

                    template_activated = Enum.YLeaf(15, "template-activated")

                    template_activation_failed = Enum.YLeaf(16, "template-activation-failed")

                    template_deactivated = Enum.YLeaf(17, "template-deactivated")

                    template_deactivation_failed = Enum.YLeaf(18, "template-deactivation-failed")

                    timer_expiry = Enum.YLeaf(19, "timer-expiry")

                    violation = Enum.YLeaf(20, "violation")


                class MatchType(Enum):
                    """
                    MatchType (Enum Class)

                    .. data:: match_all = 0

                    .. data:: match_first = 1

                    """

                    match_all = Enum.YLeaf(0, "match-all")

                    match_first = Enum.YLeaf(1, "match-first")



                class ClassNumber(Entity):
                    """
                    class number, 1 for 1st class, 2 for 2nd...
                    
                    .. attribute:: number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: class_
                    
                    	The class type this control policy\-map triggers upon
                    	**type**\: union of the below types:
                    
                    		**type**\:  :py:class:`Class_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.Class_>`
                    
                    		**type**\: str
                    
                    .. attribute:: execution_type
                    
                    	
                    	**type**\:  :py:class:`ExecutionType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.ExecutionType>`
                    
                    .. attribute:: action_number
                    
                    	action number, 1 for 1st class, 2 for 2nd..
                    	**type**\: list of  		 :py:class:`ActionNumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.PolicyMap.Event.ClassNumber, self).__init__()

                        self.yang_name = "class-number"
                        self.yang_parent_name = "event"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['number']
                        self._child_classes = OrderedDict([("action-number", ("action_number", Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber))])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                            ('class_', (YLeaf(YType.str, 'class'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Event.ClassNumber.Class_'),'str'])),
                            ('execution_type', (YLeaf(YType.enumeration, 'execution-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Event.ClassNumber.ExecutionType')])),
                        ])
                        self.number = None
                        self.class_ = None
                        self.execution_type = None

                        self.action_number = YList(self)
                        self._segment_path = lambda: "class-number" + "[number='" + str(self.number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.PolicyMap.Event.ClassNumber, ['number', 'class_', 'execution_type'], name, value)

                    class Class_(Enum):
                        """
                        Class\_ (Enum Class)

                        The class type this control policy\-map triggers upon

                        .. data:: always = 0

                        """

                        always = Enum.YLeaf(0, "always")


                    class ExecutionType(Enum):
                        """
                        ExecutionType (Enum Class)

                        .. data:: do_all = 0

                        .. data:: do_until_failure = 1

                        .. data:: do_until_success = 2

                        """

                        do_all = Enum.YLeaf(0, "do-all")

                        do_until_failure = Enum.YLeaf(1, "do-until-failure")

                        do_until_success = Enum.YLeaf(2, "do-until-success")



                    class ActionNumber(Entity):
                        """
                        action number, 1 for 1st class, 2 for 2nd...
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        .. attribute:: terminate
                        
                        	terminate auth method
                        	**type**\:  :py:class:`Terminate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Terminate>`
                        
                        .. attribute:: replace
                        
                        	clear existing session and create session for violating host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: clear_session
                        
                        	clears an active session
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: resume
                        
                        	resume operation to be specified
                        	**type**\:  :py:class:`Resume <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Resume>`
                        
                        .. attribute:: authentication_restart
                        
                        	restarts the auth sequence after the specified number of sec
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: pause
                        
                        	pause operation to be specified
                        	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Pause>`
                        
                        .. attribute:: authorize
                        
                        	authorize session
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: activate
                        
                        	activate template or policy
                        	**type**\:  :py:class:`Activate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Activate>`
                        
                        .. attribute:: authenticate
                        
                        	authenticate a session
                        	**type**\:  :py:class:`Authenticate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate>`
                        
                        .. attribute:: map
                        
                        	map identity\-update attribute to a auto\-conf templates
                        	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Map>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber, self).__init__()

                            self.yang_name = "action-number"
                            self.yang_parent_name = "class-number"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([("terminate", ("terminate", Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Terminate)), ("resume", ("resume", Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Resume)), ("pause", ("pause", Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Pause)), ("activate", ("activate", Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Activate)), ("authenticate", ("authenticate", Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate)), ("map", ("map", Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Map))])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                ('replace', (YLeaf(YType.empty, 'replace'), ['Empty'])),
                                ('clear_session', (YLeaf(YType.empty, 'clear-session'), ['Empty'])),
                                ('authentication_restart', (YLeaf(YType.uint16, 'authentication-restart'), ['int'])),
                                ('authorize', (YLeaf(YType.empty, 'authorize'), ['Empty'])),
                            ])
                            self.number = None
                            self.replace = None
                            self.clear_session = None
                            self.authentication_restart = None
                            self.authorize = None

                            self.terminate = Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Terminate()
                            self.terminate.parent = self
                            self._children_name_map["terminate"] = "terminate"

                            self.resume = Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Resume()
                            self.resume.parent = self
                            self._children_name_map["resume"] = "resume"

                            self.pause = Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Pause()
                            self.pause.parent = self
                            self._children_name_map["pause"] = "pause"

                            self.activate = Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Activate()
                            self.activate.parent = self
                            self._children_name_map["activate"] = "activate"

                            self.authenticate = Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate()
                            self.authenticate.parent = self
                            self._children_name_map["authenticate"] = "authenticate"

                            self.map = Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Map()
                            self.map.parent = self
                            self._children_name_map["map"] = "map"
                            self._segment_path = lambda: "action-number" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber, ['number', 'replace', 'clear_session', 'authentication_restart', 'authorize'], name, value)


                        class Terminate(Entity):
                            """
                            terminate auth method
                            
                            .. attribute:: dot1x
                            
                            	dot1x method
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mab
                            
                            	mab method
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: webauth
                            
                            	webauth method
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Terminate, self).__init__()

                                self.yang_name = "terminate"
                                self.yang_parent_name = "action-number"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                                    ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                                    ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                                ])
                                self.dot1x = None
                                self.mab = None
                                self.webauth = None
                                self._segment_path = lambda: "terminate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Terminate, ['dot1x', 'mab', 'webauth'], name, value)


                        class Resume(Entity):
                            """
                            resume operation to be specified
                            
                            .. attribute:: reauthentication
                            
                            	resume reauthentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Resume, self).__init__()

                                self.yang_name = "resume"
                                self.yang_parent_name = "action-number"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reauthentication', (YLeaf(YType.empty, 'reauthentication'), ['Empty'])),
                                ])
                                self.reauthentication = None
                                self._segment_path = lambda: "resume"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Resume, ['reauthentication'], name, value)


                        class Pause(Entity):
                            """
                            pause operation to be specified
                            
                            .. attribute:: reauthentication
                            
                            	pause reauthentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Pause, self).__init__()

                                self.yang_name = "pause"
                                self.yang_parent_name = "action-number"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reauthentication', (YLeaf(YType.empty, 'reauthentication'), ['Empty'])),
                                ])
                                self.reauthentication = None
                                self._segment_path = lambda: "pause"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Pause, ['reauthentication'], name, value)


                        class Activate(Entity):
                            """
                            activate template or policy
                            
                            .. attribute:: service_template
                            
                            	activate service template
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Activate, self).__init__()

                                self.yang_name = "activate"
                                self.yang_parent_name = "action-number"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('service_template', (YLeaf(YType.str, 'service-template'), ['str'])),
                                ])
                                self.service_template = None
                                self._segment_path = lambda: "activate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Activate, ['service_template'], name, value)


                        class Authenticate(Entity):
                            """
                            authenticate a session
                            
                            .. attribute:: using
                            
                            	authenticate a session
                            	**type**\:  :py:class:`Using <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate.Using>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate, self).__init__()

                                self.yang_name = "authenticate"
                                self.yang_parent_name = "action-number"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("using", ("using", Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate.Using))])
                                self._leafs = OrderedDict()

                                self.using = Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate.Using()
                                self.using.parent = self
                                self._children_name_map["using"] = "using"
                                self._segment_path = lambda: "authenticate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate, [], name, value)


                            class Using(Entity):
                                """
                                authenticate a session
                                
                                .. attribute:: method
                                
                                	
                                	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate.Using.Method>`
                                
                                .. attribute:: both
                                
                                	Enabling Dot1x Authenticator & Supplicant
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: retries
                                
                                	Number of times to retry failed authentications
                                	**type**\: int
                                
                                	**range:** 1..5
                                
                                .. attribute:: retry_time
                                
                                	Time interval between retries
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: priority
                                
                                	Method priority
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: parameter_map
                                
                                	Specify parameter map name
                                	**type**\: str
                                
                                	**length:** 1..256
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate.Using, self).__init__()

                                    self.yang_name = "using"
                                    self.yang_parent_name = "authenticate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('method', (YLeaf(YType.enumeration, 'method'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate.Using.Method')])),
                                        ('both', (YLeaf(YType.empty, 'both'), ['Empty'])),
                                        ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                                        ('retry_time', (YLeaf(YType.uint16, 'retry-time'), ['int'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                        ('parameter_map', (YLeaf(YType.str, 'parameter-map'), ['str'])),
                                    ])
                                    self.method = None
                                    self.both = None
                                    self.retries = None
                                    self.retry_time = None
                                    self.priority = None
                                    self.parameter_map = None
                                    self._segment_path = lambda: "using"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Authenticate.Using, ['method', 'both', 'retries', 'retry_time', 'priority', 'parameter_map'], name, value)

                                class Method(Enum):
                                    """
                                    Method (Enum Class)

                                    .. data:: dot1x = 0

                                    .. data:: mab = 1

                                    .. data:: webauth = 2

                                    """

                                    dot1x = Enum.YLeaf(0, "dot1x")

                                    mab = Enum.YLeaf(1, "mab")

                                    webauth = Enum.YLeaf(2, "webauth")



                        class Map(Entity):
                            """
                            map identity\-update attribute to a auto\-conf templates
                            
                            .. attribute:: attribute_to_service
                            
                            	identity\-update attribute to a auto\-conf templates
                            	**type**\:  :py:class:`AttributeToService <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Map.AttributeToService>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Map, self).__init__()

                                self.yang_name = "map"
                                self.yang_parent_name = "action-number"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("attribute-to-service", ("attribute_to_service", Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Map.AttributeToService))])
                                self._leafs = OrderedDict()

                                self.attribute_to_service = Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Map.AttributeToService()
                                self.attribute_to_service.parent = self
                                self._children_name_map["attribute_to_service"] = "attribute-to-service"
                                self._segment_path = lambda: "map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Map, [], name, value)


                            class AttributeToService(Entity):
                                """
                                identity\-update attribute to a auto\-conf templates
                                
                                .. attribute:: table
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Map.AttributeToService, self).__init__()

                                    self.yang_name = "attribute-to-service"
                                    self.yang_parent_name = "map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                    ])
                                    self.table = None
                                    self._segment_path = lambda: "attribute-to-service"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Event.ClassNumber.ActionNumber.Map.AttributeToService, ['table'], name, value)


            class Class(Entity):
                """
                policy criteria
                
                .. attribute:: name  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**length:** 1..512
                
                		**type**\:  :py:class:`ClassNameType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.ClassNameType>`
                
                .. attribute:: type
                
                	type of the class\-map
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.Type>`
                
                .. attribute:: insert_before
                
                	Insert the class before a specified class
                	**type**\: str
                
                .. attribute:: appnav_policy
                
                	
                	**type**\:  :py:class:`AppnavPolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.AppnavPolicy>`
                
                .. attribute:: avc
                
                	
                	**type**\:  :py:class:`Avc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.Avc>`
                
                .. attribute:: policy
                
                	
                	**type**\:  :py:class:`Policy_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.Policy_>`
                
                .. attribute:: service_policy
                
                	Deep Packet Inspection Engine
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ServicePolicy>`
                
                .. attribute:: pm_policy
                
                	
                	**type**\:  :py:class:`PmPolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy>`
                
                .. attribute:: inspect_police
                
                	
                	**type**\:  :py:class:`InspectPolice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.InspectPolice>`
                
                .. attribute:: random_detect
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: action_list
                
                	
                	**type**\: list of  		 :py:class:`ActionList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Policy.PolicyMap.Class, self).__init__()

                    self.yang_name = "class"
                    self.yang_parent_name = "policy-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("appnav-policy", ("appnav_policy", Native.Policy.PolicyMap.Class.AppnavPolicy)), ("avc", ("avc", Native.Policy.PolicyMap.Class.Avc)), ("policy", ("policy", Native.Policy.PolicyMap.Class.Policy_)), ("service-policy", ("service_policy", Native.Policy.PolicyMap.Class.ServicePolicy)), ("pm-policy", ("pm_policy", Native.Policy.PolicyMap.Class.PmPolicy)), ("inspect-police", ("inspect_police", Native.Policy.PolicyMap.Class.InspectPolice)), ("action-list", ("action_list", Native.Policy.PolicyMap.Class.ActionList))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'ClassNameType', '')])),
                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.Type')])),
                        ('insert_before', (YLeaf(YType.str, 'insert-before'), ['str'])),
                        ('random_detect', (YLeaf(YType.empty, 'random-detect'), ['Empty'])),
                    ])
                    self.name = None
                    self.type = None
                    self.insert_before = None
                    self.random_detect = None

                    self.appnav_policy = Native.Policy.PolicyMap.Class.AppnavPolicy()
                    self.appnav_policy.parent = self
                    self._children_name_map["appnav_policy"] = "appnav-policy"

                    self.avc = Native.Policy.PolicyMap.Class.Avc()
                    self.avc.parent = self
                    self._children_name_map["avc"] = "avc"

                    self.policy = Native.Policy.PolicyMap.Class.Policy_()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.service_policy = Native.Policy.PolicyMap.Class.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"

                    self.pm_policy = Native.Policy.PolicyMap.Class.PmPolicy()
                    self.pm_policy.parent = self
                    self._children_name_map["pm_policy"] = "pm-policy"

                    self.inspect_police = Native.Policy.PolicyMap.Class.InspectPolice()
                    self.inspect_police.parent = self
                    self._children_name_map["inspect_police"] = "inspect-police"

                    self.action_list = YList(self)
                    self._segment_path = lambda: "class" + "[name='" + str(self.name) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Policy.PolicyMap.Class, ['name', 'type', 'insert_before', 'random_detect'], name, value)

                class Type(Enum):
                    """
                    Type (Enum Class)

                    type of the class\-map

                    .. data:: inspect = 0

                    """

                    inspect = Enum.YLeaf(0, "inspect")



                class AppnavPolicy(Entity):
                    """
                    
                    
                    .. attribute:: distribute
                    
                    	Distribute action
                    	**type**\: list of  		 :py:class:`Distribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.AppnavPolicy.Distribute>`
                    
                    .. attribute:: monitor_load
                    
                    	Monitor AO
                    	**type**\:  :py:class:`MonitorLoad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.AppnavPolicy.MonitorLoad>`
                    
                    .. attribute:: pass_through
                    
                    	pass\-through action
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.PolicyMap.Class.AppnavPolicy, self).__init__()

                        self.yang_name = "appnav-policy"
                        self.yang_parent_name = "class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("distribute", ("distribute", Native.Policy.PolicyMap.Class.AppnavPolicy.Distribute))])
                        self._leafs = OrderedDict([
                            ('monitor_load', (YLeaf(YType.enumeration, 'monitor-load'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.AppnavPolicy.MonitorLoad')])),
                            ('pass_through', (YLeaf(YType.empty, 'pass-through'), ['Empty'])),
                        ])
                        self.monitor_load = None
                        self.pass_through = None

                        self.distribute = YList(self)
                        self._segment_path = lambda: "appnav-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.PolicyMap.Class.AppnavPolicy, ['monitor_load', 'pass_through'], name, value)

                    class MonitorLoad(Enum):
                        """
                        MonitorLoad (Enum Class)

                        Monitor AO

                        .. data:: MS_port_mapper = 0

                        .. data:: cifs = 1

                        .. data:: http = 2

                        .. data:: ica = 3

                        .. data:: mapi = 4

                        .. data:: nfs = 5

                        .. data:: ssl = 6

                        .. data:: video = 7

                        """

                        MS_port_mapper = Enum.YLeaf(0, "MS-port-mapper")

                        cifs = Enum.YLeaf(1, "cifs")

                        http = Enum.YLeaf(2, "http")

                        ica = Enum.YLeaf(3, "ica")

                        mapi = Enum.YLeaf(4, "mapi")

                        nfs = Enum.YLeaf(5, "nfs")

                        ssl = Enum.YLeaf(6, "ssl")

                        video = Enum.YLeaf(7, "video")



                    class Distribute(Entity):
                        """
                        Distribute action
                        
                        .. attribute:: service_node_group  (key)
                        
                        	Distribute to service\-node\-group
                        	**type**\: str
                        
                        .. attribute:: insert_before
                        
                        	Insert before specific node
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.AppnavPolicy.Distribute, self).__init__()

                            self.yang_name = "distribute"
                            self.yang_parent_name = "appnav-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['service_node_group']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('service_node_group', (YLeaf(YType.str, 'service-node-group'), ['str'])),
                                ('insert_before', (YLeaf(YType.str, 'insert-before'), ['str'])),
                            ])
                            self.service_node_group = None
                            self.insert_before = None
                            self._segment_path = lambda: "distribute" + "[service-node-group='" + str(self.service_node_group) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.AppnavPolicy.Distribute, ['service_node_group', 'insert_before'], name, value)


                class Avc(Entity):
                    """
                    
                    
                    .. attribute:: allow
                    
                    	Allow the packet
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: deny
                    
                    	Deny the packet
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.PolicyMap.Class.Avc, self).__init__()

                        self.yang_name = "avc"
                        self.yang_parent_name = "class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow', (YLeaf(YType.empty, 'allow'), ['Empty'])),
                            ('deny', (YLeaf(YType.empty, 'deny'), ['Empty'])),
                        ])
                        self.allow = None
                        self.deny = None
                        self._segment_path = lambda: "avc"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.PolicyMap.Class.Avc, ['allow', 'deny'], name, value)


                class Policy_(Entity):
                    """
                    
                    
                    .. attribute:: action
                    
                    	
                    	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.Policy_.Action>`
                    
                    .. attribute:: log
                    
                    	Send logging message for drop or pass
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: parameter_map
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..256
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.PolicyMap.Class.Policy_, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.Policy_.Action')])),
                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                            ('parameter_map', (YLeaf(YType.str, 'parameter-map'), ['str'])),
                        ])
                        self.action = None
                        self.log = None
                        self.parameter_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.PolicyMap.Class.Policy_, ['action', 'log', 'parameter_map'], name, value)

                    class Action(Enum):
                        """
                        Action (Enum Class)

                        .. data:: cxsc = 0

                        .. data:: drop = 1

                        .. data:: inspect = 2

                        .. data:: pass_ = 3

                        """

                        cxsc = Enum.YLeaf(0, "cxsc")

                        drop = Enum.YLeaf(1, "drop")

                        inspect = Enum.YLeaf(2, "inspect")

                        pass_ = Enum.YLeaf(3, "pass")



                class ServicePolicy(Entity):
                    """
                    Deep Packet Inspection Engine
                    
                    .. attribute:: type
                    
                    	
                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ServicePolicy.Type>`
                    
                    .. attribute:: policy_map
                    
                    	DPI policy\-map name
                    	**type**\: str
                    
                    	**length:** 1..512
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.PolicyMap.Class.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ServicePolicy.Type')])),
                            ('policy_map', (YLeaf(YType.str, 'policy-map'), ['str'])),
                        ])
                        self.type = None
                        self.policy_map = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.PolicyMap.Class.ServicePolicy, ['type', 'policy_map'], name, value)

                    class Type(Enum):
                        """
                        Type (Enum Class)

                        .. data:: avc = 0

                        .. data:: gtpv0 = 1

                        .. data:: gtpv1 = 2

                        .. data:: imap = 3

                        .. data:: pop3 = 4

                        .. data:: smtp = 5

                        .. data:: sunrpc = 6

                        """

                        avc = Enum.YLeaf(0, "avc")

                        gtpv0 = Enum.YLeaf(1, "gtpv0")

                        gtpv1 = Enum.YLeaf(2, "gtpv1")

                        imap = Enum.YLeaf(3, "imap")

                        pop3 = Enum.YLeaf(4, "pop3")

                        smtp = Enum.YLeaf(5, "smtp")

                        sunrpc = Enum.YLeaf(6, "sunrpc")



                class PmPolicy(Entity):
                    """
                    
                    
                    .. attribute:: flow
                    
                    	Flow subcommands
                    	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.Flow>`
                    
                    .. attribute:: monitor
                    
                    	Monitor related parameters
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.Monitor>`
                    
                    .. attribute:: react
                    
                    	Configure threshold crossing actions
                    	**type**\: list of  		 :py:class:`React <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.React>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.PolicyMap.Class.PmPolicy, self).__init__()

                        self.yang_name = "pm-policy"
                        self.yang_parent_name = "class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("flow", ("flow", Native.Policy.PolicyMap.Class.PmPolicy.Flow)), ("monitor", ("monitor", Native.Policy.PolicyMap.Class.PmPolicy.Monitor)), ("react", ("react", Native.Policy.PolicyMap.Class.PmPolicy.React))])
                        self._leafs = OrderedDict()

                        self.flow = Native.Policy.PolicyMap.Class.PmPolicy.Flow()
                        self.flow.parent = self
                        self._children_name_map["flow"] = "flow"

                        self.monitor = Native.Policy.PolicyMap.Class.PmPolicy.Monitor()
                        self.monitor.parent = self
                        self._children_name_map["monitor"] = "monitor"

                        self.react = YList(self)
                        self._segment_path = lambda: "pm-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy, [], name, value)


                    class Flow(Entity):
                        """
                        Flow subcommands
                        
                        .. attribute:: monitor
                        
                        	Apply a Flow Monitor
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.PmPolicy.Flow, self).__init__()

                            self.yang_name = "flow"
                            self.yang_parent_name = "pm-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('monitor', (YLeaf(YType.str, 'monitor'), ['str'])),
                            ])
                            self.monitor = None
                            self._segment_path = lambda: "flow"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.Flow, ['monitor'], name, value)


                    class Monitor(Entity):
                        """
                        Monitor related parameters
                        
                        .. attribute:: metric
                        
                        	Monitor metric
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.PmPolicy.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "pm-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric", ("metric", Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric))])
                            self._leafs = OrderedDict()

                            self.metric = Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"
                            self._segment_path = lambda: "monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.Monitor, [], name, value)


                        class Metric(Entity):
                            """
                            Monitor metric
                            
                            .. attribute:: rtp
                            
                            	RTP metrics parameters
                            	**type**\:  :py:class:`Rtp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric.Rtp>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rtp", ("rtp", Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric.Rtp))])
                                self._leafs = OrderedDict()

                                self.rtp = Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric.Rtp()
                                self.rtp.parent = self
                                self._children_name_map["rtp"] = "rtp"
                                self._segment_path = lambda: "metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric, [], name, value)


                            class Rtp(Entity):
                                """
                                RTP metrics parameters
                                
                                .. attribute:: clock_rate
                                
                                	RTP timestamp field's sampling frequency
                                	**type**\: list of  		 :py:class:`ClockRate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric.Rtp.ClockRate>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric.Rtp, self).__init__()

                                    self.yang_name = "rtp"
                                    self.yang_parent_name = "metric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("clock-rate", ("clock_rate", Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric.Rtp.ClockRate))])
                                    self._leafs = OrderedDict()

                                    self.clock_rate = YList(self)
                                    self._segment_path = lambda: "rtp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric.Rtp, [], name, value)


                                class ClockRate(Entity):
                                    """
                                    RTP timestamp field's sampling frequency
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..127
                                    
                                    		**type**\:  :py:class:`Number <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric.Rtp.ClockRate.Number>`
                                    
                                    .. attribute:: frequency
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1000..192000
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric.Rtp.ClockRate, self).__init__()

                                        self.yang_name = "clock-rate"
                                        self.yang_parent_name = "rtp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.PmPolicy.Monitor.Metric.Rtp.ClockRate.Number')])),
                                            ('frequency', (YLeaf(YType.uint32, 'frequency'), ['int'])),
                                        ])
                                        self.number = None
                                        self.frequency = None
                                        self._segment_path = lambda: "clock-rate" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.Monitor.Metric.Rtp.ClockRate, ['number', 'frequency'], name, value)

                                    class Number(Enum):
                                        """
                                        Number (Enum Class)

                                        .. data:: celb = 0

                                        .. data:: cn = 1

                                        .. data:: default = 2

                                        .. data:: dvi4 = 3

                                        .. data:: dvi4_2 = 4

                                        .. data:: dvi4_3 = 5

                                        .. data:: dvi4_4 = 6

                                        .. data:: g722 = 7

                                        .. data:: g723 = 8

                                        .. data:: g728 = 9

                                        .. data:: g729 = 10

                                        .. data:: gsm = 11

                                        .. data:: h261 = 12

                                        .. data:: h263 = 13

                                        .. data:: jpeg = 14

                                        .. data:: l16 = 15

                                        .. data:: l16_2 = 16

                                        .. data:: lpc = 17

                                        .. data:: mp2t = 18

                                        .. data:: mpa = 19

                                        .. data:: mpv = 20

                                        .. data:: nv = 21

                                        .. data:: pcma = 22

                                        .. data:: pcmu = 23

                                        .. data:: qcelp = 24

                                        """

                                        celb = Enum.YLeaf(0, "celb")

                                        cn = Enum.YLeaf(1, "cn")

                                        default = Enum.YLeaf(2, "default")

                                        dvi4 = Enum.YLeaf(3, "dvi4")

                                        dvi4_2 = Enum.YLeaf(4, "dvi4-2")

                                        dvi4_3 = Enum.YLeaf(5, "dvi4-3")

                                        dvi4_4 = Enum.YLeaf(6, "dvi4-4")

                                        g722 = Enum.YLeaf(7, "g722")

                                        g723 = Enum.YLeaf(8, "g723")

                                        g728 = Enum.YLeaf(9, "g728")

                                        g729 = Enum.YLeaf(10, "g729")

                                        gsm = Enum.YLeaf(11, "gsm")

                                        h261 = Enum.YLeaf(12, "h261")

                                        h263 = Enum.YLeaf(13, "h263")

                                        jpeg = Enum.YLeaf(14, "jpeg")

                                        l16 = Enum.YLeaf(15, "l16")

                                        l16_2 = Enum.YLeaf(16, "l16-2")

                                        lpc = Enum.YLeaf(17, "lpc")

                                        mp2t = Enum.YLeaf(18, "mp2t")

                                        mpa = Enum.YLeaf(19, "mpa")

                                        mpv = Enum.YLeaf(20, "mpv")

                                        nv = Enum.YLeaf(21, "nv")

                                        pcma = Enum.YLeaf(22, "pcma")

                                        pcmu = Enum.YLeaf(23, "pcmu")

                                        qcelp = Enum.YLeaf(24, "qcelp")



                    class React(Entity):
                        """
                        Configure threshold crossing actions
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: mode
                        
                        	
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.React.Mode>`
                        
                        .. attribute:: description
                        
                        	Description for the instance
                        	**type**\: str
                        
                        .. attribute:: action
                        
                        	Config react action
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.React.Action>`
                        
                        .. attribute:: alarm
                        
                        	Config react alarm
                        	**type**\:  :py:class:`Alarm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm>`
                        
                        .. attribute:: threshold
                        
                        	Config react threshold
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.PmPolicy.React, self).__init__()

                            self.yang_name = "react"
                            self.yang_parent_name = "pm-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("action", ("action", Native.Policy.PolicyMap.Class.PmPolicy.React.Action)), ("alarm", ("alarm", Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm)), ("threshold", ("threshold", Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.PmPolicy.React.Mode')])),
                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ])
                            self.id = None
                            self.mode = None
                            self.description = None

                            self.action = Native.Policy.PolicyMap.Class.PmPolicy.React.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"

                            self.alarm = Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm()
                            self.alarm.parent = self
                            self._children_name_map["alarm"] = "alarm"

                            self.threshold = Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"
                            self._segment_path = lambda: "react" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.React, ['id', 'mode', 'description'], name, value)

                        class Mode(Enum):
                            """
                            Mode (Enum Class)

                            .. data:: media_stop = 0

                            .. data:: mrv = 1

                            .. data:: rtp_jitter_average = 2

                            .. data:: transport_packets_lost_rate = 3

                            """

                            media_stop = Enum.YLeaf(0, "media-stop")

                            mrv = Enum.YLeaf(1, "mrv")

                            rtp_jitter_average = Enum.YLeaf(2, "rtp-jitter-average")

                            transport_packets_lost_rate = Enum.YLeaf(3, "transport-packets-lost-rate")



                        class Action(Entity):
                            """
                            Config react action
                            
                            .. attribute:: snmp
                            
                            	SNMP is notified of the event
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: syslog
                            
                            	The threshold\-crossing event is logged to syslog
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.PmPolicy.React.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "react"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('snmp', (YLeaf(YType.empty, 'snmp'), ['Empty'])),
                                    ('syslog', (YLeaf(YType.empty, 'syslog'), ['Empty'])),
                                ])
                                self.snmp = None
                                self.syslog = None
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.React.Action, ['snmp', 'syslog'], name, value)


                        class Alarm(Entity):
                            """
                            Config react alarm
                            
                            .. attribute:: severity
                            
                            	Alarm severity \- default level none
                            	**type**\:  :py:class:`Severity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm.Severity>`
                            
                            .. attribute:: type
                            
                            	Alarm raised type \- for each flow or a group
                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm.Type>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm, self).__init__()

                                self.yang_name = "alarm"
                                self.yang_parent_name = "react"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("type", ("type", Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm.Type))])
                                self._leafs = OrderedDict([
                                    ('severity', (YLeaf(YType.enumeration, 'severity'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.PmPolicy.React.Alarm.Severity')])),
                                ])
                                self.severity = None

                                self.type = Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm.Type()
                                self.type.parent = self
                                self._children_name_map["type"] = "type"
                                self._segment_path = lambda: "alarm"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm, ['severity'], name, value)

                            class Severity(Enum):
                                """
                                Severity (Enum Class)

                                Alarm severity \- default level none

                                .. data:: alert = 0

                                .. data:: critical = 1

                                .. data:: emergency = 2

                                .. data:: error = 3

                                .. data:: info = 4

                                """

                                alert = Enum.YLeaf(0, "alert")

                                critical = Enum.YLeaf(1, "critical")

                                emergency = Enum.YLeaf(2, "emergency")

                                error = Enum.YLeaf(3, "error")

                                info = Enum.YLeaf(4, "info")



                            class Type(Entity):
                                """
                                Alarm raised type \- for each flow or a group
                                
                                .. attribute:: discrete
                                
                                	Alert for each flow within the class
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: grouped
                                
                                	Alert if more than one flow cross the threshold
                                	**type**\:  :py:class:`Grouped <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm.Type.Grouped>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm.Type, self).__init__()

                                    self.yang_name = "type"
                                    self.yang_parent_name = "alarm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("grouped", ("grouped", Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm.Type.Grouped))])
                                    self._leafs = OrderedDict([
                                        ('discrete', (YLeaf(YType.empty, 'discrete'), ['Empty'])),
                                    ])
                                    self.discrete = None

                                    self.grouped = Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm.Type.Grouped()
                                    self.grouped.parent = self
                                    self._children_name_map["grouped"] = "grouped"
                                    self._segment_path = lambda: "type"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm.Type, ['discrete'], name, value)


                                class Grouped(Entity):
                                    """
                                    Alert if more than one flow cross the threshold
                                    
                                    .. attribute:: count
                                    
                                    	Number of flows in the group cross the threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: percent
                                    
                                    	Percent of flows in the group cross the threshold
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm.Type.Grouped, self).__init__()

                                        self.yang_name = "grouped"
                                        self.yang_parent_name = "type"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ])
                                        self.count = None
                                        self.percent = None
                                        self._segment_path = lambda: "grouped"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.React.Alarm.Type.Grouped, ['count', 'percent'], name, value)


                        class Threshold(Entity):
                            """
                            Config react threshold
                            
                            .. attribute:: value
                            
                            	Range of percentage loss that would trigger the alarm
                            	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold.Value>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "react"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("value", ("value", Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold.Value))])
                                self._leafs = OrderedDict()

                                self.value = Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold.Value()
                                self.value.parent = self
                                self._children_name_map["value"] = "value"
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold, [], name, value)


                            class Value(Entity):
                                """
                                Range of percentage loss that would trigger the alarm
                                
                                .. attribute:: ge
                                
                                	greater and equal to
                                	**type**\: str
                                
                                .. attribute:: gt
                                
                                	greater than
                                	**type**\: str
                                
                                .. attribute:: le
                                
                                	less and equal to
                                	**type**\: str
                                
                                .. attribute:: lt
                                
                                	less than
                                	**type**\: str
                                
                                .. attribute:: range
                                
                                	threshold within the range of
                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold.Value.Range>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold.Value, self).__init__()

                                    self.yang_name = "value"
                                    self.yang_parent_name = "threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold.Value.Range))])
                                    self._leafs = OrderedDict([
                                        ('ge', (YLeaf(YType.str, 'ge'), ['str'])),
                                        ('gt', (YLeaf(YType.str, 'gt'), ['str'])),
                                        ('le', (YLeaf(YType.str, 'le'), ['str'])),
                                        ('lt', (YLeaf(YType.str, 'lt'), ['str'])),
                                    ])
                                    self.ge = None
                                    self.gt = None
                                    self.le = None
                                    self.lt = None

                                    self.range = Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold.Value.Range()
                                    self.range.parent = self
                                    self._children_name_map["range"] = "range"
                                    self._segment_path = lambda: "value"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold.Value, ['ge', 'gt', 'le', 'lt'], name, value)


                                class Range(Entity):
                                    """
                                    threshold within the range of
                                    
                                    .. attribute:: low
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: high
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold.Value.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('low', (YLeaf(YType.str, 'low'), ['str'])),
                                            ('high', (YLeaf(YType.str, 'high'), ['str'])),
                                        ])
                                        self.low = None
                                        self.high = None
                                        self._segment_path = lambda: "range"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.PmPolicy.React.Threshold.Value.Range, ['low', 'high'], name, value)


                class InspectPolice(Entity):
                    """
                    
                    
                    .. attribute:: police
                    
                    	Police
                    	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.InspectPolice.Police>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.PolicyMap.Class.InspectPolice, self).__init__()

                        self.yang_name = "inspect-police"
                        self.yang_parent_name = "class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("police", ("police", Native.Policy.PolicyMap.Class.InspectPolice.Police))])
                        self._leafs = OrderedDict()

                        self.police = Native.Policy.PolicyMap.Class.InspectPolice.Police()
                        self.police.parent = self
                        self._children_name_map["police"] = "police"
                        self._segment_path = lambda: "inspect-police"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.PolicyMap.Class.InspectPolice, [], name, value)


                    class Police(Entity):
                        """
                        Police
                        
                        .. attribute:: rate
                        
                        	Specify police rate
                        	**type**\: int
                        
                        	**range:** 8000..2000000000
                        
                        .. attribute:: burst
                        
                        	Specify 'burst' parameter
                        	**type**\: int
                        
                        	**range:** 1000..512000000
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.InspectPolice.Police, self).__init__()

                            self.yang_name = "police"
                            self.yang_parent_name = "inspect-police"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ('burst', (YLeaf(YType.uint32, 'burst'), ['int'])),
                            ])
                            self.rate = None
                            self.burst = None
                            self._segment_path = lambda: "police"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.InspectPolice.Police, ['rate', 'burst'], name, value)


                class ActionList(Entity):
                    """
                    
                    
                    .. attribute:: action_type  (key)
                    
                    	
                    	**type**\:  :py:class:`PolicyActionType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.PolicyActionType>`
                    
                    .. attribute:: bandwidth
                    
                    	
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Bandwidth>`
                    
                    .. attribute:: compression
                    
                    	
                    	**type**\:  :py:class:`Compression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Compression>`
                    
                    .. attribute:: estimate
                    
                    	
                    	**type**\:  :py:class:`Estimate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Estimate>`
                    
                    .. attribute:: forward
                    
                    	
                    	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Forward>`
                    
                    .. attribute:: fair_queue
                    
                    	
                    	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.FairQueue>`
                    
                    .. attribute:: netflow_sampler
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: police_aggregate
                    
                    	
                    	**type**\:  :py:class:`PoliceAggregate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceAggregate>`
                    
                    .. attribute:: police_policy_map
                    
                    	
                    	**type**\:  :py:class:`PolicePolicyMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap>`
                    
                    .. attribute:: police_cir_percent
                    
                    	
                    	**type**\:  :py:class:`PoliceCirPercent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent>`
                    
                    .. attribute:: police_rate_unit
                    
                    	
                    	**type**\:  :py:class:`PoliceRateUnit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit>`
                    
                    .. attribute:: police_rate_percent
                    
                    	
                    	**type**\:  :py:class:`PoliceRatePercent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent>`
                    
                    .. attribute:: police_rate_pdp
                    
                    	
                    	**type**\:  :py:class:`PoliceRatePdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp>`
                    
                    .. attribute:: police_target_bitrate
                    
                    	
                    	**type**\:  :py:class:`PoliceTargetBitrate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate>`
                    
                    .. attribute:: police_flow
                    
                    	
                    	**type**\:  :py:class:`PoliceFlow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow>`
                    
                    .. attribute:: police_catalyst
                    
                    	
                    	**type**\:  :py:class:`PoliceCatalyst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst>`
                    
                    .. attribute:: police_switch
                    
                    	
                    	**type**\:  :py:class:`PoliceSwitch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceSwitch>`
                    
                    .. attribute:: priority
                    
                    	
                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Priority>`
                    
                    .. attribute:: queue_buffers
                    
                    	
                    	**type**\:  :py:class:`QueueBuffers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.QueueBuffers>`
                    
                    .. attribute:: queue_limit
                    
                    	
                    	**type**\:  :py:class:`QueueLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.QueueLimit>`
                    
                    .. attribute:: queue_limit_dscp
                    
                    	
                    	**type**\:  :py:class:`QueueLimitDscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.QueueLimitDscp>`
                    
                    .. attribute:: random_detect
                    
                    	
                    	**type**\:  :py:class:`RandomDetect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.RandomDetect>`
                    
                    .. attribute:: service_policy
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..512
                    
                    	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap>`
                    
                    .. attribute:: set
                    
                    	
                    	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set>`
                    
                    .. attribute:: shape
                    
                    	
                    	**type**\:  :py:class:`Shape <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Shape>`
                    
                    .. attribute:: trust
                    
                    	
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Trust>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Policy.PolicyMap.Class.ActionList, self).__init__()

                        self.yang_name = "action-list"
                        self.yang_parent_name = "class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['action_type']
                        self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Policy.PolicyMap.Class.ActionList.Bandwidth)), ("compression", ("compression", Native.Policy.PolicyMap.Class.ActionList.Compression)), ("estimate", ("estimate", Native.Policy.PolicyMap.Class.ActionList.Estimate)), ("forward", ("forward", Native.Policy.PolicyMap.Class.ActionList.Forward)), ("fair-queue", ("fair_queue", Native.Policy.PolicyMap.Class.ActionList.FairQueue)), ("police-aggregate", ("police_aggregate", Native.Policy.PolicyMap.Class.ActionList.PoliceAggregate)), ("police-policy-map", ("police_policy_map", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap)), ("police-cir-percent", ("police_cir_percent", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent)), ("police-rate-unit", ("police_rate_unit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit)), ("police-rate-percent", ("police_rate_percent", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent)), ("police-rate-pdp", ("police_rate_pdp", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp)), ("police-target-bitrate", ("police_target_bitrate", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate)), ("police-flow", ("police_flow", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow)), ("police-catalyst", ("police_catalyst", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst)), ("police-switch", ("police_switch", Native.Policy.PolicyMap.Class.ActionList.PoliceSwitch)), ("priority", ("priority", Native.Policy.PolicyMap.Class.ActionList.Priority)), ("queue-buffers", ("queue_buffers", Native.Policy.PolicyMap.Class.ActionList.QueueBuffers)), ("queue-limit", ("queue_limit", Native.Policy.PolicyMap.Class.ActionList.QueueLimit)), ("queue-limit-dscp", ("queue_limit_dscp", Native.Policy.PolicyMap.Class.ActionList.QueueLimitDscp)), ("random-detect", ("random_detect", Native.Policy.PolicyMap.Class.ActionList.RandomDetect)), ("set", ("set", Native.Policy.PolicyMap.Class.ActionList.Set)), ("shape", ("shape", Native.Policy.PolicyMap.Class.ActionList.Shape))])
                        self._leafs = OrderedDict([
                            ('action_type', (YLeaf(YType.enumeration, 'action-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'PolicyActionType', '')])),
                            ('netflow_sampler', (YLeaf(YType.str, 'netflow-sampler'), ['str'])),
                            ('service_policy', (YLeaf(YType.str, 'service-policy'), ['str'])),
                            ('trust', (YLeaf(YType.enumeration, 'trust'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.Trust')])),
                        ])
                        self.action_type = None
                        self.netflow_sampler = None
                        self.service_policy = None
                        self.trust = None

                        self.bandwidth = Native.Policy.PolicyMap.Class.ActionList.Bandwidth()
                        self.bandwidth.parent = self
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.compression = Native.Policy.PolicyMap.Class.ActionList.Compression()
                        self.compression.parent = self
                        self._children_name_map["compression"] = "compression"

                        self.estimate = Native.Policy.PolicyMap.Class.ActionList.Estimate()
                        self.estimate.parent = self
                        self._children_name_map["estimate"] = "estimate"

                        self.forward = Native.Policy.PolicyMap.Class.ActionList.Forward()
                        self.forward.parent = self
                        self._children_name_map["forward"] = "forward"

                        self.fair_queue = Native.Policy.PolicyMap.Class.ActionList.FairQueue()
                        self.fair_queue.parent = self
                        self._children_name_map["fair_queue"] = "fair-queue"

                        self.police_aggregate = Native.Policy.PolicyMap.Class.ActionList.PoliceAggregate()
                        self.police_aggregate.parent = self
                        self._children_name_map["police_aggregate"] = "police-aggregate"

                        self.police_policy_map = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap()
                        self.police_policy_map.parent = self
                        self._children_name_map["police_policy_map"] = "police-policy-map"

                        self.police_cir_percent = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent()
                        self.police_cir_percent.parent = self
                        self._children_name_map["police_cir_percent"] = "police-cir-percent"

                        self.police_rate_unit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit()
                        self.police_rate_unit.parent = self
                        self._children_name_map["police_rate_unit"] = "police-rate-unit"

                        self.police_rate_percent = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent()
                        self.police_rate_percent.parent = self
                        self._children_name_map["police_rate_percent"] = "police-rate-percent"

                        self.police_rate_pdp = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp()
                        self.police_rate_pdp.parent = self
                        self._children_name_map["police_rate_pdp"] = "police-rate-pdp"

                        self.police_target_bitrate = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate()
                        self.police_target_bitrate.parent = self
                        self._children_name_map["police_target_bitrate"] = "police-target-bitrate"

                        self.police_flow = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow()
                        self.police_flow.parent = self
                        self._children_name_map["police_flow"] = "police-flow"

                        self.police_catalyst = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst()
                        self.police_catalyst.parent = self
                        self._children_name_map["police_catalyst"] = "police-catalyst"

                        self.police_switch = Native.Policy.PolicyMap.Class.ActionList.PoliceSwitch()
                        self.police_switch.parent = self
                        self._children_name_map["police_switch"] = "police-switch"

                        self.priority = Native.Policy.PolicyMap.Class.ActionList.Priority()
                        self.priority.parent = self
                        self._children_name_map["priority"] = "priority"

                        self.queue_buffers = Native.Policy.PolicyMap.Class.ActionList.QueueBuffers()
                        self.queue_buffers.parent = self
                        self._children_name_map["queue_buffers"] = "queue-buffers"

                        self.queue_limit = Native.Policy.PolicyMap.Class.ActionList.QueueLimit()
                        self.queue_limit.parent = self
                        self._children_name_map["queue_limit"] = "queue-limit"

                        self.queue_limit_dscp = Native.Policy.PolicyMap.Class.ActionList.QueueLimitDscp()
                        self.queue_limit_dscp.parent = self
                        self._children_name_map["queue_limit_dscp"] = "queue-limit-dscp"

                        self.random_detect = Native.Policy.PolicyMap.Class.ActionList.RandomDetect()
                        self.random_detect.parent = self
                        self._children_name_map["random_detect"] = "random-detect"

                        self.set = Native.Policy.PolicyMap.Class.ActionList.Set()
                        self.set.parent = self
                        self._children_name_map["set"] = "set"

                        self.shape = Native.Policy.PolicyMap.Class.ActionList.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"
                        self._segment_path = lambda: "action-list" + "[action-type='" + str(self.action_type) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList, ['action_type', 'netflow_sampler', 'service_policy', 'trust'], name, value)

                    class Trust(Enum):
                        """
                        Trust (Enum Class)

                        .. data:: cos = 0

                        .. data:: dscp = 1

                        .. data:: ip_precedence = 2

                        """

                        cos = Enum.YLeaf(0, "cos")

                        dscp = Enum.YLeaf(1, "dscp")

                        ip_precedence = Enum.YLeaf(2, "ip-precedence")



                    class Bandwidth(Entity):
                        """
                        
                        
                        .. attribute:: bits
                        
                        	
                        	**type**\: int
                        
                        	**range:** 8..2000000
                        
                        .. attribute:: percent
                        
                        	% of total Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        .. attribute:: remaining
                        
                        	% of the remaining bandwidth
                        	**type**\:  :py:class:`Remaining <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("remaining", ("remaining", Native.Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining))])
                            self._leafs = OrderedDict([
                                ('bits', (YLeaf(YType.uint32, 'bits'), ['int'])),
                                ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                            ])
                            self.bits = None
                            self.percent = None

                            self.remaining = Native.Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining()
                            self.remaining.parent = self
                            self._children_name_map["remaining"] = "remaining"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Bandwidth, ['bits', 'percent'], name, value)


                        class Remaining(Entity):
                            """
                            % of the remaining bandwidth
                            
                            .. attribute:: rem_option
                            
                            	
                            	**type**\:  :py:class:`RemOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining.RemOption>`
                            
                            .. attribute:: percent
                            
                            	% of the remaining bandwidth
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: ratio
                            
                            	ratio for sharing excess bandwidth
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: account
                            
                            	Overhead Accounting
                            	**type**\:  :py:class:`Account <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining.Account>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining, self).__init__()

                                self.yang_name = "remaining"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("account", ("account", Native.Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining.Account))])
                                self._leafs = OrderedDict([
                                    ('rem_option', (YLeaf(YType.enumeration, 'rem-option'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining.RemOption')])),
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('ratio', (YLeaf(YType.uint16, 'ratio'), ['int'])),
                                ])
                                self.rem_option = None
                                self.percent = None
                                self.ratio = None

                                self.account = Native.Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining.Account()
                                self.account.parent = self
                                self._children_name_map["account"] = "account"
                                self._segment_path = lambda: "remaining"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining, ['rem_option', 'percent', 'ratio'], name, value)

                            class RemOption(Enum):
                                """
                                RemOption (Enum Class)

                                .. data:: percent = 0

                                .. data:: ratio = 1

                                """

                                percent = Enum.YLeaf(0, "percent")

                                ratio = Enum.YLeaf(1, "ratio")



                            class Account(Entity):
                                """
                                Overhead Accounting
                                
                                .. attribute:: user_defined
                                
                                	Offset Size
                                	**type**\: int
                                
                                	**range:** \-1000000..1000000
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining.Account, self).__init__()

                                    self.yang_name = "account"
                                    self.yang_parent_name = "remaining"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('user_defined', (YLeaf(YType.int32, 'user-defined'), ['int'])),
                                    ])
                                    self.user_defined = None
                                    self._segment_path = lambda: "account"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Bandwidth.Remaining.Account, ['user_defined'], name, value)


                    class Compression(Entity):
                        """
                        
                        
                        .. attribute:: header
                        
                        	configure header compression
                        	**type**\:  :py:class:`Header <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Compression.Header>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.Compression, self).__init__()

                            self.yang_name = "compression"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("header", ("header", Native.Policy.PolicyMap.Class.ActionList.Compression.Header))])
                            self._leafs = OrderedDict()

                            self.header = None
                            self._children_name_map["header"] = "header"
                            self._segment_path = lambda: "compression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Compression, [], name, value)


                        class Header(Entity):
                            """
                            configure header compression
                            
                            .. attribute:: ip
                            
                            	configure ip header compression
                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Compression.Header.Ip>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.Compression.Header, self).__init__()

                                self.yang_name = "header"
                                self.yang_parent_name = "compression"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.enumeration, 'ip'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.Compression.Header.Ip')])),
                                ])
                                self.ip = None
                                self._segment_path = lambda: "header"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Compression.Header, ['ip'], name, value)

                            class Ip(Enum):
                                """
                                Ip (Enum Class)

                                configure ip header compression

                                .. data:: rtp = 0

                                .. data:: tcp = 1

                                """

                                rtp = Enum.YLeaf(0, "rtp")

                                tcp = Enum.YLeaf(1, "tcp")



                    class Estimate(Entity):
                        """
                        
                        
                        .. attribute:: bandwidth
                        
                        	bandwidth required to service this class
                        	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Estimate.Bandwidth>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.Estimate, self).__init__()

                            self.yang_name = "estimate"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Policy.PolicyMap.Class.ActionList.Estimate.Bandwidth))])
                            self._leafs = OrderedDict()

                            self.bandwidth = None
                            self._children_name_map["bandwidth"] = "bandwidth"
                            self._segment_path = lambda: "estimate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Estimate, [], name, value)


                        class Bandwidth(Entity):
                            """
                            bandwidth required to service this class
                            
                            .. attribute:: delay_one_in
                            
                            	specify QoS target delay
                            	**type**\:  :py:class:`DelayOneIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Estimate.Bandwidth.DelayOneIn>`
                            
                            .. attribute:: drop_one_in
                            
                            	specify QoS target loss rate
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.Estimate.Bandwidth, self).__init__()

                                self.yang_name = "bandwidth"
                                self.yang_parent_name = "estimate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("delay-one-in", ("delay_one_in", Native.Policy.PolicyMap.Class.ActionList.Estimate.Bandwidth.DelayOneIn))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('drop_one_in', (YLeaf(YType.uint32, 'drop-one-in'), ['int'])),
                                ])
                                self.drop_one_in = None

                                self.delay_one_in = Native.Policy.PolicyMap.Class.ActionList.Estimate.Bandwidth.DelayOneIn()
                                self.delay_one_in.parent = self
                                self._children_name_map["delay_one_in"] = "delay-one-in"
                                self._segment_path = lambda: "bandwidth"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Estimate.Bandwidth, ['drop_one_in'], name, value)


                            class DelayOneIn(Entity):
                                """
                                specify QoS target delay
                                
                                .. attribute:: doi
                                
                                	
                                	**type**\: int
                                
                                	**range:** 50..1000000
                                
                                .. attribute:: milliseconds
                                
                                	
                                	**type**\: int
                                
                                	**range:** 8..1000
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.Estimate.Bandwidth.DelayOneIn, self).__init__()

                                    self.yang_name = "delay-one-in"
                                    self.yang_parent_name = "bandwidth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('doi', (YLeaf(YType.uint32, 'doi'), ['int'])),
                                        ('milliseconds', (YLeaf(YType.uint32, 'milliseconds'), ['int'])),
                                    ])
                                    self.doi = None
                                    self.milliseconds = None
                                    self._segment_path = lambda: "delay-one-in"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Estimate.Bandwidth.DelayOneIn, ['doi', 'milliseconds'], name, value)


                    class Forward(Entity):
                        """
                        
                        
                        .. attribute:: service_path
                        
                        	Service Path Entries
                        	**type**\: int
                        
                        	**range:** 0..16777215
                        
                        .. attribute:: service_index
                        
                        	Service Index
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.Forward, self).__init__()

                            self.yang_name = "forward"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('service_path', (YLeaf(YType.uint32, 'service-path'), ['int'])),
                                ('service_index', (YLeaf(YType.uint8, 'service-index'), ['int'])),
                            ])
                            self.service_path = None
                            self.service_index = None
                            self._segment_path = lambda: "forward"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Forward, ['service_path', 'service_index'], name, value)


                    class FairQueue(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_queues
                        
                        	
                        	**type**\: int
                        
                        	**range:** 16..None \| 32..None \| 64..None \| 128..None \| 256..None \| 512..None \| 1024..None \| 2048..None \| 4096..None
                        
                        .. attribute:: queue_limit
                        
                        	per flow queue limit
                        	**type**\: int
                        
                        	**range:** 1..32768
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.FairQueue, self).__init__()

                            self.yang_name = "fair-queue"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dynamic_queues', (YLeaf(YType.uint32, 'dynamic-queues'), ['int'])),
                                ('queue_limit', (YLeaf(YType.uint16, 'queue-limit'), ['int'])),
                            ])
                            self.dynamic_queues = None
                            self.queue_limit = None
                            self._segment_path = lambda: "fair-queue"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.FairQueue, ['dynamic_queues', 'queue_limit'], name, value)


                    class PoliceAggregate(Entity):
                        """
                        
                        
                        .. attribute:: police
                        
                        	
                        	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceAggregate.Police>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceAggregate, self).__init__()

                            self.yang_name = "police-aggregate"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("police", ("police", Native.Policy.PolicyMap.Class.ActionList.PoliceAggregate.Police))])
                            self._leafs = OrderedDict()

                            self.police = Native.Policy.PolicyMap.Class.ActionList.PoliceAggregate.Police()
                            self.police.parent = self
                            self._children_name_map["police"] = "police"
                            self._segment_path = lambda: "police-aggregate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceAggregate, [], name, value)


                        class Police(Entity):
                            """
                            
                            
                            .. attribute:: aggregate
                            
                            	Choose aggregate policer for current class
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceAggregate.Police, self).__init__()

                                self.yang_name = "police"
                                self.yang_parent_name = "police-aggregate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('aggregate', (YLeaf(YType.str, 'aggregate'), ['str'])),
                                ])
                                self.aggregate = None
                                self._segment_path = lambda: "police"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceAggregate.Police, ['aggregate'], name, value)


                    class PolicePolicyMap(Entity):
                        """
                        
                        
                        .. attribute:: police
                        
                        	
                        	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap, self).__init__()

                            self.yang_name = "police-policy-map"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("police", ("police", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police))])
                            self._leafs = OrderedDict()

                            self.police = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police()
                            self.police.parent = self
                            self._children_name_map["police"] = "police"
                            self._segment_path = lambda: "police-policy-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap, [], name, value)


                        class Police(Entity):
                            """
                            
                            
                            .. attribute:: cir
                            
                            	Committed information rate
                            	**type**\: int
                            
                            	**range:** 8000..64000000000
                            
                            .. attribute:: bc
                            
                            	Conform burst
                            	**type**\: int
                            
                            	**range:** 1000..512000000
                            
                            .. attribute:: be
                            
                            	Excess burst
                            	**type**\: int
                            
                            	**range:** 1000..512000000
                            
                            .. attribute:: pir
                            
                            	Peak Information Rate
                            	**type**\: int
                            
                            	**range:** 8000..64000000000
                            
                            .. attribute:: pir_be
                            
                            	
                            	**type**\:  :py:class:`PirBe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.PirBe>`
                            
                            .. attribute:: actions
                            
                            	
                            	**type**\:  :py:class:`Actions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police, self).__init__()

                                self.yang_name = "police"
                                self.yang_parent_name = "police-policy-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pir-be", ("pir_be", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.PirBe)), ("actions", ("actions", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions))])
                                self._leafs = OrderedDict([
                                    ('cir', (YLeaf(YType.uint64, 'cir'), ['int'])),
                                    ('bc', (YLeaf(YType.uint32, 'bc'), ['int'])),
                                    ('be', (YLeaf(YType.uint32, 'be'), ['int'])),
                                    ('pir', (YLeaf(YType.uint64, 'pir'), ['int'])),
                                ])
                                self.cir = None
                                self.bc = None
                                self.be = None
                                self.pir = None

                                self.pir_be = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.PirBe()
                                self.pir_be.parent = self
                                self._children_name_map["pir_be"] = "pir-be"

                                self.actions = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions()
                                self.actions.parent = self
                                self._children_name_map["actions"] = "actions"
                                self._segment_path = lambda: "police"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police, ['cir', 'bc', 'be', 'pir'], name, value)


                            class PirBe(Entity):
                                """
                                
                                
                                .. attribute:: be
                                
                                	Excess burst
                                	**type**\: int
                                
                                	**range:** 1000..512000000
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.PirBe, self).__init__()

                                    self.yang_name = "pir-be"
                                    self.yang_parent_name = "police"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('be', (YLeaf(YType.uint32, 'be'), ['int'])),
                                    ])
                                    self.be = None
                                    self._segment_path = lambda: "pir-be"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.PirBe, ['be'], name, value)


                            class Actions(Entity):
                                """
                                
                                
                                .. attribute:: conform_set_clp_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetClpTransmit>`
                                
                                .. attribute:: conform_set_cos_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmit>`
                                
                                .. attribute:: conform_set_cos_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetCosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmitTable>`
                                
                                .. attribute:: conform_set_discard_class_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDiscardClassTransmit>`
                                
                                .. attribute:: conform_set_dscp_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmit>`
                                
                                .. attribute:: conform_set_dscp_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmitTable>`
                                
                                .. attribute:: conform_set_frde_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetFrdeTransmit>`
                                
                                .. attribute:: conform_set_mpls_exp_imposition_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmit>`
                                
                                .. attribute:: conform_set_mpls_exp_imposition_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmitTable>`
                                
                                .. attribute:: conform_set_mpls_exp_topmost_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmit>`
                                
                                .. attribute:: conform_set_mpls_exp_topmost_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmitTable>`
                                
                                .. attribute:: conform_set_prec_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmit>`
                                
                                .. attribute:: conform_set_prec_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetPrecTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmitTable>`
                                
                                .. attribute:: conform_set_qos_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmit>`
                                
                                .. attribute:: conform_set_qos_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetQosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmitTable>`
                                
                                .. attribute:: conform_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformTransmit>`
                                
                                .. attribute:: conform_drop
                                
                                	
                                	**type**\:  :py:class:`ConformDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformDrop>`
                                
                                .. attribute:: exceed_dscp
                                
                                	
                                	**type**\:  :py:class:`ExceedDscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDscp>`
                                
                                .. attribute:: exceed_set_clp_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetClpTransmit>`
                                
                                .. attribute:: exceed_set_cos_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetCosTransmit>`
                                
                                .. attribute:: exceed_set_discard_class_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDiscardClassTransmit>`
                                
                                .. attribute:: exceed_set_dscp_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit>`
                                
                                .. attribute:: exceed_set_dscp_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ExceedSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmitTable>`
                                
                                .. attribute:: exceed_set_frde_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetFrdeTransmit>`
                                
                                .. attribute:: exceed_set_mpls_exp_imposition_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpImpositionTransmit>`
                                
                                .. attribute:: exceed_set_mpls_exp_topmost_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpTopmostTransmit>`
                                
                                .. attribute:: exceed_set_prec_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetPrecTransmit>`
                                
                                .. attribute:: exceed_set_qos_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetQosTransmit>`
                                
                                .. attribute:: exceed_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedTransmit>`
                                
                                .. attribute:: exceed_drop
                                
                                	
                                	**type**\:  :py:class:`ExceedDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDrop>`
                                
                                .. attribute:: violate_set_clp_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetClpTransmit>`
                                
                                .. attribute:: violate_set_cos_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetCosTransmit>`
                                
                                .. attribute:: violate_set_discard_class_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDiscardClassTransmit>`
                                
                                .. attribute:: violate_set_dscp_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDscpTransmit>`
                                
                                .. attribute:: violate_set_frde_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetFrdeTransmit>`
                                
                                .. attribute:: violate_set_mpls_exp_imposition_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpImpositionTransmit>`
                                
                                .. attribute:: violate_set_mpls_exp_topmost_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpTopmostTransmit>`
                                
                                .. attribute:: violate_set_prec_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetPrecTransmit>`
                                
                                .. attribute:: violate_set_qos_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetQosTransmit>`
                                
                                .. attribute:: violate_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateTransmit>`
                                
                                .. attribute:: violate_drop
                                
                                	
                                	**type**\:  :py:class:`ViolateDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateDrop>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions, self).__init__()

                                    self.yang_name = "actions"
                                    self.yang_parent_name = "police"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("conform-set-clp-transmit", ("conform_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetClpTransmit)), ("conform-set-cos-transmit", ("conform_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmit)), ("conform-set-cos-transmit-table", ("conform_set_cos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmitTable)), ("conform-set-discard-class-transmit", ("conform_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDiscardClassTransmit)), ("conform-set-dscp-transmit", ("conform_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmit)), ("conform-set-dscp-transmit-table", ("conform_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmitTable)), ("conform-set-frde-transmit", ("conform_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetFrdeTransmit)), ("conform-set-mpls-exp-imposition-transmit", ("conform_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmit)), ("conform-set-mpls-exp-imposition-transmit-table", ("conform_set_mpls_exp_imposition_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmitTable)), ("conform-set-mpls-exp-topmost-transmit", ("conform_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmit)), ("conform-set-mpls-exp-topmost-transmit-table", ("conform_set_mpls_exp_topmost_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmitTable)), ("conform-set-prec-transmit", ("conform_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmit)), ("conform-set-prec-transmit-table", ("conform_set_prec_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmitTable)), ("conform-set-qos-transmit", ("conform_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmit)), ("conform-set-qos-transmit-table", ("conform_set_qos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmitTable)), ("conform-transmit", ("conform_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformTransmit)), ("conform-drop", ("conform_drop", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformDrop)), ("exceed-dscp", ("exceed_dscp", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDscp)), ("exceed-set-clp-transmit", ("exceed_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetClpTransmit)), ("exceed-set-cos-transmit", ("exceed_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetCosTransmit)), ("exceed-set-discard-class-transmit", ("exceed_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDiscardClassTransmit)), ("exceed-set-dscp-transmit", ("exceed_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit)), ("exceed-set-dscp-transmit-table", ("exceed_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmitTable)), ("exceed-set-frde-transmit", ("exceed_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetFrdeTransmit)), ("exceed-set-mpls-exp-imposition-transmit", ("exceed_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpImpositionTransmit)), ("exceed-set-mpls-exp-topmost-transmit", ("exceed_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpTopmostTransmit)), ("exceed-set-prec-transmit", ("exceed_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetPrecTransmit)), ("exceed-set-qos-transmit", ("exceed_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetQosTransmit)), ("exceed-transmit", ("exceed_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedTransmit)), ("exceed-drop", ("exceed_drop", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDrop)), ("violate-set-clp-transmit", ("violate_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetClpTransmit)), ("violate-set-cos-transmit", ("violate_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetCosTransmit)), ("violate-set-discard-class-transmit", ("violate_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDiscardClassTransmit)), ("violate-set-dscp-transmit", ("violate_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDscpTransmit)), ("violate-set-frde-transmit", ("violate_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetFrdeTransmit)), ("violate-set-mpls-exp-imposition-transmit", ("violate_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpImpositionTransmit)), ("violate-set-mpls-exp-topmost-transmit", ("violate_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpTopmostTransmit)), ("violate-set-prec-transmit", ("violate_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetPrecTransmit)), ("violate-set-qos-transmit", ("violate_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetQosTransmit)), ("violate-transmit", ("violate_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateTransmit)), ("violate-drop", ("violate_drop", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateDrop))])
                                    self._leafs = OrderedDict()

                                    self.conform_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetClpTransmit()
                                    self.conform_set_clp_transmit.parent = self
                                    self._children_name_map["conform_set_clp_transmit"] = "conform-set-clp-transmit"

                                    self.conform_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmit()
                                    self.conform_set_cos_transmit.parent = self
                                    self._children_name_map["conform_set_cos_transmit"] = "conform-set-cos-transmit"

                                    self.conform_set_cos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmitTable()
                                    self.conform_set_cos_transmit_table.parent = self
                                    self._children_name_map["conform_set_cos_transmit_table"] = "conform-set-cos-transmit-table"

                                    self.conform_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDiscardClassTransmit()
                                    self.conform_set_discard_class_transmit.parent = self
                                    self._children_name_map["conform_set_discard_class_transmit"] = "conform-set-discard-class-transmit"

                                    self.conform_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmit()
                                    self.conform_set_dscp_transmit.parent = self
                                    self._children_name_map["conform_set_dscp_transmit"] = "conform-set-dscp-transmit"

                                    self.conform_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmitTable()
                                    self.conform_set_dscp_transmit_table.parent = self
                                    self._children_name_map["conform_set_dscp_transmit_table"] = "conform-set-dscp-transmit-table"

                                    self.conform_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetFrdeTransmit()
                                    self.conform_set_frde_transmit.parent = self
                                    self._children_name_map["conform_set_frde_transmit"] = "conform-set-frde-transmit"

                                    self.conform_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmit()
                                    self.conform_set_mpls_exp_imposition_transmit.parent = self
                                    self._children_name_map["conform_set_mpls_exp_imposition_transmit"] = "conform-set-mpls-exp-imposition-transmit"

                                    self.conform_set_mpls_exp_imposition_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmitTable()
                                    self.conform_set_mpls_exp_imposition_transmit_table.parent = self
                                    self._children_name_map["conform_set_mpls_exp_imposition_transmit_table"] = "conform-set-mpls-exp-imposition-transmit-table"

                                    self.conform_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmit()
                                    self.conform_set_mpls_exp_topmost_transmit.parent = self
                                    self._children_name_map["conform_set_mpls_exp_topmost_transmit"] = "conform-set-mpls-exp-topmost-transmit"

                                    self.conform_set_mpls_exp_topmost_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmitTable()
                                    self.conform_set_mpls_exp_topmost_transmit_table.parent = self
                                    self._children_name_map["conform_set_mpls_exp_topmost_transmit_table"] = "conform-set-mpls-exp-topmost-transmit-table"

                                    self.conform_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmit()
                                    self.conform_set_prec_transmit.parent = self
                                    self._children_name_map["conform_set_prec_transmit"] = "conform-set-prec-transmit"

                                    self.conform_set_prec_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmitTable()
                                    self.conform_set_prec_transmit_table.parent = self
                                    self._children_name_map["conform_set_prec_transmit_table"] = "conform-set-prec-transmit-table"

                                    self.conform_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmit()
                                    self.conform_set_qos_transmit.parent = self
                                    self._children_name_map["conform_set_qos_transmit"] = "conform-set-qos-transmit"

                                    self.conform_set_qos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmitTable()
                                    self.conform_set_qos_transmit_table.parent = self
                                    self._children_name_map["conform_set_qos_transmit_table"] = "conform-set-qos-transmit-table"

                                    self.conform_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformTransmit()
                                    self.conform_transmit.parent = self
                                    self._children_name_map["conform_transmit"] = "conform-transmit"

                                    self.conform_drop = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformDrop()
                                    self.conform_drop.parent = self
                                    self._children_name_map["conform_drop"] = "conform-drop"

                                    self.exceed_dscp = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDscp()
                                    self.exceed_dscp.parent = self
                                    self._children_name_map["exceed_dscp"] = "exceed-dscp"

                                    self.exceed_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetClpTransmit()
                                    self.exceed_set_clp_transmit.parent = self
                                    self._children_name_map["exceed_set_clp_transmit"] = "exceed-set-clp-transmit"

                                    self.exceed_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetCosTransmit()
                                    self.exceed_set_cos_transmit.parent = self
                                    self._children_name_map["exceed_set_cos_transmit"] = "exceed-set-cos-transmit"

                                    self.exceed_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDiscardClassTransmit()
                                    self.exceed_set_discard_class_transmit.parent = self
                                    self._children_name_map["exceed_set_discard_class_transmit"] = "exceed-set-discard-class-transmit"

                                    self.exceed_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit()
                                    self.exceed_set_dscp_transmit.parent = self
                                    self._children_name_map["exceed_set_dscp_transmit"] = "exceed-set-dscp-transmit"

                                    self.exceed_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmitTable()
                                    self.exceed_set_dscp_transmit_table.parent = self
                                    self._children_name_map["exceed_set_dscp_transmit_table"] = "exceed-set-dscp-transmit-table"

                                    self.exceed_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetFrdeTransmit()
                                    self.exceed_set_frde_transmit.parent = self
                                    self._children_name_map["exceed_set_frde_transmit"] = "exceed-set-frde-transmit"

                                    self.exceed_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpImpositionTransmit()
                                    self.exceed_set_mpls_exp_imposition_transmit.parent = self
                                    self._children_name_map["exceed_set_mpls_exp_imposition_transmit"] = "exceed-set-mpls-exp-imposition-transmit"

                                    self.exceed_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpTopmostTransmit()
                                    self.exceed_set_mpls_exp_topmost_transmit.parent = self
                                    self._children_name_map["exceed_set_mpls_exp_topmost_transmit"] = "exceed-set-mpls-exp-topmost-transmit"

                                    self.exceed_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetPrecTransmit()
                                    self.exceed_set_prec_transmit.parent = self
                                    self._children_name_map["exceed_set_prec_transmit"] = "exceed-set-prec-transmit"

                                    self.exceed_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetQosTransmit()
                                    self.exceed_set_qos_transmit.parent = self
                                    self._children_name_map["exceed_set_qos_transmit"] = "exceed-set-qos-transmit"

                                    self.exceed_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedTransmit()
                                    self.exceed_transmit.parent = self
                                    self._children_name_map["exceed_transmit"] = "exceed-transmit"

                                    self.exceed_drop = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDrop()
                                    self.exceed_drop.parent = self
                                    self._children_name_map["exceed_drop"] = "exceed-drop"

                                    self.violate_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetClpTransmit()
                                    self.violate_set_clp_transmit.parent = self
                                    self._children_name_map["violate_set_clp_transmit"] = "violate-set-clp-transmit"

                                    self.violate_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetCosTransmit()
                                    self.violate_set_cos_transmit.parent = self
                                    self._children_name_map["violate_set_cos_transmit"] = "violate-set-cos-transmit"

                                    self.violate_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDiscardClassTransmit()
                                    self.violate_set_discard_class_transmit.parent = self
                                    self._children_name_map["violate_set_discard_class_transmit"] = "violate-set-discard-class-transmit"

                                    self.violate_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDscpTransmit()
                                    self.violate_set_dscp_transmit.parent = self
                                    self._children_name_map["violate_set_dscp_transmit"] = "violate-set-dscp-transmit"

                                    self.violate_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetFrdeTransmit()
                                    self.violate_set_frde_transmit.parent = self
                                    self._children_name_map["violate_set_frde_transmit"] = "violate-set-frde-transmit"

                                    self.violate_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpImpositionTransmit()
                                    self.violate_set_mpls_exp_imposition_transmit.parent = self
                                    self._children_name_map["violate_set_mpls_exp_imposition_transmit"] = "violate-set-mpls-exp-imposition-transmit"

                                    self.violate_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpTopmostTransmit()
                                    self.violate_set_mpls_exp_topmost_transmit.parent = self
                                    self._children_name_map["violate_set_mpls_exp_topmost_transmit"] = "violate-set-mpls-exp-topmost-transmit"

                                    self.violate_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetPrecTransmit()
                                    self.violate_set_prec_transmit.parent = self
                                    self._children_name_map["violate_set_prec_transmit"] = "violate-set-prec-transmit"

                                    self.violate_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetQosTransmit()
                                    self.violate_set_qos_transmit.parent = self
                                    self._children_name_map["violate_set_qos_transmit"] = "violate-set-qos-transmit"

                                    self.violate_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateTransmit()
                                    self.violate_transmit.parent = self
                                    self._children_name_map["violate_transmit"] = "violate-transmit"

                                    self.violate_drop = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateDrop()
                                    self.violate_drop.parent = self
                                    self._children_name_map["violate_drop"] = "violate-drop"
                                    self._segment_path = lambda: "actions"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions, [], name, value)


                                class ConformSetClpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetClpTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetClpTransmit, self).__init__()

                                        self.yang_name = "conform-set-clp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetClpTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetClpTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-clp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetClpTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_clp_transmit
                                        
                                        	set atm clp and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetClpTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-clp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                            ])
                                            self.set_clp_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetClpTransmit.ConformAction, ['set_clp_transmit'], name, value)


                                class ConformSetCosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmit, self).__init__()

                                        self.yang_name = "conform-set-cos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-cos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-cos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                            ])
                                            self.set_cos_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmit.ConformAction, ['set_cos_transmit'], name, value)


                                class ConformSetCosTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-cos-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-cos-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-cos-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_cos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetCosTransmitTable.ConformAction, ['set_cos_transmit', 'table'], name, value)


                                class ConformSetDiscardClassTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDiscardClassTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDiscardClassTransmit, self).__init__()

                                        self.yang_name = "conform-set-discard-class-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDiscardClassTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDiscardClassTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-discard-class-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDiscardClassTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_discard_class_transmit
                                        
                                        	set discard\-class and send it
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDiscardClassTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-discard-class-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                            ])
                                            self.set_discard_class_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDiscardClassTransmit.ConformAction, ['set_discard_class_transmit'], name, value)


                                class ConformSetDscpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmit, self).__init__()

                                        self.yang_name = "conform-set-dscp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-dscp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-dscp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmit.ConformAction, ['set_dscp_transmit'], name, value)


                                class ConformSetDscpTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-dscp-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-dscp-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-dscp-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetDscpTransmitTable.ConformAction, ['set_dscp_transmit', 'table'], name, value)


                                class ConformSetFrdeTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetFrdeTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetFrdeTransmit, self).__init__()

                                        self.yang_name = "conform-set-frde-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetFrdeTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetFrdeTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-frde-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetFrdeTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_frde_transmit
                                        
                                        	set FR DE and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetFrdeTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-frde-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                            ])
                                            self.set_frde_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetFrdeTransmit.ConformAction, ['set_frde_transmit'], name, value)


                                class ConformSetMplsExpImpositionTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmit, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-imposition-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                class ConformSetMplsExpImpositionTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-imposition-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, ['set_mpls_exp_imposition_transmit', 'table'], name, value)


                                class ConformSetMplsExpTopmostTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmit, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-topmost-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                class ConformSetMplsExpTopmostTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-topmost-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, ['set_mpls_exp_topmost_transmit', 'table'], name, value)


                                class ConformSetPrecTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmit, self).__init__()

                                        self.yang_name = "conform-set-prec-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-prec-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-prec-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                            ])
                                            self.set_prec_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmit.ConformAction, ['set_prec_transmit'], name, value)


                                class ConformSetPrecTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-prec-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-prec-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-prec-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_prec_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetPrecTransmitTable.ConformAction, ['set_prec_transmit', 'table'], name, value)


                                class ConformSetQosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmit, self).__init__()

                                        self.yang_name = "conform-set-qos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-qos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-qos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                            ])
                                            self.set_qos_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmit.ConformAction, ['set_qos_transmit'], name, value)


                                class ConformSetQosTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-qos-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-qos-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-qos-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_qos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformSetQosTransmitTable.ConformAction, ['set_qos_transmit', 'table'], name, value)


                                class ConformTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformTransmit, self).__init__()

                                        self.yang_name = "conform-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: transmit
                                        
                                        	transmit packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                            ])
                                            self.transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformTransmit.ConformAction, ['transmit'], name, value)


                                class ConformDrop(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformDrop.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformDrop, self).__init__()

                                        self.yang_name = "conform-drop"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformDrop.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformDrop.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-drop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformDrop, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: drop
                                        
                                        	drop packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformDrop.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-drop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ])
                                            self.drop = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ConformDrop.ConformAction, ['drop'], name, value)


                                class ExceedDscp(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDscp.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDscp, self).__init__()

                                        self.yang_name = "exceed-dscp"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDscp.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDscp.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-dscp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDscp, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: dscp
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDscp.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-dscp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                            ])
                                            self.dscp = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDscp.ExceedAction, ['dscp'], name, value)


                                class ExceedSetClpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetClpTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetClpTransmit, self).__init__()

                                        self.yang_name = "exceed-set-clp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetClpTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetClpTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-clp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetClpTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_clp_transmit
                                        
                                        	set atm clp and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetClpTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-clp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                            ])
                                            self.set_clp_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetClpTransmit.ExceedAction, ['set_clp_transmit'], name, value)


                                class ExceedSetCosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetCosTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetCosTransmit, self).__init__()

                                        self.yang_name = "exceed-set-cos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetCosTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetCosTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-cos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetCosTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetCosTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-cos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_cos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetCosTransmit.ExceedAction, ['set_cos_transmit', 'table'], name, value)


                                class ExceedSetDiscardClassTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDiscardClassTransmit, self).__init__()

                                        self.yang_name = "exceed-set-discard-class-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-discard-class-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDiscardClassTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_discard_class_transmit
                                        
                                        	set discard\-class and send it
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-discard-class-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                            ])
                                            self.set_discard_class_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction, ['set_discard_class_transmit'], name, value)


                                class ExceedSetDscpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit, self).__init__()

                                        self.yang_name = "exceed-set-dscp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-dscp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`SetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-dscp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("set-dscp-transmit", ("set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit))])
                                            self._leafs = OrderedDict()

                                            self.set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit()
                                            self.set_dscp_transmit.parent = self
                                            self._children_name_map["set_dscp_transmit"] = "set-dscp-transmit"
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction, [], name, value)


                                        class SetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: dscp
                                            
                                            	
                                            	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, self).__init__()

                                                self.yang_name = "set-dscp-transmit"
                                                self.yang_parent_name = "exceed-action"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp))])
                                                self._leafs = OrderedDict()

                                                self.dscp = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp()
                                                self.dscp.parent = self
                                                self._children_name_map["dscp"] = "dscp"
                                                self._segment_path = lambda: "set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, [], name, value)


                                            class Dscp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: table
                                                
                                                	
                                                	**type**\:  :py:class:`Table <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, self).__init__()

                                                    self.yang_name = "dscp"
                                                    self.yang_parent_name = "set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('table', (YLeaf(YType.enumeration, 'table'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table')])),
                                                    ])
                                                    self.table = None
                                                    self._segment_path = lambda: "dscp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, ['table'], name, value)

                                                class Table(Enum):
                                                    """
                                                    Table (Enum Class)

                                                    .. data:: policed_dscp = 0

                                                    """

                                                    policed_dscp = Enum.YLeaf(0, "policed-dscp")



                                class ExceedSetDscpTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmitTable, self).__init__()

                                        self.yang_name = "exceed-set-dscp-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-dscp-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmitTable, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-dscp-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction, ['set_dscp_transmit', 'table'], name, value)


                                class ExceedSetFrdeTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetFrdeTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetFrdeTransmit, self).__init__()

                                        self.yang_name = "exceed-set-frde-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetFrdeTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetFrdeTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-frde-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetFrdeTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_frde_transmit
                                        
                                        	set FR DE and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetFrdeTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-frde-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                            ])
                                            self.set_frde_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetFrdeTransmit.ExceedAction, ['set_frde_transmit'], name, value)


                                class ExceedSetMplsExpImpositionTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpImpositionTransmit, self).__init__()

                                        self.yang_name = "exceed-set-mpls-exp-imposition-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-mpls-exp-imposition-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpImpositionTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-mpls-exp-imposition-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                class ExceedSetMplsExpTopmostTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpTopmostTransmit, self).__init__()

                                        self.yang_name = "exceed-set-mpls-exp-topmost-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-mpls-exp-topmost-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpTopmostTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-mpls-exp-topmost-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                class ExceedSetPrecTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetPrecTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetPrecTransmit, self).__init__()

                                        self.yang_name = "exceed-set-prec-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetPrecTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetPrecTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-prec-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetPrecTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetPrecTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-prec-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_prec_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetPrecTransmit.ExceedAction, ['set_prec_transmit', 'table'], name, value)


                                class ExceedSetQosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetQosTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetQosTransmit, self).__init__()

                                        self.yang_name = "exceed-set-qos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetQosTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetQosTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-qos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetQosTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetQosTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-qos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                            ])
                                            self.set_qos_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedSetQosTransmit.ExceedAction, ['set_qos_transmit'], name, value)


                                class ExceedTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedTransmit, self).__init__()

                                        self.yang_name = "exceed-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: transmit
                                        
                                        	transmit packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                            ])
                                            self.transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedTransmit.ExceedAction, ['transmit'], name, value)


                                class ExceedDrop(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDrop.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDrop, self).__init__()

                                        self.yang_name = "exceed-drop"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDrop.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDrop.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-drop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDrop, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: drop
                                        
                                        	drop packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDrop.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-drop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ])
                                            self.drop = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ExceedDrop.ExceedAction, ['drop'], name, value)


                                class ViolateSetClpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetClpTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetClpTransmit, self).__init__()

                                        self.yang_name = "violate-set-clp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetClpTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetClpTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-clp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetClpTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_clp_transmit
                                        
                                        	set atm clp and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetClpTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-clp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                            ])
                                            self.set_clp_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetClpTransmit.ViolateAction, ['set_clp_transmit'], name, value)


                                class ViolateSetCosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetCosTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetCosTransmit, self).__init__()

                                        self.yang_name = "violate-set-cos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetCosTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetCosTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-cos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetCosTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetCosTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-cos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_cos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetCosTransmit.ViolateAction, ['set_cos_transmit', 'table'], name, value)


                                class ViolateSetDiscardClassTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDiscardClassTransmit, self).__init__()

                                        self.yang_name = "violate-set-discard-class-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-discard-class-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDiscardClassTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_discard_class_transmit
                                        
                                        	set discard\-class and send it
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-discard-class-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                            ])
                                            self.set_discard_class_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction, ['set_discard_class_transmit'], name, value)


                                class ViolateSetDscpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDscpTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDscpTransmit, self).__init__()

                                        self.yang_name = "violate-set-dscp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDscpTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDscpTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-dscp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDscpTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDscpTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-dscp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetDscpTransmit.ViolateAction, ['set_dscp_transmit', 'table'], name, value)


                                class ViolateSetFrdeTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetFrdeTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetFrdeTransmit, self).__init__()

                                        self.yang_name = "violate-set-frde-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetFrdeTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetFrdeTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-frde-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetFrdeTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_frde_transmit
                                        
                                        	set FR DE and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetFrdeTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-frde-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                            ])
                                            self.set_frde_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetFrdeTransmit.ViolateAction, ['set_frde_transmit'], name, value)


                                class ViolateSetMplsExpImpositionTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpImpositionTransmit, self).__init__()

                                        self.yang_name = "violate-set-mpls-exp-imposition-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-mpls-exp-imposition-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpImpositionTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-mpls-exp-imposition-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                class ViolateSetMplsExpTopmostTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpTopmostTransmit, self).__init__()

                                        self.yang_name = "violate-set-mpls-exp-topmost-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-mpls-exp-topmost-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpTopmostTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-mpls-exp-topmost-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                class ViolateSetPrecTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetPrecTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetPrecTransmit, self).__init__()

                                        self.yang_name = "violate-set-prec-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetPrecTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetPrecTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-prec-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetPrecTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetPrecTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-prec-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_prec_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetPrecTransmit.ViolateAction, ['set_prec_transmit', 'table'], name, value)


                                class ViolateSetQosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetQosTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetQosTransmit, self).__init__()

                                        self.yang_name = "violate-set-qos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetQosTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetQosTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-qos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetQosTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetQosTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-qos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                            ])
                                            self.set_qos_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateSetQosTransmit.ViolateAction, ['set_qos_transmit'], name, value)


                                class ViolateTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateTransmit, self).__init__()

                                        self.yang_name = "violate-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: transmit
                                        
                                        	transmit packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                            ])
                                            self.transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateTransmit.ViolateAction, ['transmit'], name, value)


                                class ViolateDrop(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateDrop.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateDrop, self).__init__()

                                        self.yang_name = "violate-drop"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateDrop.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateDrop.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-drop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateDrop, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: drop
                                        
                                        	drop packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateDrop.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-drop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ])
                                            self.drop = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PolicePolicyMap.Police.Actions.ViolateDrop.ViolateAction, ['drop'], name, value)


                    class PoliceCirPercent(Entity):
                        """
                        
                        
                        .. attribute:: police
                        
                        	
                        	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent, self).__init__()

                            self.yang_name = "police-cir-percent"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("police", ("police", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police))])
                            self._leafs = OrderedDict()

                            self.police = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police()
                            self.police.parent = self
                            self._children_name_map["police"] = "police"
                            self._segment_path = lambda: "police-cir-percent"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent, [], name, value)


                        class Police(Entity):
                            """
                            
                            
                            .. attribute:: cir
                            
                            	Committed information rate
                            	**type**\:  :py:class:`Cir <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police, self).__init__()

                                self.yang_name = "police"
                                self.yang_parent_name = "police-cir-percent"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cir", ("cir", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir))])
                                self._leafs = OrderedDict()

                                self.cir = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir()
                                self.cir.parent = self
                                self._children_name_map["cir"] = "cir"
                                self._segment_path = lambda: "police"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police, [], name, value)


                            class Cir(Entity):
                                """
                                Committed information rate
                                
                                .. attribute:: percent
                                
                                	% of interface bandwidth for Committed information rate
                                	**type**\:  :py:class:`Percent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir, self).__init__()

                                    self.yang_name = "cir"
                                    self.yang_parent_name = "police"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("percent", ("percent", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent))])
                                    self._leafs = OrderedDict()

                                    self.percent = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent()
                                    self.percent.parent = self
                                    self._children_name_map["percent"] = "percent"
                                    self._segment_path = lambda: "cir"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir, [], name, value)


                                class Percent(Entity):
                                    """
                                    % of interface bandwidth for Committed information rate
                                    
                                    .. attribute:: percentage
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: bc
                                    
                                    	Conform burst
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: bc_ms
                                    
                                    	
                                    	**type**\:  :py:class:`BcMs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.BcMs>`
                                    
                                    .. attribute:: be
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: be_ms
                                    
                                    	
                                    	**type**\:  :py:class:`BeMs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.BeMs>`
                                    
                                    .. attribute:: pir
                                    
                                    	Peak Information Rate
                                    	**type**\:  :py:class:`Pir <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Pir>`
                                    
                                    .. attribute:: pir_be
                                    
                                    	
                                    	**type**\:  :py:class:`PirBe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.PirBe>`
                                    
                                    .. attribute:: pir_be_ms
                                    
                                    	
                                    	**type**\:  :py:class:`PirBeMs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.PirBeMs>`
                                    
                                    .. attribute:: actions
                                    
                                    	
                                    	**type**\:  :py:class:`Actions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent, self).__init__()

                                        self.yang_name = "percent"
                                        self.yang_parent_name = "cir"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bc-ms", ("bc_ms", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.BcMs)), ("be-ms", ("be_ms", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.BeMs)), ("pir", ("pir", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Pir)), ("pir-be", ("pir_be", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.PirBe)), ("pir-be-ms", ("pir_be_ms", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.PirBeMs)), ("actions", ("actions", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions))])
                                        self._leafs = OrderedDict([
                                            ('percentage', (YLeaf(YType.uint8, 'percentage'), ['int'])),
                                            ('bc', (YLeaf(YType.uint16, 'bc'), ['int'])),
                                            ('be', (YLeaf(YType.uint16, 'be'), ['int'])),
                                        ])
                                        self.percentage = None
                                        self.bc = None
                                        self.be = None

                                        self.bc_ms = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.BcMs()
                                        self.bc_ms.parent = self
                                        self._children_name_map["bc_ms"] = "bc-ms"

                                        self.be_ms = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.BeMs()
                                        self.be_ms.parent = self
                                        self._children_name_map["be_ms"] = "be-ms"

                                        self.pir = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Pir()
                                        self.pir.parent = self
                                        self._children_name_map["pir"] = "pir"

                                        self.pir_be = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.PirBe()
                                        self.pir_be.parent = self
                                        self._children_name_map["pir_be"] = "pir-be"

                                        self.pir_be_ms = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.PirBeMs()
                                        self.pir_be_ms.parent = self
                                        self._children_name_map["pir_be_ms"] = "pir-be-ms"

                                        self.actions = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions()
                                        self.actions.parent = self
                                        self._children_name_map["actions"] = "actions"
                                        self._segment_path = lambda: "percent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent, ['percentage', 'bc', 'be'], name, value)


                                    class BcMs(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ms
                                        
                                        	Milli seconds
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.BcMs, self).__init__()

                                            self.yang_name = "bc-ms"
                                            self.yang_parent_name = "percent"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ms', (YLeaf(YType.empty, 'ms'), ['Empty'])),
                                            ])
                                            self.ms = None
                                            self._segment_path = lambda: "bc-ms"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.BcMs, ['ms'], name, value)


                                    class BeMs(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ms
                                        
                                        	Milli seconds
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.BeMs, self).__init__()

                                            self.yang_name = "be-ms"
                                            self.yang_parent_name = "percent"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ms', (YLeaf(YType.empty, 'ms'), ['Empty'])),
                                            ])
                                            self.ms = None
                                            self._segment_path = lambda: "be-ms"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.BeMs, ['ms'], name, value)


                                    class Pir(Entity):
                                        """
                                        Peak Information Rate
                                        
                                        .. attribute:: percent
                                        
                                        	% of interface bandwidth for Peak Information Rate
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Pir, self).__init__()

                                            self.yang_name = "pir"
                                            self.yang_parent_name = "percent"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ])
                                            self.percent = None
                                            self._segment_path = lambda: "pir"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Pir, ['percent'], name, value)


                                    class PirBe(Entity):
                                        """
                                        
                                        
                                        .. attribute:: be
                                        
                                        	Excess burst
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.PirBe, self).__init__()

                                            self.yang_name = "pir-be"
                                            self.yang_parent_name = "percent"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('be', (YLeaf(YType.uint16, 'be'), ['int'])),
                                            ])
                                            self.be = None
                                            self._segment_path = lambda: "pir-be"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.PirBe, ['be'], name, value)


                                    class PirBeMs(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ms
                                        
                                        	Milli seconds
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.PirBeMs, self).__init__()

                                            self.yang_name = "pir-be-ms"
                                            self.yang_parent_name = "percent"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ms', (YLeaf(YType.empty, 'ms'), ['Empty'])),
                                            ])
                                            self.ms = None
                                            self._segment_path = lambda: "pir-be-ms"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.PirBeMs, ['ms'], name, value)


                                    class Actions(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_set_clp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetClpTransmit>`
                                        
                                        .. attribute:: conform_set_cos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmit>`
                                        
                                        .. attribute:: conform_set_cos_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetCosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmitTable>`
                                        
                                        .. attribute:: conform_set_discard_class_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDiscardClassTransmit>`
                                        
                                        .. attribute:: conform_set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmit>`
                                        
                                        .. attribute:: conform_set_dscp_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmitTable>`
                                        
                                        .. attribute:: conform_set_frde_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetFrdeTransmit>`
                                        
                                        .. attribute:: conform_set_mpls_exp_imposition_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmit>`
                                        
                                        .. attribute:: conform_set_mpls_exp_imposition_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmitTable>`
                                        
                                        .. attribute:: conform_set_mpls_exp_topmost_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmit>`
                                        
                                        .. attribute:: conform_set_mpls_exp_topmost_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmitTable>`
                                        
                                        .. attribute:: conform_set_prec_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmit>`
                                        
                                        .. attribute:: conform_set_prec_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetPrecTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmitTable>`
                                        
                                        .. attribute:: conform_set_qos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmit>`
                                        
                                        .. attribute:: conform_set_qos_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetQosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmitTable>`
                                        
                                        .. attribute:: conform_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformTransmit>`
                                        
                                        .. attribute:: conform_drop
                                        
                                        	
                                        	**type**\:  :py:class:`ConformDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformDrop>`
                                        
                                        .. attribute:: exceed_dscp
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedDscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDscp>`
                                        
                                        .. attribute:: exceed_set_clp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetClpTransmit>`
                                        
                                        .. attribute:: exceed_set_cos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetCosTransmit>`
                                        
                                        .. attribute:: exceed_set_discard_class_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDiscardClassTransmit>`
                                        
                                        .. attribute:: exceed_set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit>`
                                        
                                        .. attribute:: exceed_set_dscp_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmitTable>`
                                        
                                        .. attribute:: exceed_set_frde_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetFrdeTransmit>`
                                        
                                        .. attribute:: exceed_set_mpls_exp_imposition_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpImpositionTransmit>`
                                        
                                        .. attribute:: exceed_set_mpls_exp_topmost_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpTopmostTransmit>`
                                        
                                        .. attribute:: exceed_set_prec_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetPrecTransmit>`
                                        
                                        .. attribute:: exceed_set_qos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetQosTransmit>`
                                        
                                        .. attribute:: exceed_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedTransmit>`
                                        
                                        .. attribute:: exceed_drop
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDrop>`
                                        
                                        .. attribute:: violate_set_clp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetClpTransmit>`
                                        
                                        .. attribute:: violate_set_cos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetCosTransmit>`
                                        
                                        .. attribute:: violate_set_discard_class_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDiscardClassTransmit>`
                                        
                                        .. attribute:: violate_set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDscpTransmit>`
                                        
                                        .. attribute:: violate_set_frde_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetFrdeTransmit>`
                                        
                                        .. attribute:: violate_set_mpls_exp_imposition_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpImpositionTransmit>`
                                        
                                        .. attribute:: violate_set_mpls_exp_topmost_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpTopmostTransmit>`
                                        
                                        .. attribute:: violate_set_prec_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetPrecTransmit>`
                                        
                                        .. attribute:: violate_set_qos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetQosTransmit>`
                                        
                                        .. attribute:: violate_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateTransmit>`
                                        
                                        .. attribute:: violate_drop
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateDrop>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions, self).__init__()

                                            self.yang_name = "actions"
                                            self.yang_parent_name = "percent"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-set-clp-transmit", ("conform_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetClpTransmit)), ("conform-set-cos-transmit", ("conform_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmit)), ("conform-set-cos-transmit-table", ("conform_set_cos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmitTable)), ("conform-set-discard-class-transmit", ("conform_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDiscardClassTransmit)), ("conform-set-dscp-transmit", ("conform_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmit)), ("conform-set-dscp-transmit-table", ("conform_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmitTable)), ("conform-set-frde-transmit", ("conform_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetFrdeTransmit)), ("conform-set-mpls-exp-imposition-transmit", ("conform_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmit)), ("conform-set-mpls-exp-imposition-transmit-table", ("conform_set_mpls_exp_imposition_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmitTable)), ("conform-set-mpls-exp-topmost-transmit", ("conform_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmit)), ("conform-set-mpls-exp-topmost-transmit-table", ("conform_set_mpls_exp_topmost_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmitTable)), ("conform-set-prec-transmit", ("conform_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmit)), ("conform-set-prec-transmit-table", ("conform_set_prec_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmitTable)), ("conform-set-qos-transmit", ("conform_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmit)), ("conform-set-qos-transmit-table", ("conform_set_qos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmitTable)), ("conform-transmit", ("conform_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformTransmit)), ("conform-drop", ("conform_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformDrop)), ("exceed-dscp", ("exceed_dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDscp)), ("exceed-set-clp-transmit", ("exceed_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetClpTransmit)), ("exceed-set-cos-transmit", ("exceed_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetCosTransmit)), ("exceed-set-discard-class-transmit", ("exceed_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDiscardClassTransmit)), ("exceed-set-dscp-transmit", ("exceed_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit)), ("exceed-set-dscp-transmit-table", ("exceed_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmitTable)), ("exceed-set-frde-transmit", ("exceed_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetFrdeTransmit)), ("exceed-set-mpls-exp-imposition-transmit", ("exceed_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpImpositionTransmit)), ("exceed-set-mpls-exp-topmost-transmit", ("exceed_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpTopmostTransmit)), ("exceed-set-prec-transmit", ("exceed_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetPrecTransmit)), ("exceed-set-qos-transmit", ("exceed_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetQosTransmit)), ("exceed-transmit", ("exceed_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedTransmit)), ("exceed-drop", ("exceed_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDrop)), ("violate-set-clp-transmit", ("violate_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetClpTransmit)), ("violate-set-cos-transmit", ("violate_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetCosTransmit)), ("violate-set-discard-class-transmit", ("violate_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDiscardClassTransmit)), ("violate-set-dscp-transmit", ("violate_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDscpTransmit)), ("violate-set-frde-transmit", ("violate_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetFrdeTransmit)), ("violate-set-mpls-exp-imposition-transmit", ("violate_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpImpositionTransmit)), ("violate-set-mpls-exp-topmost-transmit", ("violate_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpTopmostTransmit)), ("violate-set-prec-transmit", ("violate_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetPrecTransmit)), ("violate-set-qos-transmit", ("violate_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetQosTransmit)), ("violate-transmit", ("violate_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateTransmit)), ("violate-drop", ("violate_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateDrop))])
                                            self._leafs = OrderedDict()

                                            self.conform_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetClpTransmit()
                                            self.conform_set_clp_transmit.parent = self
                                            self._children_name_map["conform_set_clp_transmit"] = "conform-set-clp-transmit"

                                            self.conform_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmit()
                                            self.conform_set_cos_transmit.parent = self
                                            self._children_name_map["conform_set_cos_transmit"] = "conform-set-cos-transmit"

                                            self.conform_set_cos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmitTable()
                                            self.conform_set_cos_transmit_table.parent = self
                                            self._children_name_map["conform_set_cos_transmit_table"] = "conform-set-cos-transmit-table"

                                            self.conform_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDiscardClassTransmit()
                                            self.conform_set_discard_class_transmit.parent = self
                                            self._children_name_map["conform_set_discard_class_transmit"] = "conform-set-discard-class-transmit"

                                            self.conform_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmit()
                                            self.conform_set_dscp_transmit.parent = self
                                            self._children_name_map["conform_set_dscp_transmit"] = "conform-set-dscp-transmit"

                                            self.conform_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmitTable()
                                            self.conform_set_dscp_transmit_table.parent = self
                                            self._children_name_map["conform_set_dscp_transmit_table"] = "conform-set-dscp-transmit-table"

                                            self.conform_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetFrdeTransmit()
                                            self.conform_set_frde_transmit.parent = self
                                            self._children_name_map["conform_set_frde_transmit"] = "conform-set-frde-transmit"

                                            self.conform_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmit()
                                            self.conform_set_mpls_exp_imposition_transmit.parent = self
                                            self._children_name_map["conform_set_mpls_exp_imposition_transmit"] = "conform-set-mpls-exp-imposition-transmit"

                                            self.conform_set_mpls_exp_imposition_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmitTable()
                                            self.conform_set_mpls_exp_imposition_transmit_table.parent = self
                                            self._children_name_map["conform_set_mpls_exp_imposition_transmit_table"] = "conform-set-mpls-exp-imposition-transmit-table"

                                            self.conform_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmit()
                                            self.conform_set_mpls_exp_topmost_transmit.parent = self
                                            self._children_name_map["conform_set_mpls_exp_topmost_transmit"] = "conform-set-mpls-exp-topmost-transmit"

                                            self.conform_set_mpls_exp_topmost_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmitTable()
                                            self.conform_set_mpls_exp_topmost_transmit_table.parent = self
                                            self._children_name_map["conform_set_mpls_exp_topmost_transmit_table"] = "conform-set-mpls-exp-topmost-transmit-table"

                                            self.conform_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmit()
                                            self.conform_set_prec_transmit.parent = self
                                            self._children_name_map["conform_set_prec_transmit"] = "conform-set-prec-transmit"

                                            self.conform_set_prec_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmitTable()
                                            self.conform_set_prec_transmit_table.parent = self
                                            self._children_name_map["conform_set_prec_transmit_table"] = "conform-set-prec-transmit-table"

                                            self.conform_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmit()
                                            self.conform_set_qos_transmit.parent = self
                                            self._children_name_map["conform_set_qos_transmit"] = "conform-set-qos-transmit"

                                            self.conform_set_qos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmitTable()
                                            self.conform_set_qos_transmit_table.parent = self
                                            self._children_name_map["conform_set_qos_transmit_table"] = "conform-set-qos-transmit-table"

                                            self.conform_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformTransmit()
                                            self.conform_transmit.parent = self
                                            self._children_name_map["conform_transmit"] = "conform-transmit"

                                            self.conform_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformDrop()
                                            self.conform_drop.parent = self
                                            self._children_name_map["conform_drop"] = "conform-drop"

                                            self.exceed_dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDscp()
                                            self.exceed_dscp.parent = self
                                            self._children_name_map["exceed_dscp"] = "exceed-dscp"

                                            self.exceed_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetClpTransmit()
                                            self.exceed_set_clp_transmit.parent = self
                                            self._children_name_map["exceed_set_clp_transmit"] = "exceed-set-clp-transmit"

                                            self.exceed_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetCosTransmit()
                                            self.exceed_set_cos_transmit.parent = self
                                            self._children_name_map["exceed_set_cos_transmit"] = "exceed-set-cos-transmit"

                                            self.exceed_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDiscardClassTransmit()
                                            self.exceed_set_discard_class_transmit.parent = self
                                            self._children_name_map["exceed_set_discard_class_transmit"] = "exceed-set-discard-class-transmit"

                                            self.exceed_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit()
                                            self.exceed_set_dscp_transmit.parent = self
                                            self._children_name_map["exceed_set_dscp_transmit"] = "exceed-set-dscp-transmit"

                                            self.exceed_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmitTable()
                                            self.exceed_set_dscp_transmit_table.parent = self
                                            self._children_name_map["exceed_set_dscp_transmit_table"] = "exceed-set-dscp-transmit-table"

                                            self.exceed_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetFrdeTransmit()
                                            self.exceed_set_frde_transmit.parent = self
                                            self._children_name_map["exceed_set_frde_transmit"] = "exceed-set-frde-transmit"

                                            self.exceed_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpImpositionTransmit()
                                            self.exceed_set_mpls_exp_imposition_transmit.parent = self
                                            self._children_name_map["exceed_set_mpls_exp_imposition_transmit"] = "exceed-set-mpls-exp-imposition-transmit"

                                            self.exceed_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpTopmostTransmit()
                                            self.exceed_set_mpls_exp_topmost_transmit.parent = self
                                            self._children_name_map["exceed_set_mpls_exp_topmost_transmit"] = "exceed-set-mpls-exp-topmost-transmit"

                                            self.exceed_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetPrecTransmit()
                                            self.exceed_set_prec_transmit.parent = self
                                            self._children_name_map["exceed_set_prec_transmit"] = "exceed-set-prec-transmit"

                                            self.exceed_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetQosTransmit()
                                            self.exceed_set_qos_transmit.parent = self
                                            self._children_name_map["exceed_set_qos_transmit"] = "exceed-set-qos-transmit"

                                            self.exceed_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedTransmit()
                                            self.exceed_transmit.parent = self
                                            self._children_name_map["exceed_transmit"] = "exceed-transmit"

                                            self.exceed_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDrop()
                                            self.exceed_drop.parent = self
                                            self._children_name_map["exceed_drop"] = "exceed-drop"

                                            self.violate_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetClpTransmit()
                                            self.violate_set_clp_transmit.parent = self
                                            self._children_name_map["violate_set_clp_transmit"] = "violate-set-clp-transmit"

                                            self.violate_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetCosTransmit()
                                            self.violate_set_cos_transmit.parent = self
                                            self._children_name_map["violate_set_cos_transmit"] = "violate-set-cos-transmit"

                                            self.violate_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDiscardClassTransmit()
                                            self.violate_set_discard_class_transmit.parent = self
                                            self._children_name_map["violate_set_discard_class_transmit"] = "violate-set-discard-class-transmit"

                                            self.violate_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDscpTransmit()
                                            self.violate_set_dscp_transmit.parent = self
                                            self._children_name_map["violate_set_dscp_transmit"] = "violate-set-dscp-transmit"

                                            self.violate_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetFrdeTransmit()
                                            self.violate_set_frde_transmit.parent = self
                                            self._children_name_map["violate_set_frde_transmit"] = "violate-set-frde-transmit"

                                            self.violate_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpImpositionTransmit()
                                            self.violate_set_mpls_exp_imposition_transmit.parent = self
                                            self._children_name_map["violate_set_mpls_exp_imposition_transmit"] = "violate-set-mpls-exp-imposition-transmit"

                                            self.violate_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpTopmostTransmit()
                                            self.violate_set_mpls_exp_topmost_transmit.parent = self
                                            self._children_name_map["violate_set_mpls_exp_topmost_transmit"] = "violate-set-mpls-exp-topmost-transmit"

                                            self.violate_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetPrecTransmit()
                                            self.violate_set_prec_transmit.parent = self
                                            self._children_name_map["violate_set_prec_transmit"] = "violate-set-prec-transmit"

                                            self.violate_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetQosTransmit()
                                            self.violate_set_qos_transmit.parent = self
                                            self._children_name_map["violate_set_qos_transmit"] = "violate-set-qos-transmit"

                                            self.violate_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateTransmit()
                                            self.violate_transmit.parent = self
                                            self._children_name_map["violate_transmit"] = "violate-transmit"

                                            self.violate_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateDrop()
                                            self.violate_drop.parent = self
                                            self._children_name_map["violate_drop"] = "violate-drop"
                                            self._segment_path = lambda: "actions"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions, [], name, value)


                                        class ConformSetClpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetClpTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetClpTransmit, self).__init__()

                                                self.yang_name = "conform-set-clp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetClpTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetClpTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-clp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetClpTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_clp_transmit
                                                
                                                	set atm clp and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetClpTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-clp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_clp_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetClpTransmit.ConformAction, ['set_clp_transmit'], name, value)


                                        class ConformSetCosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmit, self).__init__()

                                                self.yang_name = "conform-set-cos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-cos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-cos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmit.ConformAction, ['set_cos_transmit'], name, value)


                                        class ConformSetCosTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-cos-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-cos-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-cos-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetCosTransmitTable.ConformAction, ['set_cos_transmit', 'table'], name, value)


                                        class ConformSetDiscardClassTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDiscardClassTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDiscardClassTransmit, self).__init__()

                                                self.yang_name = "conform-set-discard-class-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDiscardClassTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDiscardClassTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-discard-class-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDiscardClassTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_discard_class_transmit
                                                
                                                	set discard\-class and send it
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDiscardClassTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-discard-class-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                    ])
                                                    self.set_discard_class_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDiscardClassTransmit.ConformAction, ['set_discard_class_transmit'], name, value)


                                        class ConformSetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmit, self).__init__()

                                                self.yang_name = "conform-set-dscp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmit.ConformAction, ['set_dscp_transmit'], name, value)


                                        class ConformSetDscpTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-dscp-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-dscp-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-dscp-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetDscpTransmitTable.ConformAction, ['set_dscp_transmit', 'table'], name, value)


                                        class ConformSetFrdeTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetFrdeTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetFrdeTransmit, self).__init__()

                                                self.yang_name = "conform-set-frde-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetFrdeTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetFrdeTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-frde-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetFrdeTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_frde_transmit
                                                
                                                	set FR DE and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetFrdeTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-frde-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_frde_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetFrdeTransmit.ConformAction, ['set_frde_transmit'], name, value)


                                        class ConformSetMplsExpImpositionTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmit, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-imposition-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                        class ConformSetMplsExpImpositionTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-imposition-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, ['set_mpls_exp_imposition_transmit', 'table'], name, value)


                                        class ConformSetMplsExpTopmostTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmit, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-topmost-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                        class ConformSetMplsExpTopmostTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-topmost-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, ['set_mpls_exp_topmost_transmit', 'table'], name, value)


                                        class ConformSetPrecTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmit, self).__init__()

                                                self.yang_name = "conform-set-prec-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-prec-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-prec-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmit.ConformAction, ['set_prec_transmit'], name, value)


                                        class ConformSetPrecTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-prec-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-prec-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-prec-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetPrecTransmitTable.ConformAction, ['set_prec_transmit', 'table'], name, value)


                                        class ConformSetQosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmit, self).__init__()

                                                self.yang_name = "conform-set-qos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-qos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-qos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmit.ConformAction, ['set_qos_transmit'], name, value)


                                        class ConformSetQosTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-qos-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-qos-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-qos-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformSetQosTransmitTable.ConformAction, ['set_qos_transmit', 'table'], name, value)


                                        class ConformTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformTransmit, self).__init__()

                                                self.yang_name = "conform-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: transmit
                                                
                                                	transmit packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                    ])
                                                    self.transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformTransmit.ConformAction, ['transmit'], name, value)


                                        class ConformDrop(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformDrop.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformDrop, self).__init__()

                                                self.yang_name = "conform-drop"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformDrop.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformDrop.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformDrop, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: drop
                                                
                                                	drop packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformDrop.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ])
                                                    self.drop = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ConformDrop.ConformAction, ['drop'], name, value)


                                        class ExceedDscp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDscp.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDscp, self).__init__()

                                                self.yang_name = "exceed-dscp"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDscp.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDscp.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-dscp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDscp, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: dscp
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDscp.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-dscp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ])
                                                    self.dscp = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDscp.ExceedAction, ['dscp'], name, value)


                                        class ExceedSetClpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetClpTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetClpTransmit, self).__init__()

                                                self.yang_name = "exceed-set-clp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetClpTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetClpTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-clp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetClpTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_clp_transmit
                                                
                                                	set atm clp and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetClpTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-clp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_clp_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetClpTransmit.ExceedAction, ['set_clp_transmit'], name, value)


                                        class ExceedSetCosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetCosTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetCosTransmit, self).__init__()

                                                self.yang_name = "exceed-set-cos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetCosTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetCosTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-cos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetCosTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetCosTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-cos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetCosTransmit.ExceedAction, ['set_cos_transmit', 'table'], name, value)


                                        class ExceedSetDiscardClassTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDiscardClassTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDiscardClassTransmit, self).__init__()

                                                self.yang_name = "exceed-set-discard-class-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDiscardClassTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDiscardClassTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-discard-class-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDiscardClassTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_discard_class_transmit
                                                
                                                	set discard\-class and send it
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDiscardClassTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-discard-class-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                    ])
                                                    self.set_discard_class_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDiscardClassTransmit.ExceedAction, ['set_discard_class_transmit'], name, value)


                                        class ExceedSetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit, self).__init__()

                                                self.yang_name = "exceed-set-dscp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	
                                                	**type**\:  :py:class:`SetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("set-dscp-transmit", ("set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit))])
                                                    self._leafs = OrderedDict()

                                                    self.set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit()
                                                    self.set_dscp_transmit.parent = self
                                                    self._children_name_map["set_dscp_transmit"] = "set-dscp-transmit"
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction, [], name, value)


                                                class SetDscpTransmit(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: dscp
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-policy'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, self).__init__()

                                                        self.yang_name = "set-dscp-transmit"
                                                        self.yang_parent_name = "exceed-action"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp))])
                                                        self._leafs = OrderedDict()

                                                        self.dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp()
                                                        self.dscp.parent = self
                                                        self._children_name_map["dscp"] = "dscp"
                                                        self._segment_path = lambda: "set-dscp-transmit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, [], name, value)


                                                    class Dscp(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: table
                                                        
                                                        	
                                                        	**type**\:  :py:class:`Table <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-policy'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, self).__init__()

                                                            self.yang_name = "dscp"
                                                            self.yang_parent_name = "set-dscp-transmit"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('table', (YLeaf(YType.enumeration, 'table'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table')])),
                                                            ])
                                                            self.table = None
                                                            self._segment_path = lambda: "dscp"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, ['table'], name, value)

                                                        class Table(Enum):
                                                            """
                                                            Table (Enum Class)

                                                            .. data:: policed_dscp = 0

                                                            """

                                                            policed_dscp = Enum.YLeaf(0, "policed-dscp")



                                        class ExceedSetDscpTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmitTable.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmitTable, self).__init__()

                                                self.yang_name = "exceed-set-dscp-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmitTable.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmitTable.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-dscp-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmitTable, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmitTable.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-dscp-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetDscpTransmitTable.ExceedAction, ['set_dscp_transmit', 'table'], name, value)


                                        class ExceedSetFrdeTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetFrdeTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetFrdeTransmit, self).__init__()

                                                self.yang_name = "exceed-set-frde-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetFrdeTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetFrdeTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-frde-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetFrdeTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_frde_transmit
                                                
                                                	set FR DE and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetFrdeTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-frde-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_frde_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetFrdeTransmit.ExceedAction, ['set_frde_transmit'], name, value)


                                        class ExceedSetMplsExpImpositionTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpImpositionTransmit, self).__init__()

                                                self.yang_name = "exceed-set-mpls-exp-imposition-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-mpls-exp-imposition-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpImpositionTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-mpls-exp-imposition-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                        class ExceedSetMplsExpTopmostTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpTopmostTransmit, self).__init__()

                                                self.yang_name = "exceed-set-mpls-exp-topmost-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-mpls-exp-topmost-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpTopmostTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-mpls-exp-topmost-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                        class ExceedSetPrecTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetPrecTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetPrecTransmit, self).__init__()

                                                self.yang_name = "exceed-set-prec-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetPrecTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetPrecTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-prec-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetPrecTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetPrecTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-prec-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetPrecTransmit.ExceedAction, ['set_prec_transmit', 'table'], name, value)


                                        class ExceedSetQosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetQosTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetQosTransmit, self).__init__()

                                                self.yang_name = "exceed-set-qos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetQosTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetQosTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-qos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetQosTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetQosTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-qos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedSetQosTransmit.ExceedAction, ['set_qos_transmit'], name, value)


                                        class ExceedTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedTransmit, self).__init__()

                                                self.yang_name = "exceed-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: transmit
                                                
                                                	transmit packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                    ])
                                                    self.transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedTransmit.ExceedAction, ['transmit'], name, value)


                                        class ExceedDrop(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDrop.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDrop, self).__init__()

                                                self.yang_name = "exceed-drop"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDrop.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDrop.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDrop, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: drop
                                                
                                                	drop packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDrop.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ])
                                                    self.drop = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ExceedDrop.ExceedAction, ['drop'], name, value)


                                        class ViolateSetClpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetClpTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetClpTransmit, self).__init__()

                                                self.yang_name = "violate-set-clp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetClpTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetClpTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-clp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetClpTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_clp_transmit
                                                
                                                	set atm clp and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetClpTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-clp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_clp_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetClpTransmit.ViolateAction, ['set_clp_transmit'], name, value)


                                        class ViolateSetCosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetCosTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetCosTransmit, self).__init__()

                                                self.yang_name = "violate-set-cos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetCosTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetCosTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-cos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetCosTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetCosTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-cos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetCosTransmit.ViolateAction, ['set_cos_transmit', 'table'], name, value)


                                        class ViolateSetDiscardClassTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDiscardClassTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDiscardClassTransmit, self).__init__()

                                                self.yang_name = "violate-set-discard-class-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDiscardClassTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDiscardClassTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-discard-class-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDiscardClassTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_discard_class_transmit
                                                
                                                	set discard\-class and send it
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDiscardClassTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-discard-class-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                    ])
                                                    self.set_discard_class_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDiscardClassTransmit.ViolateAction, ['set_discard_class_transmit'], name, value)


                                        class ViolateSetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDscpTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDscpTransmit, self).__init__()

                                                self.yang_name = "violate-set-dscp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDscpTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDscpTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDscpTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDscpTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetDscpTransmit.ViolateAction, ['set_dscp_transmit', 'table'], name, value)


                                        class ViolateSetFrdeTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetFrdeTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetFrdeTransmit, self).__init__()

                                                self.yang_name = "violate-set-frde-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetFrdeTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetFrdeTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-frde-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetFrdeTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_frde_transmit
                                                
                                                	set FR DE and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetFrdeTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-frde-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_frde_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetFrdeTransmit.ViolateAction, ['set_frde_transmit'], name, value)


                                        class ViolateSetMplsExpImpositionTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpImpositionTransmit, self).__init__()

                                                self.yang_name = "violate-set-mpls-exp-imposition-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-mpls-exp-imposition-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpImpositionTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-mpls-exp-imposition-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                        class ViolateSetMplsExpTopmostTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpTopmostTransmit, self).__init__()

                                                self.yang_name = "violate-set-mpls-exp-topmost-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-mpls-exp-topmost-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpTopmostTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-mpls-exp-topmost-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                        class ViolateSetPrecTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetPrecTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetPrecTransmit, self).__init__()

                                                self.yang_name = "violate-set-prec-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetPrecTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetPrecTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-prec-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetPrecTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetPrecTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-prec-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetPrecTransmit.ViolateAction, ['set_prec_transmit', 'table'], name, value)


                                        class ViolateSetQosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetQosTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetQosTransmit, self).__init__()

                                                self.yang_name = "violate-set-qos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetQosTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetQosTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-qos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetQosTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetQosTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-qos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateSetQosTransmit.ViolateAction, ['set_qos_transmit'], name, value)


                                        class ViolateTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateTransmit, self).__init__()

                                                self.yang_name = "violate-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: transmit
                                                
                                                	transmit packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                    ])
                                                    self.transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateTransmit.ViolateAction, ['transmit'], name, value)


                                        class ViolateDrop(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateDrop.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateDrop, self).__init__()

                                                self.yang_name = "violate-drop"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateDrop.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateDrop.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateDrop, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: drop
                                                
                                                	drop packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateDrop.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ])
                                                    self.drop = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCirPercent.Police.Cir.Percent.Actions.ViolateDrop.ViolateAction, ['drop'], name, value)


                    class PoliceRateUnit(Entity):
                        """
                        
                        
                        .. attribute:: police
                        
                        	
                        	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit, self).__init__()

                            self.yang_name = "police-rate-unit"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("police", ("police", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police))])
                            self._leafs = OrderedDict()

                            self.police = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police()
                            self.police.parent = self
                            self._children_name_map["police"] = "police"
                            self._segment_path = lambda: "police-rate-unit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit, [], name, value)


                        class Police(Entity):
                            """
                            
                            
                            .. attribute:: rate
                            
                            	Specify police rate
                            	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police, self).__init__()

                                self.yang_name = "police"
                                self.yang_parent_name = "police-rate-unit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rate", ("rate", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate))])
                                self._leafs = OrderedDict()

                                self.rate = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate()
                                self.rate.parent = self
                                self._children_name_map["rate"] = "rate"
                                self._segment_path = lambda: "police"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police, [], name, value)


                            class Rate(Entity):
                                """
                                Specify police rate
                                
                                .. attribute:: units
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: xps
                                
                                	
                                	**type**\:  :py:class:`PolicePpsBpsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.PolicePpsBpsType>`
                                
                                .. attribute:: burst
                                
                                	Specify 'burst' parameter
                                	**type**\:  :py:class:`Burst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Burst>`
                                
                                .. attribute:: peak_rate
                                
                                	Specify peak rate
                                	**type**\:  :py:class:`PeakRate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.PeakRate>`
                                
                                .. attribute:: peak_burst
                                
                                	Specify 'peak\-burst' parameter for peak\-rate
                                	**type**\:  :py:class:`PeakBurst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.PeakBurst>`
                                
                                .. attribute:: actions
                                
                                	
                                	**type**\:  :py:class:`Actions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate, self).__init__()

                                    self.yang_name = "rate"
                                    self.yang_parent_name = "police"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("burst", ("burst", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Burst)), ("peak-rate", ("peak_rate", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.PeakRate)), ("peak-burst", ("peak_burst", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.PeakBurst)), ("actions", ("actions", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions))])
                                    self._leafs = OrderedDict([
                                        ('units', (YLeaf(YType.uint64, 'units'), ['int'])),
                                        ('xps', (YLeaf(YType.enumeration, 'xps'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'PolicePpsBpsType', '')])),
                                    ])
                                    self.units = None
                                    self.xps = None

                                    self.burst = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Burst()
                                    self.burst.parent = self
                                    self._children_name_map["burst"] = "burst"

                                    self.peak_rate = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.PeakRate()
                                    self.peak_rate.parent = self
                                    self._children_name_map["peak_rate"] = "peak-rate"

                                    self.peak_burst = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.PeakBurst()
                                    self.peak_burst.parent = self
                                    self._children_name_map["peak_burst"] = "peak-burst"

                                    self.actions = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions()
                                    self.actions.parent = self
                                    self._children_name_map["actions"] = "actions"
                                    self._segment_path = lambda: "rate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate, ['units', 'xps'], name, value)


                                class Burst(Entity):
                                    """
                                    Specify 'burst' parameter
                                    
                                    .. attribute:: burst_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: burst_type
                                    
                                    	
                                    	**type**\:  :py:class:`PolicePacketsBytesType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.PolicePacketsBytesType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Burst, self).__init__()

                                        self.yang_name = "burst"
                                        self.yang_parent_name = "rate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('burst_value', (YLeaf(YType.uint32, 'burst-value'), ['int'])),
                                            ('burst_type', (YLeaf(YType.enumeration, 'burst-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'PolicePacketsBytesType', '')])),
                                        ])
                                        self.burst_value = None
                                        self.burst_type = None
                                        self._segment_path = lambda: "burst"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Burst, ['burst_value', 'burst_type'], name, value)


                                class PeakRate(Entity):
                                    """
                                    Specify peak rate
                                    
                                    .. attribute:: peak_rate_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..512000000
                                    
                                    .. attribute:: xps
                                    
                                    	
                                    	**type**\:  :py:class:`PolicePpsBpsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.PolicePpsBpsType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.PeakRate, self).__init__()

                                        self.yang_name = "peak-rate"
                                        self.yang_parent_name = "rate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peak_rate_value', (YLeaf(YType.uint32, 'peak-rate-value'), ['int'])),
                                            ('xps', (YLeaf(YType.enumeration, 'xps'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'PolicePpsBpsType', '')])),
                                        ])
                                        self.peak_rate_value = None
                                        self.xps = None
                                        self._segment_path = lambda: "peak-rate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.PeakRate, ['peak_rate_value', 'xps'], name, value)


                                class PeakBurst(Entity):
                                    """
                                    Specify 'peak\-burst' parameter for peak\-rate
                                    
                                    .. attribute:: burst_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: burst_type
                                    
                                    	
                                    	**type**\:  :py:class:`PolicePacketsBytesType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.PolicePacketsBytesType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.PeakBurst, self).__init__()

                                        self.yang_name = "peak-burst"
                                        self.yang_parent_name = "rate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('burst_value', (YLeaf(YType.uint32, 'burst-value'), ['int'])),
                                            ('burst_type', (YLeaf(YType.enumeration, 'burst-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'PolicePacketsBytesType', '')])),
                                        ])
                                        self.burst_value = None
                                        self.burst_type = None
                                        self._segment_path = lambda: "peak-burst"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.PeakBurst, ['burst_value', 'burst_type'], name, value)


                                class Actions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_set_clp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetClpTransmit>`
                                    
                                    .. attribute:: conform_set_cos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmit>`
                                    
                                    .. attribute:: conform_set_cos_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetCosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmitTable>`
                                    
                                    .. attribute:: conform_set_discard_class_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDiscardClassTransmit>`
                                    
                                    .. attribute:: conform_set_dscp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmit>`
                                    
                                    .. attribute:: conform_set_dscp_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmitTable>`
                                    
                                    .. attribute:: conform_set_frde_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetFrdeTransmit>`
                                    
                                    .. attribute:: conform_set_mpls_exp_imposition_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmit>`
                                    
                                    .. attribute:: conform_set_mpls_exp_imposition_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmitTable>`
                                    
                                    .. attribute:: conform_set_mpls_exp_topmost_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmit>`
                                    
                                    .. attribute:: conform_set_mpls_exp_topmost_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmitTable>`
                                    
                                    .. attribute:: conform_set_prec_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmit>`
                                    
                                    .. attribute:: conform_set_prec_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetPrecTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmitTable>`
                                    
                                    .. attribute:: conform_set_qos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmit>`
                                    
                                    .. attribute:: conform_set_qos_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetQosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmitTable>`
                                    
                                    .. attribute:: conform_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformTransmit>`
                                    
                                    .. attribute:: conform_drop
                                    
                                    	
                                    	**type**\:  :py:class:`ConformDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformDrop>`
                                    
                                    .. attribute:: exceed_dscp
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedDscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDscp>`
                                    
                                    .. attribute:: exceed_set_clp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetClpTransmit>`
                                    
                                    .. attribute:: exceed_set_cos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetCosTransmit>`
                                    
                                    .. attribute:: exceed_set_discard_class_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDiscardClassTransmit>`
                                    
                                    .. attribute:: exceed_set_dscp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit>`
                                    
                                    .. attribute:: exceed_set_dscp_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmitTable>`
                                    
                                    .. attribute:: exceed_set_frde_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetFrdeTransmit>`
                                    
                                    .. attribute:: exceed_set_mpls_exp_imposition_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpImpositionTransmit>`
                                    
                                    .. attribute:: exceed_set_mpls_exp_topmost_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpTopmostTransmit>`
                                    
                                    .. attribute:: exceed_set_prec_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetPrecTransmit>`
                                    
                                    .. attribute:: exceed_set_qos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetQosTransmit>`
                                    
                                    .. attribute:: exceed_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedTransmit>`
                                    
                                    .. attribute:: exceed_drop
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDrop>`
                                    
                                    .. attribute:: violate_set_clp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetClpTransmit>`
                                    
                                    .. attribute:: violate_set_cos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetCosTransmit>`
                                    
                                    .. attribute:: violate_set_discard_class_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDiscardClassTransmit>`
                                    
                                    .. attribute:: violate_set_dscp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDscpTransmit>`
                                    
                                    .. attribute:: violate_set_frde_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetFrdeTransmit>`
                                    
                                    .. attribute:: violate_set_mpls_exp_imposition_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpImpositionTransmit>`
                                    
                                    .. attribute:: violate_set_mpls_exp_topmost_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpTopmostTransmit>`
                                    
                                    .. attribute:: violate_set_prec_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetPrecTransmit>`
                                    
                                    .. attribute:: violate_set_qos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetQosTransmit>`
                                    
                                    .. attribute:: violate_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateTransmit>`
                                    
                                    .. attribute:: violate_drop
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateDrop>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions, self).__init__()

                                        self.yang_name = "actions"
                                        self.yang_parent_name = "rate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-set-clp-transmit", ("conform_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetClpTransmit)), ("conform-set-cos-transmit", ("conform_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmit)), ("conform-set-cos-transmit-table", ("conform_set_cos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmitTable)), ("conform-set-discard-class-transmit", ("conform_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDiscardClassTransmit)), ("conform-set-dscp-transmit", ("conform_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmit)), ("conform-set-dscp-transmit-table", ("conform_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmitTable)), ("conform-set-frde-transmit", ("conform_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetFrdeTransmit)), ("conform-set-mpls-exp-imposition-transmit", ("conform_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmit)), ("conform-set-mpls-exp-imposition-transmit-table", ("conform_set_mpls_exp_imposition_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmitTable)), ("conform-set-mpls-exp-topmost-transmit", ("conform_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmit)), ("conform-set-mpls-exp-topmost-transmit-table", ("conform_set_mpls_exp_topmost_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmitTable)), ("conform-set-prec-transmit", ("conform_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmit)), ("conform-set-prec-transmit-table", ("conform_set_prec_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmitTable)), ("conform-set-qos-transmit", ("conform_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmit)), ("conform-set-qos-transmit-table", ("conform_set_qos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmitTable)), ("conform-transmit", ("conform_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformTransmit)), ("conform-drop", ("conform_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformDrop)), ("exceed-dscp", ("exceed_dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDscp)), ("exceed-set-clp-transmit", ("exceed_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetClpTransmit)), ("exceed-set-cos-transmit", ("exceed_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetCosTransmit)), ("exceed-set-discard-class-transmit", ("exceed_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDiscardClassTransmit)), ("exceed-set-dscp-transmit", ("exceed_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit)), ("exceed-set-dscp-transmit-table", ("exceed_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmitTable)), ("exceed-set-frde-transmit", ("exceed_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetFrdeTransmit)), ("exceed-set-mpls-exp-imposition-transmit", ("exceed_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpImpositionTransmit)), ("exceed-set-mpls-exp-topmost-transmit", ("exceed_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpTopmostTransmit)), ("exceed-set-prec-transmit", ("exceed_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetPrecTransmit)), ("exceed-set-qos-transmit", ("exceed_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetQosTransmit)), ("exceed-transmit", ("exceed_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedTransmit)), ("exceed-drop", ("exceed_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDrop)), ("violate-set-clp-transmit", ("violate_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetClpTransmit)), ("violate-set-cos-transmit", ("violate_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetCosTransmit)), ("violate-set-discard-class-transmit", ("violate_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDiscardClassTransmit)), ("violate-set-dscp-transmit", ("violate_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDscpTransmit)), ("violate-set-frde-transmit", ("violate_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetFrdeTransmit)), ("violate-set-mpls-exp-imposition-transmit", ("violate_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpImpositionTransmit)), ("violate-set-mpls-exp-topmost-transmit", ("violate_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpTopmostTransmit)), ("violate-set-prec-transmit", ("violate_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetPrecTransmit)), ("violate-set-qos-transmit", ("violate_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetQosTransmit)), ("violate-transmit", ("violate_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateTransmit)), ("violate-drop", ("violate_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateDrop))])
                                        self._leafs = OrderedDict()

                                        self.conform_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetClpTransmit()
                                        self.conform_set_clp_transmit.parent = self
                                        self._children_name_map["conform_set_clp_transmit"] = "conform-set-clp-transmit"

                                        self.conform_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmit()
                                        self.conform_set_cos_transmit.parent = self
                                        self._children_name_map["conform_set_cos_transmit"] = "conform-set-cos-transmit"

                                        self.conform_set_cos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmitTable()
                                        self.conform_set_cos_transmit_table.parent = self
                                        self._children_name_map["conform_set_cos_transmit_table"] = "conform-set-cos-transmit-table"

                                        self.conform_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDiscardClassTransmit()
                                        self.conform_set_discard_class_transmit.parent = self
                                        self._children_name_map["conform_set_discard_class_transmit"] = "conform-set-discard-class-transmit"

                                        self.conform_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmit()
                                        self.conform_set_dscp_transmit.parent = self
                                        self._children_name_map["conform_set_dscp_transmit"] = "conform-set-dscp-transmit"

                                        self.conform_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmitTable()
                                        self.conform_set_dscp_transmit_table.parent = self
                                        self._children_name_map["conform_set_dscp_transmit_table"] = "conform-set-dscp-transmit-table"

                                        self.conform_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetFrdeTransmit()
                                        self.conform_set_frde_transmit.parent = self
                                        self._children_name_map["conform_set_frde_transmit"] = "conform-set-frde-transmit"

                                        self.conform_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmit()
                                        self.conform_set_mpls_exp_imposition_transmit.parent = self
                                        self._children_name_map["conform_set_mpls_exp_imposition_transmit"] = "conform-set-mpls-exp-imposition-transmit"

                                        self.conform_set_mpls_exp_imposition_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmitTable()
                                        self.conform_set_mpls_exp_imposition_transmit_table.parent = self
                                        self._children_name_map["conform_set_mpls_exp_imposition_transmit_table"] = "conform-set-mpls-exp-imposition-transmit-table"

                                        self.conform_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmit()
                                        self.conform_set_mpls_exp_topmost_transmit.parent = self
                                        self._children_name_map["conform_set_mpls_exp_topmost_transmit"] = "conform-set-mpls-exp-topmost-transmit"

                                        self.conform_set_mpls_exp_topmost_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmitTable()
                                        self.conform_set_mpls_exp_topmost_transmit_table.parent = self
                                        self._children_name_map["conform_set_mpls_exp_topmost_transmit_table"] = "conform-set-mpls-exp-topmost-transmit-table"

                                        self.conform_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmit()
                                        self.conform_set_prec_transmit.parent = self
                                        self._children_name_map["conform_set_prec_transmit"] = "conform-set-prec-transmit"

                                        self.conform_set_prec_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmitTable()
                                        self.conform_set_prec_transmit_table.parent = self
                                        self._children_name_map["conform_set_prec_transmit_table"] = "conform-set-prec-transmit-table"

                                        self.conform_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmit()
                                        self.conform_set_qos_transmit.parent = self
                                        self._children_name_map["conform_set_qos_transmit"] = "conform-set-qos-transmit"

                                        self.conform_set_qos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmitTable()
                                        self.conform_set_qos_transmit_table.parent = self
                                        self._children_name_map["conform_set_qos_transmit_table"] = "conform-set-qos-transmit-table"

                                        self.conform_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformTransmit()
                                        self.conform_transmit.parent = self
                                        self._children_name_map["conform_transmit"] = "conform-transmit"

                                        self.conform_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformDrop()
                                        self.conform_drop.parent = self
                                        self._children_name_map["conform_drop"] = "conform-drop"

                                        self.exceed_dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDscp()
                                        self.exceed_dscp.parent = self
                                        self._children_name_map["exceed_dscp"] = "exceed-dscp"

                                        self.exceed_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetClpTransmit()
                                        self.exceed_set_clp_transmit.parent = self
                                        self._children_name_map["exceed_set_clp_transmit"] = "exceed-set-clp-transmit"

                                        self.exceed_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetCosTransmit()
                                        self.exceed_set_cos_transmit.parent = self
                                        self._children_name_map["exceed_set_cos_transmit"] = "exceed-set-cos-transmit"

                                        self.exceed_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDiscardClassTransmit()
                                        self.exceed_set_discard_class_transmit.parent = self
                                        self._children_name_map["exceed_set_discard_class_transmit"] = "exceed-set-discard-class-transmit"

                                        self.exceed_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit()
                                        self.exceed_set_dscp_transmit.parent = self
                                        self._children_name_map["exceed_set_dscp_transmit"] = "exceed-set-dscp-transmit"

                                        self.exceed_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmitTable()
                                        self.exceed_set_dscp_transmit_table.parent = self
                                        self._children_name_map["exceed_set_dscp_transmit_table"] = "exceed-set-dscp-transmit-table"

                                        self.exceed_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetFrdeTransmit()
                                        self.exceed_set_frde_transmit.parent = self
                                        self._children_name_map["exceed_set_frde_transmit"] = "exceed-set-frde-transmit"

                                        self.exceed_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpImpositionTransmit()
                                        self.exceed_set_mpls_exp_imposition_transmit.parent = self
                                        self._children_name_map["exceed_set_mpls_exp_imposition_transmit"] = "exceed-set-mpls-exp-imposition-transmit"

                                        self.exceed_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpTopmostTransmit()
                                        self.exceed_set_mpls_exp_topmost_transmit.parent = self
                                        self._children_name_map["exceed_set_mpls_exp_topmost_transmit"] = "exceed-set-mpls-exp-topmost-transmit"

                                        self.exceed_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetPrecTransmit()
                                        self.exceed_set_prec_transmit.parent = self
                                        self._children_name_map["exceed_set_prec_transmit"] = "exceed-set-prec-transmit"

                                        self.exceed_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetQosTransmit()
                                        self.exceed_set_qos_transmit.parent = self
                                        self._children_name_map["exceed_set_qos_transmit"] = "exceed-set-qos-transmit"

                                        self.exceed_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedTransmit()
                                        self.exceed_transmit.parent = self
                                        self._children_name_map["exceed_transmit"] = "exceed-transmit"

                                        self.exceed_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDrop()
                                        self.exceed_drop.parent = self
                                        self._children_name_map["exceed_drop"] = "exceed-drop"

                                        self.violate_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetClpTransmit()
                                        self.violate_set_clp_transmit.parent = self
                                        self._children_name_map["violate_set_clp_transmit"] = "violate-set-clp-transmit"

                                        self.violate_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetCosTransmit()
                                        self.violate_set_cos_transmit.parent = self
                                        self._children_name_map["violate_set_cos_transmit"] = "violate-set-cos-transmit"

                                        self.violate_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDiscardClassTransmit()
                                        self.violate_set_discard_class_transmit.parent = self
                                        self._children_name_map["violate_set_discard_class_transmit"] = "violate-set-discard-class-transmit"

                                        self.violate_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDscpTransmit()
                                        self.violate_set_dscp_transmit.parent = self
                                        self._children_name_map["violate_set_dscp_transmit"] = "violate-set-dscp-transmit"

                                        self.violate_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetFrdeTransmit()
                                        self.violate_set_frde_transmit.parent = self
                                        self._children_name_map["violate_set_frde_transmit"] = "violate-set-frde-transmit"

                                        self.violate_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpImpositionTransmit()
                                        self.violate_set_mpls_exp_imposition_transmit.parent = self
                                        self._children_name_map["violate_set_mpls_exp_imposition_transmit"] = "violate-set-mpls-exp-imposition-transmit"

                                        self.violate_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpTopmostTransmit()
                                        self.violate_set_mpls_exp_topmost_transmit.parent = self
                                        self._children_name_map["violate_set_mpls_exp_topmost_transmit"] = "violate-set-mpls-exp-topmost-transmit"

                                        self.violate_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetPrecTransmit()
                                        self.violate_set_prec_transmit.parent = self
                                        self._children_name_map["violate_set_prec_transmit"] = "violate-set-prec-transmit"

                                        self.violate_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetQosTransmit()
                                        self.violate_set_qos_transmit.parent = self
                                        self._children_name_map["violate_set_qos_transmit"] = "violate-set-qos-transmit"

                                        self.violate_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateTransmit()
                                        self.violate_transmit.parent = self
                                        self._children_name_map["violate_transmit"] = "violate-transmit"

                                        self.violate_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateDrop()
                                        self.violate_drop.parent = self
                                        self._children_name_map["violate_drop"] = "violate-drop"
                                        self._segment_path = lambda: "actions"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions, [], name, value)


                                    class ConformSetClpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetClpTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetClpTransmit, self).__init__()

                                            self.yang_name = "conform-set-clp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetClpTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetClpTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-clp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetClpTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_clp_transmit
                                            
                                            	set atm clp and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetClpTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-clp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                ])
                                                self.set_clp_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetClpTransmit.ConformAction, ['set_clp_transmit'], name, value)


                                    class ConformSetCosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmit, self).__init__()

                                            self.yang_name = "conform-set-cos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-cos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_cos_transmit
                                            
                                            	rewrite packet cos and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-cos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                ])
                                                self.set_cos_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmit.ConformAction, ['set_cos_transmit'], name, value)


                                    class ConformSetCosTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-cos-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-cos-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_cos_transmit
                                            
                                            	rewrite packet cos and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-cos-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_cos_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetCosTransmitTable.ConformAction, ['set_cos_transmit', 'table'], name, value)


                                    class ConformSetDiscardClassTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDiscardClassTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDiscardClassTransmit, self).__init__()

                                            self.yang_name = "conform-set-discard-class-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDiscardClassTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDiscardClassTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-discard-class-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDiscardClassTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_discard_class_transmit
                                            
                                            	set discard\-class and send it
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDiscardClassTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-discard-class-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                ])
                                                self.set_discard_class_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDiscardClassTransmit.ConformAction, ['set_discard_class_transmit'], name, value)


                                    class ConformSetDscpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmit, self).__init__()

                                            self.yang_name = "conform-set-dscp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-dscp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_dscp_transmit
                                            
                                            	set dscp and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..63
                                            
                                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-dscp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ])
                                                self.set_dscp_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmit.ConformAction, ['set_dscp_transmit'], name, value)


                                    class ConformSetDscpTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-dscp-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-dscp-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_dscp_transmit
                                            
                                            	set dscp and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..63
                                            
                                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-dscp-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_dscp_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetDscpTransmitTable.ConformAction, ['set_dscp_transmit', 'table'], name, value)


                                    class ConformSetFrdeTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetFrdeTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetFrdeTransmit, self).__init__()

                                            self.yang_name = "conform-set-frde-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetFrdeTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetFrdeTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-frde-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetFrdeTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_frde_transmit
                                            
                                            	set FR DE and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetFrdeTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-frde-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                ])
                                                self.set_frde_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetFrdeTransmit.ConformAction, ['set_frde_transmit'], name, value)


                                    class ConformSetMplsExpImpositionTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmit, self).__init__()

                                            self.yang_name = "conform-set-mpls-exp-imposition-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_mpls_exp_imposition_transmit
                                            
                                            	set exp at tag imposition and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_imposition_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                    class ConformSetMplsExpImpositionTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-mpls-exp-imposition-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_mpls_exp_imposition_transmit
                                            
                                            	set exp at tag imposition and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_mpls_exp_imposition_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, ['set_mpls_exp_imposition_transmit', 'table'], name, value)


                                    class ConformSetMplsExpTopmostTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmit, self).__init__()

                                            self.yang_name = "conform-set-mpls-exp-topmost-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_mpls_exp_topmost_transmit
                                            
                                            	set exp on topmost label and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_topmost_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                    class ConformSetMplsExpTopmostTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-mpls-exp-topmost-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_mpls_exp_topmost_transmit
                                            
                                            	set exp on topmost label and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_mpls_exp_topmost_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, ['set_mpls_exp_topmost_transmit', 'table'], name, value)


                                    class ConformSetPrecTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmit, self).__init__()

                                            self.yang_name = "conform-set-prec-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-prec-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_prec_transmit
                                            
                                            	rewrite packet precedence and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-prec-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                ])
                                                self.set_prec_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmit.ConformAction, ['set_prec_transmit'], name, value)


                                    class ConformSetPrecTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-prec-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-prec-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_prec_transmit
                                            
                                            	rewrite packet precedence and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-prec-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_prec_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetPrecTransmitTable.ConformAction, ['set_prec_transmit', 'table'], name, value)


                                    class ConformSetQosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmit, self).__init__()

                                            self.yang_name = "conform-set-qos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-qos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_qos_transmit
                                            
                                            	set qos\-group and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..99
                                            
                                            		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-qos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                ])
                                                self.set_qos_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmit.ConformAction, ['set_qos_transmit'], name, value)


                                    class ConformSetQosTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-qos-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-qos-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_qos_transmit
                                            
                                            	set qos\-group and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..99
                                            
                                            		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-qos-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_qos_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformSetQosTransmitTable.ConformAction, ['set_qos_transmit', 'table'], name, value)


                                    class ConformTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformTransmit, self).__init__()

                                            self.yang_name = "conform-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: transmit
                                            
                                            	transmit packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                ])
                                                self.transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformTransmit.ConformAction, ['transmit'], name, value)


                                    class ConformDrop(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformDrop.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformDrop, self).__init__()

                                            self.yang_name = "conform-drop"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformDrop.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformDrop.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformDrop, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: drop
                                            
                                            	drop packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformDrop.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-drop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ])
                                                self.drop = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ConformDrop.ConformAction, ['drop'], name, value)


                                    class ExceedDscp(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDscp.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDscp, self).__init__()

                                            self.yang_name = "exceed-dscp"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDscp.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDscp.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-dscp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDscp, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: dscp
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..63
                                            
                                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDscp.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-dscp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ])
                                                self.dscp = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDscp.ExceedAction, ['dscp'], name, value)


                                    class ExceedSetClpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetClpTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetClpTransmit, self).__init__()

                                            self.yang_name = "exceed-set-clp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetClpTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetClpTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-clp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetClpTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_clp_transmit
                                            
                                            	set atm clp and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetClpTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-clp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                ])
                                                self.set_clp_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetClpTransmit.ExceedAction, ['set_clp_transmit'], name, value)


                                    class ExceedSetCosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetCosTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetCosTransmit, self).__init__()

                                            self.yang_name = "exceed-set-cos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetCosTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetCosTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-cos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetCosTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_cos_transmit
                                            
                                            	rewrite packet cos and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetCosTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-cos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_cos_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetCosTransmit.ExceedAction, ['set_cos_transmit', 'table'], name, value)


                                    class ExceedSetDiscardClassTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDiscardClassTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDiscardClassTransmit, self).__init__()

                                            self.yang_name = "exceed-set-discard-class-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDiscardClassTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDiscardClassTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-discard-class-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDiscardClassTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_discard_class_transmit
                                            
                                            	set discard\-class and send it
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDiscardClassTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-discard-class-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                ])
                                                self.set_discard_class_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDiscardClassTransmit.ExceedAction, ['set_discard_class_transmit'], name, value)


                                    class ExceedSetDscpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit, self).__init__()

                                            self.yang_name = "exceed-set-dscp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-dscp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_dscp_transmit
                                            
                                            	
                                            	**type**\:  :py:class:`SetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-dscp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("set-dscp-transmit", ("set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit))])
                                                self._leafs = OrderedDict()

                                                self.set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit()
                                                self.set_dscp_transmit.parent = self
                                                self._children_name_map["set_dscp_transmit"] = "set-dscp-transmit"
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction, [], name, value)


                                            class SetDscpTransmit(Entity):
                                                """
                                                
                                                
                                                .. attribute:: dscp
                                                
                                                	
                                                	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, self).__init__()

                                                    self.yang_name = "set-dscp-transmit"
                                                    self.yang_parent_name = "exceed-action"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp))])
                                                    self._leafs = OrderedDict()

                                                    self.dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp()
                                                    self.dscp.parent = self
                                                    self._children_name_map["dscp"] = "dscp"
                                                    self._segment_path = lambda: "set-dscp-transmit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, [], name, value)


                                                class Dscp(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: table
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Table <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-policy'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, self).__init__()

                                                        self.yang_name = "dscp"
                                                        self.yang_parent_name = "set-dscp-transmit"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('table', (YLeaf(YType.enumeration, 'table'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table')])),
                                                        ])
                                                        self.table = None
                                                        self._segment_path = lambda: "dscp"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, ['table'], name, value)

                                                    class Table(Enum):
                                                        """
                                                        Table (Enum Class)

                                                        .. data:: policed_dscp = 0

                                                        """

                                                        policed_dscp = Enum.YLeaf(0, "policed-dscp")



                                    class ExceedSetDscpTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmitTable.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmitTable, self).__init__()

                                            self.yang_name = "exceed-set-dscp-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmitTable.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmitTable.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-dscp-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmitTable, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_dscp_transmit
                                            
                                            	set dscp and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..63
                                            
                                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmitTable.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-dscp-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_dscp_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetDscpTransmitTable.ExceedAction, ['set_dscp_transmit', 'table'], name, value)


                                    class ExceedSetFrdeTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetFrdeTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetFrdeTransmit, self).__init__()

                                            self.yang_name = "exceed-set-frde-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetFrdeTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetFrdeTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-frde-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetFrdeTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_frde_transmit
                                            
                                            	set FR DE and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetFrdeTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-frde-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                ])
                                                self.set_frde_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetFrdeTransmit.ExceedAction, ['set_frde_transmit'], name, value)


                                    class ExceedSetMplsExpImpositionTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpImpositionTransmit, self).__init__()

                                            self.yang_name = "exceed-set-mpls-exp-imposition-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-mpls-exp-imposition-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpImpositionTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_mpls_exp_imposition_transmit
                                            
                                            	set exp at tag imposition and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-mpls-exp-imposition-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_imposition_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                    class ExceedSetMplsExpTopmostTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpTopmostTransmit, self).__init__()

                                            self.yang_name = "exceed-set-mpls-exp-topmost-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-mpls-exp-topmost-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpTopmostTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_mpls_exp_topmost_transmit
                                            
                                            	set exp on topmost label and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-mpls-exp-topmost-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_topmost_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                    class ExceedSetPrecTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetPrecTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetPrecTransmit, self).__init__()

                                            self.yang_name = "exceed-set-prec-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetPrecTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetPrecTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-prec-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetPrecTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_prec_transmit
                                            
                                            	rewrite packet precedence and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetPrecTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-prec-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_prec_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetPrecTransmit.ExceedAction, ['set_prec_transmit', 'table'], name, value)


                                    class ExceedSetQosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetQosTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetQosTransmit, self).__init__()

                                            self.yang_name = "exceed-set-qos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetQosTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetQosTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-qos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetQosTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_qos_transmit
                                            
                                            	set qos\-group and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..99
                                            
                                            		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetQosTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-qos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                ])
                                                self.set_qos_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedSetQosTransmit.ExceedAction, ['set_qos_transmit'], name, value)


                                    class ExceedTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedTransmit, self).__init__()

                                            self.yang_name = "exceed-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: transmit
                                            
                                            	transmit packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                ])
                                                self.transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedTransmit.ExceedAction, ['transmit'], name, value)


                                    class ExceedDrop(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDrop.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDrop, self).__init__()

                                            self.yang_name = "exceed-drop"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDrop.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDrop.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDrop, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: drop
                                            
                                            	drop packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDrop.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-drop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ])
                                                self.drop = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ExceedDrop.ExceedAction, ['drop'], name, value)


                                    class ViolateSetClpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetClpTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetClpTransmit, self).__init__()

                                            self.yang_name = "violate-set-clp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetClpTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetClpTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-clp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetClpTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_clp_transmit
                                            
                                            	set atm clp and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetClpTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-clp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                ])
                                                self.set_clp_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetClpTransmit.ViolateAction, ['set_clp_transmit'], name, value)


                                    class ViolateSetCosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetCosTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetCosTransmit, self).__init__()

                                            self.yang_name = "violate-set-cos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetCosTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetCosTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-cos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetCosTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_cos_transmit
                                            
                                            	rewrite packet cos and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetCosTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-cos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_cos_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetCosTransmit.ViolateAction, ['set_cos_transmit', 'table'], name, value)


                                    class ViolateSetDiscardClassTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDiscardClassTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDiscardClassTransmit, self).__init__()

                                            self.yang_name = "violate-set-discard-class-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDiscardClassTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDiscardClassTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-discard-class-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDiscardClassTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_discard_class_transmit
                                            
                                            	set discard\-class and send it
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDiscardClassTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-discard-class-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                ])
                                                self.set_discard_class_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDiscardClassTransmit.ViolateAction, ['set_discard_class_transmit'], name, value)


                                    class ViolateSetDscpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDscpTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDscpTransmit, self).__init__()

                                            self.yang_name = "violate-set-dscp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDscpTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDscpTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-dscp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDscpTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_dscp_transmit
                                            
                                            	set dscp and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..63
                                            
                                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDscpTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-dscp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_dscp_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetDscpTransmit.ViolateAction, ['set_dscp_transmit', 'table'], name, value)


                                    class ViolateSetFrdeTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetFrdeTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetFrdeTransmit, self).__init__()

                                            self.yang_name = "violate-set-frde-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetFrdeTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetFrdeTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-frde-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetFrdeTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_frde_transmit
                                            
                                            	set FR DE and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetFrdeTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-frde-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                ])
                                                self.set_frde_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetFrdeTransmit.ViolateAction, ['set_frde_transmit'], name, value)


                                    class ViolateSetMplsExpImpositionTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpImpositionTransmit, self).__init__()

                                            self.yang_name = "violate-set-mpls-exp-imposition-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-mpls-exp-imposition-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpImpositionTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_mpls_exp_imposition_transmit
                                            
                                            	set exp at tag imposition and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-mpls-exp-imposition-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_imposition_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                    class ViolateSetMplsExpTopmostTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpTopmostTransmit, self).__init__()

                                            self.yang_name = "violate-set-mpls-exp-topmost-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-mpls-exp-topmost-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpTopmostTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_mpls_exp_topmost_transmit
                                            
                                            	set exp on topmost label and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-mpls-exp-topmost-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_topmost_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                    class ViolateSetPrecTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetPrecTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetPrecTransmit, self).__init__()

                                            self.yang_name = "violate-set-prec-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetPrecTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetPrecTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-prec-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetPrecTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_prec_transmit
                                            
                                            	rewrite packet precedence and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetPrecTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-prec-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_prec_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetPrecTransmit.ViolateAction, ['set_prec_transmit', 'table'], name, value)


                                    class ViolateSetQosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetQosTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetQosTransmit, self).__init__()

                                            self.yang_name = "violate-set-qos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetQosTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetQosTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-qos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetQosTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_qos_transmit
                                            
                                            	set qos\-group and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..99
                                            
                                            		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetQosTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-qos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                ])
                                                self.set_qos_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateSetQosTransmit.ViolateAction, ['set_qos_transmit'], name, value)


                                    class ViolateTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateTransmit, self).__init__()

                                            self.yang_name = "violate-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: transmit
                                            
                                            	transmit packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                ])
                                                self.transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateTransmit.ViolateAction, ['transmit'], name, value)


                                    class ViolateDrop(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateDrop.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateDrop, self).__init__()

                                            self.yang_name = "violate-drop"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateDrop.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateDrop.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateDrop, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: drop
                                            
                                            	drop packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateDrop.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-drop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ])
                                                self.drop = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRateUnit.Police.Rate.Actions.ViolateDrop.ViolateAction, ['drop'], name, value)


                    class PoliceRatePercent(Entity):
                        """
                        
                        
                        .. attribute:: police
                        
                        	
                        	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent, self).__init__()

                            self.yang_name = "police-rate-percent"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("police", ("police", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police))])
                            self._leafs = OrderedDict()

                            self.police = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police()
                            self.police.parent = self
                            self._children_name_map["police"] = "police"
                            self._segment_path = lambda: "police-rate-percent"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent, [], name, value)


                        class Police(Entity):
                            """
                            
                            
                            .. attribute:: rate
                            
                            	Specify police rate
                            	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police, self).__init__()

                                self.yang_name = "police"
                                self.yang_parent_name = "police-rate-percent"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rate", ("rate", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate))])
                                self._leafs = OrderedDict()

                                self.rate = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate()
                                self.rate.parent = self
                                self._children_name_map["rate"] = "rate"
                                self._segment_path = lambda: "police"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police, [], name, value)


                            class Rate(Entity):
                                """
                                Specify police rate
                                
                                .. attribute:: percent
                                
                                	% of interface bandwidth for rate
                                	**type**\:  :py:class:`Percent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate, self).__init__()

                                    self.yang_name = "rate"
                                    self.yang_parent_name = "police"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("percent", ("percent", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent))])
                                    self._leafs = OrderedDict()

                                    self.percent = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent()
                                    self.percent.parent = self
                                    self._children_name_map["percent"] = "percent"
                                    self._segment_path = lambda: "rate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate, [], name, value)


                                class Percent(Entity):
                                    """
                                    % of interface bandwidth for rate
                                    
                                    .. attribute:: percentage
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: burst
                                    
                                    	Specify 'burst' parameter
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ms
                                    
                                    	Treat 'burst' value in milliseconds
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: peak_rate
                                    
                                    	Specify peak rate
                                    	**type**\:  :py:class:`PeakRate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.PeakRate>`
                                    
                                    .. attribute:: peak_burst
                                    
                                    	Specify 'peak\-burst' parameter for 'peak\-rate'
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: peak_burst_ms
                                    
                                    	
                                    	**type**\:  :py:class:`PeakBurstMs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.PeakBurstMs>`
                                    
                                    .. attribute:: actions
                                    
                                    	
                                    	**type**\:  :py:class:`Actions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent, self).__init__()

                                        self.yang_name = "percent"
                                        self.yang_parent_name = "rate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("peak-rate", ("peak_rate", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.PeakRate)), ("peak-burst-ms", ("peak_burst_ms", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.PeakBurstMs)), ("actions", ("actions", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions))])
                                        self._leafs = OrderedDict([
                                            ('percentage', (YLeaf(YType.uint8, 'percentage'), ['int'])),
                                            ('burst', (YLeaf(YType.uint16, 'burst'), ['int'])),
                                            ('ms', (YLeaf(YType.empty, 'ms'), ['Empty'])),
                                            ('peak_burst', (YLeaf(YType.uint16, 'peak-burst'), ['int'])),
                                        ])
                                        self.percentage = None
                                        self.burst = None
                                        self.ms = None
                                        self.peak_burst = None

                                        self.peak_rate = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.PeakRate()
                                        self.peak_rate.parent = self
                                        self._children_name_map["peak_rate"] = "peak-rate"

                                        self.peak_burst_ms = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.PeakBurstMs()
                                        self.peak_burst_ms.parent = self
                                        self._children_name_map["peak_burst_ms"] = "peak-burst-ms"

                                        self.actions = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions()
                                        self.actions.parent = self
                                        self._children_name_map["actions"] = "actions"
                                        self._segment_path = lambda: "percent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent, ['percentage', 'burst', 'ms', 'peak_burst'], name, value)


                                    class PeakRate(Entity):
                                        """
                                        Specify peak rate
                                        
                                        .. attribute:: percent
                                        
                                        	% of interface bandwidth for peak\-rate
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.PeakRate, self).__init__()

                                            self.yang_name = "peak-rate"
                                            self.yang_parent_name = "percent"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ])
                                            self.percent = None
                                            self._segment_path = lambda: "peak-rate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.PeakRate, ['percent'], name, value)


                                    class PeakBurstMs(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ms
                                        
                                        	Milli seconds
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.PeakBurstMs, self).__init__()

                                            self.yang_name = "peak-burst-ms"
                                            self.yang_parent_name = "percent"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ms', (YLeaf(YType.empty, 'ms'), ['Empty'])),
                                            ])
                                            self.ms = None
                                            self._segment_path = lambda: "peak-burst-ms"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.PeakBurstMs, ['ms'], name, value)


                                    class Actions(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_set_clp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetClpTransmit>`
                                        
                                        .. attribute:: conform_set_cos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmit>`
                                        
                                        .. attribute:: conform_set_cos_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetCosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmitTable>`
                                        
                                        .. attribute:: conform_set_discard_class_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDiscardClassTransmit>`
                                        
                                        .. attribute:: conform_set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmit>`
                                        
                                        .. attribute:: conform_set_dscp_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmitTable>`
                                        
                                        .. attribute:: conform_set_frde_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetFrdeTransmit>`
                                        
                                        .. attribute:: conform_set_mpls_exp_imposition_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmit>`
                                        
                                        .. attribute:: conform_set_mpls_exp_imposition_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmitTable>`
                                        
                                        .. attribute:: conform_set_mpls_exp_topmost_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmit>`
                                        
                                        .. attribute:: conform_set_mpls_exp_topmost_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmitTable>`
                                        
                                        .. attribute:: conform_set_prec_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmit>`
                                        
                                        .. attribute:: conform_set_prec_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetPrecTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmitTable>`
                                        
                                        .. attribute:: conform_set_qos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmit>`
                                        
                                        .. attribute:: conform_set_qos_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetQosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmitTable>`
                                        
                                        .. attribute:: conform_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformTransmit>`
                                        
                                        .. attribute:: conform_drop
                                        
                                        	
                                        	**type**\:  :py:class:`ConformDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformDrop>`
                                        
                                        .. attribute:: exceed_dscp
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedDscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDscp>`
                                        
                                        .. attribute:: exceed_set_clp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetClpTransmit>`
                                        
                                        .. attribute:: exceed_set_cos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetCosTransmit>`
                                        
                                        .. attribute:: exceed_set_discard_class_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDiscardClassTransmit>`
                                        
                                        .. attribute:: exceed_set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit>`
                                        
                                        .. attribute:: exceed_set_dscp_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmitTable>`
                                        
                                        .. attribute:: exceed_set_frde_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetFrdeTransmit>`
                                        
                                        .. attribute:: exceed_set_mpls_exp_imposition_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpImpositionTransmit>`
                                        
                                        .. attribute:: exceed_set_mpls_exp_topmost_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpTopmostTransmit>`
                                        
                                        .. attribute:: exceed_set_prec_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetPrecTransmit>`
                                        
                                        .. attribute:: exceed_set_qos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetQosTransmit>`
                                        
                                        .. attribute:: exceed_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedTransmit>`
                                        
                                        .. attribute:: exceed_drop
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDrop>`
                                        
                                        .. attribute:: violate_set_clp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetClpTransmit>`
                                        
                                        .. attribute:: violate_set_cos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetCosTransmit>`
                                        
                                        .. attribute:: violate_set_discard_class_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDiscardClassTransmit>`
                                        
                                        .. attribute:: violate_set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDscpTransmit>`
                                        
                                        .. attribute:: violate_set_frde_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetFrdeTransmit>`
                                        
                                        .. attribute:: violate_set_mpls_exp_imposition_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpImpositionTransmit>`
                                        
                                        .. attribute:: violate_set_mpls_exp_topmost_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpTopmostTransmit>`
                                        
                                        .. attribute:: violate_set_prec_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetPrecTransmit>`
                                        
                                        .. attribute:: violate_set_qos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetQosTransmit>`
                                        
                                        .. attribute:: violate_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateTransmit>`
                                        
                                        .. attribute:: violate_drop
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateDrop>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions, self).__init__()

                                            self.yang_name = "actions"
                                            self.yang_parent_name = "percent"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-set-clp-transmit", ("conform_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetClpTransmit)), ("conform-set-cos-transmit", ("conform_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmit)), ("conform-set-cos-transmit-table", ("conform_set_cos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmitTable)), ("conform-set-discard-class-transmit", ("conform_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDiscardClassTransmit)), ("conform-set-dscp-transmit", ("conform_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmit)), ("conform-set-dscp-transmit-table", ("conform_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmitTable)), ("conform-set-frde-transmit", ("conform_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetFrdeTransmit)), ("conform-set-mpls-exp-imposition-transmit", ("conform_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmit)), ("conform-set-mpls-exp-imposition-transmit-table", ("conform_set_mpls_exp_imposition_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmitTable)), ("conform-set-mpls-exp-topmost-transmit", ("conform_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmit)), ("conform-set-mpls-exp-topmost-transmit-table", ("conform_set_mpls_exp_topmost_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmitTable)), ("conform-set-prec-transmit", ("conform_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmit)), ("conform-set-prec-transmit-table", ("conform_set_prec_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmitTable)), ("conform-set-qos-transmit", ("conform_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmit)), ("conform-set-qos-transmit-table", ("conform_set_qos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmitTable)), ("conform-transmit", ("conform_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformTransmit)), ("conform-drop", ("conform_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformDrop)), ("exceed-dscp", ("exceed_dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDscp)), ("exceed-set-clp-transmit", ("exceed_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetClpTransmit)), ("exceed-set-cos-transmit", ("exceed_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetCosTransmit)), ("exceed-set-discard-class-transmit", ("exceed_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDiscardClassTransmit)), ("exceed-set-dscp-transmit", ("exceed_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit)), ("exceed-set-dscp-transmit-table", ("exceed_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmitTable)), ("exceed-set-frde-transmit", ("exceed_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetFrdeTransmit)), ("exceed-set-mpls-exp-imposition-transmit", ("exceed_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpImpositionTransmit)), ("exceed-set-mpls-exp-topmost-transmit", ("exceed_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpTopmostTransmit)), ("exceed-set-prec-transmit", ("exceed_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetPrecTransmit)), ("exceed-set-qos-transmit", ("exceed_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetQosTransmit)), ("exceed-transmit", ("exceed_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedTransmit)), ("exceed-drop", ("exceed_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDrop)), ("violate-set-clp-transmit", ("violate_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetClpTransmit)), ("violate-set-cos-transmit", ("violate_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetCosTransmit)), ("violate-set-discard-class-transmit", ("violate_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDiscardClassTransmit)), ("violate-set-dscp-transmit", ("violate_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDscpTransmit)), ("violate-set-frde-transmit", ("violate_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetFrdeTransmit)), ("violate-set-mpls-exp-imposition-transmit", ("violate_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpImpositionTransmit)), ("violate-set-mpls-exp-topmost-transmit", ("violate_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpTopmostTransmit)), ("violate-set-prec-transmit", ("violate_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetPrecTransmit)), ("violate-set-qos-transmit", ("violate_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetQosTransmit)), ("violate-transmit", ("violate_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateTransmit)), ("violate-drop", ("violate_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateDrop))])
                                            self._leafs = OrderedDict()

                                            self.conform_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetClpTransmit()
                                            self.conform_set_clp_transmit.parent = self
                                            self._children_name_map["conform_set_clp_transmit"] = "conform-set-clp-transmit"

                                            self.conform_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmit()
                                            self.conform_set_cos_transmit.parent = self
                                            self._children_name_map["conform_set_cos_transmit"] = "conform-set-cos-transmit"

                                            self.conform_set_cos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmitTable()
                                            self.conform_set_cos_transmit_table.parent = self
                                            self._children_name_map["conform_set_cos_transmit_table"] = "conform-set-cos-transmit-table"

                                            self.conform_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDiscardClassTransmit()
                                            self.conform_set_discard_class_transmit.parent = self
                                            self._children_name_map["conform_set_discard_class_transmit"] = "conform-set-discard-class-transmit"

                                            self.conform_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmit()
                                            self.conform_set_dscp_transmit.parent = self
                                            self._children_name_map["conform_set_dscp_transmit"] = "conform-set-dscp-transmit"

                                            self.conform_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmitTable()
                                            self.conform_set_dscp_transmit_table.parent = self
                                            self._children_name_map["conform_set_dscp_transmit_table"] = "conform-set-dscp-transmit-table"

                                            self.conform_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetFrdeTransmit()
                                            self.conform_set_frde_transmit.parent = self
                                            self._children_name_map["conform_set_frde_transmit"] = "conform-set-frde-transmit"

                                            self.conform_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmit()
                                            self.conform_set_mpls_exp_imposition_transmit.parent = self
                                            self._children_name_map["conform_set_mpls_exp_imposition_transmit"] = "conform-set-mpls-exp-imposition-transmit"

                                            self.conform_set_mpls_exp_imposition_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmitTable()
                                            self.conform_set_mpls_exp_imposition_transmit_table.parent = self
                                            self._children_name_map["conform_set_mpls_exp_imposition_transmit_table"] = "conform-set-mpls-exp-imposition-transmit-table"

                                            self.conform_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmit()
                                            self.conform_set_mpls_exp_topmost_transmit.parent = self
                                            self._children_name_map["conform_set_mpls_exp_topmost_transmit"] = "conform-set-mpls-exp-topmost-transmit"

                                            self.conform_set_mpls_exp_topmost_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmitTable()
                                            self.conform_set_mpls_exp_topmost_transmit_table.parent = self
                                            self._children_name_map["conform_set_mpls_exp_topmost_transmit_table"] = "conform-set-mpls-exp-topmost-transmit-table"

                                            self.conform_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmit()
                                            self.conform_set_prec_transmit.parent = self
                                            self._children_name_map["conform_set_prec_transmit"] = "conform-set-prec-transmit"

                                            self.conform_set_prec_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmitTable()
                                            self.conform_set_prec_transmit_table.parent = self
                                            self._children_name_map["conform_set_prec_transmit_table"] = "conform-set-prec-transmit-table"

                                            self.conform_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmit()
                                            self.conform_set_qos_transmit.parent = self
                                            self._children_name_map["conform_set_qos_transmit"] = "conform-set-qos-transmit"

                                            self.conform_set_qos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmitTable()
                                            self.conform_set_qos_transmit_table.parent = self
                                            self._children_name_map["conform_set_qos_transmit_table"] = "conform-set-qos-transmit-table"

                                            self.conform_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformTransmit()
                                            self.conform_transmit.parent = self
                                            self._children_name_map["conform_transmit"] = "conform-transmit"

                                            self.conform_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformDrop()
                                            self.conform_drop.parent = self
                                            self._children_name_map["conform_drop"] = "conform-drop"

                                            self.exceed_dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDscp()
                                            self.exceed_dscp.parent = self
                                            self._children_name_map["exceed_dscp"] = "exceed-dscp"

                                            self.exceed_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetClpTransmit()
                                            self.exceed_set_clp_transmit.parent = self
                                            self._children_name_map["exceed_set_clp_transmit"] = "exceed-set-clp-transmit"

                                            self.exceed_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetCosTransmit()
                                            self.exceed_set_cos_transmit.parent = self
                                            self._children_name_map["exceed_set_cos_transmit"] = "exceed-set-cos-transmit"

                                            self.exceed_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDiscardClassTransmit()
                                            self.exceed_set_discard_class_transmit.parent = self
                                            self._children_name_map["exceed_set_discard_class_transmit"] = "exceed-set-discard-class-transmit"

                                            self.exceed_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit()
                                            self.exceed_set_dscp_transmit.parent = self
                                            self._children_name_map["exceed_set_dscp_transmit"] = "exceed-set-dscp-transmit"

                                            self.exceed_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmitTable()
                                            self.exceed_set_dscp_transmit_table.parent = self
                                            self._children_name_map["exceed_set_dscp_transmit_table"] = "exceed-set-dscp-transmit-table"

                                            self.exceed_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetFrdeTransmit()
                                            self.exceed_set_frde_transmit.parent = self
                                            self._children_name_map["exceed_set_frde_transmit"] = "exceed-set-frde-transmit"

                                            self.exceed_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpImpositionTransmit()
                                            self.exceed_set_mpls_exp_imposition_transmit.parent = self
                                            self._children_name_map["exceed_set_mpls_exp_imposition_transmit"] = "exceed-set-mpls-exp-imposition-transmit"

                                            self.exceed_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpTopmostTransmit()
                                            self.exceed_set_mpls_exp_topmost_transmit.parent = self
                                            self._children_name_map["exceed_set_mpls_exp_topmost_transmit"] = "exceed-set-mpls-exp-topmost-transmit"

                                            self.exceed_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetPrecTransmit()
                                            self.exceed_set_prec_transmit.parent = self
                                            self._children_name_map["exceed_set_prec_transmit"] = "exceed-set-prec-transmit"

                                            self.exceed_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetQosTransmit()
                                            self.exceed_set_qos_transmit.parent = self
                                            self._children_name_map["exceed_set_qos_transmit"] = "exceed-set-qos-transmit"

                                            self.exceed_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedTransmit()
                                            self.exceed_transmit.parent = self
                                            self._children_name_map["exceed_transmit"] = "exceed-transmit"

                                            self.exceed_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDrop()
                                            self.exceed_drop.parent = self
                                            self._children_name_map["exceed_drop"] = "exceed-drop"

                                            self.violate_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetClpTransmit()
                                            self.violate_set_clp_transmit.parent = self
                                            self._children_name_map["violate_set_clp_transmit"] = "violate-set-clp-transmit"

                                            self.violate_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetCosTransmit()
                                            self.violate_set_cos_transmit.parent = self
                                            self._children_name_map["violate_set_cos_transmit"] = "violate-set-cos-transmit"

                                            self.violate_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDiscardClassTransmit()
                                            self.violate_set_discard_class_transmit.parent = self
                                            self._children_name_map["violate_set_discard_class_transmit"] = "violate-set-discard-class-transmit"

                                            self.violate_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDscpTransmit()
                                            self.violate_set_dscp_transmit.parent = self
                                            self._children_name_map["violate_set_dscp_transmit"] = "violate-set-dscp-transmit"

                                            self.violate_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetFrdeTransmit()
                                            self.violate_set_frde_transmit.parent = self
                                            self._children_name_map["violate_set_frde_transmit"] = "violate-set-frde-transmit"

                                            self.violate_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpImpositionTransmit()
                                            self.violate_set_mpls_exp_imposition_transmit.parent = self
                                            self._children_name_map["violate_set_mpls_exp_imposition_transmit"] = "violate-set-mpls-exp-imposition-transmit"

                                            self.violate_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpTopmostTransmit()
                                            self.violate_set_mpls_exp_topmost_transmit.parent = self
                                            self._children_name_map["violate_set_mpls_exp_topmost_transmit"] = "violate-set-mpls-exp-topmost-transmit"

                                            self.violate_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetPrecTransmit()
                                            self.violate_set_prec_transmit.parent = self
                                            self._children_name_map["violate_set_prec_transmit"] = "violate-set-prec-transmit"

                                            self.violate_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetQosTransmit()
                                            self.violate_set_qos_transmit.parent = self
                                            self._children_name_map["violate_set_qos_transmit"] = "violate-set-qos-transmit"

                                            self.violate_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateTransmit()
                                            self.violate_transmit.parent = self
                                            self._children_name_map["violate_transmit"] = "violate-transmit"

                                            self.violate_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateDrop()
                                            self.violate_drop.parent = self
                                            self._children_name_map["violate_drop"] = "violate-drop"
                                            self._segment_path = lambda: "actions"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions, [], name, value)


                                        class ConformSetClpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetClpTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetClpTransmit, self).__init__()

                                                self.yang_name = "conform-set-clp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetClpTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetClpTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-clp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetClpTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_clp_transmit
                                                
                                                	set atm clp and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetClpTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-clp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_clp_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetClpTransmit.ConformAction, ['set_clp_transmit'], name, value)


                                        class ConformSetCosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmit, self).__init__()

                                                self.yang_name = "conform-set-cos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-cos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-cos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmit.ConformAction, ['set_cos_transmit'], name, value)


                                        class ConformSetCosTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-cos-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-cos-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-cos-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetCosTransmitTable.ConformAction, ['set_cos_transmit', 'table'], name, value)


                                        class ConformSetDiscardClassTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDiscardClassTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDiscardClassTransmit, self).__init__()

                                                self.yang_name = "conform-set-discard-class-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDiscardClassTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDiscardClassTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-discard-class-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDiscardClassTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_discard_class_transmit
                                                
                                                	set discard\-class and send it
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDiscardClassTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-discard-class-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                    ])
                                                    self.set_discard_class_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDiscardClassTransmit.ConformAction, ['set_discard_class_transmit'], name, value)


                                        class ConformSetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmit, self).__init__()

                                                self.yang_name = "conform-set-dscp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmit.ConformAction, ['set_dscp_transmit'], name, value)


                                        class ConformSetDscpTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-dscp-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-dscp-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-dscp-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetDscpTransmitTable.ConformAction, ['set_dscp_transmit', 'table'], name, value)


                                        class ConformSetFrdeTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetFrdeTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetFrdeTransmit, self).__init__()

                                                self.yang_name = "conform-set-frde-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetFrdeTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetFrdeTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-frde-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetFrdeTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_frde_transmit
                                                
                                                	set FR DE and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetFrdeTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-frde-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_frde_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetFrdeTransmit.ConformAction, ['set_frde_transmit'], name, value)


                                        class ConformSetMplsExpImpositionTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmit, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-imposition-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                        class ConformSetMplsExpImpositionTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-imposition-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, ['set_mpls_exp_imposition_transmit', 'table'], name, value)


                                        class ConformSetMplsExpTopmostTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmit, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-topmost-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                        class ConformSetMplsExpTopmostTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-topmost-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, ['set_mpls_exp_topmost_transmit', 'table'], name, value)


                                        class ConformSetPrecTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmit, self).__init__()

                                                self.yang_name = "conform-set-prec-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-prec-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-prec-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmit.ConformAction, ['set_prec_transmit'], name, value)


                                        class ConformSetPrecTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-prec-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-prec-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-prec-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetPrecTransmitTable.ConformAction, ['set_prec_transmit', 'table'], name, value)


                                        class ConformSetQosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmit, self).__init__()

                                                self.yang_name = "conform-set-qos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-qos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-qos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmit.ConformAction, ['set_qos_transmit'], name, value)


                                        class ConformSetQosTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-qos-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-qos-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-qos-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformSetQosTransmitTable.ConformAction, ['set_qos_transmit', 'table'], name, value)


                                        class ConformTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformTransmit, self).__init__()

                                                self.yang_name = "conform-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: transmit
                                                
                                                	transmit packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                    ])
                                                    self.transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformTransmit.ConformAction, ['transmit'], name, value)


                                        class ConformDrop(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformDrop.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformDrop, self).__init__()

                                                self.yang_name = "conform-drop"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformDrop.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformDrop.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformDrop, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: drop
                                                
                                                	drop packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformDrop.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ])
                                                    self.drop = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ConformDrop.ConformAction, ['drop'], name, value)


                                        class ExceedDscp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDscp.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDscp, self).__init__()

                                                self.yang_name = "exceed-dscp"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDscp.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDscp.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-dscp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDscp, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: dscp
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDscp.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-dscp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ])
                                                    self.dscp = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDscp.ExceedAction, ['dscp'], name, value)


                                        class ExceedSetClpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetClpTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetClpTransmit, self).__init__()

                                                self.yang_name = "exceed-set-clp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetClpTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetClpTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-clp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetClpTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_clp_transmit
                                                
                                                	set atm clp and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetClpTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-clp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_clp_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetClpTransmit.ExceedAction, ['set_clp_transmit'], name, value)


                                        class ExceedSetCosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetCosTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetCosTransmit, self).__init__()

                                                self.yang_name = "exceed-set-cos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetCosTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetCosTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-cos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetCosTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetCosTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-cos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetCosTransmit.ExceedAction, ['set_cos_transmit', 'table'], name, value)


                                        class ExceedSetDiscardClassTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDiscardClassTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDiscardClassTransmit, self).__init__()

                                                self.yang_name = "exceed-set-discard-class-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDiscardClassTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDiscardClassTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-discard-class-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDiscardClassTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_discard_class_transmit
                                                
                                                	set discard\-class and send it
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDiscardClassTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-discard-class-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                    ])
                                                    self.set_discard_class_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDiscardClassTransmit.ExceedAction, ['set_discard_class_transmit'], name, value)


                                        class ExceedSetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit, self).__init__()

                                                self.yang_name = "exceed-set-dscp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	
                                                	**type**\:  :py:class:`SetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("set-dscp-transmit", ("set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit))])
                                                    self._leafs = OrderedDict()

                                                    self.set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit()
                                                    self.set_dscp_transmit.parent = self
                                                    self._children_name_map["set_dscp_transmit"] = "set-dscp-transmit"
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction, [], name, value)


                                                class SetDscpTransmit(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: dscp
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-policy'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, self).__init__()

                                                        self.yang_name = "set-dscp-transmit"
                                                        self.yang_parent_name = "exceed-action"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp))])
                                                        self._leafs = OrderedDict()

                                                        self.dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp()
                                                        self.dscp.parent = self
                                                        self._children_name_map["dscp"] = "dscp"
                                                        self._segment_path = lambda: "set-dscp-transmit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, [], name, value)


                                                    class Dscp(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: table
                                                        
                                                        	
                                                        	**type**\:  :py:class:`Table <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-policy'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, self).__init__()

                                                            self.yang_name = "dscp"
                                                            self.yang_parent_name = "set-dscp-transmit"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('table', (YLeaf(YType.enumeration, 'table'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table')])),
                                                            ])
                                                            self.table = None
                                                            self._segment_path = lambda: "dscp"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, ['table'], name, value)

                                                        class Table(Enum):
                                                            """
                                                            Table (Enum Class)

                                                            .. data:: policed_dscp = 0

                                                            """

                                                            policed_dscp = Enum.YLeaf(0, "policed-dscp")



                                        class ExceedSetDscpTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmitTable.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmitTable, self).__init__()

                                                self.yang_name = "exceed-set-dscp-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmitTable.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmitTable.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-dscp-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmitTable, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmitTable.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-dscp-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetDscpTransmitTable.ExceedAction, ['set_dscp_transmit', 'table'], name, value)


                                        class ExceedSetFrdeTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetFrdeTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetFrdeTransmit, self).__init__()

                                                self.yang_name = "exceed-set-frde-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetFrdeTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetFrdeTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-frde-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetFrdeTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_frde_transmit
                                                
                                                	set FR DE and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetFrdeTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-frde-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_frde_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetFrdeTransmit.ExceedAction, ['set_frde_transmit'], name, value)


                                        class ExceedSetMplsExpImpositionTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpImpositionTransmit, self).__init__()

                                                self.yang_name = "exceed-set-mpls-exp-imposition-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-mpls-exp-imposition-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpImpositionTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-mpls-exp-imposition-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                        class ExceedSetMplsExpTopmostTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpTopmostTransmit, self).__init__()

                                                self.yang_name = "exceed-set-mpls-exp-topmost-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-mpls-exp-topmost-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpTopmostTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-mpls-exp-topmost-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                        class ExceedSetPrecTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetPrecTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetPrecTransmit, self).__init__()

                                                self.yang_name = "exceed-set-prec-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetPrecTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetPrecTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-prec-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetPrecTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetPrecTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-prec-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetPrecTransmit.ExceedAction, ['set_prec_transmit', 'table'], name, value)


                                        class ExceedSetQosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetQosTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetQosTransmit, self).__init__()

                                                self.yang_name = "exceed-set-qos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetQosTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetQosTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-qos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetQosTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetQosTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-qos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedSetQosTransmit.ExceedAction, ['set_qos_transmit'], name, value)


                                        class ExceedTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedTransmit, self).__init__()

                                                self.yang_name = "exceed-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: transmit
                                                
                                                	transmit packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                    ])
                                                    self.transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedTransmit.ExceedAction, ['transmit'], name, value)


                                        class ExceedDrop(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDrop.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDrop, self).__init__()

                                                self.yang_name = "exceed-drop"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDrop.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDrop.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDrop, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: drop
                                                
                                                	drop packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDrop.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ])
                                                    self.drop = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ExceedDrop.ExceedAction, ['drop'], name, value)


                                        class ViolateSetClpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetClpTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetClpTransmit, self).__init__()

                                                self.yang_name = "violate-set-clp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetClpTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetClpTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-clp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetClpTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_clp_transmit
                                                
                                                	set atm clp and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetClpTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-clp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_clp_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetClpTransmit.ViolateAction, ['set_clp_transmit'], name, value)


                                        class ViolateSetCosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetCosTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetCosTransmit, self).__init__()

                                                self.yang_name = "violate-set-cos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetCosTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetCosTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-cos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetCosTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetCosTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-cos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetCosTransmit.ViolateAction, ['set_cos_transmit', 'table'], name, value)


                                        class ViolateSetDiscardClassTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDiscardClassTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDiscardClassTransmit, self).__init__()

                                                self.yang_name = "violate-set-discard-class-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDiscardClassTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDiscardClassTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-discard-class-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDiscardClassTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_discard_class_transmit
                                                
                                                	set discard\-class and send it
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDiscardClassTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-discard-class-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                    ])
                                                    self.set_discard_class_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDiscardClassTransmit.ViolateAction, ['set_discard_class_transmit'], name, value)


                                        class ViolateSetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDscpTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDscpTransmit, self).__init__()

                                                self.yang_name = "violate-set-dscp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDscpTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDscpTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDscpTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDscpTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetDscpTransmit.ViolateAction, ['set_dscp_transmit', 'table'], name, value)


                                        class ViolateSetFrdeTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetFrdeTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetFrdeTransmit, self).__init__()

                                                self.yang_name = "violate-set-frde-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetFrdeTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetFrdeTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-frde-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetFrdeTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_frde_transmit
                                                
                                                	set FR DE and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetFrdeTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-frde-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_frde_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetFrdeTransmit.ViolateAction, ['set_frde_transmit'], name, value)


                                        class ViolateSetMplsExpImpositionTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpImpositionTransmit, self).__init__()

                                                self.yang_name = "violate-set-mpls-exp-imposition-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-mpls-exp-imposition-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpImpositionTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-mpls-exp-imposition-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                        class ViolateSetMplsExpTopmostTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpTopmostTransmit, self).__init__()

                                                self.yang_name = "violate-set-mpls-exp-topmost-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-mpls-exp-topmost-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpTopmostTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-mpls-exp-topmost-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                        class ViolateSetPrecTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetPrecTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetPrecTransmit, self).__init__()

                                                self.yang_name = "violate-set-prec-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetPrecTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetPrecTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-prec-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetPrecTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetPrecTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-prec-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetPrecTransmit.ViolateAction, ['set_prec_transmit', 'table'], name, value)


                                        class ViolateSetQosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetQosTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetQosTransmit, self).__init__()

                                                self.yang_name = "violate-set-qos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetQosTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetQosTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-qos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetQosTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetQosTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-qos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateSetQosTransmit.ViolateAction, ['set_qos_transmit'], name, value)


                                        class ViolateTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateTransmit, self).__init__()

                                                self.yang_name = "violate-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: transmit
                                                
                                                	transmit packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                    ])
                                                    self.transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateTransmit.ViolateAction, ['transmit'], name, value)


                                        class ViolateDrop(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateDrop.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateDrop, self).__init__()

                                                self.yang_name = "violate-drop"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateDrop.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateDrop.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateDrop, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: drop
                                                
                                                	drop packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateDrop.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ])
                                                    self.drop = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePercent.Police.Rate.Percent.Actions.ViolateDrop.ViolateAction, ['drop'], name, value)


                    class PoliceRatePdp(Entity):
                        """
                        
                        
                        .. attribute:: police
                        
                        	
                        	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp, self).__init__()

                            self.yang_name = "police-rate-pdp"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("police", ("police", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police))])
                            self._leafs = OrderedDict()

                            self.police = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police()
                            self.police.parent = self
                            self._children_name_map["police"] = "police"
                            self._segment_path = lambda: "police-rate-pdp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp, [], name, value)


                        class Police(Entity):
                            """
                            
                            
                            .. attribute:: rate
                            
                            	Specify police rate
                            	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police, self).__init__()

                                self.yang_name = "police"
                                self.yang_parent_name = "police-rate-pdp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rate", ("rate", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate))])
                                self._leafs = OrderedDict()

                                self.rate = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate()
                                self.rate.parent = self
                                self._children_name_map["rate"] = "rate"
                                self._segment_path = lambda: "police"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police, [], name, value)


                            class Rate(Entity):
                                """
                                Specify police rate
                                
                                .. attribute:: pdp
                                
                                	% of interface bandwidth for rate
                                	**type**\:  :py:class:`Pdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate, self).__init__()

                                    self.yang_name = "rate"
                                    self.yang_parent_name = "police"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pdp", ("pdp", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp))])
                                    self._leafs = OrderedDict()

                                    self.pdp = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp()
                                    self.pdp.parent = self
                                    self._children_name_map["pdp"] = "pdp"
                                    self._segment_path = lambda: "rate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate, [], name, value)


                                class Pdp(Entity):
                                    """
                                    % of interface bandwidth for rate
                                    
                                    .. attribute:: burst
                                    
                                    	Conform burst
                                    	**type**\: int
                                    
                                    	**range:** 1000..512000000
                                    
                                    .. attribute:: peak_rate
                                    
                                    	Specify peak rate
                                    	**type**\:  :py:class:`PeakRate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.PeakRate>`
                                    
                                    .. attribute:: peak_burst
                                    
                                    	Specify 'peak\-burst' parameter for 'peak\-rate'
                                    	**type**\: int
                                    
                                    	**range:** 1000..512000000
                                    
                                    .. attribute:: actions
                                    
                                    	
                                    	**type**\:  :py:class:`Actions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp, self).__init__()

                                        self.yang_name = "pdp"
                                        self.yang_parent_name = "rate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("actions", ("actions", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions))])
                                        self._leafs = OrderedDict([
                                            ('burst', (YLeaf(YType.uint32, 'burst'), ['int'])),
                                            ('peak_rate', (YLeaf(YType.enumeration, 'peak-rate'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.PeakRate')])),
                                            ('peak_burst', (YLeaf(YType.uint32, 'peak-burst'), ['int'])),
                                        ])
                                        self.burst = None
                                        self.peak_rate = None
                                        self.peak_burst = None

                                        self.actions = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions()
                                        self.actions.parent = self
                                        self._children_name_map["actions"] = "actions"
                                        self._segment_path = lambda: "pdp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp, ['burst', 'peak_rate', 'peak_burst'], name, value)

                                    class PeakRate(Enum):
                                        """
                                        PeakRate (Enum Class)

                                        Specify peak rate

                                        .. data:: pdp = 0

                                        """

                                        pdp = Enum.YLeaf(0, "pdp")



                                    class Actions(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_set_clp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetClpTransmit>`
                                        
                                        .. attribute:: conform_set_cos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmit>`
                                        
                                        .. attribute:: conform_set_cos_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetCosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmitTable>`
                                        
                                        .. attribute:: conform_set_discard_class_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDiscardClassTransmit>`
                                        
                                        .. attribute:: conform_set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmit>`
                                        
                                        .. attribute:: conform_set_dscp_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmitTable>`
                                        
                                        .. attribute:: conform_set_frde_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetFrdeTransmit>`
                                        
                                        .. attribute:: conform_set_mpls_exp_imposition_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmit>`
                                        
                                        .. attribute:: conform_set_mpls_exp_imposition_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmitTable>`
                                        
                                        .. attribute:: conform_set_mpls_exp_topmost_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmit>`
                                        
                                        .. attribute:: conform_set_mpls_exp_topmost_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmitTable>`
                                        
                                        .. attribute:: conform_set_prec_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmit>`
                                        
                                        .. attribute:: conform_set_prec_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetPrecTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmitTable>`
                                        
                                        .. attribute:: conform_set_qos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmit>`
                                        
                                        .. attribute:: conform_set_qos_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ConformSetQosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmitTable>`
                                        
                                        .. attribute:: conform_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ConformTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformTransmit>`
                                        
                                        .. attribute:: conform_drop
                                        
                                        	
                                        	**type**\:  :py:class:`ConformDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformDrop>`
                                        
                                        .. attribute:: exceed_dscp
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedDscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDscp>`
                                        
                                        .. attribute:: exceed_set_clp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetClpTransmit>`
                                        
                                        .. attribute:: exceed_set_cos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetCosTransmit>`
                                        
                                        .. attribute:: exceed_set_discard_class_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDiscardClassTransmit>`
                                        
                                        .. attribute:: exceed_set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit>`
                                        
                                        .. attribute:: exceed_set_dscp_transmit_table
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmitTable>`
                                        
                                        .. attribute:: exceed_set_frde_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetFrdeTransmit>`
                                        
                                        .. attribute:: exceed_set_mpls_exp_imposition_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpImpositionTransmit>`
                                        
                                        .. attribute:: exceed_set_mpls_exp_topmost_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpTopmostTransmit>`
                                        
                                        .. attribute:: exceed_set_prec_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetPrecTransmit>`
                                        
                                        .. attribute:: exceed_set_qos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetQosTransmit>`
                                        
                                        .. attribute:: exceed_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedTransmit>`
                                        
                                        .. attribute:: exceed_drop
                                        
                                        	
                                        	**type**\:  :py:class:`ExceedDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDrop>`
                                        
                                        .. attribute:: violate_set_clp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetClpTransmit>`
                                        
                                        .. attribute:: violate_set_cos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetCosTransmit>`
                                        
                                        .. attribute:: violate_set_discard_class_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDiscardClassTransmit>`
                                        
                                        .. attribute:: violate_set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDscpTransmit>`
                                        
                                        .. attribute:: violate_set_frde_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetFrdeTransmit>`
                                        
                                        .. attribute:: violate_set_mpls_exp_imposition_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpImpositionTransmit>`
                                        
                                        .. attribute:: violate_set_mpls_exp_topmost_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpTopmostTransmit>`
                                        
                                        .. attribute:: violate_set_prec_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetPrecTransmit>`
                                        
                                        .. attribute:: violate_set_qos_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetQosTransmit>`
                                        
                                        .. attribute:: violate_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateTransmit>`
                                        
                                        .. attribute:: violate_drop
                                        
                                        	
                                        	**type**\:  :py:class:`ViolateDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateDrop>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions, self).__init__()

                                            self.yang_name = "actions"
                                            self.yang_parent_name = "pdp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-set-clp-transmit", ("conform_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetClpTransmit)), ("conform-set-cos-transmit", ("conform_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmit)), ("conform-set-cos-transmit-table", ("conform_set_cos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmitTable)), ("conform-set-discard-class-transmit", ("conform_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDiscardClassTransmit)), ("conform-set-dscp-transmit", ("conform_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmit)), ("conform-set-dscp-transmit-table", ("conform_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmitTable)), ("conform-set-frde-transmit", ("conform_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetFrdeTransmit)), ("conform-set-mpls-exp-imposition-transmit", ("conform_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmit)), ("conform-set-mpls-exp-imposition-transmit-table", ("conform_set_mpls_exp_imposition_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmitTable)), ("conform-set-mpls-exp-topmost-transmit", ("conform_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmit)), ("conform-set-mpls-exp-topmost-transmit-table", ("conform_set_mpls_exp_topmost_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmitTable)), ("conform-set-prec-transmit", ("conform_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmit)), ("conform-set-prec-transmit-table", ("conform_set_prec_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmitTable)), ("conform-set-qos-transmit", ("conform_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmit)), ("conform-set-qos-transmit-table", ("conform_set_qos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmitTable)), ("conform-transmit", ("conform_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformTransmit)), ("conform-drop", ("conform_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformDrop)), ("exceed-dscp", ("exceed_dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDscp)), ("exceed-set-clp-transmit", ("exceed_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetClpTransmit)), ("exceed-set-cos-transmit", ("exceed_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetCosTransmit)), ("exceed-set-discard-class-transmit", ("exceed_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDiscardClassTransmit)), ("exceed-set-dscp-transmit", ("exceed_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit)), ("exceed-set-dscp-transmit-table", ("exceed_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmitTable)), ("exceed-set-frde-transmit", ("exceed_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetFrdeTransmit)), ("exceed-set-mpls-exp-imposition-transmit", ("exceed_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpImpositionTransmit)), ("exceed-set-mpls-exp-topmost-transmit", ("exceed_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpTopmostTransmit)), ("exceed-set-prec-transmit", ("exceed_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetPrecTransmit)), ("exceed-set-qos-transmit", ("exceed_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetQosTransmit)), ("exceed-transmit", ("exceed_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedTransmit)), ("exceed-drop", ("exceed_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDrop)), ("violate-set-clp-transmit", ("violate_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetClpTransmit)), ("violate-set-cos-transmit", ("violate_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetCosTransmit)), ("violate-set-discard-class-transmit", ("violate_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDiscardClassTransmit)), ("violate-set-dscp-transmit", ("violate_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDscpTransmit)), ("violate-set-frde-transmit", ("violate_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetFrdeTransmit)), ("violate-set-mpls-exp-imposition-transmit", ("violate_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpImpositionTransmit)), ("violate-set-mpls-exp-topmost-transmit", ("violate_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpTopmostTransmit)), ("violate-set-prec-transmit", ("violate_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetPrecTransmit)), ("violate-set-qos-transmit", ("violate_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetQosTransmit)), ("violate-transmit", ("violate_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateTransmit)), ("violate-drop", ("violate_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateDrop))])
                                            self._leafs = OrderedDict()

                                            self.conform_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetClpTransmit()
                                            self.conform_set_clp_transmit.parent = self
                                            self._children_name_map["conform_set_clp_transmit"] = "conform-set-clp-transmit"

                                            self.conform_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmit()
                                            self.conform_set_cos_transmit.parent = self
                                            self._children_name_map["conform_set_cos_transmit"] = "conform-set-cos-transmit"

                                            self.conform_set_cos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmitTable()
                                            self.conform_set_cos_transmit_table.parent = self
                                            self._children_name_map["conform_set_cos_transmit_table"] = "conform-set-cos-transmit-table"

                                            self.conform_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDiscardClassTransmit()
                                            self.conform_set_discard_class_transmit.parent = self
                                            self._children_name_map["conform_set_discard_class_transmit"] = "conform-set-discard-class-transmit"

                                            self.conform_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmit()
                                            self.conform_set_dscp_transmit.parent = self
                                            self._children_name_map["conform_set_dscp_transmit"] = "conform-set-dscp-transmit"

                                            self.conform_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmitTable()
                                            self.conform_set_dscp_transmit_table.parent = self
                                            self._children_name_map["conform_set_dscp_transmit_table"] = "conform-set-dscp-transmit-table"

                                            self.conform_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetFrdeTransmit()
                                            self.conform_set_frde_transmit.parent = self
                                            self._children_name_map["conform_set_frde_transmit"] = "conform-set-frde-transmit"

                                            self.conform_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmit()
                                            self.conform_set_mpls_exp_imposition_transmit.parent = self
                                            self._children_name_map["conform_set_mpls_exp_imposition_transmit"] = "conform-set-mpls-exp-imposition-transmit"

                                            self.conform_set_mpls_exp_imposition_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmitTable()
                                            self.conform_set_mpls_exp_imposition_transmit_table.parent = self
                                            self._children_name_map["conform_set_mpls_exp_imposition_transmit_table"] = "conform-set-mpls-exp-imposition-transmit-table"

                                            self.conform_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmit()
                                            self.conform_set_mpls_exp_topmost_transmit.parent = self
                                            self._children_name_map["conform_set_mpls_exp_topmost_transmit"] = "conform-set-mpls-exp-topmost-transmit"

                                            self.conform_set_mpls_exp_topmost_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmitTable()
                                            self.conform_set_mpls_exp_topmost_transmit_table.parent = self
                                            self._children_name_map["conform_set_mpls_exp_topmost_transmit_table"] = "conform-set-mpls-exp-topmost-transmit-table"

                                            self.conform_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmit()
                                            self.conform_set_prec_transmit.parent = self
                                            self._children_name_map["conform_set_prec_transmit"] = "conform-set-prec-transmit"

                                            self.conform_set_prec_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmitTable()
                                            self.conform_set_prec_transmit_table.parent = self
                                            self._children_name_map["conform_set_prec_transmit_table"] = "conform-set-prec-transmit-table"

                                            self.conform_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmit()
                                            self.conform_set_qos_transmit.parent = self
                                            self._children_name_map["conform_set_qos_transmit"] = "conform-set-qos-transmit"

                                            self.conform_set_qos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmitTable()
                                            self.conform_set_qos_transmit_table.parent = self
                                            self._children_name_map["conform_set_qos_transmit_table"] = "conform-set-qos-transmit-table"

                                            self.conform_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformTransmit()
                                            self.conform_transmit.parent = self
                                            self._children_name_map["conform_transmit"] = "conform-transmit"

                                            self.conform_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformDrop()
                                            self.conform_drop.parent = self
                                            self._children_name_map["conform_drop"] = "conform-drop"

                                            self.exceed_dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDscp()
                                            self.exceed_dscp.parent = self
                                            self._children_name_map["exceed_dscp"] = "exceed-dscp"

                                            self.exceed_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetClpTransmit()
                                            self.exceed_set_clp_transmit.parent = self
                                            self._children_name_map["exceed_set_clp_transmit"] = "exceed-set-clp-transmit"

                                            self.exceed_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetCosTransmit()
                                            self.exceed_set_cos_transmit.parent = self
                                            self._children_name_map["exceed_set_cos_transmit"] = "exceed-set-cos-transmit"

                                            self.exceed_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDiscardClassTransmit()
                                            self.exceed_set_discard_class_transmit.parent = self
                                            self._children_name_map["exceed_set_discard_class_transmit"] = "exceed-set-discard-class-transmit"

                                            self.exceed_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit()
                                            self.exceed_set_dscp_transmit.parent = self
                                            self._children_name_map["exceed_set_dscp_transmit"] = "exceed-set-dscp-transmit"

                                            self.exceed_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmitTable()
                                            self.exceed_set_dscp_transmit_table.parent = self
                                            self._children_name_map["exceed_set_dscp_transmit_table"] = "exceed-set-dscp-transmit-table"

                                            self.exceed_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetFrdeTransmit()
                                            self.exceed_set_frde_transmit.parent = self
                                            self._children_name_map["exceed_set_frde_transmit"] = "exceed-set-frde-transmit"

                                            self.exceed_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpImpositionTransmit()
                                            self.exceed_set_mpls_exp_imposition_transmit.parent = self
                                            self._children_name_map["exceed_set_mpls_exp_imposition_transmit"] = "exceed-set-mpls-exp-imposition-transmit"

                                            self.exceed_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpTopmostTransmit()
                                            self.exceed_set_mpls_exp_topmost_transmit.parent = self
                                            self._children_name_map["exceed_set_mpls_exp_topmost_transmit"] = "exceed-set-mpls-exp-topmost-transmit"

                                            self.exceed_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetPrecTransmit()
                                            self.exceed_set_prec_transmit.parent = self
                                            self._children_name_map["exceed_set_prec_transmit"] = "exceed-set-prec-transmit"

                                            self.exceed_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetQosTransmit()
                                            self.exceed_set_qos_transmit.parent = self
                                            self._children_name_map["exceed_set_qos_transmit"] = "exceed-set-qos-transmit"

                                            self.exceed_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedTransmit()
                                            self.exceed_transmit.parent = self
                                            self._children_name_map["exceed_transmit"] = "exceed-transmit"

                                            self.exceed_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDrop()
                                            self.exceed_drop.parent = self
                                            self._children_name_map["exceed_drop"] = "exceed-drop"

                                            self.violate_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetClpTransmit()
                                            self.violate_set_clp_transmit.parent = self
                                            self._children_name_map["violate_set_clp_transmit"] = "violate-set-clp-transmit"

                                            self.violate_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetCosTransmit()
                                            self.violate_set_cos_transmit.parent = self
                                            self._children_name_map["violate_set_cos_transmit"] = "violate-set-cos-transmit"

                                            self.violate_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDiscardClassTransmit()
                                            self.violate_set_discard_class_transmit.parent = self
                                            self._children_name_map["violate_set_discard_class_transmit"] = "violate-set-discard-class-transmit"

                                            self.violate_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDscpTransmit()
                                            self.violate_set_dscp_transmit.parent = self
                                            self._children_name_map["violate_set_dscp_transmit"] = "violate-set-dscp-transmit"

                                            self.violate_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetFrdeTransmit()
                                            self.violate_set_frde_transmit.parent = self
                                            self._children_name_map["violate_set_frde_transmit"] = "violate-set-frde-transmit"

                                            self.violate_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpImpositionTransmit()
                                            self.violate_set_mpls_exp_imposition_transmit.parent = self
                                            self._children_name_map["violate_set_mpls_exp_imposition_transmit"] = "violate-set-mpls-exp-imposition-transmit"

                                            self.violate_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpTopmostTransmit()
                                            self.violate_set_mpls_exp_topmost_transmit.parent = self
                                            self._children_name_map["violate_set_mpls_exp_topmost_transmit"] = "violate-set-mpls-exp-topmost-transmit"

                                            self.violate_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetPrecTransmit()
                                            self.violate_set_prec_transmit.parent = self
                                            self._children_name_map["violate_set_prec_transmit"] = "violate-set-prec-transmit"

                                            self.violate_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetQosTransmit()
                                            self.violate_set_qos_transmit.parent = self
                                            self._children_name_map["violate_set_qos_transmit"] = "violate-set-qos-transmit"

                                            self.violate_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateTransmit()
                                            self.violate_transmit.parent = self
                                            self._children_name_map["violate_transmit"] = "violate-transmit"

                                            self.violate_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateDrop()
                                            self.violate_drop.parent = self
                                            self._children_name_map["violate_drop"] = "violate-drop"
                                            self._segment_path = lambda: "actions"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions, [], name, value)


                                        class ConformSetClpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetClpTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetClpTransmit, self).__init__()

                                                self.yang_name = "conform-set-clp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetClpTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetClpTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-clp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetClpTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_clp_transmit
                                                
                                                	set atm clp and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetClpTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-clp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_clp_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetClpTransmit.ConformAction, ['set_clp_transmit'], name, value)


                                        class ConformSetCosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmit, self).__init__()

                                                self.yang_name = "conform-set-cos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-cos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-cos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmit.ConformAction, ['set_cos_transmit'], name, value)


                                        class ConformSetCosTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-cos-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-cos-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-cos-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetCosTransmitTable.ConformAction, ['set_cos_transmit', 'table'], name, value)


                                        class ConformSetDiscardClassTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDiscardClassTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDiscardClassTransmit, self).__init__()

                                                self.yang_name = "conform-set-discard-class-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDiscardClassTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDiscardClassTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-discard-class-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDiscardClassTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_discard_class_transmit
                                                
                                                	set discard\-class and send it
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDiscardClassTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-discard-class-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                    ])
                                                    self.set_discard_class_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDiscardClassTransmit.ConformAction, ['set_discard_class_transmit'], name, value)


                                        class ConformSetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmit, self).__init__()

                                                self.yang_name = "conform-set-dscp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmit.ConformAction, ['set_dscp_transmit'], name, value)


                                        class ConformSetDscpTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-dscp-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-dscp-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-dscp-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetDscpTransmitTable.ConformAction, ['set_dscp_transmit', 'table'], name, value)


                                        class ConformSetFrdeTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetFrdeTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetFrdeTransmit, self).__init__()

                                                self.yang_name = "conform-set-frde-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetFrdeTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetFrdeTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-frde-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetFrdeTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_frde_transmit
                                                
                                                	set FR DE and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetFrdeTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-frde-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_frde_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetFrdeTransmit.ConformAction, ['set_frde_transmit'], name, value)


                                        class ConformSetMplsExpImpositionTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmit, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-imposition-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                        class ConformSetMplsExpImpositionTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-imposition-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, ['set_mpls_exp_imposition_transmit', 'table'], name, value)


                                        class ConformSetMplsExpTopmostTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmit, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-topmost-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                        class ConformSetMplsExpTopmostTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-mpls-exp-topmost-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, ['set_mpls_exp_topmost_transmit', 'table'], name, value)


                                        class ConformSetPrecTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmit, self).__init__()

                                                self.yang_name = "conform-set-prec-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-prec-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-prec-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmit.ConformAction, ['set_prec_transmit'], name, value)


                                        class ConformSetPrecTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-prec-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-prec-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-prec-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetPrecTransmitTable.ConformAction, ['set_prec_transmit', 'table'], name, value)


                                        class ConformSetQosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmit, self).__init__()

                                                self.yang_name = "conform-set-qos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-qos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-qos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmit.ConformAction, ['set_qos_transmit'], name, value)


                                        class ConformSetQosTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmitTable.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmitTable, self).__init__()

                                                self.yang_name = "conform-set-qos-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmitTable.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmitTable.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-set-qos-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmitTable, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmitTable.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-set-qos-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformSetQosTransmitTable.ConformAction, ['set_qos_transmit', 'table'], name, value)


                                        class ConformTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformTransmit.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformTransmit, self).__init__()

                                                self.yang_name = "conform-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformTransmit.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformTransmit.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformTransmit, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: transmit
                                                
                                                	transmit packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformTransmit.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                    ])
                                                    self.transmit = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformTransmit.ConformAction, ['transmit'], name, value)


                                        class ConformDrop(Entity):
                                            """
                                            
                                            
                                            .. attribute:: conform_action
                                            
                                            	action when rate is less than conform burst
                                            	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformDrop.ConformAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformDrop, self).__init__()

                                                self.yang_name = "conform-drop"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformDrop.ConformAction))])
                                                self._leafs = OrderedDict()

                                                self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformDrop.ConformAction()
                                                self.conform_action.parent = self
                                                self._children_name_map["conform_action"] = "conform-action"
                                                self._segment_path = lambda: "conform-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformDrop, [], name, value)


                                            class ConformAction(Entity):
                                                """
                                                action when rate is less than conform burst
                                                
                                                .. attribute:: drop
                                                
                                                	drop packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformDrop.ConformAction, self).__init__()

                                                    self.yang_name = "conform-action"
                                                    self.yang_parent_name = "conform-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ])
                                                    self.drop = None
                                                    self._segment_path = lambda: "conform-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ConformDrop.ConformAction, ['drop'], name, value)


                                        class ExceedDscp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDscp.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDscp, self).__init__()

                                                self.yang_name = "exceed-dscp"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDscp.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDscp.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-dscp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDscp, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: dscp
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDscp.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-dscp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ])
                                                    self.dscp = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDscp.ExceedAction, ['dscp'], name, value)


                                        class ExceedSetClpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetClpTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetClpTransmit, self).__init__()

                                                self.yang_name = "exceed-set-clp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetClpTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetClpTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-clp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetClpTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_clp_transmit
                                                
                                                	set atm clp and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetClpTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-clp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_clp_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetClpTransmit.ExceedAction, ['set_clp_transmit'], name, value)


                                        class ExceedSetCosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetCosTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetCosTransmit, self).__init__()

                                                self.yang_name = "exceed-set-cos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetCosTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetCosTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-cos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetCosTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetCosTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-cos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetCosTransmit.ExceedAction, ['set_cos_transmit', 'table'], name, value)


                                        class ExceedSetDiscardClassTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDiscardClassTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDiscardClassTransmit, self).__init__()

                                                self.yang_name = "exceed-set-discard-class-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDiscardClassTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDiscardClassTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-discard-class-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDiscardClassTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_discard_class_transmit
                                                
                                                	set discard\-class and send it
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDiscardClassTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-discard-class-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                    ])
                                                    self.set_discard_class_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDiscardClassTransmit.ExceedAction, ['set_discard_class_transmit'], name, value)


                                        class ExceedSetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit, self).__init__()

                                                self.yang_name = "exceed-set-dscp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	
                                                	**type**\:  :py:class:`SetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("set-dscp-transmit", ("set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit))])
                                                    self._leafs = OrderedDict()

                                                    self.set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit()
                                                    self.set_dscp_transmit.parent = self
                                                    self._children_name_map["set_dscp_transmit"] = "set-dscp-transmit"
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction, [], name, value)


                                                class SetDscpTransmit(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: dscp
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-policy'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, self).__init__()

                                                        self.yang_name = "set-dscp-transmit"
                                                        self.yang_parent_name = "exceed-action"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp))])
                                                        self._leafs = OrderedDict()

                                                        self.dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp()
                                                        self.dscp.parent = self
                                                        self._children_name_map["dscp"] = "dscp"
                                                        self._segment_path = lambda: "set-dscp-transmit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, [], name, value)


                                                    class Dscp(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: table
                                                        
                                                        	
                                                        	**type**\:  :py:class:`Table <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-policy'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, self).__init__()

                                                            self.yang_name = "dscp"
                                                            self.yang_parent_name = "set-dscp-transmit"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('table', (YLeaf(YType.enumeration, 'table'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table')])),
                                                            ])
                                                            self.table = None
                                                            self._segment_path = lambda: "dscp"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, ['table'], name, value)

                                                        class Table(Enum):
                                                            """
                                                            Table (Enum Class)

                                                            .. data:: policed_dscp = 0

                                                            """

                                                            policed_dscp = Enum.YLeaf(0, "policed-dscp")



                                        class ExceedSetDscpTransmitTable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmitTable.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmitTable, self).__init__()

                                                self.yang_name = "exceed-set-dscp-transmit-table"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmitTable.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmitTable.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-dscp-transmit-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmitTable, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmitTable.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-dscp-transmit-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetDscpTransmitTable.ExceedAction, ['set_dscp_transmit', 'table'], name, value)


                                        class ExceedSetFrdeTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetFrdeTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetFrdeTransmit, self).__init__()

                                                self.yang_name = "exceed-set-frde-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetFrdeTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetFrdeTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-frde-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetFrdeTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_frde_transmit
                                                
                                                	set FR DE and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetFrdeTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-frde-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_frde_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetFrdeTransmit.ExceedAction, ['set_frde_transmit'], name, value)


                                        class ExceedSetMplsExpImpositionTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpImpositionTransmit, self).__init__()

                                                self.yang_name = "exceed-set-mpls-exp-imposition-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-mpls-exp-imposition-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpImpositionTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-mpls-exp-imposition-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                        class ExceedSetMplsExpTopmostTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpTopmostTransmit, self).__init__()

                                                self.yang_name = "exceed-set-mpls-exp-topmost-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-mpls-exp-topmost-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpTopmostTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-mpls-exp-topmost-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                        class ExceedSetPrecTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetPrecTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetPrecTransmit, self).__init__()

                                                self.yang_name = "exceed-set-prec-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetPrecTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetPrecTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-prec-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetPrecTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetPrecTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-prec-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetPrecTransmit.ExceedAction, ['set_prec_transmit', 'table'], name, value)


                                        class ExceedSetQosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetQosTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetQosTransmit, self).__init__()

                                                self.yang_name = "exceed-set-qos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetQosTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetQosTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-set-qos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetQosTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetQosTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-set-qos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedSetQosTransmit.ExceedAction, ['set_qos_transmit'], name, value)


                                        class ExceedTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedTransmit.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedTransmit, self).__init__()

                                                self.yang_name = "exceed-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedTransmit.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedTransmit.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedTransmit, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: transmit
                                                
                                                	transmit packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedTransmit.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                    ])
                                                    self.transmit = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedTransmit.ExceedAction, ['transmit'], name, value)


                                        class ExceedDrop(Entity):
                                            """
                                            
                                            
                                            .. attribute:: exceed_action
                                            
                                            	action when rate is within conform and conform + exceed burst
                                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDrop.ExceedAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDrop, self).__init__()

                                                self.yang_name = "exceed-drop"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDrop.ExceedAction))])
                                                self._leafs = OrderedDict()

                                                self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDrop.ExceedAction()
                                                self.exceed_action.parent = self
                                                self._children_name_map["exceed_action"] = "exceed-action"
                                                self._segment_path = lambda: "exceed-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDrop, [], name, value)


                                            class ExceedAction(Entity):
                                                """
                                                action when rate is within conform and conform + exceed burst
                                                
                                                .. attribute:: drop
                                                
                                                	drop packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDrop.ExceedAction, self).__init__()

                                                    self.yang_name = "exceed-action"
                                                    self.yang_parent_name = "exceed-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ])
                                                    self.drop = None
                                                    self._segment_path = lambda: "exceed-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ExceedDrop.ExceedAction, ['drop'], name, value)


                                        class ViolateSetClpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetClpTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetClpTransmit, self).__init__()

                                                self.yang_name = "violate-set-clp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetClpTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetClpTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-clp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetClpTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_clp_transmit
                                                
                                                	set atm clp and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetClpTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-clp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_clp_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetClpTransmit.ViolateAction, ['set_clp_transmit'], name, value)


                                        class ViolateSetCosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetCosTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetCosTransmit, self).__init__()

                                                self.yang_name = "violate-set-cos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetCosTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetCosTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-cos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetCosTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_cos_transmit
                                                
                                                	rewrite packet cos and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetCosTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-cos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_cos_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetCosTransmit.ViolateAction, ['set_cos_transmit', 'table'], name, value)


                                        class ViolateSetDiscardClassTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDiscardClassTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDiscardClassTransmit, self).__init__()

                                                self.yang_name = "violate-set-discard-class-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDiscardClassTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDiscardClassTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-discard-class-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDiscardClassTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_discard_class_transmit
                                                
                                                	set discard\-class and send it
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDiscardClassTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-discard-class-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                    ])
                                                    self.set_discard_class_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDiscardClassTransmit.ViolateAction, ['set_discard_class_transmit'], name, value)


                                        class ViolateSetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDscpTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDscpTransmit, self).__init__()

                                                self.yang_name = "violate-set-dscp-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDscpTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDscpTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDscpTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_dscp_transmit
                                                
                                                	set dscp and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..63
                                                
                                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDscpTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_dscp_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetDscpTransmit.ViolateAction, ['set_dscp_transmit', 'table'], name, value)


                                        class ViolateSetFrdeTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetFrdeTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetFrdeTransmit, self).__init__()

                                                self.yang_name = "violate-set-frde-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetFrdeTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetFrdeTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-frde-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetFrdeTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_frde_transmit
                                                
                                                	set FR DE and send it
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetFrdeTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-frde-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                    ])
                                                    self.set_frde_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetFrdeTransmit.ViolateAction, ['set_frde_transmit'], name, value)


                                        class ViolateSetMplsExpImpositionTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpImpositionTransmit, self).__init__()

                                                self.yang_name = "violate-set-mpls-exp-imposition-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-mpls-exp-imposition-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpImpositionTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_imposition_transmit
                                                
                                                	set exp at tag imposition and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-mpls-exp-imposition-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_imposition_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                        class ViolateSetMplsExpTopmostTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpTopmostTransmit, self).__init__()

                                                self.yang_name = "violate-set-mpls-exp-topmost-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-mpls-exp-topmost-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpTopmostTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_mpls_exp_topmost_transmit
                                                
                                                	set exp on topmost label and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-mpls-exp-topmost-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ])
                                                    self.set_mpls_exp_topmost_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                        class ViolateSetPrecTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetPrecTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetPrecTransmit, self).__init__()

                                                self.yang_name = "violate-set-prec-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetPrecTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetPrecTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-prec-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetPrecTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_prec_transmit
                                                
                                                	rewrite packet precedence and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..7
                                                
                                                		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                                
                                                .. attribute:: table
                                                
                                                	Specify table\-map
                                                	**type**\: str
                                                
                                                	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetPrecTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-prec-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                    ])
                                                    self.set_prec_transmit = None
                                                    self.table = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetPrecTransmit.ViolateAction, ['set_prec_transmit', 'table'], name, value)


                                        class ViolateSetQosTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetQosTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetQosTransmit, self).__init__()

                                                self.yang_name = "violate-set-qos-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetQosTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetQosTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-set-qos-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetQosTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: set_qos_transmit
                                                
                                                	set qos\-group and send it
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 0..99
                                                
                                                		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetQosTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-set-qos-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                    ])
                                                    self.set_qos_transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateSetQosTransmit.ViolateAction, ['set_qos_transmit'], name, value)


                                        class ViolateTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateTransmit.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateTransmit, self).__init__()

                                                self.yang_name = "violate-transmit"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateTransmit.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateTransmit.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateTransmit, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: transmit
                                                
                                                	transmit packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateTransmit.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                    ])
                                                    self.transmit = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateTransmit.ViolateAction, ['transmit'], name, value)


                                        class ViolateDrop(Entity):
                                            """
                                            
                                            
                                            .. attribute:: violate_action
                                            
                                            	action when rate is greater than conform + exceed burst
                                            	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateDrop.ViolateAction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateDrop, self).__init__()

                                                self.yang_name = "violate-drop"
                                                self.yang_parent_name = "actions"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateDrop.ViolateAction))])
                                                self._leafs = OrderedDict()

                                                self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateDrop.ViolateAction()
                                                self.violate_action.parent = self
                                                self._children_name_map["violate_action"] = "violate-action"
                                                self._segment_path = lambda: "violate-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateDrop, [], name, value)


                                            class ViolateAction(Entity):
                                                """
                                                action when rate is greater than conform + exceed burst
                                                
                                                .. attribute:: drop
                                                
                                                	drop packet
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateDrop.ViolateAction, self).__init__()

                                                    self.yang_name = "violate-action"
                                                    self.yang_parent_name = "violate-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ])
                                                    self.drop = None
                                                    self._segment_path = lambda: "violate-action"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceRatePdp.Police.Rate.Pdp.Actions.ViolateDrop.ViolateAction, ['drop'], name, value)


                    class PoliceTargetBitrate(Entity):
                        """
                        
                        
                        .. attribute:: police
                        
                        	
                        	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate, self).__init__()

                            self.yang_name = "police-target-bitrate"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("police", ("police", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police))])
                            self._leafs = OrderedDict()

                            self.police = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police()
                            self.police.parent = self
                            self._children_name_map["police"] = "police"
                            self._segment_path = lambda: "police-target-bitrate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate, [], name, value)


                        class Police(Entity):
                            """
                            
                            
                            .. attribute:: bit_rate
                            
                            	Target bit rate (bits per second) (postfix k, m, g optional),decimal point allowed
                            	**type**\: int
                            
                            	**range:** 8000..10000000000
                            
                            .. attribute:: confirm_burst_byte
                            
                            	Burst Byte
                            	**type**\: int
                            
                            	**range:** 100..512000000
                            
                            .. attribute:: excess_burst_byte
                            
                            	Burst Byte
                            	**type**\: int
                            
                            	**range:** 100..512000000
                            
                            .. attribute:: conform_action
                            
                            	action when rate is less than conform burst
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: transmit
                            
                            	transmit packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: exceed_action
                            
                            	action when rate is within conform and conform + exceed burst
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: drop
                            
                            	drop packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: set_dscp_transmit
                            
                            	set dscp and send it
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	Set packet dscp from dscp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: table
                            
                            	Specify table\-map
                            	**type**\: str
                            
                            .. attribute:: actions
                            
                            	
                            	**type**\:  :py:class:`Actions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police, self).__init__()

                                self.yang_name = "police"
                                self.yang_parent_name = "police-target-bitrate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("actions", ("actions", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions))])
                                self._leafs = OrderedDict([
                                    ('bit_rate', (YLeaf(YType.uint64, 'bit-rate'), ['int'])),
                                    ('confirm_burst_byte', (YLeaf(YType.uint64, 'confirm_burst-byte'), ['int'])),
                                    ('excess_burst_byte', (YLeaf(YType.uint64, 'excess_burst-byte'), ['int'])),
                                    ('conform_action', (YLeaf(YType.empty, 'conform-action'), ['Empty'])),
                                    ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                    ('exceed_action', (YLeaf(YType.empty, 'exceed-action'), ['Empty'])),
                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                    ('set_dscp_transmit', (YLeaf(YType.empty, 'set-dscp-transmit'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                ])
                                self.bit_rate = None
                                self.confirm_burst_byte = None
                                self.excess_burst_byte = None
                                self.conform_action = None
                                self.transmit = None
                                self.exceed_action = None
                                self.drop = None
                                self.set_dscp_transmit = None
                                self.dscp = None
                                self.table = None

                                self.actions = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions()
                                self.actions.parent = self
                                self._children_name_map["actions"] = "actions"
                                self._segment_path = lambda: "police"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police, ['bit_rate', 'confirm_burst_byte', 'excess_burst_byte', 'conform_action', 'transmit', 'exceed_action', 'drop', 'set_dscp_transmit', 'dscp', 'table'], name, value)


                            class Actions(Entity):
                                """
                                
                                
                                .. attribute:: conform_set_clp_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetClpTransmit>`
                                
                                .. attribute:: conform_set_cos_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmit>`
                                
                                .. attribute:: conform_set_cos_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetCosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmitTable>`
                                
                                .. attribute:: conform_set_discard_class_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDiscardClassTransmit>`
                                
                                .. attribute:: conform_set_dscp_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmit>`
                                
                                .. attribute:: conform_set_dscp_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmitTable>`
                                
                                .. attribute:: conform_set_frde_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetFrdeTransmit>`
                                
                                .. attribute:: conform_set_mpls_exp_imposition_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmit>`
                                
                                .. attribute:: conform_set_mpls_exp_imposition_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmitTable>`
                                
                                .. attribute:: conform_set_mpls_exp_topmost_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmit>`
                                
                                .. attribute:: conform_set_mpls_exp_topmost_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmitTable>`
                                
                                .. attribute:: conform_set_prec_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmit>`
                                
                                .. attribute:: conform_set_prec_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetPrecTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmitTable>`
                                
                                .. attribute:: conform_set_qos_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmit>`
                                
                                .. attribute:: conform_set_qos_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetQosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmitTable>`
                                
                                .. attribute:: conform_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformTransmit>`
                                
                                .. attribute:: conform_drop
                                
                                	
                                	**type**\:  :py:class:`ConformDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformDrop>`
                                
                                .. attribute:: exceed_dscp
                                
                                	
                                	**type**\:  :py:class:`ExceedDscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDscp>`
                                
                                .. attribute:: exceed_set_clp_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetClpTransmit>`
                                
                                .. attribute:: exceed_set_cos_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetCosTransmit>`
                                
                                .. attribute:: exceed_set_discard_class_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDiscardClassTransmit>`
                                
                                .. attribute:: exceed_set_dscp_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit>`
                                
                                .. attribute:: exceed_set_dscp_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ExceedSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmitTable>`
                                
                                .. attribute:: exceed_set_frde_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetFrdeTransmit>`
                                
                                .. attribute:: exceed_set_mpls_exp_imposition_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpImpositionTransmit>`
                                
                                .. attribute:: exceed_set_mpls_exp_topmost_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpTopmostTransmit>`
                                
                                .. attribute:: exceed_set_prec_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetPrecTransmit>`
                                
                                .. attribute:: exceed_set_qos_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetQosTransmit>`
                                
                                .. attribute:: exceed_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedTransmit>`
                                
                                .. attribute:: exceed_drop
                                
                                	
                                	**type**\:  :py:class:`ExceedDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDrop>`
                                
                                .. attribute:: violate_set_clp_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetClpTransmit>`
                                
                                .. attribute:: violate_set_cos_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetCosTransmit>`
                                
                                .. attribute:: violate_set_discard_class_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDiscardClassTransmit>`
                                
                                .. attribute:: violate_set_dscp_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDscpTransmit>`
                                
                                .. attribute:: violate_set_frde_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetFrdeTransmit>`
                                
                                .. attribute:: violate_set_mpls_exp_imposition_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpImpositionTransmit>`
                                
                                .. attribute:: violate_set_mpls_exp_topmost_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpTopmostTransmit>`
                                
                                .. attribute:: violate_set_prec_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetPrecTransmit>`
                                
                                .. attribute:: violate_set_qos_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetQosTransmit>`
                                
                                .. attribute:: violate_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateTransmit>`
                                
                                .. attribute:: violate_drop
                                
                                	
                                	**type**\:  :py:class:`ViolateDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateDrop>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions, self).__init__()

                                    self.yang_name = "actions"
                                    self.yang_parent_name = "police"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("conform-set-clp-transmit", ("conform_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetClpTransmit)), ("conform-set-cos-transmit", ("conform_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmit)), ("conform-set-cos-transmit-table", ("conform_set_cos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmitTable)), ("conform-set-discard-class-transmit", ("conform_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDiscardClassTransmit)), ("conform-set-dscp-transmit", ("conform_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmit)), ("conform-set-dscp-transmit-table", ("conform_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmitTable)), ("conform-set-frde-transmit", ("conform_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetFrdeTransmit)), ("conform-set-mpls-exp-imposition-transmit", ("conform_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmit)), ("conform-set-mpls-exp-imposition-transmit-table", ("conform_set_mpls_exp_imposition_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmitTable)), ("conform-set-mpls-exp-topmost-transmit", ("conform_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmit)), ("conform-set-mpls-exp-topmost-transmit-table", ("conform_set_mpls_exp_topmost_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmitTable)), ("conform-set-prec-transmit", ("conform_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmit)), ("conform-set-prec-transmit-table", ("conform_set_prec_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmitTable)), ("conform-set-qos-transmit", ("conform_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmit)), ("conform-set-qos-transmit-table", ("conform_set_qos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmitTable)), ("conform-transmit", ("conform_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformTransmit)), ("conform-drop", ("conform_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformDrop)), ("exceed-dscp", ("exceed_dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDscp)), ("exceed-set-clp-transmit", ("exceed_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetClpTransmit)), ("exceed-set-cos-transmit", ("exceed_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetCosTransmit)), ("exceed-set-discard-class-transmit", ("exceed_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDiscardClassTransmit)), ("exceed-set-dscp-transmit", ("exceed_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit)), ("exceed-set-dscp-transmit-table", ("exceed_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmitTable)), ("exceed-set-frde-transmit", ("exceed_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetFrdeTransmit)), ("exceed-set-mpls-exp-imposition-transmit", ("exceed_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpImpositionTransmit)), ("exceed-set-mpls-exp-topmost-transmit", ("exceed_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpTopmostTransmit)), ("exceed-set-prec-transmit", ("exceed_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetPrecTransmit)), ("exceed-set-qos-transmit", ("exceed_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetQosTransmit)), ("exceed-transmit", ("exceed_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedTransmit)), ("exceed-drop", ("exceed_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDrop)), ("violate-set-clp-transmit", ("violate_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetClpTransmit)), ("violate-set-cos-transmit", ("violate_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetCosTransmit)), ("violate-set-discard-class-transmit", ("violate_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDiscardClassTransmit)), ("violate-set-dscp-transmit", ("violate_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDscpTransmit)), ("violate-set-frde-transmit", ("violate_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetFrdeTransmit)), ("violate-set-mpls-exp-imposition-transmit", ("violate_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpImpositionTransmit)), ("violate-set-mpls-exp-topmost-transmit", ("violate_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpTopmostTransmit)), ("violate-set-prec-transmit", ("violate_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetPrecTransmit)), ("violate-set-qos-transmit", ("violate_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetQosTransmit)), ("violate-transmit", ("violate_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateTransmit)), ("violate-drop", ("violate_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateDrop))])
                                    self._leafs = OrderedDict()

                                    self.conform_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetClpTransmit()
                                    self.conform_set_clp_transmit.parent = self
                                    self._children_name_map["conform_set_clp_transmit"] = "conform-set-clp-transmit"

                                    self.conform_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmit()
                                    self.conform_set_cos_transmit.parent = self
                                    self._children_name_map["conform_set_cos_transmit"] = "conform-set-cos-transmit"

                                    self.conform_set_cos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmitTable()
                                    self.conform_set_cos_transmit_table.parent = self
                                    self._children_name_map["conform_set_cos_transmit_table"] = "conform-set-cos-transmit-table"

                                    self.conform_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDiscardClassTransmit()
                                    self.conform_set_discard_class_transmit.parent = self
                                    self._children_name_map["conform_set_discard_class_transmit"] = "conform-set-discard-class-transmit"

                                    self.conform_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmit()
                                    self.conform_set_dscp_transmit.parent = self
                                    self._children_name_map["conform_set_dscp_transmit"] = "conform-set-dscp-transmit"

                                    self.conform_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmitTable()
                                    self.conform_set_dscp_transmit_table.parent = self
                                    self._children_name_map["conform_set_dscp_transmit_table"] = "conform-set-dscp-transmit-table"

                                    self.conform_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetFrdeTransmit()
                                    self.conform_set_frde_transmit.parent = self
                                    self._children_name_map["conform_set_frde_transmit"] = "conform-set-frde-transmit"

                                    self.conform_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmit()
                                    self.conform_set_mpls_exp_imposition_transmit.parent = self
                                    self._children_name_map["conform_set_mpls_exp_imposition_transmit"] = "conform-set-mpls-exp-imposition-transmit"

                                    self.conform_set_mpls_exp_imposition_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmitTable()
                                    self.conform_set_mpls_exp_imposition_transmit_table.parent = self
                                    self._children_name_map["conform_set_mpls_exp_imposition_transmit_table"] = "conform-set-mpls-exp-imposition-transmit-table"

                                    self.conform_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmit()
                                    self.conform_set_mpls_exp_topmost_transmit.parent = self
                                    self._children_name_map["conform_set_mpls_exp_topmost_transmit"] = "conform-set-mpls-exp-topmost-transmit"

                                    self.conform_set_mpls_exp_topmost_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmitTable()
                                    self.conform_set_mpls_exp_topmost_transmit_table.parent = self
                                    self._children_name_map["conform_set_mpls_exp_topmost_transmit_table"] = "conform-set-mpls-exp-topmost-transmit-table"

                                    self.conform_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmit()
                                    self.conform_set_prec_transmit.parent = self
                                    self._children_name_map["conform_set_prec_transmit"] = "conform-set-prec-transmit"

                                    self.conform_set_prec_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmitTable()
                                    self.conform_set_prec_transmit_table.parent = self
                                    self._children_name_map["conform_set_prec_transmit_table"] = "conform-set-prec-transmit-table"

                                    self.conform_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmit()
                                    self.conform_set_qos_transmit.parent = self
                                    self._children_name_map["conform_set_qos_transmit"] = "conform-set-qos-transmit"

                                    self.conform_set_qos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmitTable()
                                    self.conform_set_qos_transmit_table.parent = self
                                    self._children_name_map["conform_set_qos_transmit_table"] = "conform-set-qos-transmit-table"

                                    self.conform_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformTransmit()
                                    self.conform_transmit.parent = self
                                    self._children_name_map["conform_transmit"] = "conform-transmit"

                                    self.conform_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformDrop()
                                    self.conform_drop.parent = self
                                    self._children_name_map["conform_drop"] = "conform-drop"

                                    self.exceed_dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDscp()
                                    self.exceed_dscp.parent = self
                                    self._children_name_map["exceed_dscp"] = "exceed-dscp"

                                    self.exceed_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetClpTransmit()
                                    self.exceed_set_clp_transmit.parent = self
                                    self._children_name_map["exceed_set_clp_transmit"] = "exceed-set-clp-transmit"

                                    self.exceed_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetCosTransmit()
                                    self.exceed_set_cos_transmit.parent = self
                                    self._children_name_map["exceed_set_cos_transmit"] = "exceed-set-cos-transmit"

                                    self.exceed_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDiscardClassTransmit()
                                    self.exceed_set_discard_class_transmit.parent = self
                                    self._children_name_map["exceed_set_discard_class_transmit"] = "exceed-set-discard-class-transmit"

                                    self.exceed_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit()
                                    self.exceed_set_dscp_transmit.parent = self
                                    self._children_name_map["exceed_set_dscp_transmit"] = "exceed-set-dscp-transmit"

                                    self.exceed_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmitTable()
                                    self.exceed_set_dscp_transmit_table.parent = self
                                    self._children_name_map["exceed_set_dscp_transmit_table"] = "exceed-set-dscp-transmit-table"

                                    self.exceed_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetFrdeTransmit()
                                    self.exceed_set_frde_transmit.parent = self
                                    self._children_name_map["exceed_set_frde_transmit"] = "exceed-set-frde-transmit"

                                    self.exceed_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpImpositionTransmit()
                                    self.exceed_set_mpls_exp_imposition_transmit.parent = self
                                    self._children_name_map["exceed_set_mpls_exp_imposition_transmit"] = "exceed-set-mpls-exp-imposition-transmit"

                                    self.exceed_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpTopmostTransmit()
                                    self.exceed_set_mpls_exp_topmost_transmit.parent = self
                                    self._children_name_map["exceed_set_mpls_exp_topmost_transmit"] = "exceed-set-mpls-exp-topmost-transmit"

                                    self.exceed_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetPrecTransmit()
                                    self.exceed_set_prec_transmit.parent = self
                                    self._children_name_map["exceed_set_prec_transmit"] = "exceed-set-prec-transmit"

                                    self.exceed_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetQosTransmit()
                                    self.exceed_set_qos_transmit.parent = self
                                    self._children_name_map["exceed_set_qos_transmit"] = "exceed-set-qos-transmit"

                                    self.exceed_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedTransmit()
                                    self.exceed_transmit.parent = self
                                    self._children_name_map["exceed_transmit"] = "exceed-transmit"

                                    self.exceed_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDrop()
                                    self.exceed_drop.parent = self
                                    self._children_name_map["exceed_drop"] = "exceed-drop"

                                    self.violate_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetClpTransmit()
                                    self.violate_set_clp_transmit.parent = self
                                    self._children_name_map["violate_set_clp_transmit"] = "violate-set-clp-transmit"

                                    self.violate_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetCosTransmit()
                                    self.violate_set_cos_transmit.parent = self
                                    self._children_name_map["violate_set_cos_transmit"] = "violate-set-cos-transmit"

                                    self.violate_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDiscardClassTransmit()
                                    self.violate_set_discard_class_transmit.parent = self
                                    self._children_name_map["violate_set_discard_class_transmit"] = "violate-set-discard-class-transmit"

                                    self.violate_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDscpTransmit()
                                    self.violate_set_dscp_transmit.parent = self
                                    self._children_name_map["violate_set_dscp_transmit"] = "violate-set-dscp-transmit"

                                    self.violate_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetFrdeTransmit()
                                    self.violate_set_frde_transmit.parent = self
                                    self._children_name_map["violate_set_frde_transmit"] = "violate-set-frde-transmit"

                                    self.violate_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpImpositionTransmit()
                                    self.violate_set_mpls_exp_imposition_transmit.parent = self
                                    self._children_name_map["violate_set_mpls_exp_imposition_transmit"] = "violate-set-mpls-exp-imposition-transmit"

                                    self.violate_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpTopmostTransmit()
                                    self.violate_set_mpls_exp_topmost_transmit.parent = self
                                    self._children_name_map["violate_set_mpls_exp_topmost_transmit"] = "violate-set-mpls-exp-topmost-transmit"

                                    self.violate_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetPrecTransmit()
                                    self.violate_set_prec_transmit.parent = self
                                    self._children_name_map["violate_set_prec_transmit"] = "violate-set-prec-transmit"

                                    self.violate_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetQosTransmit()
                                    self.violate_set_qos_transmit.parent = self
                                    self._children_name_map["violate_set_qos_transmit"] = "violate-set-qos-transmit"

                                    self.violate_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateTransmit()
                                    self.violate_transmit.parent = self
                                    self._children_name_map["violate_transmit"] = "violate-transmit"

                                    self.violate_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateDrop()
                                    self.violate_drop.parent = self
                                    self._children_name_map["violate_drop"] = "violate-drop"
                                    self._segment_path = lambda: "actions"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions, [], name, value)


                                class ConformSetClpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetClpTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetClpTransmit, self).__init__()

                                        self.yang_name = "conform-set-clp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetClpTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetClpTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-clp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetClpTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_clp_transmit
                                        
                                        	set atm clp and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetClpTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-clp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                            ])
                                            self.set_clp_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetClpTransmit.ConformAction, ['set_clp_transmit'], name, value)


                                class ConformSetCosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmit, self).__init__()

                                        self.yang_name = "conform-set-cos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-cos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-cos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                            ])
                                            self.set_cos_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmit.ConformAction, ['set_cos_transmit'], name, value)


                                class ConformSetCosTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-cos-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-cos-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-cos-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_cos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetCosTransmitTable.ConformAction, ['set_cos_transmit', 'table'], name, value)


                                class ConformSetDiscardClassTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDiscardClassTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDiscardClassTransmit, self).__init__()

                                        self.yang_name = "conform-set-discard-class-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDiscardClassTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDiscardClassTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-discard-class-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDiscardClassTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_discard_class_transmit
                                        
                                        	set discard\-class and send it
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDiscardClassTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-discard-class-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                            ])
                                            self.set_discard_class_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDiscardClassTransmit.ConformAction, ['set_discard_class_transmit'], name, value)


                                class ConformSetDscpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmit, self).__init__()

                                        self.yang_name = "conform-set-dscp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-dscp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-dscp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmit.ConformAction, ['set_dscp_transmit'], name, value)


                                class ConformSetDscpTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-dscp-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-dscp-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-dscp-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetDscpTransmitTable.ConformAction, ['set_dscp_transmit', 'table'], name, value)


                                class ConformSetFrdeTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetFrdeTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetFrdeTransmit, self).__init__()

                                        self.yang_name = "conform-set-frde-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetFrdeTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetFrdeTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-frde-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetFrdeTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_frde_transmit
                                        
                                        	set FR DE and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetFrdeTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-frde-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                            ])
                                            self.set_frde_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetFrdeTransmit.ConformAction, ['set_frde_transmit'], name, value)


                                class ConformSetMplsExpImpositionTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmit, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-imposition-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                class ConformSetMplsExpImpositionTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-imposition-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, ['set_mpls_exp_imposition_transmit', 'table'], name, value)


                                class ConformSetMplsExpTopmostTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmit, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-topmost-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                class ConformSetMplsExpTopmostTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-topmost-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, ['set_mpls_exp_topmost_transmit', 'table'], name, value)


                                class ConformSetPrecTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmit, self).__init__()

                                        self.yang_name = "conform-set-prec-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-prec-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-prec-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                            ])
                                            self.set_prec_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmit.ConformAction, ['set_prec_transmit'], name, value)


                                class ConformSetPrecTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-prec-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-prec-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-prec-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_prec_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetPrecTransmitTable.ConformAction, ['set_prec_transmit', 'table'], name, value)


                                class ConformSetQosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmit, self).__init__()

                                        self.yang_name = "conform-set-qos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-qos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-qos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                            ])
                                            self.set_qos_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmit.ConformAction, ['set_qos_transmit'], name, value)


                                class ConformSetQosTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-qos-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-qos-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-qos-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_qos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformSetQosTransmitTable.ConformAction, ['set_qos_transmit', 'table'], name, value)


                                class ConformTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformTransmit, self).__init__()

                                        self.yang_name = "conform-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: transmit
                                        
                                        	transmit packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                            ])
                                            self.transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformTransmit.ConformAction, ['transmit'], name, value)


                                class ConformDrop(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformDrop.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformDrop, self).__init__()

                                        self.yang_name = "conform-drop"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformDrop.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformDrop.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-drop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformDrop, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: drop
                                        
                                        	drop packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformDrop.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-drop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ])
                                            self.drop = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ConformDrop.ConformAction, ['drop'], name, value)


                                class ExceedDscp(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDscp.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDscp, self).__init__()

                                        self.yang_name = "exceed-dscp"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDscp.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDscp.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-dscp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDscp, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: dscp
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDscp.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-dscp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                            ])
                                            self.dscp = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDscp.ExceedAction, ['dscp'], name, value)


                                class ExceedSetClpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetClpTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetClpTransmit, self).__init__()

                                        self.yang_name = "exceed-set-clp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetClpTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetClpTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-clp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetClpTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_clp_transmit
                                        
                                        	set atm clp and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetClpTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-clp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                            ])
                                            self.set_clp_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetClpTransmit.ExceedAction, ['set_clp_transmit'], name, value)


                                class ExceedSetCosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetCosTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetCosTransmit, self).__init__()

                                        self.yang_name = "exceed-set-cos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetCosTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetCosTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-cos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetCosTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetCosTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-cos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_cos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetCosTransmit.ExceedAction, ['set_cos_transmit', 'table'], name, value)


                                class ExceedSetDiscardClassTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDiscardClassTransmit, self).__init__()

                                        self.yang_name = "exceed-set-discard-class-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-discard-class-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDiscardClassTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_discard_class_transmit
                                        
                                        	set discard\-class and send it
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-discard-class-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                            ])
                                            self.set_discard_class_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction, ['set_discard_class_transmit'], name, value)


                                class ExceedSetDscpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit, self).__init__()

                                        self.yang_name = "exceed-set-dscp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-dscp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`SetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-dscp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("set-dscp-transmit", ("set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit))])
                                            self._leafs = OrderedDict()

                                            self.set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit()
                                            self.set_dscp_transmit.parent = self
                                            self._children_name_map["set_dscp_transmit"] = "set-dscp-transmit"
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction, [], name, value)


                                        class SetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: dscp
                                            
                                            	
                                            	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, self).__init__()

                                                self.yang_name = "set-dscp-transmit"
                                                self.yang_parent_name = "exceed-action"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp))])
                                                self._leafs = OrderedDict()

                                                self.dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp()
                                                self.dscp.parent = self
                                                self._children_name_map["dscp"] = "dscp"
                                                self._segment_path = lambda: "set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, [], name, value)


                                            class Dscp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: table
                                                
                                                	
                                                	**type**\:  :py:class:`Table <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, self).__init__()

                                                    self.yang_name = "dscp"
                                                    self.yang_parent_name = "set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('table', (YLeaf(YType.enumeration, 'table'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table')])),
                                                    ])
                                                    self.table = None
                                                    self._segment_path = lambda: "dscp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, ['table'], name, value)

                                                class Table(Enum):
                                                    """
                                                    Table (Enum Class)

                                                    .. data:: policed_dscp = 0

                                                    """

                                                    policed_dscp = Enum.YLeaf(0, "policed-dscp")



                                class ExceedSetDscpTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmitTable, self).__init__()

                                        self.yang_name = "exceed-set-dscp-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-dscp-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmitTable, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-dscp-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction, ['set_dscp_transmit', 'table'], name, value)


                                class ExceedSetFrdeTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetFrdeTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetFrdeTransmit, self).__init__()

                                        self.yang_name = "exceed-set-frde-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetFrdeTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetFrdeTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-frde-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetFrdeTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_frde_transmit
                                        
                                        	set FR DE and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetFrdeTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-frde-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                            ])
                                            self.set_frde_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetFrdeTransmit.ExceedAction, ['set_frde_transmit'], name, value)


                                class ExceedSetMplsExpImpositionTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpImpositionTransmit, self).__init__()

                                        self.yang_name = "exceed-set-mpls-exp-imposition-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-mpls-exp-imposition-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpImpositionTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-mpls-exp-imposition-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                class ExceedSetMplsExpTopmostTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpTopmostTransmit, self).__init__()

                                        self.yang_name = "exceed-set-mpls-exp-topmost-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-mpls-exp-topmost-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpTopmostTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-mpls-exp-topmost-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                class ExceedSetPrecTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetPrecTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetPrecTransmit, self).__init__()

                                        self.yang_name = "exceed-set-prec-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetPrecTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetPrecTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-prec-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetPrecTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetPrecTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-prec-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_prec_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetPrecTransmit.ExceedAction, ['set_prec_transmit', 'table'], name, value)


                                class ExceedSetQosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetQosTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetQosTransmit, self).__init__()

                                        self.yang_name = "exceed-set-qos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetQosTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetQosTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-qos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetQosTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetQosTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-qos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                            ])
                                            self.set_qos_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedSetQosTransmit.ExceedAction, ['set_qos_transmit'], name, value)


                                class ExceedTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedTransmit, self).__init__()

                                        self.yang_name = "exceed-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: transmit
                                        
                                        	transmit packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                            ])
                                            self.transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedTransmit.ExceedAction, ['transmit'], name, value)


                                class ExceedDrop(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDrop.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDrop, self).__init__()

                                        self.yang_name = "exceed-drop"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDrop.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDrop.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-drop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDrop, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: drop
                                        
                                        	drop packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDrop.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-drop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ])
                                            self.drop = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ExceedDrop.ExceedAction, ['drop'], name, value)


                                class ViolateSetClpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetClpTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetClpTransmit, self).__init__()

                                        self.yang_name = "violate-set-clp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetClpTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetClpTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-clp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetClpTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_clp_transmit
                                        
                                        	set atm clp and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetClpTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-clp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                            ])
                                            self.set_clp_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetClpTransmit.ViolateAction, ['set_clp_transmit'], name, value)


                                class ViolateSetCosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetCosTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetCosTransmit, self).__init__()

                                        self.yang_name = "violate-set-cos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetCosTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetCosTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-cos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetCosTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetCosTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-cos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_cos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetCosTransmit.ViolateAction, ['set_cos_transmit', 'table'], name, value)


                                class ViolateSetDiscardClassTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDiscardClassTransmit, self).__init__()

                                        self.yang_name = "violate-set-discard-class-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-discard-class-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDiscardClassTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_discard_class_transmit
                                        
                                        	set discard\-class and send it
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-discard-class-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                            ])
                                            self.set_discard_class_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction, ['set_discard_class_transmit'], name, value)


                                class ViolateSetDscpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDscpTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDscpTransmit, self).__init__()

                                        self.yang_name = "violate-set-dscp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDscpTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDscpTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-dscp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDscpTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDscpTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-dscp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetDscpTransmit.ViolateAction, ['set_dscp_transmit', 'table'], name, value)


                                class ViolateSetFrdeTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetFrdeTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetFrdeTransmit, self).__init__()

                                        self.yang_name = "violate-set-frde-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetFrdeTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetFrdeTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-frde-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetFrdeTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_frde_transmit
                                        
                                        	set FR DE and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetFrdeTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-frde-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                            ])
                                            self.set_frde_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetFrdeTransmit.ViolateAction, ['set_frde_transmit'], name, value)


                                class ViolateSetMplsExpImpositionTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpImpositionTransmit, self).__init__()

                                        self.yang_name = "violate-set-mpls-exp-imposition-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-mpls-exp-imposition-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpImpositionTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-mpls-exp-imposition-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                class ViolateSetMplsExpTopmostTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpTopmostTransmit, self).__init__()

                                        self.yang_name = "violate-set-mpls-exp-topmost-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-mpls-exp-topmost-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpTopmostTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-mpls-exp-topmost-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                class ViolateSetPrecTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetPrecTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetPrecTransmit, self).__init__()

                                        self.yang_name = "violate-set-prec-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetPrecTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetPrecTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-prec-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetPrecTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetPrecTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-prec-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_prec_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetPrecTransmit.ViolateAction, ['set_prec_transmit', 'table'], name, value)


                                class ViolateSetQosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetQosTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetQosTransmit, self).__init__()

                                        self.yang_name = "violate-set-qos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetQosTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetQosTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-qos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetQosTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetQosTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-qos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                            ])
                                            self.set_qos_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateSetQosTransmit.ViolateAction, ['set_qos_transmit'], name, value)


                                class ViolateTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateTransmit, self).__init__()

                                        self.yang_name = "violate-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: transmit
                                        
                                        	transmit packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                            ])
                                            self.transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateTransmit.ViolateAction, ['transmit'], name, value)


                                class ViolateDrop(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateDrop.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateDrop, self).__init__()

                                        self.yang_name = "violate-drop"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateDrop.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateDrop.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-drop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateDrop, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: drop
                                        
                                        	drop packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateDrop.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-drop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ])
                                            self.drop = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceTargetBitrate.Police.Actions.ViolateDrop.ViolateAction, ['drop'], name, value)


                    class PoliceFlow(Entity):
                        """
                        
                        
                        .. attribute:: police
                        
                        	
                        	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow, self).__init__()

                            self.yang_name = "police-flow"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("police", ("police", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police))])
                            self._leafs = OrderedDict()

                            self.police = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police()
                            self.police.parent = self
                            self._children_name_map["police"] = "police"
                            self._segment_path = lambda: "police-flow"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow, [], name, value)


                        class Police(Entity):
                            """
                            
                            
                            .. attribute:: flow
                            
                            	police each flow
                            	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police, self).__init__()

                                self.yang_name = "police"
                                self.yang_parent_name = "police-flow"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("flow", ("flow", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow))])
                                self._leafs = OrderedDict()

                                self.flow = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow()
                                self.flow.parent = self
                                self._children_name_map["flow"] = "flow"
                                self._segment_path = lambda: "police"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police, [], name, value)


                            class Flow(Entity):
                                """
                                police each flow
                                
                                .. attribute:: mask
                                
                                	flow mask to be used for policing
                                	**type**\:  :py:class:`Mask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Mask>`
                                
                                .. attribute:: bps
                                
                                	
                                	**type**\: int
                                
                                	**range:** 8000..64000000000
                                
                                .. attribute:: burst_normal
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1000..512000000
                                
                                .. attribute:: actions
                                
                                	
                                	**type**\:  :py:class:`Actions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow, self).__init__()

                                    self.yang_name = "flow"
                                    self.yang_parent_name = "police"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("actions", ("actions", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions))])
                                    self._leafs = OrderedDict([
                                        ('mask', (YLeaf(YType.enumeration, 'mask'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Mask')])),
                                        ('bps', (YLeaf(YType.uint64, 'bps'), ['int'])),
                                        ('burst_normal', (YLeaf(YType.uint32, 'burst-normal'), ['int'])),
                                    ])
                                    self.mask = None
                                    self.bps = None
                                    self.burst_normal = None

                                    self.actions = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions()
                                    self.actions.parent = self
                                    self._children_name_map["actions"] = "actions"
                                    self._segment_path = lambda: "flow"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow, ['mask', 'bps', 'burst_normal'], name, value)

                                class Mask(Enum):
                                    """
                                    Mask (Enum Class)

                                    flow mask to be used for policing

                                    .. data:: dest_only = 0

                                    .. data:: full_flow = 1

                                    .. data:: src_only = 2

                                    """

                                    dest_only = Enum.YLeaf(0, "dest-only")

                                    full_flow = Enum.YLeaf(1, "full-flow")

                                    src_only = Enum.YLeaf(2, "src-only")



                                class Actions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_set_clp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetClpTransmit>`
                                    
                                    .. attribute:: conform_set_cos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmit>`
                                    
                                    .. attribute:: conform_set_cos_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetCosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmitTable>`
                                    
                                    .. attribute:: conform_set_discard_class_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDiscardClassTransmit>`
                                    
                                    .. attribute:: conform_set_dscp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmit>`
                                    
                                    .. attribute:: conform_set_dscp_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmitTable>`
                                    
                                    .. attribute:: conform_set_frde_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetFrdeTransmit>`
                                    
                                    .. attribute:: conform_set_mpls_exp_imposition_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmit>`
                                    
                                    .. attribute:: conform_set_mpls_exp_imposition_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmitTable>`
                                    
                                    .. attribute:: conform_set_mpls_exp_topmost_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmit>`
                                    
                                    .. attribute:: conform_set_mpls_exp_topmost_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmitTable>`
                                    
                                    .. attribute:: conform_set_prec_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmit>`
                                    
                                    .. attribute:: conform_set_prec_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetPrecTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmitTable>`
                                    
                                    .. attribute:: conform_set_qos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmit>`
                                    
                                    .. attribute:: conform_set_qos_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ConformSetQosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmitTable>`
                                    
                                    .. attribute:: conform_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ConformTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformTransmit>`
                                    
                                    .. attribute:: conform_drop
                                    
                                    	
                                    	**type**\:  :py:class:`ConformDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformDrop>`
                                    
                                    .. attribute:: exceed_dscp
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedDscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDscp>`
                                    
                                    .. attribute:: exceed_set_clp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetClpTransmit>`
                                    
                                    .. attribute:: exceed_set_cos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetCosTransmit>`
                                    
                                    .. attribute:: exceed_set_discard_class_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDiscardClassTransmit>`
                                    
                                    .. attribute:: exceed_set_dscp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit>`
                                    
                                    .. attribute:: exceed_set_dscp_transmit_table
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmitTable>`
                                    
                                    .. attribute:: exceed_set_frde_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetFrdeTransmit>`
                                    
                                    .. attribute:: exceed_set_mpls_exp_imposition_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpImpositionTransmit>`
                                    
                                    .. attribute:: exceed_set_mpls_exp_topmost_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpTopmostTransmit>`
                                    
                                    .. attribute:: exceed_set_prec_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetPrecTransmit>`
                                    
                                    .. attribute:: exceed_set_qos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetQosTransmit>`
                                    
                                    .. attribute:: exceed_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedTransmit>`
                                    
                                    .. attribute:: exceed_drop
                                    
                                    	
                                    	**type**\:  :py:class:`ExceedDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDrop>`
                                    
                                    .. attribute:: violate_set_clp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetClpTransmit>`
                                    
                                    .. attribute:: violate_set_cos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetCosTransmit>`
                                    
                                    .. attribute:: violate_set_discard_class_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDiscardClassTransmit>`
                                    
                                    .. attribute:: violate_set_dscp_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDscpTransmit>`
                                    
                                    .. attribute:: violate_set_frde_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetFrdeTransmit>`
                                    
                                    .. attribute:: violate_set_mpls_exp_imposition_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpImpositionTransmit>`
                                    
                                    .. attribute:: violate_set_mpls_exp_topmost_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpTopmostTransmit>`
                                    
                                    .. attribute:: violate_set_prec_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetPrecTransmit>`
                                    
                                    .. attribute:: violate_set_qos_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetQosTransmit>`
                                    
                                    .. attribute:: violate_transmit
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateTransmit>`
                                    
                                    .. attribute:: violate_drop
                                    
                                    	
                                    	**type**\:  :py:class:`ViolateDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateDrop>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions, self).__init__()

                                        self.yang_name = "actions"
                                        self.yang_parent_name = "flow"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-set-clp-transmit", ("conform_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetClpTransmit)), ("conform-set-cos-transmit", ("conform_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmit)), ("conform-set-cos-transmit-table", ("conform_set_cos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmitTable)), ("conform-set-discard-class-transmit", ("conform_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDiscardClassTransmit)), ("conform-set-dscp-transmit", ("conform_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmit)), ("conform-set-dscp-transmit-table", ("conform_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmitTable)), ("conform-set-frde-transmit", ("conform_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetFrdeTransmit)), ("conform-set-mpls-exp-imposition-transmit", ("conform_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmit)), ("conform-set-mpls-exp-imposition-transmit-table", ("conform_set_mpls_exp_imposition_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmitTable)), ("conform-set-mpls-exp-topmost-transmit", ("conform_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmit)), ("conform-set-mpls-exp-topmost-transmit-table", ("conform_set_mpls_exp_topmost_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmitTable)), ("conform-set-prec-transmit", ("conform_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmit)), ("conform-set-prec-transmit-table", ("conform_set_prec_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmitTable)), ("conform-set-qos-transmit", ("conform_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmit)), ("conform-set-qos-transmit-table", ("conform_set_qos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmitTable)), ("conform-transmit", ("conform_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformTransmit)), ("conform-drop", ("conform_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformDrop)), ("exceed-dscp", ("exceed_dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDscp)), ("exceed-set-clp-transmit", ("exceed_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetClpTransmit)), ("exceed-set-cos-transmit", ("exceed_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetCosTransmit)), ("exceed-set-discard-class-transmit", ("exceed_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDiscardClassTransmit)), ("exceed-set-dscp-transmit", ("exceed_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit)), ("exceed-set-dscp-transmit-table", ("exceed_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmitTable)), ("exceed-set-frde-transmit", ("exceed_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetFrdeTransmit)), ("exceed-set-mpls-exp-imposition-transmit", ("exceed_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpImpositionTransmit)), ("exceed-set-mpls-exp-topmost-transmit", ("exceed_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpTopmostTransmit)), ("exceed-set-prec-transmit", ("exceed_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetPrecTransmit)), ("exceed-set-qos-transmit", ("exceed_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetQosTransmit)), ("exceed-transmit", ("exceed_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedTransmit)), ("exceed-drop", ("exceed_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDrop)), ("violate-set-clp-transmit", ("violate_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetClpTransmit)), ("violate-set-cos-transmit", ("violate_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetCosTransmit)), ("violate-set-discard-class-transmit", ("violate_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDiscardClassTransmit)), ("violate-set-dscp-transmit", ("violate_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDscpTransmit)), ("violate-set-frde-transmit", ("violate_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetFrdeTransmit)), ("violate-set-mpls-exp-imposition-transmit", ("violate_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpImpositionTransmit)), ("violate-set-mpls-exp-topmost-transmit", ("violate_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpTopmostTransmit)), ("violate-set-prec-transmit", ("violate_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetPrecTransmit)), ("violate-set-qos-transmit", ("violate_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetQosTransmit)), ("violate-transmit", ("violate_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateTransmit)), ("violate-drop", ("violate_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateDrop))])
                                        self._leafs = OrderedDict()

                                        self.conform_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetClpTransmit()
                                        self.conform_set_clp_transmit.parent = self
                                        self._children_name_map["conform_set_clp_transmit"] = "conform-set-clp-transmit"

                                        self.conform_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmit()
                                        self.conform_set_cos_transmit.parent = self
                                        self._children_name_map["conform_set_cos_transmit"] = "conform-set-cos-transmit"

                                        self.conform_set_cos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmitTable()
                                        self.conform_set_cos_transmit_table.parent = self
                                        self._children_name_map["conform_set_cos_transmit_table"] = "conform-set-cos-transmit-table"

                                        self.conform_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDiscardClassTransmit()
                                        self.conform_set_discard_class_transmit.parent = self
                                        self._children_name_map["conform_set_discard_class_transmit"] = "conform-set-discard-class-transmit"

                                        self.conform_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmit()
                                        self.conform_set_dscp_transmit.parent = self
                                        self._children_name_map["conform_set_dscp_transmit"] = "conform-set-dscp-transmit"

                                        self.conform_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmitTable()
                                        self.conform_set_dscp_transmit_table.parent = self
                                        self._children_name_map["conform_set_dscp_transmit_table"] = "conform-set-dscp-transmit-table"

                                        self.conform_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetFrdeTransmit()
                                        self.conform_set_frde_transmit.parent = self
                                        self._children_name_map["conform_set_frde_transmit"] = "conform-set-frde-transmit"

                                        self.conform_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmit()
                                        self.conform_set_mpls_exp_imposition_transmit.parent = self
                                        self._children_name_map["conform_set_mpls_exp_imposition_transmit"] = "conform-set-mpls-exp-imposition-transmit"

                                        self.conform_set_mpls_exp_imposition_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmitTable()
                                        self.conform_set_mpls_exp_imposition_transmit_table.parent = self
                                        self._children_name_map["conform_set_mpls_exp_imposition_transmit_table"] = "conform-set-mpls-exp-imposition-transmit-table"

                                        self.conform_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmit()
                                        self.conform_set_mpls_exp_topmost_transmit.parent = self
                                        self._children_name_map["conform_set_mpls_exp_topmost_transmit"] = "conform-set-mpls-exp-topmost-transmit"

                                        self.conform_set_mpls_exp_topmost_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmitTable()
                                        self.conform_set_mpls_exp_topmost_transmit_table.parent = self
                                        self._children_name_map["conform_set_mpls_exp_topmost_transmit_table"] = "conform-set-mpls-exp-topmost-transmit-table"

                                        self.conform_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmit()
                                        self.conform_set_prec_transmit.parent = self
                                        self._children_name_map["conform_set_prec_transmit"] = "conform-set-prec-transmit"

                                        self.conform_set_prec_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmitTable()
                                        self.conform_set_prec_transmit_table.parent = self
                                        self._children_name_map["conform_set_prec_transmit_table"] = "conform-set-prec-transmit-table"

                                        self.conform_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmit()
                                        self.conform_set_qos_transmit.parent = self
                                        self._children_name_map["conform_set_qos_transmit"] = "conform-set-qos-transmit"

                                        self.conform_set_qos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmitTable()
                                        self.conform_set_qos_transmit_table.parent = self
                                        self._children_name_map["conform_set_qos_transmit_table"] = "conform-set-qos-transmit-table"

                                        self.conform_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformTransmit()
                                        self.conform_transmit.parent = self
                                        self._children_name_map["conform_transmit"] = "conform-transmit"

                                        self.conform_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformDrop()
                                        self.conform_drop.parent = self
                                        self._children_name_map["conform_drop"] = "conform-drop"

                                        self.exceed_dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDscp()
                                        self.exceed_dscp.parent = self
                                        self._children_name_map["exceed_dscp"] = "exceed-dscp"

                                        self.exceed_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetClpTransmit()
                                        self.exceed_set_clp_transmit.parent = self
                                        self._children_name_map["exceed_set_clp_transmit"] = "exceed-set-clp-transmit"

                                        self.exceed_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetCosTransmit()
                                        self.exceed_set_cos_transmit.parent = self
                                        self._children_name_map["exceed_set_cos_transmit"] = "exceed-set-cos-transmit"

                                        self.exceed_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDiscardClassTransmit()
                                        self.exceed_set_discard_class_transmit.parent = self
                                        self._children_name_map["exceed_set_discard_class_transmit"] = "exceed-set-discard-class-transmit"

                                        self.exceed_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit()
                                        self.exceed_set_dscp_transmit.parent = self
                                        self._children_name_map["exceed_set_dscp_transmit"] = "exceed-set-dscp-transmit"

                                        self.exceed_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmitTable()
                                        self.exceed_set_dscp_transmit_table.parent = self
                                        self._children_name_map["exceed_set_dscp_transmit_table"] = "exceed-set-dscp-transmit-table"

                                        self.exceed_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetFrdeTransmit()
                                        self.exceed_set_frde_transmit.parent = self
                                        self._children_name_map["exceed_set_frde_transmit"] = "exceed-set-frde-transmit"

                                        self.exceed_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpImpositionTransmit()
                                        self.exceed_set_mpls_exp_imposition_transmit.parent = self
                                        self._children_name_map["exceed_set_mpls_exp_imposition_transmit"] = "exceed-set-mpls-exp-imposition-transmit"

                                        self.exceed_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpTopmostTransmit()
                                        self.exceed_set_mpls_exp_topmost_transmit.parent = self
                                        self._children_name_map["exceed_set_mpls_exp_topmost_transmit"] = "exceed-set-mpls-exp-topmost-transmit"

                                        self.exceed_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetPrecTransmit()
                                        self.exceed_set_prec_transmit.parent = self
                                        self._children_name_map["exceed_set_prec_transmit"] = "exceed-set-prec-transmit"

                                        self.exceed_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetQosTransmit()
                                        self.exceed_set_qos_transmit.parent = self
                                        self._children_name_map["exceed_set_qos_transmit"] = "exceed-set-qos-transmit"

                                        self.exceed_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedTransmit()
                                        self.exceed_transmit.parent = self
                                        self._children_name_map["exceed_transmit"] = "exceed-transmit"

                                        self.exceed_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDrop()
                                        self.exceed_drop.parent = self
                                        self._children_name_map["exceed_drop"] = "exceed-drop"

                                        self.violate_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetClpTransmit()
                                        self.violate_set_clp_transmit.parent = self
                                        self._children_name_map["violate_set_clp_transmit"] = "violate-set-clp-transmit"

                                        self.violate_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetCosTransmit()
                                        self.violate_set_cos_transmit.parent = self
                                        self._children_name_map["violate_set_cos_transmit"] = "violate-set-cos-transmit"

                                        self.violate_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDiscardClassTransmit()
                                        self.violate_set_discard_class_transmit.parent = self
                                        self._children_name_map["violate_set_discard_class_transmit"] = "violate-set-discard-class-transmit"

                                        self.violate_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDscpTransmit()
                                        self.violate_set_dscp_transmit.parent = self
                                        self._children_name_map["violate_set_dscp_transmit"] = "violate-set-dscp-transmit"

                                        self.violate_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetFrdeTransmit()
                                        self.violate_set_frde_transmit.parent = self
                                        self._children_name_map["violate_set_frde_transmit"] = "violate-set-frde-transmit"

                                        self.violate_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpImpositionTransmit()
                                        self.violate_set_mpls_exp_imposition_transmit.parent = self
                                        self._children_name_map["violate_set_mpls_exp_imposition_transmit"] = "violate-set-mpls-exp-imposition-transmit"

                                        self.violate_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpTopmostTransmit()
                                        self.violate_set_mpls_exp_topmost_transmit.parent = self
                                        self._children_name_map["violate_set_mpls_exp_topmost_transmit"] = "violate-set-mpls-exp-topmost-transmit"

                                        self.violate_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetPrecTransmit()
                                        self.violate_set_prec_transmit.parent = self
                                        self._children_name_map["violate_set_prec_transmit"] = "violate-set-prec-transmit"

                                        self.violate_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetQosTransmit()
                                        self.violate_set_qos_transmit.parent = self
                                        self._children_name_map["violate_set_qos_transmit"] = "violate-set-qos-transmit"

                                        self.violate_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateTransmit()
                                        self.violate_transmit.parent = self
                                        self._children_name_map["violate_transmit"] = "violate-transmit"

                                        self.violate_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateDrop()
                                        self.violate_drop.parent = self
                                        self._children_name_map["violate_drop"] = "violate-drop"
                                        self._segment_path = lambda: "actions"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions, [], name, value)


                                    class ConformSetClpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetClpTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetClpTransmit, self).__init__()

                                            self.yang_name = "conform-set-clp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetClpTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetClpTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-clp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetClpTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_clp_transmit
                                            
                                            	set atm clp and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetClpTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-clp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                ])
                                                self.set_clp_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetClpTransmit.ConformAction, ['set_clp_transmit'], name, value)


                                    class ConformSetCosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmit, self).__init__()

                                            self.yang_name = "conform-set-cos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-cos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_cos_transmit
                                            
                                            	rewrite packet cos and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-cos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                ])
                                                self.set_cos_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmit.ConformAction, ['set_cos_transmit'], name, value)


                                    class ConformSetCosTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-cos-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-cos-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_cos_transmit
                                            
                                            	rewrite packet cos and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-cos-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_cos_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetCosTransmitTable.ConformAction, ['set_cos_transmit', 'table'], name, value)


                                    class ConformSetDiscardClassTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDiscardClassTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDiscardClassTransmit, self).__init__()

                                            self.yang_name = "conform-set-discard-class-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDiscardClassTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDiscardClassTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-discard-class-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDiscardClassTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_discard_class_transmit
                                            
                                            	set discard\-class and send it
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDiscardClassTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-discard-class-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                ])
                                                self.set_discard_class_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDiscardClassTransmit.ConformAction, ['set_discard_class_transmit'], name, value)


                                    class ConformSetDscpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmit, self).__init__()

                                            self.yang_name = "conform-set-dscp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-dscp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_dscp_transmit
                                            
                                            	set dscp and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..63
                                            
                                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-dscp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ])
                                                self.set_dscp_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmit.ConformAction, ['set_dscp_transmit'], name, value)


                                    class ConformSetDscpTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-dscp-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-dscp-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_dscp_transmit
                                            
                                            	set dscp and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..63
                                            
                                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-dscp-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_dscp_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetDscpTransmitTable.ConformAction, ['set_dscp_transmit', 'table'], name, value)


                                    class ConformSetFrdeTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetFrdeTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetFrdeTransmit, self).__init__()

                                            self.yang_name = "conform-set-frde-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetFrdeTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetFrdeTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-frde-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetFrdeTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_frde_transmit
                                            
                                            	set FR DE and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetFrdeTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-frde-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                ])
                                                self.set_frde_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetFrdeTransmit.ConformAction, ['set_frde_transmit'], name, value)


                                    class ConformSetMplsExpImpositionTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmit, self).__init__()

                                            self.yang_name = "conform-set-mpls-exp-imposition-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_mpls_exp_imposition_transmit
                                            
                                            	set exp at tag imposition and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_imposition_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                    class ConformSetMplsExpImpositionTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-mpls-exp-imposition-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_mpls_exp_imposition_transmit
                                            
                                            	set exp at tag imposition and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_mpls_exp_imposition_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, ['set_mpls_exp_imposition_transmit', 'table'], name, value)


                                    class ConformSetMplsExpTopmostTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmit, self).__init__()

                                            self.yang_name = "conform-set-mpls-exp-topmost-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_mpls_exp_topmost_transmit
                                            
                                            	set exp on topmost label and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_topmost_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                    class ConformSetMplsExpTopmostTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-mpls-exp-topmost-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_mpls_exp_topmost_transmit
                                            
                                            	set exp on topmost label and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_mpls_exp_topmost_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, ['set_mpls_exp_topmost_transmit', 'table'], name, value)


                                    class ConformSetPrecTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmit, self).__init__()

                                            self.yang_name = "conform-set-prec-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-prec-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_prec_transmit
                                            
                                            	rewrite packet precedence and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-prec-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                ])
                                                self.set_prec_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmit.ConformAction, ['set_prec_transmit'], name, value)


                                    class ConformSetPrecTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-prec-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-prec-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_prec_transmit
                                            
                                            	rewrite packet precedence and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-prec-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_prec_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetPrecTransmitTable.ConformAction, ['set_prec_transmit', 'table'], name, value)


                                    class ConformSetQosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmit, self).__init__()

                                            self.yang_name = "conform-set-qos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-qos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_qos_transmit
                                            
                                            	set qos\-group and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..99
                                            
                                            		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-qos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                ])
                                                self.set_qos_transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmit.ConformAction, ['set_qos_transmit'], name, value)


                                    class ConformSetQosTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmitTable.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmitTable, self).__init__()

                                            self.yang_name = "conform-set-qos-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmitTable.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmitTable.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-set-qos-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmitTable, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: set_qos_transmit
                                            
                                            	set qos\-group and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..99
                                            
                                            		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmitTable.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-set-qos-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_qos_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformSetQosTransmitTable.ConformAction, ['set_qos_transmit', 'table'], name, value)


                                    class ConformTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformTransmit.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformTransmit, self).__init__()

                                            self.yang_name = "conform-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformTransmit.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformTransmit.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformTransmit, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: transmit
                                            
                                            	transmit packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformTransmit.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                ])
                                                self.transmit = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformTransmit.ConformAction, ['transmit'], name, value)


                                    class ConformDrop(Entity):
                                        """
                                        
                                        
                                        .. attribute:: conform_action
                                        
                                        	action when rate is less than conform burst
                                        	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformDrop.ConformAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformDrop, self).__init__()

                                            self.yang_name = "conform-drop"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformDrop.ConformAction))])
                                            self._leafs = OrderedDict()

                                            self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformDrop.ConformAction()
                                            self.conform_action.parent = self
                                            self._children_name_map["conform_action"] = "conform-action"
                                            self._segment_path = lambda: "conform-drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformDrop, [], name, value)


                                        class ConformAction(Entity):
                                            """
                                            action when rate is less than conform burst
                                            
                                            .. attribute:: drop
                                            
                                            	drop packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformDrop.ConformAction, self).__init__()

                                                self.yang_name = "conform-action"
                                                self.yang_parent_name = "conform-drop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ])
                                                self.drop = None
                                                self._segment_path = lambda: "conform-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ConformDrop.ConformAction, ['drop'], name, value)


                                    class ExceedDscp(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDscp.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDscp, self).__init__()

                                            self.yang_name = "exceed-dscp"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDscp.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDscp.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-dscp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDscp, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: dscp
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..63
                                            
                                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDscp.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-dscp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ])
                                                self.dscp = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDscp.ExceedAction, ['dscp'], name, value)


                                    class ExceedSetClpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetClpTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetClpTransmit, self).__init__()

                                            self.yang_name = "exceed-set-clp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetClpTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetClpTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-clp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetClpTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_clp_transmit
                                            
                                            	set atm clp and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetClpTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-clp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                ])
                                                self.set_clp_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetClpTransmit.ExceedAction, ['set_clp_transmit'], name, value)


                                    class ExceedSetCosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetCosTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetCosTransmit, self).__init__()

                                            self.yang_name = "exceed-set-cos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetCosTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetCosTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-cos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetCosTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_cos_transmit
                                            
                                            	rewrite packet cos and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetCosTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-cos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_cos_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetCosTransmit.ExceedAction, ['set_cos_transmit', 'table'], name, value)


                                    class ExceedSetDiscardClassTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDiscardClassTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDiscardClassTransmit, self).__init__()

                                            self.yang_name = "exceed-set-discard-class-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDiscardClassTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDiscardClassTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-discard-class-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDiscardClassTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_discard_class_transmit
                                            
                                            	set discard\-class and send it
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDiscardClassTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-discard-class-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                ])
                                                self.set_discard_class_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDiscardClassTransmit.ExceedAction, ['set_discard_class_transmit'], name, value)


                                    class ExceedSetDscpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit, self).__init__()

                                            self.yang_name = "exceed-set-dscp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-dscp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_dscp_transmit
                                            
                                            	
                                            	**type**\:  :py:class:`SetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-dscp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("set-dscp-transmit", ("set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit))])
                                                self._leafs = OrderedDict()

                                                self.set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit()
                                                self.set_dscp_transmit.parent = self
                                                self._children_name_map["set_dscp_transmit"] = "set-dscp-transmit"
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction, [], name, value)


                                            class SetDscpTransmit(Entity):
                                                """
                                                
                                                
                                                .. attribute:: dscp
                                                
                                                	
                                                	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, self).__init__()

                                                    self.yang_name = "set-dscp-transmit"
                                                    self.yang_parent_name = "exceed-action"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp))])
                                                    self._leafs = OrderedDict()

                                                    self.dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp()
                                                    self.dscp.parent = self
                                                    self._children_name_map["dscp"] = "dscp"
                                                    self._segment_path = lambda: "set-dscp-transmit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, [], name, value)


                                                class Dscp(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: table
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Table <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-policy'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, self).__init__()

                                                        self.yang_name = "dscp"
                                                        self.yang_parent_name = "set-dscp-transmit"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('table', (YLeaf(YType.enumeration, 'table'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table')])),
                                                        ])
                                                        self.table = None
                                                        self._segment_path = lambda: "dscp"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, ['table'], name, value)

                                                    class Table(Enum):
                                                        """
                                                        Table (Enum Class)

                                                        .. data:: policed_dscp = 0

                                                        """

                                                        policed_dscp = Enum.YLeaf(0, "policed-dscp")



                                    class ExceedSetDscpTransmitTable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmitTable.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmitTable, self).__init__()

                                            self.yang_name = "exceed-set-dscp-transmit-table"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmitTable.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmitTable.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-dscp-transmit-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmitTable, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_dscp_transmit
                                            
                                            	set dscp and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..63
                                            
                                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmitTable.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-dscp-transmit-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_dscp_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetDscpTransmitTable.ExceedAction, ['set_dscp_transmit', 'table'], name, value)


                                    class ExceedSetFrdeTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetFrdeTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetFrdeTransmit, self).__init__()

                                            self.yang_name = "exceed-set-frde-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetFrdeTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetFrdeTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-frde-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetFrdeTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_frde_transmit
                                            
                                            	set FR DE and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetFrdeTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-frde-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                ])
                                                self.set_frde_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetFrdeTransmit.ExceedAction, ['set_frde_transmit'], name, value)


                                    class ExceedSetMplsExpImpositionTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpImpositionTransmit, self).__init__()

                                            self.yang_name = "exceed-set-mpls-exp-imposition-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-mpls-exp-imposition-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpImpositionTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_mpls_exp_imposition_transmit
                                            
                                            	set exp at tag imposition and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-mpls-exp-imposition-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_imposition_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                    class ExceedSetMplsExpTopmostTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpTopmostTransmit, self).__init__()

                                            self.yang_name = "exceed-set-mpls-exp-topmost-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-mpls-exp-topmost-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpTopmostTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_mpls_exp_topmost_transmit
                                            
                                            	set exp on topmost label and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-mpls-exp-topmost-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_topmost_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                    class ExceedSetPrecTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetPrecTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetPrecTransmit, self).__init__()

                                            self.yang_name = "exceed-set-prec-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetPrecTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetPrecTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-prec-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetPrecTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_prec_transmit
                                            
                                            	rewrite packet precedence and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetPrecTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-prec-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_prec_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetPrecTransmit.ExceedAction, ['set_prec_transmit', 'table'], name, value)


                                    class ExceedSetQosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetQosTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetQosTransmit, self).__init__()

                                            self.yang_name = "exceed-set-qos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetQosTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetQosTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-set-qos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetQosTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: set_qos_transmit
                                            
                                            	set qos\-group and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..99
                                            
                                            		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetQosTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-set-qos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                ])
                                                self.set_qos_transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedSetQosTransmit.ExceedAction, ['set_qos_transmit'], name, value)


                                    class ExceedTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedTransmit.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedTransmit, self).__init__()

                                            self.yang_name = "exceed-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedTransmit.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedTransmit.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedTransmit, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: transmit
                                            
                                            	transmit packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedTransmit.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                ])
                                                self.transmit = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedTransmit.ExceedAction, ['transmit'], name, value)


                                    class ExceedDrop(Entity):
                                        """
                                        
                                        
                                        .. attribute:: exceed_action
                                        
                                        	action when rate is within conform and conform + exceed burst
                                        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDrop.ExceedAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDrop, self).__init__()

                                            self.yang_name = "exceed-drop"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDrop.ExceedAction))])
                                            self._leafs = OrderedDict()

                                            self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDrop.ExceedAction()
                                            self.exceed_action.parent = self
                                            self._children_name_map["exceed_action"] = "exceed-action"
                                            self._segment_path = lambda: "exceed-drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDrop, [], name, value)


                                        class ExceedAction(Entity):
                                            """
                                            action when rate is within conform and conform + exceed burst
                                            
                                            .. attribute:: drop
                                            
                                            	drop packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDrop.ExceedAction, self).__init__()

                                                self.yang_name = "exceed-action"
                                                self.yang_parent_name = "exceed-drop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ])
                                                self.drop = None
                                                self._segment_path = lambda: "exceed-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ExceedDrop.ExceedAction, ['drop'], name, value)


                                    class ViolateSetClpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetClpTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetClpTransmit, self).__init__()

                                            self.yang_name = "violate-set-clp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetClpTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetClpTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-clp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetClpTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_clp_transmit
                                            
                                            	set atm clp and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetClpTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-clp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                                ])
                                                self.set_clp_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetClpTransmit.ViolateAction, ['set_clp_transmit'], name, value)


                                    class ViolateSetCosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetCosTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetCosTransmit, self).__init__()

                                            self.yang_name = "violate-set-cos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetCosTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetCosTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-cos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetCosTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_cos_transmit
                                            
                                            	rewrite packet cos and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetCosTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-cos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_cos_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetCosTransmit.ViolateAction, ['set_cos_transmit', 'table'], name, value)


                                    class ViolateSetDiscardClassTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDiscardClassTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDiscardClassTransmit, self).__init__()

                                            self.yang_name = "violate-set-discard-class-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDiscardClassTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDiscardClassTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-discard-class-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDiscardClassTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_discard_class_transmit
                                            
                                            	set discard\-class and send it
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDiscardClassTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-discard-class-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                                ])
                                                self.set_discard_class_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDiscardClassTransmit.ViolateAction, ['set_discard_class_transmit'], name, value)


                                    class ViolateSetDscpTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDscpTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDscpTransmit, self).__init__()

                                            self.yang_name = "violate-set-dscp-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDscpTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDscpTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-dscp-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDscpTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_dscp_transmit
                                            
                                            	set dscp and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..63
                                            
                                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDscpTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-dscp-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_dscp_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetDscpTransmit.ViolateAction, ['set_dscp_transmit', 'table'], name, value)


                                    class ViolateSetFrdeTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetFrdeTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetFrdeTransmit, self).__init__()

                                            self.yang_name = "violate-set-frde-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetFrdeTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetFrdeTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-frde-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetFrdeTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_frde_transmit
                                            
                                            	set FR DE and send it
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetFrdeTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-frde-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                                ])
                                                self.set_frde_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetFrdeTransmit.ViolateAction, ['set_frde_transmit'], name, value)


                                    class ViolateSetMplsExpImpositionTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpImpositionTransmit, self).__init__()

                                            self.yang_name = "violate-set-mpls-exp-imposition-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-mpls-exp-imposition-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpImpositionTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_mpls_exp_imposition_transmit
                                            
                                            	set exp at tag imposition and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-mpls-exp-imposition-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_imposition_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                    class ViolateSetMplsExpTopmostTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpTopmostTransmit, self).__init__()

                                            self.yang_name = "violate-set-mpls-exp-topmost-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-mpls-exp-topmost-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpTopmostTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_mpls_exp_topmost_transmit
                                            
                                            	set exp on topmost label and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-mpls-exp-topmost-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ])
                                                self.set_mpls_exp_topmost_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                    class ViolateSetPrecTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetPrecTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetPrecTransmit, self).__init__()

                                            self.yang_name = "violate-set-prec-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetPrecTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetPrecTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-prec-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetPrecTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_prec_transmit
                                            
                                            	rewrite packet precedence and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..7
                                            
                                            		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                            
                                            .. attribute:: table
                                            
                                            	Specify table\-map
                                            	**type**\: str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetPrecTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-prec-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                                ])
                                                self.set_prec_transmit = None
                                                self.table = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetPrecTransmit.ViolateAction, ['set_prec_transmit', 'table'], name, value)


                                    class ViolateSetQosTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetQosTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetQosTransmit, self).__init__()

                                            self.yang_name = "violate-set-qos-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetQosTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetQosTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-set-qos-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetQosTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: set_qos_transmit
                                            
                                            	set qos\-group and send it
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 0..99
                                            
                                            		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetQosTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-set-qos-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                ])
                                                self.set_qos_transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateSetQosTransmit.ViolateAction, ['set_qos_transmit'], name, value)


                                    class ViolateTransmit(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateTransmit.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateTransmit, self).__init__()

                                            self.yang_name = "violate-transmit"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateTransmit.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateTransmit.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-transmit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateTransmit, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: transmit
                                            
                                            	transmit packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateTransmit.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-transmit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                                ])
                                                self.transmit = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateTransmit.ViolateAction, ['transmit'], name, value)


                                    class ViolateDrop(Entity):
                                        """
                                        
                                        
                                        .. attribute:: violate_action
                                        
                                        	action when rate is greater than conform + exceed burst
                                        	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateDrop.ViolateAction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateDrop, self).__init__()

                                            self.yang_name = "violate-drop"
                                            self.yang_parent_name = "actions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateDrop.ViolateAction))])
                                            self._leafs = OrderedDict()

                                            self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateDrop.ViolateAction()
                                            self.violate_action.parent = self
                                            self._children_name_map["violate_action"] = "violate-action"
                                            self._segment_path = lambda: "violate-drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateDrop, [], name, value)


                                        class ViolateAction(Entity):
                                            """
                                            action when rate is greater than conform + exceed burst
                                            
                                            .. attribute:: drop
                                            
                                            	drop packet
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateDrop.ViolateAction, self).__init__()

                                                self.yang_name = "violate-action"
                                                self.yang_parent_name = "violate-drop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ])
                                                self.drop = None
                                                self._segment_path = lambda: "violate-action"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceFlow.Police.Flow.Actions.ViolateDrop.ViolateAction, ['drop'], name, value)


                    class PoliceCatalyst(Entity):
                        """
                        
                        
                        .. attribute:: police
                        
                        	
                        	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst, self).__init__()

                            self.yang_name = "police-catalyst"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("police", ("police", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police))])
                            self._leafs = OrderedDict()

                            self.police = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police()
                            self.police.parent = self
                            self._children_name_map["police"] = "police"
                            self._segment_path = lambda: "police-catalyst"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst, [], name, value)


                        class Police(Entity):
                            """
                            
                            
                            .. attribute:: bps_value
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: bps
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: byte_value
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: byte
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: actions
                            
                            	
                            	**type**\:  :py:class:`Actions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police, self).__init__()

                                self.yang_name = "police"
                                self.yang_parent_name = "police-catalyst"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("actions", ("actions", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions))])
                                self._leafs = OrderedDict([
                                    ('bps_value', (YLeaf(YType.str, 'bps-value'), ['str'])),
                                    ('bps', (YLeaf(YType.empty, 'bps'), ['Empty'])),
                                    ('byte_value', (YLeaf(YType.str, 'byte-value'), ['str'])),
                                    ('byte', (YLeaf(YType.empty, 'byte'), ['Empty'])),
                                ])
                                self.bps_value = None
                                self.bps = None
                                self.byte_value = None
                                self.byte = None

                                self.actions = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions()
                                self.actions.parent = self
                                self._children_name_map["actions"] = "actions"
                                self._segment_path = lambda: "police"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police, ['bps_value', 'bps', 'byte_value', 'byte'], name, value)


                            class Actions(Entity):
                                """
                                
                                
                                .. attribute:: conform_set_clp_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetClpTransmit>`
                                
                                .. attribute:: conform_set_cos_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmit>`
                                
                                .. attribute:: conform_set_cos_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetCosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmitTable>`
                                
                                .. attribute:: conform_set_discard_class_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDiscardClassTransmit>`
                                
                                .. attribute:: conform_set_dscp_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmit>`
                                
                                .. attribute:: conform_set_dscp_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmitTable>`
                                
                                .. attribute:: conform_set_frde_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetFrdeTransmit>`
                                
                                .. attribute:: conform_set_mpls_exp_imposition_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmit>`
                                
                                .. attribute:: conform_set_mpls_exp_imposition_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpImpositionTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmitTable>`
                                
                                .. attribute:: conform_set_mpls_exp_topmost_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmit>`
                                
                                .. attribute:: conform_set_mpls_exp_topmost_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetMplsExpTopmostTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmitTable>`
                                
                                .. attribute:: conform_set_prec_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmit>`
                                
                                .. attribute:: conform_set_prec_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetPrecTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmitTable>`
                                
                                .. attribute:: conform_set_qos_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmit>`
                                
                                .. attribute:: conform_set_qos_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ConformSetQosTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmitTable>`
                                
                                .. attribute:: conform_transmit
                                
                                	
                                	**type**\:  :py:class:`ConformTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformTransmit>`
                                
                                .. attribute:: conform_drop
                                
                                	
                                	**type**\:  :py:class:`ConformDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformDrop>`
                                
                                .. attribute:: exceed_dscp
                                
                                	
                                	**type**\:  :py:class:`ExceedDscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDscp>`
                                
                                .. attribute:: exceed_set_clp_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetClpTransmit>`
                                
                                .. attribute:: exceed_set_cos_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetCosTransmit>`
                                
                                .. attribute:: exceed_set_discard_class_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDiscardClassTransmit>`
                                
                                .. attribute:: exceed_set_dscp_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit>`
                                
                                .. attribute:: exceed_set_dscp_transmit_table
                                
                                	
                                	**type**\:  :py:class:`ExceedSetDscpTransmitTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmitTable>`
                                
                                .. attribute:: exceed_set_frde_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetFrdeTransmit>`
                                
                                .. attribute:: exceed_set_mpls_exp_imposition_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpImpositionTransmit>`
                                
                                .. attribute:: exceed_set_mpls_exp_topmost_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpTopmostTransmit>`
                                
                                .. attribute:: exceed_set_prec_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetPrecTransmit>`
                                
                                .. attribute:: exceed_set_qos_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetQosTransmit>`
                                
                                .. attribute:: exceed_transmit
                                
                                	
                                	**type**\:  :py:class:`ExceedTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedTransmit>`
                                
                                .. attribute:: exceed_drop
                                
                                	
                                	**type**\:  :py:class:`ExceedDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDrop>`
                                
                                .. attribute:: violate_set_clp_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetClpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetClpTransmit>`
                                
                                .. attribute:: violate_set_cos_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetCosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetCosTransmit>`
                                
                                .. attribute:: violate_set_discard_class_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetDiscardClassTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDiscardClassTransmit>`
                                
                                .. attribute:: violate_set_dscp_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDscpTransmit>`
                                
                                .. attribute:: violate_set_frde_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetFrdeTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetFrdeTransmit>`
                                
                                .. attribute:: violate_set_mpls_exp_imposition_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetMplsExpImpositionTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpImpositionTransmit>`
                                
                                .. attribute:: violate_set_mpls_exp_topmost_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetMplsExpTopmostTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpTopmostTransmit>`
                                
                                .. attribute:: violate_set_prec_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetPrecTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetPrecTransmit>`
                                
                                .. attribute:: violate_set_qos_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateSetQosTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetQosTransmit>`
                                
                                .. attribute:: violate_transmit
                                
                                	
                                	**type**\:  :py:class:`ViolateTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateTransmit>`
                                
                                .. attribute:: violate_drop
                                
                                	
                                	**type**\:  :py:class:`ViolateDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateDrop>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions, self).__init__()

                                    self.yang_name = "actions"
                                    self.yang_parent_name = "police"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("conform-set-clp-transmit", ("conform_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetClpTransmit)), ("conform-set-cos-transmit", ("conform_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmit)), ("conform-set-cos-transmit-table", ("conform_set_cos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmitTable)), ("conform-set-discard-class-transmit", ("conform_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDiscardClassTransmit)), ("conform-set-dscp-transmit", ("conform_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmit)), ("conform-set-dscp-transmit-table", ("conform_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmitTable)), ("conform-set-frde-transmit", ("conform_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetFrdeTransmit)), ("conform-set-mpls-exp-imposition-transmit", ("conform_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmit)), ("conform-set-mpls-exp-imposition-transmit-table", ("conform_set_mpls_exp_imposition_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmitTable)), ("conform-set-mpls-exp-topmost-transmit", ("conform_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmit)), ("conform-set-mpls-exp-topmost-transmit-table", ("conform_set_mpls_exp_topmost_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmitTable)), ("conform-set-prec-transmit", ("conform_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmit)), ("conform-set-prec-transmit-table", ("conform_set_prec_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmitTable)), ("conform-set-qos-transmit", ("conform_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmit)), ("conform-set-qos-transmit-table", ("conform_set_qos_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmitTable)), ("conform-transmit", ("conform_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformTransmit)), ("conform-drop", ("conform_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformDrop)), ("exceed-dscp", ("exceed_dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDscp)), ("exceed-set-clp-transmit", ("exceed_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetClpTransmit)), ("exceed-set-cos-transmit", ("exceed_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetCosTransmit)), ("exceed-set-discard-class-transmit", ("exceed_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDiscardClassTransmit)), ("exceed-set-dscp-transmit", ("exceed_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit)), ("exceed-set-dscp-transmit-table", ("exceed_set_dscp_transmit_table", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmitTable)), ("exceed-set-frde-transmit", ("exceed_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetFrdeTransmit)), ("exceed-set-mpls-exp-imposition-transmit", ("exceed_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpImpositionTransmit)), ("exceed-set-mpls-exp-topmost-transmit", ("exceed_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpTopmostTransmit)), ("exceed-set-prec-transmit", ("exceed_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetPrecTransmit)), ("exceed-set-qos-transmit", ("exceed_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetQosTransmit)), ("exceed-transmit", ("exceed_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedTransmit)), ("exceed-drop", ("exceed_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDrop)), ("violate-set-clp-transmit", ("violate_set_clp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetClpTransmit)), ("violate-set-cos-transmit", ("violate_set_cos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetCosTransmit)), ("violate-set-discard-class-transmit", ("violate_set_discard_class_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDiscardClassTransmit)), ("violate-set-dscp-transmit", ("violate_set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDscpTransmit)), ("violate-set-frde-transmit", ("violate_set_frde_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetFrdeTransmit)), ("violate-set-mpls-exp-imposition-transmit", ("violate_set_mpls_exp_imposition_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpImpositionTransmit)), ("violate-set-mpls-exp-topmost-transmit", ("violate_set_mpls_exp_topmost_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpTopmostTransmit)), ("violate-set-prec-transmit", ("violate_set_prec_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetPrecTransmit)), ("violate-set-qos-transmit", ("violate_set_qos_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetQosTransmit)), ("violate-transmit", ("violate_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateTransmit)), ("violate-drop", ("violate_drop", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateDrop))])
                                    self._leafs = OrderedDict()

                                    self.conform_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetClpTransmit()
                                    self.conform_set_clp_transmit.parent = self
                                    self._children_name_map["conform_set_clp_transmit"] = "conform-set-clp-transmit"

                                    self.conform_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmit()
                                    self.conform_set_cos_transmit.parent = self
                                    self._children_name_map["conform_set_cos_transmit"] = "conform-set-cos-transmit"

                                    self.conform_set_cos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmitTable()
                                    self.conform_set_cos_transmit_table.parent = self
                                    self._children_name_map["conform_set_cos_transmit_table"] = "conform-set-cos-transmit-table"

                                    self.conform_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDiscardClassTransmit()
                                    self.conform_set_discard_class_transmit.parent = self
                                    self._children_name_map["conform_set_discard_class_transmit"] = "conform-set-discard-class-transmit"

                                    self.conform_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmit()
                                    self.conform_set_dscp_transmit.parent = self
                                    self._children_name_map["conform_set_dscp_transmit"] = "conform-set-dscp-transmit"

                                    self.conform_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmitTable()
                                    self.conform_set_dscp_transmit_table.parent = self
                                    self._children_name_map["conform_set_dscp_transmit_table"] = "conform-set-dscp-transmit-table"

                                    self.conform_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetFrdeTransmit()
                                    self.conform_set_frde_transmit.parent = self
                                    self._children_name_map["conform_set_frde_transmit"] = "conform-set-frde-transmit"

                                    self.conform_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmit()
                                    self.conform_set_mpls_exp_imposition_transmit.parent = self
                                    self._children_name_map["conform_set_mpls_exp_imposition_transmit"] = "conform-set-mpls-exp-imposition-transmit"

                                    self.conform_set_mpls_exp_imposition_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmitTable()
                                    self.conform_set_mpls_exp_imposition_transmit_table.parent = self
                                    self._children_name_map["conform_set_mpls_exp_imposition_transmit_table"] = "conform-set-mpls-exp-imposition-transmit-table"

                                    self.conform_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmit()
                                    self.conform_set_mpls_exp_topmost_transmit.parent = self
                                    self._children_name_map["conform_set_mpls_exp_topmost_transmit"] = "conform-set-mpls-exp-topmost-transmit"

                                    self.conform_set_mpls_exp_topmost_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmitTable()
                                    self.conform_set_mpls_exp_topmost_transmit_table.parent = self
                                    self._children_name_map["conform_set_mpls_exp_topmost_transmit_table"] = "conform-set-mpls-exp-topmost-transmit-table"

                                    self.conform_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmit()
                                    self.conform_set_prec_transmit.parent = self
                                    self._children_name_map["conform_set_prec_transmit"] = "conform-set-prec-transmit"

                                    self.conform_set_prec_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmitTable()
                                    self.conform_set_prec_transmit_table.parent = self
                                    self._children_name_map["conform_set_prec_transmit_table"] = "conform-set-prec-transmit-table"

                                    self.conform_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmit()
                                    self.conform_set_qos_transmit.parent = self
                                    self._children_name_map["conform_set_qos_transmit"] = "conform-set-qos-transmit"

                                    self.conform_set_qos_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmitTable()
                                    self.conform_set_qos_transmit_table.parent = self
                                    self._children_name_map["conform_set_qos_transmit_table"] = "conform-set-qos-transmit-table"

                                    self.conform_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformTransmit()
                                    self.conform_transmit.parent = self
                                    self._children_name_map["conform_transmit"] = "conform-transmit"

                                    self.conform_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformDrop()
                                    self.conform_drop.parent = self
                                    self._children_name_map["conform_drop"] = "conform-drop"

                                    self.exceed_dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDscp()
                                    self.exceed_dscp.parent = self
                                    self._children_name_map["exceed_dscp"] = "exceed-dscp"

                                    self.exceed_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetClpTransmit()
                                    self.exceed_set_clp_transmit.parent = self
                                    self._children_name_map["exceed_set_clp_transmit"] = "exceed-set-clp-transmit"

                                    self.exceed_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetCosTransmit()
                                    self.exceed_set_cos_transmit.parent = self
                                    self._children_name_map["exceed_set_cos_transmit"] = "exceed-set-cos-transmit"

                                    self.exceed_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDiscardClassTransmit()
                                    self.exceed_set_discard_class_transmit.parent = self
                                    self._children_name_map["exceed_set_discard_class_transmit"] = "exceed-set-discard-class-transmit"

                                    self.exceed_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit()
                                    self.exceed_set_dscp_transmit.parent = self
                                    self._children_name_map["exceed_set_dscp_transmit"] = "exceed-set-dscp-transmit"

                                    self.exceed_set_dscp_transmit_table = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmitTable()
                                    self.exceed_set_dscp_transmit_table.parent = self
                                    self._children_name_map["exceed_set_dscp_transmit_table"] = "exceed-set-dscp-transmit-table"

                                    self.exceed_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetFrdeTransmit()
                                    self.exceed_set_frde_transmit.parent = self
                                    self._children_name_map["exceed_set_frde_transmit"] = "exceed-set-frde-transmit"

                                    self.exceed_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpImpositionTransmit()
                                    self.exceed_set_mpls_exp_imposition_transmit.parent = self
                                    self._children_name_map["exceed_set_mpls_exp_imposition_transmit"] = "exceed-set-mpls-exp-imposition-transmit"

                                    self.exceed_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpTopmostTransmit()
                                    self.exceed_set_mpls_exp_topmost_transmit.parent = self
                                    self._children_name_map["exceed_set_mpls_exp_topmost_transmit"] = "exceed-set-mpls-exp-topmost-transmit"

                                    self.exceed_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetPrecTransmit()
                                    self.exceed_set_prec_transmit.parent = self
                                    self._children_name_map["exceed_set_prec_transmit"] = "exceed-set-prec-transmit"

                                    self.exceed_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetQosTransmit()
                                    self.exceed_set_qos_transmit.parent = self
                                    self._children_name_map["exceed_set_qos_transmit"] = "exceed-set-qos-transmit"

                                    self.exceed_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedTransmit()
                                    self.exceed_transmit.parent = self
                                    self._children_name_map["exceed_transmit"] = "exceed-transmit"

                                    self.exceed_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDrop()
                                    self.exceed_drop.parent = self
                                    self._children_name_map["exceed_drop"] = "exceed-drop"

                                    self.violate_set_clp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetClpTransmit()
                                    self.violate_set_clp_transmit.parent = self
                                    self._children_name_map["violate_set_clp_transmit"] = "violate-set-clp-transmit"

                                    self.violate_set_cos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetCosTransmit()
                                    self.violate_set_cos_transmit.parent = self
                                    self._children_name_map["violate_set_cos_transmit"] = "violate-set-cos-transmit"

                                    self.violate_set_discard_class_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDiscardClassTransmit()
                                    self.violate_set_discard_class_transmit.parent = self
                                    self._children_name_map["violate_set_discard_class_transmit"] = "violate-set-discard-class-transmit"

                                    self.violate_set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDscpTransmit()
                                    self.violate_set_dscp_transmit.parent = self
                                    self._children_name_map["violate_set_dscp_transmit"] = "violate-set-dscp-transmit"

                                    self.violate_set_frde_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetFrdeTransmit()
                                    self.violate_set_frde_transmit.parent = self
                                    self._children_name_map["violate_set_frde_transmit"] = "violate-set-frde-transmit"

                                    self.violate_set_mpls_exp_imposition_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpImpositionTransmit()
                                    self.violate_set_mpls_exp_imposition_transmit.parent = self
                                    self._children_name_map["violate_set_mpls_exp_imposition_transmit"] = "violate-set-mpls-exp-imposition-transmit"

                                    self.violate_set_mpls_exp_topmost_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpTopmostTransmit()
                                    self.violate_set_mpls_exp_topmost_transmit.parent = self
                                    self._children_name_map["violate_set_mpls_exp_topmost_transmit"] = "violate-set-mpls-exp-topmost-transmit"

                                    self.violate_set_prec_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetPrecTransmit()
                                    self.violate_set_prec_transmit.parent = self
                                    self._children_name_map["violate_set_prec_transmit"] = "violate-set-prec-transmit"

                                    self.violate_set_qos_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetQosTransmit()
                                    self.violate_set_qos_transmit.parent = self
                                    self._children_name_map["violate_set_qos_transmit"] = "violate-set-qos-transmit"

                                    self.violate_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateTransmit()
                                    self.violate_transmit.parent = self
                                    self._children_name_map["violate_transmit"] = "violate-transmit"

                                    self.violate_drop = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateDrop()
                                    self.violate_drop.parent = self
                                    self._children_name_map["violate_drop"] = "violate-drop"
                                    self._segment_path = lambda: "actions"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions, [], name, value)


                                class ConformSetClpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetClpTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetClpTransmit, self).__init__()

                                        self.yang_name = "conform-set-clp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetClpTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetClpTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-clp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetClpTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_clp_transmit
                                        
                                        	set atm clp and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetClpTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-clp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                            ])
                                            self.set_clp_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetClpTransmit.ConformAction, ['set_clp_transmit'], name, value)


                                class ConformSetCosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmit, self).__init__()

                                        self.yang_name = "conform-set-cos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-cos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-cos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                            ])
                                            self.set_cos_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmit.ConformAction, ['set_cos_transmit'], name, value)


                                class ConformSetCosTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-cos-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-cos-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-cos-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_cos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetCosTransmitTable.ConformAction, ['set_cos_transmit', 'table'], name, value)


                                class ConformSetDiscardClassTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDiscardClassTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDiscardClassTransmit, self).__init__()

                                        self.yang_name = "conform-set-discard-class-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDiscardClassTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDiscardClassTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-discard-class-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDiscardClassTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_discard_class_transmit
                                        
                                        	set discard\-class and send it
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDiscardClassTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-discard-class-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                            ])
                                            self.set_discard_class_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDiscardClassTransmit.ConformAction, ['set_discard_class_transmit'], name, value)


                                class ConformSetDscpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmit, self).__init__()

                                        self.yang_name = "conform-set-dscp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-dscp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-dscp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmit.ConformAction, ['set_dscp_transmit'], name, value)


                                class ConformSetDscpTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-dscp-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-dscp-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-dscp-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetDscpTransmitTable.ConformAction, ['set_dscp_transmit', 'table'], name, value)


                                class ConformSetFrdeTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetFrdeTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetFrdeTransmit, self).__init__()

                                        self.yang_name = "conform-set-frde-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetFrdeTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetFrdeTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-frde-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetFrdeTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_frde_transmit
                                        
                                        	set FR DE and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetFrdeTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-frde-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                            ])
                                            self.set_frde_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetFrdeTransmit.ConformAction, ['set_frde_transmit'], name, value)


                                class ConformSetMplsExpImpositionTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmit, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-imposition-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmit.ConformAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                class ConformSetMplsExpImpositionTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-imposition-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-imposition-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-imposition-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpImpositionTransmitTable.ConformAction, ['set_mpls_exp_imposition_transmit', 'table'], name, value)


                                class ConformSetMplsExpTopmostTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmit, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-topmost-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmit.ConformAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                class ConformSetMplsExpTopmostTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-mpls-exp-topmost-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-mpls-exp-topmost-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-mpls-exp-topmost-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetMplsExpTopmostTransmitTable.ConformAction, ['set_mpls_exp_topmost_transmit', 'table'], name, value)


                                class ConformSetPrecTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmit, self).__init__()

                                        self.yang_name = "conform-set-prec-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-prec-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-prec-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                            ])
                                            self.set_prec_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmit.ConformAction, ['set_prec_transmit'], name, value)


                                class ConformSetPrecTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-prec-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-prec-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-prec-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_prec_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetPrecTransmitTable.ConformAction, ['set_prec_transmit', 'table'], name, value)


                                class ConformSetQosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmit, self).__init__()

                                        self.yang_name = "conform-set-qos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-qos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-qos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                            ])
                                            self.set_qos_transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmit.ConformAction, ['set_qos_transmit'], name, value)


                                class ConformSetQosTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmitTable.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmitTable, self).__init__()

                                        self.yang_name = "conform-set-qos-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmitTable.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmitTable.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-set-qos-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmitTable, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmitTable.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-set-qos-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_qos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformSetQosTransmitTable.ConformAction, ['set_qos_transmit', 'table'], name, value)


                                class ConformTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformTransmit.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformTransmit, self).__init__()

                                        self.yang_name = "conform-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformTransmit.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformTransmit.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformTransmit, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: transmit
                                        
                                        	transmit packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformTransmit.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                            ])
                                            self.transmit = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformTransmit.ConformAction, ['transmit'], name, value)


                                class ConformDrop(Entity):
                                    """
                                    
                                    
                                    .. attribute:: conform_action
                                    
                                    	action when rate is less than conform burst
                                    	**type**\:  :py:class:`ConformAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformDrop.ConformAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformDrop, self).__init__()

                                        self.yang_name = "conform-drop"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("conform-action", ("conform_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformDrop.ConformAction))])
                                        self._leafs = OrderedDict()

                                        self.conform_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformDrop.ConformAction()
                                        self.conform_action.parent = self
                                        self._children_name_map["conform_action"] = "conform-action"
                                        self._segment_path = lambda: "conform-drop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformDrop, [], name, value)


                                    class ConformAction(Entity):
                                        """
                                        action when rate is less than conform burst
                                        
                                        .. attribute:: drop
                                        
                                        	drop packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformDrop.ConformAction, self).__init__()

                                            self.yang_name = "conform-action"
                                            self.yang_parent_name = "conform-drop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ])
                                            self.drop = None
                                            self._segment_path = lambda: "conform-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ConformDrop.ConformAction, ['drop'], name, value)


                                class ExceedDscp(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDscp.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDscp, self).__init__()

                                        self.yang_name = "exceed-dscp"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDscp.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDscp.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-dscp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDscp, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: dscp
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDscp.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-dscp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dscp', (YLeaf(YType.str, 'dscp'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                            ])
                                            self.dscp = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDscp.ExceedAction, ['dscp'], name, value)


                                class ExceedSetClpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetClpTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetClpTransmit, self).__init__()

                                        self.yang_name = "exceed-set-clp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetClpTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetClpTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-clp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetClpTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_clp_transmit
                                        
                                        	set atm clp and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetClpTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-clp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                            ])
                                            self.set_clp_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetClpTransmit.ExceedAction, ['set_clp_transmit'], name, value)


                                class ExceedSetCosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetCosTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetCosTransmit, self).__init__()

                                        self.yang_name = "exceed-set-cos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetCosTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetCosTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-cos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetCosTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetCosTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-cos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_cos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetCosTransmit.ExceedAction, ['set_cos_transmit', 'table'], name, value)


                                class ExceedSetDiscardClassTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDiscardClassTransmit, self).__init__()

                                        self.yang_name = "exceed-set-discard-class-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-discard-class-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDiscardClassTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_discard_class_transmit
                                        
                                        	set discard\-class and send it
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-discard-class-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                            ])
                                            self.set_discard_class_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDiscardClassTransmit.ExceedAction, ['set_discard_class_transmit'], name, value)


                                class ExceedSetDscpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit, self).__init__()

                                        self.yang_name = "exceed-set-dscp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-dscp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	
                                        	**type**\:  :py:class:`SetDscpTransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-dscp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("set-dscp-transmit", ("set_dscp_transmit", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit))])
                                            self._leafs = OrderedDict()

                                            self.set_dscp_transmit = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit()
                                            self.set_dscp_transmit.parent = self
                                            self._children_name_map["set_dscp_transmit"] = "set-dscp-transmit"
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction, [], name, value)


                                        class SetDscpTransmit(Entity):
                                            """
                                            
                                            
                                            .. attribute:: dscp
                                            
                                            	
                                            	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp>`
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, self).__init__()

                                                self.yang_name = "set-dscp-transmit"
                                                self.yang_parent_name = "exceed-action"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp))])
                                                self._leafs = OrderedDict()

                                                self.dscp = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp()
                                                self.dscp.parent = self
                                                self._children_name_map["dscp"] = "dscp"
                                                self._segment_path = lambda: "set-dscp-transmit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit, [], name, value)


                                            class Dscp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: table
                                                
                                                	
                                                	**type**\:  :py:class:`Table <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table>`
                                                
                                                

                                                """

                                                _prefix = 'ios-policy'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, self).__init__()

                                                    self.yang_name = "dscp"
                                                    self.yang_parent_name = "set-dscp-transmit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('table', (YLeaf(YType.enumeration, 'table'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp.Table')])),
                                                    ])
                                                    self.table = None
                                                    self._segment_path = lambda: "dscp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmit.ExceedAction.SetDscpTransmit.Dscp, ['table'], name, value)

                                                class Table(Enum):
                                                    """
                                                    Table (Enum Class)

                                                    .. data:: policed_dscp = 0

                                                    """

                                                    policed_dscp = Enum.YLeaf(0, "policed-dscp")



                                class ExceedSetDscpTransmitTable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmitTable, self).__init__()

                                        self.yang_name = "exceed-set-dscp-transmit-table"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-dscp-transmit-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmitTable, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-dscp-transmit-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetDscpTransmitTable.ExceedAction, ['set_dscp_transmit', 'table'], name, value)


                                class ExceedSetFrdeTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetFrdeTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetFrdeTransmit, self).__init__()

                                        self.yang_name = "exceed-set-frde-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetFrdeTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetFrdeTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-frde-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetFrdeTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_frde_transmit
                                        
                                        	set FR DE and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetFrdeTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-frde-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                            ])
                                            self.set_frde_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetFrdeTransmit.ExceedAction, ['set_frde_transmit'], name, value)


                                class ExceedSetMplsExpImpositionTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpImpositionTransmit, self).__init__()

                                        self.yang_name = "exceed-set-mpls-exp-imposition-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-mpls-exp-imposition-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpImpositionTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-mpls-exp-imposition-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpImpositionTransmit.ExceedAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                class ExceedSetMplsExpTopmostTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpTopmostTransmit, self).__init__()

                                        self.yang_name = "exceed-set-mpls-exp-topmost-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-mpls-exp-topmost-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpTopmostTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-mpls-exp-topmost-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetMplsExpTopmostTransmit.ExceedAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                class ExceedSetPrecTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetPrecTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetPrecTransmit, self).__init__()

                                        self.yang_name = "exceed-set-prec-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetPrecTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetPrecTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-prec-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetPrecTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetPrecTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-prec-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_prec_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetPrecTransmit.ExceedAction, ['set_prec_transmit', 'table'], name, value)


                                class ExceedSetQosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetQosTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetQosTransmit, self).__init__()

                                        self.yang_name = "exceed-set-qos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetQosTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetQosTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-set-qos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetQosTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetQosTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-set-qos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                            ])
                                            self.set_qos_transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedSetQosTransmit.ExceedAction, ['set_qos_transmit'], name, value)


                                class ExceedTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedTransmit.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedTransmit, self).__init__()

                                        self.yang_name = "exceed-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedTransmit.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedTransmit.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedTransmit, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: transmit
                                        
                                        	transmit packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedTransmit.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                            ])
                                            self.transmit = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedTransmit.ExceedAction, ['transmit'], name, value)


                                class ExceedDrop(Entity):
                                    """
                                    
                                    
                                    .. attribute:: exceed_action
                                    
                                    	action when rate is within conform and conform + exceed burst
                                    	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDrop.ExceedAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDrop, self).__init__()

                                        self.yang_name = "exceed-drop"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("exceed-action", ("exceed_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDrop.ExceedAction))])
                                        self._leafs = OrderedDict()

                                        self.exceed_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDrop.ExceedAction()
                                        self.exceed_action.parent = self
                                        self._children_name_map["exceed_action"] = "exceed-action"
                                        self._segment_path = lambda: "exceed-drop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDrop, [], name, value)


                                    class ExceedAction(Entity):
                                        """
                                        action when rate is within conform and conform + exceed burst
                                        
                                        .. attribute:: drop
                                        
                                        	drop packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDrop.ExceedAction, self).__init__()

                                            self.yang_name = "exceed-action"
                                            self.yang_parent_name = "exceed-drop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ])
                                            self.drop = None
                                            self._segment_path = lambda: "exceed-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ExceedDrop.ExceedAction, ['drop'], name, value)


                                class ViolateSetClpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetClpTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetClpTransmit, self).__init__()

                                        self.yang_name = "violate-set-clp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetClpTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetClpTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-clp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetClpTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_clp_transmit
                                        
                                        	set atm clp and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetClpTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-clp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_clp_transmit', (YLeaf(YType.empty, 'set-clp-transmit'), ['Empty'])),
                                            ])
                                            self.set_clp_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetClpTransmit.ViolateAction, ['set_clp_transmit'], name, value)


                                class ViolateSetCosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetCosTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetCosTransmit, self).__init__()

                                        self.yang_name = "violate-set-cos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetCosTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetCosTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-cos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetCosTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_cos_transmit
                                        
                                        	rewrite packet cos and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`CosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CosValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetCosTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-cos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_cos_transmit', (YLeaf(YType.str, 'set-cos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CosValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_cos_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetCosTransmit.ViolateAction, ['set_cos_transmit', 'table'], name, value)


                                class ViolateSetDiscardClassTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDiscardClassTransmit, self).__init__()

                                        self.yang_name = "violate-set-discard-class-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-discard-class-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDiscardClassTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_discard_class_transmit
                                        
                                        	set discard\-class and send it
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-discard-class-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_discard_class_transmit', (YLeaf(YType.uint8, 'set-discard-class-transmit'), ['int'])),
                                            ])
                                            self.set_discard_class_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDiscardClassTransmit.ViolateAction, ['set_discard_class_transmit'], name, value)


                                class ViolateSetDscpTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDscpTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDscpTransmit, self).__init__()

                                        self.yang_name = "violate-set-dscp-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDscpTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDscpTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-dscp-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDscpTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_dscp_transmit
                                        
                                        	set dscp and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..63
                                        
                                        		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDscpTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-dscp-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_dscp_transmit', (YLeaf(YType.str, 'set-dscp-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_dscp_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetDscpTransmit.ViolateAction, ['set_dscp_transmit', 'table'], name, value)


                                class ViolateSetFrdeTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetFrdeTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetFrdeTransmit, self).__init__()

                                        self.yang_name = "violate-set-frde-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetFrdeTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetFrdeTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-frde-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetFrdeTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_frde_transmit
                                        
                                        	set FR DE and send it
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetFrdeTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-frde-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_frde_transmit', (YLeaf(YType.empty, 'set-frde-transmit'), ['Empty'])),
                                            ])
                                            self.set_frde_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetFrdeTransmit.ViolateAction, ['set_frde_transmit'], name, value)


                                class ViolateSetMplsExpImpositionTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpImpositionTransmit, self).__init__()

                                        self.yang_name = "violate-set-mpls-exp-imposition-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-mpls-exp-imposition-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpImpositionTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_imposition_transmit
                                        
                                        	set exp at tag imposition and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-mpls-exp-imposition-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_imposition_transmit', (YLeaf(YType.str, 'set-mpls-exp-imposition-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_imposition_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpImpositionTransmit.ViolateAction, ['set_mpls_exp_imposition_transmit'], name, value)


                                class ViolateSetMplsExpTopmostTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpTopmostTransmit, self).__init__()

                                        self.yang_name = "violate-set-mpls-exp-topmost-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-mpls-exp-topmost-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpTopmostTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_mpls_exp_topmost_transmit
                                        
                                        	set exp on topmost label and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`ExpValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.ExpValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-mpls-exp-topmost-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_mpls_exp_topmost_transmit', (YLeaf(YType.str, 'set-mpls-exp-topmost-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'ExpValueType', '')])),
                                            ])
                                            self.set_mpls_exp_topmost_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetMplsExpTopmostTransmit.ViolateAction, ['set_mpls_exp_topmost_transmit'], name, value)


                                class ViolateSetPrecTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetPrecTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetPrecTransmit, self).__init__()

                                        self.yang_name = "violate-set-prec-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetPrecTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetPrecTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-prec-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetPrecTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_prec_transmit
                                        
                                        	rewrite packet precedence and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..7
                                        
                                        		**type**\:  :py:class:`PrecValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecValueType>`
                                        
                                        .. attribute:: table
                                        
                                        	Specify table\-map
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetPrecTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-prec-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_prec_transmit', (YLeaf(YType.str, 'set-prec-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecValueType', '')])),
                                                ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                            ])
                                            self.set_prec_transmit = None
                                            self.table = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetPrecTransmit.ViolateAction, ['set_prec_transmit', 'table'], name, value)


                                class ViolateSetQosTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetQosTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetQosTransmit, self).__init__()

                                        self.yang_name = "violate-set-qos-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetQosTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetQosTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-set-qos-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetQosTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: set_qos_transmit
                                        
                                        	set qos\-group and send it
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 0..99
                                        
                                        		**type**\:  :py:class:`QosValueType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.QosValueType>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetQosTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-set-qos-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_qos_transmit', (YLeaf(YType.str, 'set-qos-transmit'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'QosValueType', '')])),
                                            ])
                                            self.set_qos_transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateSetQosTransmit.ViolateAction, ['set_qos_transmit'], name, value)


                                class ViolateTransmit(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateTransmit.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateTransmit, self).__init__()

                                        self.yang_name = "violate-transmit"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateTransmit.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateTransmit.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-transmit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateTransmit, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: transmit
                                        
                                        	transmit packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateTransmit.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-transmit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                                            ])
                                            self.transmit = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateTransmit.ViolateAction, ['transmit'], name, value)


                                class ViolateDrop(Entity):
                                    """
                                    
                                    
                                    .. attribute:: violate_action
                                    
                                    	action when rate is greater than conform + exceed burst
                                    	**type**\:  :py:class:`ViolateAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateDrop.ViolateAction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateDrop, self).__init__()

                                        self.yang_name = "violate-drop"
                                        self.yang_parent_name = "actions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("violate-action", ("violate_action", Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateDrop.ViolateAction))])
                                        self._leafs = OrderedDict()

                                        self.violate_action = Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateDrop.ViolateAction()
                                        self.violate_action.parent = self
                                        self._children_name_map["violate_action"] = "violate-action"
                                        self._segment_path = lambda: "violate-drop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateDrop, [], name, value)


                                    class ViolateAction(Entity):
                                        """
                                        action when rate is greater than conform + exceed burst
                                        
                                        .. attribute:: drop
                                        
                                        	drop packet
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateDrop.ViolateAction, self).__init__()

                                            self.yang_name = "violate-action"
                                            self.yang_parent_name = "violate-drop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ])
                                            self.drop = None
                                            self._segment_path = lambda: "violate-action"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceCatalyst.Police.Actions.ViolateDrop.ViolateAction, ['drop'], name, value)


                    class PoliceSwitch(Entity):
                        """
                        
                        
                        .. attribute:: police
                        
                        	
                        	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceSwitch.Police>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.PoliceSwitch, self).__init__()

                            self.yang_name = "police-switch"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("police", ("police", Native.Policy.PolicyMap.Class.ActionList.PoliceSwitch.Police))])
                            self._leafs = OrderedDict()

                            self.police = Native.Policy.PolicyMap.Class.ActionList.PoliceSwitch.Police()
                            self.police.parent = self
                            self._children_name_map["police"] = "police"
                            self._segment_path = lambda: "police-switch"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceSwitch, [], name, value)


                        class Police(Entity):
                            """
                            
                            
                            .. attribute:: cir
                            
                            	
                            	**type**\: int
                            
                            	**range:** 8000..1000000000
                            
                            .. attribute:: bc
                            
                            	
                            	**type**\: int
                            
                            	**range:** 8000..2000000
                            
                            .. attribute:: exceed_action
                            
                            	action when rate is exceeded
                            	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.PoliceSwitch.Police.ExceedAction>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.PoliceSwitch.Police, self).__init__()

                                self.yang_name = "police"
                                self.yang_parent_name = "police-switch"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('cir', (YLeaf(YType.uint32, 'cir'), ['int'])),
                                    ('bc', (YLeaf(YType.uint32, 'bc'), ['int'])),
                                    ('exceed_action', (YLeaf(YType.enumeration, 'exceed-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.PoliceSwitch.Police.ExceedAction')])),
                                ])
                                self.cir = None
                                self.bc = None
                                self.exceed_action = None
                                self._segment_path = lambda: "police"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.PoliceSwitch.Police, ['cir', 'bc', 'exceed_action'], name, value)

                            class ExceedAction(Enum):
                                """
                                ExceedAction (Enum Class)

                                action when rate is exceeded

                                .. data:: drop = 0

                                .. data:: policed_dscp_transmit = 1

                                """

                                drop = Enum.YLeaf(0, "drop")

                                policed_dscp_transmit = Enum.YLeaf(1, "policed-dscp-transmit")



                    class Priority(Entity):
                        """
                        
                        
                        .. attribute:: level
                        
                        	Multi\-Level Priority Queue
                        	**type**\: int
                        
                        	**range:** 1..2
                        
                        .. attribute:: kilo_bits
                        
                        	
                        	**type**\: int
                        
                        	**range:** 8..2000000
                        
                        .. attribute:: percent
                        
                        	% of total bandwidth
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: burst
                        
                        	
                        	**type**\: int
                        
                        	**range:** 32..64000000
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.Priority, self).__init__()

                            self.yang_name = "priority"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ('kilo_bits', (YLeaf(YType.uint32, 'kilo-bits'), ['int'])),
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                                ('burst', (YLeaf(YType.uint32, 'burst'), ['int'])),
                            ])
                            self.level = None
                            self.kilo_bits = None
                            self.percent = None
                            self.burst = None
                            self._segment_path = lambda: "priority"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Priority, ['level', 'kilo_bits', 'percent', 'burst'], name, value)


                    class QueueBuffers(Entity):
                        """
                        
                        
                        .. attribute:: ratio
                        
                        	Relative buffer size for queue
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.QueueBuffers, self).__init__()

                            self.yang_name = "queue-buffers"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ratio', (YLeaf(YType.uint8, 'ratio'), ['int'])),
                            ])
                            self.ratio = None
                            self._segment_path = lambda: "queue-buffers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.QueueBuffers, ['ratio'], name, value)


                    class QueueLimit(Entity):
                        """
                        
                        
                        .. attribute:: queue_limit_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8192000
                        
                        .. attribute:: queue_limit_type
                        
                        	
                        	**type**\:  :py:class:`QueueLimitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.QueueLimit.QueueLimitType>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.QueueLimit, self).__init__()

                            self.yang_name = "queue-limit"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('queue_limit_value', (YLeaf(YType.uint32, 'queue-limit-value'), ['int'])),
                                ('queue_limit_type', (YLeaf(YType.enumeration, 'queue-limit-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.QueueLimit.QueueLimitType')])),
                            ])
                            self.queue_limit_value = None
                            self.queue_limit_type = None
                            self._segment_path = lambda: "queue-limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.QueueLimit, ['queue_limit_value', 'queue_limit_type'], name, value)

                        class QueueLimitType(Enum):
                            """
                            QueueLimitType (Enum Class)

                            .. data:: bytes = 0

                            .. data:: ms = 1

                            .. data:: packets = 2

                            .. data:: us = 3

                            """

                            bytes = Enum.YLeaf(0, "bytes")

                            ms = Enum.YLeaf(1, "ms")

                            packets = Enum.YLeaf(2, "packets")

                            us = Enum.YLeaf(3, "us")



                    class QueueLimitDscp(Entity):
                        """
                        
                        
                        .. attribute:: dscp
                        
                        	parameters for each dscp value
                        	**type**\: list of  		 :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.QueueLimitDscp.Dscp>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.QueueLimitDscp, self).__init__()

                            self.yang_name = "queue-limit-dscp"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.QueueLimitDscp.Dscp))])
                            self._leafs = OrderedDict()

                            self.dscp = YList(self)
                            self._segment_path = lambda: "queue-limit-dscp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.QueueLimitDscp, [], name, value)


                        class Dscp(Entity):
                            """
                            parameters for each dscp value
                            
                            .. attribute:: dscp_val  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..63
                            
                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                            
                            .. attribute:: values
                            
                            	dscp values
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp_val1
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..63
                            
                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                            
                            .. attribute:: percent
                            
                            	% of threshold
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.QueueLimitDscp.Dscp, self).__init__()

                                self.yang_name = "dscp"
                                self.yang_parent_name = "queue-limit-dscp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['dscp_val']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dscp_val', (YLeaf(YType.str, 'dscp-val'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                    ('values', (YLeaf(YType.empty, 'values'), ['Empty'])),
                                    ('dscp_val1', (YLeaf(YType.str, 'dscp-val1'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                ])
                                self.dscp_val = None
                                self.values = None
                                self.dscp_val1 = None
                                self.percent = None
                                self._segment_path = lambda: "dscp" + "[dscp-val='" + str(self.dscp_val) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.QueueLimitDscp.Dscp, ['dscp_val', 'values', 'dscp_val1', 'percent'], name, value)


                    class RandomDetect(Entity):
                        """
                        
                        
                        .. attribute:: aggregate
                        
                        	aggregate subclasses
                        	**type**\:  :py:class:`Aggregate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Aggregate>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cos_based
                        
                        	Enable cos\-class\-based WRED as drop policy, supported on ASR9xx platform only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cos
                        
                        	parameters for each cos value, supported on ASR9xx platform only
                        	**type**\:  :py:class:`Cos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Cos>`
                        
                        .. attribute:: discard_class_based
                        
                        	Enable discard\-class\-based WRED as drop policy
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: discard_class
                        
                        	parameters for each discard\-class value
                        	**type**\:  :py:class:`DiscardClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.RandomDetect.DiscardClass>`
                        
                        .. attribute:: dscp_based
                        
                        	Enable dscp\-based WRED as drop policy
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	parameters for each dscp value
                        	**type**\: list of  		 :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Dscp>`
                        
                        .. attribute:: ecn
                        
                        	explicit congestion notification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: exponential_weighting_constant
                        
                        	weight for mean queue depth calculation
                        	**type**\: int
                        
                        	**range:** 1..16
                        
                        .. attribute:: precedence_based
                        
                        	Enable precedence\-based WRED as drop policy
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: precedence
                        
                        	parameters for each precedence value
                        	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Precedence>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.RandomDetect, self).__init__()

                            self.yang_name = "random-detect"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("aggregate", ("aggregate", Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Aggregate)), ("cos", ("cos", Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Cos)), ("discard-class", ("discard_class", Native.Policy.PolicyMap.Class.ActionList.RandomDetect.DiscardClass)), ("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Dscp)), ("precedence", ("precedence", Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Precedence))])
                            self._leafs = OrderedDict([
                                ('cos_based', (YLeaf(YType.empty, 'cos-based'), ['Empty'])),
                                ('discard_class_based', (YLeaf(YType.empty, 'discard-class-based'), ['Empty'])),
                                ('dscp_based', (YLeaf(YType.empty, 'dscp-based'), ['Empty'])),
                                ('ecn', (YLeaf(YType.empty, 'ecn'), ['Empty'])),
                                ('exponential_weighting_constant', (YLeaf(YType.uint16, 'exponential-weighting-constant'), ['int'])),
                                ('precedence_based', (YLeaf(YType.empty, 'precedence-based'), ['Empty'])),
                            ])
                            self.cos_based = None
                            self.discard_class_based = None
                            self.dscp_based = None
                            self.ecn = None
                            self.exponential_weighting_constant = None
                            self.precedence_based = None

                            self.aggregate = None
                            self._children_name_map["aggregate"] = "aggregate"

                            self.cos = Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Cos()
                            self.cos.parent = self
                            self._children_name_map["cos"] = "cos"

                            self.discard_class = Native.Policy.PolicyMap.Class.ActionList.RandomDetect.DiscardClass()
                            self.discard_class.parent = self
                            self._children_name_map["discard_class"] = "discard-class"

                            self.precedence = Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Precedence()
                            self.precedence.parent = self
                            self._children_name_map["precedence"] = "precedence"

                            self.dscp = YList(self)
                            self._segment_path = lambda: "random-detect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.RandomDetect, ['cos_based', 'discard_class_based', 'dscp_based', 'ecn', 'exponential_weighting_constant', 'precedence_based'], name, value)


                        class Aggregate(Entity):
                            """
                            aggregate subclasses
                            
                            .. attribute:: minimum_thresh
                            
                            	minimum threshold for red aggregate
                            	**type**\: int
                            
                            	**range:** 0..1000000
                            
                            .. attribute:: maximum_thresh
                            
                            	maximum threshold for red aggregate
                            	**type**\: int
                            
                            	**range:** 0..1000000
                            
                            .. attribute:: mark_probability
                            
                            	mark\-probability for red aggregate
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: denominator
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Aggregate, self).__init__()

                                self.yang_name = "aggregate"
                                self.yang_parent_name = "random-detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('minimum_thresh', (YLeaf(YType.uint32, 'minimum-thresh'), ['int'])),
                                    ('maximum_thresh', (YLeaf(YType.uint32, 'maximum-thresh'), ['int'])),
                                    ('mark_probability', (YLeaf(YType.empty, 'mark-probability'), ['Empty'])),
                                    ('denominator', (YLeaf(YType.uint32, 'denominator'), ['int'])),
                                ])
                                self.minimum_thresh = None
                                self.maximum_thresh = None
                                self.mark_probability = None
                                self.denominator = None
                                self._segment_path = lambda: "aggregate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Aggregate, ['minimum_thresh', 'maximum_thresh', 'mark_probability', 'denominator'], name, value)


                        class Cos(Entity):
                            """
                            parameters for each cos value, supported on ASR9xx platform only
                            
                            .. attribute:: cos_val
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: min_threshold
                            
                            	minimum threshold (in packet by default)
                            	**type**\: int
                            
                            	**range:** 1..512000000
                            
                            .. attribute:: min_threshold_unit
                            
                            	bytes supported on ASR platform only, ms on ASR100x only, us on ASR9xx only
                            	**type**\:  :py:class:`BytesMsUsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.BytesMsUsType>`
                            
                            .. attribute:: max_threshold
                            
                            	maximum threshold (in packet by default)
                            	**type**\: int
                            
                            	**range:** 1..512000000
                            
                            .. attribute:: max_threshold_unit
                            
                            	bytes supported on ASR platform only, ms on ASR100x only, us on ASR9xx only
                            	**type**\:  :py:class:`BytesMsUsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.BytesMsUsType>`
                            
                            .. attribute:: denominator
                            
                            	mark probability denominator
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Cos, self).__init__()

                                self.yang_name = "cos"
                                self.yang_parent_name = "random-detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('cos_val', (YLeaf(YType.uint16, 'cos-val'), ['int'])),
                                    ('min_threshold', (YLeaf(YType.uint32, 'min-threshold'), ['int'])),
                                    ('min_threshold_unit', (YLeaf(YType.enumeration, 'min-threshold-unit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'BytesMsUsType', '')])),
                                    ('max_threshold', (YLeaf(YType.uint32, 'max-threshold'), ['int'])),
                                    ('max_threshold_unit', (YLeaf(YType.enumeration, 'max-threshold-unit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'BytesMsUsType', '')])),
                                    ('denominator', (YLeaf(YType.uint16, 'denominator'), ['int'])),
                                ])
                                self.cos_val = None
                                self.min_threshold = None
                                self.min_threshold_unit = None
                                self.max_threshold = None
                                self.max_threshold_unit = None
                                self.denominator = None
                                self._segment_path = lambda: "cos"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Cos, ['cos_val', 'min_threshold', 'min_threshold_unit', 'max_threshold', 'max_threshold_unit', 'denominator'], name, value)


                        class DiscardClass(Entity):
                            """
                            parameters for each discard\-class value
                            
                            .. attribute:: dclass
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: min_threshold
                            
                            	minimum threshold (in packet by default)
                            	**type**\: int
                            
                            	**range:** 1..512000000
                            
                            .. attribute:: min_threshold_unit
                            
                            	bytes supported on ASR platform only, ms on ASR100x only, us on ASR9xx only
                            	**type**\:  :py:class:`BytesMsUsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.BytesMsUsType>`
                            
                            .. attribute:: max_threshold
                            
                            	maximum threshold (in packet by default)
                            	**type**\: int
                            
                            	**range:** 1..512000000
                            
                            .. attribute:: max_threshold_unit
                            
                            	bytes supported on ASR platform only, ms on ASR100x only, us on ASR9xx only
                            	**type**\:  :py:class:`BytesMsUsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.BytesMsUsType>`
                            
                            .. attribute:: denominator
                            
                            	mark probability denominator
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.RandomDetect.DiscardClass, self).__init__()

                                self.yang_name = "discard-class"
                                self.yang_parent_name = "random-detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dclass', (YLeaf(YType.uint16, 'dclass'), ['int'])),
                                    ('min_threshold', (YLeaf(YType.uint32, 'min-threshold'), ['int'])),
                                    ('min_threshold_unit', (YLeaf(YType.enumeration, 'min-threshold-unit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'BytesMsUsType', '')])),
                                    ('max_threshold', (YLeaf(YType.uint32, 'max-threshold'), ['int'])),
                                    ('max_threshold_unit', (YLeaf(YType.enumeration, 'max-threshold-unit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'BytesMsUsType', '')])),
                                    ('denominator', (YLeaf(YType.uint16, 'denominator'), ['int'])),
                                ])
                                self.dclass = None
                                self.min_threshold = None
                                self.min_threshold_unit = None
                                self.max_threshold = None
                                self.max_threshold_unit = None
                                self.denominator = None
                                self._segment_path = lambda: "discard-class"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.RandomDetect.DiscardClass, ['dclass', 'min_threshold', 'min_threshold_unit', 'max_threshold', 'max_threshold_unit', 'denominator'], name, value)


                        class Dscp(Entity):
                            """
                            parameters for each dscp value
                            
                            .. attribute:: dscp_val  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..63
                            
                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                            
                            .. attribute:: min_threshold
                            
                            	minimum threshold (in packet by default)
                            	**type**\: int
                            
                            	**range:** 1..512000000
                            
                            .. attribute:: min_threshold_unit
                            
                            	bytes supported on ASR platform only, ms on ASR100x only, us on ASR9xx only
                            	**type**\:  :py:class:`BytesMsUsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.BytesMsUsType>`
                            
                            .. attribute:: max_threshold
                            
                            	maximum threshold (in packet by default)
                            	**type**\: int
                            
                            	**range:** 1..512000000
                            
                            .. attribute:: max_threshold_unit
                            
                            	bytes supported on ASR platform only, ms on ASR100x only, us on ASR9xx only
                            	**type**\:  :py:class:`BytesMsUsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.BytesMsUsType>`
                            
                            .. attribute:: denominator
                            
                            	mark probability denominator
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Dscp, self).__init__()

                                self.yang_name = "dscp"
                                self.yang_parent_name = "random-detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['dscp_val']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dscp_val', (YLeaf(YType.str, 'dscp-val'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                    ('min_threshold', (YLeaf(YType.uint32, 'min-threshold'), ['int'])),
                                    ('min_threshold_unit', (YLeaf(YType.enumeration, 'min-threshold-unit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'BytesMsUsType', '')])),
                                    ('max_threshold', (YLeaf(YType.uint32, 'max-threshold'), ['int'])),
                                    ('max_threshold_unit', (YLeaf(YType.enumeration, 'max-threshold-unit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'BytesMsUsType', '')])),
                                    ('denominator', (YLeaf(YType.uint16, 'denominator'), ['int'])),
                                ])
                                self.dscp_val = None
                                self.min_threshold = None
                                self.min_threshold_unit = None
                                self.max_threshold = None
                                self.max_threshold_unit = None
                                self.denominator = None
                                self._segment_path = lambda: "dscp" + "[dscp-val='" + str(self.dscp_val) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Dscp, ['dscp_val', 'min_threshold', 'min_threshold_unit', 'max_threshold', 'max_threshold_unit', 'denominator'], name, value)


                        class Precedence(Entity):
                            """
                            parameters for each precedence value
                            
                            .. attribute:: prec
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..7
                            
                            		**type**\:  :py:class:`PrecedenceType2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.PrecedenceType2>`
                            
                            .. attribute:: min_threshold
                            
                            	minimum threshold (in packet by default)
                            	**type**\: int
                            
                            	**range:** 1..512000000
                            
                            .. attribute:: min_threshold_unit
                            
                            	bytes supported on ASR platform only, ms on ASR100x only, us on ASR9xx only
                            	**type**\:  :py:class:`BytesMsUsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.BytesMsUsType>`
                            
                            .. attribute:: max_threshold
                            
                            	maximum threshold (in packet by default)
                            	**type**\: int
                            
                            	**range:** 1..512000000
                            
                            .. attribute:: max_threshold_unit
                            
                            	bytes supported on ASR platform only, ms on ASR100x only, us on ASR9xx only
                            	**type**\:  :py:class:`BytesMsUsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy.BytesMsUsType>`
                            
                            .. attribute:: denominator
                            
                            	mark probability denominator
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Precedence, self).__init__()

                                self.yang_name = "precedence"
                                self.yang_parent_name = "random-detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prec', (YLeaf(YType.str, 'prec'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'PrecedenceType2', '')])),
                                    ('min_threshold', (YLeaf(YType.uint32, 'min-threshold'), ['int'])),
                                    ('min_threshold_unit', (YLeaf(YType.enumeration, 'min-threshold-unit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'BytesMsUsType', '')])),
                                    ('max_threshold', (YLeaf(YType.uint32, 'max-threshold'), ['int'])),
                                    ('max_threshold_unit', (YLeaf(YType.enumeration, 'max-threshold-unit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_policy', 'BytesMsUsType', '')])),
                                    ('denominator', (YLeaf(YType.uint16, 'denominator'), ['int'])),
                                ])
                                self.prec = None
                                self.min_threshold = None
                                self.min_threshold_unit = None
                                self.max_threshold = None
                                self.max_threshold_unit = None
                                self.denominator = None
                                self._segment_path = lambda: "precedence"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.RandomDetect.Precedence, ['prec', 'min_threshold', 'min_threshold_unit', 'max_threshold', 'max_threshold_unit', 'denominator'], name, value)


                    class Set(Entity):
                        """
                        
                        
                        .. attribute:: atm_clp
                        
                        	Set ATM CLP bit to 1
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cos
                        
                        	Set IEEE 802.1Q/ISL class of service/user priority
                        	**type**\:  :py:class:`Cos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.Cos>`
                        
                        .. attribute:: discard_class
                        
                        	Discard behavior identifier
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: dscp
                        
                        	Set DSCP in IP(v4) and IPv6 packets
                        	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.Dscp>`
                        
                        .. attribute:: fr_de
                        
                        	Set FR DE bit to 1
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ip
                        
                        	Set IP specific values
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.Ip>`
                        
                        .. attribute:: mpls
                        
                        	Set MPLS specific values
                        	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.Mpls>`
                        
                        .. attribute:: qos_group
                        
                        	Set QoS Group
                        	**type**\:  :py:class:`QosGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.QosGroup>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.Set, self).__init__()

                            self.yang_name = "set"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cos", ("cos", Native.Policy.PolicyMap.Class.ActionList.Set.Cos)), ("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.Set.Dscp)), ("ip", ("ip", Native.Policy.PolicyMap.Class.ActionList.Set.Ip)), ("mpls", ("mpls", Native.Policy.PolicyMap.Class.ActionList.Set.Mpls)), ("qos-group", ("qos_group", Native.Policy.PolicyMap.Class.ActionList.Set.QosGroup))])
                            self._leafs = OrderedDict([
                                ('atm_clp', (YLeaf(YType.empty, 'atm-clp'), ['Empty'])),
                                ('discard_class', (YLeaf(YType.uint16, 'discard-class'), ['int'])),
                                ('fr_de', (YLeaf(YType.empty, 'fr-de'), ['Empty'])),
                            ])
                            self.atm_clp = None
                            self.discard_class = None
                            self.fr_de = None

                            self.cos = Native.Policy.PolicyMap.Class.ActionList.Set.Cos()
                            self.cos.parent = self
                            self._children_name_map["cos"] = "cos"

                            self.dscp = Native.Policy.PolicyMap.Class.ActionList.Set.Dscp()
                            self.dscp.parent = self
                            self._children_name_map["dscp"] = "dscp"

                            self.ip = Native.Policy.PolicyMap.Class.ActionList.Set.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"

                            self.mpls = Native.Policy.PolicyMap.Class.ActionList.Set.Mpls()
                            self.mpls.parent = self
                            self._children_name_map["mpls"] = "mpls"

                            self.qos_group = Native.Policy.PolicyMap.Class.ActionList.Set.QosGroup()
                            self.qos_group.parent = self
                            self._children_name_map["qos_group"] = "qos-group"
                            self._segment_path = lambda: "set"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set, ['atm_clp', 'discard_class', 'fr_de'], name, value)


                        class Cos(Entity):
                            """
                            Set IEEE 802.1Q/ISL class of service/user priority
                            
                            .. attribute:: val
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: pack
                            
                            	
                            	**type**\:  :py:class:`Pack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.Cos.Pack>`
                            
                            .. attribute:: user_priority
                            
                            	Set value from WLAN user\-priority
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: table
                            
                            	Set codepoint value based on tablemap
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.Set.Cos, self).__init__()

                                self.yang_name = "cos"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('val', (YLeaf(YType.uint16, 'val'), ['int'])),
                                    ('pack', (YLeaf(YType.enumeration, 'pack'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Policy.PolicyMap.Class.ActionList.Set.Cos.Pack')])),
                                    ('user_priority', (YLeaf(YType.empty, 'user-priority'), ['Empty'])),
                                    ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                ])
                                self.val = None
                                self.pack = None
                                self.user_priority = None
                                self.table = None
                                self._segment_path = lambda: "cos"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set.Cos, ['val', 'pack', 'user_priority', 'table'], name, value)

                            class Pack(Enum):
                                """
                                Pack (Enum Class)

                                .. data:: dscp = 0

                                .. data:: precedence = 1

                                .. data:: cos = 2

                                .. data:: qos_group = 3

                                .. data:: wlan = 4

                                """

                                dscp = Enum.YLeaf(0, "dscp")

                                precedence = Enum.YLeaf(1, "precedence")

                                cos = Enum.YLeaf(2, "cos")

                                qos_group = Enum.YLeaf(3, "qos-group")

                                wlan = Enum.YLeaf(4, "wlan")



                        class Dscp(Entity):
                            """
                            Set DSCP in IP(v4) and IPv6 packets
                            
                            .. attribute:: dscp
                            
                            	Set packet dscp from dscp
                            	**type**\:  :py:class:`Dscp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.Dscp.Dscp_>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: tunnel
                            
                            	set tunnel packet dscp
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp_val
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..63
                            
                            		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.Set.Dscp, self).__init__()

                                self.yang_name = "dscp"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.Set.Dscp.Dscp_))])
                                self._leafs = OrderedDict([
                                    ('tunnel', (YLeaf(YType.empty, 'tunnel'), ['Empty'])),
                                    ('dscp_val', (YLeaf(YType.str, 'dscp-val'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                ])
                                self.tunnel = None
                                self.dscp_val = None

                                self.dscp = None
                                self._children_name_map["dscp"] = "dscp"
                                self._segment_path = lambda: "dscp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set.Dscp, ['tunnel', 'dscp_val'], name, value)


                            class Dscp_(Entity):
                                """
                                Set packet dscp from dscp
                                
                                .. attribute:: table
                                
                                	Set packet dscp from dscp based on table map
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.Set.Dscp.Dscp_, self).__init__()

                                    self.yang_name = "dscp"
                                    self.yang_parent_name = "dscp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('table', (YLeaf(YType.str, 'table'), ['str'])),
                                    ])
                                    self.table = None
                                    self._segment_path = lambda: "dscp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set.Dscp.Dscp_, ['table'], name, value)


                        class Ip(Entity):
                            """
                            Set IP specific values
                            
                            .. attribute:: dscp
                            
                            	Set IP DSCP (DiffServ CodePointint)
                            	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.Ip.Dscp>`
                            
                            .. attribute:: precedence
                            
                            	Set IP precedence
                            	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.Ip.Precedence>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.Set.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dscp", ("dscp", Native.Policy.PolicyMap.Class.ActionList.Set.Ip.Dscp)), ("precedence", ("precedence", Native.Policy.PolicyMap.Class.ActionList.Set.Ip.Precedence))])
                                self._leafs = OrderedDict()

                                self.dscp = Native.Policy.PolicyMap.Class.ActionList.Set.Ip.Dscp()
                                self.dscp.parent = self
                                self._children_name_map["dscp"] = "dscp"

                                self.precedence = None
                                self._children_name_map["precedence"] = "precedence"
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set.Ip, [], name, value)


                            class Dscp(Entity):
                                """
                                Set IP DSCP (DiffServ CodePointint)
                                
                                .. attribute:: tunnel
                                
                                	set tunnel packet dscp
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: dscp_val
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..63
                                
                                		**type**\:  :py:class:`DscpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.DscpType>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.Set.Ip.Dscp, self).__init__()

                                    self.yang_name = "dscp"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('tunnel', (YLeaf(YType.empty, 'tunnel'), ['Empty'])),
                                        ('dscp_val', (YLeaf(YType.str, 'dscp-val'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'DscpType', '')])),
                                    ])
                                    self.tunnel = None
                                    self.dscp_val = None
                                    self._segment_path = lambda: "dscp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set.Ip.Dscp, ['tunnel', 'dscp_val'], name, value)


                            class Precedence(Entity):
                                """
                                Set IP precedence
                                
                                .. attribute:: precedence_val
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..7
                                
                                		**type**\:  :py:class:`PrecedenceType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.PrecedenceType>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.Set.Ip.Precedence, self).__init__()

                                    self.yang_name = "precedence"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('precedence_val', (YLeaf(YType.str, 'precedence-val'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'PrecedenceType', '')])),
                                    ])
                                    self.precedence_val = None
                                    self._segment_path = lambda: "precedence"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set.Ip.Precedence, ['precedence_val'], name, value)


                        class Mpls(Entity):
                            """
                            Set MPLS specific values
                            
                            .. attribute:: experimental
                            
                            	Set Experimental value
                            	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.Set.Mpls, self).__init__()

                                self.yang_name = "mpls"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("experimental", ("experimental", Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental))])
                                self._leafs = OrderedDict()

                                self.experimental = Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental()
                                self.experimental.parent = self
                                self._children_name_map["experimental"] = "experimental"
                                self._segment_path = lambda: "mpls"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set.Mpls, [], name, value)


                            class Experimental(Entity):
                                """
                                Set Experimental value
                                
                                .. attribute:: imposition
                                
                                	Set Experimental value at tag imposition
                                	**type**\:  :py:class:`Imposition <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental.Imposition>`
                                
                                .. attribute:: topmost
                                
                                	Set Experimental value  on topmost label
                                	**type**\:  :py:class:`Topmost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental.Topmost>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental, self).__init__()

                                    self.yang_name = "experimental"
                                    self.yang_parent_name = "mpls"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition", ("imposition", Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental.Imposition)), ("topmost", ("topmost", Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental.Topmost))])
                                    self._leafs = OrderedDict()

                                    self.imposition = Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental.Imposition()
                                    self.imposition.parent = self
                                    self._children_name_map["imposition"] = "imposition"

                                    self.topmost = Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental.Topmost()
                                    self.topmost.parent = self
                                    self._children_name_map["topmost"] = "topmost"
                                    self._segment_path = lambda: "experimental"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental, [], name, value)


                                class Imposition(Entity):
                                    """
                                    Set Experimental value at tag imposition
                                    
                                    .. attribute:: exp_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental.Imposition, self).__init__()

                                        self.yang_name = "imposition"
                                        self.yang_parent_name = "experimental"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('exp_value', (YLeaf(YType.uint8, 'exp-value'), ['int'])),
                                        ])
                                        self.exp_value = None
                                        self._segment_path = lambda: "imposition"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental.Imposition, ['exp_value'], name, value)


                                class Topmost(Entity):
                                    """
                                    Set Experimental value  on topmost label
                                    
                                    .. attribute:: exp_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental.Topmost, self).__init__()

                                        self.yang_name = "topmost"
                                        self.yang_parent_name = "experimental"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('exp_value', (YLeaf(YType.uint8, 'exp-value'), ['int'])),
                                        ])
                                        self.exp_value = None
                                        self._segment_path = lambda: "topmost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set.Mpls.Experimental.Topmost, ['exp_value'], name, value)


                        class QosGroup(Entity):
                            """
                            Set QoS Group
                            
                            .. attribute:: qos_group_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..99
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.Set.QosGroup, self).__init__()

                                self.yang_name = "qos-group"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('qos_group_value', (YLeaf(YType.uint8, 'qos-group-value'), ['int'])),
                                ])
                                self.qos_group_value = None
                                self._segment_path = lambda: "qos-group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Set.QosGroup, ['qos_group_value'], name, value)


                    class Shape(Entity):
                        """
                        
                        
                        .. attribute:: adaptive
                        
                        	Enable Traffic Shaping adaptation to BECN
                        	**type**\: int
                        
                        	**range:** 8000..154400000
                        
                        .. attribute:: average
                        
                        	configure token bucket\: CIR (bps) [Bc (bits) [Be (bits)]], send out Bc only per interval
                        	**type**\:  :py:class:`Average <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Shape.Average>`
                        
                        .. attribute:: fecn_adapt
                        
                        	Enable Traffic Shaping reflection of FECN as BECN
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fr_voice_adapt
                        
                        	Enable rate adjustment depending on voice presence
                        	**type**\:  :py:class:`FrVoiceAdapt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Shape.FrVoiceAdapt>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: max_buffers
                        
                        	Set Maximum Buffer Limit
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Policy.PolicyMap.Class.ActionList.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "action-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("average", ("average", Native.Policy.PolicyMap.Class.ActionList.Shape.Average)), ("fr-voice-adapt", ("fr_voice_adapt", Native.Policy.PolicyMap.Class.ActionList.Shape.FrVoiceAdapt))])
                            self._leafs = OrderedDict([
                                ('adaptive', (YLeaf(YType.uint32, 'adaptive'), ['int'])),
                                ('fecn_adapt', (YLeaf(YType.empty, 'fecn-adapt'), ['Empty'])),
                                ('max_buffers', (YLeaf(YType.uint16, 'max-buffers'), ['int'])),
                            ])
                            self.adaptive = None
                            self.fecn_adapt = None
                            self.max_buffers = None

                            self.average = Native.Policy.PolicyMap.Class.ActionList.Shape.Average()
                            self.average.parent = self
                            self._children_name_map["average"] = "average"

                            self.fr_voice_adapt = None
                            self._children_name_map["fr_voice_adapt"] = "fr-voice-adapt"
                            self._segment_path = lambda: "shape"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Shape, ['adaptive', 'fecn_adapt', 'max_buffers'], name, value)


                        class Average(Entity):
                            """
                            configure token bucket\: CIR (bps) [Bc (bits) [Be (bits)]], send out Bc only per interval
                            
                            .. attribute:: bit_rate
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bits_per_interval_sustained
                            
                            	
                            	**type**\: int
                            
                            	**range:** 256..154400000
                            
                            .. attribute:: bits_per_interval_excess
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..154400000
                            
                            .. attribute:: account
                            
                            	Overhead Accounting
                            	**type**\:  :py:class:`Account <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Shape.Average.Account>`
                            
                            .. attribute:: percent
                            
                            	% of interface bandwidth for Committed information rate
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: burst_size_sustained
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..2000
                            
                            .. attribute:: ms
                            
                            	milliseconds
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: bse
                            
                            	
                            	**type**\:  :py:class:`Bse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.PolicyMap.Class.ActionList.Shape.Average.Bse>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.Shape.Average, self).__init__()

                                self.yang_name = "average"
                                self.yang_parent_name = "shape"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("account", ("account", Native.Policy.PolicyMap.Class.ActionList.Shape.Average.Account)), ("bse", ("bse", Native.Policy.PolicyMap.Class.ActionList.Shape.Average.Bse))])
                                self._leafs = OrderedDict([
                                    ('bit_rate', (YLeaf(YType.uint64, 'bit-rate'), ['int'])),
                                    ('bits_per_interval_sustained', (YLeaf(YType.uint32, 'bits-per-interval-sustained'), ['int'])),
                                    ('bits_per_interval_excess', (YLeaf(YType.uint32, 'bits-per-interval-excess'), ['int'])),
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('burst_size_sustained', (YLeaf(YType.uint16, 'burst-size-sustained'), ['int'])),
                                    ('ms', (YLeaf(YType.empty, 'ms'), ['Empty'])),
                                ])
                                self.bit_rate = None
                                self.bits_per_interval_sustained = None
                                self.bits_per_interval_excess = None
                                self.percent = None
                                self.burst_size_sustained = None
                                self.ms = None

                                self.account = Native.Policy.PolicyMap.Class.ActionList.Shape.Average.Account()
                                self.account.parent = self
                                self._children_name_map["account"] = "account"

                                self.bse = Native.Policy.PolicyMap.Class.ActionList.Shape.Average.Bse()
                                self.bse.parent = self
                                self._children_name_map["bse"] = "bse"
                                self._segment_path = lambda: "average"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Shape.Average, ['bit_rate', 'bits_per_interval_sustained', 'bits_per_interval_excess', 'percent', 'burst_size_sustained', 'ms'], name, value)


                            class Account(Entity):
                                """
                                Overhead Accounting
                                
                                .. attribute:: user_defined
                                
                                	Offset Size
                                	**type**\: int
                                
                                	**range:** \-1000000..1000000
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.Shape.Average.Account, self).__init__()

                                    self.yang_name = "account"
                                    self.yang_parent_name = "average"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('user_defined', (YLeaf(YType.int32, 'user-defined'), ['int'])),
                                    ])
                                    self.user_defined = None
                                    self._segment_path = lambda: "account"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Shape.Average.Account, ['user_defined'], name, value)


                            class Bse(Entity):
                                """
                                
                                
                                .. attribute:: burst_size_excess
                                
                                	
                                	**type**\: int
                                
                                	**range:** 10..2000
                                
                                .. attribute:: ms
                                
                                	milliseconds
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Policy.PolicyMap.Class.ActionList.Shape.Average.Bse, self).__init__()

                                    self.yang_name = "bse"
                                    self.yang_parent_name = "average"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('burst_size_excess', (YLeaf(YType.uint16, 'burst-size-excess'), ['int'])),
                                        ('ms', (YLeaf(YType.empty, 'ms'), ['Empty'])),
                                    ])
                                    self.burst_size_excess = None
                                    self.ms = None
                                    self._segment_path = lambda: "bse"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Shape.Average.Bse, ['burst_size_excess', 'ms'], name, value)


                        class FrVoiceAdapt(Entity):
                            """
                            Enable rate adjustment depending on voice presence
                            
                            .. attribute:: deactivation
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..10000
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Policy.PolicyMap.Class.ActionList.Shape.FrVoiceAdapt, self).__init__()

                                self.yang_name = "fr-voice-adapt"
                                self.yang_parent_name = "shape"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('deactivation', (YLeaf(YType.uint16, 'deactivation'), ['int'])),
                                ])
                                self.deactivation = None
                                self._segment_path = lambda: "fr-voice-adapt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Policy.PolicyMap.Class.ActionList.Shape.FrVoiceAdapt, ['deactivation'], name, value)


    class Interface(Entity):
        """
        Configure Interfaces
        
        .. attribute:: appnav_compress
        
        	Service\-Context Virtual Interface Compress
        	**type**\: list of  		 :py:class:`AppNavCompress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress>`
        
        .. attribute:: appnav_uncompress
        
        	Service\-Context Virtual Interface UnCompress
        	**type**\: list of  		 :py:class:`AppNavUnCompress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress>`
        
        .. attribute:: atm
        
        	ATM interface
        	**type**\: list of  		 :py:class:`ATM <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM>`
        
        .. attribute:: atm_subinterface
        
        	
        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface>`
        
        .. attribute:: atm_acr
        
        	ATM\-ACR interface
        	**type**\: list of  		 :py:class:`ATMACR <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR>`
        
        .. attribute:: atm_acrsubinterface
        
        	
        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface>`
        
        .. attribute:: bdi
        
        	Bridge\-Domain interface
        	**type**\: list of  		 :py:class:`BDI <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI>`
        
        .. attribute:: cem
        
        	Circuit Emulation interface
        	**type**\: list of  		 :py:class:`CEM <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM>`
        
        .. attribute:: cem_acr
        
        	Circuit Emulation interface
        	**type**\: list of  		 :py:class:`CEMACR <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR>`
        
        .. attribute:: embedded_service_engine
        
        	cisco embedded service engine module
        	**type**\: list of  		 :py:class:`EmbeddedServiceEngine <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine>`
        
        .. attribute:: ethernet
        
        	IEEE 802.3
        	**type**\: list of  		 :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet>`
        
        .. attribute:: fastethernet
        
        	FastEthernet IEEE 802.3
        	**type**\: list of  		 :py:class:`FastEthernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet>`
        
        .. attribute:: ucse
        
        	Cisco ucse server
        	**type**\: list of  		 :py:class:`Ucse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse>`
        
        .. attribute:: ethernet_internal
        
        	Ethernet\-Internal interface
        	**type**\: list of  		 :py:class:`EthernetInternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal>`
        
        .. attribute:: service_engine
        
        	Cisco service engine module
        	**type**\: list of  		 :py:class:`ServiceEngine <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine>`
        
        .. attribute:: gigabitethernet
        
        	GigabitEthernet IEEE 802.3z
        	**type**\: list of  		 :py:class:`GigabitEthernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet>`
        
        .. attribute:: twogigabitethernet
        
        	Two Gigabit Ethernet
        	**type**\: list of  		 :py:class:`TwoGigabitEthernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet>`
        
        .. attribute:: fivegigabitethernet
        
        	Five Gigabit Ethernet
        	**type**\: list of  		 :py:class:`FiveGigabitEthernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet>`
        
        .. attribute:: tengigabitethernet
        
        	Ten Gigabit Ethernet
        	**type**\: list of  		 :py:class:`TenGigabitEthernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet>`
        
        .. attribute:: twentyfivegige
        
        	Twenty Five Gigabit Ethernet
        	**type**\: list of  		 :py:class:`TwentyFiveGigE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE>`
        
        .. attribute:: fortygigabitethernet
        
        	Forty Gigabit Ethernet
        	**type**\: list of  		 :py:class:`FortyGigabitEthernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet>`
        
        .. attribute:: hundredgige
        
        	Hundred Gigabit Ethernet
        	**type**\: list of  		 :py:class:`HundredGigE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE>`
        
        .. attribute:: loopback
        
        	Loopback interface
        	**type**\: list of  		 :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback>`
        
        .. attribute:: lisp
        
        	Locator/ID Separation Protocol Virtual Interface
        	**type**\: list of  		 :py:class:`LISP <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP>`
        
        .. attribute:: lisp_subinterface
        
        	Locator/ID Separation Protocol Virtual Interface
        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface>`
        
        .. attribute:: nve
        
        	Network virtualization endpoint interface
        	**type**\: list of  		 :py:class:`Nve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve>`
        
        .. attribute:: overlay
        
        	Overlay interface
        	**type**\: list of  		 :py:class:`Overlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay>`
        
        .. attribute:: port_channel
        
        	Ethernet Channel of interfaces
        	**type**\: list of  		 :py:class:`PortChannel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel>`
        
        .. attribute:: port_channel_subinterface
        
        	
        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface>`
        
        .. attribute:: pseudowire
        
        	Pseudowire Interface
        	**type**\: list of  		 :py:class:`Pseudowire <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire>`
        
        .. attribute:: sm
        
        	SM Interface
        	**type**\: list of  		 :py:class:`SM <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM>`
        
        .. attribute:: cellular
        
        	Cellular Interface
        	**type**\: list of  		 :py:class:`Cellular <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular>`
        
        .. attribute:: vlan
        
        	Catalyst Vlans
        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan>`
        
        .. attribute:: group_async
        
        	Async Group interface
        	**type**\: list of  		 :py:class:`GroupAsync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync>`
        
        .. attribute:: multilink
        
        	Multilink\-group interface
        	**type**\: list of  		 :py:class:`Multilink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink>`
        
        .. attribute:: serial
        
        	Serial interface
        	**type**\: list of  		 :py:class:`Serial <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial>`
        
        .. attribute:: tunnel
        
        	Tunnel interface
        	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel>`
        
        .. attribute:: virtual_template
        
        	Virtual Template interface
        	**type**\: list of  		 :py:class:`VirtualTemplate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate>`
        
        .. attribute:: virtualportgroup
        
        	Virtual Port Group
        	**type**\: list of  		 :py:class:`VirtualPortGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup>`
        
        .. attribute:: vasileft
        
        	vasileft
        	**type**\: list of  		 :py:class:`Vasileft <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft>`
        
        .. attribute:: vasiright
        
        	vasiright
        	**type**\: list of  		 :py:class:`Vasiright <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Interface, self).__init__()

            self.yang_name = "interface"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("AppNav-Compress", ("appnav_compress", Native.Interface.AppNavCompress)), ("AppNav-UnCompress", ("appnav_uncompress", Native.Interface.AppNavUnCompress)), ("ATM", ("atm", Native.Interface.ATM)), ("ATM-subinterface", ("atm_subinterface", Native.Interface.ATMSubinterface)), ("ATM-ACR", ("atm_acr", Native.Interface.ATMACR)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.ATMACRsubinterface)), ("BDI", ("bdi", Native.Interface.BDI)), ("CEM", ("cem", Native.Interface.CEM)), ("CEM-ACR", ("cem_acr", Native.Interface.CEMACR)), ("Embedded-Service-Engine", ("embedded_service_engine", Native.Interface.EmbeddedServiceEngine)), ("Ethernet", ("ethernet", Native.Interface.Ethernet)), ("FastEthernet", ("fastethernet", Native.Interface.FastEthernet)), ("ucse", ("ucse", Native.Interface.Ucse)), ("Ethernet-Internal", ("ethernet_internal", Native.Interface.EthernetInternal)), ("Service-Engine", ("service_engine", Native.Interface.ServiceEngine)), ("GigabitEthernet", ("gigabitethernet", Native.Interface.GigabitEthernet)), ("TwoGigabitEthernet", ("twogigabitethernet", Native.Interface.TwoGigabitEthernet)), ("FiveGigabitEthernet", ("fivegigabitethernet", Native.Interface.FiveGigabitEthernet)), ("TenGigabitEthernet", ("tengigabitethernet", Native.Interface.TenGigabitEthernet)), ("TwentyFiveGigE", ("twentyfivegige", Native.Interface.TwentyFiveGigE)), ("FortyGigabitEthernet", ("fortygigabitethernet", Native.Interface.FortyGigabitEthernet)), ("HundredGigE", ("hundredgige", Native.Interface.HundredGigE)), ("Loopback", ("loopback", Native.Interface.Loopback)), ("LISP", ("lisp", Native.Interface.LISP)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.LISPSubinterface)), ("nve", ("nve", Native.Interface.Nve)), ("overlay", ("overlay", Native.Interface.Overlay)), ("Port-channel", ("port_channel", Native.Interface.PortChannel)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.PortChannelSubinterface)), ("pseudowire", ("pseudowire", Native.Interface.Pseudowire)), ("SM", ("sm", Native.Interface.SM)), ("Cellular", ("cellular", Native.Interface.Cellular)), ("Vlan", ("vlan", Native.Interface.Vlan)), ("Group-Async", ("group_async", Native.Interface.GroupAsync)), ("Multilink", ("multilink", Native.Interface.Multilink)), ("Serial", ("serial", Native.Interface.Serial)), ("Tunnel", ("tunnel", Native.Interface.Tunnel)), ("Virtual-Template", ("virtual_template", Native.Interface.VirtualTemplate)), ("VirtualPortGroup", ("virtualportgroup", Native.Interface.VirtualPortGroup)), ("vasileft", ("vasileft", Native.Interface.Vasileft)), ("vasiright", ("vasiright", Native.Interface.Vasiright))])
            self._leafs = OrderedDict()

            self.atm_subinterface = Native.Interface.ATMSubinterface()
            self.atm_subinterface.parent = self
            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

            self.atm_acrsubinterface = Native.Interface.ATMACRsubinterface()
            self.atm_acrsubinterface.parent = self
            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

            self.lisp_subinterface = Native.Interface.LISPSubinterface()
            self.lisp_subinterface.parent = self
            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

            self.port_channel_subinterface = Native.Interface.PortChannelSubinterface()
            self.port_channel_subinterface.parent = self
            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"

            self.appnav_compress = YList(self)
            self.appnav_uncompress = YList(self)
            self.atm = YList(self)
            self.atm_acr = YList(self)
            self.bdi = YList(self)
            self.cem = YList(self)
            self.cem_acr = YList(self)
            self.embedded_service_engine = YList(self)
            self.ethernet = YList(self)
            self.fastethernet = YList(self)
            self.ucse = YList(self)
            self.ethernet_internal = YList(self)
            self.service_engine = YList(self)
            self.gigabitethernet = YList(self)
            self.twogigabitethernet = YList(self)
            self.fivegigabitethernet = YList(self)
            self.tengigabitethernet = YList(self)
            self.twentyfivegige = YList(self)
            self.fortygigabitethernet = YList(self)
            self.hundredgige = YList(self)
            self.loopback = YList(self)
            self.lisp = YList(self)
            self.nve = YList(self)
            self.overlay = YList(self)
            self.port_channel = YList(self)
            self.pseudowire = YList(self)
            self.sm = YList(self)
            self.cellular = YList(self)
            self.vlan = YList(self)
            self.group_async = YList(self)
            self.multilink = YList(self)
            self.serial = YList(self)
            self.tunnel = YList(self)
            self.virtual_template = YList(self)
            self.virtualportgroup = YList(self)
            self.vasileft = YList(self)
            self.vasiright = YList(self)
            self._segment_path = lambda: "interface"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Interface, [], name, value)


        class AppNavCompress(Entity):
            """
            Service\-Context Virtual Interface Compress
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..1000
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.PmPath>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.AppNavCompress, self).__init__()

                self.yang_name = "AppNav-Compress"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.AppNavCompress.SwitchportConf)), ("switchport", ("switchport", Native.Interface.AppNavCompress.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.AppNavCompress.StackwiseVirtual)), ("arp", ("arp", Native.Interface.AppNavCompress.Arp)), ("backup", ("backup", Native.Interface.AppNavCompress.Backup)), ("cemoudp", ("cemoudp", Native.Interface.AppNavCompress.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.AppNavCompress.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.AppNavCompress.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.AppNavCompress.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.AppNavCompress.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.AppNavCompress.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.AppNavCompress.Flowcontrol)), ("isis", ("isis", Native.Interface.AppNavCompress.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.AppNavCompress.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.AppNavCompress.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.AppNavCompress.Bandwidth)), ("dampening", ("dampening", Native.Interface.AppNavCompress.Dampening)), ("domain", ("domain", Native.Interface.AppNavCompress.Domain)), ("hold-queue", ("hold_queue", Native.Interface.AppNavCompress.HoldQueue)), ("mpls", ("mpls", Native.Interface.AppNavCompress.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.AppNavCompress.IpVrf)), ("vrf", ("vrf", Native.Interface.AppNavCompress.Vrf)), ("ip", ("ip", Native.Interface.AppNavCompress.Ip)), ("ipv6", ("ipv6", Native.Interface.AppNavCompress.Ipv6)), ("logging", ("logging", Native.Interface.AppNavCompress.Logging)), ("mdix", ("mdix", Native.Interface.AppNavCompress.Mdix)), ("mop", ("mop", Native.Interface.AppNavCompress.Mop)), ("interface_qos", ("interface_qos", Native.Interface.AppNavCompress.InterfaceQos)), ("source", ("source", Native.Interface.AppNavCompress.Source)), ("standby", ("standby", Native.Interface.AppNavCompress.Standby)), ("access-session", ("access_session", Native.Interface.AppNavCompress.AccessSession)), ("storm-control", ("storm_control", Native.Interface.AppNavCompress.StormControl)), ("trust", ("trust", Native.Interface.AppNavCompress.Trust)), ("priority-queue", ("priority_queue", Native.Interface.AppNavCompress.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.AppNavCompress.RcvQueue)), ("peer", ("peer", Native.Interface.AppNavCompress.Peer)), ("pm-path", ("pm_path", Native.Interface.AppNavCompress.PmPath))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.AppNavCompress.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.AppNavCompress.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.AppNavCompress.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.AppNavCompress.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.AppNavCompress.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.AppNavCompress.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.AppNavCompress.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.AppNavCompress.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.AppNavCompress.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.AppNavCompress.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.AppNavCompress.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.AppNavCompress.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.AppNavCompress.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.AppNavCompress.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.AppNavCompress.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.AppNavCompress.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.AppNavCompress.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.AppNavCompress.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.AppNavCompress.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.AppNavCompress.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.AppNavCompress.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.AppNavCompress.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.AppNavCompress.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.AppNavCompress.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.AppNavCompress.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.AppNavCompress.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.AppNavCompress.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.AppNavCompress.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.AppNavCompress.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.AppNavCompress.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.AppNavCompress.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.AppNavCompress.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.AppNavCompress.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.AppNavCompress.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.AppNavCompress.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "AppNav-Compress" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.AppNavCompress, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.AppNavCompress.Backup.Delay)), ("interface", ("interface", Native.Interface.AppNavCompress.Backup.Interface_)), ("load", ("load", Native.Interface.AppNavCompress.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.AppNavCompress.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.AppNavCompress.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.AppNavCompress.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.AppNavCompress.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.AppNavCompress.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.AppNavCompress.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.AppNavCompress.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.AppNavCompress.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.AppNavCompress.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.AppNavCompress.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.AppNavCompress.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.AppNavCompress.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.AppNavCompress.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.AppNavCompress.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.AppNavCompress.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.AppNavCompress.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.AppNavCompress.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.AppNavCompress.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.AppNavCompress.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.AppNavCompress.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.AppNavCompress.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.AppNavCompress.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.AppNavCompress.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.AppNavCompress.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.AppNavCompress.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.AppNavCompress.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.AppNavCompress.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.AppNavCompress.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.AppNavCompress.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.AppNavCompress.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.AppNavCompress.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.AppNavCompress.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.AppNavCompress.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.AppNavCompress.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.AppNavCompress.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.AppNavCompress.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.AppNavCompress.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.AppNavCompress.Ip.Arp)), ("vrf", ("vrf", Native.Interface.AppNavCompress.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.AppNavCompress.Ip.NoAddress)), ("address", ("address", Native.Interface.AppNavCompress.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.AppNavCompress.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.AppNavCompress.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.AppNavCompress.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.AppNavCompress.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.AppNavCompress.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.AppNavCompress.Ip.Pim)), ("policy", ("policy", Native.Interface.AppNavCompress.Ip.Policy)), ("rip", ("rip", Native.Interface.AppNavCompress.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.AppNavCompress.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.AppNavCompress.Ip.RouteCache)), ("router", ("router", Native.Interface.AppNavCompress.Ip.Router)), ("tcp", ("tcp", Native.Interface.AppNavCompress.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.AppNavCompress.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.AppNavCompress.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.AppNavCompress.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.AppNavCompress.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.AppNavCompress.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.AppNavCompress.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.AppNavCompress.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.AppNavCompress.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.AppNavCompress.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.AppNavCompress.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.AppNavCompress.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.AppNavCompress.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.AppNavCompress.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.AppNavCompress.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.AppNavCompress.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.AppNavCompress.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.AppNavCompress.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.AppNavCompress.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.AppNavCompress.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.AppNavCompress.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.AppNavCompress.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.AppNavCompress.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.AppNavCompress.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.AppNavCompress.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.AppNavCompress.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.AppNavCompress.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.AppNavCompress.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.AppNavCompress.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.AppNavCompress.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.AppNavCompress.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.AppNavCompress.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.AppNavCompress.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.AppNavCompress.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.AppNavCompress.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.AppNavCompress.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.AppNavCompress.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.AppNavCompress.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.AppNavCompress.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.AppNavCompress.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.AppNavCompress.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.AppNavCompress.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.AppNavCompress.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.AppNavCompress.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.AppNavCompress.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.AppNavCompress.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.AppNavCompress.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.AppNavCompress.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.AppNavCompress.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.AppNavCompress.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.AppNavCompress.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.AppNavCompress.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.AppNavCompress.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.AppNavCompress.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.AppNavCompress.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.AppNavCompress.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.AppNavCompress.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.AppNavCompress.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.AppNavCompress.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.AppNavCompress.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.AppNavCompress.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.AppNavCompress.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.AppNavCompress.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.AppNavCompress.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.AppNavCompress.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.AppNavCompress.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.AppNavCompress.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.AppNavCompress.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.AppNavCompress.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.AppNavCompress.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.AppNavCompress.Ipv6.Dhcp)), ("address", ("address", Native.Interface.AppNavCompress.Ipv6.Address)), ("nd", ("nd", Native.Interface.AppNavCompress.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.AppNavCompress.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.AppNavCompress.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.AppNavCompress.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.AppNavCompress.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.AppNavCompress.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.AppNavCompress.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.AppNavCompress.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.AppNavCompress.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.AppNavCompress.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.AppNavCompress.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.AppNavCompress.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.AppNavCompress.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.AppNavCompress.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.AppNavCompress.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.AppNavCompress.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.AppNavCompress.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.AppNavCompress.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.AppNavCompress.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.AppNavCompress.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.AppNavCompress.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.AppNavCompress.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.AppNavCompress.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.AppNavCompress.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.AppNavCompress.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.AppNavCompress.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.AppNavCompress.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.AppNavCompress.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.AppNavCompress.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.AppNavCompress.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.AppNavCompress.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.AppNavCompress.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.AppNavCompress.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.AppNavCompress.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.AppNavCompress.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.AppNavCompress.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.AppNavCompress.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.AppNavCompress.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.AppNavCompress.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.AppNavCompress.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.AppNavCompress.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.AppNavCompress.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.AppNavCompress.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.AppNavCompress.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.AppNavCompress.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.AppNavCompress.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.AppNavCompress.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.AppNavCompress.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.AppNavCompress.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.AppNavCompress.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.AppNavCompress.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.AppNavCompress.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.AppNavCompress.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.AppNavCompress.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.AppNavCompress.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.AppNavCompress.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.AppNavCompress.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.AppNavCompress.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.AppNavCompress.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.AppNavCompress.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.AppNavCompress.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.AppNavCompress.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.AppNavCompress.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.AppNavCompress.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.AppNavCompress.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.AppNavCompress.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.AppNavCompress.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.AppNavCompress.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.AppNavCompress.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.AppNavCompress.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.AppNavCompress.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.AppNavCompress.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.AppNavCompress.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavCompress.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.AppNavCompress.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.AppNavCompress.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.AppNavCompress.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.AppNavCompress.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.AppNavCompress.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavCompress.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.AppNavCompress.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.AppNavCompress.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavCompress.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavCompress.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.AppNavCompress.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.AppNavCompress.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavCompress.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavCompress.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavCompress.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.AppNavCompress.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.AppNavCompress.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavCompress.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.AppNavCompress.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.AppNavCompress.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.AppNavCompress.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.AppNavCompress.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavCompress.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "AppNav-Compress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavCompress.PmPath, [u'name', u'interface_id'], name, value)


        class AppNavUnCompress(Entity):
            """
            Service\-Context Virtual Interface UnCompress
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..1000
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.PmPath>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.AppNavUnCompress, self).__init__()

                self.yang_name = "AppNav-UnCompress"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.AppNavUnCompress.SwitchportConf)), ("switchport", ("switchport", Native.Interface.AppNavUnCompress.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.AppNavUnCompress.StackwiseVirtual)), ("arp", ("arp", Native.Interface.AppNavUnCompress.Arp)), ("backup", ("backup", Native.Interface.AppNavUnCompress.Backup)), ("cemoudp", ("cemoudp", Native.Interface.AppNavUnCompress.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.AppNavUnCompress.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.AppNavUnCompress.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.AppNavUnCompress.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.AppNavUnCompress.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.AppNavUnCompress.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.AppNavUnCompress.Flowcontrol)), ("isis", ("isis", Native.Interface.AppNavUnCompress.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.AppNavUnCompress.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.AppNavUnCompress.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.AppNavUnCompress.Bandwidth)), ("dampening", ("dampening", Native.Interface.AppNavUnCompress.Dampening)), ("domain", ("domain", Native.Interface.AppNavUnCompress.Domain)), ("hold-queue", ("hold_queue", Native.Interface.AppNavUnCompress.HoldQueue)), ("mpls", ("mpls", Native.Interface.AppNavUnCompress.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.AppNavUnCompress.IpVrf)), ("vrf", ("vrf", Native.Interface.AppNavUnCompress.Vrf)), ("ip", ("ip", Native.Interface.AppNavUnCompress.Ip)), ("ipv6", ("ipv6", Native.Interface.AppNavUnCompress.Ipv6)), ("logging", ("logging", Native.Interface.AppNavUnCompress.Logging)), ("mdix", ("mdix", Native.Interface.AppNavUnCompress.Mdix)), ("mop", ("mop", Native.Interface.AppNavUnCompress.Mop)), ("interface_qos", ("interface_qos", Native.Interface.AppNavUnCompress.InterfaceQos)), ("source", ("source", Native.Interface.AppNavUnCompress.Source)), ("standby", ("standby", Native.Interface.AppNavUnCompress.Standby)), ("access-session", ("access_session", Native.Interface.AppNavUnCompress.AccessSession)), ("storm-control", ("storm_control", Native.Interface.AppNavUnCompress.StormControl)), ("trust", ("trust", Native.Interface.AppNavUnCompress.Trust)), ("priority-queue", ("priority_queue", Native.Interface.AppNavUnCompress.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.AppNavUnCompress.RcvQueue)), ("peer", ("peer", Native.Interface.AppNavUnCompress.Peer)), ("pm-path", ("pm_path", Native.Interface.AppNavUnCompress.PmPath))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.AppNavUnCompress.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.AppNavUnCompress.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.AppNavUnCompress.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.AppNavUnCompress.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.AppNavUnCompress.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.AppNavUnCompress.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.AppNavUnCompress.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.AppNavUnCompress.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.AppNavUnCompress.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.AppNavUnCompress.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.AppNavUnCompress.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.AppNavUnCompress.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.AppNavUnCompress.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.AppNavUnCompress.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.AppNavUnCompress.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.AppNavUnCompress.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.AppNavUnCompress.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.AppNavUnCompress.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.AppNavUnCompress.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.AppNavUnCompress.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.AppNavUnCompress.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.AppNavUnCompress.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.AppNavUnCompress.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.AppNavUnCompress.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.AppNavUnCompress.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.AppNavUnCompress.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.AppNavUnCompress.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.AppNavUnCompress.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.AppNavUnCompress.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.AppNavUnCompress.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.AppNavUnCompress.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.AppNavUnCompress.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.AppNavUnCompress.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.AppNavUnCompress.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.AppNavUnCompress.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "AppNav-UnCompress" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.AppNavUnCompress, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.AppNavUnCompress.Backup.Delay)), ("interface", ("interface", Native.Interface.AppNavUnCompress.Backup.Interface_)), ("load", ("load", Native.Interface.AppNavUnCompress.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.AppNavUnCompress.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.AppNavUnCompress.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.AppNavUnCompress.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.AppNavUnCompress.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.AppNavUnCompress.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.AppNavUnCompress.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.AppNavUnCompress.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.AppNavUnCompress.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.AppNavUnCompress.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.AppNavUnCompress.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.AppNavUnCompress.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.AppNavUnCompress.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.AppNavUnCompress.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.AppNavUnCompress.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.AppNavUnCompress.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.AppNavUnCompress.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.AppNavUnCompress.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.AppNavUnCompress.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.AppNavUnCompress.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.AppNavUnCompress.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.AppNavUnCompress.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.AppNavUnCompress.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.AppNavUnCompress.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.AppNavUnCompress.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.AppNavUnCompress.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.AppNavUnCompress.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.AppNavUnCompress.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.AppNavUnCompress.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.AppNavUnCompress.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.AppNavUnCompress.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.AppNavUnCompress.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.AppNavUnCompress.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.AppNavUnCompress.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.AppNavUnCompress.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.AppNavUnCompress.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.AppNavUnCompress.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.AppNavUnCompress.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.AppNavUnCompress.Ip.Arp)), ("vrf", ("vrf", Native.Interface.AppNavUnCompress.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.AppNavUnCompress.Ip.NoAddress)), ("address", ("address", Native.Interface.AppNavUnCompress.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.AppNavUnCompress.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.AppNavUnCompress.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.AppNavUnCompress.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.AppNavUnCompress.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.AppNavUnCompress.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.AppNavUnCompress.Ip.Pim)), ("policy", ("policy", Native.Interface.AppNavUnCompress.Ip.Policy)), ("rip", ("rip", Native.Interface.AppNavUnCompress.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.AppNavUnCompress.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.AppNavUnCompress.Ip.RouteCache)), ("router", ("router", Native.Interface.AppNavUnCompress.Ip.Router)), ("tcp", ("tcp", Native.Interface.AppNavUnCompress.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.AppNavUnCompress.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.AppNavUnCompress.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.AppNavUnCompress.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.AppNavUnCompress.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.AppNavUnCompress.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.AppNavUnCompress.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.AppNavUnCompress.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.AppNavUnCompress.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.AppNavUnCompress.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.AppNavUnCompress.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.AppNavUnCompress.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.AppNavUnCompress.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.AppNavUnCompress.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.AppNavUnCompress.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.AppNavUnCompress.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.AppNavUnCompress.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.AppNavUnCompress.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.AppNavUnCompress.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.AppNavUnCompress.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.AppNavUnCompress.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.AppNavUnCompress.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.AppNavUnCompress.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.AppNavUnCompress.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.AppNavUnCompress.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.AppNavUnCompress.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.AppNavUnCompress.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.AppNavUnCompress.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.AppNavUnCompress.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.AppNavUnCompress.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.AppNavUnCompress.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.AppNavUnCompress.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.AppNavUnCompress.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.AppNavUnCompress.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.AppNavUnCompress.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.AppNavUnCompress.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.AppNavUnCompress.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.AppNavUnCompress.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.AppNavUnCompress.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.AppNavUnCompress.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.AppNavUnCompress.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.AppNavUnCompress.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.AppNavUnCompress.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.AppNavUnCompress.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.AppNavUnCompress.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.AppNavUnCompress.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.AppNavUnCompress.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.AppNavUnCompress.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.AppNavUnCompress.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.AppNavUnCompress.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.AppNavUnCompress.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.AppNavUnCompress.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.AppNavUnCompress.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.AppNavUnCompress.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.AppNavUnCompress.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.AppNavUnCompress.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.AppNavUnCompress.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.AppNavUnCompress.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.AppNavUnCompress.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.AppNavUnCompress.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.AppNavUnCompress.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.AppNavUnCompress.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.AppNavUnCompress.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.AppNavUnCompress.Ipv6.Dhcp)), ("address", ("address", Native.Interface.AppNavUnCompress.Ipv6.Address)), ("nd", ("nd", Native.Interface.AppNavUnCompress.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.AppNavUnCompress.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.AppNavUnCompress.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.AppNavUnCompress.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.AppNavUnCompress.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.AppNavUnCompress.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.AppNavUnCompress.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.AppNavUnCompress.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.AppNavUnCompress.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.AppNavUnCompress.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.AppNavUnCompress.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.AppNavUnCompress.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.AppNavUnCompress.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.AppNavUnCompress.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.AppNavUnCompress.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.AppNavUnCompress.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.AppNavUnCompress.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.AppNavUnCompress.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.AppNavUnCompress.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.AppNavUnCompress.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.AppNavUnCompress.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.AppNavUnCompress.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.AppNavUnCompress.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.AppNavUnCompress.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.AppNavUnCompress.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.AppNavUnCompress.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.AppNavUnCompress.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.AppNavUnCompress.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.AppNavUnCompress.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.AppNavUnCompress.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.AppNavUnCompress.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.AppNavUnCompress.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.AppNavUnCompress.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.AppNavUnCompress.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.AppNavUnCompress.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.AppNavUnCompress.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.AppNavUnCompress.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.AppNavUnCompress.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.AppNavUnCompress.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.AppNavUnCompress.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.AppNavUnCompress.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.AppNavUnCompress.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.AppNavUnCompress.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.AppNavUnCompress.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.AppNavUnCompress.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.AppNavUnCompress.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.AppNavUnCompress.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.AppNavUnCompress.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.AppNavUnCompress.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.AppNavUnCompress.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.AppNavUnCompress.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.AppNavUnCompress.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.AppNavUnCompress.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.AppNavUnCompress.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.AppNavUnCompress.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.AppNavUnCompress.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.AppNavUnCompress.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.AppNavUnCompress.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.AppNavUnCompress.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.AppNavUnCompress.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.AppNavUnCompress.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.AppNavUnCompress.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.AppNavUnCompress.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "AppNav-UnCompress"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.AppNavUnCompress.PmPath, [u'name', u'interface_id'], name, value)


        class ATM(Entity):
            """
            ATM interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Vrf>`
            
            .. attribute:: cisco_ios_xe_interfaces_ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6>`
            
            .. attribute:: cisco_ios_xe_interfaces_load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.PmPath>`
            
            .. attribute:: service_policy
            
            	
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.ServicePolicy>`
            
            .. attribute:: cisco_ios_xe_atm_ip_
            
            	IP address
            	**type**\:  :py:class:`CiscoIOSXEAtmIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEAtmIp>`
            
            .. attribute:: atm
            
            	ATM
            	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm>`
            
            .. attribute:: cisco_ios_xe_atm_load_interval
            
            	Load interval
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: cdp
            
            	
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cdp>`
            
            .. attribute:: cem
            
            	CEM
            	**type**\: list of  		 :py:class:`Cem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cem>`
            
            .. attribute:: pvc
            
            	PVC
            	**type**\: list of  		 :py:class:`Pvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.ATM, self).__init__()

                self.yang_name = "ATM"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.ATM.SwitchportConf)), ("switchport", ("switchport", Native.Interface.ATM.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.ATM.StackwiseVirtual)), ("arp", ("arp", Native.Interface.ATM.Arp)), ("backup", ("backup", Native.Interface.ATM.Backup)), ("cemoudp", ("cemoudp", Native.Interface.ATM.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.ATM.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.ATM.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.ATM.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.ATM.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.ATM.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.ATM.Flowcontrol)), ("isis", ("isis", Native.Interface.ATM.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.ATM.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.ATM.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.ATM.Bandwidth)), ("dampening", ("dampening", Native.Interface.ATM.Dampening)), ("domain", ("domain", Native.Interface.ATM.Domain)), ("hold-queue", ("hold_queue", Native.Interface.ATM.HoldQueue)), ("mpls", ("mpls", Native.Interface.ATM.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.ATM.IpVrf)), ("vrf", ("vrf", Native.Interface.ATM.Vrf)), ("ip", ("cisco_ios_xe_interfaces_ip", Native.Interface.ATM.CiscoIOSXEInterfacesIp)), ("ipv6", ("ipv6", Native.Interface.ATM.Ipv6)), ("logging", ("logging", Native.Interface.ATM.Logging)), ("mdix", ("mdix", Native.Interface.ATM.Mdix)), ("mop", ("mop", Native.Interface.ATM.Mop)), ("interface_qos", ("interface_qos", Native.Interface.ATM.InterfaceQos)), ("source", ("source", Native.Interface.ATM.Source)), ("standby", ("standby", Native.Interface.ATM.Standby)), ("access-session", ("access_session", Native.Interface.ATM.AccessSession)), ("storm-control", ("storm_control", Native.Interface.ATM.StormControl)), ("trust", ("trust", Native.Interface.ATM.Trust)), ("priority-queue", ("priority_queue", Native.Interface.ATM.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.ATM.RcvQueue)), ("peer", ("peer", Native.Interface.ATM.Peer)), ("pm-path", ("pm_path", Native.Interface.ATM.PmPath)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.ATM.ServicePolicy)), ("Cisco-IOS-XE-atm:ip", ("cisco_ios_xe_atm_ip_", Native.Interface.ATM.CiscoIOSXEAtmIp)), ("Cisco-IOS-XE-atm:atm", ("atm", Native.Interface.ATM.Atm)), ("Cisco-IOS-XE-atm:cem", ("cem", Native.Interface.ATM.Cem)), ("Cisco-IOS-XE-atm:pvc", ("pvc", Native.Interface.ATM.Pvc))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('cisco_ios_xe_interfaces_load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.ServiceInsertion')])),
                    ('cisco_ios_xe_atm_load_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-atm:load-interval'), ['int'])),
                    ('cdp', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-atm:cdp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Cdp')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.cisco_ios_xe_interfaces_load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.cisco_ios_xe_atm_load_interval = None
                self.cdp = None

                self.switchport_conf = Native.Interface.ATM.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.ATM.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.ATM.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.ATM.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.ATM.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.ATM.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.ATM.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.ATM.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.ATM.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.ATM.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.ATM.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.ATM.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.ATM.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.ATM.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.ATM.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.ATM.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.ATM.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.ATM.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.ATM.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.ATM.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.cisco_ios_xe_interfaces_ip = Native.Interface.ATM.CiscoIOSXEInterfacesIp()
                self.cisco_ios_xe_interfaces_ip.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_ip"] = "ip"

                self.ipv6 = Native.Interface.ATM.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.ATM.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.ATM.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.ATM.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.ATM.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.ATM.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.ATM.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.ATM.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.ATM.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.ATM.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.ATM.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.ATM.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.ATM.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.ATM.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.service_policy = Native.Interface.ATM.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.cisco_ios_xe_atm_ip_ = Native.Interface.ATM.CiscoIOSXEAtmIp()
                self.cisco_ios_xe_atm_ip_.parent = self
                self._children_name_map["cisco_ios_xe_atm_ip_"] = "Cisco-IOS-XE-atm:ip"

                self.atm = Native.Interface.ATM.Atm()
                self.atm.parent = self
                self._children_name_map["atm"] = "Cisco-IOS-XE-atm:atm"

                self.hold_queue = YList(self)
                self.cem = YList(self)
                self.pvc = YList(self)
                self._segment_path = lambda: "ATM" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.ATM, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'cisco_ios_xe_interfaces_load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'cisco_ios_xe_atm_load_interval', 'cdp'], name, value)

            class Cdp(Enum):
                """
                Cdp (Enum Class)

                .. data:: enable = 0

                """

                enable = Enum.YLeaf(0, "enable")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.ATM.Backup.Delay)), ("interface", ("interface", Native.Interface.ATM.Backup.Interface_)), ("load", ("load", Native.Interface.ATM.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.ATM.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.ATM.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.ATM.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.ATM.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.ATM.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.ATM.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.ATM.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.ATM.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.ATM.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.ATM.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.ATM.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.ATM.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.ATM.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.ATM.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.ATM.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.ATM.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.ATM.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.ATM.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.ATM.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.ATM.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.ATM.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.ATM.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.ATM.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.ATM.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.ATM.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.ATM.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.ATM.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.ATM.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.ATM.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.ATM.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.ATM.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.ATM.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.ATM.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.ATM.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.ATM.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.ATM.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Vrf, [u'forwarding'], name, value)


            class CiscoIOSXEInterfacesIp(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.CiscoIOSXEInterfacesIp, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup)), ("arp", ("arp", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp)), ("vrf", ("vrf", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Vrf)), ("no-address", ("no_address", Native.Interface.ATM.CiscoIOSXEInterfacesIp.NoAddress)), ("address", ("address", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.ATM.CiscoIOSXEInterfacesIp.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.ATM.CiscoIOSXEInterfacesIp.HelloInterval)), ("authentication", ("authentication", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication)), ("hold-time", ("hold_time", Native.Interface.ATM.CiscoIOSXEInterfacesIp.HoldTime)), ("helper-address", ("helper_address", Native.Interface.ATM.CiscoIOSXEInterfacesIp.HelperAddress)), ("pim", ("pim", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Pim)), ("policy", ("policy", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Policy)), ("rip", ("rip", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.ATM.CiscoIOSXEInterfacesIp.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.ATM.CiscoIOSXEInterfacesIp.RouteCache)), ("router", ("router", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Router)), ("tcp", ("tcp", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.ATM.CiscoIOSXEInterfacesIp.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Dhcp)), ("summary-address", ("summary_address", Native.Interface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress)), ("verify", ("verify", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.ATM.CiscoIOSXEInterfacesIp.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.ATM.CiscoIOSXEInterfacesIp.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.ATM.CiscoIOSXEInterfacesIp.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.ATM.CiscoIOSXEInterfacesIp.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.ATM.CiscoIOSXEInterfacesIp.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In)), ("out", ("out", Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Secondary)), ("primary", ("primary", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source)), ("unicast", ("unicast", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.ATM.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.ATM.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.ATM.Ipv6.Dhcp)), ("address", ("address", Native.Interface.ATM.Ipv6.Address)), ("nd", ("nd", Native.Interface.ATM.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.ATM.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.ATM.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.ATM.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.ATM.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.ATM.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.ATM.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.ATM.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.ATM.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.ATM.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.ATM.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.ATM.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.ATM.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.ATM.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.ATM.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.ATM.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.ATM.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.ATM.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.ATM.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.ATM.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.ATM.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.ATM.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.ATM.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.ATM.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.ATM.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.ATM.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.ATM.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.ATM.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.ATM.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.ATM.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.ATM.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.ATM.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.ATM.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.ATM.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.ATM.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.ATM.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.ATM.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.ATM.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.ATM.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATM.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.ATM.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.ATM.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.ATM.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.ATM.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.ATM.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.ATM.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.ATM.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.ATM.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.ATM.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.ATM.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.ATM.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.ATM.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.ATM.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.ATM.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.ATM.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.ATM.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.ATM.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.ATM.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.ATM.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.ATM.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.ATM.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.ATM.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.ATM.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.ATM.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.ATM.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.ATM.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.ATM.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.ATM.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.ATM.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.ATM.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.ATM.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.ATM.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.ATM.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.ATM.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.ATM.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.ATM.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.ATM.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.ATM.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.ATM.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.ATM.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.ATM.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.ATM.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.ATM.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.ATM.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.ATM.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.ATM.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.ATM.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.ATM.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.ATM.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.ATM.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.ATM.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATM.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.ATM.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.ATM.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATM.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.ATM.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.ATM.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATM.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.ATM.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.ATM.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATM.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATM.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATM.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATM.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATM.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.PmPath, [u'name', u'interface_id'], name, value)


            class ServicePolicy(Entity):
                """
                
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.ATM.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.input = None
                    self.output = None
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.ServicePolicy, ['input', 'output'], name, value)


            class CiscoIOSXEAtmIp(Entity):
                """
                IP address
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: split_horizon
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.ATM.CiscoIOSXEAtmIp, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('split_horizon', (YLeaf(YType.empty, 'split-horizon'), ['Empty'])),
                    ])
                    self.address = None
                    self.split_horizon = None
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.CiscoIOSXEAtmIp, ['address', 'split_horizon'], name, value)


            class Atm(Entity):
                """
                ATM
                
                .. attribute:: bandwidth
                
                	ATM bandwith
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Bandwidth>`
                
                .. attribute:: enable_ilmi_trap
                
                	Enable\-ilmi\-trap
                	**type**\: bool
                
                .. attribute:: ilmi_keepalive
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: route_bridged
                
                	
                	**type**\:  :py:class:`RouteBridged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.RouteBridged>`
                
                .. attribute:: pvp
                
                	PVP
                	**type**\: list of  		 :py:class:`Pvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Pvp>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.ATM.Atm, self).__init__()

                    self.yang_name = "atm"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("pvp", ("pvp", Native.Interface.ATM.Atm.Pvp))])
                    self._leafs = OrderedDict([
                        ('bandwidth', (YLeaf(YType.enumeration, 'bandwidth'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Atm.Bandwidth')])),
                        ('enable_ilmi_trap', (YLeaf(YType.boolean, 'enable-ilmi-trap'), ['bool'])),
                        ('ilmi_keepalive', (YLeaf(YType.empty, 'ilmi-keepalive'), ['Empty'])),
                        ('route_bridged', (YLeaf(YType.enumeration, 'route-bridged'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Atm.RouteBridged')])),
                    ])
                    self.bandwidth = None
                    self.enable_ilmi_trap = None
                    self.ilmi_keepalive = None
                    self.route_bridged = None

                    self.pvp = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:atm"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Atm, ['bandwidth', 'enable_ilmi_trap', 'ilmi_keepalive', 'route_bridged'], name, value)

                class Bandwidth(Enum):
                    """
                    Bandwidth (Enum Class)

                    ATM bandwith

                    .. data:: dynamic = 0

                    """

                    dynamic = Enum.YLeaf(0, "dynamic")


                class RouteBridged(Enum):
                    """
                    RouteBridged (Enum Class)

                    .. data:: ip = 0

                    .. data:: ipv6 = 1

                    """

                    ip = Enum.YLeaf(0, "ip")

                    ipv6 = Enum.YLeaf(1, "ipv6")



                class Pvp(Entity):
                    """
                    PVP
                    
                    .. attribute:: pvp_number  (key)
                    
                    	PVP number
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: l2transport
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Pvp.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Pvp.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATM.Atm.Pvp, self).__init__()

                        self.yang_name = "pvp"
                        self.yang_parent_name = "atm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['pvp_number']
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATM.Atm.Pvp.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATM.Atm.Pvp.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('pvp_number', (YLeaf(YType.uint16, 'pvp-number'), ['int'])),
                            ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                        ])
                        self.pvp_number = None
                        self.l2transport = None

                        self.xconnect = Native.Interface.ATM.Atm.Pvp.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"

                        self.xconnect_pw_class = Native.Interface.ATM.Atm.Pvp.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                        self._segment_path = lambda: "pvp" + "[pvp-number='" + str(self.pvp_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Atm.Pvp, ['pvp_number', 'l2transport'], name, value)


                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Pvp.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Pvp.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Pvp.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATM.Atm.Pvp.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "pvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATM.Atm.Pvp.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Atm.Pvp.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Atm.Pvp.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.ATM.Atm.Pvp.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Atm.Pvp.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Pvp.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Pvp.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATM.Atm.Pvp.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATM.Atm.Pvp.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATM.Atm.Pvp.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.ATM.Atm.Pvp.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.ATM.Atm.Pvp.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Atm.Pvp.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATM.Atm.Pvp.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATM.Atm.Pvp.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATM.Atm.Pvp.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATM.Atm.Pvp.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATM.Atm.Pvp.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "pvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Atm.Pvp.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Cem(Entity):
                """
                CEM
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: xconnect
                
                	
                	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cem.Xconnect>`
                
                .. attribute:: xconnect_pw_class
                
                	
                	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cem.XconnectPwClass>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.ATM.Cem, self).__init__()

                    self.yang_name = "cem"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATM.Cem.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATM.Cem.XconnectPwClass))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                    ])
                    self.number = None

                    self.xconnect = Native.Interface.ATM.Cem.Xconnect()
                    self.xconnect.parent = self
                    self._children_name_map["xconnect"] = "xconnect"

                    self.xconnect_pw_class = Native.Interface.ATM.Cem.XconnectPwClass()
                    self.xconnect_pw_class.parent = self
                    self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:cem" + "[number='" + str(self.number) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Cem, ['number'], name, value)


                class Xconnect(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vcid
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: encapsulation
                    
                    	Data encapsulation method
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cem.Xconnect.Encapsulation>`
                    
                    .. attribute:: manual
                    
                    	Manually configure L2TP session parameters
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pw_class
                    
                    	Optional pseudowire\-class to use for advanced configuration
                    	**type**\: str
                    
                    .. attribute:: sequencing
                    
                    	Configure sequencing options for xconnect
                    	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cem.Xconnect.Sequencing>`
                    
                    .. attribute:: backup
                    
                    	Xconnect backup configuration commands
                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cem.Xconnect.Backup>`
                    
                    .. attribute:: mtu
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATM.Cem.Xconnect, self).__init__()

                        self.yang_name = "xconnect"
                        self.yang_parent_name = "cem"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATM.Cem.Xconnect.Backup))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Cem.Xconnect.Encapsulation')])),
                            ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                            ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Cem.Xconnect.Sequencing')])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                        ])
                        self.address = None
                        self.vcid = None
                        self.encapsulation = None
                        self.manual = None
                        self.pw_class = None
                        self.sequencing = None
                        self.mtu = None

                        self.backup = Native.Interface.ATM.Cem.Xconnect.Backup()
                        self.backup.parent = self
                        self._children_name_map["backup"] = "backup"
                        self._segment_path = lambda: "xconnect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Cem.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Data encapsulation method

                        .. data:: mpls = 0

                        .. data:: l2tpv3 = 1

                        """

                        mpls = Enum.YLeaf(0, "mpls")

                        l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                    class Sequencing(Enum):
                        """
                        Sequencing (Enum Class)

                        Configure sequencing options for xconnect

                        .. data:: both = 0

                        .. data:: receive = 1

                        .. data:: transmit = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        receive = Enum.YLeaf(1, "receive")

                        transmit = Enum.YLeaf(2, "transmit")



                    class Backup(Entity):
                        """
                        Xconnect backup configuration commands
                        
                        .. attribute:: peer
                        
                        	Backup pseudowire
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cem.Xconnect.Backup.Peer>`
                        
                        .. attribute:: delay
                        
                        	backup delay time
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cem.Xconnect.Backup.Delay>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATM.Cem.Xconnect.Backup, self).__init__()

                            self.yang_name = "backup"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATM.Cem.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATM.Cem.Xconnect.Backup.Delay))])
                            self._leafs = OrderedDict()

                            self.peer = Native.Interface.ATM.Cem.Xconnect.Backup.Peer()
                            self.peer.parent = self
                            self._children_name_map["peer"] = "peer"

                            self.delay = Native.Interface.ATM.Cem.Xconnect.Backup.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "backup"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Cem.Xconnect.Backup, [], name, value)


                        class Peer(Entity):
                            """
                            Backup pseudowire
                            
                            .. attribute:: peer_router_ip_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: priority
                            
                            	Optional priority to use for backup pseudowire
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATM.Cem.Xconnect.Backup.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.peer_router_ip_addr = None
                                self.vcid = None
                                self.pw_class = None
                                self.priority = None
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Cem.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                        class Delay(Entity):
                            """
                            backup delay time
                            
                            .. attribute:: min
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATM.Cem.Xconnect.Backup.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Cem.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                class XconnectPwClass(Entity):
                    """
                    
                    
                    .. attribute:: xconnect
                    
                    	Xconnect commands
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cem.XconnectPwClass.Xconnect>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATM.Cem.XconnectPwClass, self).__init__()

                        self.yang_name = "xconnect-pw-class"
                        self.yang_parent_name = "cem"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATM.Cem.XconnectPwClass.Xconnect))])
                        self._leafs = OrderedDict()

                        self.xconnect = Native.Interface.ATM.Cem.XconnectPwClass.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"
                        self._segment_path = lambda: "xconnect-pw-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Cem.XconnectPwClass, [], name, value)


                    class Xconnect(Entity):
                        """
                        Xconnect commands
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_class
                        
                        	Pseudowire\-class to use for encapsulation and protocol configuration
                        	**type**\: str
                        
                        .. attribute:: udp
                        
                        	UDP
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cem.XconnectPwClass.Xconnect.Udp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATM.Cem.XconnectPwClass.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "xconnect-pw-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATM.Cem.XconnectPwClass.Xconnect.Udp))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.pw_class = None

                            self.udp = Native.Interface.ATM.Cem.XconnectPwClass.Xconnect.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Cem.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                        class Udp(Entity):
                            """
                            UDP
                            
                            .. attribute:: port
                            
                            	UDP ports
                            	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Cem.XconnectPwClass.Xconnect.Udp.Port>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATM.Cem.XconnectPwClass.Xconnect.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATM.Cem.XconnectPwClass.Xconnect.Udp.Port))])
                                self._leafs = OrderedDict()

                                self.port = Native.Interface.ATM.Cem.XconnectPwClass.Xconnect.Udp.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Cem.XconnectPwClass.Xconnect.Udp, [], name, value)


                            class Port(Entity):
                                """
                                UDP ports
                                
                                .. attribute:: local
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATM.Cem.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                    self.yang_name = "port"
                                    self.yang_parent_name = "udp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                    ])
                                    self.local = None
                                    self.remote = None
                                    self._segment_path = lambda: "port"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATM.Cem.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Pvc(Entity):
                """
                PVC
                
                .. attribute:: local_vpi_vci  (key)
                
                	Vpi and vci
                	**type**\: str
                
                .. attribute:: remote_vpi_vci
                
                	Vpi and vci
                	**type**\: str
                
                .. attribute:: l2transport
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ubr
                
                	UBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ubrplus
                
                	
                	**type**\:  :py:class:`Ubrplus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Ubrplus>`
                
                .. attribute:: cbr
                
                	CBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr
                
                	VBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr_rt
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr_nrt
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: oam_pvc
                
                	
                	**type**\:  :py:class:`OamPvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.OamPvc>`
                
                	**presence node**\: True
                
                .. attribute:: service_policy
                
                	
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.ServicePolicy>`
                
                .. attribute:: encapsulation
                
                	
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Encapsulation>`
                
                .. attribute:: xconnect
                
                	
                	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Xconnect>`
                
                .. attribute:: xconnect_pw_class
                
                	
                	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.XconnectPwClass>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.ATM.Pvc, self).__init__()

                    self.yang_name = "pvc"
                    self.yang_parent_name = "ATM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['local_vpi_vci']
                    self._child_classes = OrderedDict([("ubrplus", ("ubrplus", Native.Interface.ATM.Pvc.Ubrplus)), ("oam-pvc", ("oam_pvc", Native.Interface.ATM.Pvc.OamPvc)), ("service-policy", ("service_policy", Native.Interface.ATM.Pvc.ServicePolicy)), ("encapsulation", ("encapsulation", Native.Interface.ATM.Pvc.Encapsulation)), ("xconnect", ("xconnect", Native.Interface.ATM.Pvc.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATM.Pvc.XconnectPwClass))])
                    self._leafs = OrderedDict([
                        ('local_vpi_vci', (YLeaf(YType.str, 'local-vpi-vci'), ['str'])),
                        ('remote_vpi_vci', (YLeaf(YType.str, 'remote-vpi-vci'), ['str'])),
                        ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                        ('ubr', (YLeaf(YType.uint32, 'ubr'), ['int'])),
                        ('cbr', (YLeaf(YType.uint32, 'cbr'), ['int'])),
                        ('vbr', (YLeaf(YType.uint32, 'vbr'), ['int'])),
                        ('vbr_rt', (YLeaf(YType.uint32, 'vbr-rt'), ['int'])),
                        ('vbr_nrt', (YLeaf(YType.uint32, 'vbr-nrt'), ['int'])),
                    ])
                    self.local_vpi_vci = None
                    self.remote_vpi_vci = None
                    self.l2transport = None
                    self.ubr = None
                    self.cbr = None
                    self.vbr = None
                    self.vbr_rt = None
                    self.vbr_nrt = None

                    self.ubrplus = Native.Interface.ATM.Pvc.Ubrplus()
                    self.ubrplus.parent = self
                    self._children_name_map["ubrplus"] = "ubrplus"

                    self.oam_pvc = None
                    self._children_name_map["oam_pvc"] = "oam-pvc"

                    self.service_policy = Native.Interface.ATM.Pvc.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"

                    self.encapsulation = Native.Interface.ATM.Pvc.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"

                    self.xconnect = Native.Interface.ATM.Pvc.Xconnect()
                    self.xconnect.parent = self
                    self._children_name_map["xconnect"] = "xconnect"

                    self.xconnect_pw_class = Native.Interface.ATM.Pvc.XconnectPwClass()
                    self.xconnect_pw_class.parent = self
                    self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:pvc" + "[local-vpi-vci='" + str(self.local_vpi_vci) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATM.Pvc, ['local_vpi_vci', 'remote_vpi_vci', 'l2transport', 'ubr', 'cbr', 'vbr', 'vbr_rt', 'vbr_nrt'], name, value)


                class Ubrplus(Entity):
                    """
                    
                    
                    .. attribute:: pcr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mcr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATM.Pvc.Ubrplus, self).__init__()

                        self.yang_name = "ubrplus"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pcr', (YLeaf(YType.uint32, 'PCR'), ['int'])),
                            ('mcr', (YLeaf(YType.uint32, 'MCR'), ['int'])),
                        ])
                        self.pcr = None
                        self.mcr = None
                        self._segment_path = lambda: "ubrplus"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Pvc.Ubrplus, ['pcr', 'mcr'], name, value)


                class OamPvc(Entity):
                    """
                    
                    
                    .. attribute:: loopback_frequency
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..600
                    
                    .. attribute:: manage
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATM.Pvc.OamPvc, self).__init__()

                        self.yang_name = "oam-pvc"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('loopback_frequency', (YLeaf(YType.uint32, 'loopback-frequency'), ['int'])),
                            ('manage', (YLeaf(YType.empty, 'manage'), ['Empty'])),
                        ])
                        self.loopback_frequency = None
                        self.manage = None
                        self._segment_path = lambda: "oam-pvc"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Pvc.OamPvc, ['loopback_frequency', 'manage'], name, value)


                class ServicePolicy(Entity):
                    """
                    
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATM.Pvc.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Pvc.ServicePolicy, ['input', 'output'], name, value)


                class Encapsulation(Entity):
                    """
                    
                    
                    .. attribute:: aal5autoppp
                    
                    	
                    	**type**\:  :py:class:`Aal5autoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Encapsulation.Aal5autoppp>`
                    
                    .. attribute:: aal5ciscoppp
                    
                    	
                    	**type**\:  :py:class:`Aal5ciscoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Encapsulation.Aal5ciscoppp>`
                    
                    .. attribute:: aal5mux
                    
                    	
                    	**type**\:  :py:class:`Aal5mux <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Encapsulation.Aal5mux>`
                    
                    .. attribute:: aal5nlpid
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: aal5snap
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATM.Pvc.Encapsulation, self).__init__()

                        self.yang_name = "encapsulation"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aal5autoppp", ("aal5autoppp", Native.Interface.ATM.Pvc.Encapsulation.Aal5autoppp)), ("aal5ciscoppp", ("aal5ciscoppp", Native.Interface.ATM.Pvc.Encapsulation.Aal5ciscoppp)), ("aal5mux", ("aal5mux", Native.Interface.ATM.Pvc.Encapsulation.Aal5mux))])
                        self._leafs = OrderedDict([
                            ('aal5nlpid', (YLeaf(YType.empty, 'aal5nlpid'), ['Empty'])),
                            ('aal5snap', (YLeaf(YType.empty, 'aal5snap'), ['Empty'])),
                        ])
                        self.aal5nlpid = None
                        self.aal5snap = None

                        self.aal5autoppp = Native.Interface.ATM.Pvc.Encapsulation.Aal5autoppp()
                        self.aal5autoppp.parent = self
                        self._children_name_map["aal5autoppp"] = "aal5autoppp"

                        self.aal5ciscoppp = Native.Interface.ATM.Pvc.Encapsulation.Aal5ciscoppp()
                        self.aal5ciscoppp.parent = self
                        self._children_name_map["aal5ciscoppp"] = "aal5ciscoppp"

                        self.aal5mux = Native.Interface.ATM.Pvc.Encapsulation.Aal5mux()
                        self.aal5mux.parent = self
                        self._children_name_map["aal5mux"] = "aal5mux"
                        self._segment_path = lambda: "encapsulation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Pvc.Encapsulation, ['aal5nlpid', 'aal5snap'], name, value)


                    class Aal5autoppp(Entity):
                        """
                        
                        
                        .. attribute:: virtual_template
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATM.Pvc.Encapsulation.Aal5autoppp, self).__init__()

                            self.yang_name = "aal5autoppp"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                            ])
                            self.virtual_template = None
                            self._segment_path = lambda: "aal5autoppp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Pvc.Encapsulation.Aal5autoppp, ['virtual_template'], name, value)


                    class Aal5ciscoppp(Entity):
                        """
                        
                        
                        .. attribute:: virtual_template
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATM.Pvc.Encapsulation.Aal5ciscoppp, self).__init__()

                            self.yang_name = "aal5ciscoppp"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                            ])
                            self.virtual_template = None
                            self._segment_path = lambda: "aal5ciscoppp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Pvc.Encapsulation.Aal5ciscoppp, ['virtual_template'], name, value)


                    class Aal5mux(Entity):
                        """
                        
                        
                        .. attribute:: ppp
                        
                        	
                        	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Encapsulation.Aal5mux.Ppp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATM.Pvc.Encapsulation.Aal5mux, self).__init__()

                            self.yang_name = "aal5mux"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ppp", ("ppp", Native.Interface.ATM.Pvc.Encapsulation.Aal5mux.Ppp))])
                            self._leafs = OrderedDict()

                            self.ppp = Native.Interface.ATM.Pvc.Encapsulation.Aal5mux.Ppp()
                            self.ppp.parent = self
                            self._children_name_map["ppp"] = "ppp"
                            self._segment_path = lambda: "aal5mux"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Pvc.Encapsulation.Aal5mux, [], name, value)


                        class Ppp(Entity):
                            """
                            
                            
                            .. attribute:: virtual_template
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dialer
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATM.Pvc.Encapsulation.Aal5mux.Ppp, self).__init__()

                                self.yang_name = "ppp"
                                self.yang_parent_name = "aal5mux"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                                    ('dialer', (YLeaf(YType.empty, 'dialer'), ['Empty'])),
                                ])
                                self.virtual_template = None
                                self.dialer = None
                                self._segment_path = lambda: "ppp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Pvc.Encapsulation.Aal5mux.Ppp, ['virtual_template', 'dialer'], name, value)


                class Xconnect(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vcid
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: encapsulation
                    
                    	Data encapsulation method
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Xconnect.Encapsulation>`
                    
                    .. attribute:: manual
                    
                    	Manually configure L2TP session parameters
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pw_class
                    
                    	Optional pseudowire\-class to use for advanced configuration
                    	**type**\: str
                    
                    .. attribute:: sequencing
                    
                    	Configure sequencing options for xconnect
                    	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Xconnect.Sequencing>`
                    
                    .. attribute:: backup
                    
                    	Xconnect backup configuration commands
                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Xconnect.Backup>`
                    
                    .. attribute:: mtu
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATM.Pvc.Xconnect, self).__init__()

                        self.yang_name = "xconnect"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATM.Pvc.Xconnect.Backup))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Pvc.Xconnect.Encapsulation')])),
                            ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                            ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATM.Pvc.Xconnect.Sequencing')])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                        ])
                        self.address = None
                        self.vcid = None
                        self.encapsulation = None
                        self.manual = None
                        self.pw_class = None
                        self.sequencing = None
                        self.mtu = None

                        self.backup = Native.Interface.ATM.Pvc.Xconnect.Backup()
                        self.backup.parent = self
                        self._children_name_map["backup"] = "backup"
                        self._segment_path = lambda: "xconnect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Pvc.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Data encapsulation method

                        .. data:: mpls = 0

                        .. data:: l2tpv3 = 1

                        """

                        mpls = Enum.YLeaf(0, "mpls")

                        l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                    class Sequencing(Enum):
                        """
                        Sequencing (Enum Class)

                        Configure sequencing options for xconnect

                        .. data:: both = 0

                        .. data:: receive = 1

                        .. data:: transmit = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        receive = Enum.YLeaf(1, "receive")

                        transmit = Enum.YLeaf(2, "transmit")



                    class Backup(Entity):
                        """
                        Xconnect backup configuration commands
                        
                        .. attribute:: peer
                        
                        	Backup pseudowire
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Xconnect.Backup.Peer>`
                        
                        .. attribute:: delay
                        
                        	backup delay time
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.Xconnect.Backup.Delay>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATM.Pvc.Xconnect.Backup, self).__init__()

                            self.yang_name = "backup"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATM.Pvc.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATM.Pvc.Xconnect.Backup.Delay))])
                            self._leafs = OrderedDict()

                            self.peer = Native.Interface.ATM.Pvc.Xconnect.Backup.Peer()
                            self.peer.parent = self
                            self._children_name_map["peer"] = "peer"

                            self.delay = Native.Interface.ATM.Pvc.Xconnect.Backup.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "backup"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Pvc.Xconnect.Backup, [], name, value)


                        class Peer(Entity):
                            """
                            Backup pseudowire
                            
                            .. attribute:: peer_router_ip_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: priority
                            
                            	Optional priority to use for backup pseudowire
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATM.Pvc.Xconnect.Backup.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.peer_router_ip_addr = None
                                self.vcid = None
                                self.pw_class = None
                                self.priority = None
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Pvc.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                        class Delay(Entity):
                            """
                            backup delay time
                            
                            .. attribute:: min
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATM.Pvc.Xconnect.Backup.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Pvc.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                class XconnectPwClass(Entity):
                    """
                    
                    
                    .. attribute:: xconnect
                    
                    	Xconnect commands
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATM.Pvc.XconnectPwClass, self).__init__()

                        self.yang_name = "xconnect-pw-class"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect))])
                        self._leafs = OrderedDict()

                        self.xconnect = Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"
                        self._segment_path = lambda: "xconnect-pw-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATM.Pvc.XconnectPwClass, [], name, value)


                    class Xconnect(Entity):
                        """
                        Xconnect commands
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_class
                        
                        	Pseudowire\-class to use for encapsulation and protocol configuration
                        	**type**\: str
                        
                        .. attribute:: udp
                        
                        	UDP
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect.Udp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "xconnect-pw-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect.Udp))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.pw_class = None

                            self.udp = Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                        class Udp(Entity):
                            """
                            UDP
                            
                            .. attribute:: port
                            
                            	UDP ports
                            	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect.Udp.Port>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect.Udp.Port))])
                                self._leafs = OrderedDict()

                                self.port = Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect.Udp.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect.Udp, [], name, value)


                            class Port(Entity):
                                """
                                UDP ports
                                
                                .. attribute:: local
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                    self.yang_name = "port"
                                    self.yang_parent_name = "udp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                    ])
                                    self.local = None
                                    self.remote = None
                                    self._segment_path = lambda: "port"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATM.Pvc.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


        class ATMSubinterface(Entity):
            """
            
            
            .. attribute:: atm
            
            	
            	**type**\: list of  		 :py:class:`ATM <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM>`
            
            .. attribute:: service_policy
            
            	
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ServicePolicy>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.ATMSubinterface, self).__init__()

                self.yang_name = "ATM-subinterface"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ATM", ("atm", Native.Interface.ATMSubinterface.ATM)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.ATMSubinterface.ServicePolicy))])
                self._leafs = OrderedDict()

                self.service_policy = Native.Interface.ATMSubinterface.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.atm = YList(self)
                self._segment_path = lambda: "ATM-subinterface"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.ATMSubinterface, [], name, value)


            class ATM(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: description
                
                	Interface specific description
                	**type**\: str
                
                	**length:** 0..240
                
                .. attribute:: switchport_conf
                
                	
                	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.SwitchportConf>`
                
                .. attribute:: switchport
                
                	Set switching mode characteristics
                	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Switchport>`
                
                .. attribute:: stackwise_virtual
                
                	Configure stackwise\-virtual link values
                	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StackwiseVirtual>`
                
                .. attribute:: mac_address
                
                	Manually set interface MAC address
                	**type**\: str
                
                .. attribute:: shutdown
                
                	Shutdown the selected interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: arp
                
                	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Arp>`
                
                .. attribute:: backup
                
                	Modify backup parameters
                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Backup>`
                
                .. attribute:: cemoudp
                
                	cemoudp
                	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cemoudp>`
                
                .. attribute:: cws_tunnel
                
                	Configure Cloud Web Security Tunnel
                	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CwsTunnel>`
                
                .. attribute:: l2protocol_tunnel
                
                	Tunnel Layer2 protocols
                	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.L2protocolTunnel>`
                
                	**presence node**\: True
                
                .. attribute:: encapsulation
                
                	Set encapsulation type for an interface
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Encapsulation>`
                
                .. attribute:: fair_queue_conf
                
                	
                	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.FairQueueConf>`
                
                .. attribute:: fair_queue
                
                	Enable Fair Queuing on an Interface
                	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.FairQueue>`
                
                .. attribute:: flowcontrol
                
                	Configure flow operation
                	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Flowcontrol>`
                
                .. attribute:: isis
                
                	IS\-IS commands
                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Isis>`
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\: bool
                
                .. attribute:: keepalive_settings
                
                	
                	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.KeepaliveSettings>`
                
                .. attribute:: bfd
                
                	BFD interface configuration commands
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Bfd>`
                
                .. attribute:: bandwidth
                
                	Set bandwidth informational parameter
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Bandwidth>`
                
                .. attribute:: dampening
                
                	Enable event dampening
                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Dampening>`
                
                .. attribute:: if_state
                
                	
                	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.IfState>`
                
                .. attribute:: delay
                
                	Specify interface throughput delay
                	**type**\: int
                
                	**range:** 1..16777215
                
                .. attribute:: domain
                
                	Specify a domain
                	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Domain>`
                
                .. attribute:: hold_queue
                
                	Set hold queue depth
                	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.HoldQueue>`
                
                .. attribute:: mpls
                
                	
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Mpls>`
                
                .. attribute:: ip_vrf
                
                	
                	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.IpVrf>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Vrf>`
                
                .. attribute:: cisco_ios_xe_interfaces_ip
                
                	Interface Internet Protocol config commands
                	**type**\:  :py:class:`CiscoIOSXEInterfacesIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp>`
                
                .. attribute:: ipv6
                
                	IPv6 interface subcommands
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6>`
                
                .. attribute:: cisco_ios_xe_interfaces_load_interval
                
                	Specify interval for load calculation for an interface
                	**type**\: int
                
                	**range:** 0..600
                
                .. attribute:: logging
                
                	Configure logging for interface
                	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Logging>`
                
                .. attribute:: mdix
                
                	Set Media Dependent Interface with Crossover
                	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Mdix>`
                
                .. attribute:: mop
                
                	
                	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Mop>`
                
                .. attribute:: max_reserved_bandwidth
                
                	Maximum Reservable Bandwidth on an Interface
                	**type**\: int
                
                	**range:** 1..100
                
                .. attribute:: mtu
                
                	Set the interface Maximum Transmission Unit (MTU)
                	**type**\: int
                
                	**range:** 64..18000
                
                .. attribute:: interface_qos
                
                	
                	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.InterfaceQos>`
                
                .. attribute:: service_insertion
                
                	Service\-insertion AppNav Controller
                	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.ServiceInsertion>`
                
                .. attribute:: source
                
                	Get config from another source
                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Source>`
                
                .. attribute:: standby
                
                	HSRP interface configuration commands
                	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby>`
                
                .. attribute:: access_session
                
                	Access Session specific Interface Configuration Commands
                	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.AccessSession>`
                
                .. attribute:: storm_control
                
                	storm configuration
                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl>`
                
                .. attribute:: trust
                
                	Set trust value for the interface
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Trust>`
                
                .. attribute:: priority_queue
                
                	Configure priority scheduling
                	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.PriorityQueue>`
                
                .. attribute:: rcv_queue
                
                	Configure receive queue(s)
                	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.RcvQueue>`
                
                .. attribute:: peer
                
                	Peer parameters for point to point interfaces
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Peer>`
                
                .. attribute:: pm_path
                
                	Global pm\-path configuration
                	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.PmPath>`
                
                .. attribute:: cisco_ios_xe_atm_ip_
                
                	IP address
                	**type**\:  :py:class:`CiscoIOSXEAtmIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEAtmIp>`
                
                .. attribute:: atm
                
                	ATM
                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm>`
                
                .. attribute:: cisco_ios_xe_atm_load_interval
                
                	Load interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: cdp
                
                	
                	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cdp>`
                
                .. attribute:: cem
                
                	CEM
                	**type**\: list of  		 :py:class:`Cem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cem>`
                
                .. attribute:: pvc
                
                	PVC
                	**type**\: list of  		 :py:class:`Pvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATMSubinterface.ATM, self).__init__()

                    self.yang_name = "ATM"
                    self.yang_parent_name = "ATM-subinterface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.ATMSubinterface.ATM.SwitchportConf)), ("switchport", ("switchport", Native.Interface.ATMSubinterface.ATM.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.ATMSubinterface.ATM.StackwiseVirtual)), ("arp", ("arp", Native.Interface.ATMSubinterface.ATM.Arp)), ("backup", ("backup", Native.Interface.ATMSubinterface.ATM.Backup)), ("cemoudp", ("cemoudp", Native.Interface.ATMSubinterface.ATM.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.ATMSubinterface.ATM.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.ATMSubinterface.ATM.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.ATMSubinterface.ATM.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.ATMSubinterface.ATM.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.ATMSubinterface.ATM.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.ATMSubinterface.ATM.Flowcontrol)), ("isis", ("isis", Native.Interface.ATMSubinterface.ATM.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.ATMSubinterface.ATM.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.ATMSubinterface.ATM.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.ATMSubinterface.ATM.Bandwidth)), ("dampening", ("dampening", Native.Interface.ATMSubinterface.ATM.Dampening)), ("domain", ("domain", Native.Interface.ATMSubinterface.ATM.Domain)), ("hold-queue", ("hold_queue", Native.Interface.ATMSubinterface.ATM.HoldQueue)), ("mpls", ("mpls", Native.Interface.ATMSubinterface.ATM.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.ATMSubinterface.ATM.IpVrf)), ("vrf", ("vrf", Native.Interface.ATMSubinterface.ATM.Vrf)), ("ip", ("cisco_ios_xe_interfaces_ip", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp)), ("ipv6", ("ipv6", Native.Interface.ATMSubinterface.ATM.Ipv6)), ("logging", ("logging", Native.Interface.ATMSubinterface.ATM.Logging)), ("mdix", ("mdix", Native.Interface.ATMSubinterface.ATM.Mdix)), ("mop", ("mop", Native.Interface.ATMSubinterface.ATM.Mop)), ("interface_qos", ("interface_qos", Native.Interface.ATMSubinterface.ATM.InterfaceQos)), ("source", ("source", Native.Interface.ATMSubinterface.ATM.Source)), ("standby", ("standby", Native.Interface.ATMSubinterface.ATM.Standby)), ("access-session", ("access_session", Native.Interface.ATMSubinterface.ATM.AccessSession)), ("storm-control", ("storm_control", Native.Interface.ATMSubinterface.ATM.StormControl)), ("trust", ("trust", Native.Interface.ATMSubinterface.ATM.Trust)), ("priority-queue", ("priority_queue", Native.Interface.ATMSubinterface.ATM.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.ATMSubinterface.ATM.RcvQueue)), ("peer", ("peer", Native.Interface.ATMSubinterface.ATM.Peer)), ("pm-path", ("pm_path", Native.Interface.ATMSubinterface.ATM.PmPath)), ("Cisco-IOS-XE-atm:ip", ("cisco_ios_xe_atm_ip_", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEAtmIp)), ("Cisco-IOS-XE-atm:atm", ("atm", Native.Interface.ATMSubinterface.ATM.Atm)), ("Cisco-IOS-XE-atm:cem", ("cem", Native.Interface.ATMSubinterface.ATM.Cem)), ("Cisco-IOS-XE-atm:pvc", ("pvc", Native.Interface.ATMSubinterface.ATM.Pvc))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                        ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.IfState')])),
                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                        ('cisco_ios_xe_interfaces_load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                        ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.ServiceInsertion')])),
                        ('cisco_ios_xe_atm_load_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-atm:load-interval'), ['int'])),
                        ('cdp', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-atm:cdp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Cdp')])),
                    ])
                    self.name = None
                    self.description = None
                    self.mac_address = None
                    self.shutdown = None
                    self.keepalive = None
                    self.if_state = None
                    self.delay = None
                    self.cisco_ios_xe_interfaces_load_interval = None
                    self.max_reserved_bandwidth = None
                    self.mtu = None
                    self.service_insertion = None
                    self.cisco_ios_xe_atm_load_interval = None
                    self.cdp = None

                    self.switchport_conf = Native.Interface.ATMSubinterface.ATM.SwitchportConf()
                    self.switchport_conf.parent = self
                    self._children_name_map["switchport_conf"] = "switchport-conf"

                    self.switchport = Native.Interface.ATMSubinterface.ATM.Switchport()
                    self.switchport.parent = self
                    self._children_name_map["switchport"] = "switchport"

                    self.stackwise_virtual = Native.Interface.ATMSubinterface.ATM.StackwiseVirtual()
                    self.stackwise_virtual.parent = self
                    self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                    self.arp = Native.Interface.ATMSubinterface.ATM.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.backup = Native.Interface.ATMSubinterface.ATM.Backup()
                    self.backup.parent = self
                    self._children_name_map["backup"] = "backup"

                    self.cemoudp = Native.Interface.ATMSubinterface.ATM.Cemoudp()
                    self.cemoudp.parent = self
                    self._children_name_map["cemoudp"] = "cemoudp"

                    self.cws_tunnel = Native.Interface.ATMSubinterface.ATM.CwsTunnel()
                    self.cws_tunnel.parent = self
                    self._children_name_map["cws_tunnel"] = "cws-tunnel"

                    self.l2protocol_tunnel = None
                    self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                    self.encapsulation = Native.Interface.ATMSubinterface.ATM.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"

                    self.fair_queue_conf = Native.Interface.ATMSubinterface.ATM.FairQueueConf()
                    self.fair_queue_conf.parent = self
                    self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                    self.fair_queue = Native.Interface.ATMSubinterface.ATM.FairQueue()
                    self.fair_queue.parent = self
                    self._children_name_map["fair_queue"] = "fair-queue"

                    self.flowcontrol = Native.Interface.ATMSubinterface.ATM.Flowcontrol()
                    self.flowcontrol.parent = self
                    self._children_name_map["flowcontrol"] = "flowcontrol"

                    self.isis = Native.Interface.ATMSubinterface.ATM.Isis()
                    self.isis.parent = self
                    self._children_name_map["isis"] = "isis"

                    self.keepalive_settings = Native.Interface.ATMSubinterface.ATM.KeepaliveSettings()
                    self.keepalive_settings.parent = self
                    self._children_name_map["keepalive_settings"] = "keepalive-settings"

                    self.bfd = Native.Interface.ATMSubinterface.ATM.Bfd()
                    self.bfd.parent = self
                    self._children_name_map["bfd"] = "bfd"

                    self.bandwidth = Native.Interface.ATMSubinterface.ATM.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"

                    self.dampening = Native.Interface.ATMSubinterface.ATM.Dampening()
                    self.dampening.parent = self
                    self._children_name_map["dampening"] = "dampening"

                    self.domain = Native.Interface.ATMSubinterface.ATM.Domain()
                    self.domain.parent = self
                    self._children_name_map["domain"] = "domain"

                    self.mpls = Native.Interface.ATMSubinterface.ATM.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"

                    self.ip_vrf = Native.Interface.ATMSubinterface.ATM.IpVrf()
                    self.ip_vrf.parent = self
                    self._children_name_map["ip_vrf"] = "ip-vrf"

                    self.vrf = Native.Interface.ATMSubinterface.ATM.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.cisco_ios_xe_interfaces_ip = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp()
                    self.cisco_ios_xe_interfaces_ip.parent = self
                    self._children_name_map["cisco_ios_xe_interfaces_ip"] = "ip"

                    self.ipv6 = Native.Interface.ATMSubinterface.ATM.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.logging = Native.Interface.ATMSubinterface.ATM.Logging()
                    self.logging.parent = self
                    self._children_name_map["logging"] = "logging"

                    self.mdix = Native.Interface.ATMSubinterface.ATM.Mdix()
                    self.mdix.parent = self
                    self._children_name_map["mdix"] = "mdix"

                    self.mop = Native.Interface.ATMSubinterface.ATM.Mop()
                    self.mop.parent = self
                    self._children_name_map["mop"] = "mop"

                    self.interface_qos = Native.Interface.ATMSubinterface.ATM.InterfaceQos()
                    self.interface_qos.parent = self
                    self._children_name_map["interface_qos"] = "interface_qos"

                    self.source = Native.Interface.ATMSubinterface.ATM.Source()
                    self.source.parent = self
                    self._children_name_map["source"] = "source"

                    self.standby = Native.Interface.ATMSubinterface.ATM.Standby()
                    self.standby.parent = self
                    self._children_name_map["standby"] = "standby"

                    self.access_session = Native.Interface.ATMSubinterface.ATM.AccessSession()
                    self.access_session.parent = self
                    self._children_name_map["access_session"] = "access-session"

                    self.storm_control = Native.Interface.ATMSubinterface.ATM.StormControl()
                    self.storm_control.parent = self
                    self._children_name_map["storm_control"] = "storm-control"

                    self.trust = Native.Interface.ATMSubinterface.ATM.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"

                    self.priority_queue = Native.Interface.ATMSubinterface.ATM.PriorityQueue()
                    self.priority_queue.parent = self
                    self._children_name_map["priority_queue"] = "priority-queue"

                    self.rcv_queue = Native.Interface.ATMSubinterface.ATM.RcvQueue()
                    self.rcv_queue.parent = self
                    self._children_name_map["rcv_queue"] = "rcv-queue"

                    self.peer = Native.Interface.ATMSubinterface.ATM.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"

                    self.pm_path = Native.Interface.ATMSubinterface.ATM.PmPath()
                    self.pm_path.parent = self
                    self._children_name_map["pm_path"] = "pm-path"

                    self.cisco_ios_xe_atm_ip_ = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEAtmIp()
                    self.cisco_ios_xe_atm_ip_.parent = self
                    self._children_name_map["cisco_ios_xe_atm_ip_"] = "Cisco-IOS-XE-atm:ip"

                    self.atm = Native.Interface.ATMSubinterface.ATM.Atm()
                    self.atm.parent = self
                    self._children_name_map["atm"] = "Cisco-IOS-XE-atm:atm"

                    self.hold_queue = YList(self)
                    self.cem = YList(self)
                    self.pvc = YList(self)
                    self._segment_path = lambda: "ATM" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/ATM-subinterface/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'cisco_ios_xe_interfaces_load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'cisco_ios_xe_atm_load_interval', 'cdp'], name, value)

                class Cdp(Enum):
                    """
                    Cdp (Enum Class)

                    .. data:: enable = 0

                    """

                    enable = Enum.YLeaf(0, "enable")


                class IfState(Enum):
                    """
                    IfState (Enum Class)

                    .. data:: nhrp = 0

                    """

                    nhrp = Enum.YLeaf(0, "nhrp")


                class ServiceInsertion(Enum):
                    """
                    ServiceInsertion (Enum Class)

                    Service\-insertion AppNav Controller

                    .. data:: waas = 0

                    """

                    waas = Enum.YLeaf(0, "waas")



                class SwitchportConf(Entity):
                    """
                    
                    
                    .. attribute:: switchport
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.SwitchportConf, self).__init__()

                        self.yang_name = "switchport-conf"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                        ])
                        self.switchport = None
                        self._segment_path = lambda: "switchport-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.SwitchportConf, [u'switchport'], name, value)


                class Switchport(Entity):
                    """
                    Set switching mode characteristics
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Switchport, self).__init__()

                        self.yang_name = "switchport"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "switchport"
                        self._is_frozen = True


                class StackwiseVirtual(Entity):
                    """
                    Configure stackwise\-virtual link values
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..2
                    
                    .. attribute:: dual_active_detection
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.StackwiseVirtual, self).__init__()

                        self.yang_name = "stackwise-virtual"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                            ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                        ])
                        self.link = None
                        self.dual_active_detection = None
                        self._segment_path = lambda: "stackwise-virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


                class Arp(Entity):
                    """
                    Set arp type (arpa, probe, snap), timeout, log options or 
                    packet priority
                    
                    .. attribute:: timeout
                    
                    	Set ARP cache timeout
                    	**type**\: int
                    
                    	**range:** 0..2147483
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Arp, [u'timeout'], name, value)


                class Backup(Entity):
                    """
                    Modify backup parameters
                    
                    .. attribute:: delay
                    
                    	Delays before backup line up or down transitions
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Backup.Delay>`
                    
                    .. attribute:: interface
                    
                    	Configure an interface as a backup
                    	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Backup.Interface_>`
                    
                    .. attribute:: load
                    
                    	Load thresholds for line up or down transitions
                    	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Backup.Load>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Backup, self).__init__()

                        self.yang_name = "backup"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.ATMSubinterface.ATM.Backup.Delay)), ("interface", ("interface", Native.Interface.ATMSubinterface.ATM.Backup.Interface_)), ("load", ("load", Native.Interface.ATMSubinterface.ATM.Backup.Load))])
                        self._leafs = OrderedDict()

                        self.delay = Native.Interface.ATMSubinterface.ATM.Backup.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"

                        self.interface = Native.Interface.ATMSubinterface.ATM.Backup.Interface_()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"

                        self.load = Native.Interface.ATMSubinterface.ATM.Backup.Load()
                        self.load.parent = self
                        self._children_name_map["load"] = "load"
                        self._segment_path = lambda: "backup"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Backup, [], name, value)


                    class Delay(Entity):
                        """
                        Delays before backup line up or down transitions
                        
                        .. attribute:: failure
                        
                        	Seconds
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967294
                        
                        		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                        
                        .. attribute:: secondary_disable
                        
                        	Seconds
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967294
                        
                        		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Backup.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                                ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                            ])
                            self.failure = None
                            self.secondary_disable = None
                            self._segment_path = lambda: "delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                        class Failure(Enum):
                            """
                            Failure (Enum Class)

                            Seconds

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")


                        class SecondaryDisable(Enum):
                            """
                            SecondaryDisable (Enum Class)

                            Seconds

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")



                    class Interface_(Entity):
                        """
                        Configure an interface as a backup
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Backup.Interface_.ATMSubinterface_>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Backup.Interface_.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Backup.Interface_.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Backup.Interface_.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Backup.Interface_, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.ATMSubinterface.ATM.Backup.Interface_.ATMSubinterface_)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.ATMSubinterface.ATM.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.ATMSubinterface.ATM.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.ATMSubinterface.ATM.Backup.Interface_.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Interface.ATMSubinterface.ATM.Backup.Interface_.ATMSubinterface_()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Interface.ATMSubinterface.ATM.Backup.Interface_.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Interface.ATMSubinterface.ATM.Backup.Interface_.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Interface.ATMSubinterface.ATM.Backup.Interface_.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface_(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Backup.Interface_.ATMSubinterface_, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Backup.Interface_.ATMSubinterface_, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Backup.Interface_.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Backup.Interface_.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Backup.Interface_.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                    class Load(Entity):
                        """
                        Load thresholds for line up or down transitions
                        
                        .. attribute:: kickin
                        
                        	Percentage
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..100
                        
                        		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                        
                        .. attribute:: kickout
                        
                        	Percentage
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..100
                        
                        		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Backup.Load, self).__init__()

                            self.yang_name = "load"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                                ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                            ])
                            self.kickin = None
                            self.kickout = None
                            self._segment_path = lambda: "load"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Backup.Load, [u'kickin', u'kickout'], name, value)

                        class Kickin(Enum):
                            """
                            Kickin (Enum Class)

                            Percentage

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")


                        class Kickout(Enum):
                            """
                            Kickout (Enum Class)

                            Percentage

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")



                class Cemoudp(Entity):
                    """
                    cemoudp
                    
                    .. attribute:: reserve
                    
                    	
                    	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cemoudp.Reserve>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Cemoudp, self).__init__()

                        self.yang_name = "cemoudp"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.ATMSubinterface.ATM.Cemoudp.Reserve))])
                        self._leafs = OrderedDict()

                        self.reserve = Native.Interface.ATMSubinterface.ATM.Cemoudp.Reserve()
                        self.reserve.parent = self
                        self._children_name_map["reserve"] = "reserve"
                        self._segment_path = lambda: "cemoudp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Cemoudp, [], name, value)


                    class Reserve(Entity):
                        """
                        
                        
                        .. attribute:: acr
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Cemoudp.Reserve, self).__init__()

                            self.yang_name = "reserve"
                            self.yang_parent_name = "cemoudp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                            ])
                            self.acr = None
                            self._segment_path = lambda: "reserve"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Cemoudp.Reserve, [u'acr'], name, value)


                class CwsTunnel(Entity):
                    """
                    Configure Cloud Web Security Tunnel
                    
                    .. attribute:: in_
                    
                    	Inbound traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: out
                    
                    	Outbound traffic
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CwsTunnel.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.CwsTunnel, self).__init__()

                        self.yang_name = "cws-tunnel"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("out", ("out", Native.Interface.ATMSubinterface.ATM.CwsTunnel.Out))])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None

                        self.out = Native.Interface.ATMSubinterface.ATM.CwsTunnel.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "cws-tunnel"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CwsTunnel, [u'in_'], name, value)


                    class Out(Entity):
                        """
                        Outbound traffic
                        
                        .. attribute:: tunnel_number
                        
                        	Outboud traffic tunnel identifier
                        	**type**\: int
                        
                        	**range:** 0..65534
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CwsTunnel.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "cws-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                            ])
                            self.tunnel_number = None
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CwsTunnel.Out, [u'tunnel_number'], name, value)


                class L2protocolTunnel(Entity):
                    """
                    Tunnel Layer2 protocols
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: drop_threshold
                    
                    	Set drop threshold for protocol packets
                    	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.L2protocolTunnel.DropThreshold>`
                    
                    .. attribute:: shutdown_threshold
                    
                    	Set shutdown threshold for protocol packets
                    	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.L2protocolTunnel.ShutdownThreshold>`
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.L2protocolTunnel, self).__init__()

                        self.yang_name = "l2protocol-tunnel"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.ATMSubinterface.ATM.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.ATMSubinterface.ATM.L2protocolTunnel.ShutdownThreshold))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                            ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                            ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                        ])
                        self.cdp = None
                        self.stp = None
                        self.vtp = None

                        self.drop_threshold = Native.Interface.ATMSubinterface.ATM.L2protocolTunnel.DropThreshold()
                        self.drop_threshold.parent = self
                        self._children_name_map["drop_threshold"] = "drop-threshold"

                        self.shutdown_threshold = Native.Interface.ATMSubinterface.ATM.L2protocolTunnel.ShutdownThreshold()
                        self.shutdown_threshold.parent = self
                        self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                        self._segment_path = lambda: "l2protocol-tunnel"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                    class DropThreshold(Entity):
                        """
                        Set drop threshold for protocol packets
                        
                        .. attribute:: packet_rate
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: cdp
                        
                        	Cisco Discovery Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: stp
                        
                        	Spanning Tree Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: vtp
                        
                        	Vlan Trunking Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.L2protocolTunnel.DropThreshold, self).__init__()

                            self.yang_name = "drop-threshold"
                            self.yang_parent_name = "l2protocol-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                                ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                                ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                                ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                            ])
                            self.packet_rate = None
                            self.cdp = None
                            self.stp = None
                            self.vtp = None
                            self._segment_path = lambda: "drop-threshold"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                    class ShutdownThreshold(Entity):
                        """
                        Set shutdown threshold for protocol packets
                        
                        .. attribute:: packet_rate
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: cdp
                        
                        	Cisco Discovery Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: stp
                        
                        	Spanning Tree Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: vtp
                        
                        	Vlan Trunking Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.L2protocolTunnel.ShutdownThreshold, self).__init__()

                            self.yang_name = "shutdown-threshold"
                            self.yang_parent_name = "l2protocol-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                                ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                                ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                                ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                            ])
                            self.packet_rate = None
                            self.cdp = None
                            self.stp = None
                            self.vtp = None
                            self._segment_path = lambda: "shutdown-threshold"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class Encapsulation(Entity):
                    """
                    Set encapsulation type for an interface
                    
                    .. attribute:: dot1q
                    
                    	IEEE 802.1Q Virtual LAN
                    	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Encapsulation.Dot1Q>`
                    
                    .. attribute:: isl
                    
                    	Inter Switch Link \- Virtual LAN encapsulation
                    	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Encapsulation.Isl>`
                    
                    .. attribute:: ppp
                    
                    	Point\-to\-Point protocol
                    	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Encapsulation.Ppp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: slip
                    
                    	Serial Line IP
                    	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Encapsulation.Slip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: frame_relay
                    
                    	Frame Relay networks
                    	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Encapsulation.FrameRelay>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Encapsulation, self).__init__()

                        self.yang_name = "encapsulation"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.ATMSubinterface.ATM.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.ATMSubinterface.ATM.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.ATMSubinterface.ATM.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.ATMSubinterface.ATM.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.ATMSubinterface.ATM.Encapsulation.FrameRelay))])
                        self._leafs = OrderedDict()

                        self.dot1q = Native.Interface.ATMSubinterface.ATM.Encapsulation.Dot1Q()
                        self.dot1q.parent = self
                        self._children_name_map["dot1q"] = "dot1Q"

                        self.isl = Native.Interface.ATMSubinterface.ATM.Encapsulation.Isl()
                        self.isl.parent = self
                        self._children_name_map["isl"] = "isl"

                        self.ppp = None
                        self._children_name_map["ppp"] = "ppp"

                        self.slip = None
                        self._children_name_map["slip"] = "slip"

                        self.frame_relay = None
                        self._children_name_map["frame_relay"] = "frame-relay"
                        self._segment_path = lambda: "encapsulation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Encapsulation, [], name, value)


                    class Dot1Q(Entity):
                        """
                        IEEE 802.1Q Virtual LAN
                        
                        .. attribute:: vlan_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        .. attribute:: native
                        
                        	Make this as native vlan
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Encapsulation.Dot1Q, self).__init__()

                            self.yang_name = "dot1Q"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                            ])
                            self.vlan_id = None
                            self.native = None
                            self._segment_path = lambda: "dot1Q"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                    class Isl(Entity):
                        """
                        Inter Switch Link \- Virtual LAN encapsulation
                        
                        .. attribute:: vlan_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4095
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Encapsulation.Isl, self).__init__()

                            self.yang_name = "isl"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ])
                            self.vlan_id = None
                            self._segment_path = lambda: "isl"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Encapsulation.Isl, [u'vlan_id'], name, value)


                    class Ppp(Entity):
                        """
                        Point\-to\-Point protocol
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Encapsulation.Ppp, self).__init__()

                            self.yang_name = "ppp"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "ppp"
                            self._is_frozen = True


                    class Slip(Entity):
                        """
                        Serial Line IP
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Encapsulation.Slip, self).__init__()

                            self.yang_name = "slip"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "slip"
                            self._is_frozen = True


                    class FrameRelay(Entity):
                        """
                        Frame Relay networks
                        
                        .. attribute:: ietf
                        
                        	Use RFC1490/RFC2427 encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Encapsulation.FrameRelay, self).__init__()

                            self.yang_name = "frame-relay"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                            ])
                            self.ietf = None
                            self._segment_path = lambda: "frame-relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Encapsulation.FrameRelay, [u'ietf'], name, value)


                class FairQueueConf(Entity):
                    """
                    
                    
                    .. attribute:: fair_queue
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.FairQueueConf, self).__init__()

                        self.yang_name = "fair-queue-conf"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                        ])
                        self.fair_queue = None
                        self._segment_path = lambda: "fair-queue-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.FairQueueConf, [u'fair_queue'], name, value)


                class FairQueue(Entity):
                    """
                    Enable Fair Queuing on an Interface
                    
                    .. attribute:: incomplete
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.FairQueue, self).__init__()

                        self.yang_name = "fair-queue"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                        ])
                        self.incomplete = None
                        self._segment_path = lambda: "fair-queue"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.FairQueue, [u'incomplete'], name, value)


                class Flowcontrol(Entity):
                    """
                    Configure flow operation.
                    
                    .. attribute:: receive
                    
                    	Configure receiving flow operation
                    	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Flowcontrol.Receive>`
                    
                    .. attribute:: send
                    
                    	Configure sending flow operation
                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Flowcontrol.Send>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Flowcontrol, self).__init__()

                        self.yang_name = "flowcontrol"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Flowcontrol.Receive')])),
                            ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Flowcontrol.Send')])),
                        ])
                        self.receive = None
                        self.send = None
                        self._segment_path = lambda: "flowcontrol"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Flowcontrol, [u'receive', u'send'], name, value)

                    class Receive(Enum):
                        """
                        Receive (Enum Class)

                        Configure receiving flow operation

                        .. data:: desired = 0

                        .. data:: off = 1

                        .. data:: on = 2

                        """

                        desired = Enum.YLeaf(0, "desired")

                        off = Enum.YLeaf(1, "off")

                        on = Enum.YLeaf(2, "on")


                    class Send(Enum):
                        """
                        Send (Enum Class)

                        Configure sending flow operation

                        .. data:: desired = 0

                        .. data:: off = 1

                        .. data:: on = 2

                        """

                        desired = Enum.YLeaf(0, "desired")

                        off = Enum.YLeaf(1, "off")

                        on = Enum.YLeaf(2, "on")



                class Isis(Entity):
                    """
                    IS\-IS commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Isis, self).__init__()

                        self.yang_name = "isis"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "isis"
                        self._is_frozen = True


                class KeepaliveSettings(Entity):
                    """
                    
                    
                    .. attribute:: keepalive
                    
                    	Enable keepalive
                    	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.KeepaliveSettings.Keepalive>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.KeepaliveSettings, self).__init__()

                        self.yang_name = "keepalive-settings"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.ATMSubinterface.ATM.KeepaliveSettings.Keepalive))])
                        self._leafs = OrderedDict()

                        self.keepalive = None
                        self._children_name_map["keepalive"] = "keepalive"
                        self._segment_path = lambda: "keepalive-settings"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.KeepaliveSettings, [], name, value)


                    class Keepalive(Entity):
                        """
                        Enable keepalive
                        
                        .. attribute:: period
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..32767
                        
                        .. attribute:: retries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.KeepaliveSettings.Keepalive, self).__init__()

                            self.yang_name = "keepalive"
                            self.yang_parent_name = "keepalive-settings"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                            ])
                            self.period = None
                            self.retries = None
                            self._segment_path = lambda: "keepalive"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


                class Bfd(Entity):
                    """
                    BFD interface configuration commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True


                class Bandwidth(Entity):
                    """
                    Set bandwidth informational parameter
                    
                    .. attribute:: receive
                    
                    	Specify receive\-side bandwidth
                    	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Bandwidth.Receive>`
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Bandwidth.Inherit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: qos_reference
                    
                    	Reference bandwidth for QOS
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.ATMSubinterface.ATM.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.ATMSubinterface.ATM.Bandwidth.Inherit))])
                        self._leafs = OrderedDict([
                            ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.qos_reference = None
                        self.kilobits = None

                        self.receive = Native.Interface.ATMSubinterface.ATM.Bandwidth.Receive()
                        self.receive.parent = self
                        self._children_name_map["receive"] = "receive"

                        self.inherit = None
                        self._children_name_map["inherit"] = "inherit"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                    class Receive(Entity):
                        """
                        Specify receive\-side bandwidth
                        
                        .. attribute:: inherit
                        
                        	Specify how bandwidth is inherited
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: kilobits
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Bandwidth.Receive, self).__init__()

                            self.yang_name = "receive"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                                ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                            ])
                            self.inherit = None
                            self.kilobits = None
                            self._segment_path = lambda: "receive"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                    class Inherit(Entity):
                        """
                        Specify how bandwidth is inherited
                        
                        .. attribute:: kilobits
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Bandwidth.Inherit, self).__init__()

                            self.yang_name = "inherit"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                            ])
                            self.kilobits = None
                            self._segment_path = lambda: "inherit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Bandwidth.Inherit, [u'kilobits'], name, value)


                class Dampening(Entity):
                    """
                    Enable event dampening
                    
                    .. attribute:: dampening_time
                    
                    	<1\-30>;;Half\-life time for penalty
                    	**type**\: int
                    
                    	**range:** 1..30
                    
                    .. attribute:: start_reusing_time
                    
                    	<1\-20000>;;Value to start reusing an interface
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    .. attribute:: start_supressing_time
                    
                    	<1\-20000>;;Value to start supressing an interface
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    .. attribute:: maximum_supressing_time
                    
                    	<1\-255>;;Maximum duration to suppress an interface
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Dampening.Restart>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Dampening, self).__init__()

                        self.yang_name = "dampening"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.ATMSubinterface.ATM.Dampening.Restart))])
                        self._leafs = OrderedDict([
                            ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                            ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                            ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                            ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                        ])
                        self.dampening_time = None
                        self.start_reusing_time = None
                        self.start_supressing_time = None
                        self.maximum_supressing_time = None

                        self.restart = Native.Interface.ATMSubinterface.ATM.Dampening.Restart()
                        self.restart.parent = self
                        self._children_name_map["restart"] = "restart"
                        self._segment_path = lambda: "dampening"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                    class Restart(Entity):
                        """
                        Enable restart penalty
                        
                        .. attribute:: restart
                        
                        	Enable restart penalty
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restart_penalty
                        
                        	<1\-20000>;;Penalty applied at restart
                        	**type**\: int
                        
                        	**range:** 1..20000
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Dampening.Restart, self).__init__()

                            self.yang_name = "restart"
                            self.yang_parent_name = "dampening"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                                ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                            ])
                            self.restart = None
                            self.restart_penalty = None
                            self._segment_path = lambda: "restart"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


                class Domain(Entity):
                    """
                    Specify a domain
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: path
                    
                    	Specify a service provider for this interface
                    	**type**\: str
                    
                    .. attribute:: internet_bound
                    
                    	Specify Internet\-bound interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: path_id
                    
                    	Specify service provider path\-id for this interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: path_last_resort
                    
                    	Specify if you want this interface to be a path of last resort
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: zero_sla
                    
                    	Specify if you want this interface to be a 0\-sla interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Domain, self).__init__()

                        self.yang_name = "domain"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('path', (YLeaf(YType.str, 'path'), ['str'])),
                            ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                            ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                            ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                            ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                        ])
                        self.name = None
                        self.path = None
                        self.internet_bound = None
                        self.path_id = None
                        self.path_last_resort = None
                        self.zero_sla = None
                        self._segment_path = lambda: "domain"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


                class HoldQueue(Entity):
                    """
                    Set hold queue depth
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.HoldQueue.Direction>`
                    
                    .. attribute:: queue_length
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.HoldQueue, self).__init__()

                        self.yang_name = "hold-queue"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.HoldQueue.Direction')])),
                            ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                        ])
                        self.direction = None
                        self.queue_length = None
                        self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.HoldQueue, [u'direction', u'queue_length'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Mpls(Entity):
                    """
                    
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "mpls"
                        self._is_frozen = True


                class IpVrf(Entity):
                    """
                    
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.IpVrf.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.IpVrf, self).__init__()

                        self.yang_name = "ip-vrf"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.ATMSubinterface.ATM.IpVrf.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.ATMSubinterface.ATM.IpVrf.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "ip-vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.IpVrf, [], name, value)


                    class Ip(Entity):
                        """
                        
                        
                        .. attribute:: vrf
                        
                        	
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.IpVrf.Ip.Vrf>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.IpVrf.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "ip-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.ATMSubinterface.ATM.IpVrf.Ip.Vrf))])
                            self._leafs = OrderedDict()

                            self.vrf = Native.Interface.ATMSubinterface.ATM.IpVrf.Ip.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.IpVrf.Ip, [], name, value)


                        class Vrf(Entity):
                            """
                            
                            
                            .. attribute:: forwarding
                            
                            	Configure forwarding table
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.IpVrf.Ip.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                                ])
                                self.forwarding = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Vrf, [u'forwarding'], name, value)


                class CiscoIOSXEInterfacesIp(Entity):
                    """
                    Interface Internet Protocol config commands
                    
                    .. attribute:: admission
                    
                    	Apply Network Admission Control
                    	**type**\: str
                    
                    .. attribute:: access_group
                    
                    	Specify access control for packets
                    	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup>`
                    
                    .. attribute:: arp
                    
                    	Configure ARP features
                    	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp>`
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding parameters on the interface
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Vrf>`
                    
                    .. attribute:: unnumbered
                    
                    	Enable IP processing without an explicit address
                    	**type**\: str
                    
                    .. attribute:: no_address
                    
                    	
                    	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.NoAddress>`
                    
                    .. attribute:: address
                    
                    	Set the IP address of an interface
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address>`
                    
                    .. attribute:: directed_broadcast
                    
                    	Enable forwarding of directed broadcasts
                    	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.DirectedBroadcast>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Configures EIGRP\-IPv4 hello interval
                    	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HelloInterval>`
                    
                    .. attribute:: authentication
                    
                    	authentication subcommands
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication>`
                    
                    .. attribute:: hold_time
                    
                    	Configures EIGRP\-IPv4 hold time
                    	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HoldTime>`
                    
                    .. attribute:: helper_address
                    
                    	Specify a destination address for UDP broadcasts
                    	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HelperAddress>`
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Pim>`
                    
                    .. attribute:: policy
                    
                    	Enable policy routing
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Policy>`
                    
                    .. attribute:: local_proxy_arp
                    
                    	Enable local\-proxy ARP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: proxy_arp
                    
                    	Enable proxy ARP
                    	**type**\: bool
                    
                    .. attribute:: rip
                    
                    	Router Information Protocol
                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip>`
                    
                    .. attribute:: route_cache_conf
                    
                    	
                    	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.RouteCacheConf>`
                    
                    .. attribute:: route_cache
                    
                    	Enable fast\-switching cache for outgoing packets
                    	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.RouteCache>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: router
                    
                    	IP router interface commands
                    	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Router>`
                    
                    .. attribute:: redirects
                    
                    	Enable sending ICMP Redirect messages
                    	**type**\: bool
                    
                    .. attribute:: tcp
                    
                    	TCP header compression and other parameters
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Tcp>`
                    
                    .. attribute:: virtual_reassembly
                    
                    	
                    	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.VirtualReassembly>`
                    
                    .. attribute:: dhcp
                    
                    	Configure DHCP parameters for this interface
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Dhcp>`
                    
                    .. attribute:: mtu
                    
                    	Set IP Maximum Transmission Unit
                    	**type**\: int
                    
                    	**range:** 68..9216
                    
                    .. attribute:: mroute_cache
                    
                    	Enable switching cache for incoming multicast packets
                    	**type**\: bool
                    
                    .. attribute:: summary_address
                    
                    	
                    	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress>`
                    
                    .. attribute:: verify
                    
                    	Enable per packet validation
                    	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup)), ("arp", ("arp", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp)), ("vrf", ("vrf", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Vrf)), ("no-address", ("no_address", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.NoAddress)), ("address", ("address", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HelloInterval)), ("authentication", ("authentication", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication)), ("hold-time", ("hold_time", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HoldTime)), ("helper-address", ("helper_address", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HelperAddress)), ("pim", ("pim", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Pim)), ("policy", ("policy", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Policy)), ("rip", ("rip", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.RouteCache)), ("router", ("router", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Router)), ("tcp", ("tcp", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Dhcp)), ("summary-address", ("summary_address", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress)), ("verify", ("verify", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify))])
                        self._leafs = OrderedDict([
                            ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                            ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                            ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                            ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                            ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                            ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                            ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ])
                        self.admission = None
                        self.unnumbered = None
                        self.local_proxy_arp = None
                        self.proxy_arp = None
                        self.redirects = None
                        self.mtu = None
                        self.mroute_cache = None

                        self.access_group = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup()
                        self.access_group.parent = self
                        self._children_name_map["access_group"] = "access-group"

                        self.arp = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp()
                        self.arp.parent = self
                        self._children_name_map["arp"] = "arp"

                        self.vrf = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.no_address = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.NoAddress()
                        self.no_address.parent = self
                        self._children_name_map["no_address"] = "no-address"

                        self.address = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.directed_broadcast = None
                        self._children_name_map["directed_broadcast"] = "directed-broadcast"

                        self.hello_interval = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HelloInterval()
                        self.hello_interval.parent = self
                        self._children_name_map["hello_interval"] = "hello-interval"

                        self.authentication = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.hold_time = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HoldTime()
                        self.hold_time.parent = self
                        self._children_name_map["hold_time"] = "hold-time"

                        self.pim = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Pim()
                        self.pim.parent = self
                        self._children_name_map["pim"] = "pim"

                        self.policy = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.rip = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip()
                        self.rip.parent = self
                        self._children_name_map["rip"] = "rip"

                        self.route_cache_conf = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.RouteCacheConf()
                        self.route_cache_conf.parent = self
                        self._children_name_map["route_cache_conf"] = "route-cache-conf"

                        self.route_cache = None
                        self._children_name_map["route_cache"] = "route-cache"

                        self.router = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Router()
                        self.router.parent = self
                        self._children_name_map["router"] = "router"

                        self.tcp = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"

                        self.virtual_reassembly = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.VirtualReassembly()
                        self.virtual_reassembly.parent = self
                        self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                        self.dhcp = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Dhcp()
                        self.dhcp.parent = self
                        self._children_name_map["dhcp"] = "dhcp"

                        self.summary_address = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress()
                        self.summary_address.parent = self
                        self._children_name_map["summary_address"] = "summary-address"

                        self.verify = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify()
                        self.verify.parent = self
                        self._children_name_map["verify"] = "verify"

                        self.helper_address = YList(self)
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                    class AccessGroup(Entity):
                        """
                        Specify access control for packets
                        
                        .. attribute:: in_
                        
                        	
                        	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In>`
                        
                        .. attribute:: out
                        
                        	
                        	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup, self).__init__()

                            self.yang_name = "access-group"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("in", ("in_", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In)), ("out", ("out", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out))])
                            self._leafs = OrderedDict()

                            self.in_ = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In()
                            self.in_.parent = self
                            self._children_name_map["in_"] = "in"

                            self.out = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out()
                            self.out.parent = self
                            self._children_name_map["out"] = "out"
                            self._segment_path = lambda: "access-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup, [], name, value)


                        class In(Entity):
                            """
                            
                            
                            .. attribute:: common_acl
                            
                            	
                            	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl>`
                            
                            .. attribute:: acl
                            
                            	
                            	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In, self).__init__()

                                self.yang_name = "in"
                                self.yang_parent_name = "access-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl))])
                                self._leafs = OrderedDict()

                                self.common_acl = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl()
                                self.common_acl.parent = self
                                self._children_name_map["common_acl"] = "common-acl"

                                self.acl = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl()
                                self.acl.parent = self
                                self._children_name_map["acl"] = "acl"
                                self._segment_path = lambda: "in"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In, [], name, value)


                            class CommonAcl(Entity):
                                """
                                
                                
                                .. attribute:: common
                                
                                	specify ipv4 common ACL for packet filtering
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: in_
                                
                                	inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl, self).__init__()

                                    self.yang_name = "common-acl"
                                    self.yang_parent_name = "in"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ])
                                    self.common = None
                                    self.in_ = None
                                    self._segment_path = lambda: "common-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                            class Acl(Entity):
                                """
                                
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: in_
                                
                                	inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl, self).__init__()

                                    self.yang_name = "acl"
                                    self.yang_parent_name = "in"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ])
                                    self.acl_name = None
                                    self.in_ = None
                                    self._segment_path = lambda: "acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                        class Out(Entity):
                            """
                            
                            
                            .. attribute:: common_acl
                            
                            	
                            	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl>`
                            
                            .. attribute:: acl
                            
                            	
                            	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out, self).__init__()

                                self.yang_name = "out"
                                self.yang_parent_name = "access-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl))])
                                self._leafs = OrderedDict()

                                self.common_acl = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl()
                                self.common_acl.parent = self
                                self._children_name_map["common_acl"] = "common-acl"

                                self.acl = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl()
                                self.acl.parent = self
                                self._children_name_map["acl"] = "acl"
                                self._segment_path = lambda: "out"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out, [], name, value)


                            class CommonAcl(Entity):
                                """
                                
                                
                                .. attribute:: common
                                
                                	specify ipv4 common ACL for packet filtering
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: out
                                
                                	outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl, self).__init__()

                                    self.yang_name = "common-acl"
                                    self.yang_parent_name = "out"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.common = None
                                    self.out = None
                                    self._segment_path = lambda: "common-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                            class Acl(Entity):
                                """
                                
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: out
                                
                                	outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl, self).__init__()

                                    self.yang_name = "acl"
                                    self.yang_parent_name = "out"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.acl_name = None
                                    self.out = None
                                    self._segment_path = lambda: "acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                    class Arp(Entity):
                        """
                        Configure ARP features
                        
                        .. attribute:: inspection
                        
                        	Arp Inspection configuration
                        	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp, self).__init__()

                            self.yang_name = "arp"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection))])
                            self._leafs = OrderedDict()

                            self.inspection = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection()
                            self.inspection.parent = self
                            self._children_name_map["inspection"] = "inspection"
                            self._segment_path = lambda: "arp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp, [], name, value)


                        class Inspection(Entity):
                            """
                            Arp Inspection configuration
                            
                            .. attribute:: limit
                            
                            	Configure Rate limit of incoming ARP packets
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit>`
                            
                            .. attribute:: trust
                            
                            	Configure Trust state
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection, self).__init__()

                                self.yang_name = "inspection"
                                self.yang_parent_name = "arp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit))])
                                self._leafs = OrderedDict([
                                    ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ])
                                self.trust = None

                                self.limit = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "inspection"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection, [u'trust'], name, value)


                            class Limit(Entity):
                                """
                                Configure Rate limit of incoming ARP packets
                                
                                .. attribute:: none
                                
                                	No limit
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rate
                                
                                	Rate Limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "inspection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                    ])
                                    self.none = None
                                    self.rate = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                    class Vrf(Entity):
                        """
                        VPN Routing/Forwarding parameters on the interface
                        
                        .. attribute:: receive
                        
                        	Add Interface Address into VRF Table
                        	**type**\: str
                        
                        .. attribute:: sitemap
                        
                        	Configure route\-map for routesreceived from this site
                        	**type**\: str
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Vrf.Forwarding>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Vrf.Forwarding))])
                            self._leafs = OrderedDict([
                                ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                                ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                            ])
                            self.receive = None
                            self.sitemap = None

                            self.forwarding = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Vrf.Forwarding()
                            self.forwarding.parent = self
                            self._children_name_map["forwarding"] = "forwarding"
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Vrf, [u'receive', u'sitemap'], name, value)


                        class Forwarding(Entity):
                            """
                            Configure forwarding table
                            
                            .. attribute:: liin_vrf
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mgmtvrf
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: word
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Vrf.Forwarding, self).__init__()

                                self.yang_name = "forwarding"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                    ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.liin_vrf = None
                                self.mgmtvrf = None
                                self.word = None
                                self._segment_path = lambda: "forwarding"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                    class NoAddress(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.NoAddress, self).__init__()

                            self.yang_name = "no-address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                            ])
                            self.address = None
                            self._segment_path = lambda: "no-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.NoAddress, [u'address'], name, value)


                    class Address(Entity):
                        """
                        Set the IP address of an interface
                        
                        .. attribute:: secondary
                        
                        	
                        	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Secondary>`
                        
                        .. attribute:: primary
                        
                        	
                        	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Primary>`
                        
                        .. attribute:: dhcp
                        
                        	IP Address negotiated via DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: negotiated
                        
                        	IP Address negotiated via IKEv2 Modeconfig
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Secondary)), ("primary", ("primary", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp))])
                            self._leafs = OrderedDict([
                                ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                            ])
                            self.negotiated = None

                            self.primary = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Primary()
                            self.primary.parent = self
                            self._children_name_map["primary"] = "primary"

                            self.dhcp = None
                            self._children_name_map["dhcp"] = "dhcp"

                            self.secondary = YList(self)
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address, [u'negotiated'], name, value)


                        class Secondary(Entity):
                            """
                            
                            
                            .. attribute:: address  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**mandatory**\: True
                            
                            .. attribute:: secondary
                            
                            	Make this IP address a secondary address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Secondary, self).__init__()

                                self.yang_name = "secondary"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.address = None
                                self.mask = None
                                self.secondary = None
                                self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                        class Primary(Entity):
                            """
                            
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Primary, self).__init__()

                                self.yang_name = "primary"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.address = None
                                self.mask = None
                                self._segment_path = lambda: "primary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Primary, [u'address', u'mask'], name, value)


                        class Dhcp(Entity):
                            """
                            IP Address negotiated via DHCP
                            
                            .. attribute:: client_id
                            
                            	Specify client\-id to use
                            	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId>`
                            
                            .. attribute:: hostname
                            
                            	Specify value for hostname option
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                                ])
                                self.hostname = None

                                self.client_id = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId()
                                self.client_id.parent = self
                                self._children_name_map["client_id"] = "client-id"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp, [u'hostname'], name, value)


                            class ClientId(Entity):
                                """
                                Specify client\-id to use
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five Gigabit Ethernet 
                                	**type**\: str
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five Gigabit Ethernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two Gigabit Ethernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: vlan
                                
                                	Catalyst Vlans
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId, self).__init__()

                                    self.yang_name = "client-id"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.port_channel = None
                                    self.tengigabitethernet = None
                                    self.twentyfivegige = None
                                    self.fortygigabitethernet = None
                                    self.twogigabitethernet = None
                                    self.hundredgige = None
                                    self.vlan = None
                                    self._segment_path = lambda: "client-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                    class DirectedBroadcast(Entity):
                        """
                        Enable forwarding of directed broadcasts
                        
                        .. attribute:: direct_broadcast
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.DirectedBroadcast, self).__init__()

                            self.yang_name = "directed-broadcast"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                            ])
                            self.direct_broadcast = None
                            self._segment_path = lambda: "directed-broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.DirectedBroadcast, [u'direct_broadcast'], name, value)


                    class HelloInterval(Entity):
                        """
                        Configures EIGRP\-IPv4 hello interval
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: seconds
                        
                        	Seconds between hello transmissions
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HelloInterval, self).__init__()

                            self.yang_name = "hello-interval"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                            ])
                            self.eigrp = None
                            self.seconds = None
                            self._segment_path = lambda: "hello-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HelloInterval, [u'eigrp', u'seconds'], name, value)


                    class Authentication(Entity):
                        """
                        authentication subcommands
                        
                        .. attribute:: key_chain
                        
                        	key\-chain
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication.KeyChain>`
                        
                        .. attribute:: mode
                        
                        	mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication.Mode))])
                            self._leafs = OrderedDict()

                            self.key_chain = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"

                            self.mode = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication, [], name, value)


                        class KeyChain(Entity):
                            """
                            key\-chain
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: name
                            
                            	name of key\-chain
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.eigrp = None
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                        class Mode(Entity):
                            """
                            mode
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                ])
                                self.eigrp = None
                                self.md5 = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                    class HoldTime(Entity):
                        """
                        Configures EIGRP\-IPv4 hold time
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: seconds
                        
                        	Seconds before neighbor is considered down
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HoldTime, self).__init__()

                            self.yang_name = "hold-time"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                            ])
                            self.eigrp = None
                            self.seconds = None
                            self._segment_path = lambda: "hold-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HoldTime, [u'eigrp', u'seconds'], name, value)


                    class HelperAddress(Entity):
                        """
                        Specify a destination address for UDP broadcasts
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: global_
                        
                        	Helper\-address is global
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vrf
                        
                        	VRF name for helper\-address (if different from interface VRF)
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HelperAddress, self).__init__()

                            self.yang_name = "helper-address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.address = None
                            self.global_ = None
                            self.vrf = None
                            self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                    class Pim(Entity):
                        """
                        PIM interface commands
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Pim, self).__init__()

                            self.yang_name = "pim"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "pim"
                            self._is_frozen = True


                    class Policy(Entity):
                        """
                        Enable policy routing
                        
                        .. attribute:: route_map
                        
                        	Policy route\-map
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Policy, [u'route_map'], name, value)


                    class Rip(Entity):
                        """
                        Router Information Protocol
                        
                        .. attribute:: authentication
                        
                        	Authentication control
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip, self).__init__()

                            self.yang_name = "rip"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication))])
                            self._leafs = OrderedDict()

                            self.authentication = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"
                            self._segment_path = lambda: "rip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip, [], name, value)


                        class Authentication(Entity):
                            """
                            Authentication control
                            
                            .. attribute:: key_chain
                            
                            	Authentication key\-chain
                            	**type**\: str
                            
                            .. attribute:: mode
                            
                            	Authentication mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "rip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.mode = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode()
                                self.mode.parent = self
                                self._children_name_map["mode"] = "mode"
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication, [u'key_chain'], name, value)


                            class Mode(Entity):
                                """
                                Authentication mode
                                
                                .. attribute:: md5
                                
                                	Keyed message digest
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: text
                                
                                	Clear text authentication
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode, self).__init__()

                                    self.yang_name = "mode"
                                    self.yang_parent_name = "authentication"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                        ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                    ])
                                    self.md5 = None
                                    self.text = None
                                    self._segment_path = lambda: "mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                    class RouteCacheConf(Entity):
                        """
                        
                        
                        .. attribute:: route_cache
                        
                        	
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.RouteCacheConf, self).__init__()

                            self.yang_name = "route-cache-conf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                            ])
                            self.route_cache = None
                            self._segment_path = lambda: "route-cache-conf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.RouteCacheConf, [u'route_cache'], name, value)


                    class RouteCache(Entity):
                        """
                        Enable fast\-switching cache for outgoing packets
                        
                        .. attribute:: cef
                        
                        	Enable Cisco Express Forwarding
                        	**type**\: bool
                        
                        .. attribute:: flow
                        
                        	Enable Flow fast\-switching cache
                        	**type**\: bool
                        
                        .. attribute:: policy
                        
                        	Enable fast\-switching policy cache for outgoing packets
                        	**type**\: bool
                        
                        .. attribute:: same_interface
                        
                        	Enable fast\-switching on the same interface
                        	**type**\: bool
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.RouteCache, self).__init__()

                            self.yang_name = "route-cache"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                                ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                                ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                                ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                            ])
                            self.cef = None
                            self.flow = None
                            self.policy = None
                            self.same_interface = None
                            self._segment_path = lambda: "route-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                    class Router(Entity):
                        """
                        IP router interface commands
                        
                        .. attribute:: isis
                        
                        	IS\-IS Routing for IP
                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Router.Isis>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Router, self).__init__()

                            self.yang_name = "router"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Router.Isis))])
                            self._leafs = OrderedDict()

                            self.isis = None
                            self._children_name_map["isis"] = "isis"
                            self._segment_path = lambda: "router"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Router, [], name, value)


                        class Isis(Entity):
                            """
                            IS\-IS Routing for IP
                            
                            .. attribute:: tag
                            
                            	
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Router.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "router"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                                ])
                                self.tag = None
                                self._segment_path = lambda: "isis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Router.Isis, [u'tag'], name, value)


                    class Tcp(Entity):
                        """
                        TCP header compression and other parameters
                        
                        .. attribute:: adjust_mss
                        
                        	Adjust the mss of transit packets
                        	**type**\: int
                        
                        	**range:** 500..1460
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                            ])
                            self.adjust_mss = None
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Tcp, [u'adjust_mss'], name, value)


                    class VirtualReassembly(Entity):
                        """
                        
                        
                        .. attribute:: max_reassemblies
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_fragments
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: timeout
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop_fragments
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: in_
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.VirtualReassembly, self).__init__()

                            self.yang_name = "virtual-reassembly"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                                ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                                ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                                ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                            ])
                            self.max_reassemblies = None
                            self.max_fragments = None
                            self.timeout = None
                            self.drop_fragments = None
                            self.in_ = None
                            self._segment_path = lambda: "virtual-reassembly"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                    class Dhcp(Entity):
                        """
                        Configure DHCP parameters for this interface
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True


                    class SummaryAddress(Entity):
                        """
                        
                        
                        .. attribute:: eigrp
                        
                        	
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress, self).__init__()

                            self.yang_name = "summary-address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp))])
                            self._leafs = OrderedDict()

                            self.eigrp = YList(self)
                            self._segment_path = lambda: "summary-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress, [], name, value)


                        class Eigrp(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: metric
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "summary-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ])
                                self.id = None
                                self.ip = None
                                self.mask = None
                                self.metric = None
                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                    class Verify(Entity):
                        """
                        Enable per packet validation
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: unicast
                        
                        	Enable per packet validation for unicast
                        	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify, self).__init__()

                            self.yang_name = "verify"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source", ("source", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source)), ("unicast", ("unicast", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast))])
                            self._leafs = OrderedDict()

                            self.source = None
                            self._children_name_map["source"] = "source"

                            self.unicast = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast()
                            self.unicast.parent = self
                            self._children_name_map["unicast"] = "unicast"
                            self._segment_path = lambda: "verify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify, [], name, value)


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "verify"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.vlan = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source, [], name, value)


                            class Vlan(Entity):
                                """
                                vlan specification
                                
                                .. attribute:: dhcp_snooping
                                
                                	snooping enable vlan
                                	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan.DhcpSnooping>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan.DhcpSnooping))])
                                    self._leafs = OrderedDict()

                                    self.dhcp_snooping = None
                                    self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan, [], name, value)


                                class DhcpSnooping(Entity):
                                    """
                                    snooping enable vlan
                                    
                                    .. attribute:: port_security
                                    
                                    	port security
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                        self.yang_name = "dhcp-snooping"
                                        self.yang_parent_name = "vlan"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                        ])
                                        self.port_security = None
                                        self._segment_path = lambda: "dhcp-snooping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                        class Unicast(Entity):
                            """
                            Enable per packet validation for unicast
                            
                            .. attribute:: reverse_path
                            
                            	Reverse path validation of source address (old command format)
                            	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.ReversePath>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: source
                            
                            	Validation of source address
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast, self).__init__()

                                self.yang_name = "unicast"
                                self.yang_parent_name = "verify"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source))])
                                self._leafs = OrderedDict()

                                self.reverse_path = None
                                self._children_name_map["reverse_path"] = "reverse-path"

                                self.source = Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "unicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast, [], name, value)


                            class ReversePath(Entity):
                                """
                                Reverse path validation of source address (old command format)
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.ReversePath, self).__init__()

                                    self.yang_name = "reverse-path"
                                    self.yang_parent_name = "unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "reverse-path"
                                    self._is_frozen = True


                            class Source(Entity):
                                """
                                Validation of source address
                                
                                .. attribute:: reachable_via
                                
                                	Specify reachability check to apply to the source address
                                	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source.ReachableVia>`
                                
                                .. attribute:: allow_self_ping
                                
                                	Allow router to ping itself (opens vulnerability in verification)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allow_default
                                
                                	Allow default route to match when checking source address
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source.ReachableVia')])),
                                        ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                        ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                    ])
                                    self.reachable_via = None
                                    self.allow_self_ping = None
                                    self.allow_default = None
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEInterfacesIp.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                                class ReachableVia(Enum):
                                    """
                                    ReachableVia (Enum Class)

                                    Specify reachability check to apply to the source address

                                    .. data:: any = 0

                                    .. data:: rx = 1

                                    """

                                    any = Enum.YLeaf(0, "any")

                                    rx = Enum.YLeaf(1, "rx")



                class Ipv6(Entity):
                    """
                    IPv6 interface subcommands
                    
                    .. attribute:: destination_guard
                    
                    	Configure ipv6 destination guard on the interface
                    	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.DestinationGuard>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: source_guard
                    
                    	Configure ipv6 source guard on the interface
                    	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.SourceGuard>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dhcp
                    
                    	IPv6 DHCP interface subcommands
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.Dhcp>`
                    
                    .. attribute:: address
                    
                    	Configure IPv6 address on interface
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.Address>`
                    
                    .. attribute:: unnumbered
                    
                    	Preferred interface for source address selection
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable IPv6 on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mtu
                    
                    	Set IPv6 Maximum Transmission Unit
                    	**type**\: int
                    
                    	**range:** 1280..9216
                    
                    .. attribute:: nd
                    
                    	IPv6 interface Neighbor Discovery subcommands
                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.Nd>`
                    
                    .. attribute:: redirects
                    
                    	Enable sending ICMP Redirect messages
                    	**type**\: bool
                    
                    .. attribute:: tcp
                    
                    	TCP header compression and other parameters
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.Tcp>`
                    
                    .. attribute:: traffic_filter
                    
                    	Access control list for packets
                    	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.TrafficFilter>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.ATMSubinterface.ATM.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.ATMSubinterface.ATM.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.ATMSubinterface.ATM.Ipv6.Dhcp)), ("address", ("address", Native.Interface.ATMSubinterface.ATM.Ipv6.Address)), ("nd", ("nd", Native.Interface.ATMSubinterface.ATM.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.ATMSubinterface.ATM.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.ATMSubinterface.ATM.Ipv6.TrafficFilter))])
                        self._leafs = OrderedDict([
                            ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                            ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ])
                        self.unnumbered = None
                        self.enable = None
                        self.mtu = None
                        self.redirects = None

                        self.destination_guard = None
                        self._children_name_map["destination_guard"] = "destination-guard"

                        self.source_guard = None
                        self._children_name_map["source_guard"] = "source-guard"

                        self.dhcp = Native.Interface.ATMSubinterface.ATM.Ipv6.Dhcp()
                        self.dhcp.parent = self
                        self._children_name_map["dhcp"] = "dhcp"

                        self.address = Native.Interface.ATMSubinterface.ATM.Ipv6.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.nd = Native.Interface.ATMSubinterface.ATM.Ipv6.Nd()
                        self.nd.parent = self
                        self._children_name_map["nd"] = "nd"

                        self.tcp = Native.Interface.ATMSubinterface.ATM.Ipv6.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"

                        self.traffic_filter = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                    class DestinationGuard(Entity):
                        """
                        Configure ipv6 destination guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature ipv6 destguard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Ipv6.DestinationGuard, self).__init__()

                            self.yang_name = "destination-guard"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "destination-guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                    class SourceGuard(Entity):
                        """
                        Configure ipv6 source guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature ipv6 sourceguard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Ipv6.SourceGuard, self).__init__()

                            self.yang_name = "source-guard"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "source-guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                    class Dhcp(Entity):
                        """
                        IPv6 DHCP interface subcommands
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Ipv6.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True


                    class Address(Entity):
                        """
                        Configure IPv6 address on interface
                        
                        .. attribute:: dhcp
                        
                        	Obtain IPv6 address from DHCP server
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.Address.Dhcp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: autoconfig
                        
                        	Obtain address using autoconfiguration
                        	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.Address.Autoconfig>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix_list
                        
                        	
                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.Address.PrefixList>`
                        
                        .. attribute:: link_local_address
                        
                        	
                        	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.Address.LinkLocalAddress>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Ipv6.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.ATMSubinterface.ATM.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.ATMSubinterface.ATM.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.ATMSubinterface.ATM.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.ATMSubinterface.ATM.Ipv6.Address.LinkLocalAddress))])
                            self._leafs = OrderedDict()

                            self.dhcp = None
                            self._children_name_map["dhcp"] = "dhcp"

                            self.autoconfig = None
                            self._children_name_map["autoconfig"] = "autoconfig"

                            self.prefix_list = YList(self)
                            self.link_local_address = YList(self)
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Ipv6.Address, [], name, value)


                        class Dhcp(Entity):
                            """
                            Obtain IPv6 address from DHCP server
                            
                            .. attribute:: rapid_commit
                            
                            	rapid\-commit for prefix delegation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Ipv6.Address.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                                ])
                                self.rapid_commit = None
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                        class Autoconfig(Entity):
                            """
                            Obtain address using autoconfiguration
                            
                            .. attribute:: default
                            
                            	Insert default route
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Ipv6.Address.Autoconfig, self).__init__()

                                self.yang_name = "autoconfig"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ])
                                self.default = None
                                self._segment_path = lambda: "autoconfig"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Ipv6.Address.Autoconfig, [u'default'], name, value)


                        class PrefixList(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: anycast
                            
                            	Configure as an anycast
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: eui_64
                            
                            	Use eui\-64 interface identifier
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Ipv6.Address.PrefixList, self).__init__()

                                self.yang_name = "prefix-list"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                    ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                                ])
                                self.prefix = None
                                self.anycast = None
                                self.eui_64 = None
                                self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                        class LinkLocalAddress(Entity):
                            """
                            
                            
                            .. attribute:: address  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: link_local
                            
                            	Use link\-local address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Ipv6.Address.LinkLocalAddress, self).__init__()

                                self.yang_name = "link-local-address"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                                ])
                                self.address = None
                                self.link_local = None
                                self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                    class Nd(Entity):
                        """
                        IPv6 interface Neighbor Discovery subcommands
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Ipv6.Nd, self).__init__()

                            self.yang_name = "nd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "nd"
                            self._is_frozen = True


                    class Tcp(Entity):
                        """
                        TCP header compression and other parameters
                        
                        .. attribute:: adjust_mss
                        
                        	Adjust the mss of transit packets
                        	**type**\: int
                        
                        	**range:** 40..1454
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Ipv6.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                            ])
                            self.adjust_mss = None
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Ipv6.Tcp, [u'adjust_mss'], name, value)


                    class TrafficFilter(Entity):
                        """
                        Access control list for packets
                        
                        .. attribute:: direction  (key)
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Ipv6.TrafficFilter.Direction>`
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Ipv6.TrafficFilter, self).__init__()

                            self.yang_name = "traffic-filter"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['direction']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Ipv6.TrafficFilter.Direction')])),
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                            ])
                            self.direction = None
                            self.access_list = None
                            self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: in_ = 0

                            .. data:: out = 1

                            """

                            in_ = Enum.YLeaf(0, "in")

                            out = Enum.YLeaf(1, "out")



                class Logging(Entity):
                    """
                    Configure logging for interface
                    
                    .. attribute:: event
                    
                    	Interface events
                    	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Logging.Event>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Logging, self).__init__()

                        self.yang_name = "logging"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("event", ("event", Native.Interface.ATMSubinterface.ATM.Logging.Event))])
                        self._leafs = OrderedDict()

                        self.event = Native.Interface.ATMSubinterface.ATM.Logging.Event()
                        self.event.parent = self
                        self._children_name_map["event"] = "event"
                        self._segment_path = lambda: "logging"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Logging, [], name, value)


                    class Event(Entity):
                        """
                        Interface events
                        
                        .. attribute:: bundle_status
                        
                        	BUNDLE/UNBUNDLE messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: link_status
                        
                        	UPDOWN and CHANGE messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trunk_status
                        
                        	TRUNK status messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: nfas_status
                        
                        	NFAS D\-channel status messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: power_inline_status
                        
                        	Inline power messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: spanning_tree
                        
                        	Spanning\-tree Interface events
                        	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Logging.Event.SpanningTree>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: subif_link_status
                        
                        	Sub\-interface UPDOWN and CHANGE messages
                        	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Logging.Event.SubifLinkStatus>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Logging.Event, self).__init__()

                            self.yang_name = "event"
                            self.yang_parent_name = "logging"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.ATMSubinterface.ATM.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.ATMSubinterface.ATM.Logging.Event.SubifLinkStatus))])
                            self._leafs = OrderedDict([
                                ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                                ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                                ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                                ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.bundle_status = None
                            self.link_status = None
                            self.trunk_status = None
                            self.nfas_status = None
                            self.power_inline_status = None
                            self.status = None

                            self.spanning_tree = None
                            self._children_name_map["spanning_tree"] = "spanning-tree"

                            self.subif_link_status = None
                            self._children_name_map["subif_link_status"] = "subif-link-status"
                            self._segment_path = lambda: "event"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                        class SpanningTree(Entity):
                            """
                            Spanning\-tree Interface events
                            
                            .. attribute:: status
                            
                            	Spanning\-tree state change messages
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Logging.Event.SpanningTree, self).__init__()

                                self.yang_name = "spanning-tree"
                                self.yang_parent_name = "event"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                                ])
                                self.status = None
                                self._segment_path = lambda: "spanning-tree"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Logging.Event.SpanningTree, [u'status'], name, value)


                        class SubifLinkStatus(Entity):
                            """
                            Sub\-interface UPDOWN and CHANGE messages
                            
                            .. attribute:: ignore_bulk
                            
                            	Do not log messages when the main interface is transitioning
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Logging.Event.SubifLinkStatus, self).__init__()

                                self.yang_name = "subif-link-status"
                                self.yang_parent_name = "event"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                                ])
                                self.ignore_bulk = None
                                self._segment_path = lambda: "subif-link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


                class Mdix(Entity):
                    """
                    Set Media Dependent Interface with Crossover
                    
                    .. attribute:: auto
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Mdix, self).__init__()

                        self.yang_name = "mdix"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "mdix"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Mdix, [u'auto'], name, value)


                class Mop(Entity):
                    """
                    
                    
                    .. attribute:: enabled
                    
                    	
                    	**type**\: bool
                    
                    .. attribute:: sysid
                    
                    	Send out MOP periodic system ID messages
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Mop, self).__init__()

                        self.yang_name = "mop"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                            ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                        ])
                        self.enabled = None
                        self.sysid = None
                        self._segment_path = lambda: "mop"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Mop, [u'enabled', u'sysid'], name, value)


                class InterfaceQos(Entity):
                    """
                    
                    
                    .. attribute:: trust
                    
                    	
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.InterfaceQos.Trust>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.InterfaceQos, self).__init__()

                        self.yang_name = "interface_qos"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.ATMSubinterface.ATM.InterfaceQos.Trust))])
                        self._leafs = OrderedDict()

                        self.trust = Native.Interface.ATMSubinterface.ATM.InterfaceQos.Trust()
                        self.trust.parent = self
                        self._children_name_map["trust"] = "trust"
                        self._segment_path = lambda: "interface_qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.InterfaceQos, [], name, value)


                    class Trust(Entity):
                        """
                        
                        
                        .. attribute:: device
                        
                        	
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.InterfaceQos.Trust.Device>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.InterfaceQos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "interface_qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.InterfaceQos.Trust.Device')])),
                            ])
                            self.device = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.InterfaceQos.Trust, [u'device'], name, value)

                        class Device(Enum):
                            """
                            Device (Enum Class)

                            .. data:: cisco_phone = 0

                            """

                            cisco_phone = Enum.YLeaf(0, "cisco-phone")



                class Source(Entity):
                    """
                    Get config from another source
                    
                    .. attribute:: template
                    
                    	Get config from a template
                    	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Source.Template>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Source, self).__init__()

                        self.yang_name = "source"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template", ("template", Native.Interface.ATMSubinterface.ATM.Source.Template))])
                        self._leafs = OrderedDict()

                        self.template = Native.Interface.ATMSubinterface.ATM.Source.Template()
                        self.template.parent = self
                        self._children_name_map["template"] = "template"
                        self._segment_path = lambda: "source"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Source, [], name, value)


                    class Template(Entity):
                        """
                        Get config from a template
                        
                        .. attribute:: template_name
                        
                        	
                        	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Source.Template.TemplateName>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Source.Template, self).__init__()

                            self.yang_name = "template"
                            self.yang_parent_name = "source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.ATMSubinterface.ATM.Source.Template.TemplateName))])
                            self._leafs = OrderedDict()

                            self.template_name = YList(self)
                            self._segment_path = lambda: "template"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Source.Template, [], name, value)


                        class TemplateName(Entity):
                            """
                            
                            
                            .. attribute:: template_name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: merge
                            
                            	merge option of binding
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Source.Template.TemplateName, self).__init__()

                                self.yang_name = "template-name"
                                self.yang_parent_name = "template"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['template_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                    ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                                ])
                                self.template_name = None
                                self.merge = None
                                self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


                class Standby(Entity):
                    """
                    HSRP interface configuration commands
                    
                    .. attribute:: version
                    
                    	HSRP version
                    	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.Version>`
                    
                    .. attribute:: bfd
                    
                    	Enable HSRP BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: delay
                    
                    	HSRP initialisation delay
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.Delay>`
                    
                    .. attribute:: mac_refresh
                    
                    	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: use_bia
                    
                    	HSRP uses interface's burned in address
                    	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.UseBia>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: standby_list
                    
                    	
                    	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Standby, self).__init__()

                        self.yang_name = "standby"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.ATMSubinterface.ATM.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.ATMSubinterface.ATM.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Standby.Version')])),
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                        ])
                        self.version = None
                        self.bfd = None
                        self.mac_refresh = None

                        self.delay = Native.Interface.ATMSubinterface.ATM.Standby.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"

                        self.use_bia = None
                        self._children_name_map["use_bia"] = "use-bia"

                        self.standby_list = YList(self)
                        self._segment_path = lambda: "standby"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                    class Version(Enum):
                        """
                        Version (Enum Class)

                        HSRP version

                        .. data:: Y_1 = 0

                        .. data:: Y_2 = 1

                        """

                        Y_1 = Enum.YLeaf(0, "1")

                        Y_2 = Enum.YLeaf(1, "2")



                    class Delay(Entity):
                        """
                        HSRP initialisation delay
                        
                        .. attribute:: minimum
                        
                        	Minimum delay
                        	**type**\: int
                        
                        	**range:** 0..10000
                        
                        .. attribute:: reload
                        
                        	Delay after reload
                        	**type**\: int
                        
                        	**range:** 0..10000
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Standby.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "standby"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                            ])
                            self.minimum = None
                            self.reload = None
                            self._segment_path = lambda: "delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.Delay, [u'minimum', u'reload'], name, value)


                    class UseBia(Entity):
                        """
                        HSRP uses interface's burned in address
                        
                        .. attribute:: scope
                        
                        	Specify the scope of use\-bia
                        	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.UseBia.Scope>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Standby.UseBia, self).__init__()

                            self.yang_name = "use-bia"
                            self.yang_parent_name = "standby"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.ATMSubinterface.ATM.Standby.UseBia.Scope))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.scope = Native.Interface.ATMSubinterface.ATM.Standby.UseBia.Scope()
                            self.scope.parent = self
                            self._children_name_map["scope"] = "scope"
                            self._segment_path = lambda: "use-bia"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.UseBia, [], name, value)


                        class Scope(Entity):
                            """
                            Specify the scope of use\-bia
                            
                            .. attribute:: interface
                            
                            	Use\-bia applies to all groups on this interface or sub\-interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Standby.UseBia.Scope, self).__init__()

                                self.yang_name = "scope"
                                self.yang_parent_name = "use-bia"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                                ])
                                self.interface = None
                                self._segment_path = lambda: "scope"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.UseBia.Scope, [u'interface'], name, value)


                    class StandbyList(Entity):
                        """
                        
                        
                        .. attribute:: group_number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: authentication
                        
                        	Authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication>`
                        
                        .. attribute:: follow
                        
                        	Name of HSRP group to follow
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	Enable HSRP and set the virtual IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Ip>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	Enable HSRP IPv6
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                        
                        .. attribute:: mac_address
                        
                        	Virtual MAC address
                        	**type**\: str
                        
                        .. attribute:: name
                        
                        	Redundancy name string
                        	**type**\: str
                        
                        .. attribute:: preempt
                        
                        	Overthrow lower priority Active routers
                        	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Preempt>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Priority level
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: redirect
                        
                        	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect>`
                        
                        .. attribute:: timers
                        
                        	Hello and hold timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers>`
                        
                        .. attribute:: track
                        
                        	Priority tracking
                        	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Track>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList, self).__init__()

                            self.yang_name = "standby-list"
                            self.yang_parent_name = "standby"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['group_number']
                            self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Track))])
                            self._leafs = OrderedDict([
                                ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                                ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.group_number = None
                            self.follow = None
                            self.ipv6 = None
                            self.mac_address = None
                            self.name = None
                            self.priority = None

                            self.authentication = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.ip = None
                            self._children_name_map["ip"] = "ip"

                            self.preempt = None
                            self._children_name_map["preempt"] = "preempt"

                            self.redirect = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"

                            self.timers = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"

                            self.track = YList(self)
                            self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                        class Ipv6(Enum):
                            """
                            Ipv6 (Enum Class)

                            Enable HSRP IPv6

                            .. data:: autoconfig = 0

                            """

                            autoconfig = Enum.YLeaf(0, "autoconfig")



                        class Authentication(Entity):
                            """
                            Authentication
                            
                            .. attribute:: word
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5>`
                            
                            .. attribute:: text
                            
                            	Plain text authentication
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                ])
                                self.word = None
                                self.text = None

                                self.md5 = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_chain
                                
                                	Set key chain
                                	**type**\: str
                                
                                .. attribute:: key_string
                                
                                	Set key string
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "authentication"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5.KeyString))])
                                    self._leafs = OrderedDict([
                                        ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ])
                                    self.key_chain = None

                                    self.key_string = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                                class KeyString(Entity):
                                    """
                                    Set key string
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: timeout
                                    
                                    	Set timeout
                                    	**type**\: int
                                    
                                    	**range:** 0..32767
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self.timeout = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                        class Ip(Entity):
                            """
                            Enable HSRP and set the virtual IP address
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	Make this IP address a secondary virtual IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.address = None
                                self.secondary = None
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                        class Preempt(Entity):
                            """
                            Overthrow lower priority Active routers
                            
                            .. attribute:: delay
                            
                            	Wait before preempting
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Preempt.Delay>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Preempt, self).__init__()

                                self.yang_name = "preempt"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Preempt.Delay))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.delay = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Preempt.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "preempt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Preempt, [], name, value)


                            class Delay(Entity):
                                """
                                Wait before preempting
                                
                                .. attribute:: minimum
                                
                                	Delay at least this long
                                	**type**\: int
                                
                                	**range:** 0..3600
                                
                                .. attribute:: reload
                                
                                	Delay after reload
                                	**type**\: int
                                
                                	**range:** 0..3600
                                
                                .. attribute:: sync
                                
                                	Wait for IP redundancy client
                                	**type**\: int
                                
                                	**range:** 0..3600
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Preempt.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "preempt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                        ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                    ])
                                    self.minimum = None
                                    self.reload = None
                                    self.sync = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                        class Redirect(Entity):
                            """
                            Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                            
                            .. attribute:: advertisement
                            
                            	Redirect advertisement messages
                            	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement>`
                            
                            .. attribute:: timers
                            
                            	Adjust redirect timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Timers>`
                            
                            .. attribute:: unknown
                            
                            	Redirect to non\-HSRP routers
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Timers))])
                                self._leafs = OrderedDict([
                                    ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                                ])
                                self.unknown = None

                                self.advertisement = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement()
                                self.advertisement.parent = self
                                self._children_name_map["advertisement"] = "advertisement"

                                self.timers = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                            class Advertisement(Entity):
                                """
                                Redirect advertisement messages
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                    self.yang_name = "advertisement"
                                    self.yang_parent_name = "redirect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                    self._leafs = OrderedDict()

                                    self.authentication = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._segment_path = lambda: "advertisement"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: md5
                                    
                                    	Use MD5 authentication
                                    	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "advertisement"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                        self._leafs = OrderedDict()

                                        self.md5 = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                        self.md5.parent = self
                                        self._children_name_map["md5"] = "md5"
                                        self._segment_path = lambda: "authentication"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                    class Md5(Entity):
                                        """
                                        Use MD5 authentication
                                        
                                        .. attribute:: key_chain
                                        
                                        	Set key chain
                                        	**type**\: str
                                        
                                        .. attribute:: key_string
                                        
                                        	Set key string
                                        	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                            self.yang_name = "md5"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                            self._leafs = OrderedDict([
                                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                            ])
                                            self.key_chain = None

                                            self.key_string = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                            self.key_string.parent = self
                                            self._children_name_map["key_string"] = "key-string"
                                            self._segment_path = lambda: "md5"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                        class KeyString(Entity):
                                            """
                                            Set key string
                                            
                                            .. attribute:: encrypt
                                            
                                            	
                                            	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                            
                                            .. attribute:: string
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: timeout
                                            
                                            	Set timeout
                                            	**type**\: int
                                            
                                            	**range:** 0..32767
                                            
                                            

                                            """

                                            _prefix = 'ios'
                                            _revision = '2018-05-22'

                                            def __init__(self):
                                                super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                                self.yang_name = "key-string"
                                                self.yang_parent_name = "md5"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                    ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                                ])
                                                self.encrypt = None
                                                self.string = None
                                                self.timeout = None
                                                self._segment_path = lambda: "key-string"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                            class Encrypt(Enum):
                                                """
                                                Encrypt (Enum Class)

                                                .. data:: Y_0 = 0

                                                .. data:: Y_7 = 1

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")

                                                Y_7 = Enum.YLeaf(1, "7")



                            class Timers(Entity):
                                """
                                Adjust redirect timers
                                
                                .. attribute:: advertisement
                                
                                	
                                	**type**\: int
                                
                                	**range:** 10..180
                                
                                .. attribute:: holddown
                                
                                	
                                	**type**\: int
                                
                                	**range:** 30..3600
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "redirect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                        ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                    ])
                                    self.advertisement = None
                                    self.holddown = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                        class Timers(Entity):
                            """
                            Hello and hold timers
                            
                            .. attribute:: hello_interval
                            
                            	
                            	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers.HelloInterval>`
                            
                            .. attribute:: hold_time
                            
                            	
                            	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers.HoldTime>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers.HoldTime))])
                                self._leafs = OrderedDict()

                                self.hello_interval = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers.HelloInterval()
                                self.hello_interval.parent = self
                                self._children_name_map["hello_interval"] = "hello-interval"

                                self.hold_time = Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers.HoldTime()
                                self.hold_time.parent = self
                                self._children_name_map["hold_time"] = "hold-time"
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers, [], name, value)


                            class HelloInterval(Entity):
                                """
                                
                                
                                .. attribute:: seconds
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: msec
                                
                                	Specify hello interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 15..999
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                    self.yang_name = "hello-interval"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.msec = None
                                    self._segment_path = lambda: "hello-interval"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                            class HoldTime(Entity):
                                """
                                
                                
                                .. attribute:: seconds
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: msec
                                
                                	Specify hold time in milliseconds
                                	**type**\: int
                                
                                	**range:** 50..3000
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                    self.yang_name = "hold-time"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.msec = None
                                    self._segment_path = lambda: "hold-time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                        class Track(Entity):
                            """
                            Priority tracking
                            
                            .. attribute:: number  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: decrement
                            
                            	Priority decrement
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: shutdown
                            
                            	Shutdown group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Track, self).__init__()

                                self.yang_name = "track"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['number']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                    ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.number = None
                                self.decrement = None
                                self.shutdown = None
                                self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


                class AccessSession(Entity):
                    """
                    Access Session specific Interface Configuration Commands
                    
                    .. attribute:: closed
                    
                    	Enable closed access on port (disabled by default, i.e. open access)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: port_control
                    
                    	Set the port\-control value
                    	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.AccessSession.PortControl>`
                    
                    .. attribute:: control_direction
                    
                    	Set the control\-direction on the interface
                    	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.AccessSession.ControlDirection>`
                    
                    .. attribute:: host_mode
                    
                    	Set the Host mode for authentication on this interface
                    	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.AccessSession.HostMode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.AccessSession, self).__init__()

                        self.yang_name = "access-session"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.ATMSubinterface.ATM.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.ATMSubinterface.ATM.AccessSession.ControlDirection))])
                        self._leafs = OrderedDict([
                            ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                            ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.AccessSession.HostMode')])),
                        ])
                        self.closed = None
                        self.host_mode = None

                        self.port_control = Native.Interface.ATMSubinterface.ATM.AccessSession.PortControl()
                        self.port_control.parent = self
                        self._children_name_map["port_control"] = "port-control"

                        self.control_direction = Native.Interface.ATMSubinterface.ATM.AccessSession.ControlDirection()
                        self.control_direction.parent = self
                        self._children_name_map["control_direction"] = "control-direction"
                        self._segment_path = lambda: "access-session"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.AccessSession, [u'closed', u'host_mode'], name, value)

                    class HostMode(Enum):
                        """
                        HostMode (Enum Class)

                        Set the Host mode for authentication on this interface

                        .. data:: multi_auth = 0

                        .. data:: multi_domain = 1

                        .. data:: multi_host = 2

                        .. data:: single_host = 3

                        """

                        multi_auth = Enum.YLeaf(0, "multi-auth")

                        multi_domain = Enum.YLeaf(1, "multi-domain")

                        multi_host = Enum.YLeaf(2, "multi-host")

                        single_host = Enum.YLeaf(3, "single-host")



                    class PortControl(Entity):
                        """
                        Set the port\-control value
                        
                        .. attribute:: auto
                        
                        	PortState set to automatic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.AccessSession.PortControl, self).__init__()

                            self.yang_name = "port-control"
                            self.yang_parent_name = "access-session"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                            ])
                            self.auto = None
                            self._segment_path = lambda: "port-control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.AccessSession.PortControl, [u'auto'], name, value)


                    class ControlDirection(Entity):
                        """
                        Set the control\-direction on the interface
                        
                        .. attribute:: in_
                        
                        	Control inbound traffic only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.AccessSession.ControlDirection, self).__init__()

                            self.yang_name = "control-direction"
                            self.yang_parent_name = "access-session"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                            ])
                            self.in_ = None
                            self._segment_path = lambda: "control-direction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.AccessSession.ControlDirection, [u'in_'], name, value)


                class StormControl(Entity):
                    """
                    storm configuration
                    
                    .. attribute:: action
                    
                    	Action to take for storm..control;
                    	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Action>`
                    
                    .. attribute:: broadcast
                    
                    	Broadcast address storm control
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast>`
                    
                    .. attribute:: multicast
                    
                    	Multicast address storm control
                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Multicast>`
                    
                    .. attribute:: unicast
                    
                    	Unicast address storm control
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.StormControl, self).__init__()

                        self.yang_name = "storm-control"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("action", ("action", Native.Interface.ATMSubinterface.ATM.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.ATMSubinterface.ATM.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.ATMSubinterface.ATM.StormControl.Unicast))])
                        self._leafs = OrderedDict()

                        self.action = Native.Interface.ATMSubinterface.ATM.StormControl.Action()
                        self.action.parent = self
                        self._children_name_map["action"] = "action"

                        self.broadcast = Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"

                        self.multicast = Native.Interface.ATMSubinterface.ATM.StormControl.Multicast()
                        self.multicast.parent = self
                        self._children_name_map["multicast"] = "multicast"

                        self.unicast = Native.Interface.ATMSubinterface.ATM.StormControl.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "storm-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl, [], name, value)


                    class Action(Entity):
                        """
                        Action to take for storm..control;
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\: Decimal64
                        
                        	**range:** 0..100
                        
                        .. attribute:: shutdown
                        
                        	Shutdown this interface if a storm occurs
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trap
                        
                        	Send SNMP trap if a storm occurs
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.StormControl.Action, self).__init__()

                            self.yang_name = "action"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                            ])
                            self.level = None
                            self.shutdown = None
                            self.trap = None
                            self._segment_path = lambda: "action"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                    class Broadcast(Entity):
                        """
                        Broadcast address storm control
                        
                        .. attribute:: include
                        
                        	
                        	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Include>`
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("include", ("include", Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level))])
                            self._leafs = OrderedDict()

                            self.include = Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Include()
                            self.include.parent = self
                            self._children_name_map["include"] = "include"

                            self.level = Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level()
                            self.level.parent = self
                            self._children_name_map["level"] = "level"
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast, [], name, value)


                        class Include(Entity):
                            """
                            
                            
                            .. attribute:: multicast
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Include, self).__init__()

                                self.yang_name = "include"
                                self.yang_parent_name = "broadcast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ])
                                self.multicast = None
                                self._segment_path = lambda: "include"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Include, [u'multicast'], name, value)


                        class Level(Entity):
                            """
                            Set storm suppression level on this interface
                            
                            .. attribute:: threshold
                            
                            	Broadcast address storm control
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Threshold>`
                            
                            .. attribute:: bps
                            
                            	Enter suppression level in bits per second
                            	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Bps>`
                            
                            .. attribute:: pps
                            
                            	Enter suppression level in packets per second
                            	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Pps>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level, self).__init__()

                                self.yang_name = "level"
                                self.yang_parent_name = "broadcast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Pps))])
                                self._leafs = OrderedDict()

                                self.threshold = Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"

                                self.bps = Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Bps()
                                self.bps.parent = self
                                self._children_name_map["bps"] = "bps"

                                self.pps = Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Pps()
                                self.pps.parent = self
                                self._children_name_map["pps"] = "pps"
                                self._segment_path = lambda: "level"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level, [], name, value)


                            class Threshold(Entity):
                                """
                                Broadcast address storm control
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Bps(Entity):
                                """
                                Enter suppression level in bits per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Bps, self).__init__()

                                    self.yang_name = "bps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "bps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Pps(Entity):
                                """
                                Enter suppression level in packets per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Pps, self).__init__()

                                    self.yang_name = "pps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "pps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                    class Multicast(Entity):
                        """
                        Multicast address storm control
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.StormControl.Multicast, self).__init__()

                            self.yang_name = "multicast"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level", ("level", Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level))])
                            self._leafs = OrderedDict()

                            self.level = Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level()
                            self.level.parent = self
                            self._children_name_map["level"] = "level"
                            self._segment_path = lambda: "multicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Multicast, [], name, value)


                        class Level(Entity):
                            """
                            Set storm suppression level on this interface
                            
                            .. attribute:: threshold
                            
                            	Broadcast address storm control
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Threshold>`
                            
                            .. attribute:: bps
                            
                            	Enter suppression level in bits per second
                            	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Bps>`
                            
                            .. attribute:: pps
                            
                            	Enter suppression level in packets per second
                            	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Pps>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level, self).__init__()

                                self.yang_name = "level"
                                self.yang_parent_name = "multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Pps))])
                                self._leafs = OrderedDict()

                                self.threshold = Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"

                                self.bps = Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Bps()
                                self.bps.parent = self
                                self._children_name_map["bps"] = "bps"

                                self.pps = Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Pps()
                                self.pps.parent = self
                                self._children_name_map["pps"] = "pps"
                                self._segment_path = lambda: "level"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level, [], name, value)


                            class Threshold(Entity):
                                """
                                Broadcast address storm control
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Bps(Entity):
                                """
                                Enter suppression level in bits per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Bps, self).__init__()

                                    self.yang_name = "bps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "bps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Pps(Entity):
                                """
                                Enter suppression level in packets per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Pps, self).__init__()

                                    self.yang_name = "pps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "pps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                    class Unicast(Entity):
                        """
                        Unicast address storm control
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.StormControl.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level", ("level", Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level))])
                            self._leafs = OrderedDict()

                            self.level = Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level()
                            self.level.parent = self
                            self._children_name_map["level"] = "level"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Unicast, [], name, value)


                        class Level(Entity):
                            """
                            Set storm suppression level on this interface
                            
                            .. attribute:: threshold
                            
                            	Broadcast address storm control
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Threshold>`
                            
                            .. attribute:: bps
                            
                            	Enter suppression level in bits per second
                            	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Bps>`
                            
                            .. attribute:: pps
                            
                            	Enter suppression level in packets per second
                            	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Pps>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level, self).__init__()

                                self.yang_name = "level"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Pps))])
                                self._leafs = OrderedDict()

                                self.threshold = Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"

                                self.bps = Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Bps()
                                self.bps.parent = self
                                self._children_name_map["bps"] = "bps"

                                self.pps = Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Pps()
                                self.pps.parent = self
                                self._children_name_map["pps"] = "pps"
                                self._segment_path = lambda: "level"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level, [], name, value)


                            class Threshold(Entity):
                                """
                                Broadcast address storm control
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Bps(Entity):
                                """
                                Enter suppression level in bits per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Bps, self).__init__()

                                    self.yang_name = "bps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "bps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Pps(Entity):
                                """
                                Enter suppression level in packets per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Pps, self).__init__()

                                    self.yang_name = "pps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "pps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Trust(Entity):
                    """
                    Set trust value for the interface
                    
                    .. attribute:: device
                    
                    	trusted device class
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        trusted device class

                        .. data:: cisco_phone = 0

                        .. data:: cts = 1

                        .. data:: ip_camera = 2

                        .. data:: media_player = 3

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")

                        cts = Enum.YLeaf(1, "cts")

                        ip_camera = Enum.YLeaf(2, "ip-camera")

                        media_player = Enum.YLeaf(3, "media-player")



                class PriorityQueue(Entity):
                    """
                    Configure priority scheduling
                    
                    .. attribute:: cos_map
                    
                    	Configure cos\-map for a queue
                    	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.PriorityQueue.CosMap>`
                    
                    .. attribute:: out
                    
                    	egress priority queue
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.PriorityQueue, self).__init__()

                        self.yang_name = "priority-queue"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.ATMSubinterface.ATM.PriorityQueue.CosMap))])
                        self._leafs = OrderedDict([
                            ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ])
                        self.out = None

                        self.cos_map = Native.Interface.ATMSubinterface.ATM.PriorityQueue.CosMap()
                        self.cos_map.parent = self
                        self._children_name_map["cos_map"] = "cos-map"
                        self._segment_path = lambda: "priority-queue"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.PriorityQueue, [u'out'], name, value)


                    class CosMap(Entity):
                        """
                        Configure cos\-map for a queue
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: cos_values
                        
                        	
                        	**type**\: list of int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.PriorityQueue.CosMap, self).__init__()

                            self.yang_name = "cos-map"
                            self.yang_parent_name = "priority-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                            ])
                            self.id = None
                            self.cos_values = []
                            self._segment_path = lambda: "cos-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


                class RcvQueue(Entity):
                    """
                    Configure receive queue(s)
                    
                    .. attribute:: cos_map
                    
                    	Configure cos\-map for a queue threshold
                    	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.RcvQueue.CosMap>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.RcvQueue, self).__init__()

                        self.yang_name = "rcv-queue"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.ATMSubinterface.ATM.RcvQueue.CosMap))])
                        self._leafs = OrderedDict()

                        self.cos_map = YList(self)
                        self._segment_path = lambda: "rcv-queue"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.RcvQueue, [], name, value)


                    class CosMap(Entity):
                        """
                        Configure cos\-map for a queue threshold
                        
                        .. attribute:: queue_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: threshold_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8
                        
                        .. attribute:: cos_values
                        
                        	
                        	**type**\: list of int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.RcvQueue.CosMap, self).__init__()

                            self.yang_name = "cos-map"
                            self.yang_parent_name = "rcv-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['queue_id','threshold_id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                                ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                                ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                            ])
                            self.queue_id = None
                            self.threshold_id = None
                            self.cos_values = []
                            self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


                class Peer(Entity):
                    """
                    Peer parameters for point to point interfaces
                    
                    .. attribute:: default
                    
                    	Specify default parameters
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Peer.Default>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default", ("default", Native.Interface.ATMSubinterface.ATM.Peer.Default))])
                        self._leafs = OrderedDict()

                        self.default = Native.Interface.ATMSubinterface.ATM.Peer.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"
                        self._segment_path = lambda: "peer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Peer, [], name, value)


                    class Default(Entity):
                        """
                        Specify default parameters
                        
                        .. attribute:: ip
                        
                        	Specify default IP parameters
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Peer.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Peer.Default, [], name, value)


                        class Ip(Entity):
                            """
                            Specify default IP parameters
                            
                            .. attribute:: address
                            
                            	Specify default IP address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address))])
                                self._leafs = OrderedDict()

                                self.address = Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip, [], name, value)


                            class Address(Entity):
                                """
                                Specify default IP address
                                
                                .. attribute:: dhcp
                                
                                	Use DHCP proxy client mechanism to allocate a peer IP address
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: dhcp_pool
                                
                                	Use local DHCP pools to allocate a peer IP address
                                	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address.DhcpPool>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: pool
                                
                                	Use IP pool mechanism to allocate a peer IP address
                                	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address.Pool>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address.Pool))])
                                    self._leafs = OrderedDict([
                                        ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                    ])
                                    self.dhcp = None

                                    self.dhcp_pool = None
                                    self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                    self.pool = None
                                    self._children_name_map["pool"] = "pool"
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                                class DhcpPool(Entity):
                                    """
                                    Use local DHCP pools to allocate a peer IP address
                                    
                                    .. attribute:: pools
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                        self.yang_name = "dhcp-pool"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                        ])
                                        self.pools = None
                                        self._segment_path = lambda: "dhcp-pool"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                                class Pool(Entity):
                                    """
                                    Use IP pool mechanism to allocate a peer IP address
                                    
                                    .. attribute:: pools
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address.Pool, self).__init__()

                                        self.yang_name = "pool"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                        ])
                                        self.pools = None
                                        self._segment_path = lambda: "pool"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


                class PmPath(Entity):
                    """
                    Global pm\-path configuration
                    
                    .. attribute:: name
                    
                    	WORD Path name
                    	**type**\: str
                    
                    .. attribute:: interface_id
                    
                    	<1\-255> Specify the interface\-id value
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.PmPath, self).__init__()

                        self.yang_name = "pm-path"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                        ])
                        self.name = None
                        self.interface_id = None
                        self._segment_path = lambda: "pm-path"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.PmPath, [u'name', u'interface_id'], name, value)


                class CiscoIOSXEAtmIp(Entity):
                    """
                    IP address
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: split_horizon
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEAtmIp, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('split_horizon', (YLeaf(YType.empty, 'split-horizon'), ['Empty'])),
                        ])
                        self.address = None
                        self.split_horizon = None
                        self._segment_path = lambda: "Cisco-IOS-XE-atm:ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.CiscoIOSXEAtmIp, ['address', 'split_horizon'], name, value)


                class Atm(Entity):
                    """
                    ATM
                    
                    .. attribute:: bandwidth
                    
                    	ATM bandwith
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Bandwidth>`
                    
                    .. attribute:: enable_ilmi_trap
                    
                    	Enable\-ilmi\-trap
                    	**type**\: bool
                    
                    .. attribute:: ilmi_keepalive
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: route_bridged
                    
                    	
                    	**type**\:  :py:class:`RouteBridged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.RouteBridged>`
                    
                    .. attribute:: pvp
                    
                    	PVP
                    	**type**\: list of  		 :py:class:`Pvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Pvp>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Atm, self).__init__()

                        self.yang_name = "atm"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("pvp", ("pvp", Native.Interface.ATMSubinterface.ATM.Atm.Pvp))])
                        self._leafs = OrderedDict([
                            ('bandwidth', (YLeaf(YType.enumeration, 'bandwidth'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Atm.Bandwidth')])),
                            ('enable_ilmi_trap', (YLeaf(YType.boolean, 'enable-ilmi-trap'), ['bool'])),
                            ('ilmi_keepalive', (YLeaf(YType.empty, 'ilmi-keepalive'), ['Empty'])),
                            ('route_bridged', (YLeaf(YType.enumeration, 'route-bridged'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Atm.RouteBridged')])),
                        ])
                        self.bandwidth = None
                        self.enable_ilmi_trap = None
                        self.ilmi_keepalive = None
                        self.route_bridged = None

                        self.pvp = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-atm:atm"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Atm, ['bandwidth', 'enable_ilmi_trap', 'ilmi_keepalive', 'route_bridged'], name, value)

                    class Bandwidth(Enum):
                        """
                        Bandwidth (Enum Class)

                        ATM bandwith

                        .. data:: dynamic = 0

                        """

                        dynamic = Enum.YLeaf(0, "dynamic")


                    class RouteBridged(Enum):
                        """
                        RouteBridged (Enum Class)

                        .. data:: ip = 0

                        .. data:: ipv6 = 1

                        """

                        ip = Enum.YLeaf(0, "ip")

                        ipv6 = Enum.YLeaf(1, "ipv6")



                    class Pvp(Entity):
                        """
                        PVP
                        
                        .. attribute:: pvp_number  (key)
                        
                        	PVP number
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: l2transport
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: xconnect
                        
                        	
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect>`
                        
                        .. attribute:: xconnect_pw_class
                        
                        	
                        	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Atm.Pvp, self).__init__()

                            self.yang_name = "pvp"
                            self.yang_parent_name = "atm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['pvp_number']
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass))])
                            self._leafs = OrderedDict([
                                ('pvp_number', (YLeaf(YType.uint16, 'pvp-number'), ['int'])),
                                ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                            ])
                            self.pvp_number = None
                            self.l2transport = None

                            self.xconnect = Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"

                            self.xconnect_pw_class = Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass()
                            self.xconnect_pw_class.parent = self
                            self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                            self._segment_path = lambda: "pvp" + "[pvp-number='" + str(self.pvp_number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Atm.Pvp, ['pvp_number', 'l2transport'], name, value)


                        class Xconnect(Entity):
                            """
                            
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: encapsulation
                            
                            	Data encapsulation method
                            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Encapsulation>`
                            
                            .. attribute:: manual
                            
                            	Manually configure L2TP session parameters
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: pw_class
                            
                            	Optional pseudowire\-class to use for advanced configuration
                            	**type**\: str
                            
                            .. attribute:: sequencing
                            
                            	Configure sequencing options for xconnect
                            	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Sequencing>`
                            
                            .. attribute:: backup
                            
                            	Xconnect backup configuration commands
                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup>`
                            
                            .. attribute:: mtu
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "pvp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Encapsulation')])),
                                    ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Sequencing')])),
                                    ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.encapsulation = None
                                self.manual = None
                                self.pw_class = None
                                self.sequencing = None
                                self.mtu = None

                                self.backup = Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup()
                                self.backup.parent = self
                                self._children_name_map["backup"] = "backup"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                            class Encapsulation(Enum):
                                """
                                Encapsulation (Enum Class)

                                Data encapsulation method

                                .. data:: mpls = 0

                                .. data:: l2tpv3 = 1

                                """

                                mpls = Enum.YLeaf(0, "mpls")

                                l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                            class Sequencing(Enum):
                                """
                                Sequencing (Enum Class)

                                Configure sequencing options for xconnect

                                .. data:: both = 0

                                .. data:: receive = 1

                                .. data:: transmit = 2

                                """

                                both = Enum.YLeaf(0, "both")

                                receive = Enum.YLeaf(1, "receive")

                                transmit = Enum.YLeaf(2, "transmit")



                            class Backup(Entity):
                                """
                                Xconnect backup configuration commands
                                
                                .. attribute:: peer
                                
                                	Backup pseudowire
                                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup.Peer>`
                                
                                .. attribute:: delay
                                
                                	backup delay time
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup.Delay>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup, self).__init__()

                                    self.yang_name = "backup"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup.Delay))])
                                    self._leafs = OrderedDict()

                                    self.peer = Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup.Peer()
                                    self.peer.parent = self
                                    self._children_name_map["peer"] = "peer"

                                    self.delay = Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "backup"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup, [], name, value)


                                class Peer(Entity):
                                    """
                                    Backup pseudowire
                                    
                                    .. attribute:: peer_router_ip_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: vcid
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: pw_class
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: priority
                                    
                                    	Optional priority to use for backup pseudowire
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup.Peer, self).__init__()

                                        self.yang_name = "peer"
                                        self.yang_parent_name = "backup"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                            ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                            ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                        ])
                                        self.peer_router_ip_addr = None
                                        self.vcid = None
                                        self.pw_class = None
                                        self.priority = None
                                        self._segment_path = lambda: "peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                                class Delay(Entity):
                                    """
                                    backup delay time
                                    
                                    .. attribute:: min
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "backup"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                            ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                        ])
                                        self.min = None
                                        self.max = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                        class XconnectPwClass(Entity):
                            """
                            
                            
                            .. attribute:: xconnect
                            
                            	Xconnect commands
                            	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass, self).__init__()

                                self.yang_name = "xconnect-pw-class"
                                self.yang_parent_name = "pvp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect))])
                                self._leafs = OrderedDict()

                                self.xconnect = Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect()
                                self.xconnect.parent = self
                                self._children_name_map["xconnect"] = "xconnect"
                                self._segment_path = lambda: "xconnect-pw-class"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass, [], name, value)


                            class Xconnect(Entity):
                                """
                                Xconnect commands
                                
                                .. attribute:: address
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	Pseudowire\-class to use for encapsulation and protocol configuration
                                	**type**\: str
                                
                                .. attribute:: udp
                                
                                	UDP
                                	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect, self).__init__()

                                    self.yang_name = "xconnect"
                                    self.yang_parent_name = "xconnect-pw-class"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp))])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ])
                                    self.address = None
                                    self.vcid = None
                                    self.pw_class = None

                                    self.udp = Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp()
                                    self.udp.parent = self
                                    self._children_name_map["udp"] = "udp"
                                    self._segment_path = lambda: "xconnect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                                class Udp(Entity):
                                    """
                                    UDP
                                    
                                    .. attribute:: port
                                    
                                    	UDP ports
                                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port>`
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp, self).__init__()

                                        self.yang_name = "udp"
                                        self.yang_parent_name = "xconnect"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port))])
                                        self._leafs = OrderedDict()

                                        self.port = Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port()
                                        self.port.parent = self
                                        self._children_name_map["port"] = "port"
                                        self._segment_path = lambda: "udp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp, [], name, value)


                                    class Port(Entity):
                                        """
                                        UDP ports
                                        
                                        .. attribute:: local
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-atm'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                            self.yang_name = "port"
                                            self.yang_parent_name = "udp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                                ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                            ])
                                            self.local = None
                                            self.remote = None
                                            self._segment_path = lambda: "port"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


                class Cem(Entity):
                    """
                    CEM
                    
                    .. attribute:: number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cem.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Cem, self).__init__()

                        self.yang_name = "cem"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['number']
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMSubinterface.ATM.Cem.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                        ])
                        self.number = None

                        self.xconnect = Native.Interface.ATMSubinterface.ATM.Cem.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"

                        self.xconnect_pw_class = Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                        self._segment_path = lambda: "Cisco-IOS-XE-atm:cem" + "[number='" + str(self.number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Cem, ['number'], name, value)


                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Cem.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "cem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Cem.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Cem.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Cem.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Cem.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "cem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Cem.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


                class Pvc(Entity):
                    """
                    PVC
                    
                    .. attribute:: local_vpi_vci  (key)
                    
                    	Vpi and vci
                    	**type**\: str
                    
                    .. attribute:: remote_vpi_vci
                    
                    	Vpi and vci
                    	**type**\: str
                    
                    .. attribute:: l2transport
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ubr
                    
                    	UBR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ubrplus
                    
                    	
                    	**type**\:  :py:class:`Ubrplus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Ubrplus>`
                    
                    .. attribute:: cbr
                    
                    	CBR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vbr
                    
                    	VBR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vbr_rt
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vbr_nrt
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: oam_pvc
                    
                    	
                    	**type**\:  :py:class:`OamPvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.OamPvc>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: service_policy
                    
                    	
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.ServicePolicy>`
                    
                    .. attribute:: encapsulation
                    
                    	
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMSubinterface.ATM.Pvc, self).__init__()

                        self.yang_name = "pvc"
                        self.yang_parent_name = "ATM"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['local_vpi_vci']
                        self._child_classes = OrderedDict([("ubrplus", ("ubrplus", Native.Interface.ATMSubinterface.ATM.Pvc.Ubrplus)), ("oam-pvc", ("oam_pvc", Native.Interface.ATMSubinterface.ATM.Pvc.OamPvc)), ("service-policy", ("service_policy", Native.Interface.ATMSubinterface.ATM.Pvc.ServicePolicy)), ("encapsulation", ("encapsulation", Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation)), ("xconnect", ("xconnect", Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('local_vpi_vci', (YLeaf(YType.str, 'local-vpi-vci'), ['str'])),
                            ('remote_vpi_vci', (YLeaf(YType.str, 'remote-vpi-vci'), ['str'])),
                            ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                            ('ubr', (YLeaf(YType.uint32, 'ubr'), ['int'])),
                            ('cbr', (YLeaf(YType.uint32, 'cbr'), ['int'])),
                            ('vbr', (YLeaf(YType.uint32, 'vbr'), ['int'])),
                            ('vbr_rt', (YLeaf(YType.uint32, 'vbr-rt'), ['int'])),
                            ('vbr_nrt', (YLeaf(YType.uint32, 'vbr-nrt'), ['int'])),
                        ])
                        self.local_vpi_vci = None
                        self.remote_vpi_vci = None
                        self.l2transport = None
                        self.ubr = None
                        self.cbr = None
                        self.vbr = None
                        self.vbr_rt = None
                        self.vbr_nrt = None

                        self.ubrplus = Native.Interface.ATMSubinterface.ATM.Pvc.Ubrplus()
                        self.ubrplus.parent = self
                        self._children_name_map["ubrplus"] = "ubrplus"

                        self.oam_pvc = None
                        self._children_name_map["oam_pvc"] = "oam-pvc"

                        self.service_policy = Native.Interface.ATMSubinterface.ATM.Pvc.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.encapsulation = Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.xconnect = Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"

                        self.xconnect_pw_class = Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                        self._segment_path = lambda: "Cisco-IOS-XE-atm:pvc" + "[local-vpi-vci='" + str(self.local_vpi_vci) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc, ['local_vpi_vci', 'remote_vpi_vci', 'l2transport', 'ubr', 'cbr', 'vbr', 'vbr_rt', 'vbr_nrt'], name, value)


                    class Ubrplus(Entity):
                        """
                        
                        
                        .. attribute:: pcr
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mcr
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Pvc.Ubrplus, self).__init__()

                            self.yang_name = "ubrplus"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('pcr', (YLeaf(YType.uint32, 'PCR'), ['int'])),
                                ('mcr', (YLeaf(YType.uint32, 'MCR'), ['int'])),
                            ])
                            self.pcr = None
                            self.mcr = None
                            self._segment_path = lambda: "ubrplus"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.Ubrplus, ['pcr', 'mcr'], name, value)


                    class OamPvc(Entity):
                        """
                        
                        
                        .. attribute:: loopback_frequency
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..600
                        
                        .. attribute:: manage
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Pvc.OamPvc, self).__init__()

                            self.yang_name = "oam-pvc"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('loopback_frequency', (YLeaf(YType.uint32, 'loopback-frequency'), ['int'])),
                                ('manage', (YLeaf(YType.empty, 'manage'), ['Empty'])),
                            ])
                            self.loopback_frequency = None
                            self.manage = None
                            self._segment_path = lambda: "oam-pvc"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.OamPvc, ['loopback_frequency', 'manage'], name, value)


                    class ServicePolicy(Entity):
                        """
                        
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\: str
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Pvc.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.str, 'input'), ['str'])),
                                ('output', (YLeaf(YType.str, 'output'), ['str'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.ServicePolicy, ['input', 'output'], name, value)


                    class Encapsulation(Entity):
                        """
                        
                        
                        .. attribute:: aal5autoppp
                        
                        	
                        	**type**\:  :py:class:`Aal5autoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5autoppp>`
                        
                        .. attribute:: aal5ciscoppp
                        
                        	
                        	**type**\:  :py:class:`Aal5ciscoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5ciscoppp>`
                        
                        .. attribute:: aal5mux
                        
                        	
                        	**type**\:  :py:class:`Aal5mux <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5mux>`
                        
                        .. attribute:: aal5nlpid
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: aal5snap
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("aal5autoppp", ("aal5autoppp", Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5autoppp)), ("aal5ciscoppp", ("aal5ciscoppp", Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5ciscoppp)), ("aal5mux", ("aal5mux", Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5mux))])
                            self._leafs = OrderedDict([
                                ('aal5nlpid', (YLeaf(YType.empty, 'aal5nlpid'), ['Empty'])),
                                ('aal5snap', (YLeaf(YType.empty, 'aal5snap'), ['Empty'])),
                            ])
                            self.aal5nlpid = None
                            self.aal5snap = None

                            self.aal5autoppp = Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5autoppp()
                            self.aal5autoppp.parent = self
                            self._children_name_map["aal5autoppp"] = "aal5autoppp"

                            self.aal5ciscoppp = Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5ciscoppp()
                            self.aal5ciscoppp.parent = self
                            self._children_name_map["aal5ciscoppp"] = "aal5ciscoppp"

                            self.aal5mux = Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5mux()
                            self.aal5mux.parent = self
                            self._children_name_map["aal5mux"] = "aal5mux"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation, ['aal5nlpid', 'aal5snap'], name, value)


                        class Aal5autoppp(Entity):
                            """
                            
                            
                            .. attribute:: virtual_template
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5autoppp, self).__init__()

                                self.yang_name = "aal5autoppp"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                                ])
                                self.virtual_template = None
                                self._segment_path = lambda: "aal5autoppp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5autoppp, ['virtual_template'], name, value)


                        class Aal5ciscoppp(Entity):
                            """
                            
                            
                            .. attribute:: virtual_template
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5ciscoppp, self).__init__()

                                self.yang_name = "aal5ciscoppp"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                                ])
                                self.virtual_template = None
                                self._segment_path = lambda: "aal5ciscoppp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5ciscoppp, ['virtual_template'], name, value)


                        class Aal5mux(Entity):
                            """
                            
                            
                            .. attribute:: ppp
                            
                            	
                            	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5mux.Ppp>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5mux, self).__init__()

                                self.yang_name = "aal5mux"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ppp", ("ppp", Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5mux.Ppp))])
                                self._leafs = OrderedDict()

                                self.ppp = Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5mux.Ppp()
                                self.ppp.parent = self
                                self._children_name_map["ppp"] = "ppp"
                                self._segment_path = lambda: "aal5mux"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5mux, [], name, value)


                            class Ppp(Entity):
                                """
                                
                                
                                .. attribute:: virtual_template
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dialer
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5mux.Ppp, self).__init__()

                                    self.yang_name = "ppp"
                                    self.yang_parent_name = "aal5mux"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                                        ('dialer', (YLeaf(YType.empty, 'dialer'), ['Empty'])),
                                    ])
                                    self.virtual_template = None
                                    self.dialer = None
                                    self._segment_path = lambda: "ppp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.Encapsulation.Aal5mux.Ppp, ['virtual_template', 'dialer'], name, value)


                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Pvc.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMSubinterface.ATM.Pvc.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMSubinterface.ATM.Pvc.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class ServicePolicy(Entity):
                """
                
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.ATMSubinterface.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "ATM-subinterface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.input = None
                    self.output = None
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/ATM-subinterface/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATMSubinterface.ServicePolicy, ['input', 'output'], name, value)


        class ATMACR(Entity):
            """
            ATM\-ACR interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            	**pattern:** [0\-9]
            
            .. attribute:: ip
            
            	IP address
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Ip>`
            
            .. attribute:: atm
            
            	ATM
            	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm>`
            
            .. attribute:: load_interval
            
            	Load interval
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: cdp
            
            	
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cdp>`
            
            .. attribute:: cem
            
            	CEM
            	**type**\: list of  		 :py:class:`Cem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cem>`
            
            .. attribute:: pvc
            
            	PVC
            	**type**\: list of  		 :py:class:`Pvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.ATMACR, self).__init__()

                self.yang_name = "ATM-ACR"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("Cisco-IOS-XE-atm:ip", ("ip", Native.Interface.ATMACR.Ip)), ("Cisco-IOS-XE-atm:atm", ("atm", Native.Interface.ATMACR.Atm)), ("Cisco-IOS-XE-atm:cem", ("cem", Native.Interface.ATMACR.Cem)), ("Cisco-IOS-XE-atm:pvc", ("pvc", Native.Interface.ATMACR.Pvc))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('load_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-atm:load-interval'), ['int'])),
                    ('cdp', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-atm:cdp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACR.Cdp')])),
                ])
                self.name = None
                self.load_interval = None
                self.cdp = None

                self.ip = Native.Interface.ATMACR.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "Cisco-IOS-XE-atm:ip"

                self.atm = Native.Interface.ATMACR.Atm()
                self.atm.parent = self
                self._children_name_map["atm"] = "Cisco-IOS-XE-atm:atm"

                self.cem = YList(self)
                self.pvc = YList(self)
                self._segment_path = lambda: "ATM-ACR" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.ATMACR, [u'name', 'load_interval', 'cdp'], name, value)

            class Cdp(Enum):
                """
                Cdp (Enum Class)

                .. data:: enable = 0

                """

                enable = Enum.YLeaf(0, "enable")



            class Ip(Entity):
                """
                IP address
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: split_horizon
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.ATMACR.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "ATM-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('split_horizon', (YLeaf(YType.empty, 'split-horizon'), ['Empty'])),
                    ])
                    self.address = None
                    self.split_horizon = None
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATMACR.Ip, ['address', 'split_horizon'], name, value)


            class Atm(Entity):
                """
                ATM
                
                .. attribute:: bandwidth
                
                	ATM bandwith
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Bandwidth>`
                
                .. attribute:: enable_ilmi_trap
                
                	Enable\-ilmi\-trap
                	**type**\: bool
                
                .. attribute:: ilmi_keepalive
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: route_bridged
                
                	
                	**type**\:  :py:class:`RouteBridged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.RouteBridged>`
                
                .. attribute:: pvp
                
                	PVP
                	**type**\: list of  		 :py:class:`Pvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Pvp>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.ATMACR.Atm, self).__init__()

                    self.yang_name = "atm"
                    self.yang_parent_name = "ATM-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("pvp", ("pvp", Native.Interface.ATMACR.Atm.Pvp))])
                    self._leafs = OrderedDict([
                        ('bandwidth', (YLeaf(YType.enumeration, 'bandwidth'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACR.Atm.Bandwidth')])),
                        ('enable_ilmi_trap', (YLeaf(YType.boolean, 'enable-ilmi-trap'), ['bool'])),
                        ('ilmi_keepalive', (YLeaf(YType.empty, 'ilmi-keepalive'), ['Empty'])),
                        ('route_bridged', (YLeaf(YType.enumeration, 'route-bridged'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACR.Atm.RouteBridged')])),
                    ])
                    self.bandwidth = None
                    self.enable_ilmi_trap = None
                    self.ilmi_keepalive = None
                    self.route_bridged = None

                    self.pvp = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:atm"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATMACR.Atm, ['bandwidth', 'enable_ilmi_trap', 'ilmi_keepalive', 'route_bridged'], name, value)

                class Bandwidth(Enum):
                    """
                    Bandwidth (Enum Class)

                    ATM bandwith

                    .. data:: dynamic = 0

                    """

                    dynamic = Enum.YLeaf(0, "dynamic")


                class RouteBridged(Enum):
                    """
                    RouteBridged (Enum Class)

                    .. data:: ip = 0

                    .. data:: ipv6 = 1

                    """

                    ip = Enum.YLeaf(0, "ip")

                    ipv6 = Enum.YLeaf(1, "ipv6")



                class Pvp(Entity):
                    """
                    PVP
                    
                    .. attribute:: pvp_number  (key)
                    
                    	PVP number
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: l2transport
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Pvp.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACR.Atm.Pvp, self).__init__()

                        self.yang_name = "pvp"
                        self.yang_parent_name = "atm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['pvp_number']
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMACR.Atm.Pvp.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('pvp_number', (YLeaf(YType.uint16, 'pvp-number'), ['int'])),
                            ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                        ])
                        self.pvp_number = None
                        self.l2transport = None

                        self.xconnect = Native.Interface.ATMACR.Atm.Pvp.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"

                        self.xconnect_pw_class = Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                        self._segment_path = lambda: "pvp" + "[pvp-number='" + str(self.pvp_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACR.Atm.Pvp, ['pvp_number', 'l2transport'], name, value)


                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Pvp.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Pvp.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACR.Atm.Pvp.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "pvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACR.Atm.Pvp.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACR.Atm.Pvp.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACR.Atm.Pvp.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACR.Atm.Pvp.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "pvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Cem(Entity):
                """
                CEM
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: xconnect
                
                	
                	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cem.Xconnect>`
                
                .. attribute:: xconnect_pw_class
                
                	
                	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cem.XconnectPwClass>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.ATMACR.Cem, self).__init__()

                    self.yang_name = "cem"
                    self.yang_parent_name = "ATM-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMACR.Cem.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATMACR.Cem.XconnectPwClass))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                    ])
                    self.number = None

                    self.xconnect = Native.Interface.ATMACR.Cem.Xconnect()
                    self.xconnect.parent = self
                    self._children_name_map["xconnect"] = "xconnect"

                    self.xconnect_pw_class = Native.Interface.ATMACR.Cem.XconnectPwClass()
                    self.xconnect_pw_class.parent = self
                    self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:cem" + "[number='" + str(self.number) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATMACR.Cem, ['number'], name, value)


                class Xconnect(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vcid
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: encapsulation
                    
                    	Data encapsulation method
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cem.Xconnect.Encapsulation>`
                    
                    .. attribute:: manual
                    
                    	Manually configure L2TP session parameters
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pw_class
                    
                    	Optional pseudowire\-class to use for advanced configuration
                    	**type**\: str
                    
                    .. attribute:: sequencing
                    
                    	Configure sequencing options for xconnect
                    	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cem.Xconnect.Sequencing>`
                    
                    .. attribute:: backup
                    
                    	Xconnect backup configuration commands
                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cem.Xconnect.Backup>`
                    
                    .. attribute:: mtu
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACR.Cem.Xconnect, self).__init__()

                        self.yang_name = "xconnect"
                        self.yang_parent_name = "cem"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATMACR.Cem.Xconnect.Backup))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACR.Cem.Xconnect.Encapsulation')])),
                            ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                            ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACR.Cem.Xconnect.Sequencing')])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                        ])
                        self.address = None
                        self.vcid = None
                        self.encapsulation = None
                        self.manual = None
                        self.pw_class = None
                        self.sequencing = None
                        self.mtu = None

                        self.backup = Native.Interface.ATMACR.Cem.Xconnect.Backup()
                        self.backup.parent = self
                        self._children_name_map["backup"] = "backup"
                        self._segment_path = lambda: "xconnect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACR.Cem.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Data encapsulation method

                        .. data:: mpls = 0

                        .. data:: l2tpv3 = 1

                        """

                        mpls = Enum.YLeaf(0, "mpls")

                        l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                    class Sequencing(Enum):
                        """
                        Sequencing (Enum Class)

                        Configure sequencing options for xconnect

                        .. data:: both = 0

                        .. data:: receive = 1

                        .. data:: transmit = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        receive = Enum.YLeaf(1, "receive")

                        transmit = Enum.YLeaf(2, "transmit")



                    class Backup(Entity):
                        """
                        Xconnect backup configuration commands
                        
                        .. attribute:: peer
                        
                        	Backup pseudowire
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cem.Xconnect.Backup.Peer>`
                        
                        .. attribute:: delay
                        
                        	backup delay time
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cem.Xconnect.Backup.Delay>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACR.Cem.Xconnect.Backup, self).__init__()

                            self.yang_name = "backup"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATMACR.Cem.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATMACR.Cem.Xconnect.Backup.Delay))])
                            self._leafs = OrderedDict()

                            self.peer = Native.Interface.ATMACR.Cem.Xconnect.Backup.Peer()
                            self.peer.parent = self
                            self._children_name_map["peer"] = "peer"

                            self.delay = Native.Interface.ATMACR.Cem.Xconnect.Backup.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "backup"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACR.Cem.Xconnect.Backup, [], name, value)


                        class Peer(Entity):
                            """
                            Backup pseudowire
                            
                            .. attribute:: peer_router_ip_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: priority
                            
                            	Optional priority to use for backup pseudowire
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACR.Cem.Xconnect.Backup.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.peer_router_ip_addr = None
                                self.vcid = None
                                self.pw_class = None
                                self.priority = None
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACR.Cem.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                        class Delay(Entity):
                            """
                            backup delay time
                            
                            .. attribute:: min
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACR.Cem.Xconnect.Backup.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACR.Cem.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                class XconnectPwClass(Entity):
                    """
                    
                    
                    .. attribute:: xconnect
                    
                    	Xconnect commands
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACR.Cem.XconnectPwClass, self).__init__()

                        self.yang_name = "xconnect-pw-class"
                        self.yang_parent_name = "cem"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect))])
                        self._leafs = OrderedDict()

                        self.xconnect = Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"
                        self._segment_path = lambda: "xconnect-pw-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACR.Cem.XconnectPwClass, [], name, value)


                    class Xconnect(Entity):
                        """
                        Xconnect commands
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_class
                        
                        	Pseudowire\-class to use for encapsulation and protocol configuration
                        	**type**\: str
                        
                        .. attribute:: udp
                        
                        	UDP
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "xconnect-pw-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.pw_class = None

                            self.udp = Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                        class Udp(Entity):
                            """
                            UDP
                            
                            .. attribute:: port
                            
                            	UDP ports
                            	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp.Port>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp.Port))])
                                self._leafs = OrderedDict()

                                self.port = Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp, [], name, value)


                            class Port(Entity):
                                """
                                UDP ports
                                
                                .. attribute:: local
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                    self.yang_name = "port"
                                    self.yang_parent_name = "udp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                    ])
                                    self.local = None
                                    self.remote = None
                                    self._segment_path = lambda: "port"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Pvc(Entity):
                """
                PVC
                
                .. attribute:: local_vpi_vci  (key)
                
                	Vpi and vci
                	**type**\: str
                
                .. attribute:: remote_vpi_vci
                
                	Vpi and vci
                	**type**\: str
                
                .. attribute:: l2transport
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ubr
                
                	UBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ubrplus
                
                	
                	**type**\:  :py:class:`Ubrplus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Ubrplus>`
                
                .. attribute:: cbr
                
                	CBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr
                
                	VBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr_rt
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr_nrt
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: oam_pvc
                
                	
                	**type**\:  :py:class:`OamPvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.OamPvc>`
                
                	**presence node**\: True
                
                .. attribute:: service_policy
                
                	
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.ServicePolicy>`
                
                .. attribute:: encapsulation
                
                	
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Encapsulation>`
                
                .. attribute:: xconnect
                
                	
                	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Xconnect>`
                
                .. attribute:: xconnect_pw_class
                
                	
                	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.XconnectPwClass>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.ATMACR.Pvc, self).__init__()

                    self.yang_name = "pvc"
                    self.yang_parent_name = "ATM-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['local_vpi_vci']
                    self._child_classes = OrderedDict([("ubrplus", ("ubrplus", Native.Interface.ATMACR.Pvc.Ubrplus)), ("oam-pvc", ("oam_pvc", Native.Interface.ATMACR.Pvc.OamPvc)), ("service-policy", ("service_policy", Native.Interface.ATMACR.Pvc.ServicePolicy)), ("encapsulation", ("encapsulation", Native.Interface.ATMACR.Pvc.Encapsulation)), ("xconnect", ("xconnect", Native.Interface.ATMACR.Pvc.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATMACR.Pvc.XconnectPwClass))])
                    self._leafs = OrderedDict([
                        ('local_vpi_vci', (YLeaf(YType.str, 'local-vpi-vci'), ['str'])),
                        ('remote_vpi_vci', (YLeaf(YType.str, 'remote-vpi-vci'), ['str'])),
                        ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                        ('ubr', (YLeaf(YType.uint32, 'ubr'), ['int'])),
                        ('cbr', (YLeaf(YType.uint32, 'cbr'), ['int'])),
                        ('vbr', (YLeaf(YType.uint32, 'vbr'), ['int'])),
                        ('vbr_rt', (YLeaf(YType.uint32, 'vbr-rt'), ['int'])),
                        ('vbr_nrt', (YLeaf(YType.uint32, 'vbr-nrt'), ['int'])),
                    ])
                    self.local_vpi_vci = None
                    self.remote_vpi_vci = None
                    self.l2transport = None
                    self.ubr = None
                    self.cbr = None
                    self.vbr = None
                    self.vbr_rt = None
                    self.vbr_nrt = None

                    self.ubrplus = Native.Interface.ATMACR.Pvc.Ubrplus()
                    self.ubrplus.parent = self
                    self._children_name_map["ubrplus"] = "ubrplus"

                    self.oam_pvc = None
                    self._children_name_map["oam_pvc"] = "oam-pvc"

                    self.service_policy = Native.Interface.ATMACR.Pvc.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"

                    self.encapsulation = Native.Interface.ATMACR.Pvc.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"

                    self.xconnect = Native.Interface.ATMACR.Pvc.Xconnect()
                    self.xconnect.parent = self
                    self._children_name_map["xconnect"] = "xconnect"

                    self.xconnect_pw_class = Native.Interface.ATMACR.Pvc.XconnectPwClass()
                    self.xconnect_pw_class.parent = self
                    self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:pvc" + "[local-vpi-vci='" + str(self.local_vpi_vci) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATMACR.Pvc, ['local_vpi_vci', 'remote_vpi_vci', 'l2transport', 'ubr', 'cbr', 'vbr', 'vbr_rt', 'vbr_nrt'], name, value)


                class Ubrplus(Entity):
                    """
                    
                    
                    .. attribute:: pcr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mcr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACR.Pvc.Ubrplus, self).__init__()

                        self.yang_name = "ubrplus"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pcr', (YLeaf(YType.uint32, 'PCR'), ['int'])),
                            ('mcr', (YLeaf(YType.uint32, 'MCR'), ['int'])),
                        ])
                        self.pcr = None
                        self.mcr = None
                        self._segment_path = lambda: "ubrplus"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACR.Pvc.Ubrplus, ['pcr', 'mcr'], name, value)


                class OamPvc(Entity):
                    """
                    
                    
                    .. attribute:: loopback_frequency
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..600
                    
                    .. attribute:: manage
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACR.Pvc.OamPvc, self).__init__()

                        self.yang_name = "oam-pvc"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('loopback_frequency', (YLeaf(YType.uint32, 'loopback-frequency'), ['int'])),
                            ('manage', (YLeaf(YType.empty, 'manage'), ['Empty'])),
                        ])
                        self.loopback_frequency = None
                        self.manage = None
                        self._segment_path = lambda: "oam-pvc"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACR.Pvc.OamPvc, ['loopback_frequency', 'manage'], name, value)


                class ServicePolicy(Entity):
                    """
                    
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACR.Pvc.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACR.Pvc.ServicePolicy, ['input', 'output'], name, value)


                class Encapsulation(Entity):
                    """
                    
                    
                    .. attribute:: aal5autoppp
                    
                    	
                    	**type**\:  :py:class:`Aal5autoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Encapsulation.Aal5autoppp>`
                    
                    .. attribute:: aal5ciscoppp
                    
                    	
                    	**type**\:  :py:class:`Aal5ciscoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Encapsulation.Aal5ciscoppp>`
                    
                    .. attribute:: aal5mux
                    
                    	
                    	**type**\:  :py:class:`Aal5mux <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Encapsulation.Aal5mux>`
                    
                    .. attribute:: aal5nlpid
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: aal5snap
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACR.Pvc.Encapsulation, self).__init__()

                        self.yang_name = "encapsulation"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aal5autoppp", ("aal5autoppp", Native.Interface.ATMACR.Pvc.Encapsulation.Aal5autoppp)), ("aal5ciscoppp", ("aal5ciscoppp", Native.Interface.ATMACR.Pvc.Encapsulation.Aal5ciscoppp)), ("aal5mux", ("aal5mux", Native.Interface.ATMACR.Pvc.Encapsulation.Aal5mux))])
                        self._leafs = OrderedDict([
                            ('aal5nlpid', (YLeaf(YType.empty, 'aal5nlpid'), ['Empty'])),
                            ('aal5snap', (YLeaf(YType.empty, 'aal5snap'), ['Empty'])),
                        ])
                        self.aal5nlpid = None
                        self.aal5snap = None

                        self.aal5autoppp = Native.Interface.ATMACR.Pvc.Encapsulation.Aal5autoppp()
                        self.aal5autoppp.parent = self
                        self._children_name_map["aal5autoppp"] = "aal5autoppp"

                        self.aal5ciscoppp = Native.Interface.ATMACR.Pvc.Encapsulation.Aal5ciscoppp()
                        self.aal5ciscoppp.parent = self
                        self._children_name_map["aal5ciscoppp"] = "aal5ciscoppp"

                        self.aal5mux = Native.Interface.ATMACR.Pvc.Encapsulation.Aal5mux()
                        self.aal5mux.parent = self
                        self._children_name_map["aal5mux"] = "aal5mux"
                        self._segment_path = lambda: "encapsulation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACR.Pvc.Encapsulation, ['aal5nlpid', 'aal5snap'], name, value)


                    class Aal5autoppp(Entity):
                        """
                        
                        
                        .. attribute:: virtual_template
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACR.Pvc.Encapsulation.Aal5autoppp, self).__init__()

                            self.yang_name = "aal5autoppp"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                            ])
                            self.virtual_template = None
                            self._segment_path = lambda: "aal5autoppp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACR.Pvc.Encapsulation.Aal5autoppp, ['virtual_template'], name, value)


                    class Aal5ciscoppp(Entity):
                        """
                        
                        
                        .. attribute:: virtual_template
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACR.Pvc.Encapsulation.Aal5ciscoppp, self).__init__()

                            self.yang_name = "aal5ciscoppp"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                            ])
                            self.virtual_template = None
                            self._segment_path = lambda: "aal5ciscoppp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACR.Pvc.Encapsulation.Aal5ciscoppp, ['virtual_template'], name, value)


                    class Aal5mux(Entity):
                        """
                        
                        
                        .. attribute:: ppp
                        
                        	
                        	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Encapsulation.Aal5mux.Ppp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACR.Pvc.Encapsulation.Aal5mux, self).__init__()

                            self.yang_name = "aal5mux"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ppp", ("ppp", Native.Interface.ATMACR.Pvc.Encapsulation.Aal5mux.Ppp))])
                            self._leafs = OrderedDict()

                            self.ppp = Native.Interface.ATMACR.Pvc.Encapsulation.Aal5mux.Ppp()
                            self.ppp.parent = self
                            self._children_name_map["ppp"] = "ppp"
                            self._segment_path = lambda: "aal5mux"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACR.Pvc.Encapsulation.Aal5mux, [], name, value)


                        class Ppp(Entity):
                            """
                            
                            
                            .. attribute:: virtual_template
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dialer
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACR.Pvc.Encapsulation.Aal5mux.Ppp, self).__init__()

                                self.yang_name = "ppp"
                                self.yang_parent_name = "aal5mux"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                                    ('dialer', (YLeaf(YType.empty, 'dialer'), ['Empty'])),
                                ])
                                self.virtual_template = None
                                self.dialer = None
                                self._segment_path = lambda: "ppp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACR.Pvc.Encapsulation.Aal5mux.Ppp, ['virtual_template', 'dialer'], name, value)


                class Xconnect(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vcid
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: encapsulation
                    
                    	Data encapsulation method
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Xconnect.Encapsulation>`
                    
                    .. attribute:: manual
                    
                    	Manually configure L2TP session parameters
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pw_class
                    
                    	Optional pseudowire\-class to use for advanced configuration
                    	**type**\: str
                    
                    .. attribute:: sequencing
                    
                    	Configure sequencing options for xconnect
                    	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Xconnect.Sequencing>`
                    
                    .. attribute:: backup
                    
                    	Xconnect backup configuration commands
                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Xconnect.Backup>`
                    
                    .. attribute:: mtu
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACR.Pvc.Xconnect, self).__init__()

                        self.yang_name = "xconnect"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATMACR.Pvc.Xconnect.Backup))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACR.Pvc.Xconnect.Encapsulation')])),
                            ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                            ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACR.Pvc.Xconnect.Sequencing')])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                        ])
                        self.address = None
                        self.vcid = None
                        self.encapsulation = None
                        self.manual = None
                        self.pw_class = None
                        self.sequencing = None
                        self.mtu = None

                        self.backup = Native.Interface.ATMACR.Pvc.Xconnect.Backup()
                        self.backup.parent = self
                        self._children_name_map["backup"] = "backup"
                        self._segment_path = lambda: "xconnect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACR.Pvc.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Data encapsulation method

                        .. data:: mpls = 0

                        .. data:: l2tpv3 = 1

                        """

                        mpls = Enum.YLeaf(0, "mpls")

                        l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                    class Sequencing(Enum):
                        """
                        Sequencing (Enum Class)

                        Configure sequencing options for xconnect

                        .. data:: both = 0

                        .. data:: receive = 1

                        .. data:: transmit = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        receive = Enum.YLeaf(1, "receive")

                        transmit = Enum.YLeaf(2, "transmit")



                    class Backup(Entity):
                        """
                        Xconnect backup configuration commands
                        
                        .. attribute:: peer
                        
                        	Backup pseudowire
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Xconnect.Backup.Peer>`
                        
                        .. attribute:: delay
                        
                        	backup delay time
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.Xconnect.Backup.Delay>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACR.Pvc.Xconnect.Backup, self).__init__()

                            self.yang_name = "backup"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATMACR.Pvc.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATMACR.Pvc.Xconnect.Backup.Delay))])
                            self._leafs = OrderedDict()

                            self.peer = Native.Interface.ATMACR.Pvc.Xconnect.Backup.Peer()
                            self.peer.parent = self
                            self._children_name_map["peer"] = "peer"

                            self.delay = Native.Interface.ATMACR.Pvc.Xconnect.Backup.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "backup"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACR.Pvc.Xconnect.Backup, [], name, value)


                        class Peer(Entity):
                            """
                            Backup pseudowire
                            
                            .. attribute:: peer_router_ip_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: priority
                            
                            	Optional priority to use for backup pseudowire
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACR.Pvc.Xconnect.Backup.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.peer_router_ip_addr = None
                                self.vcid = None
                                self.pw_class = None
                                self.priority = None
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACR.Pvc.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                        class Delay(Entity):
                            """
                            backup delay time
                            
                            .. attribute:: min
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACR.Pvc.Xconnect.Backup.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACR.Pvc.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                class XconnectPwClass(Entity):
                    """
                    
                    
                    .. attribute:: xconnect
                    
                    	Xconnect commands
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACR.Pvc.XconnectPwClass, self).__init__()

                        self.yang_name = "xconnect-pw-class"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect))])
                        self._leafs = OrderedDict()

                        self.xconnect = Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"
                        self._segment_path = lambda: "xconnect-pw-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACR.Pvc.XconnectPwClass, [], name, value)


                    class Xconnect(Entity):
                        """
                        Xconnect commands
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_class
                        
                        	Pseudowire\-class to use for encapsulation and protocol configuration
                        	**type**\: str
                        
                        .. attribute:: udp
                        
                        	UDP
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "xconnect-pw-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.pw_class = None

                            self.udp = Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                        class Udp(Entity):
                            """
                            UDP
                            
                            .. attribute:: port
                            
                            	UDP ports
                            	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port))])
                                self._leafs = OrderedDict()

                                self.port = Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp, [], name, value)


                            class Port(Entity):
                                """
                                UDP ports
                                
                                .. attribute:: local
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                    self.yang_name = "port"
                                    self.yang_parent_name = "udp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                    ])
                                    self.local = None
                                    self.remote = None
                                    self._segment_path = lambda: "port"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


        class ATMACRsubinterface(Entity):
            """
            
            
            .. attribute:: atm_acr
            
            	
            	**type**\: list of  		 :py:class:`ATMACR <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.ATMACRsubinterface, self).__init__()

                self.yang_name = "ATM-ACRsubinterface"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ATM-ACR", ("atm_acr", Native.Interface.ATMACRsubinterface.ATMACR))])
                self._leafs = OrderedDict()

                self.atm_acr = YList(self)
                self._segment_path = lambda: "ATM-ACRsubinterface"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.ATMACRsubinterface, [], name, value)


            class ATMACR(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                
                .. attribute:: ip
                
                	IP address
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Ip>`
                
                .. attribute:: atm
                
                	ATM
                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm>`
                
                .. attribute:: load_interval
                
                	Load interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: cdp
                
                	
                	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cdp>`
                
                .. attribute:: cem
                
                	CEM
                	**type**\: list of  		 :py:class:`Cem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cem>`
                
                .. attribute:: pvc
                
                	PVC
                	**type**\: list of  		 :py:class:`Pvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ATMACRsubinterface.ATMACR, self).__init__()

                    self.yang_name = "ATM-ACR"
                    self.yang_parent_name = "ATM-ACRsubinterface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-atm:ip", ("ip", Native.Interface.ATMACRsubinterface.ATMACR.Ip)), ("Cisco-IOS-XE-atm:atm", ("atm", Native.Interface.ATMACRsubinterface.ATMACR.Atm)), ("Cisco-IOS-XE-atm:cem", ("cem", Native.Interface.ATMACRsubinterface.ATMACR.Cem)), ("Cisco-IOS-XE-atm:pvc", ("pvc", Native.Interface.ATMACRsubinterface.ATMACR.Pvc))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('load_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-atm:load-interval'), ['int'])),
                        ('cdp', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-atm:cdp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACRsubinterface.ATMACR.Cdp')])),
                    ])
                    self.name = None
                    self.load_interval = None
                    self.cdp = None

                    self.ip = Native.Interface.ATMACRsubinterface.ATMACR.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "Cisco-IOS-XE-atm:ip"

                    self.atm = Native.Interface.ATMACRsubinterface.ATMACR.Atm()
                    self.atm.parent = self
                    self._children_name_map["atm"] = "Cisco-IOS-XE-atm:atm"

                    self.cem = YList(self)
                    self.pvc = YList(self)
                    self._segment_path = lambda: "ATM-ACR" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/ATM-ACRsubinterface/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR, [u'name', 'load_interval', 'cdp'], name, value)

                class Cdp(Enum):
                    """
                    Cdp (Enum Class)

                    .. data:: enable = 0

                    """

                    enable = Enum.YLeaf(0, "enable")



                class Ip(Entity):
                    """
                    IP address
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: split_horizon
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACRsubinterface.ATMACR.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ATM-ACR"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('split_horizon', (YLeaf(YType.empty, 'split-horizon'), ['Empty'])),
                        ])
                        self.address = None
                        self.split_horizon = None
                        self._segment_path = lambda: "Cisco-IOS-XE-atm:ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Ip, ['address', 'split_horizon'], name, value)


                class Atm(Entity):
                    """
                    ATM
                    
                    .. attribute:: bandwidth
                    
                    	ATM bandwith
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Bandwidth>`
                    
                    .. attribute:: enable_ilmi_trap
                    
                    	Enable\-ilmi\-trap
                    	**type**\: bool
                    
                    .. attribute:: ilmi_keepalive
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: route_bridged
                    
                    	
                    	**type**\:  :py:class:`RouteBridged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.RouteBridged>`
                    
                    .. attribute:: pvp
                    
                    	PVP
                    	**type**\: list of  		 :py:class:`Pvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACRsubinterface.ATMACR.Atm, self).__init__()

                        self.yang_name = "atm"
                        self.yang_parent_name = "ATM-ACR"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("pvp", ("pvp", Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp))])
                        self._leafs = OrderedDict([
                            ('bandwidth', (YLeaf(YType.enumeration, 'bandwidth'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACRsubinterface.ATMACR.Atm.Bandwidth')])),
                            ('enable_ilmi_trap', (YLeaf(YType.boolean, 'enable-ilmi-trap'), ['bool'])),
                            ('ilmi_keepalive', (YLeaf(YType.empty, 'ilmi-keepalive'), ['Empty'])),
                            ('route_bridged', (YLeaf(YType.enumeration, 'route-bridged'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACRsubinterface.ATMACR.Atm.RouteBridged')])),
                        ])
                        self.bandwidth = None
                        self.enable_ilmi_trap = None
                        self.ilmi_keepalive = None
                        self.route_bridged = None

                        self.pvp = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-atm:atm"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Atm, ['bandwidth', 'enable_ilmi_trap', 'ilmi_keepalive', 'route_bridged'], name, value)

                    class Bandwidth(Enum):
                        """
                        Bandwidth (Enum Class)

                        ATM bandwith

                        .. data:: dynamic = 0

                        """

                        dynamic = Enum.YLeaf(0, "dynamic")


                    class RouteBridged(Enum):
                        """
                        RouteBridged (Enum Class)

                        .. data:: ip = 0

                        .. data:: ipv6 = 1

                        """

                        ip = Enum.YLeaf(0, "ip")

                        ipv6 = Enum.YLeaf(1, "ipv6")



                    class Pvp(Entity):
                        """
                        PVP
                        
                        .. attribute:: pvp_number  (key)
                        
                        	PVP number
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: l2transport
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: xconnect
                        
                        	
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect>`
                        
                        .. attribute:: xconnect_pw_class
                        
                        	
                        	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp, self).__init__()

                            self.yang_name = "pvp"
                            self.yang_parent_name = "atm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['pvp_number']
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass))])
                            self._leafs = OrderedDict([
                                ('pvp_number', (YLeaf(YType.uint16, 'pvp-number'), ['int'])),
                                ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                            ])
                            self.pvp_number = None
                            self.l2transport = None

                            self.xconnect = Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"

                            self.xconnect_pw_class = Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass()
                            self.xconnect_pw_class.parent = self
                            self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                            self._segment_path = lambda: "pvp" + "[pvp-number='" + str(self.pvp_number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp, ['pvp_number', 'l2transport'], name, value)


                        class Xconnect(Entity):
                            """
                            
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: encapsulation
                            
                            	Data encapsulation method
                            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Encapsulation>`
                            
                            .. attribute:: manual
                            
                            	Manually configure L2TP session parameters
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: pw_class
                            
                            	Optional pseudowire\-class to use for advanced configuration
                            	**type**\: str
                            
                            .. attribute:: sequencing
                            
                            	Configure sequencing options for xconnect
                            	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Sequencing>`
                            
                            .. attribute:: backup
                            
                            	Xconnect backup configuration commands
                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup>`
                            
                            .. attribute:: mtu
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "pvp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Encapsulation')])),
                                    ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Sequencing')])),
                                    ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.encapsulation = None
                                self.manual = None
                                self.pw_class = None
                                self.sequencing = None
                                self.mtu = None

                                self.backup = Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup()
                                self.backup.parent = self
                                self._children_name_map["backup"] = "backup"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                            class Encapsulation(Enum):
                                """
                                Encapsulation (Enum Class)

                                Data encapsulation method

                                .. data:: mpls = 0

                                .. data:: l2tpv3 = 1

                                """

                                mpls = Enum.YLeaf(0, "mpls")

                                l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                            class Sequencing(Enum):
                                """
                                Sequencing (Enum Class)

                                Configure sequencing options for xconnect

                                .. data:: both = 0

                                .. data:: receive = 1

                                .. data:: transmit = 2

                                """

                                both = Enum.YLeaf(0, "both")

                                receive = Enum.YLeaf(1, "receive")

                                transmit = Enum.YLeaf(2, "transmit")



                            class Backup(Entity):
                                """
                                Xconnect backup configuration commands
                                
                                .. attribute:: peer
                                
                                	Backup pseudowire
                                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup.Peer>`
                                
                                .. attribute:: delay
                                
                                	backup delay time
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup.Delay>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup, self).__init__()

                                    self.yang_name = "backup"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup.Delay))])
                                    self._leafs = OrderedDict()

                                    self.peer = Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup.Peer()
                                    self.peer.parent = self
                                    self._children_name_map["peer"] = "peer"

                                    self.delay = Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "backup"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup, [], name, value)


                                class Peer(Entity):
                                    """
                                    Backup pseudowire
                                    
                                    .. attribute:: peer_router_ip_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: vcid
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: pw_class
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: priority
                                    
                                    	Optional priority to use for backup pseudowire
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup.Peer, self).__init__()

                                        self.yang_name = "peer"
                                        self.yang_parent_name = "backup"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                            ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                            ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                        ])
                                        self.peer_router_ip_addr = None
                                        self.vcid = None
                                        self.pw_class = None
                                        self.priority = None
                                        self._segment_path = lambda: "peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                                class Delay(Entity):
                                    """
                                    backup delay time
                                    
                                    .. attribute:: min
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "backup"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                            ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                        ])
                                        self.min = None
                                        self.max = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                        class XconnectPwClass(Entity):
                            """
                            
                            
                            .. attribute:: xconnect
                            
                            	Xconnect commands
                            	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass, self).__init__()

                                self.yang_name = "xconnect-pw-class"
                                self.yang_parent_name = "pvp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect))])
                                self._leafs = OrderedDict()

                                self.xconnect = Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect()
                                self.xconnect.parent = self
                                self._children_name_map["xconnect"] = "xconnect"
                                self._segment_path = lambda: "xconnect-pw-class"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass, [], name, value)


                            class Xconnect(Entity):
                                """
                                Xconnect commands
                                
                                .. attribute:: address
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	Pseudowire\-class to use for encapsulation and protocol configuration
                                	**type**\: str
                                
                                .. attribute:: udp
                                
                                	UDP
                                	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect, self).__init__()

                                    self.yang_name = "xconnect"
                                    self.yang_parent_name = "xconnect-pw-class"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp))])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ])
                                    self.address = None
                                    self.vcid = None
                                    self.pw_class = None

                                    self.udp = Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp()
                                    self.udp.parent = self
                                    self._children_name_map["udp"] = "udp"
                                    self._segment_path = lambda: "xconnect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                                class Udp(Entity):
                                    """
                                    UDP
                                    
                                    .. attribute:: port
                                    
                                    	UDP ports
                                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port>`
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp, self).__init__()

                                        self.yang_name = "udp"
                                        self.yang_parent_name = "xconnect"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port))])
                                        self._leafs = OrderedDict()

                                        self.port = Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port()
                                        self.port.parent = self
                                        self._children_name_map["port"] = "port"
                                        self._segment_path = lambda: "udp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp, [], name, value)


                                    class Port(Entity):
                                        """
                                        UDP ports
                                        
                                        .. attribute:: local
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-atm'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                            self.yang_name = "port"
                                            self.yang_parent_name = "udp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                                ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                            ])
                                            self.local = None
                                            self.remote = None
                                            self._segment_path = lambda: "port"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


                class Cem(Entity):
                    """
                    CEM
                    
                    .. attribute:: number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACRsubinterface.ATMACR.Cem, self).__init__()

                        self.yang_name = "cem"
                        self.yang_parent_name = "ATM-ACR"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['number']
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                        ])
                        self.number = None

                        self.xconnect = Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"

                        self.xconnect_pw_class = Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                        self._segment_path = lambda: "Cisco-IOS-XE-atm:cem" + "[number='" + str(self.number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Cem, ['number'], name, value)


                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "cem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Cem.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "cem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Cem.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


                class Pvc(Entity):
                    """
                    PVC
                    
                    .. attribute:: local_vpi_vci  (key)
                    
                    	Vpi and vci
                    	**type**\: str
                    
                    .. attribute:: remote_vpi_vci
                    
                    	Vpi and vci
                    	**type**\: str
                    
                    .. attribute:: l2transport
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ubr
                    
                    	UBR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ubrplus
                    
                    	
                    	**type**\:  :py:class:`Ubrplus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Ubrplus>`
                    
                    .. attribute:: cbr
                    
                    	CBR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vbr
                    
                    	VBR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vbr_rt
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vbr_nrt
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: oam_pvc
                    
                    	
                    	**type**\:  :py:class:`OamPvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.OamPvc>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: service_policy
                    
                    	
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.ServicePolicy>`
                    
                    .. attribute:: encapsulation
                    
                    	
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc, self).__init__()

                        self.yang_name = "pvc"
                        self.yang_parent_name = "ATM-ACR"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['local_vpi_vci']
                        self._child_classes = OrderedDict([("ubrplus", ("ubrplus", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Ubrplus)), ("oam-pvc", ("oam_pvc", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.OamPvc)), ("service-policy", ("service_policy", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.ServicePolicy)), ("encapsulation", ("encapsulation", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation)), ("xconnect", ("xconnect", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('local_vpi_vci', (YLeaf(YType.str, 'local-vpi-vci'), ['str'])),
                            ('remote_vpi_vci', (YLeaf(YType.str, 'remote-vpi-vci'), ['str'])),
                            ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                            ('ubr', (YLeaf(YType.uint32, 'ubr'), ['int'])),
                            ('cbr', (YLeaf(YType.uint32, 'cbr'), ['int'])),
                            ('vbr', (YLeaf(YType.uint32, 'vbr'), ['int'])),
                            ('vbr_rt', (YLeaf(YType.uint32, 'vbr-rt'), ['int'])),
                            ('vbr_nrt', (YLeaf(YType.uint32, 'vbr-nrt'), ['int'])),
                        ])
                        self.local_vpi_vci = None
                        self.remote_vpi_vci = None
                        self.l2transport = None
                        self.ubr = None
                        self.cbr = None
                        self.vbr = None
                        self.vbr_rt = None
                        self.vbr_nrt = None

                        self.ubrplus = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Ubrplus()
                        self.ubrplus.parent = self
                        self._children_name_map["ubrplus"] = "ubrplus"

                        self.oam_pvc = None
                        self._children_name_map["oam_pvc"] = "oam-pvc"

                        self.service_policy = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.encapsulation = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.xconnect = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"

                        self.xconnect_pw_class = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                        self._segment_path = lambda: "Cisco-IOS-XE-atm:pvc" + "[local-vpi-vci='" + str(self.local_vpi_vci) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc, ['local_vpi_vci', 'remote_vpi_vci', 'l2transport', 'ubr', 'cbr', 'vbr', 'vbr_rt', 'vbr_nrt'], name, value)


                    class Ubrplus(Entity):
                        """
                        
                        
                        .. attribute:: pcr
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mcr
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Ubrplus, self).__init__()

                            self.yang_name = "ubrplus"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('pcr', (YLeaf(YType.uint32, 'PCR'), ['int'])),
                                ('mcr', (YLeaf(YType.uint32, 'MCR'), ['int'])),
                            ])
                            self.pcr = None
                            self.mcr = None
                            self._segment_path = lambda: "ubrplus"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Ubrplus, ['pcr', 'mcr'], name, value)


                    class OamPvc(Entity):
                        """
                        
                        
                        .. attribute:: loopback_frequency
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..600
                        
                        .. attribute:: manage
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.OamPvc, self).__init__()

                            self.yang_name = "oam-pvc"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('loopback_frequency', (YLeaf(YType.uint32, 'loopback-frequency'), ['int'])),
                                ('manage', (YLeaf(YType.empty, 'manage'), ['Empty'])),
                            ])
                            self.loopback_frequency = None
                            self.manage = None
                            self._segment_path = lambda: "oam-pvc"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.OamPvc, ['loopback_frequency', 'manage'], name, value)


                    class ServicePolicy(Entity):
                        """
                        
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\: str
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.str, 'input'), ['str'])),
                                ('output', (YLeaf(YType.str, 'output'), ['str'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.ServicePolicy, ['input', 'output'], name, value)


                    class Encapsulation(Entity):
                        """
                        
                        
                        .. attribute:: aal5autoppp
                        
                        	
                        	**type**\:  :py:class:`Aal5autoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5autoppp>`
                        
                        .. attribute:: aal5ciscoppp
                        
                        	
                        	**type**\:  :py:class:`Aal5ciscoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5ciscoppp>`
                        
                        .. attribute:: aal5mux
                        
                        	
                        	**type**\:  :py:class:`Aal5mux <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5mux>`
                        
                        .. attribute:: aal5nlpid
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: aal5snap
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("aal5autoppp", ("aal5autoppp", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5autoppp)), ("aal5ciscoppp", ("aal5ciscoppp", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5ciscoppp)), ("aal5mux", ("aal5mux", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5mux))])
                            self._leafs = OrderedDict([
                                ('aal5nlpid', (YLeaf(YType.empty, 'aal5nlpid'), ['Empty'])),
                                ('aal5snap', (YLeaf(YType.empty, 'aal5snap'), ['Empty'])),
                            ])
                            self.aal5nlpid = None
                            self.aal5snap = None

                            self.aal5autoppp = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5autoppp()
                            self.aal5autoppp.parent = self
                            self._children_name_map["aal5autoppp"] = "aal5autoppp"

                            self.aal5ciscoppp = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5ciscoppp()
                            self.aal5ciscoppp.parent = self
                            self._children_name_map["aal5ciscoppp"] = "aal5ciscoppp"

                            self.aal5mux = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5mux()
                            self.aal5mux.parent = self
                            self._children_name_map["aal5mux"] = "aal5mux"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation, ['aal5nlpid', 'aal5snap'], name, value)


                        class Aal5autoppp(Entity):
                            """
                            
                            
                            .. attribute:: virtual_template
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5autoppp, self).__init__()

                                self.yang_name = "aal5autoppp"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                                ])
                                self.virtual_template = None
                                self._segment_path = lambda: "aal5autoppp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5autoppp, ['virtual_template'], name, value)


                        class Aal5ciscoppp(Entity):
                            """
                            
                            
                            .. attribute:: virtual_template
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5ciscoppp, self).__init__()

                                self.yang_name = "aal5ciscoppp"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                                ])
                                self.virtual_template = None
                                self._segment_path = lambda: "aal5ciscoppp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5ciscoppp, ['virtual_template'], name, value)


                        class Aal5mux(Entity):
                            """
                            
                            
                            .. attribute:: ppp
                            
                            	
                            	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5mux.Ppp>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5mux, self).__init__()

                                self.yang_name = "aal5mux"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ppp", ("ppp", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5mux.Ppp))])
                                self._leafs = OrderedDict()

                                self.ppp = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5mux.Ppp()
                                self.ppp.parent = self
                                self._children_name_map["ppp"] = "ppp"
                                self._segment_path = lambda: "aal5mux"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5mux, [], name, value)


                            class Ppp(Entity):
                                """
                                
                                
                                .. attribute:: virtual_template
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dialer
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5mux.Ppp, self).__init__()

                                    self.yang_name = "ppp"
                                    self.yang_parent_name = "aal5mux"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                                        ('dialer', (YLeaf(YType.empty, 'dialer'), ['Empty'])),
                                    ])
                                    self.virtual_template = None
                                    self.dialer = None
                                    self._segment_path = lambda: "ppp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Encapsulation.Aal5mux.Ppp, ['virtual_template', 'dialer'], name, value)


                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ATMACRsubinterface.ATMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


        class BDI(Entity):
            """
            Bridge\-Domain interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ServicePolicy>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.BDI, self).__init__()

                self.yang_name = "BDI"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.BDI.SwitchportConf)), ("switchport", ("switchport", Native.Interface.BDI.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.BDI.StackwiseVirtual)), ("arp", ("arp", Native.Interface.BDI.Arp)), ("backup", ("backup", Native.Interface.BDI.Backup)), ("cemoudp", ("cemoudp", Native.Interface.BDI.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.BDI.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.BDI.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.BDI.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.BDI.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.BDI.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.BDI.Flowcontrol)), ("isis", ("isis", Native.Interface.BDI.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.BDI.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.BDI.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.BDI.Bandwidth)), ("dampening", ("dampening", Native.Interface.BDI.Dampening)), ("domain", ("domain", Native.Interface.BDI.Domain)), ("hold-queue", ("hold_queue", Native.Interface.BDI.HoldQueue)), ("mpls", ("mpls", Native.Interface.BDI.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.BDI.IpVrf)), ("vrf", ("vrf", Native.Interface.BDI.Vrf)), ("ip", ("ip", Native.Interface.BDI.Ip)), ("ipv6", ("ipv6", Native.Interface.BDI.Ipv6)), ("logging", ("logging", Native.Interface.BDI.Logging)), ("mdix", ("mdix", Native.Interface.BDI.Mdix)), ("mop", ("mop", Native.Interface.BDI.Mop)), ("interface_qos", ("interface_qos", Native.Interface.BDI.InterfaceQos)), ("source", ("source", Native.Interface.BDI.Source)), ("standby", ("standby", Native.Interface.BDI.Standby)), ("access-session", ("access_session", Native.Interface.BDI.AccessSession)), ("storm-control", ("storm_control", Native.Interface.BDI.StormControl)), ("trust", ("trust", Native.Interface.BDI.Trust)), ("priority-queue", ("priority_queue", Native.Interface.BDI.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.BDI.RcvQueue)), ("peer", ("peer", Native.Interface.BDI.Peer)), ("pm-path", ("pm_path", Native.Interface.BDI.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.BDI.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.BDI.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.BDI.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.BDI.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.BDI.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.BDI.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.BDI.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.BDI.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.BDI.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.BDI.Service)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.BDI.ServicePolicy))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Duplex')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None

                self.switchport_conf = Native.Interface.BDI.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.BDI.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.BDI.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.BDI.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.BDI.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.BDI.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.BDI.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.BDI.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.BDI.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.BDI.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.BDI.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.BDI.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.BDI.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.BDI.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.BDI.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.BDI.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.BDI.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.BDI.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.BDI.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.BDI.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.BDI.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.BDI.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.BDI.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.BDI.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.BDI.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.BDI.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.BDI.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.BDI.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.BDI.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.BDI.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.BDI.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.BDI.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.BDI.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.BDI.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.BDI.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.BDI.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.BDI.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.BDI.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.BDI.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.BDI.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.BDI.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.BDI.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.BDI.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.BDI.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.BDI.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.service_policy = Native.Interface.BDI.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "BDI" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.BDI, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.BDI.Backup.Delay)), ("interface", ("interface", Native.Interface.BDI.Backup.Interface_)), ("load", ("load", Native.Interface.BDI.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.BDI.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.BDI.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.BDI.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.BDI.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.BDI.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.BDI.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.BDI.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.BDI.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.BDI.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.BDI.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.BDI.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.BDI.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.BDI.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.BDI.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.BDI.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.BDI.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.BDI.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.BDI.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.BDI.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.BDI.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.BDI.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.BDI.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.BDI.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.BDI.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.BDI.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.BDI.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.BDI.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.BDI.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.BDI.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.BDI.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.BDI.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.BDI.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.BDI.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.BDI.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.BDI.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.BDI.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.BDI.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.BDI.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.BDI.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.BDI.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.BDI.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.BDI.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.BDI.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.BDI.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.BDI.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.BDI.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.BDI.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.BDI.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.BDI.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.BDI.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.BDI.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.BDI.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.BDI.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.BDI.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.BDI.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.BDI.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.BDI.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.BDI.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.BDI.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.BDI.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.BDI.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.BDI.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.BDI.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.BDI.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.BDI.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.BDI.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.BDI.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.BDI.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.BDI.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.BDI.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.BDI.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.BDI.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.BDI.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.BDI.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.BDI.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.BDI.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.BDI.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.BDI.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.BDI.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.BDI.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.BDI.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.BDI.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.BDI.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.BDI.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.BDI.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.BDI.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.BDI.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.BDI.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.BDI.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.BDI.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.BDI.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.BDI.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.BDI.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.BDI.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.BDI.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.BDI.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.BDI.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.BDI.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.BDI.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.BDI.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.BDI.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.BDI.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.BDI.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.BDI.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.BDI.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.BDI.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.BDI.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.BDI.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.BDI.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.BDI.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Verify>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Nat>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.BDI.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.BDI.Ip.Arp)), ("vrf", ("vrf", Native.Interface.BDI.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.BDI.Ip.NoAddress)), ("address", ("address", Native.Interface.BDI.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.BDI.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.BDI.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.BDI.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.BDI.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.BDI.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.BDI.Ip.Pim)), ("policy", ("policy", Native.Interface.BDI.Ip.Policy)), ("rip", ("rip", Native.Interface.BDI.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.BDI.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.BDI.Ip.RouteCache)), ("router", ("router", Native.Interface.BDI.Ip.Router)), ("tcp", ("tcp", Native.Interface.BDI.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.BDI.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.BDI.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.BDI.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.BDI.Ip.Verify)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.BDI.Ip.Ospf)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.BDI.Ip.Nat))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.BDI.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.BDI.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.BDI.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.BDI.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.BDI.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.BDI.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.BDI.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.BDI.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.BDI.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.BDI.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.BDI.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.BDI.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.BDI.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.BDI.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.BDI.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.BDI.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.BDI.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.BDI.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.ospf = Native.Interface.BDI.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.nat = Native.Interface.BDI.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.BDI.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.BDI.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.BDI.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.BDI.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.BDI.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.BDI.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.BDI.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.BDI.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.BDI.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.BDI.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.BDI.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.BDI.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.BDI.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.BDI.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.BDI.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.BDI.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.BDI.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.BDI.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.BDI.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.BDI.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.BDI.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.BDI.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.BDI.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.BDI.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.BDI.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.BDI.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.BDI.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.BDI.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.BDI.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.BDI.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.BDI.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.BDI.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.BDI.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.BDI.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.BDI.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.BDI.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.BDI.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.BDI.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.BDI.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.BDI.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.BDI.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.BDI.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.BDI.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.BDI.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.BDI.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.BDI.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.BDI.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.BDI.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.BDI.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.BDI.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.BDI.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.BDI.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.BDI.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.BDI.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.BDI.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.BDI.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.BDI.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.BDI.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.BDI.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.BDI.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.BDI.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.BDI.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.BDI.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.BDI.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.BDI.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.BDI.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.BDI.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.BDI.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.BDI.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.BDI.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.BDI.Ipv6.Dhcp)), ("address", ("address", Native.Interface.BDI.Ipv6.Address)), ("nd", ("nd", Native.Interface.BDI.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.BDI.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.BDI.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.BDI.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.BDI.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.BDI.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.BDI.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.BDI.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.BDI.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.BDI.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.BDI.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.BDI.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.BDI.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.BDI.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.BDI.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.BDI.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.BDI.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.BDI.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.BDI.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.BDI.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.BDI.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.BDI.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.BDI.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.BDI.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.BDI.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.BDI.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.BDI.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.BDI.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.BDI.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.BDI.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.BDI.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.BDI.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.BDI.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.BDI.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.BDI.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.BDI.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.BDI.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.BDI.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.BDI.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.BDI.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.BDI.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.BDI.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.BDI.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.BDI.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.BDI.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.BDI.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.BDI.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.BDI.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.BDI.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.BDI.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.BDI.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.BDI.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.BDI.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.BDI.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.BDI.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.BDI.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.BDI.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.BDI.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.BDI.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.BDI.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.BDI.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.BDI.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.BDI.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.BDI.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.BDI.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.BDI.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.BDI.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.BDI.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.BDI.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.BDI.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.BDI.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.BDI.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.BDI.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.BDI.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.BDI.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.BDI.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.BDI.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.BDI.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.BDI.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.BDI.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.BDI.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.BDI.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.BDI.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.BDI.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.BDI.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.BDI.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.BDI.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.BDI.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.BDI.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.BDI.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.BDI.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.BDI.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.BDI.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.BDI.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.BDI.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.BDI.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.BDI.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.BDI.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.BDI.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.BDI.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.BDI.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.BDI.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.BDI.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.BDI.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.BDI.CarrierDelay.Down)), ("up", ("up", Native.Interface.BDI.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.BDI.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.BDI.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.BDI.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.BDI.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.BDI.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.BDI.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.BDI.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.BDI.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.BDI.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.BDI.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.BDI.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.BDI.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.BDI.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.BDI.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.BDI.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.BDI.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.BDI.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.BDI.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.BDI.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.BDI.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.BDI.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.BDI.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.BDI.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.BDI.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.BDI.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.BDI.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.BDI.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.BDI.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.BDI.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.BDI.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.BDI.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.BDI.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.BDI.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.BDI.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.BDI.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.BDI.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.BDI.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.BDI.Plim.Ethernet)), ("qos", ("qos", Native.Interface.BDI.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.BDI.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.BDI.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.BDI.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.BDI.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.BDI.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.BDI.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.BDI.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.BDI.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.BDI.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.BDI.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.BDI.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.BDI.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.BDI.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.BDI.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.BDI.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.BDI.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.BDI.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.BDI.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.BDI.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.BDI.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.BDI.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.BDI.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.BDI.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.BDI.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.BDI.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.L2protocol>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.BDI.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.BDI.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.BDI.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.BDI.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.BDI.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.BDI.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.BDI.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.BDI.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.BDI.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.BDI.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.BDI.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.BDI.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.BDI.Service.Instance.L2protocol))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.BDI.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.BDI.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.BDI.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.BDI.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.BDI.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.BDI.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.BDI.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.BDI.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.BDI.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.BDI.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.BDI.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.BDI.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.BDI.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.BDI.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.BDI.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.BDI.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.BDI.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.BDI.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.BDI.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.BDI.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.BDI.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.BDI.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.BDI.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.BDI.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.BDI.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.BDI.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.BDI.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.BDI.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.BDI.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.BDI.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.BDI.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.BDI.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.BDI.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.BDI.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.BDI.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.BDI.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.BDI.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.BDI.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.BDI.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.BDI.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.BDI.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.BDI.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.BDI.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.BDI.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.BDI.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.BDI.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.BDI.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.BDI.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.BDI.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.BDI.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.BDI.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.BDI.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.BDI.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.BDI.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.BDI.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.BDI.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.BDI.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.BDI.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.BDI.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.BDI.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.BDI.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.BDI.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.BDI.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.BDI.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "BDI"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.BDI.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.BDI.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.BDI.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.BDI.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.BDI.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.BDI.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.BDI.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.BDI.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.BDI.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.BDI.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.BDI.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.BDI.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.BDI.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.BDI.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.BDI.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.BDI.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.BDI.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.BDI.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.BDI.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.BDI.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.BDI.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


        class CEM(Entity):
            """
            Circuit Emulation interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            	**pattern:** ([0\-9]/){2}[0\-9]
            
            .. attribute:: ip
            
            	IP address
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Ip>`
            
            .. attribute:: atm
            
            	ATM
            	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm>`
            
            .. attribute:: load_interval
            
            	Load interval
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: cdp
            
            	
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cdp>`
            
            .. attribute:: cem
            
            	CEM
            	**type**\: list of  		 :py:class:`Cem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cem>`
            
            .. attribute:: pvc
            
            	PVC
            	**type**\: list of  		 :py:class:`Pvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.CEM, self).__init__()

                self.yang_name = "CEM"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("Cisco-IOS-XE-atm:ip", ("ip", Native.Interface.CEM.Ip)), ("Cisco-IOS-XE-atm:atm", ("atm", Native.Interface.CEM.Atm)), ("Cisco-IOS-XE-atm:cem", ("cem", Native.Interface.CEM.Cem)), ("Cisco-IOS-XE-atm:pvc", ("pvc", Native.Interface.CEM.Pvc))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('load_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-atm:load-interval'), ['int'])),
                    ('cdp', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-atm:cdp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEM.Cdp')])),
                ])
                self.name = None
                self.load_interval = None
                self.cdp = None

                self.ip = Native.Interface.CEM.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "Cisco-IOS-XE-atm:ip"

                self.atm = Native.Interface.CEM.Atm()
                self.atm.parent = self
                self._children_name_map["atm"] = "Cisco-IOS-XE-atm:atm"

                self.cem = YList(self)
                self.pvc = YList(self)
                self._segment_path = lambda: "CEM" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.CEM, [u'name', 'load_interval', 'cdp'], name, value)

            class Cdp(Enum):
                """
                Cdp (Enum Class)

                .. data:: enable = 0

                """

                enable = Enum.YLeaf(0, "enable")



            class Ip(Entity):
                """
                IP address
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: split_horizon
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.CEM.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "CEM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('split_horizon', (YLeaf(YType.empty, 'split-horizon'), ['Empty'])),
                    ])
                    self.address = None
                    self.split_horizon = None
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.CEM.Ip, ['address', 'split_horizon'], name, value)


            class Atm(Entity):
                """
                ATM
                
                .. attribute:: bandwidth
                
                	ATM bandwith
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Bandwidth>`
                
                .. attribute:: enable_ilmi_trap
                
                	Enable\-ilmi\-trap
                	**type**\: bool
                
                .. attribute:: ilmi_keepalive
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: route_bridged
                
                	
                	**type**\:  :py:class:`RouteBridged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.RouteBridged>`
                
                .. attribute:: pvp
                
                	PVP
                	**type**\: list of  		 :py:class:`Pvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Pvp>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.CEM.Atm, self).__init__()

                    self.yang_name = "atm"
                    self.yang_parent_name = "CEM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("pvp", ("pvp", Native.Interface.CEM.Atm.Pvp))])
                    self._leafs = OrderedDict([
                        ('bandwidth', (YLeaf(YType.enumeration, 'bandwidth'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEM.Atm.Bandwidth')])),
                        ('enable_ilmi_trap', (YLeaf(YType.boolean, 'enable-ilmi-trap'), ['bool'])),
                        ('ilmi_keepalive', (YLeaf(YType.empty, 'ilmi-keepalive'), ['Empty'])),
                        ('route_bridged', (YLeaf(YType.enumeration, 'route-bridged'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEM.Atm.RouteBridged')])),
                    ])
                    self.bandwidth = None
                    self.enable_ilmi_trap = None
                    self.ilmi_keepalive = None
                    self.route_bridged = None

                    self.pvp = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:atm"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.CEM.Atm, ['bandwidth', 'enable_ilmi_trap', 'ilmi_keepalive', 'route_bridged'], name, value)

                class Bandwidth(Enum):
                    """
                    Bandwidth (Enum Class)

                    ATM bandwith

                    .. data:: dynamic = 0

                    """

                    dynamic = Enum.YLeaf(0, "dynamic")


                class RouteBridged(Enum):
                    """
                    RouteBridged (Enum Class)

                    .. data:: ip = 0

                    .. data:: ipv6 = 1

                    """

                    ip = Enum.YLeaf(0, "ip")

                    ipv6 = Enum.YLeaf(1, "ipv6")



                class Pvp(Entity):
                    """
                    PVP
                    
                    .. attribute:: pvp_number  (key)
                    
                    	PVP number
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: l2transport
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Pvp.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Pvp.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEM.Atm.Pvp, self).__init__()

                        self.yang_name = "pvp"
                        self.yang_parent_name = "atm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['pvp_number']
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.CEM.Atm.Pvp.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.CEM.Atm.Pvp.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('pvp_number', (YLeaf(YType.uint16, 'pvp-number'), ['int'])),
                            ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                        ])
                        self.pvp_number = None
                        self.l2transport = None

                        self.xconnect = Native.Interface.CEM.Atm.Pvp.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"

                        self.xconnect_pw_class = Native.Interface.CEM.Atm.Pvp.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                        self._segment_path = lambda: "pvp" + "[pvp-number='" + str(self.pvp_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEM.Atm.Pvp, ['pvp_number', 'l2transport'], name, value)


                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Pvp.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Pvp.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Pvp.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEM.Atm.Pvp.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "pvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.CEM.Atm.Pvp.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEM.Atm.Pvp.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEM.Atm.Pvp.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.CEM.Atm.Pvp.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEM.Atm.Pvp.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Pvp.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Pvp.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEM.Atm.Pvp.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.CEM.Atm.Pvp.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.CEM.Atm.Pvp.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.CEM.Atm.Pvp.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.CEM.Atm.Pvp.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEM.Atm.Pvp.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.CEM.Atm.Pvp.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.CEM.Atm.Pvp.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.CEM.Atm.Pvp.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.CEM.Atm.Pvp.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEM.Atm.Pvp.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "pvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEM.Atm.Pvp.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.CEM.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Cem(Entity):
                """
                CEM
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: xconnect
                
                	
                	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cem.Xconnect>`
                
                .. attribute:: xconnect_pw_class
                
                	
                	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cem.XconnectPwClass>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.CEM.Cem, self).__init__()

                    self.yang_name = "cem"
                    self.yang_parent_name = "CEM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.CEM.Cem.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.CEM.Cem.XconnectPwClass))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                    ])
                    self.number = None

                    self.xconnect = Native.Interface.CEM.Cem.Xconnect()
                    self.xconnect.parent = self
                    self._children_name_map["xconnect"] = "xconnect"

                    self.xconnect_pw_class = Native.Interface.CEM.Cem.XconnectPwClass()
                    self.xconnect_pw_class.parent = self
                    self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:cem" + "[number='" + str(self.number) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.CEM.Cem, ['number'], name, value)


                class Xconnect(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vcid
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: encapsulation
                    
                    	Data encapsulation method
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cem.Xconnect.Encapsulation>`
                    
                    .. attribute:: manual
                    
                    	Manually configure L2TP session parameters
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pw_class
                    
                    	Optional pseudowire\-class to use for advanced configuration
                    	**type**\: str
                    
                    .. attribute:: sequencing
                    
                    	Configure sequencing options for xconnect
                    	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cem.Xconnect.Sequencing>`
                    
                    .. attribute:: backup
                    
                    	Xconnect backup configuration commands
                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cem.Xconnect.Backup>`
                    
                    .. attribute:: mtu
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEM.Cem.Xconnect, self).__init__()

                        self.yang_name = "xconnect"
                        self.yang_parent_name = "cem"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.CEM.Cem.Xconnect.Backup))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEM.Cem.Xconnect.Encapsulation')])),
                            ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                            ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEM.Cem.Xconnect.Sequencing')])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                        ])
                        self.address = None
                        self.vcid = None
                        self.encapsulation = None
                        self.manual = None
                        self.pw_class = None
                        self.sequencing = None
                        self.mtu = None

                        self.backup = Native.Interface.CEM.Cem.Xconnect.Backup()
                        self.backup.parent = self
                        self._children_name_map["backup"] = "backup"
                        self._segment_path = lambda: "xconnect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEM.Cem.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Data encapsulation method

                        .. data:: mpls = 0

                        .. data:: l2tpv3 = 1

                        """

                        mpls = Enum.YLeaf(0, "mpls")

                        l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                    class Sequencing(Enum):
                        """
                        Sequencing (Enum Class)

                        Configure sequencing options for xconnect

                        .. data:: both = 0

                        .. data:: receive = 1

                        .. data:: transmit = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        receive = Enum.YLeaf(1, "receive")

                        transmit = Enum.YLeaf(2, "transmit")



                    class Backup(Entity):
                        """
                        Xconnect backup configuration commands
                        
                        .. attribute:: peer
                        
                        	Backup pseudowire
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cem.Xconnect.Backup.Peer>`
                        
                        .. attribute:: delay
                        
                        	backup delay time
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cem.Xconnect.Backup.Delay>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEM.Cem.Xconnect.Backup, self).__init__()

                            self.yang_name = "backup"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.CEM.Cem.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.CEM.Cem.Xconnect.Backup.Delay))])
                            self._leafs = OrderedDict()

                            self.peer = Native.Interface.CEM.Cem.Xconnect.Backup.Peer()
                            self.peer.parent = self
                            self._children_name_map["peer"] = "peer"

                            self.delay = Native.Interface.CEM.Cem.Xconnect.Backup.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "backup"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEM.Cem.Xconnect.Backup, [], name, value)


                        class Peer(Entity):
                            """
                            Backup pseudowire
                            
                            .. attribute:: peer_router_ip_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: priority
                            
                            	Optional priority to use for backup pseudowire
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEM.Cem.Xconnect.Backup.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.peer_router_ip_addr = None
                                self.vcid = None
                                self.pw_class = None
                                self.priority = None
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEM.Cem.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                        class Delay(Entity):
                            """
                            backup delay time
                            
                            .. attribute:: min
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEM.Cem.Xconnect.Backup.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEM.Cem.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                class XconnectPwClass(Entity):
                    """
                    
                    
                    .. attribute:: xconnect
                    
                    	Xconnect commands
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cem.XconnectPwClass.Xconnect>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEM.Cem.XconnectPwClass, self).__init__()

                        self.yang_name = "xconnect-pw-class"
                        self.yang_parent_name = "cem"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.CEM.Cem.XconnectPwClass.Xconnect))])
                        self._leafs = OrderedDict()

                        self.xconnect = Native.Interface.CEM.Cem.XconnectPwClass.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"
                        self._segment_path = lambda: "xconnect-pw-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEM.Cem.XconnectPwClass, [], name, value)


                    class Xconnect(Entity):
                        """
                        Xconnect commands
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_class
                        
                        	Pseudowire\-class to use for encapsulation and protocol configuration
                        	**type**\: str
                        
                        .. attribute:: udp
                        
                        	UDP
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cem.XconnectPwClass.Xconnect.Udp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEM.Cem.XconnectPwClass.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "xconnect-pw-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.CEM.Cem.XconnectPwClass.Xconnect.Udp))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.pw_class = None

                            self.udp = Native.Interface.CEM.Cem.XconnectPwClass.Xconnect.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEM.Cem.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                        class Udp(Entity):
                            """
                            UDP
                            
                            .. attribute:: port
                            
                            	UDP ports
                            	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Cem.XconnectPwClass.Xconnect.Udp.Port>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEM.Cem.XconnectPwClass.Xconnect.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port", ("port", Native.Interface.CEM.Cem.XconnectPwClass.Xconnect.Udp.Port))])
                                self._leafs = OrderedDict()

                                self.port = Native.Interface.CEM.Cem.XconnectPwClass.Xconnect.Udp.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEM.Cem.XconnectPwClass.Xconnect.Udp, [], name, value)


                            class Port(Entity):
                                """
                                UDP ports
                                
                                .. attribute:: local
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.CEM.Cem.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                    self.yang_name = "port"
                                    self.yang_parent_name = "udp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                    ])
                                    self.local = None
                                    self.remote = None
                                    self._segment_path = lambda: "port"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.CEM.Cem.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Pvc(Entity):
                """
                PVC
                
                .. attribute:: local_vpi_vci  (key)
                
                	Vpi and vci
                	**type**\: str
                
                .. attribute:: remote_vpi_vci
                
                	Vpi and vci
                	**type**\: str
                
                .. attribute:: l2transport
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ubr
                
                	UBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ubrplus
                
                	
                	**type**\:  :py:class:`Ubrplus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Ubrplus>`
                
                .. attribute:: cbr
                
                	CBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr
                
                	VBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr_rt
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr_nrt
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: oam_pvc
                
                	
                	**type**\:  :py:class:`OamPvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.OamPvc>`
                
                	**presence node**\: True
                
                .. attribute:: service_policy
                
                	
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.ServicePolicy>`
                
                .. attribute:: encapsulation
                
                	
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Encapsulation>`
                
                .. attribute:: xconnect
                
                	
                	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Xconnect>`
                
                .. attribute:: xconnect_pw_class
                
                	
                	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.XconnectPwClass>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.CEM.Pvc, self).__init__()

                    self.yang_name = "pvc"
                    self.yang_parent_name = "CEM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['local_vpi_vci']
                    self._child_classes = OrderedDict([("ubrplus", ("ubrplus", Native.Interface.CEM.Pvc.Ubrplus)), ("oam-pvc", ("oam_pvc", Native.Interface.CEM.Pvc.OamPvc)), ("service-policy", ("service_policy", Native.Interface.CEM.Pvc.ServicePolicy)), ("encapsulation", ("encapsulation", Native.Interface.CEM.Pvc.Encapsulation)), ("xconnect", ("xconnect", Native.Interface.CEM.Pvc.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.CEM.Pvc.XconnectPwClass))])
                    self._leafs = OrderedDict([
                        ('local_vpi_vci', (YLeaf(YType.str, 'local-vpi-vci'), ['str'])),
                        ('remote_vpi_vci', (YLeaf(YType.str, 'remote-vpi-vci'), ['str'])),
                        ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                        ('ubr', (YLeaf(YType.uint32, 'ubr'), ['int'])),
                        ('cbr', (YLeaf(YType.uint32, 'cbr'), ['int'])),
                        ('vbr', (YLeaf(YType.uint32, 'vbr'), ['int'])),
                        ('vbr_rt', (YLeaf(YType.uint32, 'vbr-rt'), ['int'])),
                        ('vbr_nrt', (YLeaf(YType.uint32, 'vbr-nrt'), ['int'])),
                    ])
                    self.local_vpi_vci = None
                    self.remote_vpi_vci = None
                    self.l2transport = None
                    self.ubr = None
                    self.cbr = None
                    self.vbr = None
                    self.vbr_rt = None
                    self.vbr_nrt = None

                    self.ubrplus = Native.Interface.CEM.Pvc.Ubrplus()
                    self.ubrplus.parent = self
                    self._children_name_map["ubrplus"] = "ubrplus"

                    self.oam_pvc = None
                    self._children_name_map["oam_pvc"] = "oam-pvc"

                    self.service_policy = Native.Interface.CEM.Pvc.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"

                    self.encapsulation = Native.Interface.CEM.Pvc.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"

                    self.xconnect = Native.Interface.CEM.Pvc.Xconnect()
                    self.xconnect.parent = self
                    self._children_name_map["xconnect"] = "xconnect"

                    self.xconnect_pw_class = Native.Interface.CEM.Pvc.XconnectPwClass()
                    self.xconnect_pw_class.parent = self
                    self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:pvc" + "[local-vpi-vci='" + str(self.local_vpi_vci) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.CEM.Pvc, ['local_vpi_vci', 'remote_vpi_vci', 'l2transport', 'ubr', 'cbr', 'vbr', 'vbr_rt', 'vbr_nrt'], name, value)


                class Ubrplus(Entity):
                    """
                    
                    
                    .. attribute:: pcr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mcr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEM.Pvc.Ubrplus, self).__init__()

                        self.yang_name = "ubrplus"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pcr', (YLeaf(YType.uint32, 'PCR'), ['int'])),
                            ('mcr', (YLeaf(YType.uint32, 'MCR'), ['int'])),
                        ])
                        self.pcr = None
                        self.mcr = None
                        self._segment_path = lambda: "ubrplus"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEM.Pvc.Ubrplus, ['pcr', 'mcr'], name, value)


                class OamPvc(Entity):
                    """
                    
                    
                    .. attribute:: loopback_frequency
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..600
                    
                    .. attribute:: manage
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEM.Pvc.OamPvc, self).__init__()

                        self.yang_name = "oam-pvc"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('loopback_frequency', (YLeaf(YType.uint32, 'loopback-frequency'), ['int'])),
                            ('manage', (YLeaf(YType.empty, 'manage'), ['Empty'])),
                        ])
                        self.loopback_frequency = None
                        self.manage = None
                        self._segment_path = lambda: "oam-pvc"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEM.Pvc.OamPvc, ['loopback_frequency', 'manage'], name, value)


                class ServicePolicy(Entity):
                    """
                    
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEM.Pvc.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEM.Pvc.ServicePolicy, ['input', 'output'], name, value)


                class Encapsulation(Entity):
                    """
                    
                    
                    .. attribute:: aal5autoppp
                    
                    	
                    	**type**\:  :py:class:`Aal5autoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Encapsulation.Aal5autoppp>`
                    
                    .. attribute:: aal5ciscoppp
                    
                    	
                    	**type**\:  :py:class:`Aal5ciscoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Encapsulation.Aal5ciscoppp>`
                    
                    .. attribute:: aal5mux
                    
                    	
                    	**type**\:  :py:class:`Aal5mux <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Encapsulation.Aal5mux>`
                    
                    .. attribute:: aal5nlpid
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: aal5snap
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEM.Pvc.Encapsulation, self).__init__()

                        self.yang_name = "encapsulation"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aal5autoppp", ("aal5autoppp", Native.Interface.CEM.Pvc.Encapsulation.Aal5autoppp)), ("aal5ciscoppp", ("aal5ciscoppp", Native.Interface.CEM.Pvc.Encapsulation.Aal5ciscoppp)), ("aal5mux", ("aal5mux", Native.Interface.CEM.Pvc.Encapsulation.Aal5mux))])
                        self._leafs = OrderedDict([
                            ('aal5nlpid', (YLeaf(YType.empty, 'aal5nlpid'), ['Empty'])),
                            ('aal5snap', (YLeaf(YType.empty, 'aal5snap'), ['Empty'])),
                        ])
                        self.aal5nlpid = None
                        self.aal5snap = None

                        self.aal5autoppp = Native.Interface.CEM.Pvc.Encapsulation.Aal5autoppp()
                        self.aal5autoppp.parent = self
                        self._children_name_map["aal5autoppp"] = "aal5autoppp"

                        self.aal5ciscoppp = Native.Interface.CEM.Pvc.Encapsulation.Aal5ciscoppp()
                        self.aal5ciscoppp.parent = self
                        self._children_name_map["aal5ciscoppp"] = "aal5ciscoppp"

                        self.aal5mux = Native.Interface.CEM.Pvc.Encapsulation.Aal5mux()
                        self.aal5mux.parent = self
                        self._children_name_map["aal5mux"] = "aal5mux"
                        self._segment_path = lambda: "encapsulation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEM.Pvc.Encapsulation, ['aal5nlpid', 'aal5snap'], name, value)


                    class Aal5autoppp(Entity):
                        """
                        
                        
                        .. attribute:: virtual_template
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEM.Pvc.Encapsulation.Aal5autoppp, self).__init__()

                            self.yang_name = "aal5autoppp"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                            ])
                            self.virtual_template = None
                            self._segment_path = lambda: "aal5autoppp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEM.Pvc.Encapsulation.Aal5autoppp, ['virtual_template'], name, value)


                    class Aal5ciscoppp(Entity):
                        """
                        
                        
                        .. attribute:: virtual_template
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEM.Pvc.Encapsulation.Aal5ciscoppp, self).__init__()

                            self.yang_name = "aal5ciscoppp"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                            ])
                            self.virtual_template = None
                            self._segment_path = lambda: "aal5ciscoppp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEM.Pvc.Encapsulation.Aal5ciscoppp, ['virtual_template'], name, value)


                    class Aal5mux(Entity):
                        """
                        
                        
                        .. attribute:: ppp
                        
                        	
                        	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Encapsulation.Aal5mux.Ppp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEM.Pvc.Encapsulation.Aal5mux, self).__init__()

                            self.yang_name = "aal5mux"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ppp", ("ppp", Native.Interface.CEM.Pvc.Encapsulation.Aal5mux.Ppp))])
                            self._leafs = OrderedDict()

                            self.ppp = Native.Interface.CEM.Pvc.Encapsulation.Aal5mux.Ppp()
                            self.ppp.parent = self
                            self._children_name_map["ppp"] = "ppp"
                            self._segment_path = lambda: "aal5mux"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEM.Pvc.Encapsulation.Aal5mux, [], name, value)


                        class Ppp(Entity):
                            """
                            
                            
                            .. attribute:: virtual_template
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dialer
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEM.Pvc.Encapsulation.Aal5mux.Ppp, self).__init__()

                                self.yang_name = "ppp"
                                self.yang_parent_name = "aal5mux"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                                    ('dialer', (YLeaf(YType.empty, 'dialer'), ['Empty'])),
                                ])
                                self.virtual_template = None
                                self.dialer = None
                                self._segment_path = lambda: "ppp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEM.Pvc.Encapsulation.Aal5mux.Ppp, ['virtual_template', 'dialer'], name, value)


                class Xconnect(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vcid
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: encapsulation
                    
                    	Data encapsulation method
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Xconnect.Encapsulation>`
                    
                    .. attribute:: manual
                    
                    	Manually configure L2TP session parameters
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pw_class
                    
                    	Optional pseudowire\-class to use for advanced configuration
                    	**type**\: str
                    
                    .. attribute:: sequencing
                    
                    	Configure sequencing options for xconnect
                    	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Xconnect.Sequencing>`
                    
                    .. attribute:: backup
                    
                    	Xconnect backup configuration commands
                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Xconnect.Backup>`
                    
                    .. attribute:: mtu
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEM.Pvc.Xconnect, self).__init__()

                        self.yang_name = "xconnect"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.CEM.Pvc.Xconnect.Backup))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEM.Pvc.Xconnect.Encapsulation')])),
                            ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                            ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEM.Pvc.Xconnect.Sequencing')])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                        ])
                        self.address = None
                        self.vcid = None
                        self.encapsulation = None
                        self.manual = None
                        self.pw_class = None
                        self.sequencing = None
                        self.mtu = None

                        self.backup = Native.Interface.CEM.Pvc.Xconnect.Backup()
                        self.backup.parent = self
                        self._children_name_map["backup"] = "backup"
                        self._segment_path = lambda: "xconnect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEM.Pvc.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Data encapsulation method

                        .. data:: mpls = 0

                        .. data:: l2tpv3 = 1

                        """

                        mpls = Enum.YLeaf(0, "mpls")

                        l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                    class Sequencing(Enum):
                        """
                        Sequencing (Enum Class)

                        Configure sequencing options for xconnect

                        .. data:: both = 0

                        .. data:: receive = 1

                        .. data:: transmit = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        receive = Enum.YLeaf(1, "receive")

                        transmit = Enum.YLeaf(2, "transmit")



                    class Backup(Entity):
                        """
                        Xconnect backup configuration commands
                        
                        .. attribute:: peer
                        
                        	Backup pseudowire
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Xconnect.Backup.Peer>`
                        
                        .. attribute:: delay
                        
                        	backup delay time
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.Xconnect.Backup.Delay>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEM.Pvc.Xconnect.Backup, self).__init__()

                            self.yang_name = "backup"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.CEM.Pvc.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.CEM.Pvc.Xconnect.Backup.Delay))])
                            self._leafs = OrderedDict()

                            self.peer = Native.Interface.CEM.Pvc.Xconnect.Backup.Peer()
                            self.peer.parent = self
                            self._children_name_map["peer"] = "peer"

                            self.delay = Native.Interface.CEM.Pvc.Xconnect.Backup.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "backup"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEM.Pvc.Xconnect.Backup, [], name, value)


                        class Peer(Entity):
                            """
                            Backup pseudowire
                            
                            .. attribute:: peer_router_ip_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: priority
                            
                            	Optional priority to use for backup pseudowire
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEM.Pvc.Xconnect.Backup.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.peer_router_ip_addr = None
                                self.vcid = None
                                self.pw_class = None
                                self.priority = None
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEM.Pvc.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                        class Delay(Entity):
                            """
                            backup delay time
                            
                            .. attribute:: min
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEM.Pvc.Xconnect.Backup.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEM.Pvc.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                class XconnectPwClass(Entity):
                    """
                    
                    
                    .. attribute:: xconnect
                    
                    	Xconnect commands
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEM.Pvc.XconnectPwClass, self).__init__()

                        self.yang_name = "xconnect-pw-class"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect))])
                        self._leafs = OrderedDict()

                        self.xconnect = Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"
                        self._segment_path = lambda: "xconnect-pw-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEM.Pvc.XconnectPwClass, [], name, value)


                    class Xconnect(Entity):
                        """
                        Xconnect commands
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_class
                        
                        	Pseudowire\-class to use for encapsulation and protocol configuration
                        	**type**\: str
                        
                        .. attribute:: udp
                        
                        	UDP
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect.Udp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "xconnect-pw-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect.Udp))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.pw_class = None

                            self.udp = Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                        class Udp(Entity):
                            """
                            UDP
                            
                            .. attribute:: port
                            
                            	UDP ports
                            	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect.Udp.Port>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port", ("port", Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect.Udp.Port))])
                                self._leafs = OrderedDict()

                                self.port = Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect.Udp.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect.Udp, [], name, value)


                            class Port(Entity):
                                """
                                UDP ports
                                
                                .. attribute:: local
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                    self.yang_name = "port"
                                    self.yang_parent_name = "udp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                    ])
                                    self.local = None
                                    self.remote = None
                                    self._segment_path = lambda: "port"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.CEM.Pvc.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


        class CEMACR(Entity):
            """
            Circuit Emulation interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: ip
            
            	IP address
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Ip>`
            
            .. attribute:: atm
            
            	ATM
            	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm>`
            
            .. attribute:: load_interval
            
            	Load interval
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: cdp
            
            	
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cdp>`
            
            .. attribute:: cem
            
            	CEM
            	**type**\: list of  		 :py:class:`Cem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cem>`
            
            .. attribute:: pvc
            
            	PVC
            	**type**\: list of  		 :py:class:`Pvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.CEMACR, self).__init__()

                self.yang_name = "CEM-ACR"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("Cisco-IOS-XE-atm:ip", ("ip", Native.Interface.CEMACR.Ip)), ("Cisco-IOS-XE-atm:atm", ("atm", Native.Interface.CEMACR.Atm)), ("Cisco-IOS-XE-atm:cem", ("cem", Native.Interface.CEMACR.Cem)), ("Cisco-IOS-XE-atm:pvc", ("pvc", Native.Interface.CEMACR.Pvc))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint8, 'name'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-atm:load-interval'), ['int'])),
                    ('cdp', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-atm:cdp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEMACR.Cdp')])),
                ])
                self.name = None
                self.load_interval = None
                self.cdp = None

                self.ip = Native.Interface.CEMACR.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "Cisco-IOS-XE-atm:ip"

                self.atm = Native.Interface.CEMACR.Atm()
                self.atm.parent = self
                self._children_name_map["atm"] = "Cisco-IOS-XE-atm:atm"

                self.cem = YList(self)
                self.pvc = YList(self)
                self._segment_path = lambda: "CEM-ACR" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.CEMACR, [u'name', 'load_interval', 'cdp'], name, value)

            class Cdp(Enum):
                """
                Cdp (Enum Class)

                .. data:: enable = 0

                """

                enable = Enum.YLeaf(0, "enable")



            class Ip(Entity):
                """
                IP address
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: split_horizon
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.CEMACR.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "CEM-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('split_horizon', (YLeaf(YType.empty, 'split-horizon'), ['Empty'])),
                    ])
                    self.address = None
                    self.split_horizon = None
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.CEMACR.Ip, ['address', 'split_horizon'], name, value)


            class Atm(Entity):
                """
                ATM
                
                .. attribute:: bandwidth
                
                	ATM bandwith
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Bandwidth>`
                
                .. attribute:: enable_ilmi_trap
                
                	Enable\-ilmi\-trap
                	**type**\: bool
                
                .. attribute:: ilmi_keepalive
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: route_bridged
                
                	
                	**type**\:  :py:class:`RouteBridged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.RouteBridged>`
                
                .. attribute:: pvp
                
                	PVP
                	**type**\: list of  		 :py:class:`Pvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Pvp>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.CEMACR.Atm, self).__init__()

                    self.yang_name = "atm"
                    self.yang_parent_name = "CEM-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("pvp", ("pvp", Native.Interface.CEMACR.Atm.Pvp))])
                    self._leafs = OrderedDict([
                        ('bandwidth', (YLeaf(YType.enumeration, 'bandwidth'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEMACR.Atm.Bandwidth')])),
                        ('enable_ilmi_trap', (YLeaf(YType.boolean, 'enable-ilmi-trap'), ['bool'])),
                        ('ilmi_keepalive', (YLeaf(YType.empty, 'ilmi-keepalive'), ['Empty'])),
                        ('route_bridged', (YLeaf(YType.enumeration, 'route-bridged'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEMACR.Atm.RouteBridged')])),
                    ])
                    self.bandwidth = None
                    self.enable_ilmi_trap = None
                    self.ilmi_keepalive = None
                    self.route_bridged = None

                    self.pvp = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:atm"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.CEMACR.Atm, ['bandwidth', 'enable_ilmi_trap', 'ilmi_keepalive', 'route_bridged'], name, value)

                class Bandwidth(Enum):
                    """
                    Bandwidth (Enum Class)

                    ATM bandwith

                    .. data:: dynamic = 0

                    """

                    dynamic = Enum.YLeaf(0, "dynamic")


                class RouteBridged(Enum):
                    """
                    RouteBridged (Enum Class)

                    .. data:: ip = 0

                    .. data:: ipv6 = 1

                    """

                    ip = Enum.YLeaf(0, "ip")

                    ipv6 = Enum.YLeaf(1, "ipv6")



                class Pvp(Entity):
                    """
                    PVP
                    
                    .. attribute:: pvp_number  (key)
                    
                    	PVP number
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: l2transport
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Pvp.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEMACR.Atm.Pvp, self).__init__()

                        self.yang_name = "pvp"
                        self.yang_parent_name = "atm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['pvp_number']
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.CEMACR.Atm.Pvp.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('pvp_number', (YLeaf(YType.uint16, 'pvp-number'), ['int'])),
                            ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                        ])
                        self.pvp_number = None
                        self.l2transport = None

                        self.xconnect = Native.Interface.CEMACR.Atm.Pvp.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"

                        self.xconnect_pw_class = Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                        self._segment_path = lambda: "pvp" + "[pvp-number='" + str(self.pvp_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEMACR.Atm.Pvp, ['pvp_number', 'l2transport'], name, value)


                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Pvp.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Pvp.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEMACR.Atm.Pvp.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "pvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEMACR.Atm.Pvp.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEMACR.Atm.Pvp.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEMACR.Atm.Pvp.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.CEMACR.Atm.Pvp.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "pvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-atm'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.CEMACR.Atm.Pvp.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Cem(Entity):
                """
                CEM
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: xconnect
                
                	
                	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cem.Xconnect>`
                
                .. attribute:: xconnect_pw_class
                
                	
                	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cem.XconnectPwClass>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.CEMACR.Cem, self).__init__()

                    self.yang_name = "cem"
                    self.yang_parent_name = "CEM-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.CEMACR.Cem.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.CEMACR.Cem.XconnectPwClass))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                    ])
                    self.number = None

                    self.xconnect = Native.Interface.CEMACR.Cem.Xconnect()
                    self.xconnect.parent = self
                    self._children_name_map["xconnect"] = "xconnect"

                    self.xconnect_pw_class = Native.Interface.CEMACR.Cem.XconnectPwClass()
                    self.xconnect_pw_class.parent = self
                    self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:cem" + "[number='" + str(self.number) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.CEMACR.Cem, ['number'], name, value)


                class Xconnect(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vcid
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: encapsulation
                    
                    	Data encapsulation method
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cem.Xconnect.Encapsulation>`
                    
                    .. attribute:: manual
                    
                    	Manually configure L2TP session parameters
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pw_class
                    
                    	Optional pseudowire\-class to use for advanced configuration
                    	**type**\: str
                    
                    .. attribute:: sequencing
                    
                    	Configure sequencing options for xconnect
                    	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cem.Xconnect.Sequencing>`
                    
                    .. attribute:: backup
                    
                    	Xconnect backup configuration commands
                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cem.Xconnect.Backup>`
                    
                    .. attribute:: mtu
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEMACR.Cem.Xconnect, self).__init__()

                        self.yang_name = "xconnect"
                        self.yang_parent_name = "cem"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.CEMACR.Cem.Xconnect.Backup))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEMACR.Cem.Xconnect.Encapsulation')])),
                            ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                            ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEMACR.Cem.Xconnect.Sequencing')])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                        ])
                        self.address = None
                        self.vcid = None
                        self.encapsulation = None
                        self.manual = None
                        self.pw_class = None
                        self.sequencing = None
                        self.mtu = None

                        self.backup = Native.Interface.CEMACR.Cem.Xconnect.Backup()
                        self.backup.parent = self
                        self._children_name_map["backup"] = "backup"
                        self._segment_path = lambda: "xconnect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEMACR.Cem.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Data encapsulation method

                        .. data:: mpls = 0

                        .. data:: l2tpv3 = 1

                        """

                        mpls = Enum.YLeaf(0, "mpls")

                        l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                    class Sequencing(Enum):
                        """
                        Sequencing (Enum Class)

                        Configure sequencing options for xconnect

                        .. data:: both = 0

                        .. data:: receive = 1

                        .. data:: transmit = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        receive = Enum.YLeaf(1, "receive")

                        transmit = Enum.YLeaf(2, "transmit")



                    class Backup(Entity):
                        """
                        Xconnect backup configuration commands
                        
                        .. attribute:: peer
                        
                        	Backup pseudowire
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cem.Xconnect.Backup.Peer>`
                        
                        .. attribute:: delay
                        
                        	backup delay time
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cem.Xconnect.Backup.Delay>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEMACR.Cem.Xconnect.Backup, self).__init__()

                            self.yang_name = "backup"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.CEMACR.Cem.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.CEMACR.Cem.Xconnect.Backup.Delay))])
                            self._leafs = OrderedDict()

                            self.peer = Native.Interface.CEMACR.Cem.Xconnect.Backup.Peer()
                            self.peer.parent = self
                            self._children_name_map["peer"] = "peer"

                            self.delay = Native.Interface.CEMACR.Cem.Xconnect.Backup.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "backup"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEMACR.Cem.Xconnect.Backup, [], name, value)


                        class Peer(Entity):
                            """
                            Backup pseudowire
                            
                            .. attribute:: peer_router_ip_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: priority
                            
                            	Optional priority to use for backup pseudowire
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEMACR.Cem.Xconnect.Backup.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.peer_router_ip_addr = None
                                self.vcid = None
                                self.pw_class = None
                                self.priority = None
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEMACR.Cem.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                        class Delay(Entity):
                            """
                            backup delay time
                            
                            .. attribute:: min
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEMACR.Cem.Xconnect.Backup.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEMACR.Cem.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                class XconnectPwClass(Entity):
                    """
                    
                    
                    .. attribute:: xconnect
                    
                    	Xconnect commands
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEMACR.Cem.XconnectPwClass, self).__init__()

                        self.yang_name = "xconnect-pw-class"
                        self.yang_parent_name = "cem"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect))])
                        self._leafs = OrderedDict()

                        self.xconnect = Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"
                        self._segment_path = lambda: "xconnect-pw-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEMACR.Cem.XconnectPwClass, [], name, value)


                    class Xconnect(Entity):
                        """
                        Xconnect commands
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_class
                        
                        	Pseudowire\-class to use for encapsulation and protocol configuration
                        	**type**\: str
                        
                        .. attribute:: udp
                        
                        	UDP
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect.Udp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "xconnect-pw-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect.Udp))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.pw_class = None

                            self.udp = Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                        class Udp(Entity):
                            """
                            UDP
                            
                            .. attribute:: port
                            
                            	UDP ports
                            	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect.Udp.Port>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port", ("port", Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect.Udp.Port))])
                                self._leafs = OrderedDict()

                                self.port = Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect.Udp.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect.Udp, [], name, value)


                            class Port(Entity):
                                """
                                UDP ports
                                
                                .. attribute:: local
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                    self.yang_name = "port"
                                    self.yang_parent_name = "udp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                    ])
                                    self.local = None
                                    self.remote = None
                                    self._segment_path = lambda: "port"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.CEMACR.Cem.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Pvc(Entity):
                """
                PVC
                
                .. attribute:: local_vpi_vci  (key)
                
                	Vpi and vci
                	**type**\: str
                
                .. attribute:: remote_vpi_vci
                
                	Vpi and vci
                	**type**\: str
                
                .. attribute:: l2transport
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ubr
                
                	UBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ubrplus
                
                	
                	**type**\:  :py:class:`Ubrplus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Ubrplus>`
                
                .. attribute:: cbr
                
                	CBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr
                
                	VBR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr_rt
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vbr_nrt
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: oam_pvc
                
                	
                	**type**\:  :py:class:`OamPvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.OamPvc>`
                
                	**presence node**\: True
                
                .. attribute:: service_policy
                
                	
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.ServicePolicy>`
                
                .. attribute:: encapsulation
                
                	
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Encapsulation>`
                
                .. attribute:: xconnect
                
                	
                	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Xconnect>`
                
                .. attribute:: xconnect_pw_class
                
                	
                	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.XconnectPwClass>`
                
                

                """

                _prefix = 'ios-atm'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.CEMACR.Pvc, self).__init__()

                    self.yang_name = "pvc"
                    self.yang_parent_name = "CEM-ACR"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['local_vpi_vci']
                    self._child_classes = OrderedDict([("ubrplus", ("ubrplus", Native.Interface.CEMACR.Pvc.Ubrplus)), ("oam-pvc", ("oam_pvc", Native.Interface.CEMACR.Pvc.OamPvc)), ("service-policy", ("service_policy", Native.Interface.CEMACR.Pvc.ServicePolicy)), ("encapsulation", ("encapsulation", Native.Interface.CEMACR.Pvc.Encapsulation)), ("xconnect", ("xconnect", Native.Interface.CEMACR.Pvc.Xconnect)), ("xconnect-pw-class", ("xconnect_pw_class", Native.Interface.CEMACR.Pvc.XconnectPwClass))])
                    self._leafs = OrderedDict([
                        ('local_vpi_vci', (YLeaf(YType.str, 'local-vpi-vci'), ['str'])),
                        ('remote_vpi_vci', (YLeaf(YType.str, 'remote-vpi-vci'), ['str'])),
                        ('l2transport', (YLeaf(YType.empty, 'l2transport'), ['Empty'])),
                        ('ubr', (YLeaf(YType.uint32, 'ubr'), ['int'])),
                        ('cbr', (YLeaf(YType.uint32, 'cbr'), ['int'])),
                        ('vbr', (YLeaf(YType.uint32, 'vbr'), ['int'])),
                        ('vbr_rt', (YLeaf(YType.uint32, 'vbr-rt'), ['int'])),
                        ('vbr_nrt', (YLeaf(YType.uint32, 'vbr-nrt'), ['int'])),
                    ])
                    self.local_vpi_vci = None
                    self.remote_vpi_vci = None
                    self.l2transport = None
                    self.ubr = None
                    self.cbr = None
                    self.vbr = None
                    self.vbr_rt = None
                    self.vbr_nrt = None

                    self.ubrplus = Native.Interface.CEMACR.Pvc.Ubrplus()
                    self.ubrplus.parent = self
                    self._children_name_map["ubrplus"] = "ubrplus"

                    self.oam_pvc = None
                    self._children_name_map["oam_pvc"] = "oam-pvc"

                    self.service_policy = Native.Interface.CEMACR.Pvc.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"

                    self.encapsulation = Native.Interface.CEMACR.Pvc.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"

                    self.xconnect = Native.Interface.CEMACR.Pvc.Xconnect()
                    self.xconnect.parent = self
                    self._children_name_map["xconnect"] = "xconnect"

                    self.xconnect_pw_class = Native.Interface.CEMACR.Pvc.XconnectPwClass()
                    self.xconnect_pw_class.parent = self
                    self._children_name_map["xconnect_pw_class"] = "xconnect-pw-class"
                    self._segment_path = lambda: "Cisco-IOS-XE-atm:pvc" + "[local-vpi-vci='" + str(self.local_vpi_vci) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.CEMACR.Pvc, ['local_vpi_vci', 'remote_vpi_vci', 'l2transport', 'ubr', 'cbr', 'vbr', 'vbr_rt', 'vbr_nrt'], name, value)


                class Ubrplus(Entity):
                    """
                    
                    
                    .. attribute:: pcr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mcr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEMACR.Pvc.Ubrplus, self).__init__()

                        self.yang_name = "ubrplus"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pcr', (YLeaf(YType.uint32, 'PCR'), ['int'])),
                            ('mcr', (YLeaf(YType.uint32, 'MCR'), ['int'])),
                        ])
                        self.pcr = None
                        self.mcr = None
                        self._segment_path = lambda: "ubrplus"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEMACR.Pvc.Ubrplus, ['pcr', 'mcr'], name, value)


                class OamPvc(Entity):
                    """
                    
                    
                    .. attribute:: loopback_frequency
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..600
                    
                    .. attribute:: manage
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEMACR.Pvc.OamPvc, self).__init__()

                        self.yang_name = "oam-pvc"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('loopback_frequency', (YLeaf(YType.uint32, 'loopback-frequency'), ['int'])),
                            ('manage', (YLeaf(YType.empty, 'manage'), ['Empty'])),
                        ])
                        self.loopback_frequency = None
                        self.manage = None
                        self._segment_path = lambda: "oam-pvc"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEMACR.Pvc.OamPvc, ['loopback_frequency', 'manage'], name, value)


                class ServicePolicy(Entity):
                    """
                    
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEMACR.Pvc.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEMACR.Pvc.ServicePolicy, ['input', 'output'], name, value)


                class Encapsulation(Entity):
                    """
                    
                    
                    .. attribute:: aal5autoppp
                    
                    	
                    	**type**\:  :py:class:`Aal5autoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Encapsulation.Aal5autoppp>`
                    
                    .. attribute:: aal5ciscoppp
                    
                    	
                    	**type**\:  :py:class:`Aal5ciscoppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Encapsulation.Aal5ciscoppp>`
                    
                    .. attribute:: aal5mux
                    
                    	
                    	**type**\:  :py:class:`Aal5mux <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Encapsulation.Aal5mux>`
                    
                    .. attribute:: aal5nlpid
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: aal5snap
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEMACR.Pvc.Encapsulation, self).__init__()

                        self.yang_name = "encapsulation"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aal5autoppp", ("aal5autoppp", Native.Interface.CEMACR.Pvc.Encapsulation.Aal5autoppp)), ("aal5ciscoppp", ("aal5ciscoppp", Native.Interface.CEMACR.Pvc.Encapsulation.Aal5ciscoppp)), ("aal5mux", ("aal5mux", Native.Interface.CEMACR.Pvc.Encapsulation.Aal5mux))])
                        self._leafs = OrderedDict([
                            ('aal5nlpid', (YLeaf(YType.empty, 'aal5nlpid'), ['Empty'])),
                            ('aal5snap', (YLeaf(YType.empty, 'aal5snap'), ['Empty'])),
                        ])
                        self.aal5nlpid = None
                        self.aal5snap = None

                        self.aal5autoppp = Native.Interface.CEMACR.Pvc.Encapsulation.Aal5autoppp()
                        self.aal5autoppp.parent = self
                        self._children_name_map["aal5autoppp"] = "aal5autoppp"

                        self.aal5ciscoppp = Native.Interface.CEMACR.Pvc.Encapsulation.Aal5ciscoppp()
                        self.aal5ciscoppp.parent = self
                        self._children_name_map["aal5ciscoppp"] = "aal5ciscoppp"

                        self.aal5mux = Native.Interface.CEMACR.Pvc.Encapsulation.Aal5mux()
                        self.aal5mux.parent = self
                        self._children_name_map["aal5mux"] = "aal5mux"
                        self._segment_path = lambda: "encapsulation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEMACR.Pvc.Encapsulation, ['aal5nlpid', 'aal5snap'], name, value)


                    class Aal5autoppp(Entity):
                        """
                        
                        
                        .. attribute:: virtual_template
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEMACR.Pvc.Encapsulation.Aal5autoppp, self).__init__()

                            self.yang_name = "aal5autoppp"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                            ])
                            self.virtual_template = None
                            self._segment_path = lambda: "aal5autoppp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEMACR.Pvc.Encapsulation.Aal5autoppp, ['virtual_template'], name, value)


                    class Aal5ciscoppp(Entity):
                        """
                        
                        
                        .. attribute:: virtual_template
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEMACR.Pvc.Encapsulation.Aal5ciscoppp, self).__init__()

                            self.yang_name = "aal5ciscoppp"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                            ])
                            self.virtual_template = None
                            self._segment_path = lambda: "aal5ciscoppp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEMACR.Pvc.Encapsulation.Aal5ciscoppp, ['virtual_template'], name, value)


                    class Aal5mux(Entity):
                        """
                        
                        
                        .. attribute:: ppp
                        
                        	
                        	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Encapsulation.Aal5mux.Ppp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEMACR.Pvc.Encapsulation.Aal5mux, self).__init__()

                            self.yang_name = "aal5mux"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ppp", ("ppp", Native.Interface.CEMACR.Pvc.Encapsulation.Aal5mux.Ppp))])
                            self._leafs = OrderedDict()

                            self.ppp = Native.Interface.CEMACR.Pvc.Encapsulation.Aal5mux.Ppp()
                            self.ppp.parent = self
                            self._children_name_map["ppp"] = "ppp"
                            self._segment_path = lambda: "aal5mux"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEMACR.Pvc.Encapsulation.Aal5mux, [], name, value)


                        class Ppp(Entity):
                            """
                            
                            
                            .. attribute:: virtual_template
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dialer
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEMACR.Pvc.Encapsulation.Aal5mux.Ppp, self).__init__()

                                self.yang_name = "ppp"
                                self.yang_parent_name = "aal5mux"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('virtual_template', (YLeaf(YType.uint32, 'Virtual-Template'), ['int'])),
                                    ('dialer', (YLeaf(YType.empty, 'dialer'), ['Empty'])),
                                ])
                                self.virtual_template = None
                                self.dialer = None
                                self._segment_path = lambda: "ppp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEMACR.Pvc.Encapsulation.Aal5mux.Ppp, ['virtual_template', 'dialer'], name, value)


                class Xconnect(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vcid
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: encapsulation
                    
                    	Data encapsulation method
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Xconnect.Encapsulation>`
                    
                    .. attribute:: manual
                    
                    	Manually configure L2TP session parameters
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pw_class
                    
                    	Optional pseudowire\-class to use for advanced configuration
                    	**type**\: str
                    
                    .. attribute:: sequencing
                    
                    	Configure sequencing options for xconnect
                    	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Xconnect.Sequencing>`
                    
                    .. attribute:: backup
                    
                    	Xconnect backup configuration commands
                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Xconnect.Backup>`
                    
                    .. attribute:: mtu
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEMACR.Pvc.Xconnect, self).__init__()

                        self.yang_name = "xconnect"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.CEMACR.Pvc.Xconnect.Backup))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEMACR.Pvc.Xconnect.Encapsulation')])),
                            ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                            ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.CEMACR.Pvc.Xconnect.Sequencing')])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                        ])
                        self.address = None
                        self.vcid = None
                        self.encapsulation = None
                        self.manual = None
                        self.pw_class = None
                        self.sequencing = None
                        self.mtu = None

                        self.backup = Native.Interface.CEMACR.Pvc.Xconnect.Backup()
                        self.backup.parent = self
                        self._children_name_map["backup"] = "backup"
                        self._segment_path = lambda: "xconnect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEMACR.Pvc.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Data encapsulation method

                        .. data:: mpls = 0

                        .. data:: l2tpv3 = 1

                        """

                        mpls = Enum.YLeaf(0, "mpls")

                        l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                    class Sequencing(Enum):
                        """
                        Sequencing (Enum Class)

                        Configure sequencing options for xconnect

                        .. data:: both = 0

                        .. data:: receive = 1

                        .. data:: transmit = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        receive = Enum.YLeaf(1, "receive")

                        transmit = Enum.YLeaf(2, "transmit")



                    class Backup(Entity):
                        """
                        Xconnect backup configuration commands
                        
                        .. attribute:: peer
                        
                        	Backup pseudowire
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Xconnect.Backup.Peer>`
                        
                        .. attribute:: delay
                        
                        	backup delay time
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.Xconnect.Backup.Delay>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEMACR.Pvc.Xconnect.Backup, self).__init__()

                            self.yang_name = "backup"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.CEMACR.Pvc.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.CEMACR.Pvc.Xconnect.Backup.Delay))])
                            self._leafs = OrderedDict()

                            self.peer = Native.Interface.CEMACR.Pvc.Xconnect.Backup.Peer()
                            self.peer.parent = self
                            self._children_name_map["peer"] = "peer"

                            self.delay = Native.Interface.CEMACR.Pvc.Xconnect.Backup.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "backup"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEMACR.Pvc.Xconnect.Backup, [], name, value)


                        class Peer(Entity):
                            """
                            Backup pseudowire
                            
                            .. attribute:: peer_router_ip_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: priority
                            
                            	Optional priority to use for backup pseudowire
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEMACR.Pvc.Xconnect.Backup.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.peer_router_ip_addr = None
                                self.vcid = None
                                self.pw_class = None
                                self.priority = None
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEMACR.Pvc.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                        class Delay(Entity):
                            """
                            backup delay time
                            
                            .. attribute:: min
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEMACR.Pvc.Xconnect.Backup.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEMACR.Pvc.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                class XconnectPwClass(Entity):
                    """
                    
                    
                    .. attribute:: xconnect
                    
                    	Xconnect commands
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect>`
                    
                    

                    """

                    _prefix = 'ios-atm'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.CEMACR.Pvc.XconnectPwClass, self).__init__()

                        self.yang_name = "xconnect-pw-class"
                        self.yang_parent_name = "pvc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect))])
                        self._leafs = OrderedDict()

                        self.xconnect = Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "xconnect"
                        self._segment_path = lambda: "xconnect-pw-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.CEMACR.Pvc.XconnectPwClass, [], name, value)


                    class Xconnect(Entity):
                        """
                        Xconnect commands
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_class
                        
                        	Pseudowire\-class to use for encapsulation and protocol configuration
                        	**type**\: str
                        
                        .. attribute:: udp
                        
                        	UDP
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect.Udp>`
                        
                        

                        """

                        _prefix = 'ios-atm'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "xconnect-pw-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect.Udp))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.pw_class = None

                            self.udp = Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"
                            self._segment_path = lambda: "xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                        class Udp(Entity):
                            """
                            UDP
                            
                            .. attribute:: port
                            
                            	UDP ports
                            	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port>`
                            
                            

                            """

                            _prefix = 'ios-atm'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("port", ("port", Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port))])
                                self._leafs = OrderedDict()

                                self.port = Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect.Udp, [], name, value)


                            class Port(Entity):
                                """
                                UDP ports
                                
                                .. attribute:: local
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-atm'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                    self.yang_name = "port"
                                    self.yang_parent_name = "udp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                    ])
                                    self.local = None
                                    self.remote = None
                                    self._segment_path = lambda: "port"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.CEMACR.Pvc.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


        class EmbeddedServiceEngine(Entity):
            """
            cisco embedded service engine module
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.PmPath>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.EmbeddedServiceEngine, self).__init__()

                self.yang_name = "Embedded-Service-Engine"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.EmbeddedServiceEngine.SwitchportConf)), ("switchport", ("switchport", Native.Interface.EmbeddedServiceEngine.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.EmbeddedServiceEngine.StackwiseVirtual)), ("arp", ("arp", Native.Interface.EmbeddedServiceEngine.Arp)), ("backup", ("backup", Native.Interface.EmbeddedServiceEngine.Backup)), ("cemoudp", ("cemoudp", Native.Interface.EmbeddedServiceEngine.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.EmbeddedServiceEngine.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.EmbeddedServiceEngine.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.EmbeddedServiceEngine.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.EmbeddedServiceEngine.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.EmbeddedServiceEngine.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.EmbeddedServiceEngine.Flowcontrol)), ("isis", ("isis", Native.Interface.EmbeddedServiceEngine.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.EmbeddedServiceEngine.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.EmbeddedServiceEngine.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.EmbeddedServiceEngine.Bandwidth)), ("dampening", ("dampening", Native.Interface.EmbeddedServiceEngine.Dampening)), ("domain", ("domain", Native.Interface.EmbeddedServiceEngine.Domain)), ("hold-queue", ("hold_queue", Native.Interface.EmbeddedServiceEngine.HoldQueue)), ("mpls", ("mpls", Native.Interface.EmbeddedServiceEngine.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.EmbeddedServiceEngine.IpVrf)), ("vrf", ("vrf", Native.Interface.EmbeddedServiceEngine.Vrf)), ("ip", ("ip", Native.Interface.EmbeddedServiceEngine.Ip)), ("ipv6", ("ipv6", Native.Interface.EmbeddedServiceEngine.Ipv6)), ("logging", ("logging", Native.Interface.EmbeddedServiceEngine.Logging)), ("mdix", ("mdix", Native.Interface.EmbeddedServiceEngine.Mdix)), ("mop", ("mop", Native.Interface.EmbeddedServiceEngine.Mop)), ("interface_qos", ("interface_qos", Native.Interface.EmbeddedServiceEngine.InterfaceQos)), ("source", ("source", Native.Interface.EmbeddedServiceEngine.Source)), ("standby", ("standby", Native.Interface.EmbeddedServiceEngine.Standby)), ("access-session", ("access_session", Native.Interface.EmbeddedServiceEngine.AccessSession)), ("storm-control", ("storm_control", Native.Interface.EmbeddedServiceEngine.StormControl)), ("trust", ("trust", Native.Interface.EmbeddedServiceEngine.Trust)), ("priority-queue", ("priority_queue", Native.Interface.EmbeddedServiceEngine.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.EmbeddedServiceEngine.RcvQueue)), ("peer", ("peer", Native.Interface.EmbeddedServiceEngine.Peer)), ("pm-path", ("pm_path", Native.Interface.EmbeddedServiceEngine.PmPath))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.EmbeddedServiceEngine.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.EmbeddedServiceEngine.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.EmbeddedServiceEngine.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.EmbeddedServiceEngine.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.EmbeddedServiceEngine.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.EmbeddedServiceEngine.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.EmbeddedServiceEngine.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.EmbeddedServiceEngine.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.EmbeddedServiceEngine.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.EmbeddedServiceEngine.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.EmbeddedServiceEngine.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.EmbeddedServiceEngine.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.EmbeddedServiceEngine.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.EmbeddedServiceEngine.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.EmbeddedServiceEngine.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.EmbeddedServiceEngine.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.EmbeddedServiceEngine.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.EmbeddedServiceEngine.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.EmbeddedServiceEngine.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.EmbeddedServiceEngine.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.EmbeddedServiceEngine.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.EmbeddedServiceEngine.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.EmbeddedServiceEngine.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.EmbeddedServiceEngine.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.EmbeddedServiceEngine.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.EmbeddedServiceEngine.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.EmbeddedServiceEngine.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.EmbeddedServiceEngine.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.EmbeddedServiceEngine.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.EmbeddedServiceEngine.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.EmbeddedServiceEngine.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.EmbeddedServiceEngine.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.EmbeddedServiceEngine.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.EmbeddedServiceEngine.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.EmbeddedServiceEngine.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "Embedded-Service-Engine" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.EmbeddedServiceEngine, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.EmbeddedServiceEngine.Backup.Delay)), ("interface", ("interface", Native.Interface.EmbeddedServiceEngine.Backup.Interface_)), ("load", ("load", Native.Interface.EmbeddedServiceEngine.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.EmbeddedServiceEngine.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.EmbeddedServiceEngine.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.EmbeddedServiceEngine.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.EmbeddedServiceEngine.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.EmbeddedServiceEngine.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.EmbeddedServiceEngine.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.EmbeddedServiceEngine.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.EmbeddedServiceEngine.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.EmbeddedServiceEngine.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.EmbeddedServiceEngine.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.EmbeddedServiceEngine.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.EmbeddedServiceEngine.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.EmbeddedServiceEngine.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.EmbeddedServiceEngine.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.EmbeddedServiceEngine.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.EmbeddedServiceEngine.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.EmbeddedServiceEngine.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.EmbeddedServiceEngine.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.EmbeddedServiceEngine.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.EmbeddedServiceEngine.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.EmbeddedServiceEngine.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.EmbeddedServiceEngine.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.EmbeddedServiceEngine.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.EmbeddedServiceEngine.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.EmbeddedServiceEngine.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.EmbeddedServiceEngine.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.EmbeddedServiceEngine.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.EmbeddedServiceEngine.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.EmbeddedServiceEngine.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.EmbeddedServiceEngine.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.EmbeddedServiceEngine.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.EmbeddedServiceEngine.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.EmbeddedServiceEngine.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.EmbeddedServiceEngine.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.EmbeddedServiceEngine.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.EmbeddedServiceEngine.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.EmbeddedServiceEngine.Ip.Arp)), ("vrf", ("vrf", Native.Interface.EmbeddedServiceEngine.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.EmbeddedServiceEngine.Ip.NoAddress)), ("address", ("address", Native.Interface.EmbeddedServiceEngine.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.EmbeddedServiceEngine.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.EmbeddedServiceEngine.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.EmbeddedServiceEngine.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.EmbeddedServiceEngine.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.EmbeddedServiceEngine.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.EmbeddedServiceEngine.Ip.Pim)), ("policy", ("policy", Native.Interface.EmbeddedServiceEngine.Ip.Policy)), ("rip", ("rip", Native.Interface.EmbeddedServiceEngine.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.EmbeddedServiceEngine.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.EmbeddedServiceEngine.Ip.RouteCache)), ("router", ("router", Native.Interface.EmbeddedServiceEngine.Ip.Router)), ("tcp", ("tcp", Native.Interface.EmbeddedServiceEngine.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.EmbeddedServiceEngine.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.EmbeddedServiceEngine.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.EmbeddedServiceEngine.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.EmbeddedServiceEngine.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.EmbeddedServiceEngine.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.EmbeddedServiceEngine.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.EmbeddedServiceEngine.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.EmbeddedServiceEngine.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.EmbeddedServiceEngine.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.EmbeddedServiceEngine.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.EmbeddedServiceEngine.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.EmbeddedServiceEngine.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.EmbeddedServiceEngine.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.EmbeddedServiceEngine.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.EmbeddedServiceEngine.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.EmbeddedServiceEngine.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.EmbeddedServiceEngine.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.EmbeddedServiceEngine.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.EmbeddedServiceEngine.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.EmbeddedServiceEngine.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.EmbeddedServiceEngine.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.EmbeddedServiceEngine.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.EmbeddedServiceEngine.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.EmbeddedServiceEngine.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.EmbeddedServiceEngine.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.EmbeddedServiceEngine.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.EmbeddedServiceEngine.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.EmbeddedServiceEngine.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.EmbeddedServiceEngine.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.EmbeddedServiceEngine.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.EmbeddedServiceEngine.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.EmbeddedServiceEngine.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.EmbeddedServiceEngine.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.EmbeddedServiceEngine.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.EmbeddedServiceEngine.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.EmbeddedServiceEngine.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.EmbeddedServiceEngine.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.EmbeddedServiceEngine.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.EmbeddedServiceEngine.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.EmbeddedServiceEngine.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.EmbeddedServiceEngine.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.EmbeddedServiceEngine.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.EmbeddedServiceEngine.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.EmbeddedServiceEngine.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.EmbeddedServiceEngine.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.EmbeddedServiceEngine.Ipv6.Dhcp)), ("address", ("address", Native.Interface.EmbeddedServiceEngine.Ipv6.Address)), ("nd", ("nd", Native.Interface.EmbeddedServiceEngine.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.EmbeddedServiceEngine.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.EmbeddedServiceEngine.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.EmbeddedServiceEngine.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.EmbeddedServiceEngine.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.EmbeddedServiceEngine.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.EmbeddedServiceEngine.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.EmbeddedServiceEngine.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.EmbeddedServiceEngine.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.EmbeddedServiceEngine.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.EmbeddedServiceEngine.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.EmbeddedServiceEngine.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.EmbeddedServiceEngine.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.EmbeddedServiceEngine.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.EmbeddedServiceEngine.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.EmbeddedServiceEngine.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.EmbeddedServiceEngine.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.EmbeddedServiceEngine.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.EmbeddedServiceEngine.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.EmbeddedServiceEngine.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.EmbeddedServiceEngine.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.EmbeddedServiceEngine.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.EmbeddedServiceEngine.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.EmbeddedServiceEngine.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.EmbeddedServiceEngine.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.EmbeddedServiceEngine.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.EmbeddedServiceEngine.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.EmbeddedServiceEngine.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.EmbeddedServiceEngine.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.EmbeddedServiceEngine.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.EmbeddedServiceEngine.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.EmbeddedServiceEngine.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.EmbeddedServiceEngine.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.EmbeddedServiceEngine.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.EmbeddedServiceEngine.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EmbeddedServiceEngine.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.EmbeddedServiceEngine.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.EmbeddedServiceEngine.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.EmbeddedServiceEngine.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.EmbeddedServiceEngine.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.EmbeddedServiceEngine.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EmbeddedServiceEngine.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EmbeddedServiceEngine.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Embedded-Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EmbeddedServiceEngine.PmPath, [u'name', u'interface_id'], name, value)


        class Ethernet(Entity):
            """
            IEEE 802.3
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.PmPath>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Utd>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Umbrella>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Ethernet, self).__init__()

                self.yang_name = "Ethernet"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.Ethernet.SwitchportConf)), ("switchport", ("switchport", Native.Interface.Ethernet.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.Ethernet.StackwiseVirtual)), ("arp", ("arp", Native.Interface.Ethernet.Arp)), ("backup", ("backup", Native.Interface.Ethernet.Backup)), ("cemoudp", ("cemoudp", Native.Interface.Ethernet.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.Ethernet.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.Ethernet.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.Ethernet.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.Ethernet.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.Ethernet.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.Ethernet.Flowcontrol)), ("isis", ("isis", Native.Interface.Ethernet.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.Ethernet.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.Ethernet.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.Ethernet.Bandwidth)), ("dampening", ("dampening", Native.Interface.Ethernet.Dampening)), ("domain", ("domain", Native.Interface.Ethernet.Domain)), ("hold-queue", ("hold_queue", Native.Interface.Ethernet.HoldQueue)), ("mpls", ("mpls", Native.Interface.Ethernet.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.Ethernet.IpVrf)), ("vrf", ("vrf", Native.Interface.Ethernet.Vrf)), ("ip", ("ip", Native.Interface.Ethernet.Ip)), ("ipv6", ("ipv6", Native.Interface.Ethernet.Ipv6)), ("logging", ("logging", Native.Interface.Ethernet.Logging)), ("mdix", ("mdix", Native.Interface.Ethernet.Mdix)), ("mop", ("mop", Native.Interface.Ethernet.Mop)), ("interface_qos", ("interface_qos", Native.Interface.Ethernet.InterfaceQos)), ("source", ("source", Native.Interface.Ethernet.Source)), ("standby", ("standby", Native.Interface.Ethernet.Standby)), ("access-session", ("access_session", Native.Interface.Ethernet.AccessSession)), ("storm-control", ("storm_control", Native.Interface.Ethernet.StormControl)), ("trust", ("trust", Native.Interface.Ethernet.Trust)), ("priority-queue", ("priority_queue", Native.Interface.Ethernet.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.Ethernet.RcvQueue)), ("peer", ("peer", Native.Interface.Ethernet.Peer)), ("pm-path", ("pm_path", Native.Interface.Ethernet.PmPath)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.Ethernet.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.Ethernet.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.Ethernet.Utd)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.Ethernet.Umbrella))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.Ethernet.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.Ethernet.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.Ethernet.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.Ethernet.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.Ethernet.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.Ethernet.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.Ethernet.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.Ethernet.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.Ethernet.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.Ethernet.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.Ethernet.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.Ethernet.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.Ethernet.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.Ethernet.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.Ethernet.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.Ethernet.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.Ethernet.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.Ethernet.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.Ethernet.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.Ethernet.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.Ethernet.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.Ethernet.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.Ethernet.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.Ethernet.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.Ethernet.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.Ethernet.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.Ethernet.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.Ethernet.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.Ethernet.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.Ethernet.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.Ethernet.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.Ethernet.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.Ethernet.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.Ethernet.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.Ethernet.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.et_analytics = Native.Interface.Ethernet.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.Ethernet.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.Ethernet.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.umbrella = Native.Interface.Ethernet.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "Ethernet" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Ethernet, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Ethernet.Backup.Delay)), ("interface", ("interface", Native.Interface.Ethernet.Backup.Interface_)), ("load", ("load", Native.Interface.Ethernet.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Ethernet.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Ethernet.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Ethernet.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Ethernet.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Ethernet.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Ethernet.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Ethernet.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Ethernet.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Ethernet.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Ethernet.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Ethernet.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Ethernet.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Ethernet.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Ethernet.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Ethernet.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Ethernet.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Ethernet.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Ethernet.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Ethernet.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Ethernet.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Ethernet.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Ethernet.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.Ethernet.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Ethernet.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Ethernet.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Ethernet.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Ethernet.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Ethernet.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Ethernet.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Ethernet.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Ethernet.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Ethernet.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Ethernet.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Ethernet.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Ethernet.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Ethernet.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Ethernet.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.Ethernet.Ip.Arp)), ("vrf", ("vrf", Native.Interface.Ethernet.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.Ethernet.Ip.NoAddress)), ("address", ("address", Native.Interface.Ethernet.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Ethernet.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Ethernet.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.Ethernet.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.Ethernet.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Ethernet.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.Ethernet.Ip.Pim)), ("policy", ("policy", Native.Interface.Ethernet.Ip.Policy)), ("rip", ("rip", Native.Interface.Ethernet.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Ethernet.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Ethernet.Ip.RouteCache)), ("router", ("router", Native.Interface.Ethernet.Ip.Router)), ("tcp", ("tcp", Native.Interface.Ethernet.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Ethernet.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Ethernet.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Ethernet.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.Ethernet.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.Ethernet.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Ethernet.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Ethernet.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Ethernet.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Ethernet.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Ethernet.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Ethernet.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Ethernet.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Ethernet.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Ethernet.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Ethernet.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Ethernet.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Ethernet.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Ethernet.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Ethernet.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Ethernet.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Ethernet.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Ethernet.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Ethernet.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.Ethernet.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Ethernet.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Ethernet.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Ethernet.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Ethernet.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Ethernet.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Ethernet.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Ethernet.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Ethernet.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Ethernet.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Ethernet.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Ethernet.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Ethernet.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Ethernet.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Ethernet.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Ethernet.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Ethernet.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Ethernet.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.Ethernet.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Ethernet.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Ethernet.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Ethernet.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Ethernet.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Ethernet.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Ethernet.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Ethernet.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Ethernet.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Ethernet.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Ethernet.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Ethernet.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Ethernet.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Ethernet.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Ethernet.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Ethernet.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.Ethernet.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Ethernet.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Ethernet.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Ethernet.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Ethernet.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Ethernet.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Ethernet.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Ethernet.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Ethernet.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Ethernet.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Ethernet.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Ethernet.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Ethernet.Ipv6.Dhcp)), ("address", ("address", Native.Interface.Ethernet.Ipv6.Address)), ("nd", ("nd", Native.Interface.Ethernet.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.Ethernet.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Ethernet.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Ethernet.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Ethernet.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Ethernet.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Ethernet.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Ethernet.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Ethernet.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Ethernet.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Ethernet.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Ethernet.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Ethernet.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Ethernet.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Ethernet.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Ethernet.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Ethernet.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Ethernet.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Ethernet.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Ethernet.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Ethernet.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.Ethernet.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Ethernet.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Ethernet.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Ethernet.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Ethernet.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Ethernet.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Ethernet.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Ethernet.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Ethernet.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Ethernet.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.Ethernet.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Ethernet.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Ethernet.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Ethernet.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Ethernet.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Ethernet.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Ethernet.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Ethernet.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Ethernet.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Ethernet.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Ethernet.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Ethernet.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Ethernet.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Ethernet.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Ethernet.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Ethernet.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Ethernet.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Ethernet.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Ethernet.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Ethernet.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Ethernet.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Ethernet.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Ethernet.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Ethernet.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Ethernet.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Ethernet.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Ethernet.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Ethernet.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Ethernet.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Ethernet.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Ethernet.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Ethernet.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Ethernet.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Ethernet.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Ethernet.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Ethernet.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Ethernet.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Ethernet.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Ethernet.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Ethernet.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Ethernet.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Ethernet.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Ethernet.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Ethernet.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Ethernet.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Ethernet.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Ethernet.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Ethernet.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Ethernet.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Ethernet.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Ethernet.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Ethernet.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Ethernet.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Ethernet.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Ethernet.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ethernet.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Ethernet.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Ethernet.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Ethernet.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Ethernet.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Ethernet.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ethernet.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Ethernet.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Ethernet.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ethernet.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ethernet.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Ethernet.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Ethernet.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ethernet.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ethernet.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ethernet.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Ethernet.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Ethernet.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ethernet.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Ethernet.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Ethernet.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Ethernet.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Ethernet.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ethernet.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.PmPath, [u'name', u'interface_id'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Ethernet.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.Ethernet.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Ethernet.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Utd, ['enable'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.Ethernet.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "Ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ethernet.Umbrella, ['out', 'in_'], name, value)


        class FastEthernet(Entity):
            """
            FastEthernet IEEE 802.3
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            	**pattern:** ([0\-9]/)([0\-9]/)([1\-3][0\-9]\|4[0\-8]\|[0\-9])(\\.[0\-9]+)?
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service>`
            
            .. attribute:: lacp
            
            	LACP interface subcommands
            	**type**\:  :py:class:`Lacp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Lacp>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec_option
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXEEthernetMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ServicePolicy>`
            
            .. attribute:: auto
            
            	Configure Automation
            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Auto>`
            
            .. attribute:: datalink
            
            	Interface Datalink commands
            	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Datalink>`
            
            .. attribute:: energywise
            
            	EnergyWise interface configurations
            	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Energywise>`
            
            	**presence node**\: True
            
            .. attribute:: location
            
            	Interface location information
            	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Location>`
            
            .. attribute:: mac
            
            	MAC interface commands
            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mac>`
            
            .. attribute:: macro
            
            	Command macro
            	**type**\:  :py:class:`Macro <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Macro>`
            
            .. attribute:: dual_active
            
            	
            	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.DualActive>`
            
            .. attribute:: load_balancing
            
            	Etherchannel Load\-Balancing
            	**type**\:  :py:class:`LoadBalancing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.LoadBalancing>`
            
            .. attribute:: vlan_range
            
            	
            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.VlanRange>`
            
            .. attribute:: switch
            
            	
            	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switch>`
            
            .. attribute:: srr_queue
            
            	
            	**type**\:  :py:class:`SrrQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SrrQueue>`
            
            .. attribute:: cisco_ios_xe_switch_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_switch_macsec_option_
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXESwitchMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption>`
            
            .. attribute:: device_tracking
            
            	Configure device\-tracking on the interface
            	**type**\:  :py:class:`DeviceTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.DeviceTracking>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Snmp>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Crypto>`
            
            .. attribute:: mka
            
            	MACsec Key Agreement (MKA) interface configuration
            	**type**\:  :py:class:`Mka <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mka>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Utd>`
            
            .. attribute:: xconnect
            
            	Xconnect commands
            	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Xconnect>`
            
            .. attribute:: evpn
            
            	
            	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Evpn>`
            
            .. attribute:: fabric_domain
            
            	Fabric\-domain interface command
            	**type**\:  :py:class:`FabricDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.FabricDomain>`
            
            .. attribute:: mvrp
            
            	
            	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mvrp>`
            
            	**presence node**\: True
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Lisp>`
            
            .. attribute:: power
            
            	
            	**type**\:  :py:class:`Power <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Power>`
            
            .. attribute:: cdp
            
            	CDP interface subcommands
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cdp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ntp>`
            
            .. attribute:: authentication
            
            	Auth Manager Interface Configuration Commands
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication>`
            
            .. attribute:: mab
            
            	
            	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mab>`
            
            	**presence node**\: True
            
            .. attribute:: dot1x
            
            	Interface Config Commands for IEEE 802.1X
            	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Dot1x>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SpanningTree>`
            
            .. attribute:: performance
            
            	Global performance monitor configuration
            	**type**\:  :py:class:`Performance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Performance>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Umbrella>`
            
            .. attribute:: lldp
            
            	LLDP interface subcommands
            	**type**\:  :py:class:`Lldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Lldp>`
            
            .. attribute:: vrrp
            
            	Configure VRRP
            	**type**\:  :py:class:`Vrrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp>`
            
            .. attribute:: nat66
            
            	NAT66 interface commands
            	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Nat66>`
            
            .. attribute:: ospfv3
            
            	OSPFv3 interface commands
            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3>`
            
            .. attribute:: udld
            
            	Configure UDLD enabled or disabled and ignore global UDLD setting
            	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Udld>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts>`
            
            .. attribute:: analysis_module
            
            	Configure NAM on the interface
            	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.AnalysisModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.FastEthernet, self).__init__()

                self.yang_name = "FastEthernet"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.FastEthernet.SwitchportConf)), ("switchport", ("switchport", Native.Interface.FastEthernet.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.FastEthernet.StackwiseVirtual)), ("arp", ("arp", Native.Interface.FastEthernet.Arp)), ("backup", ("backup", Native.Interface.FastEthernet.Backup)), ("cemoudp", ("cemoudp", Native.Interface.FastEthernet.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.FastEthernet.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.FastEthernet.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.FastEthernet.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.FastEthernet.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.FastEthernet.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.FastEthernet.Flowcontrol)), ("isis", ("isis", Native.Interface.FastEthernet.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.FastEthernet.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.FastEthernet.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.FastEthernet.Bandwidth)), ("dampening", ("dampening", Native.Interface.FastEthernet.Dampening)), ("domain", ("domain", Native.Interface.FastEthernet.Domain)), ("hold-queue", ("hold_queue", Native.Interface.FastEthernet.HoldQueue)), ("mpls", ("mpls", Native.Interface.FastEthernet.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.FastEthernet.IpVrf)), ("vrf", ("vrf", Native.Interface.FastEthernet.Vrf)), ("ip", ("ip", Native.Interface.FastEthernet.Ip)), ("ipv6", ("ipv6", Native.Interface.FastEthernet.Ipv6)), ("logging", ("logging", Native.Interface.FastEthernet.Logging)), ("mdix", ("mdix", Native.Interface.FastEthernet.Mdix)), ("mop", ("mop", Native.Interface.FastEthernet.Mop)), ("interface_qos", ("interface_qos", Native.Interface.FastEthernet.InterfaceQos)), ("source", ("source", Native.Interface.FastEthernet.Source)), ("standby", ("standby", Native.Interface.FastEthernet.Standby)), ("access-session", ("access_session", Native.Interface.FastEthernet.AccessSession)), ("storm-control", ("storm_control", Native.Interface.FastEthernet.StormControl)), ("trust", ("trust", Native.Interface.FastEthernet.Trust)), ("priority-queue", ("priority_queue", Native.Interface.FastEthernet.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.FastEthernet.RcvQueue)), ("peer", ("peer", Native.Interface.FastEthernet.Peer)), ("pm-path", ("pm_path", Native.Interface.FastEthernet.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.FastEthernet.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.FastEthernet.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.FastEthernet.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.FastEthernet.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.FastEthernet.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.FastEthernet.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.FastEthernet.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.FastEthernet.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.FastEthernet.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.FastEthernet.Service)), ("Cisco-IOS-XE-ethernet:lacp", ("lacp", Native.Interface.FastEthernet.Lacp)), ("Cisco-IOS-XE-ethernet:macsec-option", ("cisco_ios_xe_ethernet_macsec_option", Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.FastEthernet.ServicePolicy)), ("Cisco-IOS-XE-switch:auto", ("auto", Native.Interface.FastEthernet.Auto)), ("Cisco-IOS-XE-switch:datalink", ("datalink", Native.Interface.FastEthernet.Datalink)), ("Cisco-IOS-XE-switch:energywise", ("energywise", Native.Interface.FastEthernet.Energywise)), ("Cisco-IOS-XE-switch:location", ("location", Native.Interface.FastEthernet.Location)), ("Cisco-IOS-XE-switch:mac", ("mac", Native.Interface.FastEthernet.Mac)), ("Cisco-IOS-XE-switch:macro", ("macro", Native.Interface.FastEthernet.Macro)), ("Cisco-IOS-XE-switch:dual-active", ("dual_active", Native.Interface.FastEthernet.DualActive)), ("Cisco-IOS-XE-switch:load-balancing", ("load_balancing", Native.Interface.FastEthernet.LoadBalancing)), ("Cisco-IOS-XE-switch:vlan-range", ("vlan_range", Native.Interface.FastEthernet.VlanRange)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Interface.FastEthernet.Switch)), ("Cisco-IOS-XE-switch:srr-queue", ("srr_queue", Native.Interface.FastEthernet.SrrQueue)), ("Cisco-IOS-XE-switch:macsec-option", ("cisco_ios_xe_switch_macsec_option_", Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption)), ("Cisco-IOS-XE-switch:device-tracking", ("device_tracking", Native.Interface.FastEthernet.DeviceTracking)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.FastEthernet.Snmp)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.FastEthernet.Crypto)), ("Cisco-IOS-XE-mka:mka", ("mka", Native.Interface.FastEthernet.Mka)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.FastEthernet.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.FastEthernet.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.FastEthernet.Utd)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.FastEthernet.Xconnect)), ("Cisco-IOS-XE-l2vpn:evpn", ("evpn", Native.Interface.FastEthernet.Evpn)), ("Cisco-IOS-XE-iwanfabric:fabric-domain", ("fabric_domain", Native.Interface.FastEthernet.FabricDomain)), ("Cisco-IOS-XE-mvrp:mvrp", ("mvrp", Native.Interface.FastEthernet.Mvrp)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.FastEthernet.Lisp)), ("Cisco-IOS-XE-power:power", ("power", Native.Interface.FastEthernet.Power)), ("Cisco-IOS-XE-cdp:cdp", ("cdp", Native.Interface.FastEthernet.Cdp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.FastEthernet.Ntp)), ("Cisco-IOS-XE-sanet:authentication", ("authentication", Native.Interface.FastEthernet.Authentication)), ("Cisco-IOS-XE-sanet:mab", ("mab", Native.Interface.FastEthernet.Mab)), ("Cisco-IOS-XE-dot1x:dot1x", ("dot1x", Native.Interface.FastEthernet.Dot1x)), ("Cisco-IOS-XE-spanning-tree:spanning-tree", ("spanning_tree", Native.Interface.FastEthernet.SpanningTree)), ("Cisco-IOS-XE-ezpm:performance", ("performance", Native.Interface.FastEthernet.Performance)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.FastEthernet.Umbrella)), ("Cisco-IOS-XE-lldp:lldp", ("lldp", Native.Interface.FastEthernet.Lldp)), ("Cisco-IOS-XE-vrrp:vrrp", ("vrrp", Native.Interface.FastEthernet.Vrrp)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Interface.FastEthernet.Ospfv3)), ("Cisco-IOS-XE-udld:udld", ("udld", Native.Interface.FastEthernet.Udld)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.FastEthernet.Cts)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Interface.FastEthernet.AnalysisModule))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Duplex')])),
                    ('cisco_ios_xe_ethernet_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-ethernet:macsec'), ['Empty'])),
                    ('cisco_ios_xe_switch_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:macsec'), ['Empty'])),
                    ('nat66', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-nat:nat66'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Nat66')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None
                self.cisco_ios_xe_ethernet_macsec = None
                self.cisco_ios_xe_switch_macsec = None
                self.nat66 = None

                self.switchport_conf = Native.Interface.FastEthernet.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.FastEthernet.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.FastEthernet.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.FastEthernet.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.FastEthernet.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.FastEthernet.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.FastEthernet.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.FastEthernet.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.FastEthernet.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.FastEthernet.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.FastEthernet.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.FastEthernet.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.FastEthernet.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.FastEthernet.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.FastEthernet.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.FastEthernet.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.FastEthernet.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.FastEthernet.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.FastEthernet.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.FastEthernet.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.FastEthernet.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.FastEthernet.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.FastEthernet.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.FastEthernet.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.FastEthernet.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.FastEthernet.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.FastEthernet.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.FastEthernet.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.FastEthernet.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.FastEthernet.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.FastEthernet.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.FastEthernet.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.FastEthernet.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.FastEthernet.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.FastEthernet.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.FastEthernet.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.FastEthernet.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.FastEthernet.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.FastEthernet.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.FastEthernet.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.FastEthernet.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.FastEthernet.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.FastEthernet.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.FastEthernet.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.FastEthernet.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.lacp = Native.Interface.FastEthernet.Lacp()
                self.lacp.parent = self
                self._children_name_map["lacp"] = "Cisco-IOS-XE-ethernet:lacp"

                self.cisco_ios_xe_ethernet_macsec_option = Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption()
                self.cisco_ios_xe_ethernet_macsec_option.parent = self
                self._children_name_map["cisco_ios_xe_ethernet_macsec_option"] = "Cisco-IOS-XE-ethernet:macsec-option"

                self.service_policy = Native.Interface.FastEthernet.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.auto = Native.Interface.FastEthernet.Auto()
                self.auto.parent = self
                self._children_name_map["auto"] = "Cisco-IOS-XE-switch:auto"

                self.datalink = Native.Interface.FastEthernet.Datalink()
                self.datalink.parent = self
                self._children_name_map["datalink"] = "Cisco-IOS-XE-switch:datalink"

                self.energywise = None
                self._children_name_map["energywise"] = "Cisco-IOS-XE-switch:energywise"

                self.location = Native.Interface.FastEthernet.Location()
                self.location.parent = self
                self._children_name_map["location"] = "Cisco-IOS-XE-switch:location"

                self.mac = Native.Interface.FastEthernet.Mac()
                self.mac.parent = self
                self._children_name_map["mac"] = "Cisco-IOS-XE-switch:mac"

                self.macro = Native.Interface.FastEthernet.Macro()
                self.macro.parent = self
                self._children_name_map["macro"] = "Cisco-IOS-XE-switch:macro"

                self.dual_active = Native.Interface.FastEthernet.DualActive()
                self.dual_active.parent = self
                self._children_name_map["dual_active"] = "Cisco-IOS-XE-switch:dual-active"

                self.load_balancing = Native.Interface.FastEthernet.LoadBalancing()
                self.load_balancing.parent = self
                self._children_name_map["load_balancing"] = "Cisco-IOS-XE-switch:load-balancing"

                self.switch = Native.Interface.FastEthernet.Switch()
                self.switch.parent = self
                self._children_name_map["switch"] = "Cisco-IOS-XE-switch:switch"

                self.srr_queue = Native.Interface.FastEthernet.SrrQueue()
                self.srr_queue.parent = self
                self._children_name_map["srr_queue"] = "Cisco-IOS-XE-switch:srr-queue"

                self.cisco_ios_xe_switch_macsec_option_ = Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption()
                self.cisco_ios_xe_switch_macsec_option_.parent = self
                self._children_name_map["cisco_ios_xe_switch_macsec_option_"] = "Cisco-IOS-XE-switch:macsec-option"

                self.device_tracking = Native.Interface.FastEthernet.DeviceTracking()
                self.device_tracking.parent = self
                self._children_name_map["device_tracking"] = "Cisco-IOS-XE-switch:device-tracking"

                self.snmp = Native.Interface.FastEthernet.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.crypto = Native.Interface.FastEthernet.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.mka = Native.Interface.FastEthernet.Mka()
                self.mka.parent = self
                self._children_name_map["mka"] = "Cisco-IOS-XE-mka:mka"

                self.et_analytics = Native.Interface.FastEthernet.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.FastEthernet.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.FastEthernet.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.xconnect = Native.Interface.FastEthernet.Xconnect()
                self.xconnect.parent = self
                self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                self.evpn = Native.Interface.FastEthernet.Evpn()
                self.evpn.parent = self
                self._children_name_map["evpn"] = "Cisco-IOS-XE-l2vpn:evpn"

                self.fabric_domain = Native.Interface.FastEthernet.FabricDomain()
                self.fabric_domain.parent = self
                self._children_name_map["fabric_domain"] = "Cisco-IOS-XE-iwanfabric:fabric-domain"

                self.mvrp = None
                self._children_name_map["mvrp"] = "Cisco-IOS-XE-mvrp:mvrp"

                self.lisp = Native.Interface.FastEthernet.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.power = Native.Interface.FastEthernet.Power()
                self.power.parent = self
                self._children_name_map["power"] = "Cisco-IOS-XE-power:power"

                self.cdp = Native.Interface.FastEthernet.Cdp()
                self.cdp.parent = self
                self._children_name_map["cdp"] = "Cisco-IOS-XE-cdp:cdp"

                self.ntp = Native.Interface.FastEthernet.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.authentication = Native.Interface.FastEthernet.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "Cisco-IOS-XE-sanet:authentication"

                self.mab = None
                self._children_name_map["mab"] = "Cisco-IOS-XE-sanet:mab"

                self.dot1x = Native.Interface.FastEthernet.Dot1x()
                self.dot1x.parent = self
                self._children_name_map["dot1x"] = "Cisco-IOS-XE-dot1x:dot1x"

                self.spanning_tree = Native.Interface.FastEthernet.SpanningTree()
                self.spanning_tree.parent = self
                self._children_name_map["spanning_tree"] = "Cisco-IOS-XE-spanning-tree:spanning-tree"

                self.performance = Native.Interface.FastEthernet.Performance()
                self.performance.parent = self
                self._children_name_map["performance"] = "Cisco-IOS-XE-ezpm:performance"

                self.umbrella = Native.Interface.FastEthernet.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.lldp = Native.Interface.FastEthernet.Lldp()
                self.lldp.parent = self
                self._children_name_map["lldp"] = "Cisco-IOS-XE-lldp:lldp"

                self.vrrp = Native.Interface.FastEthernet.Vrrp()
                self.vrrp.parent = self
                self._children_name_map["vrrp"] = "Cisco-IOS-XE-vrrp:vrrp"

                self.ospfv3 = Native.Interface.FastEthernet.Ospfv3()
                self.ospfv3.parent = self
                self._children_name_map["ospfv3"] = "Cisco-IOS-XE-ospfv3:ospfv3"

                self.udld = Native.Interface.FastEthernet.Udld()
                self.udld.parent = self
                self._children_name_map["udld"] = "Cisco-IOS-XE-udld:udld"

                self.cts = Native.Interface.FastEthernet.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.analysis_module = Native.Interface.FastEthernet.AnalysisModule()
                self.analysis_module.parent = self
                self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"

                self.hold_queue = YList(self)
                self.vlan_range = YList(self)
                self._segment_path = lambda: "FastEthernet" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.FastEthernet, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex', 'cisco_ios_xe_ethernet_macsec', u'cisco_ios_xe_switch_macsec', 'nat66'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class Nat66(Enum):
                """
                Nat66 (Enum Class)

                NAT66 interface commands

                .. data:: inside = 0

                .. data:: outside = 1

                """

                inside = Enum.YLeaf(0, "inside")

                outside = Enum.YLeaf(1, "outside")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Access>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Block>`
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: trunk
                
                	Set trunking characteristics of the interface
                	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Trunk>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Voice>`
                
                .. attribute:: priority
                
                	Set appliance 802.1p priority
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Priority>`
                
                .. attribute:: autostate
                
                	Include or exclude this port from vlan link up calculation
                	**type**\:  :py:class:`Autostate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Autostate>`
                
                .. attribute:: protected
                
                	Configure an interface to be a protected port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Set port host
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: private_vlan
                
                	Set the private VLAN configuration
                	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PrivateVlan>`
                
                .. attribute:: vepa
                
                	Reflective relay configuration
                	**type**\:  :py:class:`Vepa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Vepa>`
                
                .. attribute:: device_tracking
                
                	Configure device\-tracking on the interface
                	**type**\:  :py:class:`DeviceTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.DeviceTracking>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:access", ("access", Native.Interface.FastEthernet.Switchport.Access)), ("Cisco-IOS-XE-switch:block", ("block", Native.Interface.FastEthernet.Switchport.Block)), ("Cisco-IOS-XE-switch:mode", ("mode", Native.Interface.FastEthernet.Switchport.Mode)), ("Cisco-IOS-XE-switch:port-security", ("port_security", Native.Interface.FastEthernet.Switchport.PortSecurity)), ("Cisco-IOS-XE-switch:trunk", ("trunk", Native.Interface.FastEthernet.Switchport.Trunk)), ("Cisco-IOS-XE-switch:voice", ("voice", Native.Interface.FastEthernet.Switchport.Voice)), ("Cisco-IOS-XE-switch:priority", ("priority", Native.Interface.FastEthernet.Switchport.Priority)), ("Cisco-IOS-XE-switch:autostate", ("autostate", Native.Interface.FastEthernet.Switchport.Autostate)), ("Cisco-IOS-XE-switch:private-vlan", ("private_vlan", Native.Interface.FastEthernet.Switchport.PrivateVlan)), ("Cisco-IOS-XE-switch:vepa", ("vepa", Native.Interface.FastEthernet.Switchport.Vepa)), ("Cisco-IOS-XE-switch:device-tracking", ("device_tracking", Native.Interface.FastEthernet.Switchport.DeviceTracking))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:nonegotiate'), ['Empty'])),
                        ('protected', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:protected'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:host'), ['Empty'])),
                    ])
                    self.nonegotiate = None
                    self.protected = None
                    self.host = None

                    self.access = Native.Interface.FastEthernet.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "Cisco-IOS-XE-switch:access"

                    self.block = Native.Interface.FastEthernet.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "Cisco-IOS-XE-switch:block"

                    self.mode = Native.Interface.FastEthernet.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "Cisco-IOS-XE-switch:mode"

                    self.port_security = None
                    self._children_name_map["port_security"] = "Cisco-IOS-XE-switch:port-security"

                    self.trunk = Native.Interface.FastEthernet.Switchport.Trunk()
                    self.trunk.parent = self
                    self._children_name_map["trunk"] = "Cisco-IOS-XE-switch:trunk"

                    self.voice = Native.Interface.FastEthernet.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "Cisco-IOS-XE-switch:voice"

                    self.priority = Native.Interface.FastEthernet.Switchport.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-switch:priority"

                    self.autostate = Native.Interface.FastEthernet.Switchport.Autostate()
                    self.autostate.parent = self
                    self._children_name_map["autostate"] = "Cisco-IOS-XE-switch:autostate"

                    self.private_vlan = Native.Interface.FastEthernet.Switchport.PrivateVlan()
                    self.private_vlan.parent = self
                    self._children_name_map["private_vlan"] = "Cisco-IOS-XE-switch:private-vlan"

                    self.vepa = Native.Interface.FastEthernet.Switchport.Vepa()
                    self.vepa.parent = self
                    self._children_name_map["vepa"] = "Cisco-IOS-XE-switch:vepa"

                    self.device_tracking = Native.Interface.FastEthernet.Switchport.DeviceTracking()
                    self.device_tracking.parent = self
                    self._children_name_map["device_tracking"] = "Cisco-IOS-XE-switch:device-tracking"
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Switchport, [u'nonegotiate', u'protected', u'host'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	Set VLAN when interface is in access mode
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Access.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FastEthernet.Switchport.Access.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.FastEthernet.Switchport.Access.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:access"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switchport.Access, [], name, value)


                    class Vlan(Entity):
                        """
                        Set VLAN when interface is in access mode
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_>`
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.Access.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "access"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.Access.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dynamic = 0

                            """

                            dynamic = Enum.YLeaf(0, "dynamic")



                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: multicast
                    
                    	Block unknown multicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.multicast = None
                        self.unicast = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:block"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switchport.Block, [u'multicast', u'unicast'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Mode.Access>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dot1q_tunnel
                    
                    	set trunking mode to TUNNEL unconditionally
                    	**type**\:  :py:class:`Dot1qTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Mode.Dot1qTunnel>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dynamic
                    
                    	Set trunking mode to dynamically negotiate access or trunk mode
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Mode.Dynamic>`
                    
                    .. attribute:: private_vlan
                    
                    	Set private\-vlan mode
                    	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Mode.PrivateVlan>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Mode.Trunk>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.FastEthernet.Switchport.Mode.Access)), ("dot1q-tunnel", ("dot1q_tunnel", Native.Interface.FastEthernet.Switchport.Mode.Dot1qTunnel)), ("private-vlan", ("private_vlan", Native.Interface.FastEthernet.Switchport.Mode.PrivateVlan)), ("trunk", ("trunk", Native.Interface.FastEthernet.Switchport.Mode.Trunk))])
                        self._leafs = OrderedDict([
                            ('dynamic', (YLeaf(YType.enumeration, 'dynamic'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Switchport.Mode.Dynamic')])),
                        ])
                        self.dynamic = None

                        self.access = None
                        self._children_name_map["access"] = "access"

                        self.dot1q_tunnel = None
                        self._children_name_map["dot1q_tunnel"] = "dot1q-tunnel"

                        self.private_vlan = Native.Interface.FastEthernet.Switchport.Mode.PrivateVlan()
                        self.private_vlan.parent = self
                        self._children_name_map["private_vlan"] = "private-vlan"

                        self.trunk = None
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switchport.Mode, [u'dynamic'], name, value)

                    class Dynamic(Enum):
                        """
                        Dynamic (Enum Class)

                        Set trunking mode to dynamically negotiate access or trunk mode

                        .. data:: auto = 0

                        .. data:: desirable = 1

                        """

                        auto = Enum.YLeaf(0, "auto")

                        desirable = Enum.YLeaf(1, "desirable")



                    class Access(Entity):
                        """
                        Set trunking mode to ACCESS unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.Mode.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "access"
                            self._is_frozen = True


                    class Dot1qTunnel(Entity):
                        """
                        set trunking mode to TUNNEL unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.Mode.Dot1qTunnel, self).__init__()

                            self.yang_name = "dot1q-tunnel"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dot1q-tunnel"
                            self._is_frozen = True


                    class PrivateVlan(Entity):
                        """
                        Set private\-vlan mode
                        
                        .. attribute:: host
                        
                        	Set the mode to private\-vlan host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: promiscuous
                        
                        	Set the mode to private\-vlan promiscuous
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.Mode.PrivateVlan, self).__init__()

                            self.yang_name = "private-vlan"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('promiscuous', (YLeaf(YType.empty, 'promiscuous'), ['Empty'])),
                            ])
                            self.host = None
                            self.promiscuous = None
                            self._segment_path = lambda: "private-vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.Mode.PrivateVlan, [u'host', u'promiscuous'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking mode to TRUNK unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.Mode.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: mac_address
                    
                    	Secure mac address
                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PortSecurity.MacAddress>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Interface.FastEthernet.Switchport.PortSecurity.Aging)), ("mac-address", ("mac_address", Native.Interface.FastEthernet.Switchport.PortSecurity.MacAddress)), ("maximum", ("maximum", Native.Interface.FastEthernet.Switchport.PortSecurity.Maximum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Switchport.PortSecurity.Violation')])),
                        ])
                        self.violation = None

                        self.aging = Native.Interface.FastEthernet.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.mac_address = Native.Interface.FastEthernet.Switchport.PortSecurity.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"

                        self.maximum = Native.Interface.FastEthernet.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:port-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switchport.PortSecurity, [u'violation'], name, value)

                    class Violation(Enum):
                        """
                        Violation (Enum Class)

                        Security violation mode

                        .. data:: protect = 0

                        .. data:: restrict = 1

                        .. data:: shutdown = 2

                        """

                        protect = Enum.YLeaf(0, "protect")

                        restrict = Enum.YLeaf(1, "restrict")

                        shutdown = Enum.YLeaf(2, "shutdown")



                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PortSecurity.Aging.Type>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Switchport.PortSecurity.Aging.Type')])),
                            ])
                            self.static = None
                            self.time = None
                            self.type = None
                            self._segment_path = lambda: "aging"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.PortSecurity.Aging, [u'static', u'time', u'type'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Port\-security aging type

                            .. data:: absolute = 0

                            .. data:: inactivity = 1

                            """

                            absolute = Enum.YLeaf(0, "absolute")

                            inactivity = Enum.YLeaf(1, "inactivity")



                    class MacAddress(Entity):
                        """
                        Secure mac address
                        
                        .. attribute:: sticky
                        
                        	Configure dynamic secure addresses as sticky
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hw_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: vlan
                        
                        	set VLAN ID of the VLAN on which this address can be learned
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.PortSecurity.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                ('hw_address', (YLeaf(YType.str, 'hw-address'), ['str'])),
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.sticky = None
                            self.hw_address = None
                            self.vlan = None
                            self._segment_path = lambda: "mac-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.PortSecurity.MacAddress, [u'sticky', u'hw_address', u'vlan'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: max_addresses
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4097
                        
                        .. attribute:: vlan
                        
                        	Max secure addresses per vlan
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_addresses', (YLeaf(YType.uint16, 'max-addresses'), ['int'])),
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['str'])),
                            ])
                            self.max_addresses = None
                            self.vlan = None
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.PortSecurity.Maximum, [u'max_addresses', u'vlan'], name, value)


                class Trunk(Entity):
                    """
                    Set trunking characteristics of the interface
                    
                    .. attribute:: allowed
                    
                    	Set allowed VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Trunk.Allowed>`
                    
                    .. attribute:: encapsulation
                    
                    	Set encapsulation format on trunk port
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Trunk.Encapsulation>`
                    
                    .. attribute:: native
                    
                    	Set trunking native characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Trunk.Native_>`
                    
                    .. attribute:: pruning
                    
                    	Set pruning VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Pruning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Trunk.Pruning>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switchport.Trunk, self).__init__()

                        self.yang_name = "trunk"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.FastEthernet.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.FastEthernet.Switchport.Trunk.Native_)), ("pruning", ("pruning", Native.Interface.FastEthernet.Switchport.Trunk.Pruning))])
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Switchport.Trunk.Encapsulation')])),
                        ])
                        self.encapsulation = None

                        self.allowed = Native.Interface.FastEthernet.Switchport.Trunk.Allowed()
                        self.allowed.parent = self
                        self._children_name_map["allowed"] = "allowed"

                        self.native = Native.Interface.FastEthernet.Switchport.Trunk.Native_()
                        self.native.parent = self
                        self._children_name_map["native"] = "native"

                        self.pruning = Native.Interface.FastEthernet.Switchport.Trunk.Pruning()
                        self.pruning.parent = self
                        self._children_name_map["pruning"] = "pruning"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:trunk"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switchport.Trunk, [u'encapsulation'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Set encapsulation format on trunk port

                        .. data:: dot1q = 0

                        .. data:: isl = 1

                        .. data:: negotiate = 2

                        """

                        dot1q = Enum.YLeaf(0, "dot1q")

                        isl = Enum.YLeaf(1, "isl")

                        negotiate = Enum.YLeaf(2, "negotiate")



                    class Allowed(Entity):
                        """
                        Set allowed VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set allowed VLANs when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Trunk.Allowed.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.Trunk.Allowed, self).__init__()

                            self.yang_name = "allowed"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FastEthernet.Switchport.Trunk.Allowed.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.FastEthernet.Switchport.Trunk.Allowed.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "allowed"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.Trunk.Allowed, [], name, value)


                        class Vlan(Entity):
                            """
                            Set allowed VLANs when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: all
                            
                            	all VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "allowed"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = None
                                self.add = None
                                self.all = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                    class Native_(Entity):
                        """
                        Set trunking native characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set native VLAN when interface is in trunking mode
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.Trunk.Native_, self).__init__()

                            self.yang_name = "native"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan'),'int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "native"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.Trunk.Native_, [u'vlan'], name, value)

                        class Vlan(Enum):
                            """
                            Vlan (Enum Class)

                            Set native VLAN when interface is in trunking mode

                            .. data:: tag = 0

                            """

                            tag = Enum.YLeaf(0, "tag")



                    class Pruning(Entity):
                        """
                        Set pruning VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set VLANs enabled for pruning when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Trunk.Pruning.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.Trunk.Pruning, self).__init__()

                            self.yang_name = "pruning"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FastEthernet.Switchport.Trunk.Pruning.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.FastEthernet.Switchport.Trunk.Pruning.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "pruning"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.Trunk.Pruning, [], name, value)


                        class Vlan(Entity):
                            """
                            Set VLANs enabled for pruning when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Switchport.Trunk.Pruning.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "pruning"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeafList(YType.str, 'vlans'), ['int','str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = []
                                self.add = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Switchport.Trunk.Pruning.Vlan, [u'vlans', u'add', u'except_', u'none', u'remove'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Voice.Vlan>`
                    
                    .. attribute:: detect
                    
                    	detection enhancement keyword
                    	**type**\:  :py:class:`Detect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Voice.Detect>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FastEthernet.Switchport.Voice.Vlan)), ("detect", ("detect", Native.Interface.FastEthernet.Switchport.Voice.Detect))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.FastEthernet.Switchport.Voice.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"

                        self.detect = Native.Interface.FastEthernet.Switchport.Voice.Detect()
                        self.detect.parent = self
                        self._children_name_map["detect"] = "detect"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:voice"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switchport.Voice, [], name, value)


                    class Vlan(Entity):
                        """
                        Vlan for voice traffic
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\: str
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.Voice.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_'),'int','str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.Voice.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dot1p = 0

                            .. data:: none = 1

                            .. data:: untagged = 2

                            """

                            dot1p = Enum.YLeaf(0, "dot1p")

                            none = Enum.YLeaf(1, "none")

                            untagged = Enum.YLeaf(2, "untagged")



                    class Detect(Entity):
                        """
                        detection enhancement keyword
                        
                        .. attribute:: cisco_phone
                        
                        	Cisco IP phone
                        	**type**\:  :py:class:`CiscoPhone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Voice.Detect.CiscoPhone>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.Voice.Detect, self).__init__()

                            self.yang_name = "detect"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cisco-phone", ("cisco_phone", Native.Interface.FastEthernet.Switchport.Voice.Detect.CiscoPhone))])
                            self._leafs = OrderedDict()

                            self.cisco_phone = None
                            self._children_name_map["cisco_phone"] = "cisco-phone"
                            self._segment_path = lambda: "detect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.Voice.Detect, [], name, value)


                        class CiscoPhone(Entity):
                            """
                            Cisco IP phone
                            
                            .. attribute:: full_duplex
                            
                            	full duplex keyword
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Switchport.Voice.Detect.CiscoPhone, self).__init__()

                                self.yang_name = "cisco-phone"
                                self.yang_parent_name = "detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('full_duplex', (YLeaf(YType.empty, 'full-duplex'), ['Empty'])),
                                ])
                                self.full_duplex = None
                                self._segment_path = lambda: "cisco-phone"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Switchport.Voice.Detect.CiscoPhone, [u'full_duplex'], name, value)


                class Priority(Entity):
                    """
                    Set appliance 802.1p priority
                    
                    .. attribute:: extend
                    
                    	Set appliance 802.1p priority
                    	**type**\:  :py:class:`Extend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.Priority.Extend>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switchport.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("extend", ("extend", Native.Interface.FastEthernet.Switchport.Priority.Extend))])
                        self._leafs = OrderedDict()

                        self.extend = Native.Interface.FastEthernet.Switchport.Priority.Extend()
                        self.extend.parent = self
                        self._children_name_map["extend"] = "extend"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switchport.Priority, [], name, value)


                    class Extend(Entity):
                        """
                        Set appliance 802.1p priority
                        
                        .. attribute:: trust
                        
                        	Trust 802.1p priorities of devices on appliance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cos
                        
                        	Override 802.1p priority of devices on appliance
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.Priority.Extend, self).__init__()

                            self.yang_name = "extend"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                            ])
                            self.trust = None
                            self.cos = None
                            self._segment_path = lambda: "extend"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.Priority.Extend, [u'trust', u'cos'], name, value)


                class Autostate(Entity):
                    """
                    Include or exclude this port from vlan link up calculation
                    
                    .. attribute:: exclude
                    
                    	Exclude this port from vlan link up calculation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switchport.Autostate, self).__init__()

                        self.yang_name = "autostate"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('exclude', (YLeaf(YType.empty, 'exclude'), ['Empty'])),
                        ])
                        self.exclude = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:autostate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switchport.Autostate, [u'exclude'], name, value)


                class PrivateVlan(Entity):
                    """
                    Set the private VLAN configuration
                    
                    .. attribute:: association
                    
                    	Set the private VLAN association
                    	**type**\:  :py:class:`Association <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PrivateVlan.Association>`
                    
                    .. attribute:: host_association
                    
                    	Set the private VLAN host association
                    	**type**\:  :py:class:`HostAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PrivateVlan.HostAssociation>`
                    
                    .. attribute:: mapping
                    
                    	Set the private VLAN promiscuous mapping
                    	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PrivateVlan.Mapping>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switchport.PrivateVlan, self).__init__()

                        self.yang_name = "private-vlan"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("association", ("association", Native.Interface.FastEthernet.Switchport.PrivateVlan.Association)), ("host-association", ("host_association", Native.Interface.FastEthernet.Switchport.PrivateVlan.HostAssociation)), ("mapping", ("mapping", Native.Interface.FastEthernet.Switchport.PrivateVlan.Mapping))])
                        self._leafs = OrderedDict()

                        self.association = Native.Interface.FastEthernet.Switchport.PrivateVlan.Association()
                        self.association.parent = self
                        self._children_name_map["association"] = "association"

                        self.host_association = Native.Interface.FastEthernet.Switchport.PrivateVlan.HostAssociation()
                        self.host_association.parent = self
                        self._children_name_map["host_association"] = "host-association"

                        self.mapping = Native.Interface.FastEthernet.Switchport.PrivateVlan.Mapping()
                        self.mapping.parent = self
                        self._children_name_map["mapping"] = "mapping"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:private-vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switchport.PrivateVlan, [], name, value)


                    class Association(Entity):
                        """
                        Set the private VLAN association
                        
                        .. attribute:: host
                        
                        	Set the private VLAN host association
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PrivateVlan.Association.Host>`
                        
                        .. attribute:: mapping
                        
                        	Set the private VLAN promiscuous mapping
                        	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switchport.PrivateVlan.Association.Mapping>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.PrivateVlan.Association, self).__init__()

                            self.yang_name = "association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.Interface.FastEthernet.Switchport.PrivateVlan.Association.Host)), ("mapping", ("mapping", Native.Interface.FastEthernet.Switchport.PrivateVlan.Association.Mapping))])
                            self._leafs = OrderedDict()

                            self.host = Native.Interface.FastEthernet.Switchport.PrivateVlan.Association.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.mapping = Native.Interface.FastEthernet.Switchport.PrivateVlan.Association.Mapping()
                            self.mapping.parent = self
                            self._children_name_map["mapping"] = "mapping"
                            self._segment_path = lambda: "association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.PrivateVlan.Association, [], name, value)


                        class Host(Entity):
                            """
                            Set the private VLAN host association
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary normal range VLAN ID of the private VLAN host port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Switchport.PrivateVlan.Association.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Switchport.PrivateVlan.Association.Host, [u'primary_range', u'secondary_range'], name, value)


                        class Mapping(Entity):
                            """
                            Set the private VLAN promiscuous mapping
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: remove
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Switchport.PrivateVlan.Association.Mapping, self).__init__()

                                self.yang_name = "mapping"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self.add = None
                                self.remove = None
                                self._segment_path = lambda: "mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Switchport.PrivateVlan.Association.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                    class HostAssociation(Entity):
                        """
                        Set the private VLAN host association
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary normal range VLAN ID of the private VLAN host port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.PrivateVlan.HostAssociation, self).__init__()

                            self.yang_name = "host-association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self._segment_path = lambda: "host-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.PrivateVlan.HostAssociation, [u'primary_range', u'secondary_range'], name, value)


                    class Mapping(Entity):
                        """
                        Set the private VLAN promiscuous mapping
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: add
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: remove
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Switchport.PrivateVlan.Mapping, self).__init__()

                            self.yang_name = "mapping"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self.add = None
                            self.remove = None
                            self._segment_path = lambda: "mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Switchport.PrivateVlan.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                class Vepa(Entity):
                    """
                    Reflective relay configuration
                    
                    .. attribute:: enabled
                    
                    	Enable reflective relay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switchport.Vepa, self).__init__()

                        self.yang_name = "vepa"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                        ])
                        self.enabled = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:vepa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switchport.Vepa, [u'enabled'], name, value)


                class DeviceTracking(Entity):
                    """
                    Configure device\-tracking on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature device\-tracking
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switchport.DeviceTracking, self).__init__()

                        self.yang_name = "device-tracking"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:device-tracking"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switchport.DeviceTracking, [u'attach_policy'], name, value)


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FastEthernet.Backup.Delay)), ("interface", ("interface", Native.Interface.FastEthernet.Backup.Interface_)), ("load", ("load", Native.Interface.FastEthernet.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.FastEthernet.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.FastEthernet.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.FastEthernet.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.FastEthernet.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.FastEthernet.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.FastEthernet.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.FastEthernet.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.FastEthernet.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.FastEthernet.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.FastEthernet.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.FastEthernet.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.FastEthernet.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.FastEthernet.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.FastEthernet.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.FastEthernet.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.FastEthernet.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.FastEthernet.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.FastEthernet.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.FastEthernet.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.FastEthernet.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.FastEthernet.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.FastEthernet.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.FastEthernet.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.FastEthernet.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.FastEthernet.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.FastEthernet.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.FastEthernet.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.FastEthernet.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.FastEthernet.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.FastEthernet.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.FastEthernet.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.FastEthernet.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.FastEthernet.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.FastEthernet.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.FastEthernet.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.FastEthernet.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.FastEthernet.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.FastEthernet.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.FastEthernet.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.FastEthernet.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.FastEthernet.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.FastEthernet.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.FastEthernet.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.FastEthernet.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.FastEthernet.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.FastEthernet.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.FastEthernet.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.FastEthernet.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.FastEthernet.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.FastEthernet.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.FastEthernet.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.FastEthernet.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.FastEthernet.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.FastEthernet.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.FastEthernet.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.FastEthernet.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FastEthernet.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.FastEthernet.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.FastEthernet.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.FastEthernet.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.FastEthernet.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.FastEthernet.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.FastEthernet.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.FastEthernet.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.FastEthernet.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.FastEthernet.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.FastEthernet.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.FastEthernet.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.FastEthernet.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.FastEthernet.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.FastEthernet.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.FastEthernet.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.FastEthernet.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.FastEthernet.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.FastEthernet.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.FastEthernet.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.FastEthernet.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.FastEthernet.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.FastEthernet.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.FastEthernet.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.FastEthernet.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.FastEthernet.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.FastEthernet.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.FastEthernet.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.FastEthernet.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.FastEthernet.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.FastEthernet.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.FastEthernet.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.FastEthernet.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.FastEthernet.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.FastEthernet.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.FastEthernet.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.FastEthernet.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.FastEthernet.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.FastEthernet.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.FastEthernet.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.FastEthernet.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.FastEthernet.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.FastEthernet.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.FastEthernet.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.FastEthernet.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.FastEthernet.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.FastEthernet.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.FastEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.FastEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.FastEthernet.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.FastEthernet.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.FastEthernet.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.FastEthernet.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Igmp>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Flow>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Nbar>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf>`
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Lisp>`
                
                .. attribute:: rsvp
                
                	RSVP Interface Commands
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Nat>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.FastEthernet.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.FastEthernet.Ip.Arp)), ("vrf", ("vrf", Native.Interface.FastEthernet.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.FastEthernet.Ip.NoAddress)), ("address", ("address", Native.Interface.FastEthernet.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.FastEthernet.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.FastEthernet.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.FastEthernet.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.FastEthernet.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.FastEthernet.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.FastEthernet.Ip.Pim)), ("policy", ("policy", Native.Interface.FastEthernet.Ip.Policy)), ("rip", ("rip", Native.Interface.FastEthernet.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.FastEthernet.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.FastEthernet.Ip.RouteCache)), ("router", ("router", Native.Interface.FastEthernet.Ip.Router)), ("tcp", ("tcp", Native.Interface.FastEthernet.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.FastEthernet.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.FastEthernet.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.FastEthernet.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.FastEthernet.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.FastEthernet.Ip.Igmp)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.FastEthernet.Ip.Flow)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.FastEthernet.Ip.Nbar)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.FastEthernet.Ip.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.FastEthernet.Ip.Lisp)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Interface.FastEthernet.Ip.Rsvp)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.FastEthernet.Ip.Nat)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.FastEthernet.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None
                    self.unreachables = None

                    self.access_group = Native.Interface.FastEthernet.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.FastEthernet.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.FastEthernet.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.FastEthernet.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.FastEthernet.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.FastEthernet.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.FastEthernet.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.FastEthernet.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.FastEthernet.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.FastEthernet.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.FastEthernet.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.FastEthernet.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.FastEthernet.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.FastEthernet.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.FastEthernet.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.FastEthernet.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.FastEthernet.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.FastEthernet.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.FastEthernet.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.flow = Native.Interface.FastEthernet.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.nbar = Native.Interface.FastEthernet.Ip.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.ospf = Native.Interface.FastEthernet.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.lisp = Native.Interface.FastEthernet.Ip.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                    self.rsvp = Native.Interface.FastEthernet.Ip.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

                    self.nat = Native.Interface.FastEthernet.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.wccp = Native.Interface.FastEthernet.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache', 'unreachables'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.FastEthernet.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.FastEthernet.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.FastEthernet.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.FastEthernet.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.FastEthernet.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.FastEthernet.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.FastEthernet.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.FastEthernet.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.FastEthernet.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.FastEthernet.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.FastEthernet.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.FastEthernet.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.FastEthernet.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.FastEthernet.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.FastEthernet.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.FastEthernet.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.FastEthernet.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.FastEthernet.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.FastEthernet.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.FastEthernet.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.FastEthernet.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.FastEthernet.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.FastEthernet.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.FastEthernet.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.FastEthernet.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.FastEthernet.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.FastEthernet.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.FastEthernet.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.FastEthernet.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.FastEthernet.Ip.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ip.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ip.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.FastEthernet.Ip.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.FastEthernet.Ip.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FastEthernet.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.FastEthernet.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.FastEthernet.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.FastEthernet.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.FastEthernet.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.FastEthernet.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.FastEthernet.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.FastEthernet.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.FastEthernet.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.FastEthernet.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.FastEthernet.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.FastEthernet.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.FastEthernet.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.FastEthernet.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.FastEthernet.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.FastEthernet.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.FastEthernet.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.FastEthernet.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.FastEthernet.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.FastEthernet.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.FastEthernet.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.FastEthernet.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FastEthernet.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.FastEthernet.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.FastEthernet.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.FastEthernet.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.FastEthernet.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.FastEthernet.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.FastEthernet.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.FastEthernet.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.FastEthernet.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.FastEthernet.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.FastEthernet.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FastEthernet.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.FastEthernet.Ip.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ip.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.FastEthernet.Ip.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.FastEthernet.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.FastEthernet.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.FastEthernet.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.FastEthernet.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.FastEthernet.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.FastEthernet.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.FastEthernet.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.FastEthernet.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.FastEthernet.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.FastEthernet.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.FastEthernet.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FastEthernet.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.FastEthernet.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.FastEthernet.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.FastEthernet.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.FastEthernet.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.FastEthernet.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.FastEthernet.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.FastEthernet.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.FastEthernet.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.FastEthernet.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.FastEthernet.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FastEthernet.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.FastEthernet.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Lisp(Entity):
                    """
                    Locator/ID Separation Protocol
                    
                    .. attribute:: source_locator
                    
                    	Choose IP source address for LISP packets egressing this interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_locator', (YLeaf(YType.str, 'source-locator'), ['str'])),
                        ])
                        self.source_locator = None
                        self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Lisp, ['source_locator'], name, value)


                class Rsvp(Entity):
                    """
                    RSVP Interface Commands
                    
                    .. attribute:: authentication
                    
                    	Enables RSVP neighbor authentication (RFC 2747)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bandwidth
                    
                    	RSVP Reservable Bandwidth (kbps)
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	Select permissible RSVP neighbors
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Neighbor>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: precedence
                    
                    	RSVP precedence setting
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Precedence>`
                    
                    .. attribute:: signalling
                    
                    	RSVP signalling
                    	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Signalling>`
                    
                    .. attribute:: tos
                    
                    	RSVP TOS setting
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Tos>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FastEthernet.Ip.Rsvp.Authentication)), ("bandwidth", ("bandwidth", Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth)), ("neighbor", ("neighbor", Native.Interface.FastEthernet.Ip.Rsvp.Neighbor)), ("precedence", ("precedence", Native.Interface.FastEthernet.Ip.Rsvp.Precedence)), ("signalling", ("signalling", Native.Interface.FastEthernet.Ip.Rsvp.Signalling)), ("tos", ("tos", Native.Interface.FastEthernet.Ip.Rsvp.Tos))])
                        self._leafs = OrderedDict()

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.bandwidth = None
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.neighbor = None
                        self._children_name_map["neighbor"] = "neighbor"

                        self.precedence = Native.Interface.FastEthernet.Ip.Rsvp.Precedence()
                        self.precedence.parent = self
                        self._children_name_map["precedence"] = "precedence"

                        self.signalling = Native.Interface.FastEthernet.Ip.Rsvp.Signalling()
                        self.signalling.parent = self
                        self._children_name_map["signalling"] = "signalling"

                        self.tos = Native.Interface.FastEthernet.Ip.Rsvp.Tos()
                        self.tos.parent = self
                        self._children_name_map["tos"] = "tos"
                        self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp, [], name, value)


                    class Authentication(Entity):
                        """
                        Enables RSVP neighbor authentication (RFC 2747)
                        
                        .. attribute:: key
                        
                        	Password (8 to 40 characters, spaces allowed)
                        	**type**\: str
                        
                        .. attribute:: challenge
                        
                        	Perform challenge/response handshake with new neighbor(s)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key_chain
                        
                        	Name of key chain to use (as created by global 'key chain' command)
                        	**type**\: str
                        
                        .. attribute:: lifetime
                        
                        	Maximum lifetime of neighbor authentication state
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Authentication.Lifetime>`
                        
                        .. attribute:: type
                        
                        	Type of authentication algorithm (default = md5)
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Authentication.Type>`
                        
                        .. attribute:: window_size
                        
                        	Maximum number of messages allowed in receive window (default = 1)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Rsvp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Interface.FastEthernet.Ip.Rsvp.Authentication.Lifetime))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ip.Rsvp.Authentication.Type')])),
                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                            ])
                            self.key = None
                            self.challenge = None
                            self.key_chain = None
                            self.type = None
                            self.window_size = None

                            self.lifetime = Native.Interface.FastEthernet.Ip.Rsvp.Authentication.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Authentication, ['key', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Type of authentication algorithm (default = md5)

                            .. data:: md5 = 0

                            .. data:: sha_1 = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            sha_1 = Enum.YLeaf(1, "sha-1")



                        class Lifetime(Entity):
                            """
                            Maximum lifetime of neighbor authentication state
                            
                            .. attribute:: hh_mm_ss
                            
                            	Lifetime (default = 30 mins) in hh\:mm\:ss format
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ])
                                self.hh_mm_ss = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


                    class Bandwidth(Entity):
                        """
                        RSVP Reservable Bandwidth (kbps)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Value>`
                        
                        .. attribute:: percent
                        
                        	Percentage of interface bandwidth. Values higher than 100 represent overbooking
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: mam
                        
                        	Use bandwidth with MAM model of DSTE
                        	**type**\:  :py:class:`Mam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Mam>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Value)), ("mam", ("mam", Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Mam))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                            ])
                            self.percent = None

                            self.value = Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.mam = Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Mam()
                            self.mam.parent = self
                            self._children_name_map["mam"] = "mam"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth, ['percent'], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	Reservable Bandwidth (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            .. attribute:: sub_pool
                            
                            	Reservable Bandwidth for Tunnel using sub (BC1) pool (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.value = None
                                self.sub_pool = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Value, ['value', 'sub_pool'], name, value)


                        class Mam(Entity):
                            """
                            Use bandwidth with MAM model of DSTE
                            
                            .. attribute:: max_reservable_bw
                            
                            	Maximum Reservable bandwidth for MAM
                            	**type**\:  :py:class:`MaxReservableBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Mam, self).__init__()

                                self.yang_name = "mam"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("max-reservable-bw", ("max_reservable_bw", Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw))])
                                self._leafs = OrderedDict()

                                self.max_reservable_bw = None
                                self._children_name_map["max_reservable_bw"] = "max-reservable-bw"
                                self._segment_path = lambda: "mam"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Mam, [], name, value)


                            class MaxReservableBw(Entity):
                                """
                                Maximum Reservable bandwidth for MAM
                                
                                .. attribute:: value
                                
                                	Reservable Bandwidth (kbps)
                                	**type**\: int
                                
                                	**range:** 1..10000000
                                
                                .. attribute:: bc0
                                
                                	Reservable Bandwidth from global (BC0) pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                .. attribute:: bc1
                                
                                	Reservable Bandwidth from sub pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, self).__init__()

                                    self.yang_name = "max-reservable-bw"
                                    self.yang_parent_name = "mam"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                        ('bc0', (YLeaf(YType.uint32, 'bc0'), ['int'])),
                                        ('bc1', (YLeaf(YType.uint32, 'bc1'), ['int'])),
                                    ])
                                    self.value = None
                                    self.bc0 = None
                                    self.bc1 = None
                                    self._segment_path = lambda: "max-reservable-bw"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, ['value', 'bc0', 'bc1'], name, value)


                    class Neighbor(Entity):
                        """
                        Select permissible RSVP neighbors
                        
                        .. attribute:: acl_number
                        
                        	Access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Rsvp.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                            ])
                            self.acl_number = None
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Neighbor, ['acl_number'], name, value)


                    class Precedence(Entity):
                        """
                        RSVP precedence setting
                        
                        .. attribute:: conform
                        
                        	Precedence for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: exceed
                        
                        	Precedence for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Rsvp.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Precedence, ['conform', 'exceed'], name, value)


                    class Signalling(Entity):
                        """
                        RSVP signalling
                        
                        .. attribute:: dscp
                        
                        	DSCP for RSVP signalling messages
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: fast_local_repair
                        
                        	Fast Local Repair parameters
                        	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Signalling.FastLocalRepair>`
                        
                        .. attribute:: hello
                        
                        	Enable neighbor\-down detection
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Rsvp.Signalling, self).__init__()

                            self.yang_name = "signalling"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Interface.FastEthernet.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.fast_local_repair = Native.Interface.FastEthernet.Ip.Rsvp.Signalling.FastLocalRepair()
                            self.fast_local_repair.parent = self
                            self._children_name_map["fast_local_repair"] = "fast-local-repair"

                            self.hello = None
                            self._children_name_map["hello"] = "hello"
                            self._segment_path = lambda: "signalling"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Signalling, ['dscp'], name, value)


                        class FastLocalRepair(Entity):
                            """
                            Fast Local Repair parameters
                            
                            .. attribute:: wait_time
                            
                            	Wait Time for start of Fast Local Repair in msec
                            	**type**\: int
                            
                            	**range:** 0..5000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                                self.yang_name = "fast-local-repair"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint16, 'wait-time'), ['int'])),
                                ])
                                self.wait_time = None
                                self._segment_path = lambda: "fast-local-repair"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Signalling.FastLocalRepair, ['wait_time'], name, value)


                        class Hello(Entity):
                            """
                            Enable neighbor\-down detection
                            
                            .. attribute:: bfd
                            
                            	Configure BFD trigger for MPLS/TE FRR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	DSCP for RSVP Hello messages
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: graceful_restart
                            
                            	Configure RSVP Graceful Restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: refresh
                            
                            	Configure RSVP Hello refresh behavior for Fast\-Reroute
                            	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Refresh>`
                            
                            .. attribute:: reroute
                            
                            	Configure RSVP Hello refresh behavior for Reroute
                            	**type**\:  :py:class:`Reroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Reroute>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Refresh)), ("reroute", ("reroute", Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Reroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ('graceful_restart', (YLeaf(YType.empty, 'graceful-restart'), ['Empty'])),
                                ])
                                self.bfd = None
                                self.dscp = None
                                self.graceful_restart = None

                                self.refresh = Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Refresh()
                                self.refresh.parent = self
                                self._children_name_map["refresh"] = "refresh"

                                self.reroute = Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Reroute()
                                self.reroute.parent = self
                                self._children_name_map["reroute"] = "reroute"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello, ['bfd', 'dscp', 'graceful_restart'], name, value)


                            class Refresh(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Fast\-Reroute
                                
                                .. attribute:: interval
                                
                                	Hello interval in msec
                                	**type**\: int
                                
                                	**range:** 10..30000
                                
                                .. attribute:: misses
                                
                                	Number of missed Hello Acks which triggers neighbor down
                                	**type**\: int
                                
                                	**range:** 4..10
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Refresh, self).__init__()

                                    self.yang_name = "refresh"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.misses = None
                                    self._segment_path = lambda: "refresh"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Refresh, ['interval', 'misses'], name, value)


                            class Reroute(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Reroute
                                
                                .. attribute:: dscp
                                
                                	DSCP for RSVP Hello messages
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: refresh
                                
                                	Configure RSVP Reroute Hello refresh behavior
                                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh>`
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Reroute, self).__init__()

                                    self.yang_name = "reroute"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh))])
                                    self._leafs = OrderedDict([
                                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ])
                                    self.dscp = None

                                    self.refresh = Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh()
                                    self.refresh.parent = self
                                    self._children_name_map["refresh"] = "refresh"
                                    self._segment_path = lambda: "reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Reroute, ['dscp'], name, value)


                                class Refresh(Entity):
                                    """
                                    Configure RSVP Reroute Hello refresh behavior
                                    
                                    .. attribute:: interval
                                    
                                    	Hello Reroute interval in msec
                                    	**type**\: int
                                    
                                    	**range:** 1000..30000
                                    
                                    .. attribute:: misses
                                    
                                    	Number of missed Hello Acks which triggers neighbor down
                                    	**type**\: int
                                    
                                    	**range:** 4..10
                                    
                                    

                                    """

                                    _prefix = 'ios-rsvp'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, self).__init__()

                                        self.yang_name = "refresh"
                                        self.yang_parent_name = "reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.misses = None
                                        self._segment_path = lambda: "refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, ['interval', 'misses'], name, value)


                    class Tos(Entity):
                        """
                        RSVP TOS setting
                        
                        .. attribute:: conform
                        
                        	TOS for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: exceed
                        
                        	TOS for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Rsvp.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Rsvp.Tos, ['conform', 'exceed'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.FastEthernet.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.FastEthernet.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.FastEthernet.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.FastEthernet.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.FastEthernet.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.FastEthernet.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FastEthernet.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.FastEthernet.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FastEthernet.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.FastEthernet.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.FastEthernet.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.FastEthernet.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.FastEthernet.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.FastEthernet.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.FastEthernet.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FastEthernet.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.FastEthernet.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FastEthernet.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.FastEthernet.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.TrafficFilter>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Flow>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Crypto>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Pim>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: rip
                
                	Configure RIP routing protocol
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Rip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.FastEthernet.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.FastEthernet.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.FastEthernet.Ipv6.Dhcp)), ("address", ("address", Native.Interface.FastEthernet.Ipv6.Address)), ("nd", ("nd", Native.Interface.FastEthernet.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.FastEthernet.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.FastEthernet.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.FastEthernet.Ipv6.Flow)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.FastEthernet.Ipv6.Crypto)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.FastEthernet.Ipv6.Ospf)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.FastEthernet.Ipv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.FastEthernet.Ipv6.Pim)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Interface.FastEthernet.Ipv6.Rip))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None
                    self.unreachables = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.FastEthernet.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.FastEthernet.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.FastEthernet.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.FastEthernet.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.flow = Native.Interface.FastEthernet.Ipv6.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.crypto = Native.Interface.FastEthernet.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.ospf = Native.Interface.FastEthernet.Ipv6.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.no_pim = Native.Interface.FastEthernet.Ipv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.FastEthernet.Ipv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects', 'unreachables'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.FastEthernet.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.FastEthernet.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.FastEthernet.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.FastEthernet.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.FastEthernet.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.FastEthernet.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.FastEthernet.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.FastEthernet.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.FastEthernet.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.FastEthernet.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.FastEthernet.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.FastEthernet.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.FastEthernet.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.FastEthernet.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.FastEthernet.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.FastEthernet.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.FastEthernet.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FastEthernet.Ipv6.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.FastEthernet.Ipv6.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ipv6.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ipv6.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Crypto, ['map'], name, value)


                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process
                    
                    	
                    	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Process>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: encryption
                    
                    	Enable encryption
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Network>`
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process", ("process", Native.Interface.FastEthernet.Ipv6.Ospf.Process)), ("authentication", ("authentication", Native.Interface.FastEthernet.Ipv6.Ospf.Authentication)), ("bfd", ("bfd", Native.Interface.FastEthernet.Ipv6.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.FastEthernet.Ipv6.Ospf.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FastEthernet.Ipv6.Ospf.DemandCircuit)), ("encryption", ("encryption", Native.Interface.FastEthernet.Ipv6.Ospf.Encryption)), ("flood-reduction", ("flood_reduction", Native.Interface.FastEthernet.Ipv6.Ospf.FloodReduction)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FastEthernet.Ipv6.Ospf.MtuIgnore)), ("neighbor", ("neighbor", Native.Interface.FastEthernet.Ipv6.Ospf.Neighbor)), ("network", ("network", Native.Interface.FastEthernet.Ipv6.Ospf.Network)), ("shutdown", ("shutdown", Native.Interface.FastEthernet.Ipv6.Ospf.Shutdown))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.cost = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.FastEthernet.Ipv6.Ospf.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.FastEthernet.Ipv6.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.encryption = Native.Interface.FastEthernet.Ipv6.Ospf.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.network = Native.Interface.FastEthernet.Ipv6.Ospf.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.process = YList(self)
                        self.neighbor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf, ['cost', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Process(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: instance
                        
                        	Set the OSPF instance
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..31
                        
                        		**type**\: int
                        
                        			**range:** 32..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Ospf.Process, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['int','int'])),
                            ])
                            self.id = None
                            self.area = None
                            self.instance = None
                            self._segment_path = lambda: "process" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Process, ['id', 'area', 'instance'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec authentication
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec authentication
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 256..4294967295
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5>`
                            
                            .. attribute:: sha1
                            
                            	Use SHA\-1 authentication
                            	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ])
                                self.spi = None

                                self.md5 = Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.sha1 = Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1()
                                self.sha1.parent = self
                                self._children_name_map["sha1"] = "sha1"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec, ['spi'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Sha1(Entity):
                                """
                                Use SHA\-1 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, self).__init__()

                                    self.yang_name = "sha1"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "sha1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "sha1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ipv6.Ospf.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.DatabaseFilter, ['all', 'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.DemandCircuit, ['disable', 'ignore'], name, value)


                    class Encryption(Entity):
                        """
                        Enable encryption
                        
                        .. attribute:: null
                        
                        	No IPsec encryption on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec encryption
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec encryption
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: esp
                            
                            	Use ESP encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipsec_3des
                            
                            	Use 3DES encryption
                            	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des>`
                            
                            .. attribute:: aes_cbc
                            
                            	Use AES\-CBC encryption
                            	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                                ])
                                self.spi = None
                                self.esp = None

                                self.ipsec_3des = Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des()
                                self.ipsec_3des.parent = self
                                self._children_name_map["ipsec_3des"] = "ipsec_3des"

                                self.aes_cbc = Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc()
                                self.aes_cbc.parent = self
                                self._children_name_map["aes_cbc"] = "aes-cbc"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec, ['spi', 'esp'], name, value)


                            class Ipsec3des(Entity):
                                """
                                Use 3DES encryption
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, self).__init__()

                                    self.yang_name = "ipsec_3des"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "ipsec_3des"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "ipsec_3des"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class AesCbc(Entity):
                                """
                                Use AES\-CBC encryption
                                
                                .. attribute:: aes_cbc_128
                                
                                	Use 128 bit key
                                	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128>`
                                
                                .. attribute:: aes_192
                                
                                	Use 192 bit key
                                	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192>`
                                
                                .. attribute:: aes_256
                                
                                	Use 256 bit key
                                	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, self).__init__()

                                    self.yang_name = "aes-cbc"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256))])
                                    self._leafs = OrderedDict()

                                    self.aes_cbc_128 = Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128()
                                    self.aes_cbc_128.parent = self
                                    self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                    self.aes_192 = Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192()
                                    self.aes_192.parent = self
                                    self._children_name_map["aes_192"] = "aes-192"

                                    self.aes_256 = Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256()
                                    self.aes_256.parent = self
                                    self._children_name_map["aes_256"] = "aes-256"
                                    self._segment_path = lambda: "aes-cbc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, [], name, value)


                                class AesCbc128(Entity):
                                    """
                                    Use 128 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                        self.yang_name = "aes-cbc-128"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-cbc-128"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-cbc-128"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes192(Entity):
                                    """
                                    Use 192 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                        self.yang_name = "aes-192"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-192"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-192"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes256(Entity):
                                    """
                                    Use 256 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                        self.yang_name = "aes-256"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-256"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	Disable Flood Reduction on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Ospf.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.FloodReduction, ['disable'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Ospf.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.MtuIgnore, ['disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Ospf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FastEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.FastEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Ospf.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Ospf.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FastEthernet.Ipv6.Ospf.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ipv6.Ospf.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Ospf.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Ospf.Shutdown, ['disable'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.FastEthernet.Ipv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.FastEthernet.Ipv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Pim.Bsr, ['border'], name, value)


                class Rip(Entity):
                    """
                    Configure RIP routing protocol
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable/disable RIP routing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default_information
                    
                    	Configure handling of default route
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Rip.DefaultInformation>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ipv6.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("default-information", ("default_information", Native.Interface.FastEthernet.Ipv6.Rip.DefaultInformation))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.id = None
                        self.enable = None

                        self.default_information = Native.Interface.FastEthernet.Ipv6.Rip.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Rip, ['id', 'enable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Configure handling of default route
                        
                        .. attribute:: route
                        
                        	
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ipv6.Rip.DefaultInformation.Route>`
                        
                        .. attribute:: metric
                        
                        	Default route metric
                        	**type**\: int
                        
                        	**range:** 1..15
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ipv6.Rip.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route', (YLeaf(YType.enumeration, 'route'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ipv6.Rip.DefaultInformation.Route')])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ])
                            self.route = None
                            self.metric = None
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ipv6.Rip.DefaultInformation, ['route', 'metric'], name, value)

                        class Route(Enum):
                            """
                            Route (Enum Class)

                            .. data:: only = 0

                            .. data:: originate = 1

                            """

                            only = Enum.YLeaf(0, "only")

                            originate = Enum.YLeaf(1, "originate")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FastEthernet.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.FastEthernet.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.FastEthernet.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.FastEthernet.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.FastEthernet.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.FastEthernet.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.FastEthernet.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.FastEthernet.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.FastEthernet.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FastEthernet.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.FastEthernet.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.FastEthernet.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.FastEthernet.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.FastEthernet.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.FastEthernet.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FastEthernet.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.FastEthernet.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.FastEthernet.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.FastEthernet.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.FastEthernet.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.FastEthernet.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.FastEthernet.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.FastEthernet.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.FastEthernet.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FastEthernet.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.FastEthernet.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.FastEthernet.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FastEthernet.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.FastEthernet.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.FastEthernet.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.FastEthernet.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.FastEthernet.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.FastEthernet.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.FastEthernet.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.FastEthernet.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.FastEthernet.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.FastEthernet.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.FastEthernet.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.FastEthernet.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.FastEthernet.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.FastEthernet.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.FastEthernet.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.FastEthernet.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.FastEthernet.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.FastEthernet.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.FastEthernet.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.FastEthernet.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.FastEthernet.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.FastEthernet.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FastEthernet.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.FastEthernet.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.FastEthernet.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.FastEthernet.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.FastEthernet.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.FastEthernet.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.FastEthernet.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.FastEthernet.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FastEthernet.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.FastEthernet.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.FastEthernet.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.FastEthernet.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.FastEthernet.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.FastEthernet.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.FastEthernet.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.FastEthernet.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FastEthernet.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.FastEthernet.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.FastEthernet.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.FastEthernet.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.FastEthernet.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.FastEthernet.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.FastEthernet.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.FastEthernet.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.FastEthernet.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.FastEthernet.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.FastEthernet.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.FastEthernet.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.FastEthernet.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.FastEthernet.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.FastEthernet.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.FastEthernet.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.FastEthernet.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FastEthernet.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.FastEthernet.CarrierDelay.Down)), ("up", ("up", Native.Interface.FastEthernet.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.FastEthernet.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.FastEthernet.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.FastEthernet.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.FastEthernet.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.FastEthernet.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.FastEthernet.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.FastEthernet.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.FastEthernet.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.FastEthernet.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.FastEthernet.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.FastEthernet.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.FastEthernet.Plim.Ethernet)), ("qos", ("qos", Native.Interface.FastEthernet.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.FastEthernet.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.FastEthernet.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FastEthernet.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.FastEthernet.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.FastEthernet.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.FastEthernet.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.FastEthernet.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.FastEthernet.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.FastEthernet.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.FastEthernet.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.FastEthernet.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.FastEthernet.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.FastEthernet.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.FastEthernet.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.FastEthernet.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.FastEthernet.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.FastEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.FastEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.FastEthernet.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.FastEthernet.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.L2protocol>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.FastEthernet.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.FastEthernet.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.FastEthernet.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.FastEthernet.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.FastEthernet.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.FastEthernet.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.FastEthernet.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.FastEthernet.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.FastEthernet.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.FastEthernet.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.FastEthernet.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.FastEthernet.Service.Instance.L2protocol)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.FastEthernet.Service.Instance.Xconnect)), ("Cisco-IOS-XE-l2vpn:xconnect-pw-class", ("xconnect_pw_class", Native.Interface.FastEthernet.Service.Instance.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.FastEthernet.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.FastEthernet.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.FastEthernet.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.FastEthernet.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.FastEthernet.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.FastEthernet.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.FastEthernet.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.FastEthernet.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.FastEthernet.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.FastEthernet.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.FastEthernet.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.FastEthernet.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"

                        self.xconnect = Native.Interface.FastEthernet.Service.Instance.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                        self.xconnect_pw_class = Native.Interface.FastEthernet.Service.Instance.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.FastEthernet.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.FastEthernet.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.FastEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.FastEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.FastEthernet.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.FastEthernet.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.FastEthernet.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.FastEthernet.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.FastEthernet.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.FastEthernet.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.FastEthernet.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.FastEthernet.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.FastEthernet.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.FastEthernet.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.FastEthernet.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.FastEthernet.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.FastEthernet.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.FastEthernet.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.FastEthernet.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.FastEthernet.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.FastEthernet.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.FastEthernet.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.FastEthernet.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.FastEthernet.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.FastEthernet.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.FastEthernet.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.FastEthernet.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.FastEthernet.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.FastEthernet.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.FastEthernet.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.FastEthernet.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.FastEthernet.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Service.Instance.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Service.Instance.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Lacp(Entity):
                """
                LACP interface subcommands
                
                .. attribute:: port_priority
                
                	LACP priority on this interface 
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rate
                
                	Rate at which the LACP packets are requested to be ingressed to this interface
                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Lacp.Rate>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Lacp, self).__init__()

                    self.yang_name = "lacp"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_priority', (YLeaf(YType.uint32, 'port-priority'), ['int'])),
                        ('rate', (YLeaf(YType.enumeration, 'rate'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Lacp.Rate')])),
                    ])
                    self.port_priority = None
                    self.rate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:lacp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Lacp, ['port_priority', 'rate'], name, value)

                class Rate(Enum):
                    """
                    Rate (Enum Class)

                    Rate at which the LACP packets are requested to be ingressed to this interface

                    .. data:: fast = 0

                    .. data:: normal = 1

                    """

                    fast = Enum.YLeaf(0, "fast")

                    normal = Enum.YLeaf(1, "normal")



            class CiscoIOSXEEthernetMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: dot1q_in_clear
                    
                    	Dot1q in Clear option
                    	**type**\:  :py:class:`Dot1qInClear <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear>`
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('dot1q_in_clear', (YLeaf(YType.enumeration, 'dot1q-in-clear'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear')])),
                        ])
                        self.dot1q_in_clear = None

                        self.replay_protection = Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, ['dot1q_in_clear'], name, value)

                    class Dot1qInClear(Enum):
                        """
                        Dot1qInClear (Enum Class)

                        Dot1q in Clear option

                        .. data:: Y_1 = 0

                        """

                        Y_1 = Enum.YLeaf(0, "1")



                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, ['window_size'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FastEthernet.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.FastEthernet.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.FastEthernet.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.FastEthernet.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.FastEthernet.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.FastEthernet.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.FastEthernet.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Auto(Entity):
                """
                Configure Automation
                
                .. attribute:: qos
                
                	Configure AutoQoS
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Auto.Qos>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Auto, self).__init__()

                    self.yang_name = "auto"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("qos", ("qos", Native.Interface.FastEthernet.Auto.Qos))])
                    self._leafs = OrderedDict()

                    self.qos = Native.Interface.FastEthernet.Auto.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:auto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Auto, [], name, value)


                class Qos(Entity):
                    """
                    Configure AutoQoS
                    
                    .. attribute:: classify
                    
                    	Configure classification for untrusted devices
                    	**type**\:  :py:class:`Classify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Auto.Qos.Classify>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trust
                    
                    	Trust the DSCP/CoS marking
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Auto.Qos.Trust>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: video
                    
                    	Configure AutoQoS for video devices
                    	**type**\:  :py:class:`Video <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Auto.Qos.Video>`
                    
                    .. attribute:: voip
                    
                    	Configure AutoQoS for VoIP
                    	**type**\:  :py:class:`Voip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Auto.Qos.Voip>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Auto.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "auto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("classify", ("classify", Native.Interface.FastEthernet.Auto.Qos.Classify)), ("trust", ("trust", Native.Interface.FastEthernet.Auto.Qos.Trust)), ("video", ("video", Native.Interface.FastEthernet.Auto.Qos.Video)), ("voip", ("voip", Native.Interface.FastEthernet.Auto.Qos.Voip))])
                        self._leafs = OrderedDict()

                        self.classify = None
                        self._children_name_map["classify"] = "classify"

                        self.trust = None
                        self._children_name_map["trust"] = "trust"

                        self.video = Native.Interface.FastEthernet.Auto.Qos.Video()
                        self.video.parent = self
                        self._children_name_map["video"] = "video"

                        self.voip = None
                        self._children_name_map["voip"] = "voip"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Auto.Qos, [], name, value)


                    class Classify(Entity):
                        """
                        Configure classification for untrusted devices
                        
                        .. attribute:: police
                        
                        	Configure QoS policing for untrusted devices
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Auto.Qos.Classify, self).__init__()

                            self.yang_name = "classify"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('police', (YLeaf(YType.empty, 'police'), ['Empty'])),
                            ])
                            self.police = None
                            self._segment_path = lambda: "classify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Auto.Qos.Classify, [u'police'], name, value)


                    class Trust(Entity):
                        """
                        Trust the DSCP/CoS marking
                        
                        .. attribute:: cos
                        
                        	Trust the CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	Trust the DSCP marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Auto.Qos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cos', (YLeaf(YType.empty, 'cos'), ['Empty'])),
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ])
                            self.cos = None
                            self.dscp = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Auto.Qos.Trust, [u'cos', u'dscp'], name, value)


                    class Video(Entity):
                        """
                        Configure AutoQoS for video devices
                        
                        .. attribute:: cts
                        
                        	Trust the QoS marking of the Cisco Telepresence System
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ip_camera
                        
                        	Trust the QoS marking of the Ip Video Surveillance camera
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: media_player
                        
                        	Trust the Qos marking of the Cisco Media Player
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Auto.Qos.Video, self).__init__()

                            self.yang_name = "video"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('cts', (YLeaf(YType.empty, 'cts'), ['Empty'])),
                                ('ip_camera', (YLeaf(YType.empty, 'ip-camera'), ['Empty'])),
                                ('media_player', (YLeaf(YType.empty, 'media-player'), ['Empty'])),
                            ])
                            self.cts = None
                            self.ip_camera = None
                            self.media_player = None
                            self._segment_path = lambda: "video"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Auto.Qos.Video, [u'cts', u'ip_camera', u'media_player'], name, value)


                    class Voip(Entity):
                        """
                        Configure AutoQoS for VoIP
                        
                        .. attribute:: cisco_phone
                        
                        	Trust the QoS marking of Cisco IP Phone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cisco_softphone
                        
                        	Trust the QoS marking of Cisco IP SoftPhone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trust
                        
                        	Trust the DSCP/CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Auto.Qos.Voip, self).__init__()

                            self.yang_name = "voip"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cisco_phone', (YLeaf(YType.empty, 'cisco-phone'), ['Empty'])),
                                ('cisco_softphone', (YLeaf(YType.empty, 'cisco-softphone'), ['Empty'])),
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.cisco_phone = None
                            self.cisco_softphone = None
                            self.trust = None
                            self._segment_path = lambda: "voip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Auto.Qos.Voip, [u'cisco_phone', u'cisco_softphone', u'trust'], name, value)


            class Datalink(Entity):
                """
                Interface Datalink commands
                
                .. attribute:: flow
                
                	Interface Flow configuration subcommands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Datalink.Flow>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Datalink, self).__init__()

                    self.yang_name = "datalink"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flow", ("flow", Native.Interface.FastEthernet.Datalink.Flow))])
                    self._leafs = OrderedDict()

                    self.flow = Native.Interface.FastEthernet.Datalink.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:datalink"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Datalink, [], name, value)


                class Flow(Entity):
                    """
                    Interface Flow configuration subcommands
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Datalink.Flow.Monitor>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Datalink.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "datalink"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FastEthernet.Datalink.Flow.Monitor))])
                        self._leafs = OrderedDict()

                        self.monitor = None
                        self._children_name_map["monitor"] = "monitor"
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Datalink.Flow, [], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: user_defined_flow
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: input_output
                        
                        	Apply Flow Monitor on input/output traffic
                        	**type**\:  :py:class:`InputOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Datalink.Flow.Monitor.InputOutput>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Datalink.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('user_defined_flow', (YLeaf(YType.str, 'User-defined-flow'), ['str'])),
                                ('input_output', (YLeaf(YType.enumeration, 'input-output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Datalink.Flow.Monitor.InputOutput')])),
                            ])
                            self.user_defined_flow = None
                            self.input_output = None
                            self._segment_path = lambda: "monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Datalink.Flow.Monitor, [u'user_defined_flow', u'input_output'], name, value)

                        class InputOutput(Enum):
                            """
                            InputOutput (Enum Class)

                            Apply Flow Monitor on input/output traffic

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



            class Energywise(Entity):
                """
                EnergyWise interface configurations
                
                .. attribute:: activitycheck
                
                	Apply an activity check before turning off power    to this PoE port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: level
                
                	Set the EnergyWise level of this interface  or attached entity
                	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Energywise.Level>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Energywise, self).__init__()

                    self.yang_name = "energywise"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Interface.FastEthernet.Energywise.Level))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('activitycheck', (YLeaf(YType.empty, 'activitycheck'), ['Empty'])),
                    ])
                    self.activitycheck = None

                    self.level = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:energywise"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Energywise, [u'activitycheck'], name, value)


                class Level(Entity):
                    """
                    Set the EnergyWise level of this interface 
                    or attached entity
                    
                    .. attribute:: range  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..10
                    
                    .. attribute:: recurrence
                    
                    	Specify that this level setting should  recur at the specified time
                    	**type**\:  :py:class:`Recurrence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Energywise.Level.Recurrence>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Energywise.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "energywise"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("recurrence", ("recurrence", Native.Interface.FastEthernet.Energywise.Level.Recurrence))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                        ])
                        self.range = None

                        self.recurrence = Native.Interface.FastEthernet.Energywise.Level.Recurrence()
                        self.recurrence.parent = self
                        self._children_name_map["recurrence"] = "recurrence"
                        self._segment_path = lambda: "level" + "[range='" + str(self.range) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Energywise.Level, [u'range'], name, value)


                    class Recurrence(Entity):
                        """
                        Specify that this level setting should 
                        recur at the specified time
                        
                        .. attribute:: importance
                        
                        	Specify the importance at which the event  should be sent when it recurs
                        	**type**\: list of  		 :py:class:`Importance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Energywise.Level.Recurrence.Importance>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Energywise.Level.Recurrence, self).__init__()

                            self.yang_name = "recurrence"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("importance", ("importance", Native.Interface.FastEthernet.Energywise.Level.Recurrence.Importance))])
                            self._leafs = OrderedDict()

                            self.importance = YList(self)
                            self._segment_path = lambda: "recurrence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Energywise.Level.Recurrence, [], name, value)


                        class Importance(Entity):
                            """
                            Specify the importance at which the event 
                            should be sent when it recurs
                            
                            .. attribute:: range  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: at
                            
                            	Specify the time(s) this level setting should occur
                            	**type**\:  :py:class:`At <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Energywise.Level.Recurrence.Importance.At>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Energywise.Level.Recurrence.Importance, self).__init__()

                                self.yang_name = "importance"
                                self.yang_parent_name = "recurrence"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("at", ("at", Native.Interface.FastEthernet.Energywise.Level.Recurrence.Importance.At))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.at = Native.Interface.FastEthernet.Energywise.Level.Recurrence.Importance.At()
                                self.at.parent = self
                                self._children_name_map["at"] = "at"
                                self._segment_path = lambda: "importance" + "[range='" + str(self.range) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Energywise.Level.Recurrence.Importance, [u'range'], name, value)


                            class At(Entity):
                                """
                                Specify the time(s) this level setting should occur
                                
                                .. attribute:: minute
                                
                                	cron format of minute(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..59
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: hour
                                
                                	cron format of hour(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..23
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: day
                                
                                	cron format of day(s) of month
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..31
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: month
                                
                                	cron format of month(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..12
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: weekday
                                
                                	cron format of weekday(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..7
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Energywise.Level.Recurrence.Importance.At, self).__init__()

                                    self.yang_name = "at"
                                    self.yang_parent_name = "importance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minute', (YLeaf(YType.str, 'minute'), ['int','str'])),
                                        ('hour', (YLeaf(YType.str, 'hour'), ['int','str'])),
                                        ('day', (YLeaf(YType.str, 'day'), ['int','str'])),
                                        ('month', (YLeaf(YType.str, 'month'), ['int','str'])),
                                        ('weekday', (YLeaf(YType.str, 'weekday'), ['int','str'])),
                                    ])
                                    self.minute = None
                                    self.hour = None
                                    self.day = None
                                    self.month = None
                                    self.weekday = None
                                    self._segment_path = lambda: "at"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Energywise.Level.Recurrence.Importance.At, [u'minute', u'hour', u'day', u'month', u'weekday'], name, value)


            class Location(Entity):
                """
                Interface location information
                
                .. attribute:: civic_location_id
                
                	Civic location information
                	**type**\:  :py:class:`CivicLocationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Location.CivicLocationId>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Location, self).__init__()

                    self.yang_name = "location"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("civic-location-id", ("civic_location_id", Native.Interface.FastEthernet.Location.CivicLocationId))])
                    self._leafs = OrderedDict()

                    self.civic_location_id = Native.Interface.FastEthernet.Location.CivicLocationId()
                    self.civic_location_id.parent = self
                    self._children_name_map["civic_location_id"] = "civic-location-id"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:location"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Location, [], name, value)


                class CivicLocationId(Entity):
                    """
                    Civic location information
                    
                    .. attribute:: location_identifier
                    
                    	civic location identifier string
                    	**type**\: str
                    
                    .. attribute:: host
                    
                    	Globally defined host location identifer
                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Location.CivicLocationId.Host>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: none
                    
                    	No globally defined location identifer
                    	**type**\:  :py:class:`Y_None <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Location.CivicLocationId.Y_None>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Location.CivicLocationId, self).__init__()

                        self.yang_name = "civic-location-id"
                        self.yang_parent_name = "location"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("host", ("host", Native.Interface.FastEthernet.Location.CivicLocationId.Host)), ("none", ("none", Native.Interface.FastEthernet.Location.CivicLocationId.Y_None))])
                        self._leafs = OrderedDict([
                            ('location_identifier', (YLeaf(YType.str, 'location-identifier'), ['str'])),
                        ])
                        self.location_identifier = None

                        self.host = None
                        self._children_name_map["host"] = "host"

                        self.none = None
                        self._children_name_map["none"] = "none"
                        self._segment_path = lambda: "civic-location-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Location.CivicLocationId, [u'location_identifier'], name, value)


                    class Host(Entity):
                        """
                        Globally defined host location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Location.CivicLocationId.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "host"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Location.CivicLocationId.Host, [u'port_location'], name, value)


                    class Y_None(Entity):
                        """
                        No globally defined location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Location.CivicLocationId.Y_None, self).__init__()

                            self.yang_name = "none"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Location.CivicLocationId.Y_None, [u'port_location'], name, value)


            class Mac(Entity):
                """
                MAC interface commands
                
                .. attribute:: access_group
                
                	MAC access\-group configuration commands
                	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mac.AccessGroup>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Mac, self).__init__()

                    self.yang_name = "mac"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.FastEthernet.Mac.AccessGroup))])
                    self._leafs = OrderedDict()

                    self.access_group = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:mac"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Mac, [], name, value)


                class AccessGroup(Entity):
                    """
                    MAC access\-group configuration commands
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mac.AccessGroup.Direction>`
                    
                    .. attribute:: acl_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Mac.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "mac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Mac.AccessGroup.Direction')])),
                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                        ])
                        self.direction = None
                        self.acl_name = None
                        self._segment_path = lambda: "access-group" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Mac.AccessGroup, [u'direction', u'acl_name'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Macro(Entity):
                """
                Command macro
                
                .. attribute:: description
                
                	Macro description for this interface
                	**type**\: str
                
                .. attribute:: auto
                
                	Smartport interface macro configurations
                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Macro.Auto>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Macro, self).__init__()

                    self.yang_name = "macro"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.FastEthernet.Macro.Auto))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.auto = Native.Interface.FastEthernet.Macro.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "auto"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macro"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Macro, [u'description'], name, value)


                class Auto(Entity):
                    """
                    Smartport interface macro configurations
                    
                    .. attribute:: processing
                    
                    	Enable smartport macro auto execution on this interface
                    	**type**\: bool
                    
                    .. attribute:: port
                    
                    	Provide interface specific configuration for macro processing
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Macro.Auto.Port>`
                    
                    .. attribute:: control
                    
                    	Control macro auto execution
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Macro.Auto.Control>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Macro.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "macro"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port", ("port", Native.Interface.FastEthernet.Macro.Auto.Port)), ("control", ("control", Native.Interface.FastEthernet.Macro.Auto.Control))])
                        self._leafs = OrderedDict([
                            ('processing', (YLeaf(YType.boolean, 'processing'), ['bool'])),
                        ])
                        self.processing = None

                        self.port = Native.Interface.FastEthernet.Macro.Auto.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.control = Native.Interface.FastEthernet.Macro.Auto.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"
                        self._segment_path = lambda: "auto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Macro.Auto, [u'processing'], name, value)


                    class Port(Entity):
                        """
                        Provide interface specific configuration for macro processing
                        
                        .. attribute:: sticky
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Macro.Auto.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                            ])
                            self.sticky = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Macro.Auto.Port, [u'sticky'], name, value)


                    class Control(Entity):
                        """
                        Control macro auto execution
                        
                        .. attribute:: device
                        
                        	Enable macro auto execution for devices
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Macro.Auto.Control.Device>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Macro.Auto.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("device", ("device", Native.Interface.FastEthernet.Macro.Auto.Control.Device))])
                            self._leafs = OrderedDict()

                            self.device = Native.Interface.FastEthernet.Macro.Auto.Control.Device()
                            self.device.parent = self
                            self._children_name_map["device"] = "device"
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Macro.Auto.Control, [], name, value)


                        class Device(Entity):
                            """
                            Enable macro auto execution for devices
                            
                            .. attribute:: phone
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Macro.Auto.Control.Device, self).__init__()

                                self.yang_name = "device"
                                self.yang_parent_name = "control"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('phone', (YLeaf(YType.empty, 'phone'), ['Empty'])),
                                ])
                                self.phone = None
                                self._segment_path = lambda: "device"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Macro.Auto.Control.Device, [u'phone'], name, value)


            class DualActive(Entity):
                """
                
                
                .. attribute:: fast_hello
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.DualActive, self).__init__()

                    self.yang_name = "dual-active"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fast_hello', (YLeaf(YType.empty, 'fast-hello'), ['Empty'])),
                    ])
                    self.fast_hello = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:dual-active"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.DualActive, [u'fast_hello'], name, value)


            class LoadBalancing(Entity):
                """
                Etherchannel Load\-Balancing
                
                .. attribute:: flow
                
                	Based on the traffic flows identified by the packet headers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Based on the VLAN to member links manual configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.LoadBalancing, self).__init__()

                    self.yang_name = "load-balancing"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('flow', (YLeaf(YType.empty, 'flow'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.flow = None
                    self.vlan = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:load-balancing"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.LoadBalancing, [u'flow', u'vlan'], name, value)


            class VlanRange(Entity):
                """
                
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4096
                
                		**type**\: str
                
                .. attribute:: service_policy
                
                	Configure QoS Service Policy
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.VlanRange.ServicePolicy>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.VlanRange, self).__init__()

                    self.yang_name = "vlan-range"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.FastEthernet.VlanRange.ServicePolicy))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                    ])
                    self.id = None

                    self.service_policy = Native.Interface.FastEthernet.VlanRange.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:vlan-range" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.VlanRange, [u'id'], name, value)


                class ServicePolicy(Entity):
                    """
                    Configure QoS Service Policy
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.VlanRange.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "vlan-range"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.VlanRange.ServicePolicy, [u'input', u'output'], name, value)


            class Switch(Entity):
                """
                
                
                .. attribute:: virtual
                
                	
                	**type**\:  :py:class:`Virtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Switch.Virtual>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("virtual", ("virtual", Native.Interface.FastEthernet.Switch.Virtual))])
                    self._leafs = OrderedDict()

                    self.virtual = Native.Interface.FastEthernet.Switch.Virtual()
                    self.virtual.parent = self
                    self._children_name_map["virtual"] = "virtual"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:switch"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Switch, [], name, value)


                class Virtual(Entity):
                    """
                    
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Switch.Virtual, self).__init__()

                        self.yang_name = "virtual"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ])
                        self.link = None
                        self._segment_path = lambda: "virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Switch.Virtual, [u'link'], name, value)


            class SrrQueue(Entity):
                """
                
                
                .. attribute:: bandwidth
                
                	
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SrrQueue.Bandwidth>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.SrrQueue, self).__init__()

                    self.yang_name = "srr-queue"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.FastEthernet.SrrQueue.Bandwidth))])
                    self._leafs = OrderedDict()

                    self.bandwidth = Native.Interface.FastEthernet.SrrQueue.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:srr-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.SrrQueue, [], name, value)


                class Bandwidth(Entity):
                    """
                    
                    
                    .. attribute:: shape
                    
                    	
                    	**type**\:  :py:class:`Shape <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SrrQueue.Bandwidth.Shape>`
                    
                    .. attribute:: share
                    
                    	
                    	**type**\:  :py:class:`Share <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SrrQueue.Bandwidth.Share>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.SrrQueue.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "srr-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("shape", ("shape", Native.Interface.FastEthernet.SrrQueue.Bandwidth.Shape)), ("share", ("share", Native.Interface.FastEthernet.SrrQueue.Bandwidth.Share))])
                        self._leafs = OrderedDict()

                        self.shape = Native.Interface.FastEthernet.SrrQueue.Bandwidth.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"

                        self.share = Native.Interface.FastEthernet.SrrQueue.Bandwidth.Share()
                        self.share.parent = self
                        self._children_name_map["share"] = "share"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.SrrQueue.Bandwidth, [], name, value)


                    class Shape(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.SrrQueue.Bandwidth.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint16, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint16, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint16, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint16, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "shape"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.SrrQueue.Bandwidth.Shape, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


                    class Share(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.SrrQueue.Bandwidth.Share, self).__init__()

                            self.yang_name = "share"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint8, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint8, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint8, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint8, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "share"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.SrrQueue.Bandwidth.Share, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


            class CiscoIOSXESwitchMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection>`
                    
                    .. attribute:: network_link
                    
                    	Enable macsec on switch connected interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('network_link', (YLeaf(YType.empty, 'network-link'), ['Empty'])),
                        ])
                        self.network_link = None

                        self.replay_protection = Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption.Macsec, [u'network_link'], name, value)


                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, [u'window_size'], name, value)


            class DeviceTracking(Entity):
                """
                Configure device\-tracking on the interface
                
                .. attribute:: attach_policy
                
                	Apply a policy for feature device\-tracking
                	**type**\: str
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FastEthernet.DeviceTracking, self).__init__()

                    self.yang_name = "device-tracking"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                    ])
                    self.attach_policy = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:device-tracking"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.DeviceTracking, [u'attach_policy'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.FastEthernet.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.FastEthernet.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.FastEthernet.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.FastEthernet.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.FastEthernet.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.FastEthernet.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.FastEthernet.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.FastEthernet.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class Mka(Entity):
                """
                MACsec Key Agreement (MKA) interface configuration
                
                .. attribute:: policy
                
                	Apply MKA Policy
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mka.Policy>`
                
                .. attribute:: pre_shared_key
                
                	Configure MKA Pre\-Shared\-Key
                	**type**\:  :py:class:`PreSharedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mka.PreSharedKey>`
                
                

                """

                _prefix = 'ios-mka'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Mka, self).__init__()

                    self.yang_name = "mka"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.FastEthernet.Mka.Policy)), ("pre-shared-key", ("pre_shared_key", Native.Interface.FastEthernet.Mka.PreSharedKey))])
                    self._leafs = OrderedDict()

                    self.policy = Native.Interface.FastEthernet.Mka.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.pre_shared_key = Native.Interface.FastEthernet.Mka.PreSharedKey()
                    self.pre_shared_key.parent = self
                    self._children_name_map["pre_shared_key"] = "pre-shared-key"
                    self._segment_path = lambda: "Cisco-IOS-XE-mka:mka"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Mka, [], name, value)


                class Policy(Entity):
                    """
                    Apply MKA Policy
                    
                    .. attribute:: name
                    
                    	MKA Policy NAME
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Mka.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Mka.Policy, ['name'], name, value)


                class PreSharedKey(Entity):
                    """
                    Configure MKA Pre\-Shared\-Key
                    
                    .. attribute:: key_chain
                    
                    	Configure the key\-chain name
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mka.PreSharedKey.KeyChain>`
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Mka.PreSharedKey, self).__init__()

                        self.yang_name = "pre-shared-key"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.FastEthernet.Mka.PreSharedKey.KeyChain))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.FastEthernet.Mka.PreSharedKey.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"
                        self._segment_path = lambda: "pre-shared-key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Mka.PreSharedKey, [], name, value)


                    class KeyChain(Entity):
                        """
                        Configure the key\-chain name
                        
                        .. attribute:: name
                        
                        	Name of key\-chain to be used to get keys
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mka'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Mka.PreSharedKey.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "pre-shared-key"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Mka.PreSharedKey.KeyChain, ['name'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FastEthernet.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.FastEthernet.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Utd, ['enable'], name, value)


            class Xconnect(Entity):
                """
                Xconnect commands
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: vcid
                
                	
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: encapsulation
                
                	Data encapsulation method
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Xconnect.Encapsulation>`
                
                .. attribute:: manual
                
                	Manually configure L2TP session parameters
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sequence
                
                	Configure sequencing options for xconnect
                	**type**\:  :py:class:`Sequence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Xconnect.Sequence>`
                
                .. attribute:: pw_class
                
                	Pseudowire\-class to use for encapsulation and protocol configuration
                	**type**\: str
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Xconnect.Encapsulation')])),
                        ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                        ('sequence', (YLeaf(YType.enumeration, 'sequence'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Xconnect.Sequence')])),
                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                    ])
                    self.address = None
                    self.vcid = None
                    self.encapsulation = None
                    self.manual = None
                    self.sequence = None
                    self.pw_class = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'sequence', 'pw_class'], name, value)

                class Encapsulation(Enum):
                    """
                    Encapsulation (Enum Class)

                    Data encapsulation method

                    .. data:: mpls = 0

                    .. data:: l2tpv3 = 1

                    """

                    mpls = Enum.YLeaf(0, "mpls")

                    l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                class Sequence(Enum):
                    """
                    Sequence (Enum Class)

                    Configure sequencing options for xconnect

                    .. data:: both = 0

                    .. data:: receive = 1

                    .. data:: transmit = 2

                    """

                    both = Enum.YLeaf(0, "both")

                    receive = Enum.YLeaf(1, "receive")

                    transmit = Enum.YLeaf(2, "transmit")



            class Evpn(Entity):
                """
                
                
                .. attribute:: ethernet_segment
                
                	Ethernet segment local discriminator value
                	**type**\: list of  		 :py:class:`EthernetSegment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Evpn.EthernetSegment>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Evpn, self).__init__()

                    self.yang_name = "evpn"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet-segment", ("ethernet_segment", Native.Interface.FastEthernet.Evpn.EthernetSegment))])
                    self._leafs = OrderedDict()

                    self.ethernet_segment = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:evpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Evpn, [], name, value)


                class EthernetSegment(Entity):
                    """
                    Ethernet segment local discriminator value
                    
                    .. attribute:: es_value  (key)
                    
                    	Ethernet segment local discriminator value
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: df_election
                    
                    	Designated forwarder election parameters
                    	**type**\:  :py:class:`DfElection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Evpn.EthernetSegment.DfElection>`
                    
                    .. attribute:: redundancy
                    
                    	Multi\-homing redundancy parameters
                    	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Evpn.EthernetSegment.Redundancy>`
                    
                    .. attribute:: sytem_mac
                    
                    	System MAC address for generating the Ethernet Segment ID
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Evpn.EthernetSegment, self).__init__()

                        self.yang_name = "ethernet-segment"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['es_value']
                        self._child_classes = OrderedDict([("df-election", ("df_election", Native.Interface.FastEthernet.Evpn.EthernetSegment.DfElection)), ("redundancy", ("redundancy", Native.Interface.FastEthernet.Evpn.EthernetSegment.Redundancy))])
                        self._leafs = OrderedDict([
                            ('es_value', (YLeaf(YType.uint16, 'es-value'), ['int'])),
                            ('sytem_mac', (YLeaf(YType.str, 'sytem-mac'), ['str'])),
                        ])
                        self.es_value = None
                        self.sytem_mac = None

                        self.df_election = Native.Interface.FastEthernet.Evpn.EthernetSegment.DfElection()
                        self.df_election.parent = self
                        self._children_name_map["df_election"] = "df-election"

                        self.redundancy = Native.Interface.FastEthernet.Evpn.EthernetSegment.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                        self._segment_path = lambda: "ethernet-segment" + "[es-value='" + str(self.es_value) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Evpn.EthernetSegment, ['es_value', 'sytem_mac'], name, value)


                    class DfElection(Entity):
                        """
                        Designated forwarder election parameters
                        
                        .. attribute:: wait_time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Evpn.EthernetSegment.DfElection, self).__init__()

                            self.yang_name = "df-election"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wait_time', (YLeaf(YType.uint8, 'wait-time'), ['int'])),
                            ])
                            self.wait_time = None
                            self._segment_path = lambda: "df-election"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Evpn.EthernetSegment.DfElection, ['wait_time'], name, value)


                    class Redundancy(Entity):
                        """
                        Multi\-homing redundancy parameters
                        
                        .. attribute:: all_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: single_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Evpn.EthernetSegment.Redundancy, self).__init__()

                            self.yang_name = "redundancy"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all_active', (YLeaf(YType.empty, 'all-active'), ['Empty'])),
                                ('single_active', (YLeaf(YType.empty, 'single-active'), ['Empty'])),
                            ])
                            self.all_active = None
                            self.single_active = None
                            self._segment_path = lambda: "redundancy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Evpn.EthernetSegment.Redundancy, ['all_active', 'single_active'], name, value)


            class FabricDomain(Entity):
                """
                Fabric\-domain interface command
                
                .. attribute:: iwan_fabric
                
                	
                	**type**\:  :py:class:`IwanFabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.FabricDomain.IwanFabric>`
                
                

                """

                _prefix = 'ios-iwanfabric'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.FabricDomain, self).__init__()

                    self.yang_name = "fabric-domain"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("iwan-fabric", ("iwan_fabric", Native.Interface.FastEthernet.FabricDomain.IwanFabric))])
                    self._leafs = OrderedDict()

                    self.iwan_fabric = Native.Interface.FastEthernet.FabricDomain.IwanFabric()
                    self.iwan_fabric.parent = self
                    self._children_name_map["iwan_fabric"] = "iwan-fabric"
                    self._segment_path = lambda: "Cisco-IOS-XE-iwanfabric:fabric-domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.FabricDomain, [], name, value)


                class IwanFabric(Entity):
                    """
                    
                    
                    .. attribute:: word
                    
                    	
                    	**type**\: list of  		 :py:class:`Word <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.FabricDomain.IwanFabric.Word>`
                    
                    

                    """

                    _prefix = 'ios-iwanfabric'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.FabricDomain.IwanFabric, self).__init__()

                        self.yang_name = "iwan-fabric"
                        self.yang_parent_name = "fabric-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("word", ("word", Native.Interface.FastEthernet.FabricDomain.IwanFabric.Word))])
                        self._leafs = OrderedDict()

                        self.word = YList(self)
                        self._segment_path = lambda: "iwan-fabric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.FabricDomain.IwanFabric, [], name, value)


                    class Word(Entity):
                        """
                        
                        
                        .. attribute:: word  (key)
                        
                        	Path name
                        	**type**\: str
                        
                        .. attribute:: interface_id
                        
                        	Specify the interface\-id value
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-iwanfabric'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.FabricDomain.IwanFabric.Word, self).__init__()

                            self.yang_name = "word"
                            self.yang_parent_name = "iwan-fabric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                            ])
                            self.word = None
                            self.interface_id = None
                            self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.FabricDomain.IwanFabric.Word, ['word', 'interface_id'], name, value)


            class Mvrp(Entity):
                """
                
                
                .. attribute:: mvrp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: registration
                
                	
                	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mvrp.Registration>`
                
                .. attribute:: timer
                
                	
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mvrp.Timer>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mvrp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Mvrp, self).__init__()

                    self.yang_name = "mvrp"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("registration", ("registration", Native.Interface.FastEthernet.Mvrp.Registration)), ("timer", ("timer", Native.Interface.FastEthernet.Mvrp.Timer))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mvrp', (YLeaf(YType.empty, 'mvrp'), ['Empty'])),
                    ])
                    self.mvrp = None

                    self.registration = Native.Interface.FastEthernet.Mvrp.Registration()
                    self.registration.parent = self
                    self._children_name_map["registration"] = "registration"

                    self.timer = Native.Interface.FastEthernet.Mvrp.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-mvrp:mvrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Mvrp, ['mvrp'], name, value)


                class Registration(Entity):
                    """
                    
                    
                    .. attribute:: fixed
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: forbidden
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: normal
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Mvrp.Registration, self).__init__()

                        self.yang_name = "registration"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fixed', (YLeaf(YType.empty, 'fixed'), ['Empty'])),
                            ('forbidden', (YLeaf(YType.empty, 'forbidden'), ['Empty'])),
                            ('normal', (YLeaf(YType.empty, 'normal'), ['Empty'])),
                        ])
                        self.fixed = None
                        self.forbidden = None
                        self.normal = None
                        self._segment_path = lambda: "registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Mvrp.Registration, ['fixed', 'forbidden', 'normal'], name, value)


                class Timer(Entity):
                    """
                    
                    
                    .. attribute:: join
                    
                    	
                    	**type**\:  :py:class:`Join <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mvrp.Timer.Join>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave
                    
                    	
                    	**type**\:  :py:class:`Leave <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mvrp.Timer.Leave>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave_all
                    
                    	
                    	**type**\:  :py:class:`LeaveAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Mvrp.Timer.LeaveAll>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: periodic
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Mvrp.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("join", ("join", Native.Interface.FastEthernet.Mvrp.Timer.Join)), ("leave", ("leave", Native.Interface.FastEthernet.Mvrp.Timer.Leave)), ("leave-all", ("leave_all", Native.Interface.FastEthernet.Mvrp.Timer.LeaveAll))])
                        self._leafs = OrderedDict([
                            ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ])
                        self.periodic = None

                        self.join = None
                        self._children_name_map["join"] = "join"

                        self.leave = None
                        self._children_name_map["leave"] = "leave"

                        self.leave_all = None
                        self._children_name_map["leave_all"] = "leave-all"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Mvrp.Timer, ['periodic'], name, value)


                    class Join(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 20..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Mvrp.Timer.Join, self).__init__()

                            self.yang_name = "join"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "join"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Mvrp.Timer.Join, ['y_range'], name, value)


                    class Leave(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Mvrp.Timer.Leave, self).__init__()

                            self.yang_name = "leave"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Mvrp.Timer.Leave, ['y_range'], name, value)


                    class LeaveAll(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1000..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Mvrp.Timer.LeaveAll, self).__init__()

                            self.yang_name = "leave-all"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave-all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Mvrp.Timer.LeaveAll, ['y_range'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.FastEthernet.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.FastEthernet.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.FastEthernet.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.FastEthernet.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.FastEthernet.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.FastEthernet.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.FastEthernet.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.FastEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Power(Entity):
                """
                
                
                .. attribute:: inline
                
                	
                	**type**\:  :py:class:`Inline <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Power.Inline>`
                
                

                """

                _prefix = 'ios-power'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Power, self).__init__()

                    self.yang_name = "power"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("inline", ("inline", Native.Interface.FastEthernet.Power.Inline))])
                    self._leafs = OrderedDict()

                    self.inline = Native.Interface.FastEthernet.Power.Inline()
                    self.inline.parent = self
                    self._children_name_map["inline"] = "inline"
                    self._segment_path = lambda: "Cisco-IOS-XE-power:power"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Power, [], name, value)


                class Inline(Entity):
                    """
                    
                    
                    .. attribute:: consumption
                    
                    	
                    	**type**\: int
                    
                    	**range:** 4000..15400
                    
                    .. attribute:: never
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: auto
                    
                    	Automatically detect and power inline devices
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Power.Inline.Auto>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: four_pair
                    
                    	Four\-pair PoE power
                    	**type**\:  :py:class:`FourPair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Power.Inline.FourPair>`
                    
                    .. attribute:: police
                    
                    	Police the power drawn on the port
                    	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Power.Inline.Police>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: port
                    
                    	Configure Port Power Level
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Power.Inline.Port>`
                    
                    .. attribute:: static
                    
                    	High priority inline power interface
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Power.Inline.Static>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-power'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Power.Inline, self).__init__()

                        self.yang_name = "inline"
                        self.yang_parent_name = "power"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.FastEthernet.Power.Inline.Auto)), ("four-pair", ("four_pair", Native.Interface.FastEthernet.Power.Inline.FourPair)), ("police", ("police", Native.Interface.FastEthernet.Power.Inline.Police)), ("port", ("port", Native.Interface.FastEthernet.Power.Inline.Port)), ("static", ("static", Native.Interface.FastEthernet.Power.Inline.Static))])
                        self._leafs = OrderedDict([
                            ('consumption', (YLeaf(YType.uint16, 'consumption'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.consumption = None
                        self.never = None

                        self.auto = None
                        self._children_name_map["auto"] = "auto"

                        self.four_pair = Native.Interface.FastEthernet.Power.Inline.FourPair()
                        self.four_pair.parent = self
                        self._children_name_map["four_pair"] = "four-pair"

                        self.police = None
                        self._children_name_map["police"] = "police"

                        self.port = Native.Interface.FastEthernet.Power.Inline.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.static = None
                        self._children_name_map["static"] = "static"
                        self._segment_path = lambda: "inline"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Power.Inline, ['consumption', 'never'], name, value)


                    class Auto(Entity):
                        """
                        Automatically detect and power inline devices
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Power.Inline.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "auto"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Power.Inline.Auto, ['max'], name, value)


                    class FourPair(Entity):
                        """
                        Four\-pair PoE power
                        
                        .. attribute:: forced
                        
                        	Enable Four\-pair PoE without L2 negotiation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Power.Inline.FourPair, self).__init__()

                            self.yang_name = "four-pair"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forced', (YLeaf(YType.empty, 'forced'), ['Empty'])),
                            ])
                            self.forced = None
                            self._segment_path = lambda: "four-pair"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Power.Inline.FourPair, ['forced'], name, value)


                    class Police(Entity):
                        """
                        Police the power drawn on the port
                        
                        .. attribute:: action
                        
                        	Action to be taken when power is overdrawn on the port
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Power.Inline.Police.Action>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Power.Inline.Police, self).__init__()

                            self.yang_name = "police"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.FastEthernet.Power.Inline.Police.Action))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.FastEthernet.Power.Inline.Police.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "police"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Power.Inline.Police, [], name, value)


                        class Action(Entity):
                            """
                            Action to be taken when power is overdrawn on the port
                            
                            .. attribute:: errdisable
                            
                            	Error\-disable the port when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log a message when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-power'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Power.Inline.Police.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "police"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('errdisable', (YLeaf(YType.empty, 'errdisable'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ])
                                self.errdisable = None
                                self.log = None
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Power.Inline.Police.Action, ['errdisable', 'log'], name, value)


                    class Port(Entity):
                        """
                        Configure Port Power Level
                        
                        .. attribute:: poe_ha
                        
                        	Apply poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: perpetual_poe_ha
                        
                        	Apply perpetual\-poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: two_event
                        
                        	Enable 2\-event classification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Power.Inline.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('poe_ha', (YLeaf(YType.empty, 'poe-ha'), ['Empty'])),
                                ('perpetual_poe_ha', (YLeaf(YType.empty, 'perpetual-poe-ha'), ['Empty'])),
                                ('two_event', (YLeaf(YType.empty, 'two-event'), ['Empty'])),
                            ])
                            self.poe_ha = None
                            self.perpetual_poe_ha = None
                            self.two_event = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Power.Inline.Port, ['poe_ha', 'perpetual_poe_ha', 'two_event'], name, value)


                    class Static(Entity):
                        """
                        High priority inline power interface
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Power.Inline.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "static"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Power.Inline.Static, ['max'], name, value)


            class Cdp(Entity):
                """
                CDP interface subcommands
                
                .. attribute:: enable
                
                	Enable CDP on interface
                	**type**\: bool
                
                .. attribute:: tlv
                
                	Enable exchange of specific tlv information
                	**type**\:  :py:class:`Tlv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cdp.Tlv>`
                
                

                """

                _prefix = 'ios-cdp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Cdp, self).__init__()

                    self.yang_name = "cdp"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tlv", ("tlv", Native.Interface.FastEthernet.Cdp.Tlv))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                    ])
                    self.enable = None

                    self.tlv = Native.Interface.FastEthernet.Cdp.Tlv()
                    self.tlv.parent = self
                    self._children_name_map["tlv"] = "tlv"
                    self._segment_path = lambda: "Cisco-IOS-XE-cdp:cdp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Cdp, ['enable'], name, value)


                class Tlv(Entity):
                    """
                    Enable exchange of specific tlv information
                    
                    .. attribute:: app
                    
                    	Enable/Configure Application TLV
                    	**type**\:  :py:class:`App <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cdp.Tlv.App>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: server_location
                    
                    	Enable CDP location server on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	Exchange location information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cdp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Cdp.Tlv, self).__init__()

                        self.yang_name = "tlv"
                        self.yang_parent_name = "cdp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("app", ("app", Native.Interface.FastEthernet.Cdp.Tlv.App))])
                        self._leafs = OrderedDict([
                            ('server_location', (YLeaf(YType.empty, 'server-location'), ['Empty'])),
                            ('location', (YLeaf(YType.empty, 'location'), ['Empty'])),
                        ])
                        self.server_location = None
                        self.location = None

                        self.app = None
                        self._children_name_map["app"] = "app"
                        self._segment_path = lambda: "tlv"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Cdp.Tlv, ['server_location', 'location'], name, value)


                    class App(Entity):
                        """
                        Enable/Configure Application TLV
                        
                        .. attribute:: tlvtype
                        
                        	Configure APP TLV
                        	**type**\: int
                        
                        	**range:** 1001..65535
                        
                        .. attribute:: value
                        
                        	Configure App TLV Value information
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cdp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Cdp.Tlv.App, self).__init__()

                            self.yang_name = "app"
                            self.yang_parent_name = "tlv"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tlvtype', (YLeaf(YType.uint16, 'tlvtype'), ['int'])),
                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                            ])
                            self.tlvtype = None
                            self.value = None
                            self._segment_path = lambda: "app"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Cdp.Tlv.App, ['tlvtype', 'value'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.FastEthernet.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.FastEthernet.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.FastEthernet.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.FastEthernet.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class Authentication(Entity):
                """
                Auth Manager Interface Configuration Commands
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.ControlDirection>`
                
                .. attribute:: event
                
                	Set action for authentication events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event>`
                
                .. attribute:: fallback
                
                	Enable the Webauth fallback mechanism
                	**type**\: str
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.HostMode>`
                
                .. attribute:: open
                
                	Enable or Disable open access on this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: order
                
                	Add an authentication method to the order list
                	**type**\:  :py:class:`Order <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Order>`
                
                .. attribute:: priority
                
                	Add an authentication method to the priority list
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Priority>`
                
                .. attribute:: port_control
                
                	set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.PortControl>`
                
                .. attribute:: periodic
                
                	Enable or Disable Reauthentication for this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timer
                
                	Set authentication timer values
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Timer>`
                
                .. attribute:: violation
                
                	Configure action to take on security violations
                	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Violation>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FastEthernet.Authentication.Event)), ("order", ("order", Native.Interface.FastEthernet.Authentication.Order)), ("priority", ("priority", Native.Interface.FastEthernet.Authentication.Priority)), ("timer", ("timer", Native.Interface.FastEthernet.Authentication.Timer))])
                    self._leafs = OrderedDict([
                        ('control_direction', (YLeaf(YType.enumeration, 'control-direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Authentication.ControlDirection')])),
                        ('fallback', (YLeaf(YType.str, 'fallback'), ['str'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Authentication.HostMode')])),
                        ('open', (YLeaf(YType.empty, 'open'), ['Empty'])),
                        ('port_control', (YLeaf(YType.enumeration, 'port-control'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Authentication.PortControl')])),
                        ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Authentication.Violation')])),
                    ])
                    self.control_direction = None
                    self.fallback = None
                    self.host_mode = None
                    self.open = None
                    self.port_control = None
                    self.periodic = None
                    self.violation = None

                    self.event = Native.Interface.FastEthernet.Authentication.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.order = Native.Interface.FastEthernet.Authentication.Order()
                    self.order.parent = self
                    self._children_name_map["order"] = "order"

                    self.priority = Native.Interface.FastEthernet.Authentication.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "priority"

                    self.timer = Native.Interface.FastEthernet.Authentication.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:authentication"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Authentication, ['control_direction', 'fallback', 'host_mode', 'open', 'port_control', 'periodic', 'violation'], name, value)

                class ControlDirection(Enum):
                    """
                    ControlDirection (Enum Class)

                    Set the control\-direction on the interface

                    .. data:: both = 0

                    .. data:: in_ = 1

                    """

                    both = Enum.YLeaf(0, "both")

                    in_ = Enum.YLeaf(1, "in")


                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")


                class PortControl(Enum):
                    """
                    PortControl (Enum Class)

                    set the port\-control value

                    .. data:: auto = 0

                    .. data:: force_authorized = 1

                    .. data:: force_unauthorized = 2

                    """

                    auto = Enum.YLeaf(0, "auto")

                    force_authorized = Enum.YLeaf(1, "force-authorized")

                    force_unauthorized = Enum.YLeaf(2, "force-unauthorized")


                class Violation(Enum):
                    """
                    Violation (Enum Class)

                    Configure action to take on security violations

                    .. data:: protect = 0

                    .. data:: replace = 1

                    .. data:: restrict = 2

                    .. data:: shutdown = 3

                    """

                    protect = Enum.YLeaf(0, "protect")

                    replace = Enum.YLeaf(1, "replace")

                    restrict = Enum.YLeaf(2, "restrict")

                    shutdown = Enum.YLeaf(3, "shutdown")



                class Event(Entity):
                    """
                    Set action for authentication events
                    
                    .. attribute:: server
                    
                    	Configure actions for AAA server events
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.Server>`
                    
                    .. attribute:: fail
                    
                    	Configure actions for AAA fail events
                    	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.Fail>`
                    
                    .. attribute:: no_response
                    
                    	Configure actions for AAA no\-response events
                    	**type**\:  :py:class:`NoResponse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.NoResponse>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Authentication.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("server", ("server", Native.Interface.FastEthernet.Authentication.Event.Server)), ("fail", ("fail", Native.Interface.FastEthernet.Authentication.Event.Fail)), ("no-response", ("no_response", Native.Interface.FastEthernet.Authentication.Event.NoResponse))])
                        self._leafs = OrderedDict()

                        self.server = Native.Interface.FastEthernet.Authentication.Event.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.fail = Native.Interface.FastEthernet.Authentication.Event.Fail()
                        self.fail.parent = self
                        self._children_name_map["fail"] = "fail"

                        self.no_response = Native.Interface.FastEthernet.Authentication.Event.NoResponse()
                        self.no_response.parent = self
                        self._children_name_map["no_response"] = "no-response"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event, [], name, value)


                    class Server(Entity):
                        """
                        Configure actions for AAA server events
                        
                        .. attribute:: alive
                        
                        	Configure AAA server alive action
                        	**type**\:  :py:class:`Alive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.Server.Alive>`
                        
                        .. attribute:: dead
                        
                        	Configure AAA server dead action
                        	**type**\:  :py:class:`Dead <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.Server.Dead>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Authentication.Event.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("alive", ("alive", Native.Interface.FastEthernet.Authentication.Event.Server.Alive)), ("dead", ("dead", Native.Interface.FastEthernet.Authentication.Event.Server.Dead))])
                            self._leafs = OrderedDict()

                            self.alive = Native.Interface.FastEthernet.Authentication.Event.Server.Alive()
                            self.alive.parent = self
                            self._children_name_map["alive"] = "alive"

                            self.dead = Native.Interface.FastEthernet.Authentication.Event.Server.Dead()
                            self.dead.parent = self
                            self._children_name_map["dead"] = "dead"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.Server, [], name, value)


                        class Alive(Entity):
                            """
                            Configure AAA server alive action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.Server.Alive.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Authentication.Event.Server.Alive, self).__init__()

                                self.yang_name = "alive"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FastEthernet.Authentication.Event.Server.Alive.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FastEthernet.Authentication.Event.Server.Alive.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "alive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.Server.Alive, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all authorized clients
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Authentication.Event.Server.Alive.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "alive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reinitialize', (YLeaf(YType.empty, 'reinitialize'), ['Empty'])),
                                    ])
                                    self.reinitialize = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.Server.Alive.Action, ['reinitialize'], name, value)


                        class Dead(Entity):
                            """
                            Configure AAA server dead action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Authentication.Event.Server.Dead, self).__init__()

                                self.yang_name = "dead"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dead"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.Server.Dead, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: authorize
                                
                                	Authorize the port
                                	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action.Authorize>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all client on the port
                                	**type**\:  :py:class:`Reinitialize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action.Reinitialize>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dead"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action.Authorize)), ("reinitialize", ("reinitialize", Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action.Reinitialize))])
                                    self._leafs = OrderedDict()

                                    self.authorize = None
                                    self._children_name_map["authorize"] = "authorize"

                                    self.reinitialize = Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action.Reinitialize()
                                    self.reinitialize.parent = self
                                    self._children_name_map["reinitialize"] = "reinitialize"
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action, [], name, value)


                                class Authorize(Entity):
                                    """
                                    Authorize the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: voice
                                    
                                    	Authorize the port for VOICE traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action.Authorize, self).__init__()

                                        self.yang_name = "authorize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ('voice', (YLeaf(YType.empty, 'voice'), ['Empty'])),
                                        ])
                                        self.vlan = None
                                        self.voice = None
                                        self._segment_path = lambda: "authorize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action.Authorize, ['vlan', 'voice'], name, value)


                                class Reinitialize(Entity):
                                    """
                                    Reinitialize all client on the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, self).__init__()

                                        self.yang_name = "reinitialize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "reinitialize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, ['vlan'], name, value)


                    class Fail(Entity):
                        """
                        Configure actions for AAA fail events
                        
                        .. attribute:: action
                        
                        	Required action for fail event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.Fail.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Authentication.Event.Fail, self).__init__()

                            self.yang_name = "fail"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.FastEthernet.Authentication.Event.Fail.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.FastEthernet.Authentication.Event.Fail.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "fail"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.Fail, [], name, value)


                        class Action(Entity):
                            """
                            Required action for fail event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.Fail.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Authentication.Event.Fail.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "fail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.FastEthernet.Authentication.Event.Fail.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.FastEthernet.Authentication.Event.Fail.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.Fail.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Authentication.Event.Fail.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.Fail.Action.Authorize, ['vlan'], name, value)


                    class NoResponse(Entity):
                        """
                        Configure actions for AAA no\-response events
                        
                        .. attribute:: action
                        
                        	Required action for no\-response event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.NoResponse.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Authentication.Event.NoResponse, self).__init__()

                            self.yang_name = "no-response"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.FastEthernet.Authentication.Event.NoResponse.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.FastEthernet.Authentication.Event.NoResponse.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "no-response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.NoResponse, [], name, value)


                        class Action(Entity):
                            """
                            Required action for no\-response event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Event.NoResponse.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Authentication.Event.NoResponse.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "no-response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.FastEthernet.Authentication.Event.NoResponse.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.FastEthernet.Authentication.Event.NoResponse.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.NoResponse.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Authentication.Event.NoResponse.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Authentication.Event.NoResponse.Action.Authorize, ['vlan'], name, value)


                class Order(Entity):
                    """
                    Add an authentication method to the order list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Authentication.Order, self).__init__()

                        self.yang_name = "order"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "order"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Authentication.Order, ['dot1x', 'mab', 'webauth'], name, value)


                class Priority(Entity):
                    """
                    Add an authentication method to the priority list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Authentication.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Authentication.Priority, ['dot1x', 'mab', 'webauth'], name, value)


                class Timer(Entity):
                    """
                    Set authentication timer values
                    
                    .. attribute:: reauthenticate
                    
                    	Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                    	**type**\:  :py:class:`Reauthenticate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Timer.Reauthenticate>`
                    
                    .. attribute:: inactivity
                    
                    	Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                    	**type**\:  :py:class:`Inactivity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Timer.Inactivity>`
                    
                    .. attribute:: restart
                    
                    	Interval in seconds after which an attempt should be made toauthenticate an unauthorized port (default 60 sec)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Authentication.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reauthenticate", ("reauthenticate", Native.Interface.FastEthernet.Authentication.Timer.Reauthenticate)), ("inactivity", ("inactivity", Native.Interface.FastEthernet.Authentication.Timer.Inactivity))])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                        ])
                        self.restart = None

                        self.reauthenticate = Native.Interface.FastEthernet.Authentication.Timer.Reauthenticate()
                        self.reauthenticate.parent = self
                        self._children_name_map["reauthenticate"] = "reauthenticate"

                        self.inactivity = Native.Interface.FastEthernet.Authentication.Timer.Inactivity()
                        self.inactivity.parent = self
                        self._children_name_map["inactivity"] = "inactivity"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Authentication.Timer, ['restart'], name, value)


                    class Reauthenticate(Entity):
                        """
                        Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: server
                        
                        	Obtain re\-authentication timeout value from the server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Authentication.Timer.Reauthenticate, self).__init__()

                            self.yang_name = "reauthenticate"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                            ])
                            self.value = None
                            self.server = None
                            self._segment_path = lambda: "reauthenticate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Authentication.Timer.Reauthenticate, ['value', 'server'], name, value)


                    class Inactivity(Entity):
                        """
                        Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Timer.Inactivity.Value>`
                        
                        .. attribute:: server
                        
                        	Obtain inactivity timeout value from the server
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Authentication.Timer.Inactivity.Server>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Authentication.Timer.Inactivity, self).__init__()

                            self.yang_name = "inactivity"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.FastEthernet.Authentication.Timer.Inactivity.Value)), ("server", ("server", Native.Interface.FastEthernet.Authentication.Timer.Inactivity.Server))])
                            self._leafs = OrderedDict()

                            self.value = Native.Interface.FastEthernet.Authentication.Timer.Inactivity.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.server = None
                            self._children_name_map["server"] = "server"
                            self._segment_path = lambda: "inactivity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Authentication.Timer.Inactivity, [], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Authentication.Timer.Inactivity.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.value = None
                                self.dynamic = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Authentication.Timer.Inactivity.Value, ['value', 'dynamic'], name, value)


                        class Server(Entity):
                            """
                            Obtain inactivity timeout value from the server
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Authentication.Timer.Inactivity.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.dynamic = None
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Authentication.Timer.Inactivity.Server, ['dynamic'], name, value)


            class Mab(Entity):
                """
                
                
                .. attribute:: eap
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Mab, self).__init__()

                    self.yang_name = "mab"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                    ])
                    self.eap = None
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:mab"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Mab, ['eap'], name, value)


            class Dot1x(Entity):
                """
                Interface Config Commands for IEEE 802.1X
                
                .. attribute:: authenticator
                
                	Configure authenticator parameters
                	**type**\:  :py:class:`Authenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Dot1x.Authenticator>`
                
                .. attribute:: credentials
                
                	Credentials profile configuration
                	**type**\: str
                
                .. attribute:: max_reauth_req
                
                	Max No. of Reauthentication Attempts
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_req
                
                	Max No. of Retries
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_start
                
                	Max No. of EAPOL\-Start requests
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: pae
                
                	Set 802.1x interface pae type
                	**type**\:  :py:class:`Pae <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Dot1x.Pae>`
                
                .. attribute:: supplicant
                
                	Configure supplicant parameters
                	**type**\:  :py:class:`Supplicant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Dot1x.Supplicant>`
                
                .. attribute:: timeout
                
                	Various Timeouts
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Dot1x.Timeout>`
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Dot1x, self).__init__()

                    self.yang_name = "dot1x"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authenticator", ("authenticator", Native.Interface.FastEthernet.Dot1x.Authenticator)), ("supplicant", ("supplicant", Native.Interface.FastEthernet.Dot1x.Supplicant)), ("timeout", ("timeout", Native.Interface.FastEthernet.Dot1x.Timeout))])
                    self._leafs = OrderedDict([
                        ('credentials', (YLeaf(YType.str, 'credentials'), ['str'])),
                        ('max_reauth_req', (YLeaf(YType.uint8, 'max-reauth-req'), ['int'])),
                        ('max_req', (YLeaf(YType.uint8, 'max-req'), ['int'])),
                        ('max_start', (YLeaf(YType.uint8, 'max-start'), ['int'])),
                        ('pae', (YLeaf(YType.enumeration, 'pae'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Dot1x.Pae')])),
                    ])
                    self.credentials = None
                    self.max_reauth_req = None
                    self.max_req = None
                    self.max_start = None
                    self.pae = None

                    self.authenticator = Native.Interface.FastEthernet.Dot1x.Authenticator()
                    self.authenticator.parent = self
                    self._children_name_map["authenticator"] = "authenticator"

                    self.supplicant = Native.Interface.FastEthernet.Dot1x.Supplicant()
                    self.supplicant.parent = self
                    self._children_name_map["supplicant"] = "supplicant"

                    self.timeout = Native.Interface.FastEthernet.Dot1x.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"
                    self._segment_path = lambda: "Cisco-IOS-XE-dot1x:dot1x"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Dot1x, ['credentials', 'max_reauth_req', 'max_req', 'max_start', 'pae'], name, value)

                class Pae(Enum):
                    """
                    Pae (Enum Class)

                    Set 802.1x interface pae type

                    .. data:: authenticator = 0

                    .. data:: supplicant = 1

                    .. data:: both = 2

                    """

                    authenticator = Enum.YLeaf(0, "authenticator")

                    supplicant = Enum.YLeaf(1, "supplicant")

                    both = Enum.YLeaf(2, "both")



                class Authenticator(Entity):
                    """
                    Configure authenticator parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP authenticator parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Dot1x.Authenticator.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Dot1x.Authenticator, self).__init__()

                        self.yang_name = "authenticator"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.FastEthernet.Dot1x.Authenticator.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.FastEthernet.Dot1x.Authenticator.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "authenticator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Dot1x.Authenticator, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP authenticator parameters
                        
                        .. attribute:: profile
                        
                        	EAP authenticator profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Dot1x.Authenticator.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "authenticator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Dot1x.Authenticator.Eap, ['profile'], name, value)


                class Supplicant(Entity):
                    """
                    Configure supplicant parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP supplicant parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Dot1x.Supplicant.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Dot1x.Supplicant, self).__init__()

                        self.yang_name = "supplicant"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.FastEthernet.Dot1x.Supplicant.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.FastEthernet.Dot1x.Supplicant.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "supplicant"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Dot1x.Supplicant, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP supplicant parameters
                        
                        .. attribute:: profile
                        
                        	EAP supplicant profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Dot1x.Supplicant.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "supplicant"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Dot1x.Supplicant.Eap, ['profile'], name, value)


                class Timeout(Entity):
                    """
                    Various Timeouts
                    
                    .. attribute:: auth_period
                    
                    	Timeout for authenticator reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: held_period
                    
                    	Timeout for authentication retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: quiet_period
                    
                    	QuietPeriod in Seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ratelimit_period
                    
                    	Ratelimit Period in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: server_timeout
                    
                    	Timeout for Radius Retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: start_period
                    
                    	Timeout for EAPOL\-start retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: supp_timeout
                    
                    	Timeout for supplicant reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: tx_period
                    
                    	Timeout for supplicant retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Dot1x.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auth_period', (YLeaf(YType.uint16, 'auth-period'), ['int'])),
                            ('held_period', (YLeaf(YType.uint16, 'held-period'), ['int'])),
                            ('quiet_period', (YLeaf(YType.uint16, 'quiet-period'), ['int'])),
                            ('ratelimit_period', (YLeaf(YType.uint16, 'ratelimit-period'), ['int'])),
                            ('server_timeout', (YLeaf(YType.uint16, 'server-timeout'), ['int'])),
                            ('start_period', (YLeaf(YType.uint16, 'start-period'), ['int'])),
                            ('supp_timeout', (YLeaf(YType.uint16, 'supp-timeout'), ['int'])),
                            ('tx_period', (YLeaf(YType.uint16, 'tx-period'), ['int'])),
                        ])
                        self.auth_period = None
                        self.held_period = None
                        self.quiet_period = None
                        self.ratelimit_period = None
                        self.server_timeout = None
                        self.start_period = None
                        self.supp_timeout = None
                        self.tx_period = None
                        self._segment_path = lambda: "timeout"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Dot1x.Timeout, ['auth_period', 'held_period', 'quiet_period', 'ratelimit_period', 'server_timeout', 'start_period', 'supp_timeout', 'tx_period'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpdufilter
                
                	Don't send or receive BPDUs on this interface
                	**type**\:  :py:class:`Bpdufilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SpanningTree.Bpdufilter>`
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SpanningTree.Bpduguard>`
                
                .. attribute:: cost
                
                	To set the path cost of the interface
                	**type**\: int
                
                	**range:** 1..200000000
                
                .. attribute:: guard
                
                	Change an interface's spanning tree guard mode
                	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SpanningTree.Guard>`
                
                .. attribute:: link_type
                
                	Specify a link type for spanning tree tree protocol use
                	**type**\:  :py:class:`LinkType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SpanningTree.LinkType>`
                
                .. attribute:: portfast
                
                	Spanning tree portfast options
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                .. attribute:: port_priority
                
                	Spanning tree port\-priority options
                	**type**\: int
                
                	**range:** 0..240
                
                .. attribute:: vlan
                
                	VLAN Switch Spanning Tree
                	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SpanningTree.Vlan>`
                
                .. attribute:: loopguard
                
                	Spanning tree loopguard options
                	**type**\:  :py:class:`Loopguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SpanningTree.Loopguard>`
                
                .. attribute:: mst
                
                	Per interface MST configurations
                	**type**\:  :py:class:`Mst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SpanningTree.Mst>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Interface.FastEthernet.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Interface.FastEthernet.SpanningTree.Portfast)), ("vlan", ("vlan", Native.Interface.FastEthernet.SpanningTree.Vlan)), ("loopguard", ("loopguard", Native.Interface.FastEthernet.SpanningTree.Loopguard)), ("mst", ("mst", Native.Interface.FastEthernet.SpanningTree.Mst))])
                    self._leafs = OrderedDict([
                        ('bpdufilter', (YLeaf(YType.enumeration, 'bpdufilter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.SpanningTree.Bpdufilter')])),
                        ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ('guard', (YLeaf(YType.enumeration, 'guard'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.SpanningTree.Guard')])),
                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.SpanningTree.LinkType')])),
                        ('port_priority', (YLeaf(YType.uint8, 'port-priority'), ['int'])),
                    ])
                    self.bpdufilter = None
                    self.cost = None
                    self.guard = None
                    self.link_type = None
                    self.port_priority = None

                    self.bpduguard = Native.Interface.FastEthernet.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"

                    self.loopguard = Native.Interface.FastEthernet.SpanningTree.Loopguard()
                    self.loopguard.parent = self
                    self._children_name_map["loopguard"] = "loopguard"

                    self.mst = Native.Interface.FastEthernet.SpanningTree.Mst()
                    self.mst.parent = self
                    self._children_name_map["mst"] = "mst"

                    self.vlan = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:spanning-tree"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.SpanningTree, ['bpdufilter', 'cost', 'guard', 'link_type', 'port_priority'], name, value)

                class Bpdufilter(Enum):
                    """
                    Bpdufilter (Enum Class)

                    Don't send or receive BPDUs on this interface

                    .. data:: disable = 0

                    .. data:: enable = 1

                    """

                    disable = Enum.YLeaf(0, "disable")

                    enable = Enum.YLeaf(1, "enable")


                class Guard(Enum):
                    """
                    Guard (Enum Class)

                    Change an interface's spanning tree guard mode

                    .. data:: loop = 0

                    .. data:: none = 1

                    .. data:: root = 2

                    """

                    loop = Enum.YLeaf(0, "loop")

                    none = Enum.YLeaf(1, "none")

                    root = Enum.YLeaf(2, "root")


                class LinkType(Enum):
                    """
                    LinkType (Enum Class)

                    Specify a link type for spanning tree tree protocol use

                    .. data:: point_to_point = 0

                    .. data:: shared = 1

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")

                    shared = Enum.YLeaf(1, "shared")



                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.disable = None
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.SpanningTree.Bpduguard, ['disable', 'enable'], name, value)


                class Portfast(Entity):
                    """
                    Spanning tree portfast options
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk
                    
                    	Enable portfast on the interface even in trunk mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                        ])
                        self.disable = None
                        self.trunk = None
                        self.edge = None
                        self._segment_path = lambda: "portfast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.SpanningTree.Portfast, ['disable', 'trunk', 'edge'], name, value)


                class Vlan(Entity):
                    """
                    VLAN Switch Spanning Tree
                    
                    .. attribute:: vlan_ids  (key)
                    
                    	vlan range, example\: 1,3\-5,7,9\-11
                    	**type**\: str
                    
                    .. attribute:: cost
                    
                    	<1\-200000000> Spanning\-tree cost
                    	**type**\: int
                    
                    	**range:** 1..200000000
                    
                    .. attribute:: port_priority
                    
                    	<0\-240> port priority in increments of 16
                    	**type**\: int
                    
                    	**range:** 0..240
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.SpanningTree.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vlan_ids']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_ids', (YLeaf(YType.str, 'vlan-ids'), ['str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                        ])
                        self.vlan_ids = None
                        self.cost = None
                        self.port_priority = None
                        self._segment_path = lambda: "vlan" + "[vlan-ids='" + str(self.vlan_ids) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.SpanningTree.Vlan, ['vlan_ids', 'cost', 'port_priority'], name, value)


                class Loopguard(Entity):
                    """
                    Spanning tree loopguard options
                    
                    .. attribute:: default
                    
                    	Enable loopguard by default on all ports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.SpanningTree.Loopguard, self).__init__()

                        self.yang_name = "loopguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.default = None
                        self._segment_path = lambda: "loopguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.SpanningTree.Loopguard, ['default'], name, value)


                class Mst(Entity):
                    """
                    Per interface MST configurations
                    
                    .. attribute:: mst_instance
                    
                    	
                    	**type**\: list of  		 :py:class:`MstInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.SpanningTree.Mst.MstInstance>`
                    
                    .. attribute:: pre_standard
                    
                    	Force pre\-standard MST BPDU transmission on port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.SpanningTree.Mst, self).__init__()

                        self.yang_name = "mst"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mst-instance", ("mst_instance", Native.Interface.FastEthernet.SpanningTree.Mst.MstInstance))])
                        self._leafs = OrderedDict([
                            ('pre_standard', (YLeaf(YType.empty, 'pre-standard'), ['Empty'])),
                        ])
                        self.pre_standard = None

                        self.mst_instance = YList(self)
                        self._segment_path = lambda: "mst"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.SpanningTree.Mst, ['pre_standard'], name, value)


                    class MstInstance(Entity):
                        """
                        
                        
                        .. attribute:: instance  (key)
                        
                        	MST instance list, example 0,2\-4,6,8\-12
                        	**type**\: str
                        
                        .. attribute:: cost
                        
                        	<1\-200000000> Spanning\-tree cost
                        	**type**\: int
                        
                        	**range:** 1..200000000
                        
                        .. attribute:: port_priority
                        
                        	<0\-240> port priority in increments of 16
                        	**type**\: int
                        
                        	**range:** 0..240
                        
                        

                        """

                        _prefix = 'ios-stp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.SpanningTree.Mst.MstInstance, self).__init__()

                            self.yang_name = "mst-instance"
                            self.yang_parent_name = "mst"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                            ])
                            self.instance = None
                            self.cost = None
                            self.port_priority = None
                            self._segment_path = lambda: "mst-instance" + "[instance='" + str(self.instance) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.SpanningTree.Mst.MstInstance, ['instance', 'cost', 'port_priority'], name, value)


            class Performance(Entity):
                """
                Global performance monitor configuration
                
                .. attribute:: monitor
                
                	monitor
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Performance.Monitor>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Performance, self).__init__()

                    self.yang_name = "performance"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FastEthernet.Performance.Monitor))])
                    self._leafs = OrderedDict()

                    self.monitor = Native.Interface.FastEthernet.Performance.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"
                    self._segment_path = lambda: "Cisco-IOS-XE-ezpm:performance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Performance, [], name, value)


                class Monitor(Entity):
                    """
                    monitor
                    
                    .. attribute:: context
                    
                    	Select ezPM context
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Performance.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "performance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('context', (YLeafList(YType.str, 'context'), ['str'])),
                        ])
                        self.context = []
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Performance.Monitor, ['context'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Umbrella, ['out', 'in_'], name, value)


            class Lldp(Entity):
                """
                LLDP interface subcommands
                
                .. attribute:: receive
                
                	Enable LLDP reception on interface
                	**type**\: bool
                
                .. attribute:: transmit
                
                	Enable LLDP transmission on interface
                	**type**\: bool
                
                

                """

                _prefix = 'ios-lldp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Lldp, self).__init__()

                    self.yang_name = "lldp"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                        ('transmit', (YLeaf(YType.boolean, 'transmit'), ['bool'])),
                    ])
                    self.receive = None
                    self.transmit = None
                    self._segment_path = lambda: "Cisco-IOS-XE-lldp:lldp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Lldp, ['receive', 'transmit'], name, value)


            class Vrrp(Entity):
                """
                Configure VRRP
                
                .. attribute:: vrrp_group
                
                	
                	**type**\: list of  		 :py:class:`VrrpGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup>`
                
                .. attribute:: vrrp_group_v2
                
                	vrrp version 2
                	**type**\: list of  		 :py:class:`VrrpGroupV2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroupV2>`
                
                .. attribute:: delay
                
                	
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.Delay>`
                
                

                """

                _prefix = 'ios-vrrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Vrrp, self).__init__()

                    self.yang_name = "vrrp"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrrp-group", ("vrrp_group", Native.Interface.FastEthernet.Vrrp.VrrpGroup)), ("vrrp-group-v2", ("vrrp_group_v2", Native.Interface.FastEthernet.Vrrp.VrrpGroupV2)), ("delay", ("delay", Native.Interface.FastEthernet.Vrrp.Delay))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.FastEthernet.Vrrp.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.vrrp_group = YList(self)
                    self.vrrp_group_v2 = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vrrp:vrrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Vrrp, [], name, value)


                class VrrpGroup(Entity):
                    """
                    
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: address_family
                    
                    	Address family of the group
                    	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Vrrp.VrrpGroup, self).__init__()

                        self.yang_name = "vrrp-group"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("address-family", ("address_family", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                        ])
                        self.group_id = None

                        self.address_family = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"
                        self._segment_path = lambda: "vrrp-group" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup, ['group_id'], name, value)


                    class AddressFamily(Entity):
                        """
                        Address family of the group
                        
                        .. attribute:: ipv4
                        
                        	IPv4 Address family
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	IPv6 Address family
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily, self).__init__()

                            self.yang_name = "address-family"
                            self.yang_parent_name = "vrrp-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4)), ("ipv6", ("ipv6", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = None
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "address-family"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily, [], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 Address family
                            
                            .. attribute:: vrrpv2
                            
                            	Set VRRPv2 compatibility mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: address
                            
                            	Set the IPv4 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address)), ("preempt", ("preempt", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt)), ("timers", ("timers", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers)), ("track", ("track", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track)), ("vrrs", ("vrrs", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('vrrpv2', (YLeaf(YType.empty, 'vrrpv2'), ['Empty'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.vrrpv2 = None
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4, ['vrrpv2', 'description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv4 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary>`
                                
                                .. attribute:: secondary
                                
                                	
                                	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary)), ("secondary", ("secondary", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.secondary = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv4 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, ['address', 'primary'], name, value)


                                class Secondary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: secondary
                                    
                                    	Make this IPv4 address a secondary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, self).__init__()

                                        self.yang_name = "secondary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.secondary = None
                                        self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, ['address', 'secondary'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, ['leader'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 Address family
                            
                            .. attribute:: address
                            
                            	Set the IPv6 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address)), ("preempt", ("preempt", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt)), ("timers", ("timers", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers)), ("track", ("track", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track)), ("vrrs", ("vrrs", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6, ['description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv6 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary>`
                                
                                .. attribute:: ipv6_prefix
                                
                                	
                                	**type**\: list of  		 :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary)), ("ipv6-prefix", ("ipv6_prefix", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.ipv6_prefix = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipv6_link_local
                                    
                                    	IPv6 link\-local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv6 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_link_local', (YLeaf(YType.str, 'ipv6-link-local'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.ipv6_link_local = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, ['ipv6_link_local', 'primary'], name, value)


                                class Ipv6Prefix(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, self).__init__()

                                        self.yang_name = "ipv6-prefix"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                        ])
                                        self.prefix = None
                                        self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, ['prefix'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, ['leader'], name, value)


                class VrrpGroupV2(Entity):
                    """
                    vrrp version 2
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: authentication
                    
                    	
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Authentication>`
                    
                    .. attribute:: description
                    
                    	Up to 80 characters describing this group
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Ip>`
                    
                    .. attribute:: name
                    
                    	Unique VRRS identifier (max 48 characters)
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: shutdown
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: timers
                    
                    	
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Timers>`
                    
                    .. attribute:: track
                    
                    	
                    	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Track>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2, self).__init__()

                        self.yang_name = "vrrp-group-v2"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Authentication)), ("ip", ("ip", Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Ip)), ("preempt", ("preempt", Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Preempt)), ("timers", ("timers", Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Timers)), ("track", ("track", Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Track))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.group_id = None
                        self.description = None
                        self.name = None
                        self.priority = None
                        self.shutdown = None

                        self.authentication = Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.timers = Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Track()
                        self.track.parent = self
                        self._children_name_map["track"] = "track"
                        self._segment_path = lambda: "vrrp-group-v2" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2, ['group_id', 'description', 'name', 'priority', 'shutdown'], name, value)


                    class Authentication(Entity):
                        """
                        
                        
                        .. attribute:: text
                        
                        	authentication string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.text = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Authentication, ['text'], name, value)


                    class Ip(Entity):
                        """
                        
                        
                        .. attribute:: vrrp_ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`VrrpIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrrp-ipv4", ("vrrp_ipv4", Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4))])
                            self._leafs = OrderedDict()

                            self.vrrp_ipv4 = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Ip, [], name, value)


                        class VrrpIpv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, self).__init__()

                                self.yang_name = "vrrp-ipv4"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.ipv4 = None
                                self.secondary = None
                                self._segment_path = lambda: "vrrp-ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, ['ipv4', 'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        
                        
                        .. attribute:: delay
                        
                        	
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            
                            
                            .. attribute:: minimum
                            
                            	Seconds to delay
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                ])
                                self.minimum = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Preempt.Delay, ['minimum'], name, value)


                    class Timers(Entity):
                        """
                        
                        
                        .. attribute:: advertise
                        
                        	
                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Timers.Advertise>`
                        
                        .. attribute:: learn
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Timers.Advertise))])
                            self._leafs = OrderedDict([
                                ('learn', (YLeaf(YType.empty, 'learn'), ['Empty'])),
                            ])
                            self.learn = None

                            self.advertise = Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Timers.Advertise()
                            self.advertise.parent = self
                            self._children_name_map["advertise"] = "advertise"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Timers, ['learn'], name, value)


                        class Advertise(Entity):
                            """
                            
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Advertisement interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..999
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Timers.Advertise, self).__init__()

                                self.yang_name = "advertise"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint8, 'interval'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.interval = None
                                self.msec = None
                                self._segment_path = lambda: "advertise"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Timers.Advertise, ['interval', 'msec'], name, value)


                    class Track(Entity):
                        """
                        
                        
                        .. attribute:: event
                        
                        	
                        	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Track.Event>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("event", ("event", Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Track.Event))])
                            self._leafs = OrderedDict()

                            self.event = YList(self)
                            self._segment_path = lambda: "track"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Track, [], name, value)


                        class Event(Entity):
                            """
                            
                            
                            .. attribute:: object_id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: decrement
                            
                            	Decrement value
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Track.Event, self).__init__()

                                self.yang_name = "event"
                                self.yang_parent_name = "track"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['object_id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                    ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ])
                                self.object_id = None
                                self.decrement = None
                                self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Vrrp.VrrpGroupV2.Track.Event, ['object_id', 'decrement'], name, value)


                class Delay(Entity):
                    """
                    
                    
                    .. attribute:: reload
                    
                    	Seconds to delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: minimum
                    
                    	Seconds to delay after interface up
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Vrrp.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                        ])
                        self.reload = None
                        self.minimum = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Vrrp.Delay, ['reload', 'minimum'], name, value)


            class Ospfv3(Entity):
                """
                OSPFv3 interface commands
                
                .. attribute:: process_id
                
                	
                	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId>`
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Authentication>`
                
                .. attribute:: bfd
                
                	Enable BFD on this interface
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: cost
                
                	Route cost of this interface
                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Cost>`
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: demand_circuit
                
                	OSPF Demand Circuit
                	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.DemandCircuit>`
                
                	**presence node**\: True
                
                .. attribute:: encryption
                
                	Enable encryption
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption>`
                
                .. attribute:: flood_reduction
                
                	OSPF Flood Reduction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: manet
                
                	Mobile Adhoc Networking options
                	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Manet>`
                
                .. attribute:: mtu_ignore
                
                	Ignores the MTU in DBD packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: multi_area
                
                	Set the OSPF multi\-area ID
                	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.MultiArea>`
                
                .. attribute:: neighbor
                
                	OSPF neighbor
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Neighbor>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Network>`
                
                .. attribute:: prefix_suppression
                
                	OSPF prefix suppression
                	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.PrefixSuppression>`
                
                	**presence node**\: True
                
                .. attribute:: priority
                
                	Router priority
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: retransmit_interval
                
                	Time between retransmitting lost link state advertisements
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Shut down the interface in OSPFv3
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transmit_delay
                
                	Link state transmit delay
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Ospfv3, self).__init__()

                    self.yang_name = "ospfv3"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.FastEthernet.Ospfv3.ProcessId)), ("authentication", ("authentication", Native.Interface.FastEthernet.Ospfv3.Authentication)), ("bfd", ("bfd", Native.Interface.FastEthernet.Ospfv3.Bfd)), ("cost", ("cost", Native.Interface.FastEthernet.Ospfv3.Cost)), ("database-filter", ("database_filter", Native.Interface.FastEthernet.Ospfv3.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FastEthernet.Ospfv3.DemandCircuit)), ("encryption", ("encryption", Native.Interface.FastEthernet.Ospfv3.Encryption)), ("manet", ("manet", Native.Interface.FastEthernet.Ospfv3.Manet)), ("multi-area", ("multi_area", Native.Interface.FastEthernet.Ospfv3.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FastEthernet.Ospfv3.Neighbor)), ("network", ("network", Native.Interface.FastEthernet.Ospfv3.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FastEthernet.Ospfv3.PrefixSuppression))])
                    self._leafs = OrderedDict([
                        ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                        ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                        ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                    ])
                    self.dead_interval = None
                    self.flood_reduction = None
                    self.hello_interval = None
                    self.mtu_ignore = None
                    self.priority = None
                    self.retransmit_interval = None
                    self.shutdown = None
                    self.transmit_delay = None

                    self.authentication = Native.Interface.FastEthernet.Ospfv3.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"

                    self.cost = Native.Interface.FastEthernet.Ospfv3.Cost()
                    self.cost.parent = self
                    self._children_name_map["cost"] = "cost"

                    self.database_filter = Native.Interface.FastEthernet.Ospfv3.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"

                    self.demand_circuit = None
                    self._children_name_map["demand_circuit"] = "demand-circuit"

                    self.encryption = Native.Interface.FastEthernet.Ospfv3.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.manet = Native.Interface.FastEthernet.Ospfv3.Manet()
                    self.manet.parent = self
                    self._children_name_map["manet"] = "manet"

                    self.multi_area = Native.Interface.FastEthernet.Ospfv3.MultiArea()
                    self.multi_area.parent = self
                    self._children_name_map["multi_area"] = "multi-area"

                    self.network = Native.Interface.FastEthernet.Ospfv3.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.prefix_suppression = None
                    self._children_name_map["prefix_suppression"] = "prefix-suppression"

                    self.process_id = YList(self)
                    self.neighbor = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3, ['dead_interval', u'flood_reduction', 'hello_interval', u'mtu_ignore', 'priority', 'retransmit_interval', u'shutdown', 'transmit_delay'], name, value)


                class ProcessId(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: manet
                    
                    	Mobile Adhoc Networking options
                    	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.MultiArea>`
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Network>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipv4
                    
                    	Specify parameters for IPv4
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Specify parameters for IPv6
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.ProcessId, self).__init__()

                        self.yang_name = "process-id"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FastEthernet.Ospfv3.ProcessId.Authentication)), ("bfd", ("bfd", Native.Interface.FastEthernet.Ospfv3.ProcessId.Bfd)), ("cost", ("cost", Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost)), ("database-filter", ("database_filter", Native.Interface.FastEthernet.Ospfv3.ProcessId.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FastEthernet.Ospfv3.ProcessId.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.FastEthernet.Ospfv3.ProcessId.FloodReduction)), ("manet", ("manet", Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FastEthernet.Ospfv3.ProcessId.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.FastEthernet.Ospfv3.ProcessId.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FastEthernet.Ospfv3.ProcessId.Neighbor)), ("network", ("network", Native.Interface.FastEthernet.Ospfv3.ProcessId.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FastEthernet.Ospfv3.ProcessId.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.FastEthernet.Ospfv3.ProcessId.Shutdown)), ("ipv4", ("ipv4", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4)), ("ipv6", ("ipv6", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.id = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.FastEthernet.Ospfv3.ProcessId.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.cost = Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.database_filter = Native.Interface.FastEthernet.Ospfv3.ProcessId.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.manet = Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet()
                        self.manet.parent = self
                        self._children_name_map["manet"] = "manet"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.multi_area = Native.Interface.FastEthernet.Ospfv3.ProcessId.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.network = Native.Interface.FastEthernet.Ospfv3.ProcessId.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.ipv4 = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId, [u'id', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\: str
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.null = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Authentication, [u'key_chain', u'null'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Bfd, ['disable'], name, value)


                    class Cost(Entity):
                        """
                        Route cost of this interface
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dynamic
                        
                        	Specify dynamic cost options
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.dynamic = None
                            self._children_name_map["dynamic"] = "dynamic"
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost, [u'value'], name, value)


                        class Dynamic(Entity):
                            """
                            Specify dynamic cost options
                            
                            .. attribute:: default
                            
                            	Specify default link metric value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: hysteresis
                            
                            	Specify hysteresis value for LSA dampening
                            	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: weight
                            
                            	Specify weight to be placed on individual metrics
                            	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ])
                                self.default = None

                                self.hysteresis = None
                                self._children_name_map["hysteresis"] = "hysteresis"

                                self.weight = Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight()
                                self.weight.parent = self
                                self._children_name_map["weight"] = "weight"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic, [u'default'], name, value)


                            class Hysteresis(Entity):
                                """
                                Specify hysteresis value for LSA dampening
                                
                                .. attribute:: percent
                                
                                	Specify hysteresis percent changed
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold
                                
                                	Specify hysteresis threshold value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, self).__init__()

                                    self.yang_name = "hysteresis"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "hysteresis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                            class Weight(Entity):
                                """
                                Specify weight to be placed on individual metrics
                                
                                .. attribute:: l2_factor
                                
                                	Specify weight to be given to L2\-factor metric
                                	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: latency
                                
                                	Specify weight to be given to latency metric
                                	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: resources
                                
                                	Specify weight to be given to resources metric
                                	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: throughput
                                
                                	Specify weight to be given to throughput metric
                                	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, self).__init__()

                                    self.yang_name = "weight"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput))])
                                    self._leafs = OrderedDict()

                                    self.l2_factor = None
                                    self._children_name_map["l2_factor"] = "L2-factor"

                                    self.latency = None
                                    self._children_name_map["latency"] = "latency"

                                    self.resources = None
                                    self._children_name_map["resources"] = "resources"

                                    self.throughput = None
                                    self._children_name_map["throughput"] = "throughput"
                                    self._segment_path = lambda: "weight"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, [], name, value)


                                class L2Factor(Entity):
                                    """
                                    Specify weight to be given to L2\-factor metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                        self.yang_name = "L2-factor"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "L2-factor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                class Latency(Entity):
                                    """
                                    Specify weight to be given to latency metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, self).__init__()

                                        self.yang_name = "latency"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "latency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                class Resources(Entity):
                                    """
                                    Specify weight to be given to resources metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, self).__init__()

                                        self.yang_name = "resources"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "resources"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                class Throughput(Entity):
                                    """
                                    Specify weight to be given to throughput metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, self).__init__()

                                        self.yang_name = "throughput"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "throughput"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.ProcessId.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.DatabaseFilter, [u'all', u'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.DemandCircuit, [u'disable', u'ignore'], name, value)


                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.FloodReduction, [u'disable'], name, value)


                    class Manet(Entity):
                        """
                        Mobile Adhoc Networking options
                        
                        .. attribute:: peering
                        
                        	MANET Peering options
                        	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet.Peering>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet, self).__init__()

                            self.yang_name = "manet"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet.Peering))])
                            self._leafs = OrderedDict()

                            self.peering = Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet.Peering()
                            self.peering.parent = self
                            self._children_name_map["peering"] = "peering"
                            self._segment_path = lambda: "manet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet, [], name, value)


                        class Peering(Entity):
                            """
                            MANET Peering options
                            
                            .. attribute:: cost
                            
                            	Redundant path cost improvement required to peer
                            	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet.Peering.Cost>`
                            
                            .. attribute:: link_metrics
                            
                            	Require link metrics
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet.Peering, self).__init__()

                                self.yang_name = "peering"
                                self.yang_parent_name = "manet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet.Peering.Cost))])
                                self._leafs = OrderedDict([
                                    ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                ])
                                self.link_metrics = None

                                self.cost = Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet.Peering.Cost()
                                self.cost.parent = self
                                self._children_name_map["cost"] = "cost"
                                self._segment_path = lambda: "peering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet.Peering, [u'link_metrics'], name, value)


                            class Cost(Entity):
                                """
                                Redundant path cost improvement required to peer
                                
                                .. attribute:: percent
                                
                                	Relative incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                .. attribute:: threshold
                                
                                	Absolute incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, self).__init__()

                                    self.yang_name = "cost"
                                    self.yang_parent_name = "peering"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "cost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.MtuIgnore, [u'disable'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: disable
                        
                        	disable OSPF multi\-area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.disable = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.MultiArea, [u'id', u'cost', u'disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FastEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.FastEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FastEthernet.Ospfv3.ProcessId.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.PrefixSuppression, ['disable'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Shutdown, [u'disable'], name, value)


                    class Ipv4(Entity):
                        """
                        Specify parameters for IPv4
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Area)), ("authentication", ("authentication", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Authentication)), ("bfd", ("bfd", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Bfd)), ("cost", ("cost", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost)), ("database-filter", ("database_filter", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction)), ("manet", ("manet", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Neighbor)), ("network", ("network", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 64..95
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, [u'disable'], name, value)


                    class Ipv6(Entity):
                        """
                        Specify parameters for IPv6
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Area)), ("authentication", ("authentication", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Authentication)), ("bfd", ("bfd", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Bfd)), ("cost", ("cost", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost)), ("database-filter", ("database_filter", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction)), ("manet", ("manet", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Neighbor)), ("network", ("network", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 0..31
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, [u'disable'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: key_chain
                    
                    	Use a key\-chain for cryptographic authentication keys
                    	**type**\: str
                    
                    .. attribute:: null
                    
                    	Use no authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec authentication
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.null = None

                        self.ipsec = Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Authentication, [u'key_chain', u'null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec authentication
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 256..4294967295
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5>`
                        
                        .. attribute:: sha1
                        
                        	Use SHA\-1 authentication
                        	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                            ])
                            self.spi = None

                            self.md5 = Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"

                            self.sha1 = Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1()
                            self.sha1.parent = self
                            self._children_name_map["sha1"] = "sha1"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec, ['spi'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class Sha1(Entity):
                            """
                            Use SHA\-1 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1, self).__init__()

                                self.yang_name = "sha1"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "sha1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "sha1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                class Bfd(Entity):
                    """
                    Enable BFD on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BFD on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Bfd, ['disable'], name, value)


                class Cost(Entity):
                    """
                    Route cost of this interface
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: dynamic
                    
                    	Specify dynamic cost options
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.Cost, self).__init__()

                        self.yang_name = "cost"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.dynamic = None
                        self._children_name_map["dynamic"] = "dynamic"
                        self._segment_path = lambda: "cost"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Cost, [u'value'], name, value)


                    class Dynamic(Entity):
                        """
                        Specify dynamic cost options
                        
                        .. attribute:: default
                        
                        	Specify default link metric value
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hysteresis
                        
                        	Specify hysteresis value for LSA dampening
                        	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Hysteresis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: weight
                        
                        	Specify weight to be placed on individual metrics
                        	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic, self).__init__()

                            self.yang_name = "dynamic"
                            self.yang_parent_name = "cost"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                            ])
                            self.default = None

                            self.hysteresis = None
                            self._children_name_map["hysteresis"] = "hysteresis"

                            self.weight = Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight()
                            self.weight.parent = self
                            self._children_name_map["weight"] = "weight"
                            self._segment_path = lambda: "dynamic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic, [u'default'], name, value)


                        class Hysteresis(Entity):
                            """
                            Specify hysteresis value for LSA dampening
                            
                            .. attribute:: percent
                            
                            	Specify hysteresis percent changed
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold
                            
                            	Specify hysteresis threshold value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Hysteresis, self).__init__()

                                self.yang_name = "hysteresis"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "hysteresis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                        class Weight(Entity):
                            """
                            Specify weight to be placed on individual metrics
                            
                            .. attribute:: l2_factor
                            
                            	Specify weight to be given to L2\-factor metric
                            	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: latency
                            
                            	Specify weight to be given to latency metric
                            	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Latency>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: resources
                            
                            	Specify weight to be given to resources metric
                            	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Resources>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: throughput
                            
                            	Specify weight to be given to throughput metric
                            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight, self).__init__()

                                self.yang_name = "weight"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput))])
                                self._leafs = OrderedDict()

                                self.l2_factor = None
                                self._children_name_map["l2_factor"] = "L2-factor"

                                self.latency = None
                                self._children_name_map["latency"] = "latency"

                                self.resources = None
                                self._children_name_map["resources"] = "resources"

                                self.throughput = None
                                self._children_name_map["throughput"] = "throughput"
                                self._segment_path = lambda: "weight"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight, [], name, value)


                            class L2Factor(Entity):
                                """
                                Specify weight to be given to L2\-factor metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                    self.yang_name = "L2-factor"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "L2-factor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                            class Latency(Entity):
                                """
                                Specify weight to be given to latency metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, self).__init__()

                                    self.yang_name = "latency"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "latency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                            class Resources(Entity):
                                """
                                Specify weight to be given to resources metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, self).__init__()

                                    self.yang_name = "resources"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "resources"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                            class Throughput(Entity):
                                """
                                Specify weight to be given to throughput metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, self).__init__()

                                    self.yang_name = "throughput"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "throughput"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.DatabaseFilter.All')])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.DatabaseFilter, [u'all'], name, value)

                    class All(Enum):
                        """
                        All (Enum Class)

                        Filter all LSA

                        .. data:: out = 0

                        """

                        out = Enum.YLeaf(0, "out")



                class DemandCircuit(Entity):
                    """
                    OSPF Demand Circuit
                    
                    .. attribute:: ignore
                    
                    	Ignore demand circuit auto\-negotiation requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.DemandCircuit, self).__init__()

                        self.yang_name = "demand-circuit"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.ignore = None
                        self._segment_path = lambda: "demand-circuit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.DemandCircuit, [u'ignore'], name, value)


                class Encryption(Entity):
                    """
                    Enable encryption
                    
                    .. attribute:: null
                    
                    	No IPsec encryption on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec encryption
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec))])
                        self._leafs = OrderedDict([
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.null = None

                        self.ipsec = Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Encryption, ['null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec encryption
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: esp
                        
                        	Use ESP encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec_3des
                        
                        	Use 3DES encryption
                        	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des>`
                        
                        .. attribute:: aes_cbc
                        
                        	Use AES\-CBC encryption
                        	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                            ])
                            self.spi = None
                            self.esp = None

                            self.ipsec_3des = Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des()
                            self.ipsec_3des.parent = self
                            self._children_name_map["ipsec_3des"] = "ipsec_3des"

                            self.aes_cbc = Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc()
                            self.aes_cbc.parent = self
                            self._children_name_map["aes_cbc"] = "aes-cbc"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec, ['spi', 'esp'], name, value)


                        class Ipsec3des(Entity):
                            """
                            Use 3DES encryption
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, self).__init__()

                                self.yang_name = "ipsec_3des"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "ipsec_3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "ipsec_3des"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class AesCbc(Entity):
                            """
                            Use AES\-CBC encryption
                            
                            .. attribute:: aes_cbc_128
                            
                            	Use 128 bit key
                            	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128>`
                            
                            .. attribute:: aes_192
                            
                            	Use 192 bit key
                            	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192>`
                            
                            .. attribute:: aes_256
                            
                            	Use 256 bit key
                            	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc, self).__init__()

                                self.yang_name = "aes-cbc"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256))])
                                self._leafs = OrderedDict()

                                self.aes_cbc_128 = Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128()
                                self.aes_cbc_128.parent = self
                                self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                self.aes_192 = Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192()
                                self.aes_192.parent = self
                                self._children_name_map["aes_192"] = "aes-192"

                                self.aes_256 = Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256()
                                self.aes_256.parent = self
                                self._children_name_map["aes_256"] = "aes-256"
                                self._segment_path = lambda: "aes-cbc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc, [], name, value)


                            class AesCbc128(Entity):
                                """
                                Use 128 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                    self.yang_name = "aes-cbc-128"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-cbc-128"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-cbc-128"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes192(Entity):
                                """
                                Use 192 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                    self.yang_name = "aes-192"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-192"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-192"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes256(Entity):
                                """
                                Use 256 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                    self.yang_name = "aes-256"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-256"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-256"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                class Manet(Entity):
                    """
                    Mobile Adhoc Networking options
                    
                    .. attribute:: peering
                    
                    	MANET Peering options
                    	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Manet.Peering>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.Manet, self).__init__()

                        self.yang_name = "manet"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FastEthernet.Ospfv3.Manet.Peering))])
                        self._leafs = OrderedDict()

                        self.peering = Native.Interface.FastEthernet.Ospfv3.Manet.Peering()
                        self.peering.parent = self
                        self._children_name_map["peering"] = "peering"
                        self._segment_path = lambda: "manet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Manet, [], name, value)


                    class Peering(Entity):
                        """
                        MANET Peering options
                        
                        .. attribute:: cost
                        
                        	Redundant path cost improvement required to peer
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Manet.Peering.Cost>`
                        
                        .. attribute:: link_metrics
                        
                        	Require link metrics
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.Manet.Peering, self).__init__()

                            self.yang_name = "peering"
                            self.yang_parent_name = "manet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FastEthernet.Ospfv3.Manet.Peering.Cost))])
                            self._leafs = OrderedDict([
                                ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                            ])
                            self.link_metrics = None

                            self.cost = Native.Interface.FastEthernet.Ospfv3.Manet.Peering.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"
                            self._segment_path = lambda: "peering"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Manet.Peering, [u'link_metrics'], name, value)


                        class Cost(Entity):
                            """
                            Redundant path cost improvement required to peer
                            
                            .. attribute:: percent
                            
                            	Relative incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: threshold
                            
                            	Absolute incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Ospfv3.Manet.Peering.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "peering"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                class MultiArea(Entity):
                    """
                    Set the OSPF multi\-area ID
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.MultiArea, self).__init__()

                        self.yang_name = "multi-area"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self._segment_path = lambda: "multi-area"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.MultiArea, [u'id', u'cost'], name, value)


                class Neighbor(Entity):
                    """
                    OSPF neighbor
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	OSPF cost for point\-to\-multipoint neighbor
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Neighbor.DatabaseFilter>`
                    
                    .. attribute:: poll_interval
                    
                    	OSPF dead\-router polling interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: priority
                    
                    	OSPF priority of non\-broadcast neighbor
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FastEthernet.Ospfv3.Neighbor.DatabaseFilter))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self.poll_interval = None
                        self.priority = None

                        self.database_filter = Native.Interface.FastEthernet.Ospfv3.Neighbor.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Neighbor.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.Neighbor.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Ospfv3.Neighbor.DatabaseFilter.All')])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Neighbor.DatabaseFilter, ['all'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                class Network(Entity):
                    """
                    Network type
                    
                    .. attribute:: broadcast
                    
                    	Specify OSPF broadcast multi\-access network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: manet
                    
                    	Specify MANET OSPF interface type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: non_broadcast
                    
                    	Specify OSPF NBMA network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: point_to_multipoint
                    
                    	Specify OSPF point\-to\-multipoint network
                    	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Ospfv3.Network.PointToMultipoint>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: point_to_point
                    
                    	Specify OSPF point\-to\-point network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FastEthernet.Ospfv3.Network.PointToMultipoint))])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                            ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                        ])
                        self.broadcast = None
                        self.manet = None
                        self.non_broadcast = None
                        self.point_to_point = None

                        self.point_to_multipoint = None
                        self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                    class PointToMultipoint(Entity):
                        """
                        Specify OSPF point\-to\-multipoint network
                        
                        .. attribute:: non_broadcast
                        
                        	Specify non\-broadcast point\-to\-mpoint network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Ospfv3.Network.PointToMultipoint, self).__init__()

                            self.yang_name = "point-to-multipoint"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ])
                            self.non_broadcast = None
                            self._segment_path = lambda: "point-to-multipoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.Network.PointToMultipoint, ['non_broadcast'], name, value)


                class PrefixSuppression(Entity):
                    """
                    OSPF prefix suppression
                    
                    .. attribute:: disable
                    
                    	Disable prefix suppression
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Ospfv3.PrefixSuppression, self).__init__()

                        self.yang_name = "prefix-suppression"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "prefix-suppression"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Ospfv3.PrefixSuppression, ['disable'], name, value)


            class Udld(Entity):
                """
                Configure UDLD enabled or disabled and ignore global UDLD setting
                
                .. attribute:: port
                
                	Enable UDLD protocol on this interface despite global UDLD setting
                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Udld.Port>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-udld'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Udld, self).__init__()

                    self.yang_name = "udld"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.FastEthernet.Udld.Port))])
                    self._leafs = OrderedDict()

                    self.port = None
                    self._children_name_map["port"] = "port"
                    self._segment_path = lambda: "Cisco-IOS-XE-udld:udld"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Udld, [], name, value)


                class Port(Entity):
                    """
                    Enable UDLD protocol on this interface despite global UDLD setting
                    
                    .. attribute:: aggressive
                    
                    	Enable UDLD protocol in aggressive mode on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	Disable UDLD protocol on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-udld'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Udld.Port, self).__init__()

                        self.yang_name = "port"
                        self.yang_parent_name = "udld"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aggressive', (YLeaf(YType.empty, 'aggressive'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.aggressive = None
                        self.disable = None
                        self._segment_path = lambda: "port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Udld.Port, ['aggressive', 'disable'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.Manual>`
                
                	**presence node**\: True
                
                .. attribute:: role_based
                
                	Role\-based Access Control per\-port config commands
                	**type**\:  :py:class:`RoleBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.RoleBased>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FastEthernet.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.FastEthernet.Cts.Manual)), ("role-based", ("role_based", Native.Interface.FastEthernet.Cts.RoleBased))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"

                    self.role_based = Native.Interface.FastEthernet.Cts.RoleBased()
                    self.role_based.parent = self
                    self._children_name_map["role_based"] = "role-based"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.FastEthernet.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.FastEthernet.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.FastEthernet.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.FastEthernet.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.FastEthernet.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.FastEthernet.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.FastEthernet.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.FastEthernet.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FastEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Cts.Manual.Propagate, ['sgt'], name, value)


                class RoleBased(Entity):
                    """
                    Role\-based Access Control per\-port config commands
                    
                    .. attribute:: sgt_cache
                    
                    	Enable SGT caching on the interface
                    	**type**\: list of   :py:class:`SgtCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.RoleBased.SgtCache>`
                    
                    .. attribute:: enforcement
                    
                    	Enable Role\-based Access Control enforcement
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sgt_map
                    
                    	Assign Security Group Tag (SGT) to IP host or network address
                    	**type**\:  :py:class:`SgtMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.Cts.RoleBased.SgtMap>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.Cts.RoleBased, self).__init__()

                        self.yang_name = "role-based"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sgt-map", ("sgt_map", Native.Interface.FastEthernet.Cts.RoleBased.SgtMap))])
                        self._leafs = OrderedDict([
                            ('sgt_cache', (YLeafList(YType.enumeration, 'sgt-cache'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FastEthernet.Cts.RoleBased.SgtCache')])),
                            ('enforcement', (YLeaf(YType.empty, 'enforcement'), ['Empty'])),
                        ])
                        self.sgt_cache = []
                        self.enforcement = None

                        self.sgt_map = Native.Interface.FastEthernet.Cts.RoleBased.SgtMap()
                        self.sgt_map.parent = self
                        self._children_name_map["sgt_map"] = "sgt-map"
                        self._segment_path = lambda: "role-based"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.Cts.RoleBased, ['sgt_cache', 'enforcement'], name, value)

                    class SgtCache(Enum):
                        """
                        SgtCache (Enum Class)

                        Enable SGT caching on the interface

                        .. data:: egress = 0

                        .. data:: ingress = 1

                        """

                        egress = Enum.YLeaf(0, "egress")

                        ingress = Enum.YLeaf(1, "ingress")



                    class SgtMap(Entity):
                        """
                        Assign Security Group Tag (SGT) to IP host or network address
                        
                        .. attribute:: security_group
                        
                        	Security Group Name
                        	**type**\: str
                        
                        .. attribute:: sgt
                        
                        	Security Group Tag (SGT)
                        	**type**\: int
                        
                        	**range:** 2..65519
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FastEthernet.Cts.RoleBased.SgtMap, self).__init__()

                            self.yang_name = "sgt-map"
                            self.yang_parent_name = "role-based"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('security_group', (YLeaf(YType.str, 'security-group'), ['str'])),
                                ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                            ])
                            self.security_group = None
                            self.sgt = None
                            self._segment_path = lambda: "sgt-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FastEthernet.Cts.RoleBased.SgtMap, ['security_group', 'sgt'], name, value)


            class AnalysisModule(Entity):
                """
                Configure NAM on the interface
                
                .. attribute:: monitoring
                
                	Configure NAM monitoring on the interface
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FastEthernet.AnalysisModule.Monitoring>`
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Interface.FastEthernet.AnalysisModule, self).__init__()

                    self.yang_name = "analysis-module"
                    self.yang_parent_name = "FastEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Interface.FastEthernet.AnalysisModule.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = Native.Interface.FastEthernet.AnalysisModule.Monitoring()
                    self.monitoring.parent = self
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FastEthernet.AnalysisModule, [], name, value)


                class Monitoring(Entity):
                    """
                    Configure NAM monitoring on the interface
                    
                    .. attribute:: interface_name
                    
                    	The name of the output interface.  E.g., 'ucse 1/0/0'
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nam'
                    _revision = '2017-12-28'

                    def __init__(self):
                        super(Native.Interface.FastEthernet.AnalysisModule.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "analysis-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "monitoring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FastEthernet.AnalysisModule.Monitoring, ['interface_name'], name, value)


        class Ucse(Entity):
            """
            Cisco ucse server
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Negotiation>`
            
            .. attribute:: switchport_wrapper
            
            	
            	**type**\:  :py:class:`SwitchportWrapper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.SwitchportWrapper>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.PmPath>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Ucse, self).__init__()

                self.yang_name = "ucse"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("negotiation", ("negotiation", Native.Interface.Ucse.Negotiation)), ("switchport-wrapper", ("switchport_wrapper", Native.Interface.Ucse.SwitchportWrapper)), ("switchport-conf", ("switchport_conf", Native.Interface.Ucse.SwitchportConf)), ("switchport", ("switchport", Native.Interface.Ucse.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.Ucse.StackwiseVirtual)), ("arp", ("arp", Native.Interface.Ucse.Arp)), ("backup", ("backup", Native.Interface.Ucse.Backup)), ("cemoudp", ("cemoudp", Native.Interface.Ucse.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.Ucse.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.Ucse.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.Ucse.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.Ucse.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.Ucse.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.Ucse.Flowcontrol)), ("isis", ("isis", Native.Interface.Ucse.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.Ucse.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.Ucse.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.Ucse.Bandwidth)), ("dampening", ("dampening", Native.Interface.Ucse.Dampening)), ("domain", ("domain", Native.Interface.Ucse.Domain)), ("hold-queue", ("hold_queue", Native.Interface.Ucse.HoldQueue)), ("mpls", ("mpls", Native.Interface.Ucse.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.Ucse.IpVrf)), ("vrf", ("vrf", Native.Interface.Ucse.Vrf)), ("ip", ("ip", Native.Interface.Ucse.Ip)), ("ipv6", ("ipv6", Native.Interface.Ucse.Ipv6)), ("logging", ("logging", Native.Interface.Ucse.Logging)), ("mdix", ("mdix", Native.Interface.Ucse.Mdix)), ("mop", ("mop", Native.Interface.Ucse.Mop)), ("interface_qos", ("interface_qos", Native.Interface.Ucse.InterfaceQos)), ("source", ("source", Native.Interface.Ucse.Source)), ("standby", ("standby", Native.Interface.Ucse.Standby)), ("access-session", ("access_session", Native.Interface.Ucse.AccessSession)), ("storm-control", ("storm_control", Native.Interface.Ucse.StormControl)), ("trust", ("trust", Native.Interface.Ucse.Trust)), ("priority-queue", ("priority_queue", Native.Interface.Ucse.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.Ucse.RcvQueue)), ("peer", ("peer", Native.Interface.Ucse.Peer)), ("pm-path", ("pm_path", Native.Interface.Ucse.PmPath))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.negotiation = Native.Interface.Ucse.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "negotiation"

                self.switchport_wrapper = Native.Interface.Ucse.SwitchportWrapper()
                self.switchport_wrapper.parent = self
                self._children_name_map["switchport_wrapper"] = "switchport-wrapper"

                self.switchport_conf = Native.Interface.Ucse.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.Ucse.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.Ucse.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.Ucse.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.Ucse.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.Ucse.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.Ucse.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.Ucse.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.Ucse.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.Ucse.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.Ucse.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.Ucse.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.Ucse.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.Ucse.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.Ucse.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.Ucse.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.Ucse.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.Ucse.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.Ucse.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.Ucse.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.Ucse.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.Ucse.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.Ucse.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.Ucse.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.Ucse.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.Ucse.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.Ucse.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.Ucse.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.Ucse.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.Ucse.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.Ucse.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.Ucse.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.Ucse.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.Ucse.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.Ucse.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "ucse" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Ucse, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Negotiation, [u'auto'], name, value)


            class SwitchportWrapper(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.SwitchportWrapper.Switchport>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.SwitchportWrapper, self).__init__()

                    self.yang_name = "switchport-wrapper"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("switchport", ("switchport", Native.Interface.Ucse.SwitchportWrapper.Switchport))])
                    self._leafs = OrderedDict()

                    self.switchport = Native.Interface.Ucse.SwitchportWrapper.Switchport()
                    self.switchport.parent = self
                    self._children_name_map["switchport"] = "switchport"
                    self._segment_path = lambda: "switchport-wrapper"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.SwitchportWrapper, [], name, value)


                class Switchport(Entity):
                    """
                    
                    
                    .. attribute:: access
                    
                    	Set access mode characteristics of the interface
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.SwitchportWrapper.Switchport.Access>`
                    
                    .. attribute:: mode
                    
                    	Set trunking mode of the interface
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.SwitchportWrapper.Switchport.Mode>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking characteristics of the interface
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.SwitchportWrapper.Switchport, self).__init__()

                        self.yang_name = "switchport"
                        self.yang_parent_name = "switchport-wrapper"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.Ucse.SwitchportWrapper.Switchport.Access)), ("trunk", ("trunk", Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk))])
                        self._leafs = OrderedDict([
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.SwitchportWrapper.Switchport.Mode')])),
                        ])
                        self.mode = None

                        self.access = Native.Interface.Ucse.SwitchportWrapper.Switchport.Access()
                        self.access.parent = self
                        self._children_name_map["access"] = "access"

                        self.trunk = Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk()
                        self.trunk.parent = self
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "switchport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.SwitchportWrapper.Switchport, [u'mode'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        Set trunking mode of the interface

                        .. data:: access = 0

                        .. data:: trunk = 1

                        """

                        access = Enum.YLeaf(0, "access")

                        trunk = Enum.YLeaf(1, "trunk")



                    class Access(Entity):
                        """
                        Set access mode characteristics of the interface
                        
                        .. attribute:: vlan
                        
                        	Set VLAN when interface is in access mode
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.SwitchportWrapper.Switchport.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "access"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.SwitchportWrapper.Switchport.Access, [u'vlan'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking characteristics of the interface
                        
                        .. attribute:: allowed
                        
                        	Set allowed VLAN characteristics when interface is in trunking mode
                        	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Allowed>`
                        
                        .. attribute:: native
                        
                        	
                        	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Native_>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Native_))])
                            self._leafs = OrderedDict()

                            self.allowed = Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Allowed()
                            self.allowed.parent = self
                            self._children_name_map["allowed"] = "allowed"

                            self.native = Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Native_()
                            self.native.parent = self
                            self._children_name_map["native"] = "native"
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk, [], name, value)


                        class Allowed(Entity):
                            """
                            Set allowed VLAN characteristics when interface is in trunking mode
                            
                            .. attribute:: vlan
                            
                            	Set allowed VLANs when interface is in trunking mode
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Allowed, self).__init__()

                                self.yang_name = "allowed"
                                self.yang_parent_name = "trunk"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan))])
                                self._leafs = OrderedDict()

                                self.vlan = Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "allowed"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Allowed, [], name, value)


                            class Vlan(Entity):
                                """
                                Set allowed VLANs when interface is in trunking mode
                                
                                .. attribute:: vlans
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: add
                                
                                	VLAN IDs of the allowed VLANs when this port is in trunking mode
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\: str
                                
                                .. attribute:: all
                                
                                	all VLANs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: except_
                                
                                	all VLANs except the following
                                	**type**\: union of the below types:
                                
                                		**type**\: list of int
                                
                                			**range:** 0..65535
                                
                                		**type**\: list of str
                                
                                .. attribute:: none
                                
                                	no VLANs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: remove
                                
                                	VLAN IDs of disallowed VLANS when this port is in trunking mode
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "allowed"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                        ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                    ])
                                    self.vlans = None
                                    self.add = None
                                    self.all = None
                                    self.except_ = []
                                    self.none = None
                                    self.remove = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                        class Native_(Entity):
                            """
                            
                            
                            .. attribute:: vlan
                            
                            	Set VLAN when interface is in access mode
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Native_, self).__init__()

                                self.yang_name = "native"
                                self.yang_parent_name = "trunk"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.vlan = None
                                self._segment_path = lambda: "native"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.SwitchportWrapper.Switchport.Trunk.Native_, [u'vlan'], name, value)


            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Ucse.Backup.Delay)), ("interface", ("interface", Native.Interface.Ucse.Backup.Interface_)), ("load", ("load", Native.Interface.Ucse.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Ucse.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Ucse.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Ucse.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Ucse.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Ucse.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Ucse.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Ucse.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Ucse.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Ucse.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Ucse.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Ucse.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Ucse.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Ucse.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Ucse.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Ucse.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Ucse.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Ucse.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Ucse.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Ucse.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Ucse.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Ucse.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Ucse.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.Ucse.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Ucse.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Ucse.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Ucse.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Ucse.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Ucse.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Ucse.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Ucse.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Ucse.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Ucse.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Ucse.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Ucse.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Ucse.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Ucse.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Ucse.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.Ucse.Ip.Arp)), ("vrf", ("vrf", Native.Interface.Ucse.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.Ucse.Ip.NoAddress)), ("address", ("address", Native.Interface.Ucse.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Ucse.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Ucse.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.Ucse.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.Ucse.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Ucse.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.Ucse.Ip.Pim)), ("policy", ("policy", Native.Interface.Ucse.Ip.Policy)), ("rip", ("rip", Native.Interface.Ucse.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Ucse.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Ucse.Ip.RouteCache)), ("router", ("router", Native.Interface.Ucse.Ip.Router)), ("tcp", ("tcp", Native.Interface.Ucse.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Ucse.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Ucse.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Ucse.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.Ucse.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.Ucse.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Ucse.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Ucse.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Ucse.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Ucse.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Ucse.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Ucse.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Ucse.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Ucse.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Ucse.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Ucse.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Ucse.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Ucse.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Ucse.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Ucse.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Ucse.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Ucse.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Ucse.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Ucse.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.Ucse.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Ucse.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Ucse.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Ucse.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Ucse.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Ucse.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Ucse.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Ucse.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Ucse.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Ucse.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Ucse.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Ucse.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Ucse.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Ucse.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Ucse.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Ucse.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Ucse.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Ucse.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.Ucse.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Ucse.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Ucse.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Ucse.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Ucse.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Ucse.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Ucse.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Ucse.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Ucse.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Ucse.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Ucse.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Ucse.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Ucse.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Ucse.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Ucse.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Ucse.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.Ucse.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Ucse.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Ucse.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Ucse.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Ucse.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Ucse.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Ucse.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Ucse.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Ucse.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Ucse.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Ucse.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Ucse.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Ucse.Ipv6.Dhcp)), ("address", ("address", Native.Interface.Ucse.Ipv6.Address)), ("nd", ("nd", Native.Interface.Ucse.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.Ucse.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Ucse.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Ucse.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Ucse.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Ucse.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Ucse.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Ucse.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Ucse.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Ucse.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Ucse.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Ucse.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Ucse.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Ucse.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Ucse.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Ucse.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Ucse.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Ucse.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Ucse.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Ucse.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Ucse.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.Ucse.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Ucse.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Ucse.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Ucse.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Ucse.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Ucse.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Ucse.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Ucse.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Ucse.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Ucse.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.Ucse.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Ucse.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Ucse.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Ucse.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Ucse.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Ucse.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Ucse.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Ucse.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Ucse.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Ucse.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Ucse.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Ucse.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Ucse.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Ucse.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Ucse.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Ucse.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Ucse.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Ucse.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Ucse.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Ucse.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Ucse.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Ucse.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Ucse.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Ucse.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Ucse.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Ucse.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Ucse.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Ucse.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Ucse.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Ucse.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Ucse.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Ucse.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Ucse.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Ucse.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Ucse.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Ucse.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Ucse.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Ucse.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Ucse.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Ucse.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Ucse.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Ucse.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Ucse.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Ucse.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Ucse.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Ucse.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Ucse.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Ucse.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Ucse.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Ucse.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Ucse.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Ucse.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Ucse.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Ucse.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Ucse.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Ucse.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Ucse.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Ucse.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Ucse.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Ucse.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Ucse.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Ucse.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Ucse.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Ucse.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Ucse.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Ucse.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Ucse.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Ucse.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Ucse.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Ucse.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Ucse.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Ucse.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Ucse.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Ucse.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Ucse.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Ucse.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Ucse.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Ucse.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Ucse.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "ucse"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Ucse.PmPath, [u'name', u'interface_id'], name, value)


        class EthernetInternal(Entity):
            """
            Ethernet\-Internal interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Negotiation>`
            
            .. attribute:: switchport_wrapper
            
            	
            	**type**\:  :py:class:`SwitchportWrapper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.SwitchportWrapper>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.PmPath>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.EthernetInternal, self).__init__()

                self.yang_name = "Ethernet-Internal"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("negotiation", ("negotiation", Native.Interface.EthernetInternal.Negotiation)), ("switchport-wrapper", ("switchport_wrapper", Native.Interface.EthernetInternal.SwitchportWrapper)), ("switchport-conf", ("switchport_conf", Native.Interface.EthernetInternal.SwitchportConf)), ("switchport", ("switchport", Native.Interface.EthernetInternal.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.EthernetInternal.StackwiseVirtual)), ("arp", ("arp", Native.Interface.EthernetInternal.Arp)), ("backup", ("backup", Native.Interface.EthernetInternal.Backup)), ("cemoudp", ("cemoudp", Native.Interface.EthernetInternal.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.EthernetInternal.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.EthernetInternal.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.EthernetInternal.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.EthernetInternal.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.EthernetInternal.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.EthernetInternal.Flowcontrol)), ("isis", ("isis", Native.Interface.EthernetInternal.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.EthernetInternal.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.EthernetInternal.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.EthernetInternal.Bandwidth)), ("dampening", ("dampening", Native.Interface.EthernetInternal.Dampening)), ("domain", ("domain", Native.Interface.EthernetInternal.Domain)), ("hold-queue", ("hold_queue", Native.Interface.EthernetInternal.HoldQueue)), ("mpls", ("mpls", Native.Interface.EthernetInternal.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.EthernetInternal.IpVrf)), ("vrf", ("vrf", Native.Interface.EthernetInternal.Vrf)), ("ip", ("ip", Native.Interface.EthernetInternal.Ip)), ("ipv6", ("ipv6", Native.Interface.EthernetInternal.Ipv6)), ("logging", ("logging", Native.Interface.EthernetInternal.Logging)), ("mdix", ("mdix", Native.Interface.EthernetInternal.Mdix)), ("mop", ("mop", Native.Interface.EthernetInternal.Mop)), ("interface_qos", ("interface_qos", Native.Interface.EthernetInternal.InterfaceQos)), ("source", ("source", Native.Interface.EthernetInternal.Source)), ("standby", ("standby", Native.Interface.EthernetInternal.Standby)), ("access-session", ("access_session", Native.Interface.EthernetInternal.AccessSession)), ("storm-control", ("storm_control", Native.Interface.EthernetInternal.StormControl)), ("trust", ("trust", Native.Interface.EthernetInternal.Trust)), ("priority-queue", ("priority_queue", Native.Interface.EthernetInternal.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.EthernetInternal.RcvQueue)), ("peer", ("peer", Native.Interface.EthernetInternal.Peer)), ("pm-path", ("pm_path", Native.Interface.EthernetInternal.PmPath))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.negotiation = Native.Interface.EthernetInternal.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "negotiation"

                self.switchport_wrapper = Native.Interface.EthernetInternal.SwitchportWrapper()
                self.switchport_wrapper.parent = self
                self._children_name_map["switchport_wrapper"] = "switchport-wrapper"

                self.switchport_conf = Native.Interface.EthernetInternal.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.EthernetInternal.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.EthernetInternal.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.EthernetInternal.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.EthernetInternal.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.EthernetInternal.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.EthernetInternal.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.EthernetInternal.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.EthernetInternal.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.EthernetInternal.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.EthernetInternal.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.EthernetInternal.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.EthernetInternal.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.EthernetInternal.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.EthernetInternal.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.EthernetInternal.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.EthernetInternal.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.EthernetInternal.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.EthernetInternal.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.EthernetInternal.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.EthernetInternal.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.EthernetInternal.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.EthernetInternal.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.EthernetInternal.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.EthernetInternal.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.EthernetInternal.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.EthernetInternal.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.EthernetInternal.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.EthernetInternal.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.EthernetInternal.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.EthernetInternal.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.EthernetInternal.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.EthernetInternal.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.EthernetInternal.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.EthernetInternal.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "Ethernet-Internal" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.EthernetInternal, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Negotiation, [u'auto'], name, value)


            class SwitchportWrapper(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.SwitchportWrapper.Switchport>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.SwitchportWrapper, self).__init__()

                    self.yang_name = "switchport-wrapper"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("switchport", ("switchport", Native.Interface.EthernetInternal.SwitchportWrapper.Switchport))])
                    self._leafs = OrderedDict()

                    self.switchport = Native.Interface.EthernetInternal.SwitchportWrapper.Switchport()
                    self.switchport.parent = self
                    self._children_name_map["switchport"] = "switchport"
                    self._segment_path = lambda: "switchport-wrapper"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.SwitchportWrapper, [], name, value)


                class Switchport(Entity):
                    """
                    
                    
                    .. attribute:: access
                    
                    	Set access mode characteristics of the interface
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Access>`
                    
                    .. attribute:: mode
                    
                    	Set trunking mode of the interface
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Mode>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking characteristics of the interface
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport, self).__init__()

                        self.yang_name = "switchport"
                        self.yang_parent_name = "switchport-wrapper"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Access)), ("trunk", ("trunk", Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk))])
                        self._leafs = OrderedDict([
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.SwitchportWrapper.Switchport.Mode')])),
                        ])
                        self.mode = None

                        self.access = Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Access()
                        self.access.parent = self
                        self._children_name_map["access"] = "access"

                        self.trunk = Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk()
                        self.trunk.parent = self
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "switchport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport, [u'mode'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        Set trunking mode of the interface

                        .. data:: access = 0

                        .. data:: trunk = 1

                        """

                        access = Enum.YLeaf(0, "access")

                        trunk = Enum.YLeaf(1, "trunk")



                    class Access(Entity):
                        """
                        Set access mode characteristics of the interface
                        
                        .. attribute:: vlan
                        
                        	Set VLAN when interface is in access mode
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "access"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Access, [u'vlan'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking characteristics of the interface
                        
                        .. attribute:: allowed
                        
                        	Set allowed VLAN characteristics when interface is in trunking mode
                        	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Allowed>`
                        
                        .. attribute:: native
                        
                        	
                        	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Native_>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Native_))])
                            self._leafs = OrderedDict()

                            self.allowed = Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Allowed()
                            self.allowed.parent = self
                            self._children_name_map["allowed"] = "allowed"

                            self.native = Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Native_()
                            self.native.parent = self
                            self._children_name_map["native"] = "native"
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk, [], name, value)


                        class Allowed(Entity):
                            """
                            Set allowed VLAN characteristics when interface is in trunking mode
                            
                            .. attribute:: vlan
                            
                            	Set allowed VLANs when interface is in trunking mode
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Allowed, self).__init__()

                                self.yang_name = "allowed"
                                self.yang_parent_name = "trunk"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan))])
                                self._leafs = OrderedDict()

                                self.vlan = Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "allowed"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Allowed, [], name, value)


                            class Vlan(Entity):
                                """
                                Set allowed VLANs when interface is in trunking mode
                                
                                .. attribute:: vlans
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: add
                                
                                	VLAN IDs of the allowed VLANs when this port is in trunking mode
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\: str
                                
                                .. attribute:: all
                                
                                	all VLANs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: except_
                                
                                	all VLANs except the following
                                	**type**\: union of the below types:
                                
                                		**type**\: list of int
                                
                                			**range:** 0..65535
                                
                                		**type**\: list of str
                                
                                .. attribute:: none
                                
                                	no VLANs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: remove
                                
                                	VLAN IDs of disallowed VLANS when this port is in trunking mode
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "allowed"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                        ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                    ])
                                    self.vlans = None
                                    self.add = None
                                    self.all = None
                                    self.except_ = []
                                    self.none = None
                                    self.remove = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                        class Native_(Entity):
                            """
                            
                            
                            .. attribute:: vlan
                            
                            	Set VLAN when interface is in access mode
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Native_, self).__init__()

                                self.yang_name = "native"
                                self.yang_parent_name = "trunk"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.vlan = None
                                self._segment_path = lambda: "native"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.SwitchportWrapper.Switchport.Trunk.Native_, [u'vlan'], name, value)


            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.EthernetInternal.Backup.Delay)), ("interface", ("interface", Native.Interface.EthernetInternal.Backup.Interface_)), ("load", ("load", Native.Interface.EthernetInternal.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.EthernetInternal.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.EthernetInternal.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.EthernetInternal.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.EthernetInternal.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.EthernetInternal.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.EthernetInternal.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.EthernetInternal.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.EthernetInternal.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.EthernetInternal.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.EthernetInternal.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.EthernetInternal.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.EthernetInternal.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.EthernetInternal.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.EthernetInternal.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.EthernetInternal.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.EthernetInternal.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.EthernetInternal.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.EthernetInternal.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.EthernetInternal.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.EthernetInternal.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.EthernetInternal.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.EthernetInternal.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.EthernetInternal.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.EthernetInternal.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.EthernetInternal.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.EthernetInternal.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.EthernetInternal.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.EthernetInternal.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.EthernetInternal.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.EthernetInternal.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.EthernetInternal.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.EthernetInternal.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.EthernetInternal.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.EthernetInternal.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.EthernetInternal.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.EthernetInternal.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.EthernetInternal.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.EthernetInternal.Ip.Arp)), ("vrf", ("vrf", Native.Interface.EthernetInternal.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.EthernetInternal.Ip.NoAddress)), ("address", ("address", Native.Interface.EthernetInternal.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.EthernetInternal.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.EthernetInternal.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.EthernetInternal.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.EthernetInternal.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.EthernetInternal.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.EthernetInternal.Ip.Pim)), ("policy", ("policy", Native.Interface.EthernetInternal.Ip.Policy)), ("rip", ("rip", Native.Interface.EthernetInternal.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.EthernetInternal.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.EthernetInternal.Ip.RouteCache)), ("router", ("router", Native.Interface.EthernetInternal.Ip.Router)), ("tcp", ("tcp", Native.Interface.EthernetInternal.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.EthernetInternal.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.EthernetInternal.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.EthernetInternal.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.EthernetInternal.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.EthernetInternal.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.EthernetInternal.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.EthernetInternal.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.EthernetInternal.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.EthernetInternal.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.EthernetInternal.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.EthernetInternal.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.EthernetInternal.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.EthernetInternal.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.EthernetInternal.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.EthernetInternal.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.EthernetInternal.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.EthernetInternal.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.EthernetInternal.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.EthernetInternal.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.EthernetInternal.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.EthernetInternal.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.EthernetInternal.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.EthernetInternal.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.EthernetInternal.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.EthernetInternal.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.EthernetInternal.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.EthernetInternal.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.EthernetInternal.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.EthernetInternal.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.EthernetInternal.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.EthernetInternal.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.EthernetInternal.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.EthernetInternal.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.EthernetInternal.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.EthernetInternal.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.EthernetInternal.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.EthernetInternal.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.EthernetInternal.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.EthernetInternal.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.EthernetInternal.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.EthernetInternal.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.EthernetInternal.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.EthernetInternal.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.EthernetInternal.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.EthernetInternal.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.EthernetInternal.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.EthernetInternal.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.EthernetInternal.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.EthernetInternal.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.EthernetInternal.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.EthernetInternal.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.EthernetInternal.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.EthernetInternal.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.EthernetInternal.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.EthernetInternal.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.EthernetInternal.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.EthernetInternal.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.EthernetInternal.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.EthernetInternal.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.EthernetInternal.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.EthernetInternal.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.EthernetInternal.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.EthernetInternal.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.EthernetInternal.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.EthernetInternal.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.EthernetInternal.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.EthernetInternal.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.EthernetInternal.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.EthernetInternal.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.EthernetInternal.Ipv6.Dhcp)), ("address", ("address", Native.Interface.EthernetInternal.Ipv6.Address)), ("nd", ("nd", Native.Interface.EthernetInternal.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.EthernetInternal.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.EthernetInternal.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.EthernetInternal.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.EthernetInternal.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.EthernetInternal.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.EthernetInternal.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.EthernetInternal.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.EthernetInternal.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.EthernetInternal.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.EthernetInternal.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.EthernetInternal.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.EthernetInternal.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.EthernetInternal.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.EthernetInternal.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.EthernetInternal.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.EthernetInternal.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.EthernetInternal.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.EthernetInternal.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.EthernetInternal.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.EthernetInternal.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.EthernetInternal.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.EthernetInternal.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.EthernetInternal.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.EthernetInternal.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.EthernetInternal.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.EthernetInternal.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.EthernetInternal.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.EthernetInternal.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.EthernetInternal.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.EthernetInternal.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.EthernetInternal.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.EthernetInternal.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.EthernetInternal.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.EthernetInternal.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.EthernetInternal.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.EthernetInternal.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.EthernetInternal.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.EthernetInternal.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.EthernetInternal.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.EthernetInternal.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.EthernetInternal.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.EthernetInternal.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.EthernetInternal.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.EthernetInternal.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.EthernetInternal.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.EthernetInternal.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.EthernetInternal.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.EthernetInternal.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.EthernetInternal.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.EthernetInternal.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.EthernetInternal.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.EthernetInternal.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.EthernetInternal.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.EthernetInternal.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.EthernetInternal.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.EthernetInternal.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.EthernetInternal.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.EthernetInternal.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.EthernetInternal.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.EthernetInternal.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.EthernetInternal.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.EthernetInternal.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.EthernetInternal.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.EthernetInternal.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.EthernetInternal.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.EthernetInternal.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.EthernetInternal.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.EthernetInternal.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.EthernetInternal.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.EthernetInternal.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.EthernetInternal.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.EthernetInternal.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.EthernetInternal.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.EthernetInternal.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.EthernetInternal.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.EthernetInternal.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.EthernetInternal.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.EthernetInternal.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.EthernetInternal.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.EthernetInternal.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.EthernetInternal.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.EthernetInternal.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.EthernetInternal.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.EthernetInternal.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.EthernetInternal.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.EthernetInternal.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.EthernetInternal.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.EthernetInternal.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.EthernetInternal.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.EthernetInternal.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.EthernetInternal.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.EthernetInternal.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.EthernetInternal.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.EthernetInternal.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.EthernetInternal.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.EthernetInternal.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Ethernet-Internal"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.EthernetInternal.PmPath, [u'name', u'interface_id'], name, value)


        class ServiceEngine(Entity):
            """
            Cisco service engine module
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.PmPath>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.ServiceEngine, self).__init__()

                self.yang_name = "Service-Engine"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.ServiceEngine.SwitchportConf)), ("switchport", ("switchport", Native.Interface.ServiceEngine.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.ServiceEngine.StackwiseVirtual)), ("arp", ("arp", Native.Interface.ServiceEngine.Arp)), ("backup", ("backup", Native.Interface.ServiceEngine.Backup)), ("cemoudp", ("cemoudp", Native.Interface.ServiceEngine.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.ServiceEngine.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.ServiceEngine.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.ServiceEngine.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.ServiceEngine.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.ServiceEngine.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.ServiceEngine.Flowcontrol)), ("isis", ("isis", Native.Interface.ServiceEngine.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.ServiceEngine.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.ServiceEngine.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.ServiceEngine.Bandwidth)), ("dampening", ("dampening", Native.Interface.ServiceEngine.Dampening)), ("domain", ("domain", Native.Interface.ServiceEngine.Domain)), ("hold-queue", ("hold_queue", Native.Interface.ServiceEngine.HoldQueue)), ("mpls", ("mpls", Native.Interface.ServiceEngine.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.ServiceEngine.IpVrf)), ("vrf", ("vrf", Native.Interface.ServiceEngine.Vrf)), ("ip", ("ip", Native.Interface.ServiceEngine.Ip)), ("ipv6", ("ipv6", Native.Interface.ServiceEngine.Ipv6)), ("logging", ("logging", Native.Interface.ServiceEngine.Logging)), ("mdix", ("mdix", Native.Interface.ServiceEngine.Mdix)), ("mop", ("mop", Native.Interface.ServiceEngine.Mop)), ("interface_qos", ("interface_qos", Native.Interface.ServiceEngine.InterfaceQos)), ("source", ("source", Native.Interface.ServiceEngine.Source)), ("standby", ("standby", Native.Interface.ServiceEngine.Standby)), ("access-session", ("access_session", Native.Interface.ServiceEngine.AccessSession)), ("storm-control", ("storm_control", Native.Interface.ServiceEngine.StormControl)), ("trust", ("trust", Native.Interface.ServiceEngine.Trust)), ("priority-queue", ("priority_queue", Native.Interface.ServiceEngine.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.ServiceEngine.RcvQueue)), ("peer", ("peer", Native.Interface.ServiceEngine.Peer)), ("pm-path", ("pm_path", Native.Interface.ServiceEngine.PmPath))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.ServiceEngine.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.ServiceEngine.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.ServiceEngine.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.ServiceEngine.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.ServiceEngine.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.ServiceEngine.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.ServiceEngine.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.ServiceEngine.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.ServiceEngine.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.ServiceEngine.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.ServiceEngine.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.ServiceEngine.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.ServiceEngine.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.ServiceEngine.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.ServiceEngine.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.ServiceEngine.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.ServiceEngine.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.ServiceEngine.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.ServiceEngine.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.ServiceEngine.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.ServiceEngine.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.ServiceEngine.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.ServiceEngine.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.ServiceEngine.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.ServiceEngine.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.ServiceEngine.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.ServiceEngine.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.ServiceEngine.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.ServiceEngine.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.ServiceEngine.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.ServiceEngine.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.ServiceEngine.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.ServiceEngine.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.ServiceEngine.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.ServiceEngine.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "Service-Engine" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.ServiceEngine, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.ServiceEngine.Backup.Delay)), ("interface", ("interface", Native.Interface.ServiceEngine.Backup.Interface_)), ("load", ("load", Native.Interface.ServiceEngine.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.ServiceEngine.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.ServiceEngine.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.ServiceEngine.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.ServiceEngine.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.ServiceEngine.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.ServiceEngine.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.ServiceEngine.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.ServiceEngine.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.ServiceEngine.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.ServiceEngine.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.ServiceEngine.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.ServiceEngine.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.ServiceEngine.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.ServiceEngine.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.ServiceEngine.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.ServiceEngine.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.ServiceEngine.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.ServiceEngine.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.ServiceEngine.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.ServiceEngine.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.ServiceEngine.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.ServiceEngine.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.ServiceEngine.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.ServiceEngine.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.ServiceEngine.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.ServiceEngine.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.ServiceEngine.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.ServiceEngine.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.ServiceEngine.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.ServiceEngine.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.ServiceEngine.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.ServiceEngine.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.ServiceEngine.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.ServiceEngine.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.ServiceEngine.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.ServiceEngine.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.ServiceEngine.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.ServiceEngine.Ip.Arp)), ("vrf", ("vrf", Native.Interface.ServiceEngine.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.ServiceEngine.Ip.NoAddress)), ("address", ("address", Native.Interface.ServiceEngine.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.ServiceEngine.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.ServiceEngine.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.ServiceEngine.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.ServiceEngine.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.ServiceEngine.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.ServiceEngine.Ip.Pim)), ("policy", ("policy", Native.Interface.ServiceEngine.Ip.Policy)), ("rip", ("rip", Native.Interface.ServiceEngine.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.ServiceEngine.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.ServiceEngine.Ip.RouteCache)), ("router", ("router", Native.Interface.ServiceEngine.Ip.Router)), ("tcp", ("tcp", Native.Interface.ServiceEngine.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.ServiceEngine.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.ServiceEngine.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.ServiceEngine.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.ServiceEngine.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.ServiceEngine.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.ServiceEngine.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.ServiceEngine.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.ServiceEngine.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.ServiceEngine.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.ServiceEngine.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.ServiceEngine.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.ServiceEngine.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.ServiceEngine.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.ServiceEngine.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.ServiceEngine.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.ServiceEngine.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.ServiceEngine.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.ServiceEngine.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.ServiceEngine.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.ServiceEngine.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.ServiceEngine.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.ServiceEngine.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.ServiceEngine.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.ServiceEngine.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.ServiceEngine.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.ServiceEngine.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.ServiceEngine.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.ServiceEngine.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.ServiceEngine.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.ServiceEngine.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.ServiceEngine.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.ServiceEngine.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.ServiceEngine.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.ServiceEngine.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.ServiceEngine.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.ServiceEngine.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.ServiceEngine.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.ServiceEngine.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.ServiceEngine.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.ServiceEngine.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.ServiceEngine.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.ServiceEngine.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.ServiceEngine.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.ServiceEngine.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.ServiceEngine.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.ServiceEngine.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.ServiceEngine.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.ServiceEngine.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.ServiceEngine.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.ServiceEngine.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.ServiceEngine.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.ServiceEngine.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.ServiceEngine.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.ServiceEngine.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.ServiceEngine.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.ServiceEngine.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.ServiceEngine.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.ServiceEngine.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.ServiceEngine.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.ServiceEngine.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.ServiceEngine.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.ServiceEngine.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ServiceEngine.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ServiceEngine.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.ServiceEngine.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.ServiceEngine.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.ServiceEngine.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.ServiceEngine.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.ServiceEngine.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.ServiceEngine.Ipv6.Dhcp)), ("address", ("address", Native.Interface.ServiceEngine.Ipv6.Address)), ("nd", ("nd", Native.Interface.ServiceEngine.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.ServiceEngine.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.ServiceEngine.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.ServiceEngine.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.ServiceEngine.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.ServiceEngine.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.ServiceEngine.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.ServiceEngine.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.ServiceEngine.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.ServiceEngine.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.ServiceEngine.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.ServiceEngine.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.ServiceEngine.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.ServiceEngine.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.ServiceEngine.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.ServiceEngine.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.ServiceEngine.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.ServiceEngine.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.ServiceEngine.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.ServiceEngine.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.ServiceEngine.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.ServiceEngine.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.ServiceEngine.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.ServiceEngine.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.ServiceEngine.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.ServiceEngine.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.ServiceEngine.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.ServiceEngine.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.ServiceEngine.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.ServiceEngine.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.ServiceEngine.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.ServiceEngine.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.ServiceEngine.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.ServiceEngine.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.ServiceEngine.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.ServiceEngine.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.ServiceEngine.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.ServiceEngine.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.ServiceEngine.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.ServiceEngine.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.ServiceEngine.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.ServiceEngine.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.ServiceEngine.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.ServiceEngine.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.ServiceEngine.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.ServiceEngine.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.ServiceEngine.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.ServiceEngine.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.ServiceEngine.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.ServiceEngine.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.ServiceEngine.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.ServiceEngine.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.ServiceEngine.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.ServiceEngine.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.ServiceEngine.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.ServiceEngine.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.ServiceEngine.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.ServiceEngine.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.ServiceEngine.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.ServiceEngine.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.ServiceEngine.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.ServiceEngine.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.ServiceEngine.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.ServiceEngine.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.ServiceEngine.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.ServiceEngine.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.ServiceEngine.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.ServiceEngine.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.ServiceEngine.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.ServiceEngine.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.ServiceEngine.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.ServiceEngine.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.ServiceEngine.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.ServiceEngine.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.ServiceEngine.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.ServiceEngine.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.ServiceEngine.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.ServiceEngine.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.ServiceEngine.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.ServiceEngine.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.ServiceEngine.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.ServiceEngine.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.ServiceEngine.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.ServiceEngine.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.ServiceEngine.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.ServiceEngine.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.ServiceEngine.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.ServiceEngine.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.ServiceEngine.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.ServiceEngine.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.ServiceEngine.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.ServiceEngine.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ServiceEngine.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ServiceEngine.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.ServiceEngine.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.ServiceEngine.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.ServiceEngine.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Service-Engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.ServiceEngine.PmPath, [u'name', u'interface_id'], name, value)


        class GigabitEthernet(Entity):
            """
            GigabitEthernet IEEE 802.3z
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: media_type
            
            	Media type
            	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.MediaType>`
            
            .. attribute:: port_type
            
            	
            	**type**\:  :py:class:`PortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.PortType>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.PmPath>`
            
            .. attribute:: switchport_wrapper
            
            	
            	**type**\:  :py:class:`SwitchportWrapper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SwitchportWrapper>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service>`
            
            .. attribute:: lacp
            
            	LACP interface subcommands
            	**type**\:  :py:class:`Lacp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Lacp>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec_option
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXEEthernetMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ServicePolicy>`
            
            .. attribute:: auto
            
            	Configure Automation
            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Auto>`
            
            .. attribute:: datalink
            
            	Interface Datalink commands
            	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Datalink>`
            
            .. attribute:: energywise
            
            	EnergyWise interface configurations
            	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Energywise>`
            
            	**presence node**\: True
            
            .. attribute:: location
            
            	Interface location information
            	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Location>`
            
            .. attribute:: mac
            
            	MAC interface commands
            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mac>`
            
            .. attribute:: macro
            
            	Command macro
            	**type**\:  :py:class:`Macro <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Macro>`
            
            .. attribute:: dual_active
            
            	
            	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.DualActive>`
            
            .. attribute:: load_balancing
            
            	Etherchannel Load\-Balancing
            	**type**\:  :py:class:`LoadBalancing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.LoadBalancing>`
            
            .. attribute:: vlan_range
            
            	
            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.VlanRange>`
            
            .. attribute:: switch
            
            	
            	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switch>`
            
            .. attribute:: srr_queue
            
            	
            	**type**\:  :py:class:`SrrQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SrrQueue>`
            
            .. attribute:: cisco_ios_xe_switch_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_switch_macsec_option_
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXESwitchMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption>`
            
            .. attribute:: device_tracking
            
            	Configure device\-tracking on the interface
            	**type**\:  :py:class:`DeviceTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.DeviceTracking>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Snmp>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Crypto>`
            
            .. attribute:: mka
            
            	MACsec Key Agreement (MKA) interface configuration
            	**type**\:  :py:class:`Mka <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mka>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Utd>`
            
            .. attribute:: xconnect
            
            	Xconnect commands
            	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Xconnect>`
            
            .. attribute:: evpn
            
            	
            	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Evpn>`
            
            .. attribute:: fabric_domain
            
            	Fabric\-domain interface command
            	**type**\:  :py:class:`FabricDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.FabricDomain>`
            
            .. attribute:: mvrp
            
            	
            	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mvrp>`
            
            	**presence node**\: True
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Lisp>`
            
            .. attribute:: power
            
            	
            	**type**\:  :py:class:`Power <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Power>`
            
            .. attribute:: cdp
            
            	CDP interface subcommands
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cdp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ntp>`
            
            .. attribute:: authentication
            
            	Auth Manager Interface Configuration Commands
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication>`
            
            .. attribute:: mab
            
            	
            	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mab>`
            
            	**presence node**\: True
            
            .. attribute:: dot1x
            
            	Interface Config Commands for IEEE 802.1X
            	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Dot1x>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SpanningTree>`
            
            .. attribute:: performance
            
            	Global performance monitor configuration
            	**type**\:  :py:class:`Performance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Performance>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Umbrella>`
            
            .. attribute:: lldp
            
            	LLDP interface subcommands
            	**type**\:  :py:class:`Lldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Lldp>`
            
            .. attribute:: vrrp
            
            	Configure VRRP
            	**type**\:  :py:class:`Vrrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp>`
            
            .. attribute:: nat66
            
            	NAT66 interface commands
            	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Nat66>`
            
            .. attribute:: ospfv3
            
            	OSPFv3 interface commands
            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3>`
            
            .. attribute:: udld
            
            	Configure UDLD enabled or disabled and ignore global UDLD setting
            	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Udld>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts>`
            
            .. attribute:: analysis_module
            
            	Configure NAM on the interface
            	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.AnalysisModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.GigabitEthernet, self).__init__()

                self.yang_name = "GigabitEthernet"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.GigabitEthernet.SwitchportConf)), ("switchport", ("switchport", Native.Interface.GigabitEthernet.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.GigabitEthernet.StackwiseVirtual)), ("arp", ("arp", Native.Interface.GigabitEthernet.Arp)), ("backup", ("backup", Native.Interface.GigabitEthernet.Backup)), ("cemoudp", ("cemoudp", Native.Interface.GigabitEthernet.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.GigabitEthernet.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.GigabitEthernet.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.GigabitEthernet.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.GigabitEthernet.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.GigabitEthernet.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.GigabitEthernet.Flowcontrol)), ("isis", ("isis", Native.Interface.GigabitEthernet.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.GigabitEthernet.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.GigabitEthernet.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.GigabitEthernet.Bandwidth)), ("dampening", ("dampening", Native.Interface.GigabitEthernet.Dampening)), ("domain", ("domain", Native.Interface.GigabitEthernet.Domain)), ("hold-queue", ("hold_queue", Native.Interface.GigabitEthernet.HoldQueue)), ("mpls", ("mpls", Native.Interface.GigabitEthernet.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.GigabitEthernet.IpVrf)), ("vrf", ("vrf", Native.Interface.GigabitEthernet.Vrf)), ("ip", ("ip", Native.Interface.GigabitEthernet.Ip)), ("ipv6", ("ipv6", Native.Interface.GigabitEthernet.Ipv6)), ("logging", ("logging", Native.Interface.GigabitEthernet.Logging)), ("mdix", ("mdix", Native.Interface.GigabitEthernet.Mdix)), ("mop", ("mop", Native.Interface.GigabitEthernet.Mop)), ("interface_qos", ("interface_qos", Native.Interface.GigabitEthernet.InterfaceQos)), ("source", ("source", Native.Interface.GigabitEthernet.Source)), ("standby", ("standby", Native.Interface.GigabitEthernet.Standby)), ("access-session", ("access_session", Native.Interface.GigabitEthernet.AccessSession)), ("storm-control", ("storm_control", Native.Interface.GigabitEthernet.StormControl)), ("trust", ("trust", Native.Interface.GigabitEthernet.Trust)), ("priority-queue", ("priority_queue", Native.Interface.GigabitEthernet.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.GigabitEthernet.RcvQueue)), ("peer", ("peer", Native.Interface.GigabitEthernet.Peer)), ("pm-path", ("pm_path", Native.Interface.GigabitEthernet.PmPath)), ("switchport-wrapper", ("switchport_wrapper", Native.Interface.GigabitEthernet.SwitchportWrapper)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.GigabitEthernet.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.GigabitEthernet.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.GigabitEthernet.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.GigabitEthernet.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.GigabitEthernet.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.GigabitEthernet.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.GigabitEthernet.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.GigabitEthernet.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.GigabitEthernet.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.GigabitEthernet.Service)), ("Cisco-IOS-XE-ethernet:lacp", ("lacp", Native.Interface.GigabitEthernet.Lacp)), ("Cisco-IOS-XE-ethernet:macsec-option", ("cisco_ios_xe_ethernet_macsec_option", Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.GigabitEthernet.ServicePolicy)), ("Cisco-IOS-XE-switch:auto", ("auto", Native.Interface.GigabitEthernet.Auto)), ("Cisco-IOS-XE-switch:datalink", ("datalink", Native.Interface.GigabitEthernet.Datalink)), ("Cisco-IOS-XE-switch:energywise", ("energywise", Native.Interface.GigabitEthernet.Energywise)), ("Cisco-IOS-XE-switch:location", ("location", Native.Interface.GigabitEthernet.Location)), ("Cisco-IOS-XE-switch:mac", ("mac", Native.Interface.GigabitEthernet.Mac)), ("Cisco-IOS-XE-switch:macro", ("macro", Native.Interface.GigabitEthernet.Macro)), ("Cisco-IOS-XE-switch:dual-active", ("dual_active", Native.Interface.GigabitEthernet.DualActive)), ("Cisco-IOS-XE-switch:load-balancing", ("load_balancing", Native.Interface.GigabitEthernet.LoadBalancing)), ("Cisco-IOS-XE-switch:vlan-range", ("vlan_range", Native.Interface.GigabitEthernet.VlanRange)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Interface.GigabitEthernet.Switch)), ("Cisco-IOS-XE-switch:srr-queue", ("srr_queue", Native.Interface.GigabitEthernet.SrrQueue)), ("Cisco-IOS-XE-switch:macsec-option", ("cisco_ios_xe_switch_macsec_option_", Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption)), ("Cisco-IOS-XE-switch:device-tracking", ("device_tracking", Native.Interface.GigabitEthernet.DeviceTracking)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.GigabitEthernet.Snmp)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.GigabitEthernet.Crypto)), ("Cisco-IOS-XE-mka:mka", ("mka", Native.Interface.GigabitEthernet.Mka)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.GigabitEthernet.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.GigabitEthernet.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.GigabitEthernet.Utd)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.GigabitEthernet.Xconnect)), ("Cisco-IOS-XE-l2vpn:evpn", ("evpn", Native.Interface.GigabitEthernet.Evpn)), ("Cisco-IOS-XE-iwanfabric:fabric-domain", ("fabric_domain", Native.Interface.GigabitEthernet.FabricDomain)), ("Cisco-IOS-XE-mvrp:mvrp", ("mvrp", Native.Interface.GigabitEthernet.Mvrp)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.GigabitEthernet.Lisp)), ("Cisco-IOS-XE-power:power", ("power", Native.Interface.GigabitEthernet.Power)), ("Cisco-IOS-XE-cdp:cdp", ("cdp", Native.Interface.GigabitEthernet.Cdp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.GigabitEthernet.Ntp)), ("Cisco-IOS-XE-sanet:authentication", ("authentication", Native.Interface.GigabitEthernet.Authentication)), ("Cisco-IOS-XE-sanet:mab", ("mab", Native.Interface.GigabitEthernet.Mab)), ("Cisco-IOS-XE-dot1x:dot1x", ("dot1x", Native.Interface.GigabitEthernet.Dot1x)), ("Cisco-IOS-XE-spanning-tree:spanning-tree", ("spanning_tree", Native.Interface.GigabitEthernet.SpanningTree)), ("Cisco-IOS-XE-ezpm:performance", ("performance", Native.Interface.GigabitEthernet.Performance)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.GigabitEthernet.Umbrella)), ("Cisco-IOS-XE-lldp:lldp", ("lldp", Native.Interface.GigabitEthernet.Lldp)), ("Cisco-IOS-XE-vrrp:vrrp", ("vrrp", Native.Interface.GigabitEthernet.Vrrp)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Interface.GigabitEthernet.Ospfv3)), ("Cisco-IOS-XE-udld:udld", ("udld", Native.Interface.GigabitEthernet.Udld)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.GigabitEthernet.Cts)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Interface.GigabitEthernet.AnalysisModule))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('media_type', (YLeaf(YType.enumeration, 'media-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.MediaType')])),
                    ('port_type', (YLeaf(YType.enumeration, 'port-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.PortType')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Duplex')])),
                    ('cisco_ios_xe_ethernet_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-ethernet:macsec'), ['Empty'])),
                    ('cisco_ios_xe_switch_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:macsec'), ['Empty'])),
                    ('nat66', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-nat:nat66'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Nat66')])),
                ])
                self.name = None
                self.media_type = None
                self.port_type = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None
                self.cisco_ios_xe_ethernet_macsec = None
                self.cisco_ios_xe_switch_macsec = None
                self.nat66 = None

                self.switchport_conf = Native.Interface.GigabitEthernet.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.GigabitEthernet.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.GigabitEthernet.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.GigabitEthernet.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.GigabitEthernet.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.GigabitEthernet.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.GigabitEthernet.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.GigabitEthernet.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.GigabitEthernet.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.GigabitEthernet.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.GigabitEthernet.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.GigabitEthernet.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.GigabitEthernet.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.GigabitEthernet.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.GigabitEthernet.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.GigabitEthernet.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.GigabitEthernet.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.GigabitEthernet.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.GigabitEthernet.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.GigabitEthernet.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.GigabitEthernet.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.GigabitEthernet.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.GigabitEthernet.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.GigabitEthernet.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.GigabitEthernet.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.GigabitEthernet.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.GigabitEthernet.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.GigabitEthernet.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.GigabitEthernet.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.GigabitEthernet.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.GigabitEthernet.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.GigabitEthernet.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.GigabitEthernet.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.GigabitEthernet.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.GigabitEthernet.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.switchport_wrapper = Native.Interface.GigabitEthernet.SwitchportWrapper()
                self.switchport_wrapper.parent = self
                self._children_name_map["switchport_wrapper"] = "switchport-wrapper"

                self.carrier_delay = Native.Interface.GigabitEthernet.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.GigabitEthernet.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.GigabitEthernet.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.GigabitEthernet.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.GigabitEthernet.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.GigabitEthernet.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.GigabitEthernet.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.GigabitEthernet.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.GigabitEthernet.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.GigabitEthernet.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.lacp = Native.Interface.GigabitEthernet.Lacp()
                self.lacp.parent = self
                self._children_name_map["lacp"] = "Cisco-IOS-XE-ethernet:lacp"

                self.cisco_ios_xe_ethernet_macsec_option = Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption()
                self.cisco_ios_xe_ethernet_macsec_option.parent = self
                self._children_name_map["cisco_ios_xe_ethernet_macsec_option"] = "Cisco-IOS-XE-ethernet:macsec-option"

                self.service_policy = Native.Interface.GigabitEthernet.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.auto = Native.Interface.GigabitEthernet.Auto()
                self.auto.parent = self
                self._children_name_map["auto"] = "Cisco-IOS-XE-switch:auto"

                self.datalink = Native.Interface.GigabitEthernet.Datalink()
                self.datalink.parent = self
                self._children_name_map["datalink"] = "Cisco-IOS-XE-switch:datalink"

                self.energywise = None
                self._children_name_map["energywise"] = "Cisco-IOS-XE-switch:energywise"

                self.location = Native.Interface.GigabitEthernet.Location()
                self.location.parent = self
                self._children_name_map["location"] = "Cisco-IOS-XE-switch:location"

                self.mac = Native.Interface.GigabitEthernet.Mac()
                self.mac.parent = self
                self._children_name_map["mac"] = "Cisco-IOS-XE-switch:mac"

                self.macro = Native.Interface.GigabitEthernet.Macro()
                self.macro.parent = self
                self._children_name_map["macro"] = "Cisco-IOS-XE-switch:macro"

                self.dual_active = Native.Interface.GigabitEthernet.DualActive()
                self.dual_active.parent = self
                self._children_name_map["dual_active"] = "Cisco-IOS-XE-switch:dual-active"

                self.load_balancing = Native.Interface.GigabitEthernet.LoadBalancing()
                self.load_balancing.parent = self
                self._children_name_map["load_balancing"] = "Cisco-IOS-XE-switch:load-balancing"

                self.switch = Native.Interface.GigabitEthernet.Switch()
                self.switch.parent = self
                self._children_name_map["switch"] = "Cisco-IOS-XE-switch:switch"

                self.srr_queue = Native.Interface.GigabitEthernet.SrrQueue()
                self.srr_queue.parent = self
                self._children_name_map["srr_queue"] = "Cisco-IOS-XE-switch:srr-queue"

                self.cisco_ios_xe_switch_macsec_option_ = Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption()
                self.cisco_ios_xe_switch_macsec_option_.parent = self
                self._children_name_map["cisco_ios_xe_switch_macsec_option_"] = "Cisco-IOS-XE-switch:macsec-option"

                self.device_tracking = Native.Interface.GigabitEthernet.DeviceTracking()
                self.device_tracking.parent = self
                self._children_name_map["device_tracking"] = "Cisco-IOS-XE-switch:device-tracking"

                self.snmp = Native.Interface.GigabitEthernet.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.crypto = Native.Interface.GigabitEthernet.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.mka = Native.Interface.GigabitEthernet.Mka()
                self.mka.parent = self
                self._children_name_map["mka"] = "Cisco-IOS-XE-mka:mka"

                self.et_analytics = Native.Interface.GigabitEthernet.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.GigabitEthernet.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.GigabitEthernet.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.xconnect = Native.Interface.GigabitEthernet.Xconnect()
                self.xconnect.parent = self
                self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                self.evpn = Native.Interface.GigabitEthernet.Evpn()
                self.evpn.parent = self
                self._children_name_map["evpn"] = "Cisco-IOS-XE-l2vpn:evpn"

                self.fabric_domain = Native.Interface.GigabitEthernet.FabricDomain()
                self.fabric_domain.parent = self
                self._children_name_map["fabric_domain"] = "Cisco-IOS-XE-iwanfabric:fabric-domain"

                self.mvrp = None
                self._children_name_map["mvrp"] = "Cisco-IOS-XE-mvrp:mvrp"

                self.lisp = Native.Interface.GigabitEthernet.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.power = Native.Interface.GigabitEthernet.Power()
                self.power.parent = self
                self._children_name_map["power"] = "Cisco-IOS-XE-power:power"

                self.cdp = Native.Interface.GigabitEthernet.Cdp()
                self.cdp.parent = self
                self._children_name_map["cdp"] = "Cisco-IOS-XE-cdp:cdp"

                self.ntp = Native.Interface.GigabitEthernet.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.authentication = Native.Interface.GigabitEthernet.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "Cisco-IOS-XE-sanet:authentication"

                self.mab = None
                self._children_name_map["mab"] = "Cisco-IOS-XE-sanet:mab"

                self.dot1x = Native.Interface.GigabitEthernet.Dot1x()
                self.dot1x.parent = self
                self._children_name_map["dot1x"] = "Cisco-IOS-XE-dot1x:dot1x"

                self.spanning_tree = Native.Interface.GigabitEthernet.SpanningTree()
                self.spanning_tree.parent = self
                self._children_name_map["spanning_tree"] = "Cisco-IOS-XE-spanning-tree:spanning-tree"

                self.performance = Native.Interface.GigabitEthernet.Performance()
                self.performance.parent = self
                self._children_name_map["performance"] = "Cisco-IOS-XE-ezpm:performance"

                self.umbrella = Native.Interface.GigabitEthernet.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.lldp = Native.Interface.GigabitEthernet.Lldp()
                self.lldp.parent = self
                self._children_name_map["lldp"] = "Cisco-IOS-XE-lldp:lldp"

                self.vrrp = Native.Interface.GigabitEthernet.Vrrp()
                self.vrrp.parent = self
                self._children_name_map["vrrp"] = "Cisco-IOS-XE-vrrp:vrrp"

                self.ospfv3 = Native.Interface.GigabitEthernet.Ospfv3()
                self.ospfv3.parent = self
                self._children_name_map["ospfv3"] = "Cisco-IOS-XE-ospfv3:ospfv3"

                self.udld = Native.Interface.GigabitEthernet.Udld()
                self.udld.parent = self
                self._children_name_map["udld"] = "Cisco-IOS-XE-udld:udld"

                self.cts = Native.Interface.GigabitEthernet.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.analysis_module = Native.Interface.GigabitEthernet.AnalysisModule()
                self.analysis_module.parent = self
                self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"

                self.hold_queue = YList(self)
                self.vlan_range = YList(self)
                self._segment_path = lambda: "GigabitEthernet" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.GigabitEthernet, [u'name', u'media_type', u'port_type', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex', 'cisco_ios_xe_ethernet_macsec', u'cisco_ios_xe_switch_macsec', 'nat66'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class MediaType(Enum):
                """
                MediaType (Enum Class)

                Media type

                .. data:: auto_select = 0

                .. data:: rj45 = 1

                .. data:: sfp = 2

                """

                auto_select = Enum.YLeaf(0, "auto-select")

                rj45 = Enum.YLeaf(1, "rj45")

                sfp = Enum.YLeaf(2, "sfp")


            class Nat66(Enum):
                """
                Nat66 (Enum Class)

                NAT66 interface commands

                .. data:: inside = 0

                .. data:: outside = 1

                """

                inside = Enum.YLeaf(0, "inside")

                outside = Enum.YLeaf(1, "outside")


            class PortType(Enum):
                """
                PortType (Enum Class)

                .. data:: nni = 0

                """

                nni = Enum.YLeaf(0, "nni")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Access>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Block>`
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: trunk
                
                	Set trunking characteristics of the interface
                	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Trunk>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Voice>`
                
                .. attribute:: priority
                
                	Set appliance 802.1p priority
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Priority>`
                
                .. attribute:: autostate
                
                	Include or exclude this port from vlan link up calculation
                	**type**\:  :py:class:`Autostate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Autostate>`
                
                .. attribute:: protected
                
                	Configure an interface to be a protected port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Set port host
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: private_vlan
                
                	Set the private VLAN configuration
                	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PrivateVlan>`
                
                .. attribute:: vepa
                
                	Reflective relay configuration
                	**type**\:  :py:class:`Vepa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Vepa>`
                
                .. attribute:: device_tracking
                
                	Configure device\-tracking on the interface
                	**type**\:  :py:class:`DeviceTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.DeviceTracking>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:access", ("access", Native.Interface.GigabitEthernet.Switchport.Access)), ("Cisco-IOS-XE-switch:block", ("block", Native.Interface.GigabitEthernet.Switchport.Block)), ("Cisco-IOS-XE-switch:mode", ("mode", Native.Interface.GigabitEthernet.Switchport.Mode)), ("Cisco-IOS-XE-switch:port-security", ("port_security", Native.Interface.GigabitEthernet.Switchport.PortSecurity)), ("Cisco-IOS-XE-switch:trunk", ("trunk", Native.Interface.GigabitEthernet.Switchport.Trunk)), ("Cisco-IOS-XE-switch:voice", ("voice", Native.Interface.GigabitEthernet.Switchport.Voice)), ("Cisco-IOS-XE-switch:priority", ("priority", Native.Interface.GigabitEthernet.Switchport.Priority)), ("Cisco-IOS-XE-switch:autostate", ("autostate", Native.Interface.GigabitEthernet.Switchport.Autostate)), ("Cisco-IOS-XE-switch:private-vlan", ("private_vlan", Native.Interface.GigabitEthernet.Switchport.PrivateVlan)), ("Cisco-IOS-XE-switch:vepa", ("vepa", Native.Interface.GigabitEthernet.Switchport.Vepa)), ("Cisco-IOS-XE-switch:device-tracking", ("device_tracking", Native.Interface.GigabitEthernet.Switchport.DeviceTracking))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:nonegotiate'), ['Empty'])),
                        ('protected', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:protected'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:host'), ['Empty'])),
                    ])
                    self.nonegotiate = None
                    self.protected = None
                    self.host = None

                    self.access = Native.Interface.GigabitEthernet.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "Cisco-IOS-XE-switch:access"

                    self.block = Native.Interface.GigabitEthernet.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "Cisco-IOS-XE-switch:block"

                    self.mode = Native.Interface.GigabitEthernet.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "Cisco-IOS-XE-switch:mode"

                    self.port_security = None
                    self._children_name_map["port_security"] = "Cisco-IOS-XE-switch:port-security"

                    self.trunk = Native.Interface.GigabitEthernet.Switchport.Trunk()
                    self.trunk.parent = self
                    self._children_name_map["trunk"] = "Cisco-IOS-XE-switch:trunk"

                    self.voice = Native.Interface.GigabitEthernet.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "Cisco-IOS-XE-switch:voice"

                    self.priority = Native.Interface.GigabitEthernet.Switchport.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-switch:priority"

                    self.autostate = Native.Interface.GigabitEthernet.Switchport.Autostate()
                    self.autostate.parent = self
                    self._children_name_map["autostate"] = "Cisco-IOS-XE-switch:autostate"

                    self.private_vlan = Native.Interface.GigabitEthernet.Switchport.PrivateVlan()
                    self.private_vlan.parent = self
                    self._children_name_map["private_vlan"] = "Cisco-IOS-XE-switch:private-vlan"

                    self.vepa = Native.Interface.GigabitEthernet.Switchport.Vepa()
                    self.vepa.parent = self
                    self._children_name_map["vepa"] = "Cisco-IOS-XE-switch:vepa"

                    self.device_tracking = Native.Interface.GigabitEthernet.Switchport.DeviceTracking()
                    self.device_tracking.parent = self
                    self._children_name_map["device_tracking"] = "Cisco-IOS-XE-switch:device-tracking"
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Switchport, [u'nonegotiate', u'protected', u'host'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	Set VLAN when interface is in access mode
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Access.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.GigabitEthernet.Switchport.Access.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.GigabitEthernet.Switchport.Access.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:access"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Access, [], name, value)


                    class Vlan(Entity):
                        """
                        Set VLAN when interface is in access mode
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_>`
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.Access.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "access"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Access.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dynamic = 0

                            """

                            dynamic = Enum.YLeaf(0, "dynamic")



                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: multicast
                    
                    	Block unknown multicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.multicast = None
                        self.unicast = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:block"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Block, [u'multicast', u'unicast'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Mode.Access>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dot1q_tunnel
                    
                    	set trunking mode to TUNNEL unconditionally
                    	**type**\:  :py:class:`Dot1qTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Mode.Dot1qTunnel>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dynamic
                    
                    	Set trunking mode to dynamically negotiate access or trunk mode
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Mode.Dynamic>`
                    
                    .. attribute:: private_vlan
                    
                    	Set private\-vlan mode
                    	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Mode.PrivateVlan>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Mode.Trunk>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.GigabitEthernet.Switchport.Mode.Access)), ("dot1q-tunnel", ("dot1q_tunnel", Native.Interface.GigabitEthernet.Switchport.Mode.Dot1qTunnel)), ("private-vlan", ("private_vlan", Native.Interface.GigabitEthernet.Switchport.Mode.PrivateVlan)), ("trunk", ("trunk", Native.Interface.GigabitEthernet.Switchport.Mode.Trunk))])
                        self._leafs = OrderedDict([
                            ('dynamic', (YLeaf(YType.enumeration, 'dynamic'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Switchport.Mode.Dynamic')])),
                        ])
                        self.dynamic = None

                        self.access = None
                        self._children_name_map["access"] = "access"

                        self.dot1q_tunnel = None
                        self._children_name_map["dot1q_tunnel"] = "dot1q-tunnel"

                        self.private_vlan = Native.Interface.GigabitEthernet.Switchport.Mode.PrivateVlan()
                        self.private_vlan.parent = self
                        self._children_name_map["private_vlan"] = "private-vlan"

                        self.trunk = None
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Mode, [u'dynamic'], name, value)

                    class Dynamic(Enum):
                        """
                        Dynamic (Enum Class)

                        Set trunking mode to dynamically negotiate access or trunk mode

                        .. data:: auto = 0

                        .. data:: desirable = 1

                        """

                        auto = Enum.YLeaf(0, "auto")

                        desirable = Enum.YLeaf(1, "desirable")



                    class Access(Entity):
                        """
                        Set trunking mode to ACCESS unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.Mode.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "access"
                            self._is_frozen = True


                    class Dot1qTunnel(Entity):
                        """
                        set trunking mode to TUNNEL unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.Mode.Dot1qTunnel, self).__init__()

                            self.yang_name = "dot1q-tunnel"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dot1q-tunnel"
                            self._is_frozen = True


                    class PrivateVlan(Entity):
                        """
                        Set private\-vlan mode
                        
                        .. attribute:: host
                        
                        	Set the mode to private\-vlan host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: promiscuous
                        
                        	Set the mode to private\-vlan promiscuous
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.Mode.PrivateVlan, self).__init__()

                            self.yang_name = "private-vlan"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('promiscuous', (YLeaf(YType.empty, 'promiscuous'), ['Empty'])),
                            ])
                            self.host = None
                            self.promiscuous = None
                            self._segment_path = lambda: "private-vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Mode.PrivateVlan, [u'host', u'promiscuous'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking mode to TRUNK unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.Mode.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: mac_address
                    
                    	Secure mac address
                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PortSecurity.MacAddress>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Interface.GigabitEthernet.Switchport.PortSecurity.Aging)), ("mac-address", ("mac_address", Native.Interface.GigabitEthernet.Switchport.PortSecurity.MacAddress)), ("maximum", ("maximum", Native.Interface.GigabitEthernet.Switchport.PortSecurity.Maximum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Switchport.PortSecurity.Violation')])),
                        ])
                        self.violation = None

                        self.aging = Native.Interface.GigabitEthernet.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.mac_address = Native.Interface.GigabitEthernet.Switchport.PortSecurity.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"

                        self.maximum = Native.Interface.GigabitEthernet.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:port-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.PortSecurity, [u'violation'], name, value)

                    class Violation(Enum):
                        """
                        Violation (Enum Class)

                        Security violation mode

                        .. data:: protect = 0

                        .. data:: restrict = 1

                        .. data:: shutdown = 2

                        """

                        protect = Enum.YLeaf(0, "protect")

                        restrict = Enum.YLeaf(1, "restrict")

                        shutdown = Enum.YLeaf(2, "shutdown")



                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PortSecurity.Aging.Type>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Switchport.PortSecurity.Aging.Type')])),
                            ])
                            self.static = None
                            self.time = None
                            self.type = None
                            self._segment_path = lambda: "aging"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.PortSecurity.Aging, [u'static', u'time', u'type'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Port\-security aging type

                            .. data:: absolute = 0

                            .. data:: inactivity = 1

                            """

                            absolute = Enum.YLeaf(0, "absolute")

                            inactivity = Enum.YLeaf(1, "inactivity")



                    class MacAddress(Entity):
                        """
                        Secure mac address
                        
                        .. attribute:: sticky
                        
                        	Configure dynamic secure addresses as sticky
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hw_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: vlan
                        
                        	set VLAN ID of the VLAN on which this address can be learned
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.PortSecurity.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                ('hw_address', (YLeaf(YType.str, 'hw-address'), ['str'])),
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.sticky = None
                            self.hw_address = None
                            self.vlan = None
                            self._segment_path = lambda: "mac-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.PortSecurity.MacAddress, [u'sticky', u'hw_address', u'vlan'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: max_addresses
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4097
                        
                        .. attribute:: vlan
                        
                        	Max secure addresses per vlan
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_addresses', (YLeaf(YType.uint16, 'max-addresses'), ['int'])),
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['str'])),
                            ])
                            self.max_addresses = None
                            self.vlan = None
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.PortSecurity.Maximum, [u'max_addresses', u'vlan'], name, value)


                class Trunk(Entity):
                    """
                    Set trunking characteristics of the interface
                    
                    .. attribute:: allowed
                    
                    	Set allowed VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Trunk.Allowed>`
                    
                    .. attribute:: encapsulation
                    
                    	Set encapsulation format on trunk port
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Trunk.Encapsulation>`
                    
                    .. attribute:: native
                    
                    	Set trunking native characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Trunk.Native_>`
                    
                    .. attribute:: pruning
                    
                    	Set pruning VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Pruning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Trunk.Pruning>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switchport.Trunk, self).__init__()

                        self.yang_name = "trunk"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.GigabitEthernet.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.GigabitEthernet.Switchport.Trunk.Native_)), ("pruning", ("pruning", Native.Interface.GigabitEthernet.Switchport.Trunk.Pruning))])
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Switchport.Trunk.Encapsulation')])),
                        ])
                        self.encapsulation = None

                        self.allowed = Native.Interface.GigabitEthernet.Switchport.Trunk.Allowed()
                        self.allowed.parent = self
                        self._children_name_map["allowed"] = "allowed"

                        self.native = Native.Interface.GigabitEthernet.Switchport.Trunk.Native_()
                        self.native.parent = self
                        self._children_name_map["native"] = "native"

                        self.pruning = Native.Interface.GigabitEthernet.Switchport.Trunk.Pruning()
                        self.pruning.parent = self
                        self._children_name_map["pruning"] = "pruning"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:trunk"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Trunk, [u'encapsulation'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Set encapsulation format on trunk port

                        .. data:: dot1q = 0

                        .. data:: isl = 1

                        .. data:: negotiate = 2

                        """

                        dot1q = Enum.YLeaf(0, "dot1q")

                        isl = Enum.YLeaf(1, "isl")

                        negotiate = Enum.YLeaf(2, "negotiate")



                    class Allowed(Entity):
                        """
                        Set allowed VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set allowed VLANs when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Trunk.Allowed.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.Trunk.Allowed, self).__init__()

                            self.yang_name = "allowed"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.GigabitEthernet.Switchport.Trunk.Allowed.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.GigabitEthernet.Switchport.Trunk.Allowed.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "allowed"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Trunk.Allowed, [], name, value)


                        class Vlan(Entity):
                            """
                            Set allowed VLANs when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: all
                            
                            	all VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "allowed"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = None
                                self.add = None
                                self.all = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                    class Native_(Entity):
                        """
                        Set trunking native characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set native VLAN when interface is in trunking mode
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.Trunk.Native_, self).__init__()

                            self.yang_name = "native"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan'),'int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "native"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Trunk.Native_, [u'vlan'], name, value)

                        class Vlan(Enum):
                            """
                            Vlan (Enum Class)

                            Set native VLAN when interface is in trunking mode

                            .. data:: tag = 0

                            """

                            tag = Enum.YLeaf(0, "tag")



                    class Pruning(Entity):
                        """
                        Set pruning VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set VLANs enabled for pruning when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Trunk.Pruning.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.Trunk.Pruning, self).__init__()

                            self.yang_name = "pruning"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.GigabitEthernet.Switchport.Trunk.Pruning.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.GigabitEthernet.Switchport.Trunk.Pruning.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "pruning"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Trunk.Pruning, [], name, value)


                        class Vlan(Entity):
                            """
                            Set VLANs enabled for pruning when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Switchport.Trunk.Pruning.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "pruning"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeafList(YType.str, 'vlans'), ['int','str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = []
                                self.add = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Trunk.Pruning.Vlan, [u'vlans', u'add', u'except_', u'none', u'remove'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Voice.Vlan>`
                    
                    .. attribute:: detect
                    
                    	detection enhancement keyword
                    	**type**\:  :py:class:`Detect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Voice.Detect>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.GigabitEthernet.Switchport.Voice.Vlan)), ("detect", ("detect", Native.Interface.GigabitEthernet.Switchport.Voice.Detect))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.GigabitEthernet.Switchport.Voice.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"

                        self.detect = Native.Interface.GigabitEthernet.Switchport.Voice.Detect()
                        self.detect.parent = self
                        self._children_name_map["detect"] = "detect"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:voice"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Voice, [], name, value)


                    class Vlan(Entity):
                        """
                        Vlan for voice traffic
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\: str
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.Voice.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_'),'int','str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Voice.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dot1p = 0

                            .. data:: none = 1

                            .. data:: untagged = 2

                            """

                            dot1p = Enum.YLeaf(0, "dot1p")

                            none = Enum.YLeaf(1, "none")

                            untagged = Enum.YLeaf(2, "untagged")



                    class Detect(Entity):
                        """
                        detection enhancement keyword
                        
                        .. attribute:: cisco_phone
                        
                        	Cisco IP phone
                        	**type**\:  :py:class:`CiscoPhone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Voice.Detect.CiscoPhone>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.Voice.Detect, self).__init__()

                            self.yang_name = "detect"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cisco-phone", ("cisco_phone", Native.Interface.GigabitEthernet.Switchport.Voice.Detect.CiscoPhone))])
                            self._leafs = OrderedDict()

                            self.cisco_phone = None
                            self._children_name_map["cisco_phone"] = "cisco-phone"
                            self._segment_path = lambda: "detect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Voice.Detect, [], name, value)


                        class CiscoPhone(Entity):
                            """
                            Cisco IP phone
                            
                            .. attribute:: full_duplex
                            
                            	full duplex keyword
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Switchport.Voice.Detect.CiscoPhone, self).__init__()

                                self.yang_name = "cisco-phone"
                                self.yang_parent_name = "detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('full_duplex', (YLeaf(YType.empty, 'full-duplex'), ['Empty'])),
                                ])
                                self.full_duplex = None
                                self._segment_path = lambda: "cisco-phone"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Voice.Detect.CiscoPhone, [u'full_duplex'], name, value)


                class Priority(Entity):
                    """
                    Set appliance 802.1p priority
                    
                    .. attribute:: extend
                    
                    	Set appliance 802.1p priority
                    	**type**\:  :py:class:`Extend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.Priority.Extend>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switchport.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("extend", ("extend", Native.Interface.GigabitEthernet.Switchport.Priority.Extend))])
                        self._leafs = OrderedDict()

                        self.extend = Native.Interface.GigabitEthernet.Switchport.Priority.Extend()
                        self.extend.parent = self
                        self._children_name_map["extend"] = "extend"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Priority, [], name, value)


                    class Extend(Entity):
                        """
                        Set appliance 802.1p priority
                        
                        .. attribute:: trust
                        
                        	Trust 802.1p priorities of devices on appliance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cos
                        
                        	Override 802.1p priority of devices on appliance
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.Priority.Extend, self).__init__()

                            self.yang_name = "extend"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                            ])
                            self.trust = None
                            self.cos = None
                            self._segment_path = lambda: "extend"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Priority.Extend, [u'trust', u'cos'], name, value)


                class Autostate(Entity):
                    """
                    Include or exclude this port from vlan link up calculation
                    
                    .. attribute:: exclude
                    
                    	Exclude this port from vlan link up calculation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switchport.Autostate, self).__init__()

                        self.yang_name = "autostate"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('exclude', (YLeaf(YType.empty, 'exclude'), ['Empty'])),
                        ])
                        self.exclude = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:autostate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Autostate, [u'exclude'], name, value)


                class PrivateVlan(Entity):
                    """
                    Set the private VLAN configuration
                    
                    .. attribute:: association
                    
                    	Set the private VLAN association
                    	**type**\:  :py:class:`Association <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association>`
                    
                    .. attribute:: host_association
                    
                    	Set the private VLAN host association
                    	**type**\:  :py:class:`HostAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PrivateVlan.HostAssociation>`
                    
                    .. attribute:: mapping
                    
                    	Set the private VLAN promiscuous mapping
                    	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Mapping>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switchport.PrivateVlan, self).__init__()

                        self.yang_name = "private-vlan"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("association", ("association", Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association)), ("host-association", ("host_association", Native.Interface.GigabitEthernet.Switchport.PrivateVlan.HostAssociation)), ("mapping", ("mapping", Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Mapping))])
                        self._leafs = OrderedDict()

                        self.association = Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association()
                        self.association.parent = self
                        self._children_name_map["association"] = "association"

                        self.host_association = Native.Interface.GigabitEthernet.Switchport.PrivateVlan.HostAssociation()
                        self.host_association.parent = self
                        self._children_name_map["host_association"] = "host-association"

                        self.mapping = Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Mapping()
                        self.mapping.parent = self
                        self._children_name_map["mapping"] = "mapping"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:private-vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.PrivateVlan, [], name, value)


                    class Association(Entity):
                        """
                        Set the private VLAN association
                        
                        .. attribute:: host
                        
                        	Set the private VLAN host association
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association.Host>`
                        
                        .. attribute:: mapping
                        
                        	Set the private VLAN promiscuous mapping
                        	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association.Mapping>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association, self).__init__()

                            self.yang_name = "association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association.Host)), ("mapping", ("mapping", Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association.Mapping))])
                            self._leafs = OrderedDict()

                            self.host = Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.mapping = Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association.Mapping()
                            self.mapping.parent = self
                            self._children_name_map["mapping"] = "mapping"
                            self._segment_path = lambda: "association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association, [], name, value)


                        class Host(Entity):
                            """
                            Set the private VLAN host association
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary normal range VLAN ID of the private VLAN host port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association.Host, [u'primary_range', u'secondary_range'], name, value)


                        class Mapping(Entity):
                            """
                            Set the private VLAN promiscuous mapping
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: remove
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association.Mapping, self).__init__()

                                self.yang_name = "mapping"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self.add = None
                                self.remove = None
                                self._segment_path = lambda: "mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Association.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                    class HostAssociation(Entity):
                        """
                        Set the private VLAN host association
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary normal range VLAN ID of the private VLAN host port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.PrivateVlan.HostAssociation, self).__init__()

                            self.yang_name = "host-association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self._segment_path = lambda: "host-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.PrivateVlan.HostAssociation, [u'primary_range', u'secondary_range'], name, value)


                    class Mapping(Entity):
                        """
                        Set the private VLAN promiscuous mapping
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: add
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: remove
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Mapping, self).__init__()

                            self.yang_name = "mapping"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self.add = None
                            self.remove = None
                            self._segment_path = lambda: "mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.PrivateVlan.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                class Vepa(Entity):
                    """
                    Reflective relay configuration
                    
                    .. attribute:: enabled
                    
                    	Enable reflective relay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switchport.Vepa, self).__init__()

                        self.yang_name = "vepa"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                        ])
                        self.enabled = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:vepa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.Vepa, [u'enabled'], name, value)


                class DeviceTracking(Entity):
                    """
                    Configure device\-tracking on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature device\-tracking
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switchport.DeviceTracking, self).__init__()

                        self.yang_name = "device-tracking"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:device-tracking"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switchport.DeviceTracking, [u'attach_policy'], name, value)


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.GigabitEthernet.Backup.Delay)), ("interface", ("interface", Native.Interface.GigabitEthernet.Backup.Interface_)), ("load", ("load", Native.Interface.GigabitEthernet.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.GigabitEthernet.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.GigabitEthernet.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.GigabitEthernet.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.GigabitEthernet.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.GigabitEthernet.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.GigabitEthernet.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.GigabitEthernet.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.GigabitEthernet.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.GigabitEthernet.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.GigabitEthernet.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.GigabitEthernet.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.GigabitEthernet.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.GigabitEthernet.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.GigabitEthernet.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.GigabitEthernet.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.GigabitEthernet.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.GigabitEthernet.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.GigabitEthernet.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.GigabitEthernet.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.GigabitEthernet.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.GigabitEthernet.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.GigabitEthernet.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.GigabitEthernet.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.GigabitEthernet.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.GigabitEthernet.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.GigabitEthernet.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.GigabitEthernet.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.GigabitEthernet.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.GigabitEthernet.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.GigabitEthernet.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.GigabitEthernet.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.GigabitEthernet.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.GigabitEthernet.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.GigabitEthernet.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.GigabitEthernet.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.GigabitEthernet.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.GigabitEthernet.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.GigabitEthernet.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.GigabitEthernet.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.GigabitEthernet.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.GigabitEthernet.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.GigabitEthernet.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.GigabitEthernet.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.GigabitEthernet.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.GigabitEthernet.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.GigabitEthernet.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.GigabitEthernet.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.GigabitEthernet.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.GigabitEthernet.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.GigabitEthernet.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.GigabitEthernet.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.GigabitEthernet.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.GigabitEthernet.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.GigabitEthernet.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.GigabitEthernet.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.GigabitEthernet.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.GigabitEthernet.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.GigabitEthernet.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.GigabitEthernet.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.GigabitEthernet.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.GigabitEthernet.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.GigabitEthernet.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.GigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.GigabitEthernet.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.GigabitEthernet.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.GigabitEthernet.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.GigabitEthernet.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.GigabitEthernet.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.GigabitEthernet.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.GigabitEthernet.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.GigabitEthernet.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.GigabitEthernet.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.GigabitEthernet.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.GigabitEthernet.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.GigabitEthernet.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.GigabitEthernet.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.GigabitEthernet.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.GigabitEthernet.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.GigabitEthernet.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.GigabitEthernet.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.GigabitEthernet.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.GigabitEthernet.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.GigabitEthernet.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.GigabitEthernet.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.GigabitEthernet.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.GigabitEthernet.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.GigabitEthernet.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.GigabitEthernet.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.GigabitEthernet.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.GigabitEthernet.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.GigabitEthernet.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.GigabitEthernet.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.GigabitEthernet.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.GigabitEthernet.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.GigabitEthernet.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.GigabitEthernet.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.GigabitEthernet.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.GigabitEthernet.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.GigabitEthernet.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.GigabitEthernet.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.GigabitEthernet.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.GigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.GigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.GigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.GigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.GigabitEthernet.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.GigabitEthernet.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.GigabitEthernet.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.GigabitEthernet.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Igmp>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Flow>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Nbar>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf>`
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Lisp>`
                
                .. attribute:: rsvp
                
                	RSVP Interface Commands
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Nat>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.GigabitEthernet.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.GigabitEthernet.Ip.Arp)), ("vrf", ("vrf", Native.Interface.GigabitEthernet.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.GigabitEthernet.Ip.NoAddress)), ("address", ("address", Native.Interface.GigabitEthernet.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.GigabitEthernet.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.GigabitEthernet.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.GigabitEthernet.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.GigabitEthernet.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.GigabitEthernet.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.GigabitEthernet.Ip.Pim)), ("policy", ("policy", Native.Interface.GigabitEthernet.Ip.Policy)), ("rip", ("rip", Native.Interface.GigabitEthernet.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.GigabitEthernet.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.GigabitEthernet.Ip.RouteCache)), ("router", ("router", Native.Interface.GigabitEthernet.Ip.Router)), ("tcp", ("tcp", Native.Interface.GigabitEthernet.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.GigabitEthernet.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.GigabitEthernet.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.GigabitEthernet.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.GigabitEthernet.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.GigabitEthernet.Ip.Igmp)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.GigabitEthernet.Ip.Flow)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.GigabitEthernet.Ip.Nbar)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.GigabitEthernet.Ip.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.GigabitEthernet.Ip.Lisp)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Interface.GigabitEthernet.Ip.Rsvp)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.GigabitEthernet.Ip.Nat)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.GigabitEthernet.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None
                    self.unreachables = None

                    self.access_group = Native.Interface.GigabitEthernet.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.GigabitEthernet.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.GigabitEthernet.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.GigabitEthernet.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.GigabitEthernet.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.GigabitEthernet.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.GigabitEthernet.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.GigabitEthernet.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.GigabitEthernet.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.GigabitEthernet.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.GigabitEthernet.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.GigabitEthernet.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.GigabitEthernet.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.GigabitEthernet.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.GigabitEthernet.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.GigabitEthernet.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.GigabitEthernet.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.GigabitEthernet.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.GigabitEthernet.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.flow = Native.Interface.GigabitEthernet.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.nbar = Native.Interface.GigabitEthernet.Ip.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.ospf = Native.Interface.GigabitEthernet.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.lisp = Native.Interface.GigabitEthernet.Ip.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                    self.rsvp = Native.Interface.GigabitEthernet.Ip.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

                    self.nat = Native.Interface.GigabitEthernet.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.wccp = Native.Interface.GigabitEthernet.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache', 'unreachables'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.GigabitEthernet.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.GigabitEthernet.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.GigabitEthernet.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.GigabitEthernet.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.GigabitEthernet.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.GigabitEthernet.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.GigabitEthernet.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.GigabitEthernet.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.GigabitEthernet.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.GigabitEthernet.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.GigabitEthernet.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.GigabitEthernet.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.GigabitEthernet.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.GigabitEthernet.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.GigabitEthernet.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.GigabitEthernet.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.GigabitEthernet.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.GigabitEthernet.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.GigabitEthernet.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.GigabitEthernet.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.GigabitEthernet.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.GigabitEthernet.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.GigabitEthernet.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.GigabitEthernet.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.GigabitEthernet.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.GigabitEthernet.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.GigabitEthernet.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.GigabitEthernet.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.GigabitEthernet.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.GigabitEthernet.Ip.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ip.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ip.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.GigabitEthernet.Ip.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.GigabitEthernet.Ip.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.GigabitEthernet.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.GigabitEthernet.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.GigabitEthernet.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.GigabitEthernet.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.GigabitEthernet.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.GigabitEthernet.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.GigabitEthernet.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.GigabitEthernet.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.GigabitEthernet.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.GigabitEthernet.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.GigabitEthernet.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.GigabitEthernet.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.GigabitEthernet.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.GigabitEthernet.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.GigabitEthernet.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.GigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.GigabitEthernet.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.GigabitEthernet.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.GigabitEthernet.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.GigabitEthernet.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.GigabitEthernet.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.GigabitEthernet.Ip.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ip.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.GigabitEthernet.Ip.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.GigabitEthernet.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.GigabitEthernet.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.GigabitEthernet.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.GigabitEthernet.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.GigabitEthernet.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.GigabitEthernet.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.GigabitEthernet.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.GigabitEthernet.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.GigabitEthernet.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.GigabitEthernet.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.GigabitEthernet.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.GigabitEthernet.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.GigabitEthernet.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.GigabitEthernet.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.GigabitEthernet.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.GigabitEthernet.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.GigabitEthernet.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.GigabitEthernet.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.GigabitEthernet.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.GigabitEthernet.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.GigabitEthernet.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.GigabitEthernet.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Lisp(Entity):
                    """
                    Locator/ID Separation Protocol
                    
                    .. attribute:: source_locator
                    
                    	Choose IP source address for LISP packets egressing this interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_locator', (YLeaf(YType.str, 'source-locator'), ['str'])),
                        ])
                        self.source_locator = None
                        self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Lisp, ['source_locator'], name, value)


                class Rsvp(Entity):
                    """
                    RSVP Interface Commands
                    
                    .. attribute:: authentication
                    
                    	Enables RSVP neighbor authentication (RFC 2747)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bandwidth
                    
                    	RSVP Reservable Bandwidth (kbps)
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	Select permissible RSVP neighbors
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Neighbor>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: precedence
                    
                    	RSVP precedence setting
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Precedence>`
                    
                    .. attribute:: signalling
                    
                    	RSVP signalling
                    	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling>`
                    
                    .. attribute:: tos
                    
                    	RSVP TOS setting
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Tos>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.GigabitEthernet.Ip.Rsvp.Authentication)), ("bandwidth", ("bandwidth", Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth)), ("neighbor", ("neighbor", Native.Interface.GigabitEthernet.Ip.Rsvp.Neighbor)), ("precedence", ("precedence", Native.Interface.GigabitEthernet.Ip.Rsvp.Precedence)), ("signalling", ("signalling", Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling)), ("tos", ("tos", Native.Interface.GigabitEthernet.Ip.Rsvp.Tos))])
                        self._leafs = OrderedDict()

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.bandwidth = None
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.neighbor = None
                        self._children_name_map["neighbor"] = "neighbor"

                        self.precedence = Native.Interface.GigabitEthernet.Ip.Rsvp.Precedence()
                        self.precedence.parent = self
                        self._children_name_map["precedence"] = "precedence"

                        self.signalling = Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling()
                        self.signalling.parent = self
                        self._children_name_map["signalling"] = "signalling"

                        self.tos = Native.Interface.GigabitEthernet.Ip.Rsvp.Tos()
                        self.tos.parent = self
                        self._children_name_map["tos"] = "tos"
                        self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp, [], name, value)


                    class Authentication(Entity):
                        """
                        Enables RSVP neighbor authentication (RFC 2747)
                        
                        .. attribute:: key
                        
                        	Password (8 to 40 characters, spaces allowed)
                        	**type**\: str
                        
                        .. attribute:: challenge
                        
                        	Perform challenge/response handshake with new neighbor(s)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key_chain
                        
                        	Name of key chain to use (as created by global 'key chain' command)
                        	**type**\: str
                        
                        .. attribute:: lifetime
                        
                        	Maximum lifetime of neighbor authentication state
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Authentication.Lifetime>`
                        
                        .. attribute:: type
                        
                        	Type of authentication algorithm (default = md5)
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Authentication.Type>`
                        
                        .. attribute:: window_size
                        
                        	Maximum number of messages allowed in receive window (default = 1)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Rsvp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Interface.GigabitEthernet.Ip.Rsvp.Authentication.Lifetime))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ip.Rsvp.Authentication.Type')])),
                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                            ])
                            self.key = None
                            self.challenge = None
                            self.key_chain = None
                            self.type = None
                            self.window_size = None

                            self.lifetime = Native.Interface.GigabitEthernet.Ip.Rsvp.Authentication.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Authentication, ['key', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Type of authentication algorithm (default = md5)

                            .. data:: md5 = 0

                            .. data:: sha_1 = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            sha_1 = Enum.YLeaf(1, "sha-1")



                        class Lifetime(Entity):
                            """
                            Maximum lifetime of neighbor authentication state
                            
                            .. attribute:: hh_mm_ss
                            
                            	Lifetime (default = 30 mins) in hh\:mm\:ss format
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ])
                                self.hh_mm_ss = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


                    class Bandwidth(Entity):
                        """
                        RSVP Reservable Bandwidth (kbps)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Value>`
                        
                        .. attribute:: percent
                        
                        	Percentage of interface bandwidth. Values higher than 100 represent overbooking
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: mam
                        
                        	Use bandwidth with MAM model of DSTE
                        	**type**\:  :py:class:`Mam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Mam>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Value)), ("mam", ("mam", Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Mam))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                            ])
                            self.percent = None

                            self.value = Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.mam = Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Mam()
                            self.mam.parent = self
                            self._children_name_map["mam"] = "mam"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth, ['percent'], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	Reservable Bandwidth (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            .. attribute:: sub_pool
                            
                            	Reservable Bandwidth for Tunnel using sub (BC1) pool (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.value = None
                                self.sub_pool = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Value, ['value', 'sub_pool'], name, value)


                        class Mam(Entity):
                            """
                            Use bandwidth with MAM model of DSTE
                            
                            .. attribute:: max_reservable_bw
                            
                            	Maximum Reservable bandwidth for MAM
                            	**type**\:  :py:class:`MaxReservableBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Mam, self).__init__()

                                self.yang_name = "mam"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("max-reservable-bw", ("max_reservable_bw", Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw))])
                                self._leafs = OrderedDict()

                                self.max_reservable_bw = None
                                self._children_name_map["max_reservable_bw"] = "max-reservable-bw"
                                self._segment_path = lambda: "mam"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Mam, [], name, value)


                            class MaxReservableBw(Entity):
                                """
                                Maximum Reservable bandwidth for MAM
                                
                                .. attribute:: value
                                
                                	Reservable Bandwidth (kbps)
                                	**type**\: int
                                
                                	**range:** 1..10000000
                                
                                .. attribute:: bc0
                                
                                	Reservable Bandwidth from global (BC0) pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                .. attribute:: bc1
                                
                                	Reservable Bandwidth from sub pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, self).__init__()

                                    self.yang_name = "max-reservable-bw"
                                    self.yang_parent_name = "mam"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                        ('bc0', (YLeaf(YType.uint32, 'bc0'), ['int'])),
                                        ('bc1', (YLeaf(YType.uint32, 'bc1'), ['int'])),
                                    ])
                                    self.value = None
                                    self.bc0 = None
                                    self.bc1 = None
                                    self._segment_path = lambda: "max-reservable-bw"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, ['value', 'bc0', 'bc1'], name, value)


                    class Neighbor(Entity):
                        """
                        Select permissible RSVP neighbors
                        
                        .. attribute:: acl_number
                        
                        	Access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Rsvp.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                            ])
                            self.acl_number = None
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Neighbor, ['acl_number'], name, value)


                    class Precedence(Entity):
                        """
                        RSVP precedence setting
                        
                        .. attribute:: conform
                        
                        	Precedence for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: exceed
                        
                        	Precedence for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Rsvp.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Precedence, ['conform', 'exceed'], name, value)


                    class Signalling(Entity):
                        """
                        RSVP signalling
                        
                        .. attribute:: dscp
                        
                        	DSCP for RSVP signalling messages
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: fast_local_repair
                        
                        	Fast Local Repair parameters
                        	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair>`
                        
                        .. attribute:: hello
                        
                        	Enable neighbor\-down detection
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling, self).__init__()

                            self.yang_name = "signalling"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.fast_local_repair = Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair()
                            self.fast_local_repair.parent = self
                            self._children_name_map["fast_local_repair"] = "fast-local-repair"

                            self.hello = None
                            self._children_name_map["hello"] = "hello"
                            self._segment_path = lambda: "signalling"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling, ['dscp'], name, value)


                        class FastLocalRepair(Entity):
                            """
                            Fast Local Repair parameters
                            
                            .. attribute:: wait_time
                            
                            	Wait Time for start of Fast Local Repair in msec
                            	**type**\: int
                            
                            	**range:** 0..5000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                                self.yang_name = "fast-local-repair"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint16, 'wait-time'), ['int'])),
                                ])
                                self.wait_time = None
                                self._segment_path = lambda: "fast-local-repair"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair, ['wait_time'], name, value)


                        class Hello(Entity):
                            """
                            Enable neighbor\-down detection
                            
                            .. attribute:: bfd
                            
                            	Configure BFD trigger for MPLS/TE FRR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	DSCP for RSVP Hello messages
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: graceful_restart
                            
                            	Configure RSVP Graceful Restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: refresh
                            
                            	Configure RSVP Hello refresh behavior for Fast\-Reroute
                            	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh>`
                            
                            .. attribute:: reroute
                            
                            	Configure RSVP Hello refresh behavior for Reroute
                            	**type**\:  :py:class:`Reroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh)), ("reroute", ("reroute", Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ('graceful_restart', (YLeaf(YType.empty, 'graceful-restart'), ['Empty'])),
                                ])
                                self.bfd = None
                                self.dscp = None
                                self.graceful_restart = None

                                self.refresh = Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh()
                                self.refresh.parent = self
                                self._children_name_map["refresh"] = "refresh"

                                self.reroute = Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute()
                                self.reroute.parent = self
                                self._children_name_map["reroute"] = "reroute"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello, ['bfd', 'dscp', 'graceful_restart'], name, value)


                            class Refresh(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Fast\-Reroute
                                
                                .. attribute:: interval
                                
                                	Hello interval in msec
                                	**type**\: int
                                
                                	**range:** 10..30000
                                
                                .. attribute:: misses
                                
                                	Number of missed Hello Acks which triggers neighbor down
                                	**type**\: int
                                
                                	**range:** 4..10
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh, self).__init__()

                                    self.yang_name = "refresh"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.misses = None
                                    self._segment_path = lambda: "refresh"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh, ['interval', 'misses'], name, value)


                            class Reroute(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Reroute
                                
                                .. attribute:: dscp
                                
                                	DSCP for RSVP Hello messages
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: refresh
                                
                                	Configure RSVP Reroute Hello refresh behavior
                                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh>`
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute, self).__init__()

                                    self.yang_name = "reroute"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh))])
                                    self._leafs = OrderedDict([
                                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ])
                                    self.dscp = None

                                    self.refresh = Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh()
                                    self.refresh.parent = self
                                    self._children_name_map["refresh"] = "refresh"
                                    self._segment_path = lambda: "reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute, ['dscp'], name, value)


                                class Refresh(Entity):
                                    """
                                    Configure RSVP Reroute Hello refresh behavior
                                    
                                    .. attribute:: interval
                                    
                                    	Hello Reroute interval in msec
                                    	**type**\: int
                                    
                                    	**range:** 1000..30000
                                    
                                    .. attribute:: misses
                                    
                                    	Number of missed Hello Acks which triggers neighbor down
                                    	**type**\: int
                                    
                                    	**range:** 4..10
                                    
                                    

                                    """

                                    _prefix = 'ios-rsvp'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, self).__init__()

                                        self.yang_name = "refresh"
                                        self.yang_parent_name = "reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.misses = None
                                        self._segment_path = lambda: "refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, ['interval', 'misses'], name, value)


                    class Tos(Entity):
                        """
                        RSVP TOS setting
                        
                        .. attribute:: conform
                        
                        	TOS for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: exceed
                        
                        	TOS for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Rsvp.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Rsvp.Tos, ['conform', 'exceed'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.GigabitEthernet.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.GigabitEthernet.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.GigabitEthernet.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.GigabitEthernet.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.GigabitEthernet.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.GigabitEthernet.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.GigabitEthernet.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.GigabitEthernet.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.GigabitEthernet.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.GigabitEthernet.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.GigabitEthernet.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.GigabitEthernet.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.TrafficFilter>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Flow>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Crypto>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Pim>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: rip
                
                	Configure RIP routing protocol
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Rip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.GigabitEthernet.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.GigabitEthernet.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.GigabitEthernet.Ipv6.Dhcp)), ("address", ("address", Native.Interface.GigabitEthernet.Ipv6.Address)), ("nd", ("nd", Native.Interface.GigabitEthernet.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.GigabitEthernet.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.GigabitEthernet.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.GigabitEthernet.Ipv6.Flow)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.GigabitEthernet.Ipv6.Crypto)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.GigabitEthernet.Ipv6.Ospf)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.GigabitEthernet.Ipv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.GigabitEthernet.Ipv6.Pim)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Interface.GigabitEthernet.Ipv6.Rip))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None
                    self.unreachables = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.GigabitEthernet.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.GigabitEthernet.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.GigabitEthernet.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.GigabitEthernet.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.flow = Native.Interface.GigabitEthernet.Ipv6.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.crypto = Native.Interface.GigabitEthernet.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.ospf = Native.Interface.GigabitEthernet.Ipv6.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.no_pim = Native.Interface.GigabitEthernet.Ipv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.GigabitEthernet.Ipv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects', 'unreachables'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.GigabitEthernet.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.GigabitEthernet.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.GigabitEthernet.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.GigabitEthernet.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.GigabitEthernet.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.GigabitEthernet.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.GigabitEthernet.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.GigabitEthernet.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.GigabitEthernet.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.GigabitEthernet.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.GigabitEthernet.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.GigabitEthernet.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.GigabitEthernet.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.GigabitEthernet.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.GigabitEthernet.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.GigabitEthernet.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.GigabitEthernet.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.GigabitEthernet.Ipv6.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.GigabitEthernet.Ipv6.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ipv6.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ipv6.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Crypto, ['map'], name, value)


                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process
                    
                    	
                    	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Process>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: encryption
                    
                    	Enable encryption
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Network>`
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process", ("process", Native.Interface.GigabitEthernet.Ipv6.Ospf.Process)), ("authentication", ("authentication", Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication)), ("bfd", ("bfd", Native.Interface.GigabitEthernet.Ipv6.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.GigabitEthernet.Ipv6.Ospf.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.GigabitEthernet.Ipv6.Ospf.DemandCircuit)), ("encryption", ("encryption", Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption)), ("flood-reduction", ("flood_reduction", Native.Interface.GigabitEthernet.Ipv6.Ospf.FloodReduction)), ("mtu-ignore", ("mtu_ignore", Native.Interface.GigabitEthernet.Ipv6.Ospf.MtuIgnore)), ("neighbor", ("neighbor", Native.Interface.GigabitEthernet.Ipv6.Ospf.Neighbor)), ("network", ("network", Native.Interface.GigabitEthernet.Ipv6.Ospf.Network)), ("shutdown", ("shutdown", Native.Interface.GigabitEthernet.Ipv6.Ospf.Shutdown))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.cost = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.GigabitEthernet.Ipv6.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.encryption = Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.network = Native.Interface.GigabitEthernet.Ipv6.Ospf.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.process = YList(self)
                        self.neighbor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf, ['cost', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Process(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: instance
                        
                        	Set the OSPF instance
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..31
                        
                        		**type**\: int
                        
                        			**range:** 32..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Process, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['int','int'])),
                            ])
                            self.id = None
                            self.area = None
                            self.instance = None
                            self._segment_path = lambda: "process" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Process, ['id', 'area', 'instance'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec authentication
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec authentication
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 256..4294967295
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5>`
                            
                            .. attribute:: sha1
                            
                            	Use SHA\-1 authentication
                            	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ])
                                self.spi = None

                                self.md5 = Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.sha1 = Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1()
                                self.sha1.parent = self
                                self._children_name_map["sha1"] = "sha1"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec, ['spi'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Sha1(Entity):
                                """
                                Use SHA\-1 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, self).__init__()

                                    self.yang_name = "sha1"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "sha1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "sha1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ipv6.Ospf.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.DatabaseFilter, ['all', 'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.DemandCircuit, ['disable', 'ignore'], name, value)


                    class Encryption(Entity):
                        """
                        Enable encryption
                        
                        .. attribute:: null
                        
                        	No IPsec encryption on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec encryption
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec encryption
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: esp
                            
                            	Use ESP encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipsec_3des
                            
                            	Use 3DES encryption
                            	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des>`
                            
                            .. attribute:: aes_cbc
                            
                            	Use AES\-CBC encryption
                            	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                                ])
                                self.spi = None
                                self.esp = None

                                self.ipsec_3des = Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des()
                                self.ipsec_3des.parent = self
                                self._children_name_map["ipsec_3des"] = "ipsec_3des"

                                self.aes_cbc = Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc()
                                self.aes_cbc.parent = self
                                self._children_name_map["aes_cbc"] = "aes-cbc"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec, ['spi', 'esp'], name, value)


                            class Ipsec3des(Entity):
                                """
                                Use 3DES encryption
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, self).__init__()

                                    self.yang_name = "ipsec_3des"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "ipsec_3des"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "ipsec_3des"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class AesCbc(Entity):
                                """
                                Use AES\-CBC encryption
                                
                                .. attribute:: aes_cbc_128
                                
                                	Use 128 bit key
                                	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128>`
                                
                                .. attribute:: aes_192
                                
                                	Use 192 bit key
                                	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192>`
                                
                                .. attribute:: aes_256
                                
                                	Use 256 bit key
                                	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, self).__init__()

                                    self.yang_name = "aes-cbc"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256))])
                                    self._leafs = OrderedDict()

                                    self.aes_cbc_128 = Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128()
                                    self.aes_cbc_128.parent = self
                                    self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                    self.aes_192 = Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192()
                                    self.aes_192.parent = self
                                    self._children_name_map["aes_192"] = "aes-192"

                                    self.aes_256 = Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256()
                                    self.aes_256.parent = self
                                    self._children_name_map["aes_256"] = "aes-256"
                                    self._segment_path = lambda: "aes-cbc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, [], name, value)


                                class AesCbc128(Entity):
                                    """
                                    Use 128 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                        self.yang_name = "aes-cbc-128"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-cbc-128"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-cbc-128"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes192(Entity):
                                    """
                                    Use 192 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                        self.yang_name = "aes-192"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-192"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-192"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes256(Entity):
                                    """
                                    Use 256 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                        self.yang_name = "aes-256"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-256"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	Disable Flood Reduction on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.FloodReduction, ['disable'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.MtuIgnore, ['disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.GigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.GigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.GigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Ospf.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Ospf.Shutdown, ['disable'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.GigabitEthernet.Ipv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.GigabitEthernet.Ipv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Pim.Bsr, ['border'], name, value)


                class Rip(Entity):
                    """
                    Configure RIP routing protocol
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable/disable RIP routing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default_information
                    
                    	Configure handling of default route
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Rip.DefaultInformation>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ipv6.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("default-information", ("default_information", Native.Interface.GigabitEthernet.Ipv6.Rip.DefaultInformation))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.id = None
                        self.enable = None

                        self.default_information = Native.Interface.GigabitEthernet.Ipv6.Rip.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Rip, ['id', 'enable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Configure handling of default route
                        
                        .. attribute:: route
                        
                        	
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ipv6.Rip.DefaultInformation.Route>`
                        
                        .. attribute:: metric
                        
                        	Default route metric
                        	**type**\: int
                        
                        	**range:** 1..15
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ipv6.Rip.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route', (YLeaf(YType.enumeration, 'route'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ipv6.Rip.DefaultInformation.Route')])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ])
                            self.route = None
                            self.metric = None
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ipv6.Rip.DefaultInformation, ['route', 'metric'], name, value)

                        class Route(Enum):
                            """
                            Route (Enum Class)

                            .. data:: only = 0

                            .. data:: originate = 1

                            """

                            only = Enum.YLeaf(0, "only")

                            originate = Enum.YLeaf(1, "originate")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.GigabitEthernet.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.GigabitEthernet.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.GigabitEthernet.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.GigabitEthernet.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.GigabitEthernet.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.GigabitEthernet.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.GigabitEthernet.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.GigabitEthernet.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.GigabitEthernet.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.GigabitEthernet.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.GigabitEthernet.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.GigabitEthernet.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.GigabitEthernet.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.GigabitEthernet.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.GigabitEthernet.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.GigabitEthernet.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.GigabitEthernet.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.GigabitEthernet.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.GigabitEthernet.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.GigabitEthernet.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.GigabitEthernet.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.GigabitEthernet.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.GigabitEthernet.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.GigabitEthernet.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.GigabitEthernet.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.GigabitEthernet.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.GigabitEthernet.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.GigabitEthernet.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.GigabitEthernet.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.GigabitEthernet.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.GigabitEthernet.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.GigabitEthernet.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.GigabitEthernet.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.GigabitEthernet.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.GigabitEthernet.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.GigabitEthernet.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.GigabitEthernet.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.GigabitEthernet.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.GigabitEthernet.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.GigabitEthernet.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.GigabitEthernet.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.GigabitEthernet.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.GigabitEthernet.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.GigabitEthernet.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.GigabitEthernet.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.GigabitEthernet.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.GigabitEthernet.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.GigabitEthernet.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.GigabitEthernet.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.GigabitEthernet.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.GigabitEthernet.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.GigabitEthernet.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.GigabitEthernet.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.GigabitEthernet.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.GigabitEthernet.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.GigabitEthernet.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.GigabitEthernet.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.PmPath, [u'name', u'interface_id'], name, value)


            class SwitchportWrapper(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.SwitchportWrapper, self).__init__()

                    self.yang_name = "switchport-wrapper"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("switchport", ("switchport", Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport))])
                    self._leafs = OrderedDict()

                    self.switchport = Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport()
                    self.switchport.parent = self
                    self._children_name_map["switchport"] = "switchport"
                    self._segment_path = lambda: "switchport-wrapper"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.SwitchportWrapper, [], name, value)


                class Switchport(Entity):
                    """
                    
                    
                    .. attribute:: access
                    
                    	Set access mode characteristics of the interface
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Access>`
                    
                    .. attribute:: mode
                    
                    	Set trunking mode of the interface
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Mode>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking characteristics of the interface
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport, self).__init__()

                        self.yang_name = "switchport"
                        self.yang_parent_name = "switchport-wrapper"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Access)), ("trunk", ("trunk", Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk))])
                        self._leafs = OrderedDict([
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.SwitchportWrapper.Switchport.Mode')])),
                        ])
                        self.mode = None

                        self.access = Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Access()
                        self.access.parent = self
                        self._children_name_map["access"] = "access"

                        self.trunk = Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk()
                        self.trunk.parent = self
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "switchport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport, [u'mode'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        Set trunking mode of the interface

                        .. data:: access = 0

                        .. data:: trunk = 1

                        """

                        access = Enum.YLeaf(0, "access")

                        trunk = Enum.YLeaf(1, "trunk")



                    class Access(Entity):
                        """
                        Set access mode characteristics of the interface
                        
                        .. attribute:: vlan
                        
                        	Set VLAN when interface is in access mode
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "access"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Access, [u'vlan'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking characteristics of the interface
                        
                        .. attribute:: allowed
                        
                        	Set allowed VLAN characteristics when interface is in trunking mode
                        	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Allowed>`
                        
                        .. attribute:: native
                        
                        	
                        	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Native_>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Native_))])
                            self._leafs = OrderedDict()

                            self.allowed = Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Allowed()
                            self.allowed.parent = self
                            self._children_name_map["allowed"] = "allowed"

                            self.native = Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Native_()
                            self.native.parent = self
                            self._children_name_map["native"] = "native"
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk, [], name, value)


                        class Allowed(Entity):
                            """
                            Set allowed VLAN characteristics when interface is in trunking mode
                            
                            .. attribute:: vlan
                            
                            	Set allowed VLANs when interface is in trunking mode
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Allowed, self).__init__()

                                self.yang_name = "allowed"
                                self.yang_parent_name = "trunk"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan))])
                                self._leafs = OrderedDict()

                                self.vlan = Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "allowed"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Allowed, [], name, value)


                            class Vlan(Entity):
                                """
                                Set allowed VLANs when interface is in trunking mode
                                
                                .. attribute:: vlans
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: add
                                
                                	VLAN IDs of the allowed VLANs when this port is in trunking mode
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\: str
                                
                                .. attribute:: all
                                
                                	all VLANs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: except_
                                
                                	all VLANs except the following
                                	**type**\: union of the below types:
                                
                                		**type**\: list of int
                                
                                			**range:** 0..65535
                                
                                		**type**\: list of str
                                
                                .. attribute:: none
                                
                                	no VLANs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: remove
                                
                                	VLAN IDs of disallowed VLANS when this port is in trunking mode
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "allowed"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                        ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                    ])
                                    self.vlans = None
                                    self.add = None
                                    self.all = None
                                    self.except_ = []
                                    self.none = None
                                    self.remove = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                        class Native_(Entity):
                            """
                            
                            
                            .. attribute:: vlan
                            
                            	Set VLAN when interface is in access mode
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Native_, self).__init__()

                                self.yang_name = "native"
                                self.yang_parent_name = "trunk"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.vlan = None
                                self._segment_path = lambda: "native"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.SwitchportWrapper.Switchport.Trunk.Native_, [u'vlan'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.GigabitEthernet.CarrierDelay.Down)), ("up", ("up", Native.Interface.GigabitEthernet.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.GigabitEthernet.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.GigabitEthernet.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.GigabitEthernet.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.GigabitEthernet.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.GigabitEthernet.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.GigabitEthernet.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.GigabitEthernet.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.GigabitEthernet.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.GigabitEthernet.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.GigabitEthernet.Plim.Ethernet)), ("qos", ("qos", Native.Interface.GigabitEthernet.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.GigabitEthernet.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.GigabitEthernet.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.GigabitEthernet.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.GigabitEthernet.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.GigabitEthernet.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.GigabitEthernet.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.GigabitEthernet.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.GigabitEthernet.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.GigabitEthernet.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.GigabitEthernet.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.L2protocol>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.GigabitEthernet.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.GigabitEthernet.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.GigabitEthernet.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.GigabitEthernet.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.GigabitEthernet.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.GigabitEthernet.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.GigabitEthernet.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.GigabitEthernet.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.GigabitEthernet.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.GigabitEthernet.Service.Instance.L2protocol)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.GigabitEthernet.Service.Instance.Xconnect)), ("Cisco-IOS-XE-l2vpn:xconnect-pw-class", ("xconnect_pw_class", Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.GigabitEthernet.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.GigabitEthernet.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.GigabitEthernet.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.GigabitEthernet.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.GigabitEthernet.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.GigabitEthernet.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.GigabitEthernet.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.GigabitEthernet.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.GigabitEthernet.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.GigabitEthernet.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"

                        self.xconnect = Native.Interface.GigabitEthernet.Service.Instance.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                        self.xconnect_pw_class = Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.GigabitEthernet.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.GigabitEthernet.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.GigabitEthernet.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.GigabitEthernet.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.GigabitEthernet.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.GigabitEthernet.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.GigabitEthernet.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.GigabitEthernet.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.GigabitEthernet.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.GigabitEthernet.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.GigabitEthernet.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.GigabitEthernet.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.GigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.GigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.GigabitEthernet.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.GigabitEthernet.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.GigabitEthernet.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.GigabitEthernet.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.GigabitEthernet.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.GigabitEthernet.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.GigabitEthernet.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.GigabitEthernet.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Service.Instance.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Lacp(Entity):
                """
                LACP interface subcommands
                
                .. attribute:: port_priority
                
                	LACP priority on this interface 
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rate
                
                	Rate at which the LACP packets are requested to be ingressed to this interface
                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Lacp.Rate>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Lacp, self).__init__()

                    self.yang_name = "lacp"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_priority', (YLeaf(YType.uint32, 'port-priority'), ['int'])),
                        ('rate', (YLeaf(YType.enumeration, 'rate'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Lacp.Rate')])),
                    ])
                    self.port_priority = None
                    self.rate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:lacp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Lacp, ['port_priority', 'rate'], name, value)

                class Rate(Enum):
                    """
                    Rate (Enum Class)

                    Rate at which the LACP packets are requested to be ingressed to this interface

                    .. data:: fast = 0

                    .. data:: normal = 1

                    """

                    fast = Enum.YLeaf(0, "fast")

                    normal = Enum.YLeaf(1, "normal")



            class CiscoIOSXEEthernetMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: dot1q_in_clear
                    
                    	Dot1q in Clear option
                    	**type**\:  :py:class:`Dot1qInClear <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear>`
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('dot1q_in_clear', (YLeaf(YType.enumeration, 'dot1q-in-clear'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear')])),
                        ])
                        self.dot1q_in_clear = None

                        self.replay_protection = Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, ['dot1q_in_clear'], name, value)

                    class Dot1qInClear(Enum):
                        """
                        Dot1qInClear (Enum Class)

                        Dot1q in Clear option

                        .. data:: Y_1 = 0

                        """

                        Y_1 = Enum.YLeaf(0, "1")



                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, ['window_size'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.GigabitEthernet.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.GigabitEthernet.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.GigabitEthernet.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.GigabitEthernet.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.GigabitEthernet.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.GigabitEthernet.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Auto(Entity):
                """
                Configure Automation
                
                .. attribute:: qos
                
                	Configure AutoQoS
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Auto.Qos>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Auto, self).__init__()

                    self.yang_name = "auto"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("qos", ("qos", Native.Interface.GigabitEthernet.Auto.Qos))])
                    self._leafs = OrderedDict()

                    self.qos = Native.Interface.GigabitEthernet.Auto.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:auto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Auto, [], name, value)


                class Qos(Entity):
                    """
                    Configure AutoQoS
                    
                    .. attribute:: classify
                    
                    	Configure classification for untrusted devices
                    	**type**\:  :py:class:`Classify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Auto.Qos.Classify>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trust
                    
                    	Trust the DSCP/CoS marking
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Auto.Qos.Trust>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: video
                    
                    	Configure AutoQoS for video devices
                    	**type**\:  :py:class:`Video <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Auto.Qos.Video>`
                    
                    .. attribute:: voip
                    
                    	Configure AutoQoS for VoIP
                    	**type**\:  :py:class:`Voip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Auto.Qos.Voip>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Auto.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "auto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("classify", ("classify", Native.Interface.GigabitEthernet.Auto.Qos.Classify)), ("trust", ("trust", Native.Interface.GigabitEthernet.Auto.Qos.Trust)), ("video", ("video", Native.Interface.GigabitEthernet.Auto.Qos.Video)), ("voip", ("voip", Native.Interface.GigabitEthernet.Auto.Qos.Voip))])
                        self._leafs = OrderedDict()

                        self.classify = None
                        self._children_name_map["classify"] = "classify"

                        self.trust = None
                        self._children_name_map["trust"] = "trust"

                        self.video = Native.Interface.GigabitEthernet.Auto.Qos.Video()
                        self.video.parent = self
                        self._children_name_map["video"] = "video"

                        self.voip = None
                        self._children_name_map["voip"] = "voip"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Auto.Qos, [], name, value)


                    class Classify(Entity):
                        """
                        Configure classification for untrusted devices
                        
                        .. attribute:: police
                        
                        	Configure QoS policing for untrusted devices
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Auto.Qos.Classify, self).__init__()

                            self.yang_name = "classify"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('police', (YLeaf(YType.empty, 'police'), ['Empty'])),
                            ])
                            self.police = None
                            self._segment_path = lambda: "classify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Auto.Qos.Classify, [u'police'], name, value)


                    class Trust(Entity):
                        """
                        Trust the DSCP/CoS marking
                        
                        .. attribute:: cos
                        
                        	Trust the CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	Trust the DSCP marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Auto.Qos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cos', (YLeaf(YType.empty, 'cos'), ['Empty'])),
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ])
                            self.cos = None
                            self.dscp = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Auto.Qos.Trust, [u'cos', u'dscp'], name, value)


                    class Video(Entity):
                        """
                        Configure AutoQoS for video devices
                        
                        .. attribute:: cts
                        
                        	Trust the QoS marking of the Cisco Telepresence System
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ip_camera
                        
                        	Trust the QoS marking of the Ip Video Surveillance camera
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: media_player
                        
                        	Trust the Qos marking of the Cisco Media Player
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Auto.Qos.Video, self).__init__()

                            self.yang_name = "video"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('cts', (YLeaf(YType.empty, 'cts'), ['Empty'])),
                                ('ip_camera', (YLeaf(YType.empty, 'ip-camera'), ['Empty'])),
                                ('media_player', (YLeaf(YType.empty, 'media-player'), ['Empty'])),
                            ])
                            self.cts = None
                            self.ip_camera = None
                            self.media_player = None
                            self._segment_path = lambda: "video"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Auto.Qos.Video, [u'cts', u'ip_camera', u'media_player'], name, value)


                    class Voip(Entity):
                        """
                        Configure AutoQoS for VoIP
                        
                        .. attribute:: cisco_phone
                        
                        	Trust the QoS marking of Cisco IP Phone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cisco_softphone
                        
                        	Trust the QoS marking of Cisco IP SoftPhone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trust
                        
                        	Trust the DSCP/CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Auto.Qos.Voip, self).__init__()

                            self.yang_name = "voip"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cisco_phone', (YLeaf(YType.empty, 'cisco-phone'), ['Empty'])),
                                ('cisco_softphone', (YLeaf(YType.empty, 'cisco-softphone'), ['Empty'])),
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.cisco_phone = None
                            self.cisco_softphone = None
                            self.trust = None
                            self._segment_path = lambda: "voip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Auto.Qos.Voip, [u'cisco_phone', u'cisco_softphone', u'trust'], name, value)


            class Datalink(Entity):
                """
                Interface Datalink commands
                
                .. attribute:: flow
                
                	Interface Flow configuration subcommands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Datalink.Flow>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Datalink, self).__init__()

                    self.yang_name = "datalink"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flow", ("flow", Native.Interface.GigabitEthernet.Datalink.Flow))])
                    self._leafs = OrderedDict()

                    self.flow = Native.Interface.GigabitEthernet.Datalink.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:datalink"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Datalink, [], name, value)


                class Flow(Entity):
                    """
                    Interface Flow configuration subcommands
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Datalink.Flow.Monitor>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Datalink.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "datalink"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.GigabitEthernet.Datalink.Flow.Monitor))])
                        self._leafs = OrderedDict()

                        self.monitor = None
                        self._children_name_map["monitor"] = "monitor"
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Datalink.Flow, [], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: user_defined_flow
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: input_output
                        
                        	Apply Flow Monitor on input/output traffic
                        	**type**\:  :py:class:`InputOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Datalink.Flow.Monitor.InputOutput>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Datalink.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('user_defined_flow', (YLeaf(YType.str, 'User-defined-flow'), ['str'])),
                                ('input_output', (YLeaf(YType.enumeration, 'input-output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Datalink.Flow.Monitor.InputOutput')])),
                            ])
                            self.user_defined_flow = None
                            self.input_output = None
                            self._segment_path = lambda: "monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Datalink.Flow.Monitor, [u'user_defined_flow', u'input_output'], name, value)

                        class InputOutput(Enum):
                            """
                            InputOutput (Enum Class)

                            Apply Flow Monitor on input/output traffic

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



            class Energywise(Entity):
                """
                EnergyWise interface configurations
                
                .. attribute:: activitycheck
                
                	Apply an activity check before turning off power    to this PoE port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: level
                
                	Set the EnergyWise level of this interface  or attached entity
                	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Energywise.Level>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Energywise, self).__init__()

                    self.yang_name = "energywise"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Interface.GigabitEthernet.Energywise.Level))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('activitycheck', (YLeaf(YType.empty, 'activitycheck'), ['Empty'])),
                    ])
                    self.activitycheck = None

                    self.level = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:energywise"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Energywise, [u'activitycheck'], name, value)


                class Level(Entity):
                    """
                    Set the EnergyWise level of this interface 
                    or attached entity
                    
                    .. attribute:: range  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..10
                    
                    .. attribute:: recurrence
                    
                    	Specify that this level setting should  recur at the specified time
                    	**type**\:  :py:class:`Recurrence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Energywise.Level.Recurrence>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Energywise.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "energywise"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("recurrence", ("recurrence", Native.Interface.GigabitEthernet.Energywise.Level.Recurrence))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                        ])
                        self.range = None

                        self.recurrence = Native.Interface.GigabitEthernet.Energywise.Level.Recurrence()
                        self.recurrence.parent = self
                        self._children_name_map["recurrence"] = "recurrence"
                        self._segment_path = lambda: "level" + "[range='" + str(self.range) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Energywise.Level, [u'range'], name, value)


                    class Recurrence(Entity):
                        """
                        Specify that this level setting should 
                        recur at the specified time
                        
                        .. attribute:: importance
                        
                        	Specify the importance at which the event  should be sent when it recurs
                        	**type**\: list of  		 :py:class:`Importance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Energywise.Level.Recurrence.Importance>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Energywise.Level.Recurrence, self).__init__()

                            self.yang_name = "recurrence"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("importance", ("importance", Native.Interface.GigabitEthernet.Energywise.Level.Recurrence.Importance))])
                            self._leafs = OrderedDict()

                            self.importance = YList(self)
                            self._segment_path = lambda: "recurrence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Energywise.Level.Recurrence, [], name, value)


                        class Importance(Entity):
                            """
                            Specify the importance at which the event 
                            should be sent when it recurs
                            
                            .. attribute:: range  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: at
                            
                            	Specify the time(s) this level setting should occur
                            	**type**\:  :py:class:`At <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Energywise.Level.Recurrence.Importance.At>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Energywise.Level.Recurrence.Importance, self).__init__()

                                self.yang_name = "importance"
                                self.yang_parent_name = "recurrence"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("at", ("at", Native.Interface.GigabitEthernet.Energywise.Level.Recurrence.Importance.At))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.at = Native.Interface.GigabitEthernet.Energywise.Level.Recurrence.Importance.At()
                                self.at.parent = self
                                self._children_name_map["at"] = "at"
                                self._segment_path = lambda: "importance" + "[range='" + str(self.range) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Energywise.Level.Recurrence.Importance, [u'range'], name, value)


                            class At(Entity):
                                """
                                Specify the time(s) this level setting should occur
                                
                                .. attribute:: minute
                                
                                	cron format of minute(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..59
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: hour
                                
                                	cron format of hour(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..23
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: day
                                
                                	cron format of day(s) of month
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..31
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: month
                                
                                	cron format of month(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..12
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: weekday
                                
                                	cron format of weekday(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..7
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Energywise.Level.Recurrence.Importance.At, self).__init__()

                                    self.yang_name = "at"
                                    self.yang_parent_name = "importance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minute', (YLeaf(YType.str, 'minute'), ['int','str'])),
                                        ('hour', (YLeaf(YType.str, 'hour'), ['int','str'])),
                                        ('day', (YLeaf(YType.str, 'day'), ['int','str'])),
                                        ('month', (YLeaf(YType.str, 'month'), ['int','str'])),
                                        ('weekday', (YLeaf(YType.str, 'weekday'), ['int','str'])),
                                    ])
                                    self.minute = None
                                    self.hour = None
                                    self.day = None
                                    self.month = None
                                    self.weekday = None
                                    self._segment_path = lambda: "at"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Energywise.Level.Recurrence.Importance.At, [u'minute', u'hour', u'day', u'month', u'weekday'], name, value)


            class Location(Entity):
                """
                Interface location information
                
                .. attribute:: civic_location_id
                
                	Civic location information
                	**type**\:  :py:class:`CivicLocationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Location.CivicLocationId>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Location, self).__init__()

                    self.yang_name = "location"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("civic-location-id", ("civic_location_id", Native.Interface.GigabitEthernet.Location.CivicLocationId))])
                    self._leafs = OrderedDict()

                    self.civic_location_id = Native.Interface.GigabitEthernet.Location.CivicLocationId()
                    self.civic_location_id.parent = self
                    self._children_name_map["civic_location_id"] = "civic-location-id"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:location"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Location, [], name, value)


                class CivicLocationId(Entity):
                    """
                    Civic location information
                    
                    .. attribute:: location_identifier
                    
                    	civic location identifier string
                    	**type**\: str
                    
                    .. attribute:: host
                    
                    	Globally defined host location identifer
                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Location.CivicLocationId.Host>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: none
                    
                    	No globally defined location identifer
                    	**type**\:  :py:class:`Y_None <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Location.CivicLocationId.Y_None>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Location.CivicLocationId, self).__init__()

                        self.yang_name = "civic-location-id"
                        self.yang_parent_name = "location"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("host", ("host", Native.Interface.GigabitEthernet.Location.CivicLocationId.Host)), ("none", ("none", Native.Interface.GigabitEthernet.Location.CivicLocationId.Y_None))])
                        self._leafs = OrderedDict([
                            ('location_identifier', (YLeaf(YType.str, 'location-identifier'), ['str'])),
                        ])
                        self.location_identifier = None

                        self.host = None
                        self._children_name_map["host"] = "host"

                        self.none = None
                        self._children_name_map["none"] = "none"
                        self._segment_path = lambda: "civic-location-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Location.CivicLocationId, [u'location_identifier'], name, value)


                    class Host(Entity):
                        """
                        Globally defined host location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Location.CivicLocationId.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "host"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Location.CivicLocationId.Host, [u'port_location'], name, value)


                    class Y_None(Entity):
                        """
                        No globally defined location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Location.CivicLocationId.Y_None, self).__init__()

                            self.yang_name = "none"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Location.CivicLocationId.Y_None, [u'port_location'], name, value)


            class Mac(Entity):
                """
                MAC interface commands
                
                .. attribute:: access_group
                
                	MAC access\-group configuration commands
                	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mac.AccessGroup>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Mac, self).__init__()

                    self.yang_name = "mac"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.GigabitEthernet.Mac.AccessGroup))])
                    self._leafs = OrderedDict()

                    self.access_group = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:mac"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Mac, [], name, value)


                class AccessGroup(Entity):
                    """
                    MAC access\-group configuration commands
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mac.AccessGroup.Direction>`
                    
                    .. attribute:: acl_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Mac.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "mac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Mac.AccessGroup.Direction')])),
                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                        ])
                        self.direction = None
                        self.acl_name = None
                        self._segment_path = lambda: "access-group" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Mac.AccessGroup, [u'direction', u'acl_name'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Macro(Entity):
                """
                Command macro
                
                .. attribute:: description
                
                	Macro description for this interface
                	**type**\: str
                
                .. attribute:: auto
                
                	Smartport interface macro configurations
                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Macro.Auto>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Macro, self).__init__()

                    self.yang_name = "macro"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.GigabitEthernet.Macro.Auto))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.auto = Native.Interface.GigabitEthernet.Macro.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "auto"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macro"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Macro, [u'description'], name, value)


                class Auto(Entity):
                    """
                    Smartport interface macro configurations
                    
                    .. attribute:: processing
                    
                    	Enable smartport macro auto execution on this interface
                    	**type**\: bool
                    
                    .. attribute:: port
                    
                    	Provide interface specific configuration for macro processing
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Macro.Auto.Port>`
                    
                    .. attribute:: control
                    
                    	Control macro auto execution
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Macro.Auto.Control>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Macro.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "macro"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port", ("port", Native.Interface.GigabitEthernet.Macro.Auto.Port)), ("control", ("control", Native.Interface.GigabitEthernet.Macro.Auto.Control))])
                        self._leafs = OrderedDict([
                            ('processing', (YLeaf(YType.boolean, 'processing'), ['bool'])),
                        ])
                        self.processing = None

                        self.port = Native.Interface.GigabitEthernet.Macro.Auto.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.control = Native.Interface.GigabitEthernet.Macro.Auto.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"
                        self._segment_path = lambda: "auto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Macro.Auto, [u'processing'], name, value)


                    class Port(Entity):
                        """
                        Provide interface specific configuration for macro processing
                        
                        .. attribute:: sticky
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Macro.Auto.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                            ])
                            self.sticky = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Macro.Auto.Port, [u'sticky'], name, value)


                    class Control(Entity):
                        """
                        Control macro auto execution
                        
                        .. attribute:: device
                        
                        	Enable macro auto execution for devices
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Macro.Auto.Control.Device>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Macro.Auto.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("device", ("device", Native.Interface.GigabitEthernet.Macro.Auto.Control.Device))])
                            self._leafs = OrderedDict()

                            self.device = Native.Interface.GigabitEthernet.Macro.Auto.Control.Device()
                            self.device.parent = self
                            self._children_name_map["device"] = "device"
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Macro.Auto.Control, [], name, value)


                        class Device(Entity):
                            """
                            Enable macro auto execution for devices
                            
                            .. attribute:: phone
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Macro.Auto.Control.Device, self).__init__()

                                self.yang_name = "device"
                                self.yang_parent_name = "control"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('phone', (YLeaf(YType.empty, 'phone'), ['Empty'])),
                                ])
                                self.phone = None
                                self._segment_path = lambda: "device"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Macro.Auto.Control.Device, [u'phone'], name, value)


            class DualActive(Entity):
                """
                
                
                .. attribute:: fast_hello
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.DualActive, self).__init__()

                    self.yang_name = "dual-active"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fast_hello', (YLeaf(YType.empty, 'fast-hello'), ['Empty'])),
                    ])
                    self.fast_hello = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:dual-active"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.DualActive, [u'fast_hello'], name, value)


            class LoadBalancing(Entity):
                """
                Etherchannel Load\-Balancing
                
                .. attribute:: flow
                
                	Based on the traffic flows identified by the packet headers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Based on the VLAN to member links manual configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.LoadBalancing, self).__init__()

                    self.yang_name = "load-balancing"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('flow', (YLeaf(YType.empty, 'flow'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.flow = None
                    self.vlan = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:load-balancing"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.LoadBalancing, [u'flow', u'vlan'], name, value)


            class VlanRange(Entity):
                """
                
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4096
                
                		**type**\: str
                
                .. attribute:: service_policy
                
                	Configure QoS Service Policy
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.VlanRange.ServicePolicy>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.VlanRange, self).__init__()

                    self.yang_name = "vlan-range"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.GigabitEthernet.VlanRange.ServicePolicy))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                    ])
                    self.id = None

                    self.service_policy = Native.Interface.GigabitEthernet.VlanRange.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:vlan-range" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.VlanRange, [u'id'], name, value)


                class ServicePolicy(Entity):
                    """
                    Configure QoS Service Policy
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.VlanRange.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "vlan-range"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.VlanRange.ServicePolicy, [u'input', u'output'], name, value)


            class Switch(Entity):
                """
                
                
                .. attribute:: virtual
                
                	
                	**type**\:  :py:class:`Virtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Switch.Virtual>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("virtual", ("virtual", Native.Interface.GigabitEthernet.Switch.Virtual))])
                    self._leafs = OrderedDict()

                    self.virtual = Native.Interface.GigabitEthernet.Switch.Virtual()
                    self.virtual.parent = self
                    self._children_name_map["virtual"] = "virtual"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:switch"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Switch, [], name, value)


                class Virtual(Entity):
                    """
                    
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Switch.Virtual, self).__init__()

                        self.yang_name = "virtual"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ])
                        self.link = None
                        self._segment_path = lambda: "virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Switch.Virtual, [u'link'], name, value)


            class SrrQueue(Entity):
                """
                
                
                .. attribute:: bandwidth
                
                	
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SrrQueue.Bandwidth>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.SrrQueue, self).__init__()

                    self.yang_name = "srr-queue"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.GigabitEthernet.SrrQueue.Bandwidth))])
                    self._leafs = OrderedDict()

                    self.bandwidth = Native.Interface.GigabitEthernet.SrrQueue.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:srr-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.SrrQueue, [], name, value)


                class Bandwidth(Entity):
                    """
                    
                    
                    .. attribute:: shape
                    
                    	
                    	**type**\:  :py:class:`Shape <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SrrQueue.Bandwidth.Shape>`
                    
                    .. attribute:: share
                    
                    	
                    	**type**\:  :py:class:`Share <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SrrQueue.Bandwidth.Share>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.SrrQueue.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "srr-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("shape", ("shape", Native.Interface.GigabitEthernet.SrrQueue.Bandwidth.Shape)), ("share", ("share", Native.Interface.GigabitEthernet.SrrQueue.Bandwidth.Share))])
                        self._leafs = OrderedDict()

                        self.shape = Native.Interface.GigabitEthernet.SrrQueue.Bandwidth.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"

                        self.share = Native.Interface.GigabitEthernet.SrrQueue.Bandwidth.Share()
                        self.share.parent = self
                        self._children_name_map["share"] = "share"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.SrrQueue.Bandwidth, [], name, value)


                    class Shape(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.SrrQueue.Bandwidth.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint16, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint16, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint16, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint16, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "shape"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.SrrQueue.Bandwidth.Shape, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


                    class Share(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.SrrQueue.Bandwidth.Share, self).__init__()

                            self.yang_name = "share"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint8, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint8, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint8, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint8, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "share"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.SrrQueue.Bandwidth.Share, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


            class CiscoIOSXESwitchMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection>`
                    
                    .. attribute:: network_link
                    
                    	Enable macsec on switch connected interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('network_link', (YLeaf(YType.empty, 'network-link'), ['Empty'])),
                        ])
                        self.network_link = None

                        self.replay_protection = Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec, [u'network_link'], name, value)


                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, [u'window_size'], name, value)


            class DeviceTracking(Entity):
                """
                Configure device\-tracking on the interface
                
                .. attribute:: attach_policy
                
                	Apply a policy for feature device\-tracking
                	**type**\: str
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.DeviceTracking, self).__init__()

                    self.yang_name = "device-tracking"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                    ])
                    self.attach_policy = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:device-tracking"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.DeviceTracking, [u'attach_policy'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.GigabitEthernet.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.GigabitEthernet.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.GigabitEthernet.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.GigabitEthernet.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.GigabitEthernet.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.GigabitEthernet.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.GigabitEthernet.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.GigabitEthernet.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class Mka(Entity):
                """
                MACsec Key Agreement (MKA) interface configuration
                
                .. attribute:: policy
                
                	Apply MKA Policy
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mka.Policy>`
                
                .. attribute:: pre_shared_key
                
                	Configure MKA Pre\-Shared\-Key
                	**type**\:  :py:class:`PreSharedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mka.PreSharedKey>`
                
                

                """

                _prefix = 'ios-mka'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Mka, self).__init__()

                    self.yang_name = "mka"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.GigabitEthernet.Mka.Policy)), ("pre-shared-key", ("pre_shared_key", Native.Interface.GigabitEthernet.Mka.PreSharedKey))])
                    self._leafs = OrderedDict()

                    self.policy = Native.Interface.GigabitEthernet.Mka.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.pre_shared_key = Native.Interface.GigabitEthernet.Mka.PreSharedKey()
                    self.pre_shared_key.parent = self
                    self._children_name_map["pre_shared_key"] = "pre-shared-key"
                    self._segment_path = lambda: "Cisco-IOS-XE-mka:mka"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Mka, [], name, value)


                class Policy(Entity):
                    """
                    Apply MKA Policy
                    
                    .. attribute:: name
                    
                    	MKA Policy NAME
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Mka.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Mka.Policy, ['name'], name, value)


                class PreSharedKey(Entity):
                    """
                    Configure MKA Pre\-Shared\-Key
                    
                    .. attribute:: key_chain
                    
                    	Configure the key\-chain name
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mka.PreSharedKey.KeyChain>`
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Mka.PreSharedKey, self).__init__()

                        self.yang_name = "pre-shared-key"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.GigabitEthernet.Mka.PreSharedKey.KeyChain))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.GigabitEthernet.Mka.PreSharedKey.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"
                        self._segment_path = lambda: "pre-shared-key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Mka.PreSharedKey, [], name, value)


                    class KeyChain(Entity):
                        """
                        Configure the key\-chain name
                        
                        .. attribute:: name
                        
                        	Name of key\-chain to be used to get keys
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mka'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Mka.PreSharedKey.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "pre-shared-key"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Mka.PreSharedKey.KeyChain, ['name'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Utd, ['enable'], name, value)


            class Xconnect(Entity):
                """
                Xconnect commands
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: vcid
                
                	
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: encapsulation
                
                	Data encapsulation method
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Xconnect.Encapsulation>`
                
                .. attribute:: manual
                
                	Manually configure L2TP session parameters
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sequence
                
                	Configure sequencing options for xconnect
                	**type**\:  :py:class:`Sequence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Xconnect.Sequence>`
                
                .. attribute:: pw_class
                
                	Pseudowire\-class to use for encapsulation and protocol configuration
                	**type**\: str
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Xconnect.Encapsulation')])),
                        ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                        ('sequence', (YLeaf(YType.enumeration, 'sequence'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Xconnect.Sequence')])),
                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                    ])
                    self.address = None
                    self.vcid = None
                    self.encapsulation = None
                    self.manual = None
                    self.sequence = None
                    self.pw_class = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'sequence', 'pw_class'], name, value)

                class Encapsulation(Enum):
                    """
                    Encapsulation (Enum Class)

                    Data encapsulation method

                    .. data:: mpls = 0

                    .. data:: l2tpv3 = 1

                    """

                    mpls = Enum.YLeaf(0, "mpls")

                    l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                class Sequence(Enum):
                    """
                    Sequence (Enum Class)

                    Configure sequencing options for xconnect

                    .. data:: both = 0

                    .. data:: receive = 1

                    .. data:: transmit = 2

                    """

                    both = Enum.YLeaf(0, "both")

                    receive = Enum.YLeaf(1, "receive")

                    transmit = Enum.YLeaf(2, "transmit")



            class Evpn(Entity):
                """
                
                
                .. attribute:: ethernet_segment
                
                	Ethernet segment local discriminator value
                	**type**\: list of  		 :py:class:`EthernetSegment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Evpn.EthernetSegment>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Evpn, self).__init__()

                    self.yang_name = "evpn"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet-segment", ("ethernet_segment", Native.Interface.GigabitEthernet.Evpn.EthernetSegment))])
                    self._leafs = OrderedDict()

                    self.ethernet_segment = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:evpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Evpn, [], name, value)


                class EthernetSegment(Entity):
                    """
                    Ethernet segment local discriminator value
                    
                    .. attribute:: es_value  (key)
                    
                    	Ethernet segment local discriminator value
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: df_election
                    
                    	Designated forwarder election parameters
                    	**type**\:  :py:class:`DfElection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Evpn.EthernetSegment.DfElection>`
                    
                    .. attribute:: redundancy
                    
                    	Multi\-homing redundancy parameters
                    	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Evpn.EthernetSegment.Redundancy>`
                    
                    .. attribute:: sytem_mac
                    
                    	System MAC address for generating the Ethernet Segment ID
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Evpn.EthernetSegment, self).__init__()

                        self.yang_name = "ethernet-segment"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['es_value']
                        self._child_classes = OrderedDict([("df-election", ("df_election", Native.Interface.GigabitEthernet.Evpn.EthernetSegment.DfElection)), ("redundancy", ("redundancy", Native.Interface.GigabitEthernet.Evpn.EthernetSegment.Redundancy))])
                        self._leafs = OrderedDict([
                            ('es_value', (YLeaf(YType.uint16, 'es-value'), ['int'])),
                            ('sytem_mac', (YLeaf(YType.str, 'sytem-mac'), ['str'])),
                        ])
                        self.es_value = None
                        self.sytem_mac = None

                        self.df_election = Native.Interface.GigabitEthernet.Evpn.EthernetSegment.DfElection()
                        self.df_election.parent = self
                        self._children_name_map["df_election"] = "df-election"

                        self.redundancy = Native.Interface.GigabitEthernet.Evpn.EthernetSegment.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                        self._segment_path = lambda: "ethernet-segment" + "[es-value='" + str(self.es_value) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Evpn.EthernetSegment, ['es_value', 'sytem_mac'], name, value)


                    class DfElection(Entity):
                        """
                        Designated forwarder election parameters
                        
                        .. attribute:: wait_time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Evpn.EthernetSegment.DfElection, self).__init__()

                            self.yang_name = "df-election"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wait_time', (YLeaf(YType.uint8, 'wait-time'), ['int'])),
                            ])
                            self.wait_time = None
                            self._segment_path = lambda: "df-election"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Evpn.EthernetSegment.DfElection, ['wait_time'], name, value)


                    class Redundancy(Entity):
                        """
                        Multi\-homing redundancy parameters
                        
                        .. attribute:: all_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: single_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Evpn.EthernetSegment.Redundancy, self).__init__()

                            self.yang_name = "redundancy"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all_active', (YLeaf(YType.empty, 'all-active'), ['Empty'])),
                                ('single_active', (YLeaf(YType.empty, 'single-active'), ['Empty'])),
                            ])
                            self.all_active = None
                            self.single_active = None
                            self._segment_path = lambda: "redundancy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Evpn.EthernetSegment.Redundancy, ['all_active', 'single_active'], name, value)


            class FabricDomain(Entity):
                """
                Fabric\-domain interface command
                
                .. attribute:: iwan_fabric
                
                	
                	**type**\:  :py:class:`IwanFabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.FabricDomain.IwanFabric>`
                
                

                """

                _prefix = 'ios-iwanfabric'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.FabricDomain, self).__init__()

                    self.yang_name = "fabric-domain"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("iwan-fabric", ("iwan_fabric", Native.Interface.GigabitEthernet.FabricDomain.IwanFabric))])
                    self._leafs = OrderedDict()

                    self.iwan_fabric = Native.Interface.GigabitEthernet.FabricDomain.IwanFabric()
                    self.iwan_fabric.parent = self
                    self._children_name_map["iwan_fabric"] = "iwan-fabric"
                    self._segment_path = lambda: "Cisco-IOS-XE-iwanfabric:fabric-domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.FabricDomain, [], name, value)


                class IwanFabric(Entity):
                    """
                    
                    
                    .. attribute:: word
                    
                    	
                    	**type**\: list of  		 :py:class:`Word <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.FabricDomain.IwanFabric.Word>`
                    
                    

                    """

                    _prefix = 'ios-iwanfabric'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.FabricDomain.IwanFabric, self).__init__()

                        self.yang_name = "iwan-fabric"
                        self.yang_parent_name = "fabric-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("word", ("word", Native.Interface.GigabitEthernet.FabricDomain.IwanFabric.Word))])
                        self._leafs = OrderedDict()

                        self.word = YList(self)
                        self._segment_path = lambda: "iwan-fabric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.FabricDomain.IwanFabric, [], name, value)


                    class Word(Entity):
                        """
                        
                        
                        .. attribute:: word  (key)
                        
                        	Path name
                        	**type**\: str
                        
                        .. attribute:: interface_id
                        
                        	Specify the interface\-id value
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-iwanfabric'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.FabricDomain.IwanFabric.Word, self).__init__()

                            self.yang_name = "word"
                            self.yang_parent_name = "iwan-fabric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                            ])
                            self.word = None
                            self.interface_id = None
                            self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.FabricDomain.IwanFabric.Word, ['word', 'interface_id'], name, value)


            class Mvrp(Entity):
                """
                
                
                .. attribute:: mvrp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: registration
                
                	
                	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mvrp.Registration>`
                
                .. attribute:: timer
                
                	
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mvrp.Timer>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mvrp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Mvrp, self).__init__()

                    self.yang_name = "mvrp"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("registration", ("registration", Native.Interface.GigabitEthernet.Mvrp.Registration)), ("timer", ("timer", Native.Interface.GigabitEthernet.Mvrp.Timer))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mvrp', (YLeaf(YType.empty, 'mvrp'), ['Empty'])),
                    ])
                    self.mvrp = None

                    self.registration = Native.Interface.GigabitEthernet.Mvrp.Registration()
                    self.registration.parent = self
                    self._children_name_map["registration"] = "registration"

                    self.timer = Native.Interface.GigabitEthernet.Mvrp.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-mvrp:mvrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Mvrp, ['mvrp'], name, value)


                class Registration(Entity):
                    """
                    
                    
                    .. attribute:: fixed
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: forbidden
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: normal
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Mvrp.Registration, self).__init__()

                        self.yang_name = "registration"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fixed', (YLeaf(YType.empty, 'fixed'), ['Empty'])),
                            ('forbidden', (YLeaf(YType.empty, 'forbidden'), ['Empty'])),
                            ('normal', (YLeaf(YType.empty, 'normal'), ['Empty'])),
                        ])
                        self.fixed = None
                        self.forbidden = None
                        self.normal = None
                        self._segment_path = lambda: "registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Mvrp.Registration, ['fixed', 'forbidden', 'normal'], name, value)


                class Timer(Entity):
                    """
                    
                    
                    .. attribute:: join
                    
                    	
                    	**type**\:  :py:class:`Join <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mvrp.Timer.Join>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave
                    
                    	
                    	**type**\:  :py:class:`Leave <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mvrp.Timer.Leave>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave_all
                    
                    	
                    	**type**\:  :py:class:`LeaveAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Mvrp.Timer.LeaveAll>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: periodic
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Mvrp.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("join", ("join", Native.Interface.GigabitEthernet.Mvrp.Timer.Join)), ("leave", ("leave", Native.Interface.GigabitEthernet.Mvrp.Timer.Leave)), ("leave-all", ("leave_all", Native.Interface.GigabitEthernet.Mvrp.Timer.LeaveAll))])
                        self._leafs = OrderedDict([
                            ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ])
                        self.periodic = None

                        self.join = None
                        self._children_name_map["join"] = "join"

                        self.leave = None
                        self._children_name_map["leave"] = "leave"

                        self.leave_all = None
                        self._children_name_map["leave_all"] = "leave-all"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Mvrp.Timer, ['periodic'], name, value)


                    class Join(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 20..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Mvrp.Timer.Join, self).__init__()

                            self.yang_name = "join"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "join"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Mvrp.Timer.Join, ['y_range'], name, value)


                    class Leave(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Mvrp.Timer.Leave, self).__init__()

                            self.yang_name = "leave"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Mvrp.Timer.Leave, ['y_range'], name, value)


                    class LeaveAll(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1000..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Mvrp.Timer.LeaveAll, self).__init__()

                            self.yang_name = "leave-all"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave-all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Mvrp.Timer.LeaveAll, ['y_range'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.GigabitEthernet.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.GigabitEthernet.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.GigabitEthernet.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.GigabitEthernet.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.GigabitEthernet.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.GigabitEthernet.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.GigabitEthernet.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.GigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Power(Entity):
                """
                
                
                .. attribute:: inline
                
                	
                	**type**\:  :py:class:`Inline <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Power.Inline>`
                
                

                """

                _prefix = 'ios-power'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Power, self).__init__()

                    self.yang_name = "power"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("inline", ("inline", Native.Interface.GigabitEthernet.Power.Inline))])
                    self._leafs = OrderedDict()

                    self.inline = Native.Interface.GigabitEthernet.Power.Inline()
                    self.inline.parent = self
                    self._children_name_map["inline"] = "inline"
                    self._segment_path = lambda: "Cisco-IOS-XE-power:power"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Power, [], name, value)


                class Inline(Entity):
                    """
                    
                    
                    .. attribute:: consumption
                    
                    	
                    	**type**\: int
                    
                    	**range:** 4000..15400
                    
                    .. attribute:: never
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: auto
                    
                    	Automatically detect and power inline devices
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Power.Inline.Auto>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: four_pair
                    
                    	Four\-pair PoE power
                    	**type**\:  :py:class:`FourPair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Power.Inline.FourPair>`
                    
                    .. attribute:: police
                    
                    	Police the power drawn on the port
                    	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Power.Inline.Police>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: port
                    
                    	Configure Port Power Level
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Power.Inline.Port>`
                    
                    .. attribute:: static
                    
                    	High priority inline power interface
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Power.Inline.Static>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-power'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Power.Inline, self).__init__()

                        self.yang_name = "inline"
                        self.yang_parent_name = "power"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.GigabitEthernet.Power.Inline.Auto)), ("four-pair", ("four_pair", Native.Interface.GigabitEthernet.Power.Inline.FourPair)), ("police", ("police", Native.Interface.GigabitEthernet.Power.Inline.Police)), ("port", ("port", Native.Interface.GigabitEthernet.Power.Inline.Port)), ("static", ("static", Native.Interface.GigabitEthernet.Power.Inline.Static))])
                        self._leafs = OrderedDict([
                            ('consumption', (YLeaf(YType.uint16, 'consumption'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.consumption = None
                        self.never = None

                        self.auto = None
                        self._children_name_map["auto"] = "auto"

                        self.four_pair = Native.Interface.GigabitEthernet.Power.Inline.FourPair()
                        self.four_pair.parent = self
                        self._children_name_map["four_pair"] = "four-pair"

                        self.police = None
                        self._children_name_map["police"] = "police"

                        self.port = Native.Interface.GigabitEthernet.Power.Inline.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.static = None
                        self._children_name_map["static"] = "static"
                        self._segment_path = lambda: "inline"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Power.Inline, ['consumption', 'never'], name, value)


                    class Auto(Entity):
                        """
                        Automatically detect and power inline devices
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Power.Inline.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "auto"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Power.Inline.Auto, ['max'], name, value)


                    class FourPair(Entity):
                        """
                        Four\-pair PoE power
                        
                        .. attribute:: forced
                        
                        	Enable Four\-pair PoE without L2 negotiation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Power.Inline.FourPair, self).__init__()

                            self.yang_name = "four-pair"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forced', (YLeaf(YType.empty, 'forced'), ['Empty'])),
                            ])
                            self.forced = None
                            self._segment_path = lambda: "four-pair"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Power.Inline.FourPair, ['forced'], name, value)


                    class Police(Entity):
                        """
                        Police the power drawn on the port
                        
                        .. attribute:: action
                        
                        	Action to be taken when power is overdrawn on the port
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Power.Inline.Police.Action>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Power.Inline.Police, self).__init__()

                            self.yang_name = "police"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.GigabitEthernet.Power.Inline.Police.Action))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.GigabitEthernet.Power.Inline.Police.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "police"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Power.Inline.Police, [], name, value)


                        class Action(Entity):
                            """
                            Action to be taken when power is overdrawn on the port
                            
                            .. attribute:: errdisable
                            
                            	Error\-disable the port when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log a message when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-power'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Power.Inline.Police.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "police"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('errdisable', (YLeaf(YType.empty, 'errdisable'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ])
                                self.errdisable = None
                                self.log = None
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Power.Inline.Police.Action, ['errdisable', 'log'], name, value)


                    class Port(Entity):
                        """
                        Configure Port Power Level
                        
                        .. attribute:: poe_ha
                        
                        	Apply poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: perpetual_poe_ha
                        
                        	Apply perpetual\-poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: two_event
                        
                        	Enable 2\-event classification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Power.Inline.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('poe_ha', (YLeaf(YType.empty, 'poe-ha'), ['Empty'])),
                                ('perpetual_poe_ha', (YLeaf(YType.empty, 'perpetual-poe-ha'), ['Empty'])),
                                ('two_event', (YLeaf(YType.empty, 'two-event'), ['Empty'])),
                            ])
                            self.poe_ha = None
                            self.perpetual_poe_ha = None
                            self.two_event = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Power.Inline.Port, ['poe_ha', 'perpetual_poe_ha', 'two_event'], name, value)


                    class Static(Entity):
                        """
                        High priority inline power interface
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Power.Inline.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "static"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Power.Inline.Static, ['max'], name, value)


            class Cdp(Entity):
                """
                CDP interface subcommands
                
                .. attribute:: enable
                
                	Enable CDP on interface
                	**type**\: bool
                
                .. attribute:: tlv
                
                	Enable exchange of specific tlv information
                	**type**\:  :py:class:`Tlv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cdp.Tlv>`
                
                

                """

                _prefix = 'ios-cdp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Cdp, self).__init__()

                    self.yang_name = "cdp"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tlv", ("tlv", Native.Interface.GigabitEthernet.Cdp.Tlv))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                    ])
                    self.enable = None

                    self.tlv = Native.Interface.GigabitEthernet.Cdp.Tlv()
                    self.tlv.parent = self
                    self._children_name_map["tlv"] = "tlv"
                    self._segment_path = lambda: "Cisco-IOS-XE-cdp:cdp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Cdp, ['enable'], name, value)


                class Tlv(Entity):
                    """
                    Enable exchange of specific tlv information
                    
                    .. attribute:: app
                    
                    	Enable/Configure Application TLV
                    	**type**\:  :py:class:`App <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cdp.Tlv.App>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: server_location
                    
                    	Enable CDP location server on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	Exchange location information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cdp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Cdp.Tlv, self).__init__()

                        self.yang_name = "tlv"
                        self.yang_parent_name = "cdp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("app", ("app", Native.Interface.GigabitEthernet.Cdp.Tlv.App))])
                        self._leafs = OrderedDict([
                            ('server_location', (YLeaf(YType.empty, 'server-location'), ['Empty'])),
                            ('location', (YLeaf(YType.empty, 'location'), ['Empty'])),
                        ])
                        self.server_location = None
                        self.location = None

                        self.app = None
                        self._children_name_map["app"] = "app"
                        self._segment_path = lambda: "tlv"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Cdp.Tlv, ['server_location', 'location'], name, value)


                    class App(Entity):
                        """
                        Enable/Configure Application TLV
                        
                        .. attribute:: tlvtype
                        
                        	Configure APP TLV
                        	**type**\: int
                        
                        	**range:** 1001..65535
                        
                        .. attribute:: value
                        
                        	Configure App TLV Value information
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cdp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Cdp.Tlv.App, self).__init__()

                            self.yang_name = "app"
                            self.yang_parent_name = "tlv"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tlvtype', (YLeaf(YType.uint16, 'tlvtype'), ['int'])),
                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                            ])
                            self.tlvtype = None
                            self.value = None
                            self._segment_path = lambda: "app"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Cdp.Tlv.App, ['tlvtype', 'value'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.GigabitEthernet.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.GigabitEthernet.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.GigabitEthernet.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.GigabitEthernet.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class Authentication(Entity):
                """
                Auth Manager Interface Configuration Commands
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.ControlDirection>`
                
                .. attribute:: event
                
                	Set action for authentication events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event>`
                
                .. attribute:: fallback
                
                	Enable the Webauth fallback mechanism
                	**type**\: str
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.HostMode>`
                
                .. attribute:: open
                
                	Enable or Disable open access on this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: order
                
                	Add an authentication method to the order list
                	**type**\:  :py:class:`Order <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Order>`
                
                .. attribute:: priority
                
                	Add an authentication method to the priority list
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Priority>`
                
                .. attribute:: port_control
                
                	set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.PortControl>`
                
                .. attribute:: periodic
                
                	Enable or Disable Reauthentication for this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timer
                
                	Set authentication timer values
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Timer>`
                
                .. attribute:: violation
                
                	Configure action to take on security violations
                	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Violation>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.GigabitEthernet.Authentication.Event)), ("order", ("order", Native.Interface.GigabitEthernet.Authentication.Order)), ("priority", ("priority", Native.Interface.GigabitEthernet.Authentication.Priority)), ("timer", ("timer", Native.Interface.GigabitEthernet.Authentication.Timer))])
                    self._leafs = OrderedDict([
                        ('control_direction', (YLeaf(YType.enumeration, 'control-direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Authentication.ControlDirection')])),
                        ('fallback', (YLeaf(YType.str, 'fallback'), ['str'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Authentication.HostMode')])),
                        ('open', (YLeaf(YType.empty, 'open'), ['Empty'])),
                        ('port_control', (YLeaf(YType.enumeration, 'port-control'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Authentication.PortControl')])),
                        ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Authentication.Violation')])),
                    ])
                    self.control_direction = None
                    self.fallback = None
                    self.host_mode = None
                    self.open = None
                    self.port_control = None
                    self.periodic = None
                    self.violation = None

                    self.event = Native.Interface.GigabitEthernet.Authentication.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.order = Native.Interface.GigabitEthernet.Authentication.Order()
                    self.order.parent = self
                    self._children_name_map["order"] = "order"

                    self.priority = Native.Interface.GigabitEthernet.Authentication.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "priority"

                    self.timer = Native.Interface.GigabitEthernet.Authentication.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:authentication"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Authentication, ['control_direction', 'fallback', 'host_mode', 'open', 'port_control', 'periodic', 'violation'], name, value)

                class ControlDirection(Enum):
                    """
                    ControlDirection (Enum Class)

                    Set the control\-direction on the interface

                    .. data:: both = 0

                    .. data:: in_ = 1

                    """

                    both = Enum.YLeaf(0, "both")

                    in_ = Enum.YLeaf(1, "in")


                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")


                class PortControl(Enum):
                    """
                    PortControl (Enum Class)

                    set the port\-control value

                    .. data:: auto = 0

                    .. data:: force_authorized = 1

                    .. data:: force_unauthorized = 2

                    """

                    auto = Enum.YLeaf(0, "auto")

                    force_authorized = Enum.YLeaf(1, "force-authorized")

                    force_unauthorized = Enum.YLeaf(2, "force-unauthorized")


                class Violation(Enum):
                    """
                    Violation (Enum Class)

                    Configure action to take on security violations

                    .. data:: protect = 0

                    .. data:: replace = 1

                    .. data:: restrict = 2

                    .. data:: shutdown = 3

                    """

                    protect = Enum.YLeaf(0, "protect")

                    replace = Enum.YLeaf(1, "replace")

                    restrict = Enum.YLeaf(2, "restrict")

                    shutdown = Enum.YLeaf(3, "shutdown")



                class Event(Entity):
                    """
                    Set action for authentication events
                    
                    .. attribute:: server
                    
                    	Configure actions for AAA server events
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.Server>`
                    
                    .. attribute:: fail
                    
                    	Configure actions for AAA fail events
                    	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.Fail>`
                    
                    .. attribute:: no_response
                    
                    	Configure actions for AAA no\-response events
                    	**type**\:  :py:class:`NoResponse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.NoResponse>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Authentication.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("server", ("server", Native.Interface.GigabitEthernet.Authentication.Event.Server)), ("fail", ("fail", Native.Interface.GigabitEthernet.Authentication.Event.Fail)), ("no-response", ("no_response", Native.Interface.GigabitEthernet.Authentication.Event.NoResponse))])
                        self._leafs = OrderedDict()

                        self.server = Native.Interface.GigabitEthernet.Authentication.Event.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.fail = Native.Interface.GigabitEthernet.Authentication.Event.Fail()
                        self.fail.parent = self
                        self._children_name_map["fail"] = "fail"

                        self.no_response = Native.Interface.GigabitEthernet.Authentication.Event.NoResponse()
                        self.no_response.parent = self
                        self._children_name_map["no_response"] = "no-response"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event, [], name, value)


                    class Server(Entity):
                        """
                        Configure actions for AAA server events
                        
                        .. attribute:: alive
                        
                        	Configure AAA server alive action
                        	**type**\:  :py:class:`Alive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.Server.Alive>`
                        
                        .. attribute:: dead
                        
                        	Configure AAA server dead action
                        	**type**\:  :py:class:`Dead <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Authentication.Event.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("alive", ("alive", Native.Interface.GigabitEthernet.Authentication.Event.Server.Alive)), ("dead", ("dead", Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead))])
                            self._leafs = OrderedDict()

                            self.alive = Native.Interface.GigabitEthernet.Authentication.Event.Server.Alive()
                            self.alive.parent = self
                            self._children_name_map["alive"] = "alive"

                            self.dead = Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead()
                            self.dead.parent = self
                            self._children_name_map["dead"] = "dead"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.Server, [], name, value)


                        class Alive(Entity):
                            """
                            Configure AAA server alive action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.Server.Alive.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Authentication.Event.Server.Alive, self).__init__()

                                self.yang_name = "alive"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.GigabitEthernet.Authentication.Event.Server.Alive.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.GigabitEthernet.Authentication.Event.Server.Alive.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "alive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.Server.Alive, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all authorized clients
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Authentication.Event.Server.Alive.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "alive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reinitialize', (YLeaf(YType.empty, 'reinitialize'), ['Empty'])),
                                    ])
                                    self.reinitialize = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.Server.Alive.Action, ['reinitialize'], name, value)


                        class Dead(Entity):
                            """
                            Configure AAA server dead action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead, self).__init__()

                                self.yang_name = "dead"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dead"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: authorize
                                
                                	Authorize the port
                                	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all client on the port
                                	**type**\:  :py:class:`Reinitialize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dead"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize)), ("reinitialize", ("reinitialize", Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize))])
                                    self._leafs = OrderedDict()

                                    self.authorize = None
                                    self._children_name_map["authorize"] = "authorize"

                                    self.reinitialize = Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize()
                                    self.reinitialize.parent = self
                                    self._children_name_map["reinitialize"] = "reinitialize"
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action, [], name, value)


                                class Authorize(Entity):
                                    """
                                    Authorize the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: voice
                                    
                                    	Authorize the port for VOICE traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize, self).__init__()

                                        self.yang_name = "authorize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ('voice', (YLeaf(YType.empty, 'voice'), ['Empty'])),
                                        ])
                                        self.vlan = None
                                        self.voice = None
                                        self._segment_path = lambda: "authorize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize, ['vlan', 'voice'], name, value)


                                class Reinitialize(Entity):
                                    """
                                    Reinitialize all client on the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, self).__init__()

                                        self.yang_name = "reinitialize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "reinitialize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, ['vlan'], name, value)


                    class Fail(Entity):
                        """
                        Configure actions for AAA fail events
                        
                        .. attribute:: action
                        
                        	Required action for fail event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.Fail.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Authentication.Event.Fail, self).__init__()

                            self.yang_name = "fail"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.GigabitEthernet.Authentication.Event.Fail.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.GigabitEthernet.Authentication.Event.Fail.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "fail"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.Fail, [], name, value)


                        class Action(Entity):
                            """
                            Required action for fail event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.Fail.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Authentication.Event.Fail.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "fail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.GigabitEthernet.Authentication.Event.Fail.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.GigabitEthernet.Authentication.Event.Fail.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.Fail.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Authentication.Event.Fail.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.Fail.Action.Authorize, ['vlan'], name, value)


                    class NoResponse(Entity):
                        """
                        Configure actions for AAA no\-response events
                        
                        .. attribute:: action
                        
                        	Required action for no\-response event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.NoResponse.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Authentication.Event.NoResponse, self).__init__()

                            self.yang_name = "no-response"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.GigabitEthernet.Authentication.Event.NoResponse.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.GigabitEthernet.Authentication.Event.NoResponse.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "no-response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.NoResponse, [], name, value)


                        class Action(Entity):
                            """
                            Required action for no\-response event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Event.NoResponse.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Authentication.Event.NoResponse.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "no-response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.GigabitEthernet.Authentication.Event.NoResponse.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.GigabitEthernet.Authentication.Event.NoResponse.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.NoResponse.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Authentication.Event.NoResponse.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Event.NoResponse.Action.Authorize, ['vlan'], name, value)


                class Order(Entity):
                    """
                    Add an authentication method to the order list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Authentication.Order, self).__init__()

                        self.yang_name = "order"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "order"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Order, ['dot1x', 'mab', 'webauth'], name, value)


                class Priority(Entity):
                    """
                    Add an authentication method to the priority list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Authentication.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Priority, ['dot1x', 'mab', 'webauth'], name, value)


                class Timer(Entity):
                    """
                    Set authentication timer values
                    
                    .. attribute:: reauthenticate
                    
                    	Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                    	**type**\:  :py:class:`Reauthenticate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Timer.Reauthenticate>`
                    
                    .. attribute:: inactivity
                    
                    	Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                    	**type**\:  :py:class:`Inactivity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity>`
                    
                    .. attribute:: restart
                    
                    	Interval in seconds after which an attempt should be made toauthenticate an unauthorized port (default 60 sec)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Authentication.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reauthenticate", ("reauthenticate", Native.Interface.GigabitEthernet.Authentication.Timer.Reauthenticate)), ("inactivity", ("inactivity", Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity))])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                        ])
                        self.restart = None

                        self.reauthenticate = Native.Interface.GigabitEthernet.Authentication.Timer.Reauthenticate()
                        self.reauthenticate.parent = self
                        self._children_name_map["reauthenticate"] = "reauthenticate"

                        self.inactivity = Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity()
                        self.inactivity.parent = self
                        self._children_name_map["inactivity"] = "inactivity"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Timer, ['restart'], name, value)


                    class Reauthenticate(Entity):
                        """
                        Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: server
                        
                        	Obtain re\-authentication timeout value from the server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Authentication.Timer.Reauthenticate, self).__init__()

                            self.yang_name = "reauthenticate"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                            ])
                            self.value = None
                            self.server = None
                            self._segment_path = lambda: "reauthenticate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Timer.Reauthenticate, ['value', 'server'], name, value)


                    class Inactivity(Entity):
                        """
                        Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity.Value>`
                        
                        .. attribute:: server
                        
                        	Obtain inactivity timeout value from the server
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity.Server>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity, self).__init__()

                            self.yang_name = "inactivity"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity.Value)), ("server", ("server", Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity.Server))])
                            self._leafs = OrderedDict()

                            self.value = Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.server = None
                            self._children_name_map["server"] = "server"
                            self._segment_path = lambda: "inactivity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity, [], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.value = None
                                self.dynamic = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity.Value, ['value', 'dynamic'], name, value)


                        class Server(Entity):
                            """
                            Obtain inactivity timeout value from the server
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.dynamic = None
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Authentication.Timer.Inactivity.Server, ['dynamic'], name, value)


            class Mab(Entity):
                """
                
                
                .. attribute:: eap
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Mab, self).__init__()

                    self.yang_name = "mab"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                    ])
                    self.eap = None
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:mab"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Mab, ['eap'], name, value)


            class Dot1x(Entity):
                """
                Interface Config Commands for IEEE 802.1X
                
                .. attribute:: authenticator
                
                	Configure authenticator parameters
                	**type**\:  :py:class:`Authenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Dot1x.Authenticator>`
                
                .. attribute:: credentials
                
                	Credentials profile configuration
                	**type**\: str
                
                .. attribute:: max_reauth_req
                
                	Max No. of Reauthentication Attempts
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_req
                
                	Max No. of Retries
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_start
                
                	Max No. of EAPOL\-Start requests
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: pae
                
                	Set 802.1x interface pae type
                	**type**\:  :py:class:`Pae <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Dot1x.Pae>`
                
                .. attribute:: supplicant
                
                	Configure supplicant parameters
                	**type**\:  :py:class:`Supplicant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Dot1x.Supplicant>`
                
                .. attribute:: timeout
                
                	Various Timeouts
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Dot1x.Timeout>`
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Dot1x, self).__init__()

                    self.yang_name = "dot1x"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authenticator", ("authenticator", Native.Interface.GigabitEthernet.Dot1x.Authenticator)), ("supplicant", ("supplicant", Native.Interface.GigabitEthernet.Dot1x.Supplicant)), ("timeout", ("timeout", Native.Interface.GigabitEthernet.Dot1x.Timeout))])
                    self._leafs = OrderedDict([
                        ('credentials', (YLeaf(YType.str, 'credentials'), ['str'])),
                        ('max_reauth_req', (YLeaf(YType.uint8, 'max-reauth-req'), ['int'])),
                        ('max_req', (YLeaf(YType.uint8, 'max-req'), ['int'])),
                        ('max_start', (YLeaf(YType.uint8, 'max-start'), ['int'])),
                        ('pae', (YLeaf(YType.enumeration, 'pae'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Dot1x.Pae')])),
                    ])
                    self.credentials = None
                    self.max_reauth_req = None
                    self.max_req = None
                    self.max_start = None
                    self.pae = None

                    self.authenticator = Native.Interface.GigabitEthernet.Dot1x.Authenticator()
                    self.authenticator.parent = self
                    self._children_name_map["authenticator"] = "authenticator"

                    self.supplicant = Native.Interface.GigabitEthernet.Dot1x.Supplicant()
                    self.supplicant.parent = self
                    self._children_name_map["supplicant"] = "supplicant"

                    self.timeout = Native.Interface.GigabitEthernet.Dot1x.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"
                    self._segment_path = lambda: "Cisco-IOS-XE-dot1x:dot1x"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Dot1x, ['credentials', 'max_reauth_req', 'max_req', 'max_start', 'pae'], name, value)

                class Pae(Enum):
                    """
                    Pae (Enum Class)

                    Set 802.1x interface pae type

                    .. data:: authenticator = 0

                    .. data:: supplicant = 1

                    .. data:: both = 2

                    """

                    authenticator = Enum.YLeaf(0, "authenticator")

                    supplicant = Enum.YLeaf(1, "supplicant")

                    both = Enum.YLeaf(2, "both")



                class Authenticator(Entity):
                    """
                    Configure authenticator parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP authenticator parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Dot1x.Authenticator.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Dot1x.Authenticator, self).__init__()

                        self.yang_name = "authenticator"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.GigabitEthernet.Dot1x.Authenticator.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.GigabitEthernet.Dot1x.Authenticator.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "authenticator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Dot1x.Authenticator, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP authenticator parameters
                        
                        .. attribute:: profile
                        
                        	EAP authenticator profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Dot1x.Authenticator.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "authenticator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Dot1x.Authenticator.Eap, ['profile'], name, value)


                class Supplicant(Entity):
                    """
                    Configure supplicant parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP supplicant parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Dot1x.Supplicant.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Dot1x.Supplicant, self).__init__()

                        self.yang_name = "supplicant"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.GigabitEthernet.Dot1x.Supplicant.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.GigabitEthernet.Dot1x.Supplicant.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "supplicant"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Dot1x.Supplicant, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP supplicant parameters
                        
                        .. attribute:: profile
                        
                        	EAP supplicant profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Dot1x.Supplicant.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "supplicant"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Dot1x.Supplicant.Eap, ['profile'], name, value)


                class Timeout(Entity):
                    """
                    Various Timeouts
                    
                    .. attribute:: auth_period
                    
                    	Timeout for authenticator reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: held_period
                    
                    	Timeout for authentication retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: quiet_period
                    
                    	QuietPeriod in Seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ratelimit_period
                    
                    	Ratelimit Period in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: server_timeout
                    
                    	Timeout for Radius Retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: start_period
                    
                    	Timeout for EAPOL\-start retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: supp_timeout
                    
                    	Timeout for supplicant reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: tx_period
                    
                    	Timeout for supplicant retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Dot1x.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auth_period', (YLeaf(YType.uint16, 'auth-period'), ['int'])),
                            ('held_period', (YLeaf(YType.uint16, 'held-period'), ['int'])),
                            ('quiet_period', (YLeaf(YType.uint16, 'quiet-period'), ['int'])),
                            ('ratelimit_period', (YLeaf(YType.uint16, 'ratelimit-period'), ['int'])),
                            ('server_timeout', (YLeaf(YType.uint16, 'server-timeout'), ['int'])),
                            ('start_period', (YLeaf(YType.uint16, 'start-period'), ['int'])),
                            ('supp_timeout', (YLeaf(YType.uint16, 'supp-timeout'), ['int'])),
                            ('tx_period', (YLeaf(YType.uint16, 'tx-period'), ['int'])),
                        ])
                        self.auth_period = None
                        self.held_period = None
                        self.quiet_period = None
                        self.ratelimit_period = None
                        self.server_timeout = None
                        self.start_period = None
                        self.supp_timeout = None
                        self.tx_period = None
                        self._segment_path = lambda: "timeout"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Dot1x.Timeout, ['auth_period', 'held_period', 'quiet_period', 'ratelimit_period', 'server_timeout', 'start_period', 'supp_timeout', 'tx_period'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpdufilter
                
                	Don't send or receive BPDUs on this interface
                	**type**\:  :py:class:`Bpdufilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SpanningTree.Bpdufilter>`
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SpanningTree.Bpduguard>`
                
                .. attribute:: cost
                
                	To set the path cost of the interface
                	**type**\: int
                
                	**range:** 1..200000000
                
                .. attribute:: guard
                
                	Change an interface's spanning tree guard mode
                	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SpanningTree.Guard>`
                
                .. attribute:: link_type
                
                	Specify a link type for spanning tree tree protocol use
                	**type**\:  :py:class:`LinkType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SpanningTree.LinkType>`
                
                .. attribute:: portfast
                
                	Spanning tree portfast options
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                .. attribute:: port_priority
                
                	Spanning tree port\-priority options
                	**type**\: int
                
                	**range:** 0..240
                
                .. attribute:: vlan
                
                	VLAN Switch Spanning Tree
                	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SpanningTree.Vlan>`
                
                .. attribute:: loopguard
                
                	Spanning tree loopguard options
                	**type**\:  :py:class:`Loopguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SpanningTree.Loopguard>`
                
                .. attribute:: mst
                
                	Per interface MST configurations
                	**type**\:  :py:class:`Mst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SpanningTree.Mst>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Interface.GigabitEthernet.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Interface.GigabitEthernet.SpanningTree.Portfast)), ("vlan", ("vlan", Native.Interface.GigabitEthernet.SpanningTree.Vlan)), ("loopguard", ("loopguard", Native.Interface.GigabitEthernet.SpanningTree.Loopguard)), ("mst", ("mst", Native.Interface.GigabitEthernet.SpanningTree.Mst))])
                    self._leafs = OrderedDict([
                        ('bpdufilter', (YLeaf(YType.enumeration, 'bpdufilter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.SpanningTree.Bpdufilter')])),
                        ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ('guard', (YLeaf(YType.enumeration, 'guard'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.SpanningTree.Guard')])),
                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.SpanningTree.LinkType')])),
                        ('port_priority', (YLeaf(YType.uint8, 'port-priority'), ['int'])),
                    ])
                    self.bpdufilter = None
                    self.cost = None
                    self.guard = None
                    self.link_type = None
                    self.port_priority = None

                    self.bpduguard = Native.Interface.GigabitEthernet.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"

                    self.loopguard = Native.Interface.GigabitEthernet.SpanningTree.Loopguard()
                    self.loopguard.parent = self
                    self._children_name_map["loopguard"] = "loopguard"

                    self.mst = Native.Interface.GigabitEthernet.SpanningTree.Mst()
                    self.mst.parent = self
                    self._children_name_map["mst"] = "mst"

                    self.vlan = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:spanning-tree"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.SpanningTree, ['bpdufilter', 'cost', 'guard', 'link_type', 'port_priority'], name, value)

                class Bpdufilter(Enum):
                    """
                    Bpdufilter (Enum Class)

                    Don't send or receive BPDUs on this interface

                    .. data:: disable = 0

                    .. data:: enable = 1

                    """

                    disable = Enum.YLeaf(0, "disable")

                    enable = Enum.YLeaf(1, "enable")


                class Guard(Enum):
                    """
                    Guard (Enum Class)

                    Change an interface's spanning tree guard mode

                    .. data:: loop = 0

                    .. data:: none = 1

                    .. data:: root = 2

                    """

                    loop = Enum.YLeaf(0, "loop")

                    none = Enum.YLeaf(1, "none")

                    root = Enum.YLeaf(2, "root")


                class LinkType(Enum):
                    """
                    LinkType (Enum Class)

                    Specify a link type for spanning tree tree protocol use

                    .. data:: point_to_point = 0

                    .. data:: shared = 1

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")

                    shared = Enum.YLeaf(1, "shared")



                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.disable = None
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.SpanningTree.Bpduguard, ['disable', 'enable'], name, value)


                class Portfast(Entity):
                    """
                    Spanning tree portfast options
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk
                    
                    	Enable portfast on the interface even in trunk mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                        ])
                        self.disable = None
                        self.trunk = None
                        self.edge = None
                        self._segment_path = lambda: "portfast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.SpanningTree.Portfast, ['disable', 'trunk', 'edge'], name, value)


                class Vlan(Entity):
                    """
                    VLAN Switch Spanning Tree
                    
                    .. attribute:: vlan_ids  (key)
                    
                    	vlan range, example\: 1,3\-5,7,9\-11
                    	**type**\: str
                    
                    .. attribute:: cost
                    
                    	<1\-200000000> Spanning\-tree cost
                    	**type**\: int
                    
                    	**range:** 1..200000000
                    
                    .. attribute:: port_priority
                    
                    	<0\-240> port priority in increments of 16
                    	**type**\: int
                    
                    	**range:** 0..240
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.SpanningTree.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vlan_ids']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_ids', (YLeaf(YType.str, 'vlan-ids'), ['str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                        ])
                        self.vlan_ids = None
                        self.cost = None
                        self.port_priority = None
                        self._segment_path = lambda: "vlan" + "[vlan-ids='" + str(self.vlan_ids) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.SpanningTree.Vlan, ['vlan_ids', 'cost', 'port_priority'], name, value)


                class Loopguard(Entity):
                    """
                    Spanning tree loopguard options
                    
                    .. attribute:: default
                    
                    	Enable loopguard by default on all ports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.SpanningTree.Loopguard, self).__init__()

                        self.yang_name = "loopguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.default = None
                        self._segment_path = lambda: "loopguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.SpanningTree.Loopguard, ['default'], name, value)


                class Mst(Entity):
                    """
                    Per interface MST configurations
                    
                    .. attribute:: mst_instance
                    
                    	
                    	**type**\: list of  		 :py:class:`MstInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.SpanningTree.Mst.MstInstance>`
                    
                    .. attribute:: pre_standard
                    
                    	Force pre\-standard MST BPDU transmission on port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.SpanningTree.Mst, self).__init__()

                        self.yang_name = "mst"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mst-instance", ("mst_instance", Native.Interface.GigabitEthernet.SpanningTree.Mst.MstInstance))])
                        self._leafs = OrderedDict([
                            ('pre_standard', (YLeaf(YType.empty, 'pre-standard'), ['Empty'])),
                        ])
                        self.pre_standard = None

                        self.mst_instance = YList(self)
                        self._segment_path = lambda: "mst"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.SpanningTree.Mst, ['pre_standard'], name, value)


                    class MstInstance(Entity):
                        """
                        
                        
                        .. attribute:: instance  (key)
                        
                        	MST instance list, example 0,2\-4,6,8\-12
                        	**type**\: str
                        
                        .. attribute:: cost
                        
                        	<1\-200000000> Spanning\-tree cost
                        	**type**\: int
                        
                        	**range:** 1..200000000
                        
                        .. attribute:: port_priority
                        
                        	<0\-240> port priority in increments of 16
                        	**type**\: int
                        
                        	**range:** 0..240
                        
                        

                        """

                        _prefix = 'ios-stp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.SpanningTree.Mst.MstInstance, self).__init__()

                            self.yang_name = "mst-instance"
                            self.yang_parent_name = "mst"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                            ])
                            self.instance = None
                            self.cost = None
                            self.port_priority = None
                            self._segment_path = lambda: "mst-instance" + "[instance='" + str(self.instance) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.SpanningTree.Mst.MstInstance, ['instance', 'cost', 'port_priority'], name, value)


            class Performance(Entity):
                """
                Global performance monitor configuration
                
                .. attribute:: monitor
                
                	monitor
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Performance.Monitor>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Performance, self).__init__()

                    self.yang_name = "performance"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.GigabitEthernet.Performance.Monitor))])
                    self._leafs = OrderedDict()

                    self.monitor = Native.Interface.GigabitEthernet.Performance.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"
                    self._segment_path = lambda: "Cisco-IOS-XE-ezpm:performance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Performance, [], name, value)


                class Monitor(Entity):
                    """
                    monitor
                    
                    .. attribute:: context
                    
                    	Select ezPM context
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Performance.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "performance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('context', (YLeafList(YType.str, 'context'), ['str'])),
                        ])
                        self.context = []
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Performance.Monitor, ['context'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Umbrella, ['out', 'in_'], name, value)


            class Lldp(Entity):
                """
                LLDP interface subcommands
                
                .. attribute:: receive
                
                	Enable LLDP reception on interface
                	**type**\: bool
                
                .. attribute:: transmit
                
                	Enable LLDP transmission on interface
                	**type**\: bool
                
                

                """

                _prefix = 'ios-lldp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Lldp, self).__init__()

                    self.yang_name = "lldp"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                        ('transmit', (YLeaf(YType.boolean, 'transmit'), ['bool'])),
                    ])
                    self.receive = None
                    self.transmit = None
                    self._segment_path = lambda: "Cisco-IOS-XE-lldp:lldp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Lldp, ['receive', 'transmit'], name, value)


            class Vrrp(Entity):
                """
                Configure VRRP
                
                .. attribute:: vrrp_group
                
                	
                	**type**\: list of  		 :py:class:`VrrpGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup>`
                
                .. attribute:: vrrp_group_v2
                
                	vrrp version 2
                	**type**\: list of  		 :py:class:`VrrpGroupV2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2>`
                
                .. attribute:: delay
                
                	
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.Delay>`
                
                

                """

                _prefix = 'ios-vrrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Vrrp, self).__init__()

                    self.yang_name = "vrrp"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrrp-group", ("vrrp_group", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup)), ("vrrp-group-v2", ("vrrp_group_v2", Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2)), ("delay", ("delay", Native.Interface.GigabitEthernet.Vrrp.Delay))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.GigabitEthernet.Vrrp.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.vrrp_group = YList(self)
                    self.vrrp_group_v2 = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vrrp:vrrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp, [], name, value)


                class VrrpGroup(Entity):
                    """
                    
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: address_family
                    
                    	Address family of the group
                    	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup, self).__init__()

                        self.yang_name = "vrrp-group"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("address-family", ("address_family", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                        ])
                        self.group_id = None

                        self.address_family = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"
                        self._segment_path = lambda: "vrrp-group" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup, ['group_id'], name, value)


                    class AddressFamily(Entity):
                        """
                        Address family of the group
                        
                        .. attribute:: ipv4
                        
                        	IPv4 Address family
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	IPv6 Address family
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily, self).__init__()

                            self.yang_name = "address-family"
                            self.yang_parent_name = "vrrp-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4)), ("ipv6", ("ipv6", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = None
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "address-family"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily, [], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 Address family
                            
                            .. attribute:: vrrpv2
                            
                            	Set VRRPv2 compatibility mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: address
                            
                            	Set the IPv4 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address)), ("preempt", ("preempt", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt)), ("timers", ("timers", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers)), ("track", ("track", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track)), ("vrrs", ("vrrs", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('vrrpv2', (YLeaf(YType.empty, 'vrrpv2'), ['Empty'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.vrrpv2 = None
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4, ['vrrpv2', 'description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv4 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary>`
                                
                                .. attribute:: secondary
                                
                                	
                                	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary)), ("secondary", ("secondary", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.secondary = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv4 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, ['address', 'primary'], name, value)


                                class Secondary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: secondary
                                    
                                    	Make this IPv4 address a secondary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, self).__init__()

                                        self.yang_name = "secondary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.secondary = None
                                        self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, ['address', 'secondary'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, ['leader'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 Address family
                            
                            .. attribute:: address
                            
                            	Set the IPv6 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address)), ("preempt", ("preempt", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt)), ("timers", ("timers", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers)), ("track", ("track", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track)), ("vrrs", ("vrrs", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6, ['description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv6 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary>`
                                
                                .. attribute:: ipv6_prefix
                                
                                	
                                	**type**\: list of  		 :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary)), ("ipv6-prefix", ("ipv6_prefix", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.ipv6_prefix = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipv6_link_local
                                    
                                    	IPv6 link\-local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv6 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_link_local', (YLeaf(YType.str, 'ipv6-link-local'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.ipv6_link_local = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, ['ipv6_link_local', 'primary'], name, value)


                                class Ipv6Prefix(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, self).__init__()

                                        self.yang_name = "ipv6-prefix"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                        ])
                                        self.prefix = None
                                        self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, ['prefix'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, ['leader'], name, value)


                class VrrpGroupV2(Entity):
                    """
                    vrrp version 2
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: authentication
                    
                    	
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Authentication>`
                    
                    .. attribute:: description
                    
                    	Up to 80 characters describing this group
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Ip>`
                    
                    .. attribute:: name
                    
                    	Unique VRRS identifier (max 48 characters)
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: shutdown
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: timers
                    
                    	
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Timers>`
                    
                    .. attribute:: track
                    
                    	
                    	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Track>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2, self).__init__()

                        self.yang_name = "vrrp-group-v2"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Authentication)), ("ip", ("ip", Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Ip)), ("preempt", ("preempt", Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Preempt)), ("timers", ("timers", Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Timers)), ("track", ("track", Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Track))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.group_id = None
                        self.description = None
                        self.name = None
                        self.priority = None
                        self.shutdown = None

                        self.authentication = Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.timers = Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Track()
                        self.track.parent = self
                        self._children_name_map["track"] = "track"
                        self._segment_path = lambda: "vrrp-group-v2" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2, ['group_id', 'description', 'name', 'priority', 'shutdown'], name, value)


                    class Authentication(Entity):
                        """
                        
                        
                        .. attribute:: text
                        
                        	authentication string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.text = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Authentication, ['text'], name, value)


                    class Ip(Entity):
                        """
                        
                        
                        .. attribute:: vrrp_ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`VrrpIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrrp-ipv4", ("vrrp_ipv4", Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4))])
                            self._leafs = OrderedDict()

                            self.vrrp_ipv4 = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Ip, [], name, value)


                        class VrrpIpv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, self).__init__()

                                self.yang_name = "vrrp-ipv4"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.ipv4 = None
                                self.secondary = None
                                self._segment_path = lambda: "vrrp-ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, ['ipv4', 'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        
                        
                        .. attribute:: delay
                        
                        	
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            
                            
                            .. attribute:: minimum
                            
                            	Seconds to delay
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                ])
                                self.minimum = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay, ['minimum'], name, value)


                    class Timers(Entity):
                        """
                        
                        
                        .. attribute:: advertise
                        
                        	
                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise>`
                        
                        .. attribute:: learn
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise))])
                            self._leafs = OrderedDict([
                                ('learn', (YLeaf(YType.empty, 'learn'), ['Empty'])),
                            ])
                            self.learn = None

                            self.advertise = Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise()
                            self.advertise.parent = self
                            self._children_name_map["advertise"] = "advertise"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Timers, ['learn'], name, value)


                        class Advertise(Entity):
                            """
                            
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Advertisement interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..999
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise, self).__init__()

                                self.yang_name = "advertise"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint8, 'interval'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.interval = None
                                self.msec = None
                                self._segment_path = lambda: "advertise"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise, ['interval', 'msec'], name, value)


                    class Track(Entity):
                        """
                        
                        
                        .. attribute:: event
                        
                        	
                        	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Track.Event>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("event", ("event", Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Track.Event))])
                            self._leafs = OrderedDict()

                            self.event = YList(self)
                            self._segment_path = lambda: "track"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Track, [], name, value)


                        class Event(Entity):
                            """
                            
                            
                            .. attribute:: object_id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: decrement
                            
                            	Decrement value
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Track.Event, self).__init__()

                                self.yang_name = "event"
                                self.yang_parent_name = "track"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['object_id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                    ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ])
                                self.object_id = None
                                self.decrement = None
                                self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.VrrpGroupV2.Track.Event, ['object_id', 'decrement'], name, value)


                class Delay(Entity):
                    """
                    
                    
                    .. attribute:: reload
                    
                    	Seconds to delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: minimum
                    
                    	Seconds to delay after interface up
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Vrrp.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                        ])
                        self.reload = None
                        self.minimum = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Vrrp.Delay, ['reload', 'minimum'], name, value)


            class Ospfv3(Entity):
                """
                OSPFv3 interface commands
                
                .. attribute:: process_id
                
                	
                	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId>`
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Authentication>`
                
                .. attribute:: bfd
                
                	Enable BFD on this interface
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: cost
                
                	Route cost of this interface
                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Cost>`
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: demand_circuit
                
                	OSPF Demand Circuit
                	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.DemandCircuit>`
                
                	**presence node**\: True
                
                .. attribute:: encryption
                
                	Enable encryption
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption>`
                
                .. attribute:: flood_reduction
                
                	OSPF Flood Reduction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: manet
                
                	Mobile Adhoc Networking options
                	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Manet>`
                
                .. attribute:: mtu_ignore
                
                	Ignores the MTU in DBD packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: multi_area
                
                	Set the OSPF multi\-area ID
                	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.MultiArea>`
                
                .. attribute:: neighbor
                
                	OSPF neighbor
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Neighbor>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Network>`
                
                .. attribute:: prefix_suppression
                
                	OSPF prefix suppression
                	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.PrefixSuppression>`
                
                	**presence node**\: True
                
                .. attribute:: priority
                
                	Router priority
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: retransmit_interval
                
                	Time between retransmitting lost link state advertisements
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Shut down the interface in OSPFv3
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transmit_delay
                
                	Link state transmit delay
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Ospfv3, self).__init__()

                    self.yang_name = "ospfv3"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.GigabitEthernet.Ospfv3.ProcessId)), ("authentication", ("authentication", Native.Interface.GigabitEthernet.Ospfv3.Authentication)), ("bfd", ("bfd", Native.Interface.GigabitEthernet.Ospfv3.Bfd)), ("cost", ("cost", Native.Interface.GigabitEthernet.Ospfv3.Cost)), ("database-filter", ("database_filter", Native.Interface.GigabitEthernet.Ospfv3.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.GigabitEthernet.Ospfv3.DemandCircuit)), ("encryption", ("encryption", Native.Interface.GigabitEthernet.Ospfv3.Encryption)), ("manet", ("manet", Native.Interface.GigabitEthernet.Ospfv3.Manet)), ("multi-area", ("multi_area", Native.Interface.GigabitEthernet.Ospfv3.MultiArea)), ("neighbor", ("neighbor", Native.Interface.GigabitEthernet.Ospfv3.Neighbor)), ("network", ("network", Native.Interface.GigabitEthernet.Ospfv3.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.GigabitEthernet.Ospfv3.PrefixSuppression))])
                    self._leafs = OrderedDict([
                        ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                        ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                        ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                    ])
                    self.dead_interval = None
                    self.flood_reduction = None
                    self.hello_interval = None
                    self.mtu_ignore = None
                    self.priority = None
                    self.retransmit_interval = None
                    self.shutdown = None
                    self.transmit_delay = None

                    self.authentication = Native.Interface.GigabitEthernet.Ospfv3.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"

                    self.cost = Native.Interface.GigabitEthernet.Ospfv3.Cost()
                    self.cost.parent = self
                    self._children_name_map["cost"] = "cost"

                    self.database_filter = Native.Interface.GigabitEthernet.Ospfv3.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"

                    self.demand_circuit = None
                    self._children_name_map["demand_circuit"] = "demand-circuit"

                    self.encryption = Native.Interface.GigabitEthernet.Ospfv3.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.manet = Native.Interface.GigabitEthernet.Ospfv3.Manet()
                    self.manet.parent = self
                    self._children_name_map["manet"] = "manet"

                    self.multi_area = Native.Interface.GigabitEthernet.Ospfv3.MultiArea()
                    self.multi_area.parent = self
                    self._children_name_map["multi_area"] = "multi-area"

                    self.network = Native.Interface.GigabitEthernet.Ospfv3.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.prefix_suppression = None
                    self._children_name_map["prefix_suppression"] = "prefix-suppression"

                    self.process_id = YList(self)
                    self.neighbor = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3, ['dead_interval', u'flood_reduction', 'hello_interval', u'mtu_ignore', 'priority', 'retransmit_interval', u'shutdown', 'transmit_delay'], name, value)


                class ProcessId(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: manet
                    
                    	Mobile Adhoc Networking options
                    	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.MultiArea>`
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Network>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipv4
                    
                    	Specify parameters for IPv4
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Specify parameters for IPv6
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId, self).__init__()

                        self.yang_name = "process-id"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Authentication)), ("bfd", ("bfd", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Bfd)), ("cost", ("cost", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost)), ("database-filter", ("database_filter", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.FloodReduction)), ("manet", ("manet", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.MultiArea)), ("neighbor", ("neighbor", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Neighbor)), ("network", ("network", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Shutdown)), ("ipv4", ("ipv4", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4)), ("ipv6", ("ipv6", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.id = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.cost = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.database_filter = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.manet = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet()
                        self.manet.parent = self
                        self._children_name_map["manet"] = "manet"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.multi_area = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.network = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.ipv4 = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId, [u'id', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\: str
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.null = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Authentication, [u'key_chain', u'null'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Bfd, ['disable'], name, value)


                    class Cost(Entity):
                        """
                        Route cost of this interface
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dynamic
                        
                        	Specify dynamic cost options
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.dynamic = None
                            self._children_name_map["dynamic"] = "dynamic"
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost, [u'value'], name, value)


                        class Dynamic(Entity):
                            """
                            Specify dynamic cost options
                            
                            .. attribute:: default
                            
                            	Specify default link metric value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: hysteresis
                            
                            	Specify hysteresis value for LSA dampening
                            	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: weight
                            
                            	Specify weight to be placed on individual metrics
                            	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ])
                                self.default = None

                                self.hysteresis = None
                                self._children_name_map["hysteresis"] = "hysteresis"

                                self.weight = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight()
                                self.weight.parent = self
                                self._children_name_map["weight"] = "weight"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic, [u'default'], name, value)


                            class Hysteresis(Entity):
                                """
                                Specify hysteresis value for LSA dampening
                                
                                .. attribute:: percent
                                
                                	Specify hysteresis percent changed
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold
                                
                                	Specify hysteresis threshold value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, self).__init__()

                                    self.yang_name = "hysteresis"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "hysteresis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                            class Weight(Entity):
                                """
                                Specify weight to be placed on individual metrics
                                
                                .. attribute:: l2_factor
                                
                                	Specify weight to be given to L2\-factor metric
                                	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: latency
                                
                                	Specify weight to be given to latency metric
                                	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: resources
                                
                                	Specify weight to be given to resources metric
                                	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: throughput
                                
                                	Specify weight to be given to throughput metric
                                	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, self).__init__()

                                    self.yang_name = "weight"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput))])
                                    self._leafs = OrderedDict()

                                    self.l2_factor = None
                                    self._children_name_map["l2_factor"] = "L2-factor"

                                    self.latency = None
                                    self._children_name_map["latency"] = "latency"

                                    self.resources = None
                                    self._children_name_map["resources"] = "resources"

                                    self.throughput = None
                                    self._children_name_map["throughput"] = "throughput"
                                    self._segment_path = lambda: "weight"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, [], name, value)


                                class L2Factor(Entity):
                                    """
                                    Specify weight to be given to L2\-factor metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                        self.yang_name = "L2-factor"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "L2-factor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                class Latency(Entity):
                                    """
                                    Specify weight to be given to latency metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, self).__init__()

                                        self.yang_name = "latency"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "latency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                class Resources(Entity):
                                    """
                                    Specify weight to be given to resources metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, self).__init__()

                                        self.yang_name = "resources"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "resources"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                class Throughput(Entity):
                                    """
                                    Specify weight to be given to throughput metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, self).__init__()

                                        self.yang_name = "throughput"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "throughput"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.ProcessId.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.DatabaseFilter, [u'all', u'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.DemandCircuit, [u'disable', u'ignore'], name, value)


                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.FloodReduction, [u'disable'], name, value)


                    class Manet(Entity):
                        """
                        Mobile Adhoc Networking options
                        
                        .. attribute:: peering
                        
                        	MANET Peering options
                        	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet.Peering>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet, self).__init__()

                            self.yang_name = "manet"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet.Peering))])
                            self._leafs = OrderedDict()

                            self.peering = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet.Peering()
                            self.peering.parent = self
                            self._children_name_map["peering"] = "peering"
                            self._segment_path = lambda: "manet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet, [], name, value)


                        class Peering(Entity):
                            """
                            MANET Peering options
                            
                            .. attribute:: cost
                            
                            	Redundant path cost improvement required to peer
                            	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost>`
                            
                            .. attribute:: link_metrics
                            
                            	Require link metrics
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet.Peering, self).__init__()

                                self.yang_name = "peering"
                                self.yang_parent_name = "manet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost))])
                                self._leafs = OrderedDict([
                                    ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                ])
                                self.link_metrics = None

                                self.cost = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost()
                                self.cost.parent = self
                                self._children_name_map["cost"] = "cost"
                                self._segment_path = lambda: "peering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet.Peering, [u'link_metrics'], name, value)


                            class Cost(Entity):
                                """
                                Redundant path cost improvement required to peer
                                
                                .. attribute:: percent
                                
                                	Relative incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                .. attribute:: threshold
                                
                                	Absolute incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, self).__init__()

                                    self.yang_name = "cost"
                                    self.yang_parent_name = "peering"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "cost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.MtuIgnore, [u'disable'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: disable
                        
                        	disable OSPF multi\-area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.disable = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.MultiArea, [u'id', u'cost', u'disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.PrefixSuppression, ['disable'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Shutdown, [u'disable'], name, value)


                    class Ipv4(Entity):
                        """
                        Specify parameters for IPv4
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Area)), ("authentication", ("authentication", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication)), ("bfd", ("bfd", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd)), ("cost", ("cost", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost)), ("database-filter", ("database_filter", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction)), ("manet", ("manet", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea)), ("neighbor", ("neighbor", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor)), ("network", ("network", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 64..95
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, [u'disable'], name, value)


                    class Ipv6(Entity):
                        """
                        Specify parameters for IPv6
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Area)), ("authentication", ("authentication", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication)), ("bfd", ("bfd", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd)), ("cost", ("cost", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost)), ("database-filter", ("database_filter", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction)), ("manet", ("manet", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea)), ("neighbor", ("neighbor", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor)), ("network", ("network", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 0..31
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, [u'disable'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: key_chain
                    
                    	Use a key\-chain for cryptographic authentication keys
                    	**type**\: str
                    
                    .. attribute:: null
                    
                    	Use no authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec authentication
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.null = None

                        self.ipsec = Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Authentication, [u'key_chain', u'null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec authentication
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 256..4294967295
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5>`
                        
                        .. attribute:: sha1
                        
                        	Use SHA\-1 authentication
                        	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                            ])
                            self.spi = None

                            self.md5 = Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"

                            self.sha1 = Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1()
                            self.sha1.parent = self
                            self._children_name_map["sha1"] = "sha1"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec, ['spi'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class Sha1(Entity):
                            """
                            Use SHA\-1 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1, self).__init__()

                                self.yang_name = "sha1"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "sha1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "sha1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                class Bfd(Entity):
                    """
                    Enable BFD on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BFD on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Bfd, ['disable'], name, value)


                class Cost(Entity):
                    """
                    Route cost of this interface
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: dynamic
                    
                    	Specify dynamic cost options
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.Cost, self).__init__()

                        self.yang_name = "cost"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.dynamic = None
                        self._children_name_map["dynamic"] = "dynamic"
                        self._segment_path = lambda: "cost"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Cost, [u'value'], name, value)


                    class Dynamic(Entity):
                        """
                        Specify dynamic cost options
                        
                        .. attribute:: default
                        
                        	Specify default link metric value
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hysteresis
                        
                        	Specify hysteresis value for LSA dampening
                        	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: weight
                        
                        	Specify weight to be placed on individual metrics
                        	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic, self).__init__()

                            self.yang_name = "dynamic"
                            self.yang_parent_name = "cost"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                            ])
                            self.default = None

                            self.hysteresis = None
                            self._children_name_map["hysteresis"] = "hysteresis"

                            self.weight = Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight()
                            self.weight.parent = self
                            self._children_name_map["weight"] = "weight"
                            self._segment_path = lambda: "dynamic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic, [u'default'], name, value)


                        class Hysteresis(Entity):
                            """
                            Specify hysteresis value for LSA dampening
                            
                            .. attribute:: percent
                            
                            	Specify hysteresis percent changed
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold
                            
                            	Specify hysteresis threshold value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis, self).__init__()

                                self.yang_name = "hysteresis"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "hysteresis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                        class Weight(Entity):
                            """
                            Specify weight to be placed on individual metrics
                            
                            .. attribute:: l2_factor
                            
                            	Specify weight to be given to L2\-factor metric
                            	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: latency
                            
                            	Specify weight to be given to latency metric
                            	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: resources
                            
                            	Specify weight to be given to resources metric
                            	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: throughput
                            
                            	Specify weight to be given to throughput metric
                            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight, self).__init__()

                                self.yang_name = "weight"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput))])
                                self._leafs = OrderedDict()

                                self.l2_factor = None
                                self._children_name_map["l2_factor"] = "L2-factor"

                                self.latency = None
                                self._children_name_map["latency"] = "latency"

                                self.resources = None
                                self._children_name_map["resources"] = "resources"

                                self.throughput = None
                                self._children_name_map["throughput"] = "throughput"
                                self._segment_path = lambda: "weight"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight, [], name, value)


                            class L2Factor(Entity):
                                """
                                Specify weight to be given to L2\-factor metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                    self.yang_name = "L2-factor"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "L2-factor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                            class Latency(Entity):
                                """
                                Specify weight to be given to latency metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, self).__init__()

                                    self.yang_name = "latency"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "latency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                            class Resources(Entity):
                                """
                                Specify weight to be given to resources metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, self).__init__()

                                    self.yang_name = "resources"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "resources"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                            class Throughput(Entity):
                                """
                                Specify weight to be given to throughput metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, self).__init__()

                                    self.yang_name = "throughput"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "throughput"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.DatabaseFilter.All')])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.DatabaseFilter, [u'all'], name, value)

                    class All(Enum):
                        """
                        All (Enum Class)

                        Filter all LSA

                        .. data:: out = 0

                        """

                        out = Enum.YLeaf(0, "out")



                class DemandCircuit(Entity):
                    """
                    OSPF Demand Circuit
                    
                    .. attribute:: ignore
                    
                    	Ignore demand circuit auto\-negotiation requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.DemandCircuit, self).__init__()

                        self.yang_name = "demand-circuit"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.ignore = None
                        self._segment_path = lambda: "demand-circuit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.DemandCircuit, [u'ignore'], name, value)


                class Encryption(Entity):
                    """
                    Enable encryption
                    
                    .. attribute:: null
                    
                    	No IPsec encryption on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec encryption
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec))])
                        self._leafs = OrderedDict([
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.null = None

                        self.ipsec = Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Encryption, ['null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec encryption
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: esp
                        
                        	Use ESP encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec_3des
                        
                        	Use 3DES encryption
                        	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des>`
                        
                        .. attribute:: aes_cbc
                        
                        	Use AES\-CBC encryption
                        	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                            ])
                            self.spi = None
                            self.esp = None

                            self.ipsec_3des = Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des()
                            self.ipsec_3des.parent = self
                            self._children_name_map["ipsec_3des"] = "ipsec_3des"

                            self.aes_cbc = Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc()
                            self.aes_cbc.parent = self
                            self._children_name_map["aes_cbc"] = "aes-cbc"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec, ['spi', 'esp'], name, value)


                        class Ipsec3des(Entity):
                            """
                            Use 3DES encryption
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, self).__init__()

                                self.yang_name = "ipsec_3des"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "ipsec_3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "ipsec_3des"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class AesCbc(Entity):
                            """
                            Use AES\-CBC encryption
                            
                            .. attribute:: aes_cbc_128
                            
                            	Use 128 bit key
                            	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128>`
                            
                            .. attribute:: aes_192
                            
                            	Use 192 bit key
                            	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192>`
                            
                            .. attribute:: aes_256
                            
                            	Use 256 bit key
                            	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc, self).__init__()

                                self.yang_name = "aes-cbc"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256))])
                                self._leafs = OrderedDict()

                                self.aes_cbc_128 = Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128()
                                self.aes_cbc_128.parent = self
                                self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                self.aes_192 = Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192()
                                self.aes_192.parent = self
                                self._children_name_map["aes_192"] = "aes-192"

                                self.aes_256 = Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256()
                                self.aes_256.parent = self
                                self._children_name_map["aes_256"] = "aes-256"
                                self._segment_path = lambda: "aes-cbc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc, [], name, value)


                            class AesCbc128(Entity):
                                """
                                Use 128 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                    self.yang_name = "aes-cbc-128"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-cbc-128"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-cbc-128"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes192(Entity):
                                """
                                Use 192 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                    self.yang_name = "aes-192"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-192"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-192"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes256(Entity):
                                """
                                Use 256 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                    self.yang_name = "aes-256"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-256"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-256"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                class Manet(Entity):
                    """
                    Mobile Adhoc Networking options
                    
                    .. attribute:: peering
                    
                    	MANET Peering options
                    	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Manet.Peering>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.Manet, self).__init__()

                        self.yang_name = "manet"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.GigabitEthernet.Ospfv3.Manet.Peering))])
                        self._leafs = OrderedDict()

                        self.peering = Native.Interface.GigabitEthernet.Ospfv3.Manet.Peering()
                        self.peering.parent = self
                        self._children_name_map["peering"] = "peering"
                        self._segment_path = lambda: "manet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Manet, [], name, value)


                    class Peering(Entity):
                        """
                        MANET Peering options
                        
                        .. attribute:: cost
                        
                        	Redundant path cost improvement required to peer
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Manet.Peering.Cost>`
                        
                        .. attribute:: link_metrics
                        
                        	Require link metrics
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.Manet.Peering, self).__init__()

                            self.yang_name = "peering"
                            self.yang_parent_name = "manet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.GigabitEthernet.Ospfv3.Manet.Peering.Cost))])
                            self._leafs = OrderedDict([
                                ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                            ])
                            self.link_metrics = None

                            self.cost = Native.Interface.GigabitEthernet.Ospfv3.Manet.Peering.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"
                            self._segment_path = lambda: "peering"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Manet.Peering, [u'link_metrics'], name, value)


                        class Cost(Entity):
                            """
                            Redundant path cost improvement required to peer
                            
                            .. attribute:: percent
                            
                            	Relative incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: threshold
                            
                            	Absolute incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Ospfv3.Manet.Peering.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "peering"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                class MultiArea(Entity):
                    """
                    Set the OSPF multi\-area ID
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.MultiArea, self).__init__()

                        self.yang_name = "multi-area"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self._segment_path = lambda: "multi-area"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.MultiArea, [u'id', u'cost'], name, value)


                class Neighbor(Entity):
                    """
                    OSPF neighbor
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	OSPF cost for point\-to\-multipoint neighbor
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Neighbor.DatabaseFilter>`
                    
                    .. attribute:: poll_interval
                    
                    	OSPF dead\-router polling interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: priority
                    
                    	OSPF priority of non\-broadcast neighbor
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.GigabitEthernet.Ospfv3.Neighbor.DatabaseFilter))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self.poll_interval = None
                        self.priority = None

                        self.database_filter = Native.Interface.GigabitEthernet.Ospfv3.Neighbor.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Neighbor.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.Neighbor.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Ospfv3.Neighbor.DatabaseFilter.All')])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Neighbor.DatabaseFilter, ['all'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                class Network(Entity):
                    """
                    Network type
                    
                    .. attribute:: broadcast
                    
                    	Specify OSPF broadcast multi\-access network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: manet
                    
                    	Specify MANET OSPF interface type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: non_broadcast
                    
                    	Specify OSPF NBMA network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: point_to_multipoint
                    
                    	Specify OSPF point\-to\-multipoint network
                    	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Ospfv3.Network.PointToMultipoint>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: point_to_point
                    
                    	Specify OSPF point\-to\-point network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.GigabitEthernet.Ospfv3.Network.PointToMultipoint))])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                            ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                        ])
                        self.broadcast = None
                        self.manet = None
                        self.non_broadcast = None
                        self.point_to_point = None

                        self.point_to_multipoint = None
                        self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                    class PointToMultipoint(Entity):
                        """
                        Specify OSPF point\-to\-multipoint network
                        
                        .. attribute:: non_broadcast
                        
                        	Specify non\-broadcast point\-to\-mpoint network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Ospfv3.Network.PointToMultipoint, self).__init__()

                            self.yang_name = "point-to-multipoint"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ])
                            self.non_broadcast = None
                            self._segment_path = lambda: "point-to-multipoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.Network.PointToMultipoint, ['non_broadcast'], name, value)


                class PrefixSuppression(Entity):
                    """
                    OSPF prefix suppression
                    
                    .. attribute:: disable
                    
                    	Disable prefix suppression
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Ospfv3.PrefixSuppression, self).__init__()

                        self.yang_name = "prefix-suppression"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "prefix-suppression"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Ospfv3.PrefixSuppression, ['disable'], name, value)


            class Udld(Entity):
                """
                Configure UDLD enabled or disabled and ignore global UDLD setting
                
                .. attribute:: port
                
                	Enable UDLD protocol on this interface despite global UDLD setting
                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Udld.Port>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-udld'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Udld, self).__init__()

                    self.yang_name = "udld"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.GigabitEthernet.Udld.Port))])
                    self._leafs = OrderedDict()

                    self.port = None
                    self._children_name_map["port"] = "port"
                    self._segment_path = lambda: "Cisco-IOS-XE-udld:udld"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Udld, [], name, value)


                class Port(Entity):
                    """
                    Enable UDLD protocol on this interface despite global UDLD setting
                    
                    .. attribute:: aggressive
                    
                    	Enable UDLD protocol in aggressive mode on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	Disable UDLD protocol on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-udld'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Udld.Port, self).__init__()

                        self.yang_name = "port"
                        self.yang_parent_name = "udld"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aggressive', (YLeaf(YType.empty, 'aggressive'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.aggressive = None
                        self.disable = None
                        self._segment_path = lambda: "port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Udld.Port, ['aggressive', 'disable'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.Manual>`
                
                	**presence node**\: True
                
                .. attribute:: role_based
                
                	Role\-based Access Control per\-port config commands
                	**type**\:  :py:class:`RoleBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.RoleBased>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.GigabitEthernet.Cts.Manual)), ("role-based", ("role_based", Native.Interface.GigabitEthernet.Cts.RoleBased))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"

                    self.role_based = Native.Interface.GigabitEthernet.Cts.RoleBased()
                    self.role_based.parent = self
                    self._children_name_map["role_based"] = "role-based"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.GigabitEthernet.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.GigabitEthernet.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.GigabitEthernet.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.GigabitEthernet.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.GigabitEthernet.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.GigabitEthernet.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.GigabitEthernet.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.GigabitEthernet.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Cts.Manual.Propagate, ['sgt'], name, value)


                class RoleBased(Entity):
                    """
                    Role\-based Access Control per\-port config commands
                    
                    .. attribute:: sgt_cache
                    
                    	Enable SGT caching on the interface
                    	**type**\: list of   :py:class:`SgtCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.RoleBased.SgtCache>`
                    
                    .. attribute:: enforcement
                    
                    	Enable Role\-based Access Control enforcement
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sgt_map
                    
                    	Assign Security Group Tag (SGT) to IP host or network address
                    	**type**\:  :py:class:`SgtMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.Cts.RoleBased.SgtMap>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.Cts.RoleBased, self).__init__()

                        self.yang_name = "role-based"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sgt-map", ("sgt_map", Native.Interface.GigabitEthernet.Cts.RoleBased.SgtMap))])
                        self._leafs = OrderedDict([
                            ('sgt_cache', (YLeafList(YType.enumeration, 'sgt-cache'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GigabitEthernet.Cts.RoleBased.SgtCache')])),
                            ('enforcement', (YLeaf(YType.empty, 'enforcement'), ['Empty'])),
                        ])
                        self.sgt_cache = []
                        self.enforcement = None

                        self.sgt_map = Native.Interface.GigabitEthernet.Cts.RoleBased.SgtMap()
                        self.sgt_map.parent = self
                        self._children_name_map["sgt_map"] = "sgt-map"
                        self._segment_path = lambda: "role-based"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.Cts.RoleBased, ['sgt_cache', 'enforcement'], name, value)

                    class SgtCache(Enum):
                        """
                        SgtCache (Enum Class)

                        Enable SGT caching on the interface

                        .. data:: egress = 0

                        .. data:: ingress = 1

                        """

                        egress = Enum.YLeaf(0, "egress")

                        ingress = Enum.YLeaf(1, "ingress")



                    class SgtMap(Entity):
                        """
                        Assign Security Group Tag (SGT) to IP host or network address
                        
                        .. attribute:: security_group
                        
                        	Security Group Name
                        	**type**\: str
                        
                        .. attribute:: sgt
                        
                        	Security Group Tag (SGT)
                        	**type**\: int
                        
                        	**range:** 2..65519
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.GigabitEthernet.Cts.RoleBased.SgtMap, self).__init__()

                            self.yang_name = "sgt-map"
                            self.yang_parent_name = "role-based"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('security_group', (YLeaf(YType.str, 'security-group'), ['str'])),
                                ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                            ])
                            self.security_group = None
                            self.sgt = None
                            self._segment_path = lambda: "sgt-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GigabitEthernet.Cts.RoleBased.SgtMap, ['security_group', 'sgt'], name, value)


            class AnalysisModule(Entity):
                """
                Configure NAM on the interface
                
                .. attribute:: monitoring
                
                	Configure NAM monitoring on the interface
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GigabitEthernet.AnalysisModule.Monitoring>`
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Interface.GigabitEthernet.AnalysisModule, self).__init__()

                    self.yang_name = "analysis-module"
                    self.yang_parent_name = "GigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Interface.GigabitEthernet.AnalysisModule.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = Native.Interface.GigabitEthernet.AnalysisModule.Monitoring()
                    self.monitoring.parent = self
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GigabitEthernet.AnalysisModule, [], name, value)


                class Monitoring(Entity):
                    """
                    Configure NAM monitoring on the interface
                    
                    .. attribute:: interface_name
                    
                    	The name of the output interface.  E.g., 'ucse 1/0/0'
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nam'
                    _revision = '2017-12-28'

                    def __init__(self):
                        super(Native.Interface.GigabitEthernet.AnalysisModule.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "analysis-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "monitoring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GigabitEthernet.AnalysisModule.Monitoring, ['interface_name'], name, value)


        class TwoGigabitEthernet(Entity):
            """
            Two Gigabit Ethernet
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: media_type
            
            	Media type
            	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.MediaType>`
            
            .. attribute:: port_type
            
            	
            	**type**\:  :py:class:`PortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.PortType>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service>`
            
            .. attribute:: lacp
            
            	LACP interface subcommands
            	**type**\:  :py:class:`Lacp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Lacp>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec_option
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXEEthernetMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ServicePolicy>`
            
            .. attribute:: auto
            
            	Configure Automation
            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Auto>`
            
            .. attribute:: datalink
            
            	Interface Datalink commands
            	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Datalink>`
            
            .. attribute:: energywise
            
            	EnergyWise interface configurations
            	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Energywise>`
            
            	**presence node**\: True
            
            .. attribute:: location
            
            	Interface location information
            	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Location>`
            
            .. attribute:: mac
            
            	MAC interface commands
            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mac>`
            
            .. attribute:: macro
            
            	Command macro
            	**type**\:  :py:class:`Macro <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Macro>`
            
            .. attribute:: dual_active
            
            	
            	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.DualActive>`
            
            .. attribute:: load_balancing
            
            	Etherchannel Load\-Balancing
            	**type**\:  :py:class:`LoadBalancing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.LoadBalancing>`
            
            .. attribute:: vlan_range
            
            	
            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.VlanRange>`
            
            .. attribute:: switch
            
            	
            	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switch>`
            
            .. attribute:: srr_queue
            
            	
            	**type**\:  :py:class:`SrrQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SrrQueue>`
            
            .. attribute:: cisco_ios_xe_switch_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_switch_macsec_option_
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXESwitchMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption>`
            
            .. attribute:: device_tracking
            
            	Configure device\-tracking on the interface
            	**type**\:  :py:class:`DeviceTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.DeviceTracking>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Snmp>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Crypto>`
            
            .. attribute:: mka
            
            	MACsec Key Agreement (MKA) interface configuration
            	**type**\:  :py:class:`Mka <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mka>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Utd>`
            
            .. attribute:: xconnect
            
            	Xconnect commands
            	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Xconnect>`
            
            .. attribute:: evpn
            
            	
            	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Evpn>`
            
            .. attribute:: fabric_domain
            
            	Fabric\-domain interface command
            	**type**\:  :py:class:`FabricDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.FabricDomain>`
            
            .. attribute:: mvrp
            
            	
            	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mvrp>`
            
            	**presence node**\: True
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Lisp>`
            
            .. attribute:: power
            
            	
            	**type**\:  :py:class:`Power <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Power>`
            
            .. attribute:: cdp
            
            	CDP interface subcommands
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cdp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ntp>`
            
            .. attribute:: authentication
            
            	Auth Manager Interface Configuration Commands
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication>`
            
            .. attribute:: mab
            
            	
            	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mab>`
            
            	**presence node**\: True
            
            .. attribute:: dot1x
            
            	Interface Config Commands for IEEE 802.1X
            	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Dot1x>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SpanningTree>`
            
            .. attribute:: performance
            
            	Global performance monitor configuration
            	**type**\:  :py:class:`Performance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Performance>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Umbrella>`
            
            .. attribute:: lldp
            
            	LLDP interface subcommands
            	**type**\:  :py:class:`Lldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Lldp>`
            
            .. attribute:: nat66
            
            	NAT66 interface commands
            	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Nat66>`
            
            .. attribute:: ospfv3
            
            	OSPFv3 interface commands
            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3>`
            
            .. attribute:: udld
            
            	Configure UDLD enabled or disabled and ignore global UDLD setting
            	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Udld>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts>`
            
            .. attribute:: analysis_module
            
            	Configure NAM on the interface
            	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.AnalysisModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.TwoGigabitEthernet, self).__init__()

                self.yang_name = "TwoGigabitEthernet"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.TwoGigabitEthernet.SwitchportConf)), ("switchport", ("switchport", Native.Interface.TwoGigabitEthernet.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.TwoGigabitEthernet.StackwiseVirtual)), ("arp", ("arp", Native.Interface.TwoGigabitEthernet.Arp)), ("backup", ("backup", Native.Interface.TwoGigabitEthernet.Backup)), ("cemoudp", ("cemoudp", Native.Interface.TwoGigabitEthernet.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.TwoGigabitEthernet.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.TwoGigabitEthernet.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.TwoGigabitEthernet.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.TwoGigabitEthernet.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.TwoGigabitEthernet.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.TwoGigabitEthernet.Flowcontrol)), ("isis", ("isis", Native.Interface.TwoGigabitEthernet.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.TwoGigabitEthernet.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.TwoGigabitEthernet.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.TwoGigabitEthernet.Bandwidth)), ("dampening", ("dampening", Native.Interface.TwoGigabitEthernet.Dampening)), ("domain", ("domain", Native.Interface.TwoGigabitEthernet.Domain)), ("hold-queue", ("hold_queue", Native.Interface.TwoGigabitEthernet.HoldQueue)), ("mpls", ("mpls", Native.Interface.TwoGigabitEthernet.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.TwoGigabitEthernet.IpVrf)), ("vrf", ("vrf", Native.Interface.TwoGigabitEthernet.Vrf)), ("ip", ("ip", Native.Interface.TwoGigabitEthernet.Ip)), ("ipv6", ("ipv6", Native.Interface.TwoGigabitEthernet.Ipv6)), ("logging", ("logging", Native.Interface.TwoGigabitEthernet.Logging)), ("mdix", ("mdix", Native.Interface.TwoGigabitEthernet.Mdix)), ("mop", ("mop", Native.Interface.TwoGigabitEthernet.Mop)), ("interface_qos", ("interface_qos", Native.Interface.TwoGigabitEthernet.InterfaceQos)), ("source", ("source", Native.Interface.TwoGigabitEthernet.Source)), ("standby", ("standby", Native.Interface.TwoGigabitEthernet.Standby)), ("access-session", ("access_session", Native.Interface.TwoGigabitEthernet.AccessSession)), ("storm-control", ("storm_control", Native.Interface.TwoGigabitEthernet.StormControl)), ("trust", ("trust", Native.Interface.TwoGigabitEthernet.Trust)), ("priority-queue", ("priority_queue", Native.Interface.TwoGigabitEthernet.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.TwoGigabitEthernet.RcvQueue)), ("peer", ("peer", Native.Interface.TwoGigabitEthernet.Peer)), ("pm-path", ("pm_path", Native.Interface.TwoGigabitEthernet.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.TwoGigabitEthernet.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.TwoGigabitEthernet.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.TwoGigabitEthernet.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.TwoGigabitEthernet.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.TwoGigabitEthernet.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.TwoGigabitEthernet.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.TwoGigabitEthernet.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.TwoGigabitEthernet.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.TwoGigabitEthernet.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.TwoGigabitEthernet.Service)), ("Cisco-IOS-XE-ethernet:lacp", ("lacp", Native.Interface.TwoGigabitEthernet.Lacp)), ("Cisco-IOS-XE-ethernet:macsec-option", ("cisco_ios_xe_ethernet_macsec_option", Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.TwoGigabitEthernet.ServicePolicy)), ("Cisco-IOS-XE-switch:auto", ("auto", Native.Interface.TwoGigabitEthernet.Auto)), ("Cisco-IOS-XE-switch:datalink", ("datalink", Native.Interface.TwoGigabitEthernet.Datalink)), ("Cisco-IOS-XE-switch:energywise", ("energywise", Native.Interface.TwoGigabitEthernet.Energywise)), ("Cisco-IOS-XE-switch:location", ("location", Native.Interface.TwoGigabitEthernet.Location)), ("Cisco-IOS-XE-switch:mac", ("mac", Native.Interface.TwoGigabitEthernet.Mac)), ("Cisco-IOS-XE-switch:macro", ("macro", Native.Interface.TwoGigabitEthernet.Macro)), ("Cisco-IOS-XE-switch:dual-active", ("dual_active", Native.Interface.TwoGigabitEthernet.DualActive)), ("Cisco-IOS-XE-switch:load-balancing", ("load_balancing", Native.Interface.TwoGigabitEthernet.LoadBalancing)), ("Cisco-IOS-XE-switch:vlan-range", ("vlan_range", Native.Interface.TwoGigabitEthernet.VlanRange)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Interface.TwoGigabitEthernet.Switch)), ("Cisco-IOS-XE-switch:srr-queue", ("srr_queue", Native.Interface.TwoGigabitEthernet.SrrQueue)), ("Cisco-IOS-XE-switch:macsec-option", ("cisco_ios_xe_switch_macsec_option_", Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption)), ("Cisco-IOS-XE-switch:device-tracking", ("device_tracking", Native.Interface.TwoGigabitEthernet.DeviceTracking)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.TwoGigabitEthernet.Snmp)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.TwoGigabitEthernet.Crypto)), ("Cisco-IOS-XE-mka:mka", ("mka", Native.Interface.TwoGigabitEthernet.Mka)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.TwoGigabitEthernet.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.TwoGigabitEthernet.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.TwoGigabitEthernet.Utd)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.TwoGigabitEthernet.Xconnect)), ("Cisco-IOS-XE-l2vpn:evpn", ("evpn", Native.Interface.TwoGigabitEthernet.Evpn)), ("Cisco-IOS-XE-iwanfabric:fabric-domain", ("fabric_domain", Native.Interface.TwoGigabitEthernet.FabricDomain)), ("Cisco-IOS-XE-mvrp:mvrp", ("mvrp", Native.Interface.TwoGigabitEthernet.Mvrp)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.TwoGigabitEthernet.Lisp)), ("Cisco-IOS-XE-power:power", ("power", Native.Interface.TwoGigabitEthernet.Power)), ("Cisco-IOS-XE-cdp:cdp", ("cdp", Native.Interface.TwoGigabitEthernet.Cdp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.TwoGigabitEthernet.Ntp)), ("Cisco-IOS-XE-sanet:authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Authentication)), ("Cisco-IOS-XE-sanet:mab", ("mab", Native.Interface.TwoGigabitEthernet.Mab)), ("Cisco-IOS-XE-dot1x:dot1x", ("dot1x", Native.Interface.TwoGigabitEthernet.Dot1x)), ("Cisco-IOS-XE-spanning-tree:spanning-tree", ("spanning_tree", Native.Interface.TwoGigabitEthernet.SpanningTree)), ("Cisco-IOS-XE-ezpm:performance", ("performance", Native.Interface.TwoGigabitEthernet.Performance)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.TwoGigabitEthernet.Umbrella)), ("Cisco-IOS-XE-lldp:lldp", ("lldp", Native.Interface.TwoGigabitEthernet.Lldp)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Interface.TwoGigabitEthernet.Ospfv3)), ("Cisco-IOS-XE-udld:udld", ("udld", Native.Interface.TwoGigabitEthernet.Udld)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.TwoGigabitEthernet.Cts)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Interface.TwoGigabitEthernet.AnalysisModule))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('media_type', (YLeaf(YType.enumeration, 'media-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.MediaType')])),
                    ('port_type', (YLeaf(YType.enumeration, 'port-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.PortType')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Duplex')])),
                    ('cisco_ios_xe_ethernet_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-ethernet:macsec'), ['Empty'])),
                    ('cisco_ios_xe_switch_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:macsec'), ['Empty'])),
                    ('nat66', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-nat:nat66'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Nat66')])),
                ])
                self.name = None
                self.media_type = None
                self.port_type = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None
                self.cisco_ios_xe_ethernet_macsec = None
                self.cisco_ios_xe_switch_macsec = None
                self.nat66 = None

                self.switchport_conf = Native.Interface.TwoGigabitEthernet.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.TwoGigabitEthernet.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.TwoGigabitEthernet.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.TwoGigabitEthernet.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.TwoGigabitEthernet.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.TwoGigabitEthernet.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.TwoGigabitEthernet.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.TwoGigabitEthernet.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.TwoGigabitEthernet.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.TwoGigabitEthernet.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.TwoGigabitEthernet.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.TwoGigabitEthernet.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.TwoGigabitEthernet.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.TwoGigabitEthernet.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.TwoGigabitEthernet.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.TwoGigabitEthernet.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.TwoGigabitEthernet.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.TwoGigabitEthernet.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.TwoGigabitEthernet.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.TwoGigabitEthernet.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.TwoGigabitEthernet.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.TwoGigabitEthernet.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.TwoGigabitEthernet.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.TwoGigabitEthernet.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.TwoGigabitEthernet.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.TwoGigabitEthernet.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.TwoGigabitEthernet.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.TwoGigabitEthernet.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.TwoGigabitEthernet.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.TwoGigabitEthernet.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.TwoGigabitEthernet.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.TwoGigabitEthernet.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.TwoGigabitEthernet.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.TwoGigabitEthernet.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.TwoGigabitEthernet.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.TwoGigabitEthernet.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.TwoGigabitEthernet.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.TwoGigabitEthernet.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.TwoGigabitEthernet.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.TwoGigabitEthernet.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.TwoGigabitEthernet.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.TwoGigabitEthernet.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.TwoGigabitEthernet.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.TwoGigabitEthernet.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.TwoGigabitEthernet.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.lacp = Native.Interface.TwoGigabitEthernet.Lacp()
                self.lacp.parent = self
                self._children_name_map["lacp"] = "Cisco-IOS-XE-ethernet:lacp"

                self.cisco_ios_xe_ethernet_macsec_option = Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption()
                self.cisco_ios_xe_ethernet_macsec_option.parent = self
                self._children_name_map["cisco_ios_xe_ethernet_macsec_option"] = "Cisco-IOS-XE-ethernet:macsec-option"

                self.service_policy = Native.Interface.TwoGigabitEthernet.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.auto = Native.Interface.TwoGigabitEthernet.Auto()
                self.auto.parent = self
                self._children_name_map["auto"] = "Cisco-IOS-XE-switch:auto"

                self.datalink = Native.Interface.TwoGigabitEthernet.Datalink()
                self.datalink.parent = self
                self._children_name_map["datalink"] = "Cisco-IOS-XE-switch:datalink"

                self.energywise = None
                self._children_name_map["energywise"] = "Cisco-IOS-XE-switch:energywise"

                self.location = Native.Interface.TwoGigabitEthernet.Location()
                self.location.parent = self
                self._children_name_map["location"] = "Cisco-IOS-XE-switch:location"

                self.mac = Native.Interface.TwoGigabitEthernet.Mac()
                self.mac.parent = self
                self._children_name_map["mac"] = "Cisco-IOS-XE-switch:mac"

                self.macro = Native.Interface.TwoGigabitEthernet.Macro()
                self.macro.parent = self
                self._children_name_map["macro"] = "Cisco-IOS-XE-switch:macro"

                self.dual_active = Native.Interface.TwoGigabitEthernet.DualActive()
                self.dual_active.parent = self
                self._children_name_map["dual_active"] = "Cisco-IOS-XE-switch:dual-active"

                self.load_balancing = Native.Interface.TwoGigabitEthernet.LoadBalancing()
                self.load_balancing.parent = self
                self._children_name_map["load_balancing"] = "Cisco-IOS-XE-switch:load-balancing"

                self.switch = Native.Interface.TwoGigabitEthernet.Switch()
                self.switch.parent = self
                self._children_name_map["switch"] = "Cisco-IOS-XE-switch:switch"

                self.srr_queue = Native.Interface.TwoGigabitEthernet.SrrQueue()
                self.srr_queue.parent = self
                self._children_name_map["srr_queue"] = "Cisco-IOS-XE-switch:srr-queue"

                self.cisco_ios_xe_switch_macsec_option_ = Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption()
                self.cisco_ios_xe_switch_macsec_option_.parent = self
                self._children_name_map["cisco_ios_xe_switch_macsec_option_"] = "Cisco-IOS-XE-switch:macsec-option"

                self.device_tracking = Native.Interface.TwoGigabitEthernet.DeviceTracking()
                self.device_tracking.parent = self
                self._children_name_map["device_tracking"] = "Cisco-IOS-XE-switch:device-tracking"

                self.snmp = Native.Interface.TwoGigabitEthernet.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.crypto = Native.Interface.TwoGigabitEthernet.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.mka = Native.Interface.TwoGigabitEthernet.Mka()
                self.mka.parent = self
                self._children_name_map["mka"] = "Cisco-IOS-XE-mka:mka"

                self.et_analytics = Native.Interface.TwoGigabitEthernet.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.TwoGigabitEthernet.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.TwoGigabitEthernet.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.xconnect = Native.Interface.TwoGigabitEthernet.Xconnect()
                self.xconnect.parent = self
                self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                self.evpn = Native.Interface.TwoGigabitEthernet.Evpn()
                self.evpn.parent = self
                self._children_name_map["evpn"] = "Cisco-IOS-XE-l2vpn:evpn"

                self.fabric_domain = Native.Interface.TwoGigabitEthernet.FabricDomain()
                self.fabric_domain.parent = self
                self._children_name_map["fabric_domain"] = "Cisco-IOS-XE-iwanfabric:fabric-domain"

                self.mvrp = None
                self._children_name_map["mvrp"] = "Cisco-IOS-XE-mvrp:mvrp"

                self.lisp = Native.Interface.TwoGigabitEthernet.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.power = Native.Interface.TwoGigabitEthernet.Power()
                self.power.parent = self
                self._children_name_map["power"] = "Cisco-IOS-XE-power:power"

                self.cdp = Native.Interface.TwoGigabitEthernet.Cdp()
                self.cdp.parent = self
                self._children_name_map["cdp"] = "Cisco-IOS-XE-cdp:cdp"

                self.ntp = Native.Interface.TwoGigabitEthernet.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.authentication = Native.Interface.TwoGigabitEthernet.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "Cisco-IOS-XE-sanet:authentication"

                self.mab = None
                self._children_name_map["mab"] = "Cisco-IOS-XE-sanet:mab"

                self.dot1x = Native.Interface.TwoGigabitEthernet.Dot1x()
                self.dot1x.parent = self
                self._children_name_map["dot1x"] = "Cisco-IOS-XE-dot1x:dot1x"

                self.spanning_tree = Native.Interface.TwoGigabitEthernet.SpanningTree()
                self.spanning_tree.parent = self
                self._children_name_map["spanning_tree"] = "Cisco-IOS-XE-spanning-tree:spanning-tree"

                self.performance = Native.Interface.TwoGigabitEthernet.Performance()
                self.performance.parent = self
                self._children_name_map["performance"] = "Cisco-IOS-XE-ezpm:performance"

                self.umbrella = Native.Interface.TwoGigabitEthernet.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.lldp = Native.Interface.TwoGigabitEthernet.Lldp()
                self.lldp.parent = self
                self._children_name_map["lldp"] = "Cisco-IOS-XE-lldp:lldp"

                self.ospfv3 = Native.Interface.TwoGigabitEthernet.Ospfv3()
                self.ospfv3.parent = self
                self._children_name_map["ospfv3"] = "Cisco-IOS-XE-ospfv3:ospfv3"

                self.udld = Native.Interface.TwoGigabitEthernet.Udld()
                self.udld.parent = self
                self._children_name_map["udld"] = "Cisco-IOS-XE-udld:udld"

                self.cts = Native.Interface.TwoGigabitEthernet.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.analysis_module = Native.Interface.TwoGigabitEthernet.AnalysisModule()
                self.analysis_module.parent = self
                self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"

                self.hold_queue = YList(self)
                self.vlan_range = YList(self)
                self._segment_path = lambda: "TwoGigabitEthernet" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.TwoGigabitEthernet, [u'name', u'media_type', u'port_type', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex', 'cisco_ios_xe_ethernet_macsec', u'cisco_ios_xe_switch_macsec', 'nat66'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class MediaType(Enum):
                """
                MediaType (Enum Class)

                Media type

                .. data:: auto_select = 0

                .. data:: rj45 = 1

                .. data:: sfp = 2

                """

                auto_select = Enum.YLeaf(0, "auto-select")

                rj45 = Enum.YLeaf(1, "rj45")

                sfp = Enum.YLeaf(2, "sfp")


            class Nat66(Enum):
                """
                Nat66 (Enum Class)

                NAT66 interface commands

                .. data:: inside = 0

                .. data:: outside = 1

                """

                inside = Enum.YLeaf(0, "inside")

                outside = Enum.YLeaf(1, "outside")


            class PortType(Enum):
                """
                PortType (Enum Class)

                .. data:: nni = 0

                """

                nni = Enum.YLeaf(0, "nni")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Access>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Block>`
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: trunk
                
                	Set trunking characteristics of the interface
                	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Trunk>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Voice>`
                
                .. attribute:: priority
                
                	Set appliance 802.1p priority
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Priority>`
                
                .. attribute:: autostate
                
                	Include or exclude this port from vlan link up calculation
                	**type**\:  :py:class:`Autostate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Autostate>`
                
                .. attribute:: protected
                
                	Configure an interface to be a protected port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Set port host
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: private_vlan
                
                	Set the private VLAN configuration
                	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan>`
                
                .. attribute:: vepa
                
                	Reflective relay configuration
                	**type**\:  :py:class:`Vepa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Vepa>`
                
                .. attribute:: device_tracking
                
                	Configure device\-tracking on the interface
                	**type**\:  :py:class:`DeviceTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.DeviceTracking>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:access", ("access", Native.Interface.TwoGigabitEthernet.Switchport.Access)), ("Cisco-IOS-XE-switch:block", ("block", Native.Interface.TwoGigabitEthernet.Switchport.Block)), ("Cisco-IOS-XE-switch:mode", ("mode", Native.Interface.TwoGigabitEthernet.Switchport.Mode)), ("Cisco-IOS-XE-switch:port-security", ("port_security", Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity)), ("Cisco-IOS-XE-switch:trunk", ("trunk", Native.Interface.TwoGigabitEthernet.Switchport.Trunk)), ("Cisco-IOS-XE-switch:voice", ("voice", Native.Interface.TwoGigabitEthernet.Switchport.Voice)), ("Cisco-IOS-XE-switch:priority", ("priority", Native.Interface.TwoGigabitEthernet.Switchport.Priority)), ("Cisco-IOS-XE-switch:autostate", ("autostate", Native.Interface.TwoGigabitEthernet.Switchport.Autostate)), ("Cisco-IOS-XE-switch:private-vlan", ("private_vlan", Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan)), ("Cisco-IOS-XE-switch:vepa", ("vepa", Native.Interface.TwoGigabitEthernet.Switchport.Vepa)), ("Cisco-IOS-XE-switch:device-tracking", ("device_tracking", Native.Interface.TwoGigabitEthernet.Switchport.DeviceTracking))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:nonegotiate'), ['Empty'])),
                        ('protected', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:protected'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:host'), ['Empty'])),
                    ])
                    self.nonegotiate = None
                    self.protected = None
                    self.host = None

                    self.access = Native.Interface.TwoGigabitEthernet.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "Cisco-IOS-XE-switch:access"

                    self.block = Native.Interface.TwoGigabitEthernet.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "Cisco-IOS-XE-switch:block"

                    self.mode = Native.Interface.TwoGigabitEthernet.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "Cisco-IOS-XE-switch:mode"

                    self.port_security = None
                    self._children_name_map["port_security"] = "Cisco-IOS-XE-switch:port-security"

                    self.trunk = Native.Interface.TwoGigabitEthernet.Switchport.Trunk()
                    self.trunk.parent = self
                    self._children_name_map["trunk"] = "Cisco-IOS-XE-switch:trunk"

                    self.voice = Native.Interface.TwoGigabitEthernet.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "Cisco-IOS-XE-switch:voice"

                    self.priority = Native.Interface.TwoGigabitEthernet.Switchport.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-switch:priority"

                    self.autostate = Native.Interface.TwoGigabitEthernet.Switchport.Autostate()
                    self.autostate.parent = self
                    self._children_name_map["autostate"] = "Cisco-IOS-XE-switch:autostate"

                    self.private_vlan = Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan()
                    self.private_vlan.parent = self
                    self._children_name_map["private_vlan"] = "Cisco-IOS-XE-switch:private-vlan"

                    self.vepa = Native.Interface.TwoGigabitEthernet.Switchport.Vepa()
                    self.vepa.parent = self
                    self._children_name_map["vepa"] = "Cisco-IOS-XE-switch:vepa"

                    self.device_tracking = Native.Interface.TwoGigabitEthernet.Switchport.DeviceTracking()
                    self.device_tracking.parent = self
                    self._children_name_map["device_tracking"] = "Cisco-IOS-XE-switch:device-tracking"
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport, [u'nonegotiate', u'protected', u'host'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	Set VLAN when interface is in access mode
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Access.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwoGigabitEthernet.Switchport.Access.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.TwoGigabitEthernet.Switchport.Access.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:access"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Access, [], name, value)


                    class Vlan(Entity):
                        """
                        Set VLAN when interface is in access mode
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_>`
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.Access.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "access"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Access.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dynamic = 0

                            """

                            dynamic = Enum.YLeaf(0, "dynamic")



                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: multicast
                    
                    	Block unknown multicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.multicast = None
                        self.unicast = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:block"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Block, [u'multicast', u'unicast'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Mode.Access>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dot1q_tunnel
                    
                    	set trunking mode to TUNNEL unconditionally
                    	**type**\:  :py:class:`Dot1qTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Mode.Dot1qTunnel>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dynamic
                    
                    	Set trunking mode to dynamically negotiate access or trunk mode
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Mode.Dynamic>`
                    
                    .. attribute:: private_vlan
                    
                    	Set private\-vlan mode
                    	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Mode.PrivateVlan>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Mode.Trunk>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.TwoGigabitEthernet.Switchport.Mode.Access)), ("dot1q-tunnel", ("dot1q_tunnel", Native.Interface.TwoGigabitEthernet.Switchport.Mode.Dot1qTunnel)), ("private-vlan", ("private_vlan", Native.Interface.TwoGigabitEthernet.Switchport.Mode.PrivateVlan)), ("trunk", ("trunk", Native.Interface.TwoGigabitEthernet.Switchport.Mode.Trunk))])
                        self._leafs = OrderedDict([
                            ('dynamic', (YLeaf(YType.enumeration, 'dynamic'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Switchport.Mode.Dynamic')])),
                        ])
                        self.dynamic = None

                        self.access = None
                        self._children_name_map["access"] = "access"

                        self.dot1q_tunnel = None
                        self._children_name_map["dot1q_tunnel"] = "dot1q-tunnel"

                        self.private_vlan = Native.Interface.TwoGigabitEthernet.Switchport.Mode.PrivateVlan()
                        self.private_vlan.parent = self
                        self._children_name_map["private_vlan"] = "private-vlan"

                        self.trunk = None
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Mode, [u'dynamic'], name, value)

                    class Dynamic(Enum):
                        """
                        Dynamic (Enum Class)

                        Set trunking mode to dynamically negotiate access or trunk mode

                        .. data:: auto = 0

                        .. data:: desirable = 1

                        """

                        auto = Enum.YLeaf(0, "auto")

                        desirable = Enum.YLeaf(1, "desirable")



                    class Access(Entity):
                        """
                        Set trunking mode to ACCESS unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.Mode.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "access"
                            self._is_frozen = True


                    class Dot1qTunnel(Entity):
                        """
                        set trunking mode to TUNNEL unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.Mode.Dot1qTunnel, self).__init__()

                            self.yang_name = "dot1q-tunnel"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dot1q-tunnel"
                            self._is_frozen = True


                    class PrivateVlan(Entity):
                        """
                        Set private\-vlan mode
                        
                        .. attribute:: host
                        
                        	Set the mode to private\-vlan host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: promiscuous
                        
                        	Set the mode to private\-vlan promiscuous
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.Mode.PrivateVlan, self).__init__()

                            self.yang_name = "private-vlan"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('promiscuous', (YLeaf(YType.empty, 'promiscuous'), ['Empty'])),
                            ])
                            self.host = None
                            self.promiscuous = None
                            self._segment_path = lambda: "private-vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Mode.PrivateVlan, [u'host', u'promiscuous'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking mode to TRUNK unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.Mode.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: mac_address
                    
                    	Secure mac address
                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.MacAddress>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Aging)), ("mac-address", ("mac_address", Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.MacAddress)), ("maximum", ("maximum", Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Maximum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Switchport.PortSecurity.Violation')])),
                        ])
                        self.violation = None

                        self.aging = Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.mac_address = Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"

                        self.maximum = Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:port-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity, [u'violation'], name, value)

                    class Violation(Enum):
                        """
                        Violation (Enum Class)

                        Security violation mode

                        .. data:: protect = 0

                        .. data:: restrict = 1

                        .. data:: shutdown = 2

                        """

                        protect = Enum.YLeaf(0, "protect")

                        restrict = Enum.YLeaf(1, "restrict")

                        shutdown = Enum.YLeaf(2, "shutdown")



                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Aging.Type>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Switchport.PortSecurity.Aging.Type')])),
                            ])
                            self.static = None
                            self.time = None
                            self.type = None
                            self._segment_path = lambda: "aging"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Aging, [u'static', u'time', u'type'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Port\-security aging type

                            .. data:: absolute = 0

                            .. data:: inactivity = 1

                            """

                            absolute = Enum.YLeaf(0, "absolute")

                            inactivity = Enum.YLeaf(1, "inactivity")



                    class MacAddress(Entity):
                        """
                        Secure mac address
                        
                        .. attribute:: sticky
                        
                        	Configure dynamic secure addresses as sticky
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hw_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: vlan
                        
                        	set VLAN ID of the VLAN on which this address can be learned
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                ('hw_address', (YLeaf(YType.str, 'hw-address'), ['str'])),
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.sticky = None
                            self.hw_address = None
                            self.vlan = None
                            self._segment_path = lambda: "mac-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.MacAddress, [u'sticky', u'hw_address', u'vlan'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: max_addresses
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4097
                        
                        .. attribute:: vlan
                        
                        	Max secure addresses per vlan
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_addresses', (YLeaf(YType.uint16, 'max-addresses'), ['int'])),
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['str'])),
                            ])
                            self.max_addresses = None
                            self.vlan = None
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.PortSecurity.Maximum, [u'max_addresses', u'vlan'], name, value)


                class Trunk(Entity):
                    """
                    Set trunking characteristics of the interface
                    
                    .. attribute:: allowed
                    
                    	Set allowed VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Allowed>`
                    
                    .. attribute:: encapsulation
                    
                    	Set encapsulation format on trunk port
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Encapsulation>`
                    
                    .. attribute:: native
                    
                    	Set trunking native characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Native_>`
                    
                    .. attribute:: pruning
                    
                    	Set pruning VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Pruning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Pruning>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switchport.Trunk, self).__init__()

                        self.yang_name = "trunk"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Native_)), ("pruning", ("pruning", Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Pruning))])
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Switchport.Trunk.Encapsulation')])),
                        ])
                        self.encapsulation = None

                        self.allowed = Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Allowed()
                        self.allowed.parent = self
                        self._children_name_map["allowed"] = "allowed"

                        self.native = Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Native_()
                        self.native.parent = self
                        self._children_name_map["native"] = "native"

                        self.pruning = Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Pruning()
                        self.pruning.parent = self
                        self._children_name_map["pruning"] = "pruning"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:trunk"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Trunk, [u'encapsulation'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Set encapsulation format on trunk port

                        .. data:: dot1q = 0

                        .. data:: isl = 1

                        .. data:: negotiate = 2

                        """

                        dot1q = Enum.YLeaf(0, "dot1q")

                        isl = Enum.YLeaf(1, "isl")

                        negotiate = Enum.YLeaf(2, "negotiate")



                    class Allowed(Entity):
                        """
                        Set allowed VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set allowed VLANs when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Allowed.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Allowed, self).__init__()

                            self.yang_name = "allowed"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Allowed.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Allowed.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "allowed"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Allowed, [], name, value)


                        class Vlan(Entity):
                            """
                            Set allowed VLANs when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: all
                            
                            	all VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "allowed"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = None
                                self.add = None
                                self.all = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                    class Native_(Entity):
                        """
                        Set trunking native characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set native VLAN when interface is in trunking mode
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Native_, self).__init__()

                            self.yang_name = "native"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan'),'int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "native"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Native_, [u'vlan'], name, value)

                        class Vlan(Enum):
                            """
                            Vlan (Enum Class)

                            Set native VLAN when interface is in trunking mode

                            .. data:: tag = 0

                            """

                            tag = Enum.YLeaf(0, "tag")



                    class Pruning(Entity):
                        """
                        Set pruning VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set VLANs enabled for pruning when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Pruning.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Pruning, self).__init__()

                            self.yang_name = "pruning"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Pruning.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Pruning.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "pruning"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Pruning, [], name, value)


                        class Vlan(Entity):
                            """
                            Set VLANs enabled for pruning when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Pruning.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "pruning"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeafList(YType.str, 'vlans'), ['int','str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = []
                                self.add = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Trunk.Pruning.Vlan, [u'vlans', u'add', u'except_', u'none', u'remove'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Voice.Vlan>`
                    
                    .. attribute:: detect
                    
                    	detection enhancement keyword
                    	**type**\:  :py:class:`Detect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Voice.Detect>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwoGigabitEthernet.Switchport.Voice.Vlan)), ("detect", ("detect", Native.Interface.TwoGigabitEthernet.Switchport.Voice.Detect))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.TwoGigabitEthernet.Switchport.Voice.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"

                        self.detect = Native.Interface.TwoGigabitEthernet.Switchport.Voice.Detect()
                        self.detect.parent = self
                        self._children_name_map["detect"] = "detect"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:voice"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Voice, [], name, value)


                    class Vlan(Entity):
                        """
                        Vlan for voice traffic
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\: str
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.Voice.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_'),'int','str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Voice.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dot1p = 0

                            .. data:: none = 1

                            .. data:: untagged = 2

                            """

                            dot1p = Enum.YLeaf(0, "dot1p")

                            none = Enum.YLeaf(1, "none")

                            untagged = Enum.YLeaf(2, "untagged")



                    class Detect(Entity):
                        """
                        detection enhancement keyword
                        
                        .. attribute:: cisco_phone
                        
                        	Cisco IP phone
                        	**type**\:  :py:class:`CiscoPhone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Voice.Detect.CiscoPhone>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.Voice.Detect, self).__init__()

                            self.yang_name = "detect"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cisco-phone", ("cisco_phone", Native.Interface.TwoGigabitEthernet.Switchport.Voice.Detect.CiscoPhone))])
                            self._leafs = OrderedDict()

                            self.cisco_phone = None
                            self._children_name_map["cisco_phone"] = "cisco-phone"
                            self._segment_path = lambda: "detect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Voice.Detect, [], name, value)


                        class CiscoPhone(Entity):
                            """
                            Cisco IP phone
                            
                            .. attribute:: full_duplex
                            
                            	full duplex keyword
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Switchport.Voice.Detect.CiscoPhone, self).__init__()

                                self.yang_name = "cisco-phone"
                                self.yang_parent_name = "detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('full_duplex', (YLeaf(YType.empty, 'full-duplex'), ['Empty'])),
                                ])
                                self.full_duplex = None
                                self._segment_path = lambda: "cisco-phone"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Voice.Detect.CiscoPhone, [u'full_duplex'], name, value)


                class Priority(Entity):
                    """
                    Set appliance 802.1p priority
                    
                    .. attribute:: extend
                    
                    	Set appliance 802.1p priority
                    	**type**\:  :py:class:`Extend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.Priority.Extend>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switchport.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("extend", ("extend", Native.Interface.TwoGigabitEthernet.Switchport.Priority.Extend))])
                        self._leafs = OrderedDict()

                        self.extend = Native.Interface.TwoGigabitEthernet.Switchport.Priority.Extend()
                        self.extend.parent = self
                        self._children_name_map["extend"] = "extend"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Priority, [], name, value)


                    class Extend(Entity):
                        """
                        Set appliance 802.1p priority
                        
                        .. attribute:: trust
                        
                        	Trust 802.1p priorities of devices on appliance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cos
                        
                        	Override 802.1p priority of devices on appliance
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.Priority.Extend, self).__init__()

                            self.yang_name = "extend"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                            ])
                            self.trust = None
                            self.cos = None
                            self._segment_path = lambda: "extend"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Priority.Extend, [u'trust', u'cos'], name, value)


                class Autostate(Entity):
                    """
                    Include or exclude this port from vlan link up calculation
                    
                    .. attribute:: exclude
                    
                    	Exclude this port from vlan link up calculation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switchport.Autostate, self).__init__()

                        self.yang_name = "autostate"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('exclude', (YLeaf(YType.empty, 'exclude'), ['Empty'])),
                        ])
                        self.exclude = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:autostate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Autostate, [u'exclude'], name, value)


                class PrivateVlan(Entity):
                    """
                    Set the private VLAN configuration
                    
                    .. attribute:: association
                    
                    	Set the private VLAN association
                    	**type**\:  :py:class:`Association <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association>`
                    
                    .. attribute:: host_association
                    
                    	Set the private VLAN host association
                    	**type**\:  :py:class:`HostAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.HostAssociation>`
                    
                    .. attribute:: mapping
                    
                    	Set the private VLAN promiscuous mapping
                    	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Mapping>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan, self).__init__()

                        self.yang_name = "private-vlan"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("association", ("association", Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association)), ("host-association", ("host_association", Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.HostAssociation)), ("mapping", ("mapping", Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Mapping))])
                        self._leafs = OrderedDict()

                        self.association = Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association()
                        self.association.parent = self
                        self._children_name_map["association"] = "association"

                        self.host_association = Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.HostAssociation()
                        self.host_association.parent = self
                        self._children_name_map["host_association"] = "host-association"

                        self.mapping = Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Mapping()
                        self.mapping.parent = self
                        self._children_name_map["mapping"] = "mapping"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:private-vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan, [], name, value)


                    class Association(Entity):
                        """
                        Set the private VLAN association
                        
                        .. attribute:: host
                        
                        	Set the private VLAN host association
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association.Host>`
                        
                        .. attribute:: mapping
                        
                        	Set the private VLAN promiscuous mapping
                        	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association.Mapping>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association, self).__init__()

                            self.yang_name = "association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association.Host)), ("mapping", ("mapping", Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association.Mapping))])
                            self._leafs = OrderedDict()

                            self.host = Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.mapping = Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association.Mapping()
                            self.mapping.parent = self
                            self._children_name_map["mapping"] = "mapping"
                            self._segment_path = lambda: "association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association, [], name, value)


                        class Host(Entity):
                            """
                            Set the private VLAN host association
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary normal range VLAN ID of the private VLAN host port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association.Host, [u'primary_range', u'secondary_range'], name, value)


                        class Mapping(Entity):
                            """
                            Set the private VLAN promiscuous mapping
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: remove
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association.Mapping, self).__init__()

                                self.yang_name = "mapping"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self.add = None
                                self.remove = None
                                self._segment_path = lambda: "mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Association.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                    class HostAssociation(Entity):
                        """
                        Set the private VLAN host association
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary normal range VLAN ID of the private VLAN host port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.HostAssociation, self).__init__()

                            self.yang_name = "host-association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self._segment_path = lambda: "host-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.HostAssociation, [u'primary_range', u'secondary_range'], name, value)


                    class Mapping(Entity):
                        """
                        Set the private VLAN promiscuous mapping
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: add
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: remove
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Mapping, self).__init__()

                            self.yang_name = "mapping"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self.add = None
                            self.remove = None
                            self._segment_path = lambda: "mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.PrivateVlan.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                class Vepa(Entity):
                    """
                    Reflective relay configuration
                    
                    .. attribute:: enabled
                    
                    	Enable reflective relay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switchport.Vepa, self).__init__()

                        self.yang_name = "vepa"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                        ])
                        self.enabled = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:vepa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.Vepa, [u'enabled'], name, value)


                class DeviceTracking(Entity):
                    """
                    Configure device\-tracking on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature device\-tracking
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switchport.DeviceTracking, self).__init__()

                        self.yang_name = "device-tracking"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:device-tracking"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switchport.DeviceTracking, [u'attach_policy'], name, value)


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TwoGigabitEthernet.Backup.Delay)), ("interface", ("interface", Native.Interface.TwoGigabitEthernet.Backup.Interface_)), ("load", ("load", Native.Interface.TwoGigabitEthernet.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.TwoGigabitEthernet.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.TwoGigabitEthernet.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.TwoGigabitEthernet.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.TwoGigabitEthernet.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.TwoGigabitEthernet.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.TwoGigabitEthernet.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.TwoGigabitEthernet.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.TwoGigabitEthernet.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.TwoGigabitEthernet.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.TwoGigabitEthernet.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.TwoGigabitEthernet.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.TwoGigabitEthernet.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.TwoGigabitEthernet.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.TwoGigabitEthernet.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.TwoGigabitEthernet.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.TwoGigabitEthernet.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.TwoGigabitEthernet.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.TwoGigabitEthernet.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.TwoGigabitEthernet.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.TwoGigabitEthernet.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.TwoGigabitEthernet.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.TwoGigabitEthernet.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.TwoGigabitEthernet.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.TwoGigabitEthernet.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.TwoGigabitEthernet.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.TwoGigabitEthernet.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.TwoGigabitEthernet.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.TwoGigabitEthernet.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.TwoGigabitEthernet.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.TwoGigabitEthernet.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.TwoGigabitEthernet.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.TwoGigabitEthernet.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.TwoGigabitEthernet.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.TwoGigabitEthernet.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.TwoGigabitEthernet.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.TwoGigabitEthernet.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.TwoGigabitEthernet.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.TwoGigabitEthernet.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.TwoGigabitEthernet.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.TwoGigabitEthernet.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.TwoGigabitEthernet.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.TwoGigabitEthernet.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.TwoGigabitEthernet.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.TwoGigabitEthernet.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.TwoGigabitEthernet.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.TwoGigabitEthernet.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.TwoGigabitEthernet.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.TwoGigabitEthernet.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.TwoGigabitEthernet.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.TwoGigabitEthernet.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.TwoGigabitEthernet.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.TwoGigabitEthernet.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.TwoGigabitEthernet.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.TwoGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.TwoGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.TwoGigabitEthernet.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.TwoGigabitEthernet.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.TwoGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.TwoGigabitEthernet.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.TwoGigabitEthernet.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.TwoGigabitEthernet.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.TwoGigabitEthernet.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.TwoGigabitEthernet.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.TwoGigabitEthernet.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.TwoGigabitEthernet.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.TwoGigabitEthernet.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.TwoGigabitEthernet.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.TwoGigabitEthernet.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.TwoGigabitEthernet.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.TwoGigabitEthernet.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.TwoGigabitEthernet.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.TwoGigabitEthernet.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.TwoGigabitEthernet.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.TwoGigabitEthernet.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.TwoGigabitEthernet.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.TwoGigabitEthernet.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.TwoGigabitEthernet.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.TwoGigabitEthernet.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.TwoGigabitEthernet.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.TwoGigabitEthernet.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.TwoGigabitEthernet.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.TwoGigabitEthernet.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.TwoGigabitEthernet.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Igmp>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Flow>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Nbar>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf>`
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Lisp>`
                
                .. attribute:: rsvp
                
                	RSVP Interface Commands
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Nat>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.TwoGigabitEthernet.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.TwoGigabitEthernet.Ip.Arp)), ("vrf", ("vrf", Native.Interface.TwoGigabitEthernet.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.TwoGigabitEthernet.Ip.NoAddress)), ("address", ("address", Native.Interface.TwoGigabitEthernet.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.TwoGigabitEthernet.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.TwoGigabitEthernet.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.TwoGigabitEthernet.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.TwoGigabitEthernet.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.TwoGigabitEthernet.Ip.Pim)), ("policy", ("policy", Native.Interface.TwoGigabitEthernet.Ip.Policy)), ("rip", ("rip", Native.Interface.TwoGigabitEthernet.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.TwoGigabitEthernet.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.TwoGigabitEthernet.Ip.RouteCache)), ("router", ("router", Native.Interface.TwoGigabitEthernet.Ip.Router)), ("tcp", ("tcp", Native.Interface.TwoGigabitEthernet.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.TwoGigabitEthernet.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.TwoGigabitEthernet.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.TwoGigabitEthernet.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.TwoGigabitEthernet.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.TwoGigabitEthernet.Ip.Igmp)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.TwoGigabitEthernet.Ip.Flow)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.TwoGigabitEthernet.Ip.Nbar)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.TwoGigabitEthernet.Ip.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.TwoGigabitEthernet.Ip.Lisp)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Interface.TwoGigabitEthernet.Ip.Rsvp)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.TwoGigabitEthernet.Ip.Nat)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.TwoGigabitEthernet.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None
                    self.unreachables = None

                    self.access_group = Native.Interface.TwoGigabitEthernet.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.TwoGigabitEthernet.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.TwoGigabitEthernet.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.TwoGigabitEthernet.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.TwoGigabitEthernet.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.TwoGigabitEthernet.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.TwoGigabitEthernet.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.TwoGigabitEthernet.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.TwoGigabitEthernet.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.TwoGigabitEthernet.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.TwoGigabitEthernet.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.TwoGigabitEthernet.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.TwoGigabitEthernet.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.TwoGigabitEthernet.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.TwoGigabitEthernet.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.TwoGigabitEthernet.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.TwoGigabitEthernet.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.TwoGigabitEthernet.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.TwoGigabitEthernet.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.flow = Native.Interface.TwoGigabitEthernet.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.nbar = Native.Interface.TwoGigabitEthernet.Ip.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.ospf = Native.Interface.TwoGigabitEthernet.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.lisp = Native.Interface.TwoGigabitEthernet.Ip.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                    self.rsvp = Native.Interface.TwoGigabitEthernet.Ip.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

                    self.nat = Native.Interface.TwoGigabitEthernet.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.wccp = Native.Interface.TwoGigabitEthernet.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache', 'unreachables'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.TwoGigabitEthernet.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.TwoGigabitEthernet.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.TwoGigabitEthernet.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.TwoGigabitEthernet.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.TwoGigabitEthernet.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.TwoGigabitEthernet.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.TwoGigabitEthernet.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.TwoGigabitEthernet.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.TwoGigabitEthernet.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.TwoGigabitEthernet.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.TwoGigabitEthernet.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.TwoGigabitEthernet.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.TwoGigabitEthernet.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.TwoGigabitEthernet.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.TwoGigabitEthernet.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.TwoGigabitEthernet.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.TwoGigabitEthernet.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.TwoGigabitEthernet.Ip.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ip.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ip.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.TwoGigabitEthernet.Ip.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.TwoGigabitEthernet.Ip.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.TwoGigabitEthernet.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.TwoGigabitEthernet.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.TwoGigabitEthernet.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.TwoGigabitEthernet.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.TwoGigabitEthernet.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.TwoGigabitEthernet.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwoGigabitEthernet.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.TwoGigabitEthernet.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.TwoGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.TwoGigabitEthernet.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TwoGigabitEthernet.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.TwoGigabitEthernet.Ip.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ip.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.TwoGigabitEthernet.Ip.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.TwoGigabitEthernet.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.TwoGigabitEthernet.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.TwoGigabitEthernet.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.TwoGigabitEthernet.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.TwoGigabitEthernet.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.TwoGigabitEthernet.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.TwoGigabitEthernet.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.TwoGigabitEthernet.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.TwoGigabitEthernet.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TwoGigabitEthernet.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.TwoGigabitEthernet.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.TwoGigabitEthernet.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.TwoGigabitEthernet.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.TwoGigabitEthernet.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.TwoGigabitEthernet.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.TwoGigabitEthernet.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.TwoGigabitEthernet.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.TwoGigabitEthernet.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.TwoGigabitEthernet.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwoGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.TwoGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Lisp(Entity):
                    """
                    Locator/ID Separation Protocol
                    
                    .. attribute:: source_locator
                    
                    	Choose IP source address for LISP packets egressing this interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_locator', (YLeaf(YType.str, 'source-locator'), ['str'])),
                        ])
                        self.source_locator = None
                        self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Lisp, ['source_locator'], name, value)


                class Rsvp(Entity):
                    """
                    RSVP Interface Commands
                    
                    .. attribute:: authentication
                    
                    	Enables RSVP neighbor authentication (RFC 2747)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bandwidth
                    
                    	RSVP Reservable Bandwidth (kbps)
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	Select permissible RSVP neighbors
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Neighbor>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: precedence
                    
                    	RSVP precedence setting
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Precedence>`
                    
                    .. attribute:: signalling
                    
                    	RSVP signalling
                    	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling>`
                    
                    .. attribute:: tos
                    
                    	RSVP TOS setting
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Tos>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Authentication)), ("bandwidth", ("bandwidth", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth)), ("neighbor", ("neighbor", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Neighbor)), ("precedence", ("precedence", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Precedence)), ("signalling", ("signalling", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling)), ("tos", ("tos", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Tos))])
                        self._leafs = OrderedDict()

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.bandwidth = None
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.neighbor = None
                        self._children_name_map["neighbor"] = "neighbor"

                        self.precedence = Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Precedence()
                        self.precedence.parent = self
                        self._children_name_map["precedence"] = "precedence"

                        self.signalling = Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling()
                        self.signalling.parent = self
                        self._children_name_map["signalling"] = "signalling"

                        self.tos = Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Tos()
                        self.tos.parent = self
                        self._children_name_map["tos"] = "tos"
                        self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp, [], name, value)


                    class Authentication(Entity):
                        """
                        Enables RSVP neighbor authentication (RFC 2747)
                        
                        .. attribute:: key
                        
                        	Password (8 to 40 characters, spaces allowed)
                        	**type**\: str
                        
                        .. attribute:: challenge
                        
                        	Perform challenge/response handshake with new neighbor(s)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key_chain
                        
                        	Name of key chain to use (as created by global 'key chain' command)
                        	**type**\: str
                        
                        .. attribute:: lifetime
                        
                        	Maximum lifetime of neighbor authentication state
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Authentication.Lifetime>`
                        
                        .. attribute:: type
                        
                        	Type of authentication algorithm (default = md5)
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Authentication.Type>`
                        
                        .. attribute:: window_size
                        
                        	Maximum number of messages allowed in receive window (default = 1)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Authentication.Lifetime))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ip.Rsvp.Authentication.Type')])),
                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                            ])
                            self.key = None
                            self.challenge = None
                            self.key_chain = None
                            self.type = None
                            self.window_size = None

                            self.lifetime = Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Authentication.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Authentication, ['key', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Type of authentication algorithm (default = md5)

                            .. data:: md5 = 0

                            .. data:: sha_1 = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            sha_1 = Enum.YLeaf(1, "sha-1")



                        class Lifetime(Entity):
                            """
                            Maximum lifetime of neighbor authentication state
                            
                            .. attribute:: hh_mm_ss
                            
                            	Lifetime (default = 30 mins) in hh\:mm\:ss format
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ])
                                self.hh_mm_ss = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


                    class Bandwidth(Entity):
                        """
                        RSVP Reservable Bandwidth (kbps)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Value>`
                        
                        .. attribute:: percent
                        
                        	Percentage of interface bandwidth. Values higher than 100 represent overbooking
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: mam
                        
                        	Use bandwidth with MAM model of DSTE
                        	**type**\:  :py:class:`Mam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Mam>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Value)), ("mam", ("mam", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Mam))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                            ])
                            self.percent = None

                            self.value = Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.mam = Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Mam()
                            self.mam.parent = self
                            self._children_name_map["mam"] = "mam"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth, ['percent'], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	Reservable Bandwidth (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            .. attribute:: sub_pool
                            
                            	Reservable Bandwidth for Tunnel using sub (BC1) pool (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.value = None
                                self.sub_pool = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Value, ['value', 'sub_pool'], name, value)


                        class Mam(Entity):
                            """
                            Use bandwidth with MAM model of DSTE
                            
                            .. attribute:: max_reservable_bw
                            
                            	Maximum Reservable bandwidth for MAM
                            	**type**\:  :py:class:`MaxReservableBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Mam, self).__init__()

                                self.yang_name = "mam"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("max-reservable-bw", ("max_reservable_bw", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw))])
                                self._leafs = OrderedDict()

                                self.max_reservable_bw = None
                                self._children_name_map["max_reservable_bw"] = "max-reservable-bw"
                                self._segment_path = lambda: "mam"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Mam, [], name, value)


                            class MaxReservableBw(Entity):
                                """
                                Maximum Reservable bandwidth for MAM
                                
                                .. attribute:: value
                                
                                	Reservable Bandwidth (kbps)
                                	**type**\: int
                                
                                	**range:** 1..10000000
                                
                                .. attribute:: bc0
                                
                                	Reservable Bandwidth from global (BC0) pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                .. attribute:: bc1
                                
                                	Reservable Bandwidth from sub pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, self).__init__()

                                    self.yang_name = "max-reservable-bw"
                                    self.yang_parent_name = "mam"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                        ('bc0', (YLeaf(YType.uint32, 'bc0'), ['int'])),
                                        ('bc1', (YLeaf(YType.uint32, 'bc1'), ['int'])),
                                    ])
                                    self.value = None
                                    self.bc0 = None
                                    self.bc1 = None
                                    self._segment_path = lambda: "max-reservable-bw"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, ['value', 'bc0', 'bc1'], name, value)


                    class Neighbor(Entity):
                        """
                        Select permissible RSVP neighbors
                        
                        .. attribute:: acl_number
                        
                        	Access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                            ])
                            self.acl_number = None
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Neighbor, ['acl_number'], name, value)


                    class Precedence(Entity):
                        """
                        RSVP precedence setting
                        
                        .. attribute:: conform
                        
                        	Precedence for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: exceed
                        
                        	Precedence for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Precedence, ['conform', 'exceed'], name, value)


                    class Signalling(Entity):
                        """
                        RSVP signalling
                        
                        .. attribute:: dscp
                        
                        	DSCP for RSVP signalling messages
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: fast_local_repair
                        
                        	Fast Local Repair parameters
                        	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair>`
                        
                        .. attribute:: hello
                        
                        	Enable neighbor\-down detection
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling, self).__init__()

                            self.yang_name = "signalling"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.fast_local_repair = Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair()
                            self.fast_local_repair.parent = self
                            self._children_name_map["fast_local_repair"] = "fast-local-repair"

                            self.hello = None
                            self._children_name_map["hello"] = "hello"
                            self._segment_path = lambda: "signalling"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling, ['dscp'], name, value)


                        class FastLocalRepair(Entity):
                            """
                            Fast Local Repair parameters
                            
                            .. attribute:: wait_time
                            
                            	Wait Time for start of Fast Local Repair in msec
                            	**type**\: int
                            
                            	**range:** 0..5000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                                self.yang_name = "fast-local-repair"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint16, 'wait-time'), ['int'])),
                                ])
                                self.wait_time = None
                                self._segment_path = lambda: "fast-local-repair"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair, ['wait_time'], name, value)


                        class Hello(Entity):
                            """
                            Enable neighbor\-down detection
                            
                            .. attribute:: bfd
                            
                            	Configure BFD trigger for MPLS/TE FRR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	DSCP for RSVP Hello messages
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: graceful_restart
                            
                            	Configure RSVP Graceful Restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: refresh
                            
                            	Configure RSVP Hello refresh behavior for Fast\-Reroute
                            	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh>`
                            
                            .. attribute:: reroute
                            
                            	Configure RSVP Hello refresh behavior for Reroute
                            	**type**\:  :py:class:`Reroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh)), ("reroute", ("reroute", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ('graceful_restart', (YLeaf(YType.empty, 'graceful-restart'), ['Empty'])),
                                ])
                                self.bfd = None
                                self.dscp = None
                                self.graceful_restart = None

                                self.refresh = Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh()
                                self.refresh.parent = self
                                self._children_name_map["refresh"] = "refresh"

                                self.reroute = Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute()
                                self.reroute.parent = self
                                self._children_name_map["reroute"] = "reroute"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello, ['bfd', 'dscp', 'graceful_restart'], name, value)


                            class Refresh(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Fast\-Reroute
                                
                                .. attribute:: interval
                                
                                	Hello interval in msec
                                	**type**\: int
                                
                                	**range:** 10..30000
                                
                                .. attribute:: misses
                                
                                	Number of missed Hello Acks which triggers neighbor down
                                	**type**\: int
                                
                                	**range:** 4..10
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh, self).__init__()

                                    self.yang_name = "refresh"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.misses = None
                                    self._segment_path = lambda: "refresh"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh, ['interval', 'misses'], name, value)


                            class Reroute(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Reroute
                                
                                .. attribute:: dscp
                                
                                	DSCP for RSVP Hello messages
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: refresh
                                
                                	Configure RSVP Reroute Hello refresh behavior
                                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh>`
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute, self).__init__()

                                    self.yang_name = "reroute"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh))])
                                    self._leafs = OrderedDict([
                                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ])
                                    self.dscp = None

                                    self.refresh = Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh()
                                    self.refresh.parent = self
                                    self._children_name_map["refresh"] = "refresh"
                                    self._segment_path = lambda: "reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute, ['dscp'], name, value)


                                class Refresh(Entity):
                                    """
                                    Configure RSVP Reroute Hello refresh behavior
                                    
                                    .. attribute:: interval
                                    
                                    	Hello Reroute interval in msec
                                    	**type**\: int
                                    
                                    	**range:** 1000..30000
                                    
                                    .. attribute:: misses
                                    
                                    	Number of missed Hello Acks which triggers neighbor down
                                    	**type**\: int
                                    
                                    	**range:** 4..10
                                    
                                    

                                    """

                                    _prefix = 'ios-rsvp'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, self).__init__()

                                        self.yang_name = "refresh"
                                        self.yang_parent_name = "reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.misses = None
                                        self._segment_path = lambda: "refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, ['interval', 'misses'], name, value)


                    class Tos(Entity):
                        """
                        RSVP TOS setting
                        
                        .. attribute:: conform
                        
                        	TOS for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: exceed
                        
                        	TOS for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Rsvp.Tos, ['conform', 'exceed'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.TwoGigabitEthernet.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.TwoGigabitEthernet.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.TwoGigabitEthernet.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.TwoGigabitEthernet.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.TwoGigabitEthernet.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TwoGigabitEthernet.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.TwoGigabitEthernet.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TwoGigabitEthernet.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.TwoGigabitEthernet.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.TwoGigabitEthernet.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.TwoGigabitEthernet.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.TrafficFilter>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Flow>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Crypto>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Pim>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: rip
                
                	Configure RIP routing protocol
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Rip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.TwoGigabitEthernet.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.TwoGigabitEthernet.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp)), ("address", ("address", Native.Interface.TwoGigabitEthernet.Ipv6.Address)), ("nd", ("nd", Native.Interface.TwoGigabitEthernet.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.TwoGigabitEthernet.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.TwoGigabitEthernet.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.TwoGigabitEthernet.Ipv6.Flow)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.TwoGigabitEthernet.Ipv6.Crypto)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.TwoGigabitEthernet.Ipv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.TwoGigabitEthernet.Ipv6.Pim)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Interface.TwoGigabitEthernet.Ipv6.Rip))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None
                    self.unreachables = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.TwoGigabitEthernet.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.TwoGigabitEthernet.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.TwoGigabitEthernet.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.flow = Native.Interface.TwoGigabitEthernet.Ipv6.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.crypto = Native.Interface.TwoGigabitEthernet.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.ospf = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.no_pim = Native.Interface.TwoGigabitEthernet.Ipv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.TwoGigabitEthernet.Ipv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects', 'unreachables'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.TwoGigabitEthernet.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.TwoGigabitEthernet.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.TwoGigabitEthernet.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.TwoGigabitEthernet.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TwoGigabitEthernet.Ipv6.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.TwoGigabitEthernet.Ipv6.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ipv6.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ipv6.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Crypto, ['map'], name, value)


                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process
                    
                    	
                    	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Process>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: encryption
                    
                    	Enable encryption
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Network>`
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process", ("process", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Process)), ("authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication)), ("bfd", ("bfd", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.DemandCircuit)), ("encryption", ("encryption", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption)), ("flood-reduction", ("flood_reduction", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.FloodReduction)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.MtuIgnore)), ("neighbor", ("neighbor", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Neighbor)), ("network", ("network", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Network)), ("shutdown", ("shutdown", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Shutdown))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.cost = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.encryption = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.network = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.process = YList(self)
                        self.neighbor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf, ['cost', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Process(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: instance
                        
                        	Set the OSPF instance
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..31
                        
                        		**type**\: int
                        
                        			**range:** 32..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Process, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['int','int'])),
                            ])
                            self.id = None
                            self.area = None
                            self.instance = None
                            self._segment_path = lambda: "process" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Process, ['id', 'area', 'instance'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec authentication
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec authentication
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 256..4294967295
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5>`
                            
                            .. attribute:: sha1
                            
                            	Use SHA\-1 authentication
                            	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ])
                                self.spi = None

                                self.md5 = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.sha1 = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1()
                                self.sha1.parent = self
                                self._children_name_map["sha1"] = "sha1"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec, ['spi'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Sha1(Entity):
                                """
                                Use SHA\-1 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, self).__init__()

                                    self.yang_name = "sha1"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "sha1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "sha1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ipv6.Ospf.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.DatabaseFilter, ['all', 'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.DemandCircuit, ['disable', 'ignore'], name, value)


                    class Encryption(Entity):
                        """
                        Enable encryption
                        
                        .. attribute:: null
                        
                        	No IPsec encryption on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec encryption
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec encryption
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: esp
                            
                            	Use ESP encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipsec_3des
                            
                            	Use 3DES encryption
                            	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des>`
                            
                            .. attribute:: aes_cbc
                            
                            	Use AES\-CBC encryption
                            	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                                ])
                                self.spi = None
                                self.esp = None

                                self.ipsec_3des = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des()
                                self.ipsec_3des.parent = self
                                self._children_name_map["ipsec_3des"] = "ipsec_3des"

                                self.aes_cbc = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc()
                                self.aes_cbc.parent = self
                                self._children_name_map["aes_cbc"] = "aes-cbc"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec, ['spi', 'esp'], name, value)


                            class Ipsec3des(Entity):
                                """
                                Use 3DES encryption
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, self).__init__()

                                    self.yang_name = "ipsec_3des"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "ipsec_3des"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "ipsec_3des"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class AesCbc(Entity):
                                """
                                Use AES\-CBC encryption
                                
                                .. attribute:: aes_cbc_128
                                
                                	Use 128 bit key
                                	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128>`
                                
                                .. attribute:: aes_192
                                
                                	Use 192 bit key
                                	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192>`
                                
                                .. attribute:: aes_256
                                
                                	Use 256 bit key
                                	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, self).__init__()

                                    self.yang_name = "aes-cbc"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256))])
                                    self._leafs = OrderedDict()

                                    self.aes_cbc_128 = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128()
                                    self.aes_cbc_128.parent = self
                                    self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                    self.aes_192 = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192()
                                    self.aes_192.parent = self
                                    self._children_name_map["aes_192"] = "aes-192"

                                    self.aes_256 = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256()
                                    self.aes_256.parent = self
                                    self._children_name_map["aes_256"] = "aes-256"
                                    self._segment_path = lambda: "aes-cbc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, [], name, value)


                                class AesCbc128(Entity):
                                    """
                                    Use 128 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                        self.yang_name = "aes-cbc-128"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-cbc-128"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-cbc-128"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes192(Entity):
                                    """
                                    Use 192 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                        self.yang_name = "aes-192"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-192"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-192"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes256(Entity):
                                    """
                                    Use 256 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                        self.yang_name = "aes-256"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-256"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	Disable Flood Reduction on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.FloodReduction, ['disable'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.MtuIgnore, ['disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Ospf.Shutdown, ['disable'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.TwoGigabitEthernet.Ipv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.TwoGigabitEthernet.Ipv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Pim.Bsr, ['border'], name, value)


                class Rip(Entity):
                    """
                    Configure RIP routing protocol
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable/disable RIP routing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default_information
                    
                    	Configure handling of default route
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Rip.DefaultInformation>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ipv6.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("default-information", ("default_information", Native.Interface.TwoGigabitEthernet.Ipv6.Rip.DefaultInformation))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.id = None
                        self.enable = None

                        self.default_information = Native.Interface.TwoGigabitEthernet.Ipv6.Rip.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Rip, ['id', 'enable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Configure handling of default route
                        
                        .. attribute:: route
                        
                        	
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ipv6.Rip.DefaultInformation.Route>`
                        
                        .. attribute:: metric
                        
                        	Default route metric
                        	**type**\: int
                        
                        	**range:** 1..15
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ipv6.Rip.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route', (YLeaf(YType.enumeration, 'route'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ipv6.Rip.DefaultInformation.Route')])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ])
                            self.route = None
                            self.metric = None
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ipv6.Rip.DefaultInformation, ['route', 'metric'], name, value)

                        class Route(Enum):
                            """
                            Route (Enum Class)

                            .. data:: only = 0

                            .. data:: originate = 1

                            """

                            only = Enum.YLeaf(0, "only")

                            originate = Enum.YLeaf(1, "originate")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.TwoGigabitEthernet.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.TwoGigabitEthernet.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.TwoGigabitEthernet.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.TwoGigabitEthernet.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.TwoGigabitEthernet.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.TwoGigabitEthernet.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.TwoGigabitEthernet.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.TwoGigabitEthernet.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.TwoGigabitEthernet.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TwoGigabitEthernet.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.TwoGigabitEthernet.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.TwoGigabitEthernet.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.TwoGigabitEthernet.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.TwoGigabitEthernet.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.TwoGigabitEthernet.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.TwoGigabitEthernet.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.TwoGigabitEthernet.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.TwoGigabitEthernet.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.TwoGigabitEthernet.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwoGigabitEthernet.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.TwoGigabitEthernet.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.TwoGigabitEthernet.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.TwoGigabitEthernet.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.TwoGigabitEthernet.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.TwoGigabitEthernet.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.TwoGigabitEthernet.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.TwoGigabitEthernet.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.TwoGigabitEthernet.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.TwoGigabitEthernet.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.TwoGigabitEthernet.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.TwoGigabitEthernet.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.TwoGigabitEthernet.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.TwoGigabitEthernet.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.TwoGigabitEthernet.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.TwoGigabitEthernet.CarrierDelay.Down)), ("up", ("up", Native.Interface.TwoGigabitEthernet.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.TwoGigabitEthernet.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.TwoGigabitEthernet.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.TwoGigabitEthernet.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.TwoGigabitEthernet.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.TwoGigabitEthernet.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.TwoGigabitEthernet.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.TwoGigabitEthernet.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.TwoGigabitEthernet.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.TwoGigabitEthernet.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.TwoGigabitEthernet.Plim.Ethernet)), ("qos", ("qos", Native.Interface.TwoGigabitEthernet.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.TwoGigabitEthernet.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.TwoGigabitEthernet.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwoGigabitEthernet.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.TwoGigabitEthernet.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.TwoGigabitEthernet.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.TwoGigabitEthernet.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.TwoGigabitEthernet.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.TwoGigabitEthernet.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.TwoGigabitEthernet.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.TwoGigabitEthernet.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.TwoGigabitEthernet.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.TwoGigabitEthernet.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.TwoGigabitEthernet.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.TwoGigabitEthernet.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect)), ("Cisco-IOS-XE-l2vpn:xconnect-pw-class", ("xconnect_pw_class", Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.TwoGigabitEthernet.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.TwoGigabitEthernet.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.TwoGigabitEthernet.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.TwoGigabitEthernet.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"

                        self.xconnect = Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                        self.xconnect_pw_class = Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.TwoGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.TwoGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Lacp(Entity):
                """
                LACP interface subcommands
                
                .. attribute:: port_priority
                
                	LACP priority on this interface 
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rate
                
                	Rate at which the LACP packets are requested to be ingressed to this interface
                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Lacp.Rate>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Lacp, self).__init__()

                    self.yang_name = "lacp"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_priority', (YLeaf(YType.uint32, 'port-priority'), ['int'])),
                        ('rate', (YLeaf(YType.enumeration, 'rate'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Lacp.Rate')])),
                    ])
                    self.port_priority = None
                    self.rate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:lacp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Lacp, ['port_priority', 'rate'], name, value)

                class Rate(Enum):
                    """
                    Rate (Enum Class)

                    Rate at which the LACP packets are requested to be ingressed to this interface

                    .. data:: fast = 0

                    .. data:: normal = 1

                    """

                    fast = Enum.YLeaf(0, "fast")

                    normal = Enum.YLeaf(1, "normal")



            class CiscoIOSXEEthernetMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: dot1q_in_clear
                    
                    	Dot1q in Clear option
                    	**type**\:  :py:class:`Dot1qInClear <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear>`
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('dot1q_in_clear', (YLeaf(YType.enumeration, 'dot1q-in-clear'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear')])),
                        ])
                        self.dot1q_in_clear = None

                        self.replay_protection = Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, ['dot1q_in_clear'], name, value)

                    class Dot1qInClear(Enum):
                        """
                        Dot1qInClear (Enum Class)

                        Dot1q in Clear option

                        .. data:: Y_1 = 0

                        """

                        Y_1 = Enum.YLeaf(0, "1")



                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, ['window_size'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.TwoGigabitEthernet.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.TwoGigabitEthernet.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Auto(Entity):
                """
                Configure Automation
                
                .. attribute:: qos
                
                	Configure AutoQoS
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Auto.Qos>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Auto, self).__init__()

                    self.yang_name = "auto"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("qos", ("qos", Native.Interface.TwoGigabitEthernet.Auto.Qos))])
                    self._leafs = OrderedDict()

                    self.qos = Native.Interface.TwoGigabitEthernet.Auto.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:auto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Auto, [], name, value)


                class Qos(Entity):
                    """
                    Configure AutoQoS
                    
                    .. attribute:: classify
                    
                    	Configure classification for untrusted devices
                    	**type**\:  :py:class:`Classify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Auto.Qos.Classify>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trust
                    
                    	Trust the DSCP/CoS marking
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Auto.Qos.Trust>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: video
                    
                    	Configure AutoQoS for video devices
                    	**type**\:  :py:class:`Video <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Auto.Qos.Video>`
                    
                    .. attribute:: voip
                    
                    	Configure AutoQoS for VoIP
                    	**type**\:  :py:class:`Voip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Auto.Qos.Voip>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Auto.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "auto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("classify", ("classify", Native.Interface.TwoGigabitEthernet.Auto.Qos.Classify)), ("trust", ("trust", Native.Interface.TwoGigabitEthernet.Auto.Qos.Trust)), ("video", ("video", Native.Interface.TwoGigabitEthernet.Auto.Qos.Video)), ("voip", ("voip", Native.Interface.TwoGigabitEthernet.Auto.Qos.Voip))])
                        self._leafs = OrderedDict()

                        self.classify = None
                        self._children_name_map["classify"] = "classify"

                        self.trust = None
                        self._children_name_map["trust"] = "trust"

                        self.video = Native.Interface.TwoGigabitEthernet.Auto.Qos.Video()
                        self.video.parent = self
                        self._children_name_map["video"] = "video"

                        self.voip = None
                        self._children_name_map["voip"] = "voip"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Auto.Qos, [], name, value)


                    class Classify(Entity):
                        """
                        Configure classification for untrusted devices
                        
                        .. attribute:: police
                        
                        	Configure QoS policing for untrusted devices
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Auto.Qos.Classify, self).__init__()

                            self.yang_name = "classify"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('police', (YLeaf(YType.empty, 'police'), ['Empty'])),
                            ])
                            self.police = None
                            self._segment_path = lambda: "classify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Auto.Qos.Classify, [u'police'], name, value)


                    class Trust(Entity):
                        """
                        Trust the DSCP/CoS marking
                        
                        .. attribute:: cos
                        
                        	Trust the CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	Trust the DSCP marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Auto.Qos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cos', (YLeaf(YType.empty, 'cos'), ['Empty'])),
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ])
                            self.cos = None
                            self.dscp = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Auto.Qos.Trust, [u'cos', u'dscp'], name, value)


                    class Video(Entity):
                        """
                        Configure AutoQoS for video devices
                        
                        .. attribute:: cts
                        
                        	Trust the QoS marking of the Cisco Telepresence System
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ip_camera
                        
                        	Trust the QoS marking of the Ip Video Surveillance camera
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: media_player
                        
                        	Trust the Qos marking of the Cisco Media Player
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Auto.Qos.Video, self).__init__()

                            self.yang_name = "video"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('cts', (YLeaf(YType.empty, 'cts'), ['Empty'])),
                                ('ip_camera', (YLeaf(YType.empty, 'ip-camera'), ['Empty'])),
                                ('media_player', (YLeaf(YType.empty, 'media-player'), ['Empty'])),
                            ])
                            self.cts = None
                            self.ip_camera = None
                            self.media_player = None
                            self._segment_path = lambda: "video"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Auto.Qos.Video, [u'cts', u'ip_camera', u'media_player'], name, value)


                    class Voip(Entity):
                        """
                        Configure AutoQoS for VoIP
                        
                        .. attribute:: cisco_phone
                        
                        	Trust the QoS marking of Cisco IP Phone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cisco_softphone
                        
                        	Trust the QoS marking of Cisco IP SoftPhone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trust
                        
                        	Trust the DSCP/CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Auto.Qos.Voip, self).__init__()

                            self.yang_name = "voip"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cisco_phone', (YLeaf(YType.empty, 'cisco-phone'), ['Empty'])),
                                ('cisco_softphone', (YLeaf(YType.empty, 'cisco-softphone'), ['Empty'])),
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.cisco_phone = None
                            self.cisco_softphone = None
                            self.trust = None
                            self._segment_path = lambda: "voip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Auto.Qos.Voip, [u'cisco_phone', u'cisco_softphone', u'trust'], name, value)


            class Datalink(Entity):
                """
                Interface Datalink commands
                
                .. attribute:: flow
                
                	Interface Flow configuration subcommands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Datalink.Flow>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Datalink, self).__init__()

                    self.yang_name = "datalink"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flow", ("flow", Native.Interface.TwoGigabitEthernet.Datalink.Flow))])
                    self._leafs = OrderedDict()

                    self.flow = Native.Interface.TwoGigabitEthernet.Datalink.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:datalink"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Datalink, [], name, value)


                class Flow(Entity):
                    """
                    Interface Flow configuration subcommands
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Datalink.Flow.Monitor>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Datalink.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "datalink"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TwoGigabitEthernet.Datalink.Flow.Monitor))])
                        self._leafs = OrderedDict()

                        self.monitor = None
                        self._children_name_map["monitor"] = "monitor"
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Datalink.Flow, [], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: user_defined_flow
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: input_output
                        
                        	Apply Flow Monitor on input/output traffic
                        	**type**\:  :py:class:`InputOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Datalink.Flow.Monitor.InputOutput>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Datalink.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('user_defined_flow', (YLeaf(YType.str, 'User-defined-flow'), ['str'])),
                                ('input_output', (YLeaf(YType.enumeration, 'input-output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Datalink.Flow.Monitor.InputOutput')])),
                            ])
                            self.user_defined_flow = None
                            self.input_output = None
                            self._segment_path = lambda: "monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Datalink.Flow.Monitor, [u'user_defined_flow', u'input_output'], name, value)

                        class InputOutput(Enum):
                            """
                            InputOutput (Enum Class)

                            Apply Flow Monitor on input/output traffic

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



            class Energywise(Entity):
                """
                EnergyWise interface configurations
                
                .. attribute:: activitycheck
                
                	Apply an activity check before turning off power    to this PoE port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: level
                
                	Set the EnergyWise level of this interface  or attached entity
                	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Energywise.Level>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Energywise, self).__init__()

                    self.yang_name = "energywise"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Interface.TwoGigabitEthernet.Energywise.Level))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('activitycheck', (YLeaf(YType.empty, 'activitycheck'), ['Empty'])),
                    ])
                    self.activitycheck = None

                    self.level = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:energywise"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Energywise, [u'activitycheck'], name, value)


                class Level(Entity):
                    """
                    Set the EnergyWise level of this interface 
                    or attached entity
                    
                    .. attribute:: range  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..10
                    
                    .. attribute:: recurrence
                    
                    	Specify that this level setting should  recur at the specified time
                    	**type**\:  :py:class:`Recurrence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Energywise.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "energywise"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("recurrence", ("recurrence", Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                        ])
                        self.range = None

                        self.recurrence = Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence()
                        self.recurrence.parent = self
                        self._children_name_map["recurrence"] = "recurrence"
                        self._segment_path = lambda: "level" + "[range='" + str(self.range) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Energywise.Level, [u'range'], name, value)


                    class Recurrence(Entity):
                        """
                        Specify that this level setting should 
                        recur at the specified time
                        
                        .. attribute:: importance
                        
                        	Specify the importance at which the event  should be sent when it recurs
                        	**type**\: list of  		 :py:class:`Importance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence.Importance>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence, self).__init__()

                            self.yang_name = "recurrence"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("importance", ("importance", Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence.Importance))])
                            self._leafs = OrderedDict()

                            self.importance = YList(self)
                            self._segment_path = lambda: "recurrence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence, [], name, value)


                        class Importance(Entity):
                            """
                            Specify the importance at which the event 
                            should be sent when it recurs
                            
                            .. attribute:: range  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: at
                            
                            	Specify the time(s) this level setting should occur
                            	**type**\:  :py:class:`At <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence.Importance.At>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence.Importance, self).__init__()

                                self.yang_name = "importance"
                                self.yang_parent_name = "recurrence"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("at", ("at", Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence.Importance.At))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.at = Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence.Importance.At()
                                self.at.parent = self
                                self._children_name_map["at"] = "at"
                                self._segment_path = lambda: "importance" + "[range='" + str(self.range) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence.Importance, [u'range'], name, value)


                            class At(Entity):
                                """
                                Specify the time(s) this level setting should occur
                                
                                .. attribute:: minute
                                
                                	cron format of minute(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..59
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: hour
                                
                                	cron format of hour(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..23
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: day
                                
                                	cron format of day(s) of month
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..31
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: month
                                
                                	cron format of month(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..12
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: weekday
                                
                                	cron format of weekday(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..7
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence.Importance.At, self).__init__()

                                    self.yang_name = "at"
                                    self.yang_parent_name = "importance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minute', (YLeaf(YType.str, 'minute'), ['int','str'])),
                                        ('hour', (YLeaf(YType.str, 'hour'), ['int','str'])),
                                        ('day', (YLeaf(YType.str, 'day'), ['int','str'])),
                                        ('month', (YLeaf(YType.str, 'month'), ['int','str'])),
                                        ('weekday', (YLeaf(YType.str, 'weekday'), ['int','str'])),
                                    ])
                                    self.minute = None
                                    self.hour = None
                                    self.day = None
                                    self.month = None
                                    self.weekday = None
                                    self._segment_path = lambda: "at"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Energywise.Level.Recurrence.Importance.At, [u'minute', u'hour', u'day', u'month', u'weekday'], name, value)


            class Location(Entity):
                """
                Interface location information
                
                .. attribute:: civic_location_id
                
                	Civic location information
                	**type**\:  :py:class:`CivicLocationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Location.CivicLocationId>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Location, self).__init__()

                    self.yang_name = "location"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("civic-location-id", ("civic_location_id", Native.Interface.TwoGigabitEthernet.Location.CivicLocationId))])
                    self._leafs = OrderedDict()

                    self.civic_location_id = Native.Interface.TwoGigabitEthernet.Location.CivicLocationId()
                    self.civic_location_id.parent = self
                    self._children_name_map["civic_location_id"] = "civic-location-id"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:location"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Location, [], name, value)


                class CivicLocationId(Entity):
                    """
                    Civic location information
                    
                    .. attribute:: location_identifier
                    
                    	civic location identifier string
                    	**type**\: str
                    
                    .. attribute:: host
                    
                    	Globally defined host location identifer
                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Location.CivicLocationId.Host>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: none
                    
                    	No globally defined location identifer
                    	**type**\:  :py:class:`Y_None <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Location.CivicLocationId.Y_None>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Location.CivicLocationId, self).__init__()

                        self.yang_name = "civic-location-id"
                        self.yang_parent_name = "location"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("host", ("host", Native.Interface.TwoGigabitEthernet.Location.CivicLocationId.Host)), ("none", ("none", Native.Interface.TwoGigabitEthernet.Location.CivicLocationId.Y_None))])
                        self._leafs = OrderedDict([
                            ('location_identifier', (YLeaf(YType.str, 'location-identifier'), ['str'])),
                        ])
                        self.location_identifier = None

                        self.host = None
                        self._children_name_map["host"] = "host"

                        self.none = None
                        self._children_name_map["none"] = "none"
                        self._segment_path = lambda: "civic-location-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Location.CivicLocationId, [u'location_identifier'], name, value)


                    class Host(Entity):
                        """
                        Globally defined host location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Location.CivicLocationId.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "host"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Location.CivicLocationId.Host, [u'port_location'], name, value)


                    class Y_None(Entity):
                        """
                        No globally defined location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Location.CivicLocationId.Y_None, self).__init__()

                            self.yang_name = "none"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Location.CivicLocationId.Y_None, [u'port_location'], name, value)


            class Mac(Entity):
                """
                MAC interface commands
                
                .. attribute:: access_group
                
                	MAC access\-group configuration commands
                	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mac.AccessGroup>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Mac, self).__init__()

                    self.yang_name = "mac"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.TwoGigabitEthernet.Mac.AccessGroup))])
                    self._leafs = OrderedDict()

                    self.access_group = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:mac"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mac, [], name, value)


                class AccessGroup(Entity):
                    """
                    MAC access\-group configuration commands
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mac.AccessGroup.Direction>`
                    
                    .. attribute:: acl_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Mac.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "mac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Mac.AccessGroup.Direction')])),
                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                        ])
                        self.direction = None
                        self.acl_name = None
                        self._segment_path = lambda: "access-group" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mac.AccessGroup, [u'direction', u'acl_name'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Macro(Entity):
                """
                Command macro
                
                .. attribute:: description
                
                	Macro description for this interface
                	**type**\: str
                
                .. attribute:: auto
                
                	Smartport interface macro configurations
                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Macro.Auto>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Macro, self).__init__()

                    self.yang_name = "macro"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.TwoGigabitEthernet.Macro.Auto))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.auto = Native.Interface.TwoGigabitEthernet.Macro.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "auto"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macro"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Macro, [u'description'], name, value)


                class Auto(Entity):
                    """
                    Smartport interface macro configurations
                    
                    .. attribute:: processing
                    
                    	Enable smartport macro auto execution on this interface
                    	**type**\: bool
                    
                    .. attribute:: port
                    
                    	Provide interface specific configuration for macro processing
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Macro.Auto.Port>`
                    
                    .. attribute:: control
                    
                    	Control macro auto execution
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Macro.Auto.Control>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Macro.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "macro"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port", ("port", Native.Interface.TwoGigabitEthernet.Macro.Auto.Port)), ("control", ("control", Native.Interface.TwoGigabitEthernet.Macro.Auto.Control))])
                        self._leafs = OrderedDict([
                            ('processing', (YLeaf(YType.boolean, 'processing'), ['bool'])),
                        ])
                        self.processing = None

                        self.port = Native.Interface.TwoGigabitEthernet.Macro.Auto.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.control = Native.Interface.TwoGigabitEthernet.Macro.Auto.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"
                        self._segment_path = lambda: "auto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Macro.Auto, [u'processing'], name, value)


                    class Port(Entity):
                        """
                        Provide interface specific configuration for macro processing
                        
                        .. attribute:: sticky
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Macro.Auto.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                            ])
                            self.sticky = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Macro.Auto.Port, [u'sticky'], name, value)


                    class Control(Entity):
                        """
                        Control macro auto execution
                        
                        .. attribute:: device
                        
                        	Enable macro auto execution for devices
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Macro.Auto.Control.Device>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Macro.Auto.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("device", ("device", Native.Interface.TwoGigabitEthernet.Macro.Auto.Control.Device))])
                            self._leafs = OrderedDict()

                            self.device = Native.Interface.TwoGigabitEthernet.Macro.Auto.Control.Device()
                            self.device.parent = self
                            self._children_name_map["device"] = "device"
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Macro.Auto.Control, [], name, value)


                        class Device(Entity):
                            """
                            Enable macro auto execution for devices
                            
                            .. attribute:: phone
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Macro.Auto.Control.Device, self).__init__()

                                self.yang_name = "device"
                                self.yang_parent_name = "control"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('phone', (YLeaf(YType.empty, 'phone'), ['Empty'])),
                                ])
                                self.phone = None
                                self._segment_path = lambda: "device"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Macro.Auto.Control.Device, [u'phone'], name, value)


            class DualActive(Entity):
                """
                
                
                .. attribute:: fast_hello
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.DualActive, self).__init__()

                    self.yang_name = "dual-active"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fast_hello', (YLeaf(YType.empty, 'fast-hello'), ['Empty'])),
                    ])
                    self.fast_hello = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:dual-active"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.DualActive, [u'fast_hello'], name, value)


            class LoadBalancing(Entity):
                """
                Etherchannel Load\-Balancing
                
                .. attribute:: flow
                
                	Based on the traffic flows identified by the packet headers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Based on the VLAN to member links manual configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.LoadBalancing, self).__init__()

                    self.yang_name = "load-balancing"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('flow', (YLeaf(YType.empty, 'flow'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.flow = None
                    self.vlan = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:load-balancing"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.LoadBalancing, [u'flow', u'vlan'], name, value)


            class VlanRange(Entity):
                """
                
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4096
                
                		**type**\: str
                
                .. attribute:: service_policy
                
                	Configure QoS Service Policy
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.VlanRange.ServicePolicy>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.VlanRange, self).__init__()

                    self.yang_name = "vlan-range"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.TwoGigabitEthernet.VlanRange.ServicePolicy))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                    ])
                    self.id = None

                    self.service_policy = Native.Interface.TwoGigabitEthernet.VlanRange.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:vlan-range" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.VlanRange, [u'id'], name, value)


                class ServicePolicy(Entity):
                    """
                    Configure QoS Service Policy
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.VlanRange.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "vlan-range"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.VlanRange.ServicePolicy, [u'input', u'output'], name, value)


            class Switch(Entity):
                """
                
                
                .. attribute:: virtual
                
                	
                	**type**\:  :py:class:`Virtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Switch.Virtual>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("virtual", ("virtual", Native.Interface.TwoGigabitEthernet.Switch.Virtual))])
                    self._leafs = OrderedDict()

                    self.virtual = Native.Interface.TwoGigabitEthernet.Switch.Virtual()
                    self.virtual.parent = self
                    self._children_name_map["virtual"] = "virtual"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:switch"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switch, [], name, value)


                class Virtual(Entity):
                    """
                    
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Switch.Virtual, self).__init__()

                        self.yang_name = "virtual"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ])
                        self.link = None
                        self._segment_path = lambda: "virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Switch.Virtual, [u'link'], name, value)


            class SrrQueue(Entity):
                """
                
                
                .. attribute:: bandwidth
                
                	
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.SrrQueue, self).__init__()

                    self.yang_name = "srr-queue"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth))])
                    self._leafs = OrderedDict()

                    self.bandwidth = Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:srr-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.SrrQueue, [], name, value)


                class Bandwidth(Entity):
                    """
                    
                    
                    .. attribute:: shape
                    
                    	
                    	**type**\:  :py:class:`Shape <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth.Shape>`
                    
                    .. attribute:: share
                    
                    	
                    	**type**\:  :py:class:`Share <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth.Share>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "srr-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("shape", ("shape", Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth.Shape)), ("share", ("share", Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth.Share))])
                        self._leafs = OrderedDict()

                        self.shape = Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"

                        self.share = Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth.Share()
                        self.share.parent = self
                        self._children_name_map["share"] = "share"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth, [], name, value)


                    class Shape(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint16, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint16, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint16, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint16, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "shape"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth.Shape, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


                    class Share(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth.Share, self).__init__()

                            self.yang_name = "share"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint8, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint8, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint8, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint8, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "share"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.SrrQueue.Bandwidth.Share, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


            class CiscoIOSXESwitchMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection>`
                    
                    .. attribute:: network_link
                    
                    	Enable macsec on switch connected interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('network_link', (YLeaf(YType.empty, 'network-link'), ['Empty'])),
                        ])
                        self.network_link = None

                        self.replay_protection = Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec, [u'network_link'], name, value)


                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, [u'window_size'], name, value)


            class DeviceTracking(Entity):
                """
                Configure device\-tracking on the interface
                
                .. attribute:: attach_policy
                
                	Apply a policy for feature device\-tracking
                	**type**\: str
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.DeviceTracking, self).__init__()

                    self.yang_name = "device-tracking"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                    ])
                    self.attach_policy = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:device-tracking"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.DeviceTracking, [u'attach_policy'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.TwoGigabitEthernet.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.TwoGigabitEthernet.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.TwoGigabitEthernet.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.TwoGigabitEthernet.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.TwoGigabitEthernet.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.TwoGigabitEthernet.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.TwoGigabitEthernet.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.TwoGigabitEthernet.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class Mka(Entity):
                """
                MACsec Key Agreement (MKA) interface configuration
                
                .. attribute:: policy
                
                	Apply MKA Policy
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mka.Policy>`
                
                .. attribute:: pre_shared_key
                
                	Configure MKA Pre\-Shared\-Key
                	**type**\:  :py:class:`PreSharedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mka.PreSharedKey>`
                
                

                """

                _prefix = 'ios-mka'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Mka, self).__init__()

                    self.yang_name = "mka"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.TwoGigabitEthernet.Mka.Policy)), ("pre-shared-key", ("pre_shared_key", Native.Interface.TwoGigabitEthernet.Mka.PreSharedKey))])
                    self._leafs = OrderedDict()

                    self.policy = Native.Interface.TwoGigabitEthernet.Mka.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.pre_shared_key = Native.Interface.TwoGigabitEthernet.Mka.PreSharedKey()
                    self.pre_shared_key.parent = self
                    self._children_name_map["pre_shared_key"] = "pre-shared-key"
                    self._segment_path = lambda: "Cisco-IOS-XE-mka:mka"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mka, [], name, value)


                class Policy(Entity):
                    """
                    Apply MKA Policy
                    
                    .. attribute:: name
                    
                    	MKA Policy NAME
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Mka.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mka.Policy, ['name'], name, value)


                class PreSharedKey(Entity):
                    """
                    Configure MKA Pre\-Shared\-Key
                    
                    .. attribute:: key_chain
                    
                    	Configure the key\-chain name
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mka.PreSharedKey.KeyChain>`
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Mka.PreSharedKey, self).__init__()

                        self.yang_name = "pre-shared-key"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.TwoGigabitEthernet.Mka.PreSharedKey.KeyChain))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.TwoGigabitEthernet.Mka.PreSharedKey.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"
                        self._segment_path = lambda: "pre-shared-key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mka.PreSharedKey, [], name, value)


                    class KeyChain(Entity):
                        """
                        Configure the key\-chain name
                        
                        .. attribute:: name
                        
                        	Name of key\-chain to be used to get keys
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mka'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Mka.PreSharedKey.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "pre-shared-key"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mka.PreSharedKey.KeyChain, ['name'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Utd, ['enable'], name, value)


            class Xconnect(Entity):
                """
                Xconnect commands
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: vcid
                
                	
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: encapsulation
                
                	Data encapsulation method
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Xconnect.Encapsulation>`
                
                .. attribute:: manual
                
                	Manually configure L2TP session parameters
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sequence
                
                	Configure sequencing options for xconnect
                	**type**\:  :py:class:`Sequence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Xconnect.Sequence>`
                
                .. attribute:: pw_class
                
                	Pseudowire\-class to use for encapsulation and protocol configuration
                	**type**\: str
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Xconnect.Encapsulation')])),
                        ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                        ('sequence', (YLeaf(YType.enumeration, 'sequence'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Xconnect.Sequence')])),
                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                    ])
                    self.address = None
                    self.vcid = None
                    self.encapsulation = None
                    self.manual = None
                    self.sequence = None
                    self.pw_class = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'sequence', 'pw_class'], name, value)

                class Encapsulation(Enum):
                    """
                    Encapsulation (Enum Class)

                    Data encapsulation method

                    .. data:: mpls = 0

                    .. data:: l2tpv3 = 1

                    """

                    mpls = Enum.YLeaf(0, "mpls")

                    l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                class Sequence(Enum):
                    """
                    Sequence (Enum Class)

                    Configure sequencing options for xconnect

                    .. data:: both = 0

                    .. data:: receive = 1

                    .. data:: transmit = 2

                    """

                    both = Enum.YLeaf(0, "both")

                    receive = Enum.YLeaf(1, "receive")

                    transmit = Enum.YLeaf(2, "transmit")



            class Evpn(Entity):
                """
                
                
                .. attribute:: ethernet_segment
                
                	Ethernet segment local discriminator value
                	**type**\: list of  		 :py:class:`EthernetSegment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Evpn, self).__init__()

                    self.yang_name = "evpn"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet-segment", ("ethernet_segment", Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment))])
                    self._leafs = OrderedDict()

                    self.ethernet_segment = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:evpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Evpn, [], name, value)


                class EthernetSegment(Entity):
                    """
                    Ethernet segment local discriminator value
                    
                    .. attribute:: es_value  (key)
                    
                    	Ethernet segment local discriminator value
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: df_election
                    
                    	Designated forwarder election parameters
                    	**type**\:  :py:class:`DfElection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment.DfElection>`
                    
                    .. attribute:: redundancy
                    
                    	Multi\-homing redundancy parameters
                    	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment.Redundancy>`
                    
                    .. attribute:: sytem_mac
                    
                    	System MAC address for generating the Ethernet Segment ID
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment, self).__init__()

                        self.yang_name = "ethernet-segment"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['es_value']
                        self._child_classes = OrderedDict([("df-election", ("df_election", Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment.DfElection)), ("redundancy", ("redundancy", Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment.Redundancy))])
                        self._leafs = OrderedDict([
                            ('es_value', (YLeaf(YType.uint16, 'es-value'), ['int'])),
                            ('sytem_mac', (YLeaf(YType.str, 'sytem-mac'), ['str'])),
                        ])
                        self.es_value = None
                        self.sytem_mac = None

                        self.df_election = Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment.DfElection()
                        self.df_election.parent = self
                        self._children_name_map["df_election"] = "df-election"

                        self.redundancy = Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                        self._segment_path = lambda: "ethernet-segment" + "[es-value='" + str(self.es_value) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment, ['es_value', 'sytem_mac'], name, value)


                    class DfElection(Entity):
                        """
                        Designated forwarder election parameters
                        
                        .. attribute:: wait_time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment.DfElection, self).__init__()

                            self.yang_name = "df-election"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wait_time', (YLeaf(YType.uint8, 'wait-time'), ['int'])),
                            ])
                            self.wait_time = None
                            self._segment_path = lambda: "df-election"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment.DfElection, ['wait_time'], name, value)


                    class Redundancy(Entity):
                        """
                        Multi\-homing redundancy parameters
                        
                        .. attribute:: all_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: single_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment.Redundancy, self).__init__()

                            self.yang_name = "redundancy"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all_active', (YLeaf(YType.empty, 'all-active'), ['Empty'])),
                                ('single_active', (YLeaf(YType.empty, 'single-active'), ['Empty'])),
                            ])
                            self.all_active = None
                            self.single_active = None
                            self._segment_path = lambda: "redundancy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Evpn.EthernetSegment.Redundancy, ['all_active', 'single_active'], name, value)


            class FabricDomain(Entity):
                """
                Fabric\-domain interface command
                
                .. attribute:: iwan_fabric
                
                	
                	**type**\:  :py:class:`IwanFabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.FabricDomain.IwanFabric>`
                
                

                """

                _prefix = 'ios-iwanfabric'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.FabricDomain, self).__init__()

                    self.yang_name = "fabric-domain"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("iwan-fabric", ("iwan_fabric", Native.Interface.TwoGigabitEthernet.FabricDomain.IwanFabric))])
                    self._leafs = OrderedDict()

                    self.iwan_fabric = Native.Interface.TwoGigabitEthernet.FabricDomain.IwanFabric()
                    self.iwan_fabric.parent = self
                    self._children_name_map["iwan_fabric"] = "iwan-fabric"
                    self._segment_path = lambda: "Cisco-IOS-XE-iwanfabric:fabric-domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.FabricDomain, [], name, value)


                class IwanFabric(Entity):
                    """
                    
                    
                    .. attribute:: word
                    
                    	
                    	**type**\: list of  		 :py:class:`Word <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.FabricDomain.IwanFabric.Word>`
                    
                    

                    """

                    _prefix = 'ios-iwanfabric'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.FabricDomain.IwanFabric, self).__init__()

                        self.yang_name = "iwan-fabric"
                        self.yang_parent_name = "fabric-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("word", ("word", Native.Interface.TwoGigabitEthernet.FabricDomain.IwanFabric.Word))])
                        self._leafs = OrderedDict()

                        self.word = YList(self)
                        self._segment_path = lambda: "iwan-fabric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.FabricDomain.IwanFabric, [], name, value)


                    class Word(Entity):
                        """
                        
                        
                        .. attribute:: word  (key)
                        
                        	Path name
                        	**type**\: str
                        
                        .. attribute:: interface_id
                        
                        	Specify the interface\-id value
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-iwanfabric'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.FabricDomain.IwanFabric.Word, self).__init__()

                            self.yang_name = "word"
                            self.yang_parent_name = "iwan-fabric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                            ])
                            self.word = None
                            self.interface_id = None
                            self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.FabricDomain.IwanFabric.Word, ['word', 'interface_id'], name, value)


            class Mvrp(Entity):
                """
                
                
                .. attribute:: mvrp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: registration
                
                	
                	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mvrp.Registration>`
                
                .. attribute:: timer
                
                	
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mvrp.Timer>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mvrp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Mvrp, self).__init__()

                    self.yang_name = "mvrp"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("registration", ("registration", Native.Interface.TwoGigabitEthernet.Mvrp.Registration)), ("timer", ("timer", Native.Interface.TwoGigabitEthernet.Mvrp.Timer))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mvrp', (YLeaf(YType.empty, 'mvrp'), ['Empty'])),
                    ])
                    self.mvrp = None

                    self.registration = Native.Interface.TwoGigabitEthernet.Mvrp.Registration()
                    self.registration.parent = self
                    self._children_name_map["registration"] = "registration"

                    self.timer = Native.Interface.TwoGigabitEthernet.Mvrp.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-mvrp:mvrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mvrp, ['mvrp'], name, value)


                class Registration(Entity):
                    """
                    
                    
                    .. attribute:: fixed
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: forbidden
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: normal
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Mvrp.Registration, self).__init__()

                        self.yang_name = "registration"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fixed', (YLeaf(YType.empty, 'fixed'), ['Empty'])),
                            ('forbidden', (YLeaf(YType.empty, 'forbidden'), ['Empty'])),
                            ('normal', (YLeaf(YType.empty, 'normal'), ['Empty'])),
                        ])
                        self.fixed = None
                        self.forbidden = None
                        self.normal = None
                        self._segment_path = lambda: "registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mvrp.Registration, ['fixed', 'forbidden', 'normal'], name, value)


                class Timer(Entity):
                    """
                    
                    
                    .. attribute:: join
                    
                    	
                    	**type**\:  :py:class:`Join <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mvrp.Timer.Join>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave
                    
                    	
                    	**type**\:  :py:class:`Leave <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mvrp.Timer.Leave>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave_all
                    
                    	
                    	**type**\:  :py:class:`LeaveAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Mvrp.Timer.LeaveAll>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: periodic
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Mvrp.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("join", ("join", Native.Interface.TwoGigabitEthernet.Mvrp.Timer.Join)), ("leave", ("leave", Native.Interface.TwoGigabitEthernet.Mvrp.Timer.Leave)), ("leave-all", ("leave_all", Native.Interface.TwoGigabitEthernet.Mvrp.Timer.LeaveAll))])
                        self._leafs = OrderedDict([
                            ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ])
                        self.periodic = None

                        self.join = None
                        self._children_name_map["join"] = "join"

                        self.leave = None
                        self._children_name_map["leave"] = "leave"

                        self.leave_all = None
                        self._children_name_map["leave_all"] = "leave-all"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mvrp.Timer, ['periodic'], name, value)


                    class Join(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 20..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Mvrp.Timer.Join, self).__init__()

                            self.yang_name = "join"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "join"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mvrp.Timer.Join, ['y_range'], name, value)


                    class Leave(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Mvrp.Timer.Leave, self).__init__()

                            self.yang_name = "leave"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mvrp.Timer.Leave, ['y_range'], name, value)


                    class LeaveAll(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1000..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Mvrp.Timer.LeaveAll, self).__init__()

                            self.yang_name = "leave-all"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave-all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mvrp.Timer.LeaveAll, ['y_range'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.TwoGigabitEthernet.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.TwoGigabitEthernet.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.TwoGigabitEthernet.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.TwoGigabitEthernet.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.TwoGigabitEthernet.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.TwoGigabitEthernet.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.TwoGigabitEthernet.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.TwoGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Power(Entity):
                """
                
                
                .. attribute:: inline
                
                	
                	**type**\:  :py:class:`Inline <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Power.Inline>`
                
                

                """

                _prefix = 'ios-power'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Power, self).__init__()

                    self.yang_name = "power"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("inline", ("inline", Native.Interface.TwoGigabitEthernet.Power.Inline))])
                    self._leafs = OrderedDict()

                    self.inline = Native.Interface.TwoGigabitEthernet.Power.Inline()
                    self.inline.parent = self
                    self._children_name_map["inline"] = "inline"
                    self._segment_path = lambda: "Cisco-IOS-XE-power:power"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Power, [], name, value)


                class Inline(Entity):
                    """
                    
                    
                    .. attribute:: consumption
                    
                    	
                    	**type**\: int
                    
                    	**range:** 4000..15400
                    
                    .. attribute:: never
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: auto
                    
                    	Automatically detect and power inline devices
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Power.Inline.Auto>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: four_pair
                    
                    	Four\-pair PoE power
                    	**type**\:  :py:class:`FourPair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Power.Inline.FourPair>`
                    
                    .. attribute:: police
                    
                    	Police the power drawn on the port
                    	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Power.Inline.Police>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: port
                    
                    	Configure Port Power Level
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Power.Inline.Port>`
                    
                    .. attribute:: static
                    
                    	High priority inline power interface
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Power.Inline.Static>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-power'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Power.Inline, self).__init__()

                        self.yang_name = "inline"
                        self.yang_parent_name = "power"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.TwoGigabitEthernet.Power.Inline.Auto)), ("four-pair", ("four_pair", Native.Interface.TwoGigabitEthernet.Power.Inline.FourPair)), ("police", ("police", Native.Interface.TwoGigabitEthernet.Power.Inline.Police)), ("port", ("port", Native.Interface.TwoGigabitEthernet.Power.Inline.Port)), ("static", ("static", Native.Interface.TwoGigabitEthernet.Power.Inline.Static))])
                        self._leafs = OrderedDict([
                            ('consumption', (YLeaf(YType.uint16, 'consumption'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.consumption = None
                        self.never = None

                        self.auto = None
                        self._children_name_map["auto"] = "auto"

                        self.four_pair = Native.Interface.TwoGigabitEthernet.Power.Inline.FourPair()
                        self.four_pair.parent = self
                        self._children_name_map["four_pair"] = "four-pair"

                        self.police = None
                        self._children_name_map["police"] = "police"

                        self.port = Native.Interface.TwoGigabitEthernet.Power.Inline.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.static = None
                        self._children_name_map["static"] = "static"
                        self._segment_path = lambda: "inline"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Power.Inline, ['consumption', 'never'], name, value)


                    class Auto(Entity):
                        """
                        Automatically detect and power inline devices
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Power.Inline.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "auto"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Power.Inline.Auto, ['max'], name, value)


                    class FourPair(Entity):
                        """
                        Four\-pair PoE power
                        
                        .. attribute:: forced
                        
                        	Enable Four\-pair PoE without L2 negotiation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Power.Inline.FourPair, self).__init__()

                            self.yang_name = "four-pair"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forced', (YLeaf(YType.empty, 'forced'), ['Empty'])),
                            ])
                            self.forced = None
                            self._segment_path = lambda: "four-pair"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Power.Inline.FourPair, ['forced'], name, value)


                    class Police(Entity):
                        """
                        Police the power drawn on the port
                        
                        .. attribute:: action
                        
                        	Action to be taken when power is overdrawn on the port
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Power.Inline.Police.Action>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Power.Inline.Police, self).__init__()

                            self.yang_name = "police"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwoGigabitEthernet.Power.Inline.Police.Action))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.TwoGigabitEthernet.Power.Inline.Police.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "police"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Power.Inline.Police, [], name, value)


                        class Action(Entity):
                            """
                            Action to be taken when power is overdrawn on the port
                            
                            .. attribute:: errdisable
                            
                            	Error\-disable the port when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log a message when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-power'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Power.Inline.Police.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "police"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('errdisable', (YLeaf(YType.empty, 'errdisable'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ])
                                self.errdisable = None
                                self.log = None
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Power.Inline.Police.Action, ['errdisable', 'log'], name, value)


                    class Port(Entity):
                        """
                        Configure Port Power Level
                        
                        .. attribute:: poe_ha
                        
                        	Apply poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: perpetual_poe_ha
                        
                        	Apply perpetual\-poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: two_event
                        
                        	Enable 2\-event classification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Power.Inline.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('poe_ha', (YLeaf(YType.empty, 'poe-ha'), ['Empty'])),
                                ('perpetual_poe_ha', (YLeaf(YType.empty, 'perpetual-poe-ha'), ['Empty'])),
                                ('two_event', (YLeaf(YType.empty, 'two-event'), ['Empty'])),
                            ])
                            self.poe_ha = None
                            self.perpetual_poe_ha = None
                            self.two_event = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Power.Inline.Port, ['poe_ha', 'perpetual_poe_ha', 'two_event'], name, value)


                    class Static(Entity):
                        """
                        High priority inline power interface
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Power.Inline.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "static"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Power.Inline.Static, ['max'], name, value)


            class Cdp(Entity):
                """
                CDP interface subcommands
                
                .. attribute:: enable
                
                	Enable CDP on interface
                	**type**\: bool
                
                .. attribute:: tlv
                
                	Enable exchange of specific tlv information
                	**type**\:  :py:class:`Tlv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cdp.Tlv>`
                
                

                """

                _prefix = 'ios-cdp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Cdp, self).__init__()

                    self.yang_name = "cdp"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tlv", ("tlv", Native.Interface.TwoGigabitEthernet.Cdp.Tlv))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                    ])
                    self.enable = None

                    self.tlv = Native.Interface.TwoGigabitEthernet.Cdp.Tlv()
                    self.tlv.parent = self
                    self._children_name_map["tlv"] = "tlv"
                    self._segment_path = lambda: "Cisco-IOS-XE-cdp:cdp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cdp, ['enable'], name, value)


                class Tlv(Entity):
                    """
                    Enable exchange of specific tlv information
                    
                    .. attribute:: app
                    
                    	Enable/Configure Application TLV
                    	**type**\:  :py:class:`App <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cdp.Tlv.App>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: server_location
                    
                    	Enable CDP location server on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	Exchange location information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cdp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Cdp.Tlv, self).__init__()

                        self.yang_name = "tlv"
                        self.yang_parent_name = "cdp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("app", ("app", Native.Interface.TwoGigabitEthernet.Cdp.Tlv.App))])
                        self._leafs = OrderedDict([
                            ('server_location', (YLeaf(YType.empty, 'server-location'), ['Empty'])),
                            ('location', (YLeaf(YType.empty, 'location'), ['Empty'])),
                        ])
                        self.server_location = None
                        self.location = None

                        self.app = None
                        self._children_name_map["app"] = "app"
                        self._segment_path = lambda: "tlv"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cdp.Tlv, ['server_location', 'location'], name, value)


                    class App(Entity):
                        """
                        Enable/Configure Application TLV
                        
                        .. attribute:: tlvtype
                        
                        	Configure APP TLV
                        	**type**\: int
                        
                        	**range:** 1001..65535
                        
                        .. attribute:: value
                        
                        	Configure App TLV Value information
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cdp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Cdp.Tlv.App, self).__init__()

                            self.yang_name = "app"
                            self.yang_parent_name = "tlv"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tlvtype', (YLeaf(YType.uint16, 'tlvtype'), ['int'])),
                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                            ])
                            self.tlvtype = None
                            self.value = None
                            self._segment_path = lambda: "app"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cdp.Tlv.App, ['tlvtype', 'value'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.TwoGigabitEthernet.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.TwoGigabitEthernet.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.TwoGigabitEthernet.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.TwoGigabitEthernet.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class Authentication(Entity):
                """
                Auth Manager Interface Configuration Commands
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.ControlDirection>`
                
                .. attribute:: event
                
                	Set action for authentication events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event>`
                
                .. attribute:: fallback
                
                	Enable the Webauth fallback mechanism
                	**type**\: str
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.HostMode>`
                
                .. attribute:: open
                
                	Enable or Disable open access on this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: order
                
                	Add an authentication method to the order list
                	**type**\:  :py:class:`Order <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Order>`
                
                .. attribute:: priority
                
                	Add an authentication method to the priority list
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Priority>`
                
                .. attribute:: port_control
                
                	set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.PortControl>`
                
                .. attribute:: periodic
                
                	Enable or Disable Reauthentication for this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timer
                
                	Set authentication timer values
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Timer>`
                
                .. attribute:: violation
                
                	Configure action to take on security violations
                	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Violation>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.TwoGigabitEthernet.Authentication.Event)), ("order", ("order", Native.Interface.TwoGigabitEthernet.Authentication.Order)), ("priority", ("priority", Native.Interface.TwoGigabitEthernet.Authentication.Priority)), ("timer", ("timer", Native.Interface.TwoGigabitEthernet.Authentication.Timer))])
                    self._leafs = OrderedDict([
                        ('control_direction', (YLeaf(YType.enumeration, 'control-direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Authentication.ControlDirection')])),
                        ('fallback', (YLeaf(YType.str, 'fallback'), ['str'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Authentication.HostMode')])),
                        ('open', (YLeaf(YType.empty, 'open'), ['Empty'])),
                        ('port_control', (YLeaf(YType.enumeration, 'port-control'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Authentication.PortControl')])),
                        ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Authentication.Violation')])),
                    ])
                    self.control_direction = None
                    self.fallback = None
                    self.host_mode = None
                    self.open = None
                    self.port_control = None
                    self.periodic = None
                    self.violation = None

                    self.event = Native.Interface.TwoGigabitEthernet.Authentication.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.order = Native.Interface.TwoGigabitEthernet.Authentication.Order()
                    self.order.parent = self
                    self._children_name_map["order"] = "order"

                    self.priority = Native.Interface.TwoGigabitEthernet.Authentication.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "priority"

                    self.timer = Native.Interface.TwoGigabitEthernet.Authentication.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:authentication"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication, ['control_direction', 'fallback', 'host_mode', 'open', 'port_control', 'periodic', 'violation'], name, value)

                class ControlDirection(Enum):
                    """
                    ControlDirection (Enum Class)

                    Set the control\-direction on the interface

                    .. data:: both = 0

                    .. data:: in_ = 1

                    """

                    both = Enum.YLeaf(0, "both")

                    in_ = Enum.YLeaf(1, "in")


                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")


                class PortControl(Enum):
                    """
                    PortControl (Enum Class)

                    set the port\-control value

                    .. data:: auto = 0

                    .. data:: force_authorized = 1

                    .. data:: force_unauthorized = 2

                    """

                    auto = Enum.YLeaf(0, "auto")

                    force_authorized = Enum.YLeaf(1, "force-authorized")

                    force_unauthorized = Enum.YLeaf(2, "force-unauthorized")


                class Violation(Enum):
                    """
                    Violation (Enum Class)

                    Configure action to take on security violations

                    .. data:: protect = 0

                    .. data:: replace = 1

                    .. data:: restrict = 2

                    .. data:: shutdown = 3

                    """

                    protect = Enum.YLeaf(0, "protect")

                    replace = Enum.YLeaf(1, "replace")

                    restrict = Enum.YLeaf(2, "restrict")

                    shutdown = Enum.YLeaf(3, "shutdown")



                class Event(Entity):
                    """
                    Set action for authentication events
                    
                    .. attribute:: server
                    
                    	Configure actions for AAA server events
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.Server>`
                    
                    .. attribute:: fail
                    
                    	Configure actions for AAA fail events
                    	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail>`
                    
                    .. attribute:: no_response
                    
                    	Configure actions for AAA no\-response events
                    	**type**\:  :py:class:`NoResponse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Authentication.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("server", ("server", Native.Interface.TwoGigabitEthernet.Authentication.Event.Server)), ("fail", ("fail", Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail)), ("no-response", ("no_response", Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse))])
                        self._leafs = OrderedDict()

                        self.server = Native.Interface.TwoGigabitEthernet.Authentication.Event.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.fail = Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail()
                        self.fail.parent = self
                        self._children_name_map["fail"] = "fail"

                        self.no_response = Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse()
                        self.no_response.parent = self
                        self._children_name_map["no_response"] = "no-response"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event, [], name, value)


                    class Server(Entity):
                        """
                        Configure actions for AAA server events
                        
                        .. attribute:: alive
                        
                        	Configure AAA server alive action
                        	**type**\:  :py:class:`Alive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Alive>`
                        
                        .. attribute:: dead
                        
                        	Configure AAA server dead action
                        	**type**\:  :py:class:`Dead <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("alive", ("alive", Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Alive)), ("dead", ("dead", Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead))])
                            self._leafs = OrderedDict()

                            self.alive = Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Alive()
                            self.alive.parent = self
                            self._children_name_map["alive"] = "alive"

                            self.dead = Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead()
                            self.dead.parent = self
                            self._children_name_map["dead"] = "dead"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server, [], name, value)


                        class Alive(Entity):
                            """
                            Configure AAA server alive action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Alive.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Alive, self).__init__()

                                self.yang_name = "alive"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Alive.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Alive.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "alive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Alive, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all authorized clients
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Alive.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "alive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reinitialize', (YLeaf(YType.empty, 'reinitialize'), ['Empty'])),
                                    ])
                                    self.reinitialize = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Alive.Action, ['reinitialize'], name, value)


                        class Dead(Entity):
                            """
                            Configure AAA server dead action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead, self).__init__()

                                self.yang_name = "dead"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dead"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: authorize
                                
                                	Authorize the port
                                	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all client on the port
                                	**type**\:  :py:class:`Reinitialize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dead"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize)), ("reinitialize", ("reinitialize", Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize))])
                                    self._leafs = OrderedDict()

                                    self.authorize = None
                                    self._children_name_map["authorize"] = "authorize"

                                    self.reinitialize = Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize()
                                    self.reinitialize.parent = self
                                    self._children_name_map["reinitialize"] = "reinitialize"
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action, [], name, value)


                                class Authorize(Entity):
                                    """
                                    Authorize the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: voice
                                    
                                    	Authorize the port for VOICE traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize, self).__init__()

                                        self.yang_name = "authorize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ('voice', (YLeaf(YType.empty, 'voice'), ['Empty'])),
                                        ])
                                        self.vlan = None
                                        self.voice = None
                                        self._segment_path = lambda: "authorize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize, ['vlan', 'voice'], name, value)


                                class Reinitialize(Entity):
                                    """
                                    Reinitialize all client on the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, self).__init__()

                                        self.yang_name = "reinitialize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "reinitialize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, ['vlan'], name, value)


                    class Fail(Entity):
                        """
                        Configure actions for AAA fail events
                        
                        .. attribute:: action
                        
                        	Required action for fail event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail, self).__init__()

                            self.yang_name = "fail"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "fail"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail, [], name, value)


                        class Action(Entity):
                            """
                            Required action for fail event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "fail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.Fail.Action.Authorize, ['vlan'], name, value)


                    class NoResponse(Entity):
                        """
                        Configure actions for AAA no\-response events
                        
                        .. attribute:: action
                        
                        	Required action for no\-response event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse, self).__init__()

                            self.yang_name = "no-response"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "no-response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse, [], name, value)


                        class Action(Entity):
                            """
                            Required action for no\-response event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "no-response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize, ['vlan'], name, value)


                class Order(Entity):
                    """
                    Add an authentication method to the order list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Authentication.Order, self).__init__()

                        self.yang_name = "order"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "order"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Order, ['dot1x', 'mab', 'webauth'], name, value)


                class Priority(Entity):
                    """
                    Add an authentication method to the priority list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Authentication.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Priority, ['dot1x', 'mab', 'webauth'], name, value)


                class Timer(Entity):
                    """
                    Set authentication timer values
                    
                    .. attribute:: reauthenticate
                    
                    	Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                    	**type**\:  :py:class:`Reauthenticate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Timer.Reauthenticate>`
                    
                    .. attribute:: inactivity
                    
                    	Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                    	**type**\:  :py:class:`Inactivity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity>`
                    
                    .. attribute:: restart
                    
                    	Interval in seconds after which an attempt should be made toauthenticate an unauthorized port (default 60 sec)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Authentication.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reauthenticate", ("reauthenticate", Native.Interface.TwoGigabitEthernet.Authentication.Timer.Reauthenticate)), ("inactivity", ("inactivity", Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity))])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                        ])
                        self.restart = None

                        self.reauthenticate = Native.Interface.TwoGigabitEthernet.Authentication.Timer.Reauthenticate()
                        self.reauthenticate.parent = self
                        self._children_name_map["reauthenticate"] = "reauthenticate"

                        self.inactivity = Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity()
                        self.inactivity.parent = self
                        self._children_name_map["inactivity"] = "inactivity"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Timer, ['restart'], name, value)


                    class Reauthenticate(Entity):
                        """
                        Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: server
                        
                        	Obtain re\-authentication timeout value from the server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Authentication.Timer.Reauthenticate, self).__init__()

                            self.yang_name = "reauthenticate"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                            ])
                            self.value = None
                            self.server = None
                            self._segment_path = lambda: "reauthenticate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Timer.Reauthenticate, ['value', 'server'], name, value)


                    class Inactivity(Entity):
                        """
                        Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity.Value>`
                        
                        .. attribute:: server
                        
                        	Obtain inactivity timeout value from the server
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity.Server>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity, self).__init__()

                            self.yang_name = "inactivity"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity.Value)), ("server", ("server", Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity.Server))])
                            self._leafs = OrderedDict()

                            self.value = Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.server = None
                            self._children_name_map["server"] = "server"
                            self._segment_path = lambda: "inactivity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity, [], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.value = None
                                self.dynamic = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity.Value, ['value', 'dynamic'], name, value)


                        class Server(Entity):
                            """
                            Obtain inactivity timeout value from the server
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.dynamic = None
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Authentication.Timer.Inactivity.Server, ['dynamic'], name, value)


            class Mab(Entity):
                """
                
                
                .. attribute:: eap
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Mab, self).__init__()

                    self.yang_name = "mab"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                    ])
                    self.eap = None
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:mab"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Mab, ['eap'], name, value)


            class Dot1x(Entity):
                """
                Interface Config Commands for IEEE 802.1X
                
                .. attribute:: authenticator
                
                	Configure authenticator parameters
                	**type**\:  :py:class:`Authenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Dot1x.Authenticator>`
                
                .. attribute:: credentials
                
                	Credentials profile configuration
                	**type**\: str
                
                .. attribute:: max_reauth_req
                
                	Max No. of Reauthentication Attempts
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_req
                
                	Max No. of Retries
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_start
                
                	Max No. of EAPOL\-Start requests
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: pae
                
                	Set 802.1x interface pae type
                	**type**\:  :py:class:`Pae <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Dot1x.Pae>`
                
                .. attribute:: supplicant
                
                	Configure supplicant parameters
                	**type**\:  :py:class:`Supplicant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Dot1x.Supplicant>`
                
                .. attribute:: timeout
                
                	Various Timeouts
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Dot1x.Timeout>`
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Dot1x, self).__init__()

                    self.yang_name = "dot1x"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authenticator", ("authenticator", Native.Interface.TwoGigabitEthernet.Dot1x.Authenticator)), ("supplicant", ("supplicant", Native.Interface.TwoGigabitEthernet.Dot1x.Supplicant)), ("timeout", ("timeout", Native.Interface.TwoGigabitEthernet.Dot1x.Timeout))])
                    self._leafs = OrderedDict([
                        ('credentials', (YLeaf(YType.str, 'credentials'), ['str'])),
                        ('max_reauth_req', (YLeaf(YType.uint8, 'max-reauth-req'), ['int'])),
                        ('max_req', (YLeaf(YType.uint8, 'max-req'), ['int'])),
                        ('max_start', (YLeaf(YType.uint8, 'max-start'), ['int'])),
                        ('pae', (YLeaf(YType.enumeration, 'pae'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Dot1x.Pae')])),
                    ])
                    self.credentials = None
                    self.max_reauth_req = None
                    self.max_req = None
                    self.max_start = None
                    self.pae = None

                    self.authenticator = Native.Interface.TwoGigabitEthernet.Dot1x.Authenticator()
                    self.authenticator.parent = self
                    self._children_name_map["authenticator"] = "authenticator"

                    self.supplicant = Native.Interface.TwoGigabitEthernet.Dot1x.Supplicant()
                    self.supplicant.parent = self
                    self._children_name_map["supplicant"] = "supplicant"

                    self.timeout = Native.Interface.TwoGigabitEthernet.Dot1x.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"
                    self._segment_path = lambda: "Cisco-IOS-XE-dot1x:dot1x"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Dot1x, ['credentials', 'max_reauth_req', 'max_req', 'max_start', 'pae'], name, value)

                class Pae(Enum):
                    """
                    Pae (Enum Class)

                    Set 802.1x interface pae type

                    .. data:: authenticator = 0

                    .. data:: supplicant = 1

                    .. data:: both = 2

                    """

                    authenticator = Enum.YLeaf(0, "authenticator")

                    supplicant = Enum.YLeaf(1, "supplicant")

                    both = Enum.YLeaf(2, "both")



                class Authenticator(Entity):
                    """
                    Configure authenticator parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP authenticator parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Dot1x.Authenticator.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Dot1x.Authenticator, self).__init__()

                        self.yang_name = "authenticator"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.TwoGigabitEthernet.Dot1x.Authenticator.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.TwoGigabitEthernet.Dot1x.Authenticator.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "authenticator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Dot1x.Authenticator, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP authenticator parameters
                        
                        .. attribute:: profile
                        
                        	EAP authenticator profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Dot1x.Authenticator.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "authenticator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Dot1x.Authenticator.Eap, ['profile'], name, value)


                class Supplicant(Entity):
                    """
                    Configure supplicant parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP supplicant parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Dot1x.Supplicant.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Dot1x.Supplicant, self).__init__()

                        self.yang_name = "supplicant"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.TwoGigabitEthernet.Dot1x.Supplicant.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.TwoGigabitEthernet.Dot1x.Supplicant.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "supplicant"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Dot1x.Supplicant, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP supplicant parameters
                        
                        .. attribute:: profile
                        
                        	EAP supplicant profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Dot1x.Supplicant.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "supplicant"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Dot1x.Supplicant.Eap, ['profile'], name, value)


                class Timeout(Entity):
                    """
                    Various Timeouts
                    
                    .. attribute:: auth_period
                    
                    	Timeout for authenticator reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: held_period
                    
                    	Timeout for authentication retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: quiet_period
                    
                    	QuietPeriod in Seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ratelimit_period
                    
                    	Ratelimit Period in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: server_timeout
                    
                    	Timeout for Radius Retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: start_period
                    
                    	Timeout for EAPOL\-start retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: supp_timeout
                    
                    	Timeout for supplicant reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: tx_period
                    
                    	Timeout for supplicant retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Dot1x.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auth_period', (YLeaf(YType.uint16, 'auth-period'), ['int'])),
                            ('held_period', (YLeaf(YType.uint16, 'held-period'), ['int'])),
                            ('quiet_period', (YLeaf(YType.uint16, 'quiet-period'), ['int'])),
                            ('ratelimit_period', (YLeaf(YType.uint16, 'ratelimit-period'), ['int'])),
                            ('server_timeout', (YLeaf(YType.uint16, 'server-timeout'), ['int'])),
                            ('start_period', (YLeaf(YType.uint16, 'start-period'), ['int'])),
                            ('supp_timeout', (YLeaf(YType.uint16, 'supp-timeout'), ['int'])),
                            ('tx_period', (YLeaf(YType.uint16, 'tx-period'), ['int'])),
                        ])
                        self.auth_period = None
                        self.held_period = None
                        self.quiet_period = None
                        self.ratelimit_period = None
                        self.server_timeout = None
                        self.start_period = None
                        self.supp_timeout = None
                        self.tx_period = None
                        self._segment_path = lambda: "timeout"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Dot1x.Timeout, ['auth_period', 'held_period', 'quiet_period', 'ratelimit_period', 'server_timeout', 'start_period', 'supp_timeout', 'tx_period'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpdufilter
                
                	Don't send or receive BPDUs on this interface
                	**type**\:  :py:class:`Bpdufilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SpanningTree.Bpdufilter>`
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SpanningTree.Bpduguard>`
                
                .. attribute:: cost
                
                	To set the path cost of the interface
                	**type**\: int
                
                	**range:** 1..200000000
                
                .. attribute:: guard
                
                	Change an interface's spanning tree guard mode
                	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SpanningTree.Guard>`
                
                .. attribute:: link_type
                
                	Specify a link type for spanning tree tree protocol use
                	**type**\:  :py:class:`LinkType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SpanningTree.LinkType>`
                
                .. attribute:: portfast
                
                	Spanning tree portfast options
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                .. attribute:: port_priority
                
                	Spanning tree port\-priority options
                	**type**\: int
                
                	**range:** 0..240
                
                .. attribute:: vlan
                
                	VLAN Switch Spanning Tree
                	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SpanningTree.Vlan>`
                
                .. attribute:: loopguard
                
                	Spanning tree loopguard options
                	**type**\:  :py:class:`Loopguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SpanningTree.Loopguard>`
                
                .. attribute:: mst
                
                	Per interface MST configurations
                	**type**\:  :py:class:`Mst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SpanningTree.Mst>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Interface.TwoGigabitEthernet.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Interface.TwoGigabitEthernet.SpanningTree.Portfast)), ("vlan", ("vlan", Native.Interface.TwoGigabitEthernet.SpanningTree.Vlan)), ("loopguard", ("loopguard", Native.Interface.TwoGigabitEthernet.SpanningTree.Loopguard)), ("mst", ("mst", Native.Interface.TwoGigabitEthernet.SpanningTree.Mst))])
                    self._leafs = OrderedDict([
                        ('bpdufilter', (YLeaf(YType.enumeration, 'bpdufilter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.SpanningTree.Bpdufilter')])),
                        ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ('guard', (YLeaf(YType.enumeration, 'guard'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.SpanningTree.Guard')])),
                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.SpanningTree.LinkType')])),
                        ('port_priority', (YLeaf(YType.uint8, 'port-priority'), ['int'])),
                    ])
                    self.bpdufilter = None
                    self.cost = None
                    self.guard = None
                    self.link_type = None
                    self.port_priority = None

                    self.bpduguard = Native.Interface.TwoGigabitEthernet.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"

                    self.loopguard = Native.Interface.TwoGigabitEthernet.SpanningTree.Loopguard()
                    self.loopguard.parent = self
                    self._children_name_map["loopguard"] = "loopguard"

                    self.mst = Native.Interface.TwoGigabitEthernet.SpanningTree.Mst()
                    self.mst.parent = self
                    self._children_name_map["mst"] = "mst"

                    self.vlan = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:spanning-tree"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.SpanningTree, ['bpdufilter', 'cost', 'guard', 'link_type', 'port_priority'], name, value)

                class Bpdufilter(Enum):
                    """
                    Bpdufilter (Enum Class)

                    Don't send or receive BPDUs on this interface

                    .. data:: disable = 0

                    .. data:: enable = 1

                    """

                    disable = Enum.YLeaf(0, "disable")

                    enable = Enum.YLeaf(1, "enable")


                class Guard(Enum):
                    """
                    Guard (Enum Class)

                    Change an interface's spanning tree guard mode

                    .. data:: loop = 0

                    .. data:: none = 1

                    .. data:: root = 2

                    """

                    loop = Enum.YLeaf(0, "loop")

                    none = Enum.YLeaf(1, "none")

                    root = Enum.YLeaf(2, "root")


                class LinkType(Enum):
                    """
                    LinkType (Enum Class)

                    Specify a link type for spanning tree tree protocol use

                    .. data:: point_to_point = 0

                    .. data:: shared = 1

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")

                    shared = Enum.YLeaf(1, "shared")



                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.disable = None
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.SpanningTree.Bpduguard, ['disable', 'enable'], name, value)


                class Portfast(Entity):
                    """
                    Spanning tree portfast options
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk
                    
                    	Enable portfast on the interface even in trunk mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                        ])
                        self.disable = None
                        self.trunk = None
                        self.edge = None
                        self._segment_path = lambda: "portfast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.SpanningTree.Portfast, ['disable', 'trunk', 'edge'], name, value)


                class Vlan(Entity):
                    """
                    VLAN Switch Spanning Tree
                    
                    .. attribute:: vlan_ids  (key)
                    
                    	vlan range, example\: 1,3\-5,7,9\-11
                    	**type**\: str
                    
                    .. attribute:: cost
                    
                    	<1\-200000000> Spanning\-tree cost
                    	**type**\: int
                    
                    	**range:** 1..200000000
                    
                    .. attribute:: port_priority
                    
                    	<0\-240> port priority in increments of 16
                    	**type**\: int
                    
                    	**range:** 0..240
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.SpanningTree.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vlan_ids']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_ids', (YLeaf(YType.str, 'vlan-ids'), ['str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                        ])
                        self.vlan_ids = None
                        self.cost = None
                        self.port_priority = None
                        self._segment_path = lambda: "vlan" + "[vlan-ids='" + str(self.vlan_ids) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.SpanningTree.Vlan, ['vlan_ids', 'cost', 'port_priority'], name, value)


                class Loopguard(Entity):
                    """
                    Spanning tree loopguard options
                    
                    .. attribute:: default
                    
                    	Enable loopguard by default on all ports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.SpanningTree.Loopguard, self).__init__()

                        self.yang_name = "loopguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.default = None
                        self._segment_path = lambda: "loopguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.SpanningTree.Loopguard, ['default'], name, value)


                class Mst(Entity):
                    """
                    Per interface MST configurations
                    
                    .. attribute:: mst_instance
                    
                    	
                    	**type**\: list of  		 :py:class:`MstInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.SpanningTree.Mst.MstInstance>`
                    
                    .. attribute:: pre_standard
                    
                    	Force pre\-standard MST BPDU transmission on port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.SpanningTree.Mst, self).__init__()

                        self.yang_name = "mst"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mst-instance", ("mst_instance", Native.Interface.TwoGigabitEthernet.SpanningTree.Mst.MstInstance))])
                        self._leafs = OrderedDict([
                            ('pre_standard', (YLeaf(YType.empty, 'pre-standard'), ['Empty'])),
                        ])
                        self.pre_standard = None

                        self.mst_instance = YList(self)
                        self._segment_path = lambda: "mst"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.SpanningTree.Mst, ['pre_standard'], name, value)


                    class MstInstance(Entity):
                        """
                        
                        
                        .. attribute:: instance  (key)
                        
                        	MST instance list, example 0,2\-4,6,8\-12
                        	**type**\: str
                        
                        .. attribute:: cost
                        
                        	<1\-200000000> Spanning\-tree cost
                        	**type**\: int
                        
                        	**range:** 1..200000000
                        
                        .. attribute:: port_priority
                        
                        	<0\-240> port priority in increments of 16
                        	**type**\: int
                        
                        	**range:** 0..240
                        
                        

                        """

                        _prefix = 'ios-stp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.SpanningTree.Mst.MstInstance, self).__init__()

                            self.yang_name = "mst-instance"
                            self.yang_parent_name = "mst"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                            ])
                            self.instance = None
                            self.cost = None
                            self.port_priority = None
                            self._segment_path = lambda: "mst-instance" + "[instance='" + str(self.instance) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.SpanningTree.Mst.MstInstance, ['instance', 'cost', 'port_priority'], name, value)


            class Performance(Entity):
                """
                Global performance monitor configuration
                
                .. attribute:: monitor
                
                	monitor
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Performance.Monitor>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Performance, self).__init__()

                    self.yang_name = "performance"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TwoGigabitEthernet.Performance.Monitor))])
                    self._leafs = OrderedDict()

                    self.monitor = Native.Interface.TwoGigabitEthernet.Performance.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"
                    self._segment_path = lambda: "Cisco-IOS-XE-ezpm:performance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Performance, [], name, value)


                class Monitor(Entity):
                    """
                    monitor
                    
                    .. attribute:: context
                    
                    	Select ezPM context
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Performance.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "performance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('context', (YLeafList(YType.str, 'context'), ['str'])),
                        ])
                        self.context = []
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Performance.Monitor, ['context'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Umbrella, ['out', 'in_'], name, value)


            class Lldp(Entity):
                """
                LLDP interface subcommands
                
                .. attribute:: receive
                
                	Enable LLDP reception on interface
                	**type**\: bool
                
                .. attribute:: transmit
                
                	Enable LLDP transmission on interface
                	**type**\: bool
                
                

                """

                _prefix = 'ios-lldp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Lldp, self).__init__()

                    self.yang_name = "lldp"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                        ('transmit', (YLeaf(YType.boolean, 'transmit'), ['bool'])),
                    ])
                    self.receive = None
                    self.transmit = None
                    self._segment_path = lambda: "Cisco-IOS-XE-lldp:lldp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Lldp, ['receive', 'transmit'], name, value)


            class Ospfv3(Entity):
                """
                OSPFv3 interface commands
                
                .. attribute:: process_id
                
                	
                	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId>`
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication>`
                
                .. attribute:: bfd
                
                	Enable BFD on this interface
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: cost
                
                	Route cost of this interface
                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Cost>`
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: demand_circuit
                
                	OSPF Demand Circuit
                	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.DemandCircuit>`
                
                	**presence node**\: True
                
                .. attribute:: encryption
                
                	Enable encryption
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption>`
                
                .. attribute:: flood_reduction
                
                	OSPF Flood Reduction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: manet
                
                	Mobile Adhoc Networking options
                	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Manet>`
                
                .. attribute:: mtu_ignore
                
                	Ignores the MTU in DBD packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: multi_area
                
                	Set the OSPF multi\-area ID
                	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.MultiArea>`
                
                .. attribute:: neighbor
                
                	OSPF neighbor
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Neighbor>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Network>`
                
                .. attribute:: prefix_suppression
                
                	OSPF prefix suppression
                	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.PrefixSuppression>`
                
                	**presence node**\: True
                
                .. attribute:: priority
                
                	Router priority
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: retransmit_interval
                
                	Time between retransmitting lost link state advertisements
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Shut down the interface in OSPFv3
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transmit_delay
                
                	Link state transmit delay
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Ospfv3, self).__init__()

                    self.yang_name = "ospfv3"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId)), ("authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication)), ("bfd", ("bfd", Native.Interface.TwoGigabitEthernet.Ospfv3.Bfd)), ("cost", ("cost", Native.Interface.TwoGigabitEthernet.Ospfv3.Cost)), ("database-filter", ("database_filter", Native.Interface.TwoGigabitEthernet.Ospfv3.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TwoGigabitEthernet.Ospfv3.DemandCircuit)), ("encryption", ("encryption", Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption)), ("manet", ("manet", Native.Interface.TwoGigabitEthernet.Ospfv3.Manet)), ("multi-area", ("multi_area", Native.Interface.TwoGigabitEthernet.Ospfv3.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TwoGigabitEthernet.Ospfv3.Neighbor)), ("network", ("network", Native.Interface.TwoGigabitEthernet.Ospfv3.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TwoGigabitEthernet.Ospfv3.PrefixSuppression))])
                    self._leafs = OrderedDict([
                        ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                        ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                        ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                    ])
                    self.dead_interval = None
                    self.flood_reduction = None
                    self.hello_interval = None
                    self.mtu_ignore = None
                    self.priority = None
                    self.retransmit_interval = None
                    self.shutdown = None
                    self.transmit_delay = None

                    self.authentication = Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"

                    self.cost = Native.Interface.TwoGigabitEthernet.Ospfv3.Cost()
                    self.cost.parent = self
                    self._children_name_map["cost"] = "cost"

                    self.database_filter = Native.Interface.TwoGigabitEthernet.Ospfv3.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"

                    self.demand_circuit = None
                    self._children_name_map["demand_circuit"] = "demand-circuit"

                    self.encryption = Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.manet = Native.Interface.TwoGigabitEthernet.Ospfv3.Manet()
                    self.manet.parent = self
                    self._children_name_map["manet"] = "manet"

                    self.multi_area = Native.Interface.TwoGigabitEthernet.Ospfv3.MultiArea()
                    self.multi_area.parent = self
                    self._children_name_map["multi_area"] = "multi-area"

                    self.network = Native.Interface.TwoGigabitEthernet.Ospfv3.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.prefix_suppression = None
                    self._children_name_map["prefix_suppression"] = "prefix-suppression"

                    self.process_id = YList(self)
                    self.neighbor = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3, ['dead_interval', u'flood_reduction', 'hello_interval', u'mtu_ignore', 'priority', 'retransmit_interval', u'shutdown', 'transmit_delay'], name, value)


                class ProcessId(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: manet
                    
                    	Mobile Adhoc Networking options
                    	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.MultiArea>`
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Network>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipv4
                    
                    	Specify parameters for IPv4
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Specify parameters for IPv6
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId, self).__init__()

                        self.yang_name = "process-id"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Authentication)), ("bfd", ("bfd", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Bfd)), ("cost", ("cost", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost)), ("database-filter", ("database_filter", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.FloodReduction)), ("manet", ("manet", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Neighbor)), ("network", ("network", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Shutdown)), ("ipv4", ("ipv4", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4)), ("ipv6", ("ipv6", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.id = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.cost = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.database_filter = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.manet = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet()
                        self.manet.parent = self
                        self._children_name_map["manet"] = "manet"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.multi_area = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.network = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.ipv4 = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId, [u'id', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\: str
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.null = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Authentication, [u'key_chain', u'null'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Bfd, ['disable'], name, value)


                    class Cost(Entity):
                        """
                        Route cost of this interface
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dynamic
                        
                        	Specify dynamic cost options
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.dynamic = None
                            self._children_name_map["dynamic"] = "dynamic"
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost, [u'value'], name, value)


                        class Dynamic(Entity):
                            """
                            Specify dynamic cost options
                            
                            .. attribute:: default
                            
                            	Specify default link metric value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: hysteresis
                            
                            	Specify hysteresis value for LSA dampening
                            	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: weight
                            
                            	Specify weight to be placed on individual metrics
                            	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ])
                                self.default = None

                                self.hysteresis = None
                                self._children_name_map["hysteresis"] = "hysteresis"

                                self.weight = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight()
                                self.weight.parent = self
                                self._children_name_map["weight"] = "weight"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic, [u'default'], name, value)


                            class Hysteresis(Entity):
                                """
                                Specify hysteresis value for LSA dampening
                                
                                .. attribute:: percent
                                
                                	Specify hysteresis percent changed
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold
                                
                                	Specify hysteresis threshold value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, self).__init__()

                                    self.yang_name = "hysteresis"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "hysteresis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                            class Weight(Entity):
                                """
                                Specify weight to be placed on individual metrics
                                
                                .. attribute:: l2_factor
                                
                                	Specify weight to be given to L2\-factor metric
                                	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: latency
                                
                                	Specify weight to be given to latency metric
                                	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: resources
                                
                                	Specify weight to be given to resources metric
                                	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: throughput
                                
                                	Specify weight to be given to throughput metric
                                	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, self).__init__()

                                    self.yang_name = "weight"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput))])
                                    self._leafs = OrderedDict()

                                    self.l2_factor = None
                                    self._children_name_map["l2_factor"] = "L2-factor"

                                    self.latency = None
                                    self._children_name_map["latency"] = "latency"

                                    self.resources = None
                                    self._children_name_map["resources"] = "resources"

                                    self.throughput = None
                                    self._children_name_map["throughput"] = "throughput"
                                    self._segment_path = lambda: "weight"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, [], name, value)


                                class L2Factor(Entity):
                                    """
                                    Specify weight to be given to L2\-factor metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                        self.yang_name = "L2-factor"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "L2-factor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                class Latency(Entity):
                                    """
                                    Specify weight to be given to latency metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, self).__init__()

                                        self.yang_name = "latency"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "latency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                class Resources(Entity):
                                    """
                                    Specify weight to be given to resources metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, self).__init__()

                                        self.yang_name = "resources"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "resources"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                class Throughput(Entity):
                                    """
                                    Specify weight to be given to throughput metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, self).__init__()

                                        self.yang_name = "throughput"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "throughput"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter, [u'all', u'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.DemandCircuit, [u'disable', u'ignore'], name, value)


                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.FloodReduction, [u'disable'], name, value)


                    class Manet(Entity):
                        """
                        Mobile Adhoc Networking options
                        
                        .. attribute:: peering
                        
                        	MANET Peering options
                        	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet.Peering>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet, self).__init__()

                            self.yang_name = "manet"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet.Peering))])
                            self._leafs = OrderedDict()

                            self.peering = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet.Peering()
                            self.peering.parent = self
                            self._children_name_map["peering"] = "peering"
                            self._segment_path = lambda: "manet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet, [], name, value)


                        class Peering(Entity):
                            """
                            MANET Peering options
                            
                            .. attribute:: cost
                            
                            	Redundant path cost improvement required to peer
                            	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost>`
                            
                            .. attribute:: link_metrics
                            
                            	Require link metrics
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet.Peering, self).__init__()

                                self.yang_name = "peering"
                                self.yang_parent_name = "manet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost))])
                                self._leafs = OrderedDict([
                                    ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                ])
                                self.link_metrics = None

                                self.cost = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost()
                                self.cost.parent = self
                                self._children_name_map["cost"] = "cost"
                                self._segment_path = lambda: "peering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet.Peering, [u'link_metrics'], name, value)


                            class Cost(Entity):
                                """
                                Redundant path cost improvement required to peer
                                
                                .. attribute:: percent
                                
                                	Relative incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                .. attribute:: threshold
                                
                                	Absolute incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, self).__init__()

                                    self.yang_name = "cost"
                                    self.yang_parent_name = "peering"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "cost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.MtuIgnore, [u'disable'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: disable
                        
                        	disable OSPF multi\-area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.disable = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.MultiArea, [u'id', u'cost', u'disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression, ['disable'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Shutdown, [u'disable'], name, value)


                    class Ipv4(Entity):
                        """
                        Specify parameters for IPv4
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area)), ("authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication)), ("bfd", ("bfd", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd)), ("cost", ("cost", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost)), ("database-filter", ("database_filter", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction)), ("manet", ("manet", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor)), ("network", ("network", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 64..95
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, [u'disable'], name, value)


                    class Ipv6(Entity):
                        """
                        Specify parameters for IPv6
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area)), ("authentication", ("authentication", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication)), ("bfd", ("bfd", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd)), ("cost", ("cost", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost)), ("database-filter", ("database_filter", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction)), ("manet", ("manet", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor)), ("network", ("network", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 0..31
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, [u'disable'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: key_chain
                    
                    	Use a key\-chain for cryptographic authentication keys
                    	**type**\: str
                    
                    .. attribute:: null
                    
                    	Use no authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec authentication
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.null = None

                        self.ipsec = Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication, [u'key_chain', u'null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec authentication
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 256..4294967295
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5>`
                        
                        .. attribute:: sha1
                        
                        	Use SHA\-1 authentication
                        	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                            ])
                            self.spi = None

                            self.md5 = Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"

                            self.sha1 = Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1()
                            self.sha1.parent = self
                            self._children_name_map["sha1"] = "sha1"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec, ['spi'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class Sha1(Entity):
                            """
                            Use SHA\-1 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1, self).__init__()

                                self.yang_name = "sha1"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "sha1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "sha1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                class Bfd(Entity):
                    """
                    Enable BFD on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BFD on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Bfd, ['disable'], name, value)


                class Cost(Entity):
                    """
                    Route cost of this interface
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: dynamic
                    
                    	Specify dynamic cost options
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost, self).__init__()

                        self.yang_name = "cost"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.dynamic = None
                        self._children_name_map["dynamic"] = "dynamic"
                        self._segment_path = lambda: "cost"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost, [u'value'], name, value)


                    class Dynamic(Entity):
                        """
                        Specify dynamic cost options
                        
                        .. attribute:: default
                        
                        	Specify default link metric value
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hysteresis
                        
                        	Specify hysteresis value for LSA dampening
                        	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: weight
                        
                        	Specify weight to be placed on individual metrics
                        	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic, self).__init__()

                            self.yang_name = "dynamic"
                            self.yang_parent_name = "cost"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                            ])
                            self.default = None

                            self.hysteresis = None
                            self._children_name_map["hysteresis"] = "hysteresis"

                            self.weight = Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight()
                            self.weight.parent = self
                            self._children_name_map["weight"] = "weight"
                            self._segment_path = lambda: "dynamic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic, [u'default'], name, value)


                        class Hysteresis(Entity):
                            """
                            Specify hysteresis value for LSA dampening
                            
                            .. attribute:: percent
                            
                            	Specify hysteresis percent changed
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold
                            
                            	Specify hysteresis threshold value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis, self).__init__()

                                self.yang_name = "hysteresis"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "hysteresis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                        class Weight(Entity):
                            """
                            Specify weight to be placed on individual metrics
                            
                            .. attribute:: l2_factor
                            
                            	Specify weight to be given to L2\-factor metric
                            	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: latency
                            
                            	Specify weight to be given to latency metric
                            	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: resources
                            
                            	Specify weight to be given to resources metric
                            	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: throughput
                            
                            	Specify weight to be given to throughput metric
                            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight, self).__init__()

                                self.yang_name = "weight"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput))])
                                self._leafs = OrderedDict()

                                self.l2_factor = None
                                self._children_name_map["l2_factor"] = "L2-factor"

                                self.latency = None
                                self._children_name_map["latency"] = "latency"

                                self.resources = None
                                self._children_name_map["resources"] = "resources"

                                self.throughput = None
                                self._children_name_map["throughput"] = "throughput"
                                self._segment_path = lambda: "weight"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight, [], name, value)


                            class L2Factor(Entity):
                                """
                                Specify weight to be given to L2\-factor metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                    self.yang_name = "L2-factor"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "L2-factor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                            class Latency(Entity):
                                """
                                Specify weight to be given to latency metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, self).__init__()

                                    self.yang_name = "latency"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "latency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                            class Resources(Entity):
                                """
                                Specify weight to be given to resources metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, self).__init__()

                                    self.yang_name = "resources"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "resources"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                            class Throughput(Entity):
                                """
                                Specify weight to be given to throughput metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, self).__init__()

                                    self.yang_name = "throughput"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "throughput"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.DatabaseFilter.All')])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.DatabaseFilter, [u'all'], name, value)

                    class All(Enum):
                        """
                        All (Enum Class)

                        Filter all LSA

                        .. data:: out = 0

                        """

                        out = Enum.YLeaf(0, "out")



                class DemandCircuit(Entity):
                    """
                    OSPF Demand Circuit
                    
                    .. attribute:: ignore
                    
                    	Ignore demand circuit auto\-negotiation requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.DemandCircuit, self).__init__()

                        self.yang_name = "demand-circuit"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.ignore = None
                        self._segment_path = lambda: "demand-circuit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.DemandCircuit, [u'ignore'], name, value)


                class Encryption(Entity):
                    """
                    Enable encryption
                    
                    .. attribute:: null
                    
                    	No IPsec encryption on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec encryption
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec))])
                        self._leafs = OrderedDict([
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.null = None

                        self.ipsec = Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption, ['null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec encryption
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: esp
                        
                        	Use ESP encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec_3des
                        
                        	Use 3DES encryption
                        	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des>`
                        
                        .. attribute:: aes_cbc
                        
                        	Use AES\-CBC encryption
                        	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                            ])
                            self.spi = None
                            self.esp = None

                            self.ipsec_3des = Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des()
                            self.ipsec_3des.parent = self
                            self._children_name_map["ipsec_3des"] = "ipsec_3des"

                            self.aes_cbc = Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc()
                            self.aes_cbc.parent = self
                            self._children_name_map["aes_cbc"] = "aes-cbc"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec, ['spi', 'esp'], name, value)


                        class Ipsec3des(Entity):
                            """
                            Use 3DES encryption
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, self).__init__()

                                self.yang_name = "ipsec_3des"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "ipsec_3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "ipsec_3des"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class AesCbc(Entity):
                            """
                            Use AES\-CBC encryption
                            
                            .. attribute:: aes_cbc_128
                            
                            	Use 128 bit key
                            	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128>`
                            
                            .. attribute:: aes_192
                            
                            	Use 192 bit key
                            	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192>`
                            
                            .. attribute:: aes_256
                            
                            	Use 256 bit key
                            	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc, self).__init__()

                                self.yang_name = "aes-cbc"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256))])
                                self._leafs = OrderedDict()

                                self.aes_cbc_128 = Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128()
                                self.aes_cbc_128.parent = self
                                self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                self.aes_192 = Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192()
                                self.aes_192.parent = self
                                self._children_name_map["aes_192"] = "aes-192"

                                self.aes_256 = Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256()
                                self.aes_256.parent = self
                                self._children_name_map["aes_256"] = "aes-256"
                                self._segment_path = lambda: "aes-cbc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc, [], name, value)


                            class AesCbc128(Entity):
                                """
                                Use 128 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                    self.yang_name = "aes-cbc-128"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-cbc-128"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-cbc-128"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes192(Entity):
                                """
                                Use 192 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                    self.yang_name = "aes-192"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-192"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-192"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes256(Entity):
                                """
                                Use 256 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                    self.yang_name = "aes-256"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-256"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-256"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                class Manet(Entity):
                    """
                    Mobile Adhoc Networking options
                    
                    .. attribute:: peering
                    
                    	MANET Peering options
                    	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Manet.Peering>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.Manet, self).__init__()

                        self.yang_name = "manet"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TwoGigabitEthernet.Ospfv3.Manet.Peering))])
                        self._leafs = OrderedDict()

                        self.peering = Native.Interface.TwoGigabitEthernet.Ospfv3.Manet.Peering()
                        self.peering.parent = self
                        self._children_name_map["peering"] = "peering"
                        self._segment_path = lambda: "manet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Manet, [], name, value)


                    class Peering(Entity):
                        """
                        MANET Peering options
                        
                        .. attribute:: cost
                        
                        	Redundant path cost improvement required to peer
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Manet.Peering.Cost>`
                        
                        .. attribute:: link_metrics
                        
                        	Require link metrics
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.Manet.Peering, self).__init__()

                            self.yang_name = "peering"
                            self.yang_parent_name = "manet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TwoGigabitEthernet.Ospfv3.Manet.Peering.Cost))])
                            self._leafs = OrderedDict([
                                ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                            ])
                            self.link_metrics = None

                            self.cost = Native.Interface.TwoGigabitEthernet.Ospfv3.Manet.Peering.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"
                            self._segment_path = lambda: "peering"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Manet.Peering, [u'link_metrics'], name, value)


                        class Cost(Entity):
                            """
                            Redundant path cost improvement required to peer
                            
                            .. attribute:: percent
                            
                            	Relative incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: threshold
                            
                            	Absolute incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Ospfv3.Manet.Peering.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "peering"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                class MultiArea(Entity):
                    """
                    Set the OSPF multi\-area ID
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.MultiArea, self).__init__()

                        self.yang_name = "multi-area"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self._segment_path = lambda: "multi-area"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.MultiArea, [u'id', u'cost'], name, value)


                class Neighbor(Entity):
                    """
                    OSPF neighbor
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	OSPF cost for point\-to\-multipoint neighbor
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter>`
                    
                    .. attribute:: poll_interval
                    
                    	OSPF dead\-router polling interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: priority
                    
                    	OSPF priority of non\-broadcast neighbor
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TwoGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self.poll_interval = None
                        self.priority = None

                        self.database_filter = Native.Interface.TwoGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter.All')])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter, ['all'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                class Network(Entity):
                    """
                    Network type
                    
                    .. attribute:: broadcast
                    
                    	Specify OSPF broadcast multi\-access network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: manet
                    
                    	Specify MANET OSPF interface type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: non_broadcast
                    
                    	Specify OSPF NBMA network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: point_to_multipoint
                    
                    	Specify OSPF point\-to\-multipoint network
                    	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Ospfv3.Network.PointToMultipoint>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: point_to_point
                    
                    	Specify OSPF point\-to\-point network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TwoGigabitEthernet.Ospfv3.Network.PointToMultipoint))])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                            ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                        ])
                        self.broadcast = None
                        self.manet = None
                        self.non_broadcast = None
                        self.point_to_point = None

                        self.point_to_multipoint = None
                        self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                    class PointToMultipoint(Entity):
                        """
                        Specify OSPF point\-to\-multipoint network
                        
                        .. attribute:: non_broadcast
                        
                        	Specify non\-broadcast point\-to\-mpoint network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Ospfv3.Network.PointToMultipoint, self).__init__()

                            self.yang_name = "point-to-multipoint"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ])
                            self.non_broadcast = None
                            self._segment_path = lambda: "point-to-multipoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.Network.PointToMultipoint, ['non_broadcast'], name, value)


                class PrefixSuppression(Entity):
                    """
                    OSPF prefix suppression
                    
                    .. attribute:: disable
                    
                    	Disable prefix suppression
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Ospfv3.PrefixSuppression, self).__init__()

                        self.yang_name = "prefix-suppression"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "prefix-suppression"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Ospfv3.PrefixSuppression, ['disable'], name, value)


            class Udld(Entity):
                """
                Configure UDLD enabled or disabled and ignore global UDLD setting
                
                .. attribute:: port
                
                	Enable UDLD protocol on this interface despite global UDLD setting
                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Udld.Port>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-udld'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Udld, self).__init__()

                    self.yang_name = "udld"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.TwoGigabitEthernet.Udld.Port))])
                    self._leafs = OrderedDict()

                    self.port = None
                    self._children_name_map["port"] = "port"
                    self._segment_path = lambda: "Cisco-IOS-XE-udld:udld"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Udld, [], name, value)


                class Port(Entity):
                    """
                    Enable UDLD protocol on this interface despite global UDLD setting
                    
                    .. attribute:: aggressive
                    
                    	Enable UDLD protocol in aggressive mode on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	Disable UDLD protocol on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-udld'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Udld.Port, self).__init__()

                        self.yang_name = "port"
                        self.yang_parent_name = "udld"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aggressive', (YLeaf(YType.empty, 'aggressive'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.aggressive = None
                        self.disable = None
                        self._segment_path = lambda: "port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Udld.Port, ['aggressive', 'disable'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.Manual>`
                
                	**presence node**\: True
                
                .. attribute:: role_based
                
                	Role\-based Access Control per\-port config commands
                	**type**\:  :py:class:`RoleBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.RoleBased>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.TwoGigabitEthernet.Cts.Manual)), ("role-based", ("role_based", Native.Interface.TwoGigabitEthernet.Cts.RoleBased))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"

                    self.role_based = Native.Interface.TwoGigabitEthernet.Cts.RoleBased()
                    self.role_based.parent = self
                    self._children_name_map["role_based"] = "role-based"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.TwoGigabitEthernet.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.TwoGigabitEthernet.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.TwoGigabitEthernet.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.TwoGigabitEthernet.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.TwoGigabitEthernet.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.TwoGigabitEthernet.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.Manual.Propagate, ['sgt'], name, value)


                class RoleBased(Entity):
                    """
                    Role\-based Access Control per\-port config commands
                    
                    .. attribute:: sgt_cache
                    
                    	Enable SGT caching on the interface
                    	**type**\: list of   :py:class:`SgtCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.RoleBased.SgtCache>`
                    
                    .. attribute:: enforcement
                    
                    	Enable Role\-based Access Control enforcement
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sgt_map
                    
                    	Assign Security Group Tag (SGT) to IP host or network address
                    	**type**\:  :py:class:`SgtMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.Cts.RoleBased.SgtMap>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.Cts.RoleBased, self).__init__()

                        self.yang_name = "role-based"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sgt-map", ("sgt_map", Native.Interface.TwoGigabitEthernet.Cts.RoleBased.SgtMap))])
                        self._leafs = OrderedDict([
                            ('sgt_cache', (YLeafList(YType.enumeration, 'sgt-cache'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwoGigabitEthernet.Cts.RoleBased.SgtCache')])),
                            ('enforcement', (YLeaf(YType.empty, 'enforcement'), ['Empty'])),
                        ])
                        self.sgt_cache = []
                        self.enforcement = None

                        self.sgt_map = Native.Interface.TwoGigabitEthernet.Cts.RoleBased.SgtMap()
                        self.sgt_map.parent = self
                        self._children_name_map["sgt_map"] = "sgt-map"
                        self._segment_path = lambda: "role-based"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.RoleBased, ['sgt_cache', 'enforcement'], name, value)

                    class SgtCache(Enum):
                        """
                        SgtCache (Enum Class)

                        Enable SGT caching on the interface

                        .. data:: egress = 0

                        .. data:: ingress = 1

                        """

                        egress = Enum.YLeaf(0, "egress")

                        ingress = Enum.YLeaf(1, "ingress")



                    class SgtMap(Entity):
                        """
                        Assign Security Group Tag (SGT) to IP host or network address
                        
                        .. attribute:: security_group
                        
                        	Security Group Name
                        	**type**\: str
                        
                        .. attribute:: sgt
                        
                        	Security Group Tag (SGT)
                        	**type**\: int
                        
                        	**range:** 2..65519
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwoGigabitEthernet.Cts.RoleBased.SgtMap, self).__init__()

                            self.yang_name = "sgt-map"
                            self.yang_parent_name = "role-based"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('security_group', (YLeaf(YType.str, 'security-group'), ['str'])),
                                ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                            ])
                            self.security_group = None
                            self.sgt = None
                            self._segment_path = lambda: "sgt-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwoGigabitEthernet.Cts.RoleBased.SgtMap, ['security_group', 'sgt'], name, value)


            class AnalysisModule(Entity):
                """
                Configure NAM on the interface
                
                .. attribute:: monitoring
                
                	Configure NAM monitoring on the interface
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwoGigabitEthernet.AnalysisModule.Monitoring>`
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Interface.TwoGigabitEthernet.AnalysisModule, self).__init__()

                    self.yang_name = "analysis-module"
                    self.yang_parent_name = "TwoGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Interface.TwoGigabitEthernet.AnalysisModule.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = Native.Interface.TwoGigabitEthernet.AnalysisModule.Monitoring()
                    self.monitoring.parent = self
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwoGigabitEthernet.AnalysisModule, [], name, value)


                class Monitoring(Entity):
                    """
                    Configure NAM monitoring on the interface
                    
                    .. attribute:: interface_name
                    
                    	The name of the output interface.  E.g., 'ucse 1/0/0'
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nam'
                    _revision = '2017-12-28'

                    def __init__(self):
                        super(Native.Interface.TwoGigabitEthernet.AnalysisModule.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "analysis-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "monitoring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwoGigabitEthernet.AnalysisModule.Monitoring, ['interface_name'], name, value)


        class FiveGigabitEthernet(Entity):
            """
            Five Gigabit Ethernet
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: media_type
            
            	Media type
            	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.MediaType>`
            
            .. attribute:: port_type
            
            	
            	**type**\:  :py:class:`PortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.PortType>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service>`
            
            .. attribute:: lacp
            
            	LACP interface subcommands
            	**type**\:  :py:class:`Lacp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Lacp>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec_option
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXEEthernetMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ServicePolicy>`
            
            .. attribute:: auto
            
            	Configure Automation
            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Auto>`
            
            .. attribute:: datalink
            
            	Interface Datalink commands
            	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Datalink>`
            
            .. attribute:: energywise
            
            	EnergyWise interface configurations
            	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Energywise>`
            
            	**presence node**\: True
            
            .. attribute:: location
            
            	Interface location information
            	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Location>`
            
            .. attribute:: mac
            
            	MAC interface commands
            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mac>`
            
            .. attribute:: macro
            
            	Command macro
            	**type**\:  :py:class:`Macro <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Macro>`
            
            .. attribute:: dual_active
            
            	
            	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.DualActive>`
            
            .. attribute:: load_balancing
            
            	Etherchannel Load\-Balancing
            	**type**\:  :py:class:`LoadBalancing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.LoadBalancing>`
            
            .. attribute:: vlan_range
            
            	
            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.VlanRange>`
            
            .. attribute:: switch
            
            	
            	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switch>`
            
            .. attribute:: srr_queue
            
            	
            	**type**\:  :py:class:`SrrQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SrrQueue>`
            
            .. attribute:: cisco_ios_xe_switch_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_switch_macsec_option_
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXESwitchMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption>`
            
            .. attribute:: device_tracking
            
            	Configure device\-tracking on the interface
            	**type**\:  :py:class:`DeviceTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.DeviceTracking>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Snmp>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Crypto>`
            
            .. attribute:: mka
            
            	MACsec Key Agreement (MKA) interface configuration
            	**type**\:  :py:class:`Mka <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mka>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Utd>`
            
            .. attribute:: xconnect
            
            	Xconnect commands
            	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Xconnect>`
            
            .. attribute:: evpn
            
            	
            	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Evpn>`
            
            .. attribute:: fabric_domain
            
            	Fabric\-domain interface command
            	**type**\:  :py:class:`FabricDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.FabricDomain>`
            
            .. attribute:: mvrp
            
            	
            	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mvrp>`
            
            	**presence node**\: True
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Lisp>`
            
            .. attribute:: power
            
            	
            	**type**\:  :py:class:`Power <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Power>`
            
            .. attribute:: cdp
            
            	CDP interface subcommands
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cdp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ntp>`
            
            .. attribute:: authentication
            
            	Auth Manager Interface Configuration Commands
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication>`
            
            .. attribute:: mab
            
            	
            	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mab>`
            
            	**presence node**\: True
            
            .. attribute:: dot1x
            
            	Interface Config Commands for IEEE 802.1X
            	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Dot1x>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SpanningTree>`
            
            .. attribute:: performance
            
            	Global performance monitor configuration
            	**type**\:  :py:class:`Performance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Performance>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Umbrella>`
            
            .. attribute:: lldp
            
            	LLDP interface subcommands
            	**type**\:  :py:class:`Lldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Lldp>`
            
            .. attribute:: vrrp
            
            	Configure VRRP
            	**type**\:  :py:class:`Vrrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp>`
            
            .. attribute:: nat66
            
            	NAT66 interface commands
            	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Nat66>`
            
            .. attribute:: ospfv3
            
            	OSPFv3 interface commands
            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3>`
            
            .. attribute:: udld
            
            	Configure UDLD enabled or disabled and ignore global UDLD setting
            	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Udld>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts>`
            
            .. attribute:: analysis_module
            
            	Configure NAM on the interface
            	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.AnalysisModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.FiveGigabitEthernet, self).__init__()

                self.yang_name = "FiveGigabitEthernet"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.FiveGigabitEthernet.SwitchportConf)), ("switchport", ("switchport", Native.Interface.FiveGigabitEthernet.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.FiveGigabitEthernet.StackwiseVirtual)), ("arp", ("arp", Native.Interface.FiveGigabitEthernet.Arp)), ("backup", ("backup", Native.Interface.FiveGigabitEthernet.Backup)), ("cemoudp", ("cemoudp", Native.Interface.FiveGigabitEthernet.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.FiveGigabitEthernet.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.FiveGigabitEthernet.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.FiveGigabitEthernet.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.FiveGigabitEthernet.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.FiveGigabitEthernet.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.FiveGigabitEthernet.Flowcontrol)), ("isis", ("isis", Native.Interface.FiveGigabitEthernet.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.FiveGigabitEthernet.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.FiveGigabitEthernet.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.FiveGigabitEthernet.Bandwidth)), ("dampening", ("dampening", Native.Interface.FiveGigabitEthernet.Dampening)), ("domain", ("domain", Native.Interface.FiveGigabitEthernet.Domain)), ("hold-queue", ("hold_queue", Native.Interface.FiveGigabitEthernet.HoldQueue)), ("mpls", ("mpls", Native.Interface.FiveGigabitEthernet.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.FiveGigabitEthernet.IpVrf)), ("vrf", ("vrf", Native.Interface.FiveGigabitEthernet.Vrf)), ("ip", ("ip", Native.Interface.FiveGigabitEthernet.Ip)), ("ipv6", ("ipv6", Native.Interface.FiveGigabitEthernet.Ipv6)), ("logging", ("logging", Native.Interface.FiveGigabitEthernet.Logging)), ("mdix", ("mdix", Native.Interface.FiveGigabitEthernet.Mdix)), ("mop", ("mop", Native.Interface.FiveGigabitEthernet.Mop)), ("interface_qos", ("interface_qos", Native.Interface.FiveGigabitEthernet.InterfaceQos)), ("source", ("source", Native.Interface.FiveGigabitEthernet.Source)), ("standby", ("standby", Native.Interface.FiveGigabitEthernet.Standby)), ("access-session", ("access_session", Native.Interface.FiveGigabitEthernet.AccessSession)), ("storm-control", ("storm_control", Native.Interface.FiveGigabitEthernet.StormControl)), ("trust", ("trust", Native.Interface.FiveGigabitEthernet.Trust)), ("priority-queue", ("priority_queue", Native.Interface.FiveGigabitEthernet.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.FiveGigabitEthernet.RcvQueue)), ("peer", ("peer", Native.Interface.FiveGigabitEthernet.Peer)), ("pm-path", ("pm_path", Native.Interface.FiveGigabitEthernet.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.FiveGigabitEthernet.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.FiveGigabitEthernet.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.FiveGigabitEthernet.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.FiveGigabitEthernet.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.FiveGigabitEthernet.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.FiveGigabitEthernet.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.FiveGigabitEthernet.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.FiveGigabitEthernet.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.FiveGigabitEthernet.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.FiveGigabitEthernet.Service)), ("Cisco-IOS-XE-ethernet:lacp", ("lacp", Native.Interface.FiveGigabitEthernet.Lacp)), ("Cisco-IOS-XE-ethernet:macsec-option", ("cisco_ios_xe_ethernet_macsec_option", Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.FiveGigabitEthernet.ServicePolicy)), ("Cisco-IOS-XE-switch:auto", ("auto", Native.Interface.FiveGigabitEthernet.Auto)), ("Cisco-IOS-XE-switch:datalink", ("datalink", Native.Interface.FiveGigabitEthernet.Datalink)), ("Cisco-IOS-XE-switch:energywise", ("energywise", Native.Interface.FiveGigabitEthernet.Energywise)), ("Cisco-IOS-XE-switch:location", ("location", Native.Interface.FiveGigabitEthernet.Location)), ("Cisco-IOS-XE-switch:mac", ("mac", Native.Interface.FiveGigabitEthernet.Mac)), ("Cisco-IOS-XE-switch:macro", ("macro", Native.Interface.FiveGigabitEthernet.Macro)), ("Cisco-IOS-XE-switch:dual-active", ("dual_active", Native.Interface.FiveGigabitEthernet.DualActive)), ("Cisco-IOS-XE-switch:load-balancing", ("load_balancing", Native.Interface.FiveGigabitEthernet.LoadBalancing)), ("Cisco-IOS-XE-switch:vlan-range", ("vlan_range", Native.Interface.FiveGigabitEthernet.VlanRange)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Interface.FiveGigabitEthernet.Switch)), ("Cisco-IOS-XE-switch:srr-queue", ("srr_queue", Native.Interface.FiveGigabitEthernet.SrrQueue)), ("Cisco-IOS-XE-switch:macsec-option", ("cisco_ios_xe_switch_macsec_option_", Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption)), ("Cisco-IOS-XE-switch:device-tracking", ("device_tracking", Native.Interface.FiveGigabitEthernet.DeviceTracking)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.FiveGigabitEthernet.Snmp)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.FiveGigabitEthernet.Crypto)), ("Cisco-IOS-XE-mka:mka", ("mka", Native.Interface.FiveGigabitEthernet.Mka)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.FiveGigabitEthernet.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.FiveGigabitEthernet.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.FiveGigabitEthernet.Utd)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.FiveGigabitEthernet.Xconnect)), ("Cisco-IOS-XE-l2vpn:evpn", ("evpn", Native.Interface.FiveGigabitEthernet.Evpn)), ("Cisco-IOS-XE-iwanfabric:fabric-domain", ("fabric_domain", Native.Interface.FiveGigabitEthernet.FabricDomain)), ("Cisco-IOS-XE-mvrp:mvrp", ("mvrp", Native.Interface.FiveGigabitEthernet.Mvrp)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.FiveGigabitEthernet.Lisp)), ("Cisco-IOS-XE-power:power", ("power", Native.Interface.FiveGigabitEthernet.Power)), ("Cisco-IOS-XE-cdp:cdp", ("cdp", Native.Interface.FiveGigabitEthernet.Cdp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.FiveGigabitEthernet.Ntp)), ("Cisco-IOS-XE-sanet:authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Authentication)), ("Cisco-IOS-XE-sanet:mab", ("mab", Native.Interface.FiveGigabitEthernet.Mab)), ("Cisco-IOS-XE-dot1x:dot1x", ("dot1x", Native.Interface.FiveGigabitEthernet.Dot1x)), ("Cisco-IOS-XE-spanning-tree:spanning-tree", ("spanning_tree", Native.Interface.FiveGigabitEthernet.SpanningTree)), ("Cisco-IOS-XE-ezpm:performance", ("performance", Native.Interface.FiveGigabitEthernet.Performance)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.FiveGigabitEthernet.Umbrella)), ("Cisco-IOS-XE-lldp:lldp", ("lldp", Native.Interface.FiveGigabitEthernet.Lldp)), ("Cisco-IOS-XE-vrrp:vrrp", ("vrrp", Native.Interface.FiveGigabitEthernet.Vrrp)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Interface.FiveGigabitEthernet.Ospfv3)), ("Cisco-IOS-XE-udld:udld", ("udld", Native.Interface.FiveGigabitEthernet.Udld)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.FiveGigabitEthernet.Cts)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Interface.FiveGigabitEthernet.AnalysisModule))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('media_type', (YLeaf(YType.enumeration, 'media-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.MediaType')])),
                    ('port_type', (YLeaf(YType.enumeration, 'port-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.PortType')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Duplex')])),
                    ('cisco_ios_xe_ethernet_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-ethernet:macsec'), ['Empty'])),
                    ('cisco_ios_xe_switch_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:macsec'), ['Empty'])),
                    ('nat66', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-nat:nat66'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Nat66')])),
                ])
                self.name = None
                self.media_type = None
                self.port_type = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None
                self.cisco_ios_xe_ethernet_macsec = None
                self.cisco_ios_xe_switch_macsec = None
                self.nat66 = None

                self.switchport_conf = Native.Interface.FiveGigabitEthernet.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.FiveGigabitEthernet.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.FiveGigabitEthernet.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.FiveGigabitEthernet.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.FiveGigabitEthernet.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.FiveGigabitEthernet.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.FiveGigabitEthernet.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.FiveGigabitEthernet.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.FiveGigabitEthernet.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.FiveGigabitEthernet.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.FiveGigabitEthernet.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.FiveGigabitEthernet.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.FiveGigabitEthernet.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.FiveGigabitEthernet.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.FiveGigabitEthernet.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.FiveGigabitEthernet.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.FiveGigabitEthernet.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.FiveGigabitEthernet.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.FiveGigabitEthernet.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.FiveGigabitEthernet.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.FiveGigabitEthernet.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.FiveGigabitEthernet.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.FiveGigabitEthernet.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.FiveGigabitEthernet.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.FiveGigabitEthernet.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.FiveGigabitEthernet.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.FiveGigabitEthernet.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.FiveGigabitEthernet.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.FiveGigabitEthernet.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.FiveGigabitEthernet.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.FiveGigabitEthernet.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.FiveGigabitEthernet.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.FiveGigabitEthernet.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.FiveGigabitEthernet.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.FiveGigabitEthernet.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.FiveGigabitEthernet.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.FiveGigabitEthernet.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.FiveGigabitEthernet.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.FiveGigabitEthernet.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.FiveGigabitEthernet.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.FiveGigabitEthernet.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.FiveGigabitEthernet.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.FiveGigabitEthernet.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.FiveGigabitEthernet.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.FiveGigabitEthernet.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.lacp = Native.Interface.FiveGigabitEthernet.Lacp()
                self.lacp.parent = self
                self._children_name_map["lacp"] = "Cisco-IOS-XE-ethernet:lacp"

                self.cisco_ios_xe_ethernet_macsec_option = Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption()
                self.cisco_ios_xe_ethernet_macsec_option.parent = self
                self._children_name_map["cisco_ios_xe_ethernet_macsec_option"] = "Cisco-IOS-XE-ethernet:macsec-option"

                self.service_policy = Native.Interface.FiveGigabitEthernet.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.auto = Native.Interface.FiveGigabitEthernet.Auto()
                self.auto.parent = self
                self._children_name_map["auto"] = "Cisco-IOS-XE-switch:auto"

                self.datalink = Native.Interface.FiveGigabitEthernet.Datalink()
                self.datalink.parent = self
                self._children_name_map["datalink"] = "Cisco-IOS-XE-switch:datalink"

                self.energywise = None
                self._children_name_map["energywise"] = "Cisco-IOS-XE-switch:energywise"

                self.location = Native.Interface.FiveGigabitEthernet.Location()
                self.location.parent = self
                self._children_name_map["location"] = "Cisco-IOS-XE-switch:location"

                self.mac = Native.Interface.FiveGigabitEthernet.Mac()
                self.mac.parent = self
                self._children_name_map["mac"] = "Cisco-IOS-XE-switch:mac"

                self.macro = Native.Interface.FiveGigabitEthernet.Macro()
                self.macro.parent = self
                self._children_name_map["macro"] = "Cisco-IOS-XE-switch:macro"

                self.dual_active = Native.Interface.FiveGigabitEthernet.DualActive()
                self.dual_active.parent = self
                self._children_name_map["dual_active"] = "Cisco-IOS-XE-switch:dual-active"

                self.load_balancing = Native.Interface.FiveGigabitEthernet.LoadBalancing()
                self.load_balancing.parent = self
                self._children_name_map["load_balancing"] = "Cisco-IOS-XE-switch:load-balancing"

                self.switch = Native.Interface.FiveGigabitEthernet.Switch()
                self.switch.parent = self
                self._children_name_map["switch"] = "Cisco-IOS-XE-switch:switch"

                self.srr_queue = Native.Interface.FiveGigabitEthernet.SrrQueue()
                self.srr_queue.parent = self
                self._children_name_map["srr_queue"] = "Cisco-IOS-XE-switch:srr-queue"

                self.cisco_ios_xe_switch_macsec_option_ = Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption()
                self.cisco_ios_xe_switch_macsec_option_.parent = self
                self._children_name_map["cisco_ios_xe_switch_macsec_option_"] = "Cisco-IOS-XE-switch:macsec-option"

                self.device_tracking = Native.Interface.FiveGigabitEthernet.DeviceTracking()
                self.device_tracking.parent = self
                self._children_name_map["device_tracking"] = "Cisco-IOS-XE-switch:device-tracking"

                self.snmp = Native.Interface.FiveGigabitEthernet.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.crypto = Native.Interface.FiveGigabitEthernet.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.mka = Native.Interface.FiveGigabitEthernet.Mka()
                self.mka.parent = self
                self._children_name_map["mka"] = "Cisco-IOS-XE-mka:mka"

                self.et_analytics = Native.Interface.FiveGigabitEthernet.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.FiveGigabitEthernet.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.FiveGigabitEthernet.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.xconnect = Native.Interface.FiveGigabitEthernet.Xconnect()
                self.xconnect.parent = self
                self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                self.evpn = Native.Interface.FiveGigabitEthernet.Evpn()
                self.evpn.parent = self
                self._children_name_map["evpn"] = "Cisco-IOS-XE-l2vpn:evpn"

                self.fabric_domain = Native.Interface.FiveGigabitEthernet.FabricDomain()
                self.fabric_domain.parent = self
                self._children_name_map["fabric_domain"] = "Cisco-IOS-XE-iwanfabric:fabric-domain"

                self.mvrp = None
                self._children_name_map["mvrp"] = "Cisco-IOS-XE-mvrp:mvrp"

                self.lisp = Native.Interface.FiveGigabitEthernet.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.power = Native.Interface.FiveGigabitEthernet.Power()
                self.power.parent = self
                self._children_name_map["power"] = "Cisco-IOS-XE-power:power"

                self.cdp = Native.Interface.FiveGigabitEthernet.Cdp()
                self.cdp.parent = self
                self._children_name_map["cdp"] = "Cisco-IOS-XE-cdp:cdp"

                self.ntp = Native.Interface.FiveGigabitEthernet.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.authentication = Native.Interface.FiveGigabitEthernet.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "Cisco-IOS-XE-sanet:authentication"

                self.mab = None
                self._children_name_map["mab"] = "Cisco-IOS-XE-sanet:mab"

                self.dot1x = Native.Interface.FiveGigabitEthernet.Dot1x()
                self.dot1x.parent = self
                self._children_name_map["dot1x"] = "Cisco-IOS-XE-dot1x:dot1x"

                self.spanning_tree = Native.Interface.FiveGigabitEthernet.SpanningTree()
                self.spanning_tree.parent = self
                self._children_name_map["spanning_tree"] = "Cisco-IOS-XE-spanning-tree:spanning-tree"

                self.performance = Native.Interface.FiveGigabitEthernet.Performance()
                self.performance.parent = self
                self._children_name_map["performance"] = "Cisco-IOS-XE-ezpm:performance"

                self.umbrella = Native.Interface.FiveGigabitEthernet.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.lldp = Native.Interface.FiveGigabitEthernet.Lldp()
                self.lldp.parent = self
                self._children_name_map["lldp"] = "Cisco-IOS-XE-lldp:lldp"

                self.vrrp = Native.Interface.FiveGigabitEthernet.Vrrp()
                self.vrrp.parent = self
                self._children_name_map["vrrp"] = "Cisco-IOS-XE-vrrp:vrrp"

                self.ospfv3 = Native.Interface.FiveGigabitEthernet.Ospfv3()
                self.ospfv3.parent = self
                self._children_name_map["ospfv3"] = "Cisco-IOS-XE-ospfv3:ospfv3"

                self.udld = Native.Interface.FiveGigabitEthernet.Udld()
                self.udld.parent = self
                self._children_name_map["udld"] = "Cisco-IOS-XE-udld:udld"

                self.cts = Native.Interface.FiveGigabitEthernet.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.analysis_module = Native.Interface.FiveGigabitEthernet.AnalysisModule()
                self.analysis_module.parent = self
                self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"

                self.hold_queue = YList(self)
                self.vlan_range = YList(self)
                self._segment_path = lambda: "FiveGigabitEthernet" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.FiveGigabitEthernet, [u'name', u'media_type', u'port_type', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex', 'cisco_ios_xe_ethernet_macsec', u'cisco_ios_xe_switch_macsec', 'nat66'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class MediaType(Enum):
                """
                MediaType (Enum Class)

                Media type

                .. data:: auto_select = 0

                .. data:: rj45 = 1

                .. data:: sfp = 2

                """

                auto_select = Enum.YLeaf(0, "auto-select")

                rj45 = Enum.YLeaf(1, "rj45")

                sfp = Enum.YLeaf(2, "sfp")


            class Nat66(Enum):
                """
                Nat66 (Enum Class)

                NAT66 interface commands

                .. data:: inside = 0

                .. data:: outside = 1

                """

                inside = Enum.YLeaf(0, "inside")

                outside = Enum.YLeaf(1, "outside")


            class PortType(Enum):
                """
                PortType (Enum Class)

                .. data:: nni = 0

                """

                nni = Enum.YLeaf(0, "nni")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Access>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Block>`
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: trunk
                
                	Set trunking characteristics of the interface
                	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Trunk>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Voice>`
                
                .. attribute:: priority
                
                	Set appliance 802.1p priority
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Priority>`
                
                .. attribute:: autostate
                
                	Include or exclude this port from vlan link up calculation
                	**type**\:  :py:class:`Autostate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Autostate>`
                
                .. attribute:: protected
                
                	Configure an interface to be a protected port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Set port host
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: private_vlan
                
                	Set the private VLAN configuration
                	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan>`
                
                .. attribute:: vepa
                
                	Reflective relay configuration
                	**type**\:  :py:class:`Vepa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Vepa>`
                
                .. attribute:: device_tracking
                
                	Configure device\-tracking on the interface
                	**type**\:  :py:class:`DeviceTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.DeviceTracking>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:access", ("access", Native.Interface.FiveGigabitEthernet.Switchport.Access)), ("Cisco-IOS-XE-switch:block", ("block", Native.Interface.FiveGigabitEthernet.Switchport.Block)), ("Cisco-IOS-XE-switch:mode", ("mode", Native.Interface.FiveGigabitEthernet.Switchport.Mode)), ("Cisco-IOS-XE-switch:port-security", ("port_security", Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity)), ("Cisco-IOS-XE-switch:trunk", ("trunk", Native.Interface.FiveGigabitEthernet.Switchport.Trunk)), ("Cisco-IOS-XE-switch:voice", ("voice", Native.Interface.FiveGigabitEthernet.Switchport.Voice)), ("Cisco-IOS-XE-switch:priority", ("priority", Native.Interface.FiveGigabitEthernet.Switchport.Priority)), ("Cisco-IOS-XE-switch:autostate", ("autostate", Native.Interface.FiveGigabitEthernet.Switchport.Autostate)), ("Cisco-IOS-XE-switch:private-vlan", ("private_vlan", Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan)), ("Cisco-IOS-XE-switch:vepa", ("vepa", Native.Interface.FiveGigabitEthernet.Switchport.Vepa)), ("Cisco-IOS-XE-switch:device-tracking", ("device_tracking", Native.Interface.FiveGigabitEthernet.Switchport.DeviceTracking))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:nonegotiate'), ['Empty'])),
                        ('protected', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:protected'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:host'), ['Empty'])),
                    ])
                    self.nonegotiate = None
                    self.protected = None
                    self.host = None

                    self.access = Native.Interface.FiveGigabitEthernet.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "Cisco-IOS-XE-switch:access"

                    self.block = Native.Interface.FiveGigabitEthernet.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "Cisco-IOS-XE-switch:block"

                    self.mode = Native.Interface.FiveGigabitEthernet.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "Cisco-IOS-XE-switch:mode"

                    self.port_security = None
                    self._children_name_map["port_security"] = "Cisco-IOS-XE-switch:port-security"

                    self.trunk = Native.Interface.FiveGigabitEthernet.Switchport.Trunk()
                    self.trunk.parent = self
                    self._children_name_map["trunk"] = "Cisco-IOS-XE-switch:trunk"

                    self.voice = Native.Interface.FiveGigabitEthernet.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "Cisco-IOS-XE-switch:voice"

                    self.priority = Native.Interface.FiveGigabitEthernet.Switchport.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-switch:priority"

                    self.autostate = Native.Interface.FiveGigabitEthernet.Switchport.Autostate()
                    self.autostate.parent = self
                    self._children_name_map["autostate"] = "Cisco-IOS-XE-switch:autostate"

                    self.private_vlan = Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan()
                    self.private_vlan.parent = self
                    self._children_name_map["private_vlan"] = "Cisco-IOS-XE-switch:private-vlan"

                    self.vepa = Native.Interface.FiveGigabitEthernet.Switchport.Vepa()
                    self.vepa.parent = self
                    self._children_name_map["vepa"] = "Cisco-IOS-XE-switch:vepa"

                    self.device_tracking = Native.Interface.FiveGigabitEthernet.Switchport.DeviceTracking()
                    self.device_tracking.parent = self
                    self._children_name_map["device_tracking"] = "Cisco-IOS-XE-switch:device-tracking"
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport, [u'nonegotiate', u'protected', u'host'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	Set VLAN when interface is in access mode
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Access.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FiveGigabitEthernet.Switchport.Access.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.FiveGigabitEthernet.Switchport.Access.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:access"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Access, [], name, value)


                    class Vlan(Entity):
                        """
                        Set VLAN when interface is in access mode
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_>`
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.Access.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "access"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Access.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dynamic = 0

                            """

                            dynamic = Enum.YLeaf(0, "dynamic")



                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: multicast
                    
                    	Block unknown multicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.multicast = None
                        self.unicast = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:block"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Block, [u'multicast', u'unicast'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Mode.Access>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dot1q_tunnel
                    
                    	set trunking mode to TUNNEL unconditionally
                    	**type**\:  :py:class:`Dot1qTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Mode.Dot1qTunnel>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dynamic
                    
                    	Set trunking mode to dynamically negotiate access or trunk mode
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Mode.Dynamic>`
                    
                    .. attribute:: private_vlan
                    
                    	Set private\-vlan mode
                    	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Mode.PrivateVlan>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Mode.Trunk>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.FiveGigabitEthernet.Switchport.Mode.Access)), ("dot1q-tunnel", ("dot1q_tunnel", Native.Interface.FiveGigabitEthernet.Switchport.Mode.Dot1qTunnel)), ("private-vlan", ("private_vlan", Native.Interface.FiveGigabitEthernet.Switchport.Mode.PrivateVlan)), ("trunk", ("trunk", Native.Interface.FiveGigabitEthernet.Switchport.Mode.Trunk))])
                        self._leafs = OrderedDict([
                            ('dynamic', (YLeaf(YType.enumeration, 'dynamic'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Switchport.Mode.Dynamic')])),
                        ])
                        self.dynamic = None

                        self.access = None
                        self._children_name_map["access"] = "access"

                        self.dot1q_tunnel = None
                        self._children_name_map["dot1q_tunnel"] = "dot1q-tunnel"

                        self.private_vlan = Native.Interface.FiveGigabitEthernet.Switchport.Mode.PrivateVlan()
                        self.private_vlan.parent = self
                        self._children_name_map["private_vlan"] = "private-vlan"

                        self.trunk = None
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Mode, [u'dynamic'], name, value)

                    class Dynamic(Enum):
                        """
                        Dynamic (Enum Class)

                        Set trunking mode to dynamically negotiate access or trunk mode

                        .. data:: auto = 0

                        .. data:: desirable = 1

                        """

                        auto = Enum.YLeaf(0, "auto")

                        desirable = Enum.YLeaf(1, "desirable")



                    class Access(Entity):
                        """
                        Set trunking mode to ACCESS unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.Mode.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "access"
                            self._is_frozen = True


                    class Dot1qTunnel(Entity):
                        """
                        set trunking mode to TUNNEL unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.Mode.Dot1qTunnel, self).__init__()

                            self.yang_name = "dot1q-tunnel"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dot1q-tunnel"
                            self._is_frozen = True


                    class PrivateVlan(Entity):
                        """
                        Set private\-vlan mode
                        
                        .. attribute:: host
                        
                        	Set the mode to private\-vlan host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: promiscuous
                        
                        	Set the mode to private\-vlan promiscuous
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.Mode.PrivateVlan, self).__init__()

                            self.yang_name = "private-vlan"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('promiscuous', (YLeaf(YType.empty, 'promiscuous'), ['Empty'])),
                            ])
                            self.host = None
                            self.promiscuous = None
                            self._segment_path = lambda: "private-vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Mode.PrivateVlan, [u'host', u'promiscuous'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking mode to TRUNK unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.Mode.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: mac_address
                    
                    	Secure mac address
                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.MacAddress>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Aging)), ("mac-address", ("mac_address", Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.MacAddress)), ("maximum", ("maximum", Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Maximum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Switchport.PortSecurity.Violation')])),
                        ])
                        self.violation = None

                        self.aging = Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.mac_address = Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"

                        self.maximum = Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:port-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity, [u'violation'], name, value)

                    class Violation(Enum):
                        """
                        Violation (Enum Class)

                        Security violation mode

                        .. data:: protect = 0

                        .. data:: restrict = 1

                        .. data:: shutdown = 2

                        """

                        protect = Enum.YLeaf(0, "protect")

                        restrict = Enum.YLeaf(1, "restrict")

                        shutdown = Enum.YLeaf(2, "shutdown")



                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Aging.Type>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Switchport.PortSecurity.Aging.Type')])),
                            ])
                            self.static = None
                            self.time = None
                            self.type = None
                            self._segment_path = lambda: "aging"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Aging, [u'static', u'time', u'type'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Port\-security aging type

                            .. data:: absolute = 0

                            .. data:: inactivity = 1

                            """

                            absolute = Enum.YLeaf(0, "absolute")

                            inactivity = Enum.YLeaf(1, "inactivity")



                    class MacAddress(Entity):
                        """
                        Secure mac address
                        
                        .. attribute:: sticky
                        
                        	Configure dynamic secure addresses as sticky
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hw_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: vlan
                        
                        	set VLAN ID of the VLAN on which this address can be learned
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                ('hw_address', (YLeaf(YType.str, 'hw-address'), ['str'])),
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.sticky = None
                            self.hw_address = None
                            self.vlan = None
                            self._segment_path = lambda: "mac-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.MacAddress, [u'sticky', u'hw_address', u'vlan'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: max_addresses
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4097
                        
                        .. attribute:: vlan
                        
                        	Max secure addresses per vlan
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_addresses', (YLeaf(YType.uint16, 'max-addresses'), ['int'])),
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['str'])),
                            ])
                            self.max_addresses = None
                            self.vlan = None
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.PortSecurity.Maximum, [u'max_addresses', u'vlan'], name, value)


                class Trunk(Entity):
                    """
                    Set trunking characteristics of the interface
                    
                    .. attribute:: allowed
                    
                    	Set allowed VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Allowed>`
                    
                    .. attribute:: encapsulation
                    
                    	Set encapsulation format on trunk port
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Encapsulation>`
                    
                    .. attribute:: native
                    
                    	Set trunking native characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Native_>`
                    
                    .. attribute:: pruning
                    
                    	Set pruning VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Pruning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Pruning>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switchport.Trunk, self).__init__()

                        self.yang_name = "trunk"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Native_)), ("pruning", ("pruning", Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Pruning))])
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Switchport.Trunk.Encapsulation')])),
                        ])
                        self.encapsulation = None

                        self.allowed = Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Allowed()
                        self.allowed.parent = self
                        self._children_name_map["allowed"] = "allowed"

                        self.native = Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Native_()
                        self.native.parent = self
                        self._children_name_map["native"] = "native"

                        self.pruning = Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Pruning()
                        self.pruning.parent = self
                        self._children_name_map["pruning"] = "pruning"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:trunk"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Trunk, [u'encapsulation'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Set encapsulation format on trunk port

                        .. data:: dot1q = 0

                        .. data:: isl = 1

                        .. data:: negotiate = 2

                        """

                        dot1q = Enum.YLeaf(0, "dot1q")

                        isl = Enum.YLeaf(1, "isl")

                        negotiate = Enum.YLeaf(2, "negotiate")



                    class Allowed(Entity):
                        """
                        Set allowed VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set allowed VLANs when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Allowed.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Allowed, self).__init__()

                            self.yang_name = "allowed"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Allowed.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Allowed.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "allowed"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Allowed, [], name, value)


                        class Vlan(Entity):
                            """
                            Set allowed VLANs when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: all
                            
                            	all VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "allowed"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = None
                                self.add = None
                                self.all = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                    class Native_(Entity):
                        """
                        Set trunking native characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set native VLAN when interface is in trunking mode
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Native_, self).__init__()

                            self.yang_name = "native"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan'),'int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "native"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Native_, [u'vlan'], name, value)

                        class Vlan(Enum):
                            """
                            Vlan (Enum Class)

                            Set native VLAN when interface is in trunking mode

                            .. data:: tag = 0

                            """

                            tag = Enum.YLeaf(0, "tag")



                    class Pruning(Entity):
                        """
                        Set pruning VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set VLANs enabled for pruning when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Pruning.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Pruning, self).__init__()

                            self.yang_name = "pruning"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Pruning.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Pruning.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "pruning"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Pruning, [], name, value)


                        class Vlan(Entity):
                            """
                            Set VLANs enabled for pruning when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Pruning.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "pruning"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeafList(YType.str, 'vlans'), ['int','str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = []
                                self.add = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Trunk.Pruning.Vlan, [u'vlans', u'add', u'except_', u'none', u'remove'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Voice.Vlan>`
                    
                    .. attribute:: detect
                    
                    	detection enhancement keyword
                    	**type**\:  :py:class:`Detect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Voice.Detect>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FiveGigabitEthernet.Switchport.Voice.Vlan)), ("detect", ("detect", Native.Interface.FiveGigabitEthernet.Switchport.Voice.Detect))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.FiveGigabitEthernet.Switchport.Voice.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"

                        self.detect = Native.Interface.FiveGigabitEthernet.Switchport.Voice.Detect()
                        self.detect.parent = self
                        self._children_name_map["detect"] = "detect"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:voice"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Voice, [], name, value)


                    class Vlan(Entity):
                        """
                        Vlan for voice traffic
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\: str
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.Voice.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_'),'int','str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Voice.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dot1p = 0

                            .. data:: none = 1

                            .. data:: untagged = 2

                            """

                            dot1p = Enum.YLeaf(0, "dot1p")

                            none = Enum.YLeaf(1, "none")

                            untagged = Enum.YLeaf(2, "untagged")



                    class Detect(Entity):
                        """
                        detection enhancement keyword
                        
                        .. attribute:: cisco_phone
                        
                        	Cisco IP phone
                        	**type**\:  :py:class:`CiscoPhone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Voice.Detect.CiscoPhone>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.Voice.Detect, self).__init__()

                            self.yang_name = "detect"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cisco-phone", ("cisco_phone", Native.Interface.FiveGigabitEthernet.Switchport.Voice.Detect.CiscoPhone))])
                            self._leafs = OrderedDict()

                            self.cisco_phone = None
                            self._children_name_map["cisco_phone"] = "cisco-phone"
                            self._segment_path = lambda: "detect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Voice.Detect, [], name, value)


                        class CiscoPhone(Entity):
                            """
                            Cisco IP phone
                            
                            .. attribute:: full_duplex
                            
                            	full duplex keyword
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Switchport.Voice.Detect.CiscoPhone, self).__init__()

                                self.yang_name = "cisco-phone"
                                self.yang_parent_name = "detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('full_duplex', (YLeaf(YType.empty, 'full-duplex'), ['Empty'])),
                                ])
                                self.full_duplex = None
                                self._segment_path = lambda: "cisco-phone"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Voice.Detect.CiscoPhone, [u'full_duplex'], name, value)


                class Priority(Entity):
                    """
                    Set appliance 802.1p priority
                    
                    .. attribute:: extend
                    
                    	Set appliance 802.1p priority
                    	**type**\:  :py:class:`Extend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.Priority.Extend>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switchport.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("extend", ("extend", Native.Interface.FiveGigabitEthernet.Switchport.Priority.Extend))])
                        self._leafs = OrderedDict()

                        self.extend = Native.Interface.FiveGigabitEthernet.Switchport.Priority.Extend()
                        self.extend.parent = self
                        self._children_name_map["extend"] = "extend"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Priority, [], name, value)


                    class Extend(Entity):
                        """
                        Set appliance 802.1p priority
                        
                        .. attribute:: trust
                        
                        	Trust 802.1p priorities of devices on appliance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cos
                        
                        	Override 802.1p priority of devices on appliance
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.Priority.Extend, self).__init__()

                            self.yang_name = "extend"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                            ])
                            self.trust = None
                            self.cos = None
                            self._segment_path = lambda: "extend"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Priority.Extend, [u'trust', u'cos'], name, value)


                class Autostate(Entity):
                    """
                    Include or exclude this port from vlan link up calculation
                    
                    .. attribute:: exclude
                    
                    	Exclude this port from vlan link up calculation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switchport.Autostate, self).__init__()

                        self.yang_name = "autostate"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('exclude', (YLeaf(YType.empty, 'exclude'), ['Empty'])),
                        ])
                        self.exclude = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:autostate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Autostate, [u'exclude'], name, value)


                class PrivateVlan(Entity):
                    """
                    Set the private VLAN configuration
                    
                    .. attribute:: association
                    
                    	Set the private VLAN association
                    	**type**\:  :py:class:`Association <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association>`
                    
                    .. attribute:: host_association
                    
                    	Set the private VLAN host association
                    	**type**\:  :py:class:`HostAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.HostAssociation>`
                    
                    .. attribute:: mapping
                    
                    	Set the private VLAN promiscuous mapping
                    	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Mapping>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan, self).__init__()

                        self.yang_name = "private-vlan"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("association", ("association", Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association)), ("host-association", ("host_association", Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.HostAssociation)), ("mapping", ("mapping", Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Mapping))])
                        self._leafs = OrderedDict()

                        self.association = Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association()
                        self.association.parent = self
                        self._children_name_map["association"] = "association"

                        self.host_association = Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.HostAssociation()
                        self.host_association.parent = self
                        self._children_name_map["host_association"] = "host-association"

                        self.mapping = Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Mapping()
                        self.mapping.parent = self
                        self._children_name_map["mapping"] = "mapping"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:private-vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan, [], name, value)


                    class Association(Entity):
                        """
                        Set the private VLAN association
                        
                        .. attribute:: host
                        
                        	Set the private VLAN host association
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association.Host>`
                        
                        .. attribute:: mapping
                        
                        	Set the private VLAN promiscuous mapping
                        	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association.Mapping>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association, self).__init__()

                            self.yang_name = "association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association.Host)), ("mapping", ("mapping", Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association.Mapping))])
                            self._leafs = OrderedDict()

                            self.host = Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.mapping = Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association.Mapping()
                            self.mapping.parent = self
                            self._children_name_map["mapping"] = "mapping"
                            self._segment_path = lambda: "association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association, [], name, value)


                        class Host(Entity):
                            """
                            Set the private VLAN host association
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary normal range VLAN ID of the private VLAN host port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association.Host, [u'primary_range', u'secondary_range'], name, value)


                        class Mapping(Entity):
                            """
                            Set the private VLAN promiscuous mapping
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: remove
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association.Mapping, self).__init__()

                                self.yang_name = "mapping"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self.add = None
                                self.remove = None
                                self._segment_path = lambda: "mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Association.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                    class HostAssociation(Entity):
                        """
                        Set the private VLAN host association
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary normal range VLAN ID of the private VLAN host port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.HostAssociation, self).__init__()

                            self.yang_name = "host-association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self._segment_path = lambda: "host-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.HostAssociation, [u'primary_range', u'secondary_range'], name, value)


                    class Mapping(Entity):
                        """
                        Set the private VLAN promiscuous mapping
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: add
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: remove
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Mapping, self).__init__()

                            self.yang_name = "mapping"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self.add = None
                            self.remove = None
                            self._segment_path = lambda: "mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.PrivateVlan.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                class Vepa(Entity):
                    """
                    Reflective relay configuration
                    
                    .. attribute:: enabled
                    
                    	Enable reflective relay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switchport.Vepa, self).__init__()

                        self.yang_name = "vepa"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                        ])
                        self.enabled = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:vepa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.Vepa, [u'enabled'], name, value)


                class DeviceTracking(Entity):
                    """
                    Configure device\-tracking on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature device\-tracking
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switchport.DeviceTracking, self).__init__()

                        self.yang_name = "device-tracking"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:device-tracking"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switchport.DeviceTracking, [u'attach_policy'], name, value)


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FiveGigabitEthernet.Backup.Delay)), ("interface", ("interface", Native.Interface.FiveGigabitEthernet.Backup.Interface_)), ("load", ("load", Native.Interface.FiveGigabitEthernet.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.FiveGigabitEthernet.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.FiveGigabitEthernet.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.FiveGigabitEthernet.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.FiveGigabitEthernet.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.FiveGigabitEthernet.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.FiveGigabitEthernet.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.FiveGigabitEthernet.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.FiveGigabitEthernet.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.FiveGigabitEthernet.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.FiveGigabitEthernet.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.FiveGigabitEthernet.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.FiveGigabitEthernet.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.FiveGigabitEthernet.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.FiveGigabitEthernet.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.FiveGigabitEthernet.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.FiveGigabitEthernet.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.FiveGigabitEthernet.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.FiveGigabitEthernet.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.FiveGigabitEthernet.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.FiveGigabitEthernet.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.FiveGigabitEthernet.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.FiveGigabitEthernet.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.FiveGigabitEthernet.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.FiveGigabitEthernet.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.FiveGigabitEthernet.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.FiveGigabitEthernet.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.FiveGigabitEthernet.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.FiveGigabitEthernet.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.FiveGigabitEthernet.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.FiveGigabitEthernet.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.FiveGigabitEthernet.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.FiveGigabitEthernet.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.FiveGigabitEthernet.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.FiveGigabitEthernet.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.FiveGigabitEthernet.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.FiveGigabitEthernet.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.FiveGigabitEthernet.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.FiveGigabitEthernet.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.FiveGigabitEthernet.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.FiveGigabitEthernet.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.FiveGigabitEthernet.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.FiveGigabitEthernet.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.FiveGigabitEthernet.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.FiveGigabitEthernet.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.FiveGigabitEthernet.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.FiveGigabitEthernet.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.FiveGigabitEthernet.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.FiveGigabitEthernet.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.FiveGigabitEthernet.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.FiveGigabitEthernet.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.FiveGigabitEthernet.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.FiveGigabitEthernet.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.FiveGigabitEthernet.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.FiveGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.FiveGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.FiveGigabitEthernet.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.FiveGigabitEthernet.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.FiveGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.FiveGigabitEthernet.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.FiveGigabitEthernet.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.FiveGigabitEthernet.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.FiveGigabitEthernet.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.FiveGigabitEthernet.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.FiveGigabitEthernet.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.FiveGigabitEthernet.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.FiveGigabitEthernet.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.FiveGigabitEthernet.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.FiveGigabitEthernet.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.FiveGigabitEthernet.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.FiveGigabitEthernet.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.FiveGigabitEthernet.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.FiveGigabitEthernet.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.FiveGigabitEthernet.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.FiveGigabitEthernet.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.FiveGigabitEthernet.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.FiveGigabitEthernet.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.FiveGigabitEthernet.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.FiveGigabitEthernet.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.FiveGigabitEthernet.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.FiveGigabitEthernet.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.FiveGigabitEthernet.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.FiveGigabitEthernet.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.FiveGigabitEthernet.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Igmp>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Flow>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Nbar>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf>`
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Lisp>`
                
                .. attribute:: rsvp
                
                	RSVP Interface Commands
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Nat>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.FiveGigabitEthernet.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.FiveGigabitEthernet.Ip.Arp)), ("vrf", ("vrf", Native.Interface.FiveGigabitEthernet.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.FiveGigabitEthernet.Ip.NoAddress)), ("address", ("address", Native.Interface.FiveGigabitEthernet.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.FiveGigabitEthernet.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.FiveGigabitEthernet.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.FiveGigabitEthernet.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.FiveGigabitEthernet.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.FiveGigabitEthernet.Ip.Pim)), ("policy", ("policy", Native.Interface.FiveGigabitEthernet.Ip.Policy)), ("rip", ("rip", Native.Interface.FiveGigabitEthernet.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.FiveGigabitEthernet.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.FiveGigabitEthernet.Ip.RouteCache)), ("router", ("router", Native.Interface.FiveGigabitEthernet.Ip.Router)), ("tcp", ("tcp", Native.Interface.FiveGigabitEthernet.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.FiveGigabitEthernet.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.FiveGigabitEthernet.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.FiveGigabitEthernet.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.FiveGigabitEthernet.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.FiveGigabitEthernet.Ip.Igmp)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.FiveGigabitEthernet.Ip.Flow)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.FiveGigabitEthernet.Ip.Nbar)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.FiveGigabitEthernet.Ip.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.FiveGigabitEthernet.Ip.Lisp)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Interface.FiveGigabitEthernet.Ip.Rsvp)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.FiveGigabitEthernet.Ip.Nat)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.FiveGigabitEthernet.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None
                    self.unreachables = None

                    self.access_group = Native.Interface.FiveGigabitEthernet.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.FiveGigabitEthernet.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.FiveGigabitEthernet.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.FiveGigabitEthernet.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.FiveGigabitEthernet.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.FiveGigabitEthernet.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.FiveGigabitEthernet.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.FiveGigabitEthernet.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.FiveGigabitEthernet.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.FiveGigabitEthernet.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.FiveGigabitEthernet.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.FiveGigabitEthernet.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.FiveGigabitEthernet.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.FiveGigabitEthernet.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.FiveGigabitEthernet.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.FiveGigabitEthernet.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.FiveGigabitEthernet.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.FiveGigabitEthernet.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.FiveGigabitEthernet.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.flow = Native.Interface.FiveGigabitEthernet.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.nbar = Native.Interface.FiveGigabitEthernet.Ip.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.ospf = Native.Interface.FiveGigabitEthernet.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.lisp = Native.Interface.FiveGigabitEthernet.Ip.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                    self.rsvp = Native.Interface.FiveGigabitEthernet.Ip.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

                    self.nat = Native.Interface.FiveGigabitEthernet.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.wccp = Native.Interface.FiveGigabitEthernet.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache', 'unreachables'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.FiveGigabitEthernet.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.FiveGigabitEthernet.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.FiveGigabitEthernet.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.FiveGigabitEthernet.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.FiveGigabitEthernet.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.FiveGigabitEthernet.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.FiveGigabitEthernet.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.FiveGigabitEthernet.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.FiveGigabitEthernet.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.FiveGigabitEthernet.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.FiveGigabitEthernet.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.FiveGigabitEthernet.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.FiveGigabitEthernet.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.FiveGigabitEthernet.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.FiveGigabitEthernet.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.FiveGigabitEthernet.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.FiveGigabitEthernet.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.FiveGigabitEthernet.Ip.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ip.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ip.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.FiveGigabitEthernet.Ip.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.FiveGigabitEthernet.Ip.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.FiveGigabitEthernet.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.FiveGigabitEthernet.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.FiveGigabitEthernet.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.FiveGigabitEthernet.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.FiveGigabitEthernet.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.FiveGigabitEthernet.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FiveGigabitEthernet.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.FiveGigabitEthernet.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.FiveGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.FiveGigabitEthernet.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FiveGigabitEthernet.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.FiveGigabitEthernet.Ip.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ip.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.FiveGigabitEthernet.Ip.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.FiveGigabitEthernet.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.FiveGigabitEthernet.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.FiveGigabitEthernet.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.FiveGigabitEthernet.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.FiveGigabitEthernet.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.FiveGigabitEthernet.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.FiveGigabitEthernet.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.FiveGigabitEthernet.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.FiveGigabitEthernet.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FiveGigabitEthernet.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.FiveGigabitEthernet.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.FiveGigabitEthernet.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.FiveGigabitEthernet.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.FiveGigabitEthernet.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.FiveGigabitEthernet.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.FiveGigabitEthernet.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.FiveGigabitEthernet.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.FiveGigabitEthernet.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.FiveGigabitEthernet.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FiveGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.FiveGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Lisp(Entity):
                    """
                    Locator/ID Separation Protocol
                    
                    .. attribute:: source_locator
                    
                    	Choose IP source address for LISP packets egressing this interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_locator', (YLeaf(YType.str, 'source-locator'), ['str'])),
                        ])
                        self.source_locator = None
                        self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Lisp, ['source_locator'], name, value)


                class Rsvp(Entity):
                    """
                    RSVP Interface Commands
                    
                    .. attribute:: authentication
                    
                    	Enables RSVP neighbor authentication (RFC 2747)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bandwidth
                    
                    	RSVP Reservable Bandwidth (kbps)
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	Select permissible RSVP neighbors
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Neighbor>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: precedence
                    
                    	RSVP precedence setting
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Precedence>`
                    
                    .. attribute:: signalling
                    
                    	RSVP signalling
                    	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling>`
                    
                    .. attribute:: tos
                    
                    	RSVP TOS setting
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Tos>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Authentication)), ("bandwidth", ("bandwidth", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth)), ("neighbor", ("neighbor", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Neighbor)), ("precedence", ("precedence", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Precedence)), ("signalling", ("signalling", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling)), ("tos", ("tos", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Tos))])
                        self._leafs = OrderedDict()

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.bandwidth = None
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.neighbor = None
                        self._children_name_map["neighbor"] = "neighbor"

                        self.precedence = Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Precedence()
                        self.precedence.parent = self
                        self._children_name_map["precedence"] = "precedence"

                        self.signalling = Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling()
                        self.signalling.parent = self
                        self._children_name_map["signalling"] = "signalling"

                        self.tos = Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Tos()
                        self.tos.parent = self
                        self._children_name_map["tos"] = "tos"
                        self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp, [], name, value)


                    class Authentication(Entity):
                        """
                        Enables RSVP neighbor authentication (RFC 2747)
                        
                        .. attribute:: key
                        
                        	Password (8 to 40 characters, spaces allowed)
                        	**type**\: str
                        
                        .. attribute:: challenge
                        
                        	Perform challenge/response handshake with new neighbor(s)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key_chain
                        
                        	Name of key chain to use (as created by global 'key chain' command)
                        	**type**\: str
                        
                        .. attribute:: lifetime
                        
                        	Maximum lifetime of neighbor authentication state
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Authentication.Lifetime>`
                        
                        .. attribute:: type
                        
                        	Type of authentication algorithm (default = md5)
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Authentication.Type>`
                        
                        .. attribute:: window_size
                        
                        	Maximum number of messages allowed in receive window (default = 1)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Authentication.Lifetime))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ip.Rsvp.Authentication.Type')])),
                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                            ])
                            self.key = None
                            self.challenge = None
                            self.key_chain = None
                            self.type = None
                            self.window_size = None

                            self.lifetime = Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Authentication.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Authentication, ['key', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Type of authentication algorithm (default = md5)

                            .. data:: md5 = 0

                            .. data:: sha_1 = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            sha_1 = Enum.YLeaf(1, "sha-1")



                        class Lifetime(Entity):
                            """
                            Maximum lifetime of neighbor authentication state
                            
                            .. attribute:: hh_mm_ss
                            
                            	Lifetime (default = 30 mins) in hh\:mm\:ss format
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ])
                                self.hh_mm_ss = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


                    class Bandwidth(Entity):
                        """
                        RSVP Reservable Bandwidth (kbps)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Value>`
                        
                        .. attribute:: percent
                        
                        	Percentage of interface bandwidth. Values higher than 100 represent overbooking
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: mam
                        
                        	Use bandwidth with MAM model of DSTE
                        	**type**\:  :py:class:`Mam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Mam>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Value)), ("mam", ("mam", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Mam))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                            ])
                            self.percent = None

                            self.value = Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.mam = Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Mam()
                            self.mam.parent = self
                            self._children_name_map["mam"] = "mam"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth, ['percent'], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	Reservable Bandwidth (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            .. attribute:: sub_pool
                            
                            	Reservable Bandwidth for Tunnel using sub (BC1) pool (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.value = None
                                self.sub_pool = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Value, ['value', 'sub_pool'], name, value)


                        class Mam(Entity):
                            """
                            Use bandwidth with MAM model of DSTE
                            
                            .. attribute:: max_reservable_bw
                            
                            	Maximum Reservable bandwidth for MAM
                            	**type**\:  :py:class:`MaxReservableBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Mam, self).__init__()

                                self.yang_name = "mam"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("max-reservable-bw", ("max_reservable_bw", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw))])
                                self._leafs = OrderedDict()

                                self.max_reservable_bw = None
                                self._children_name_map["max_reservable_bw"] = "max-reservable-bw"
                                self._segment_path = lambda: "mam"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Mam, [], name, value)


                            class MaxReservableBw(Entity):
                                """
                                Maximum Reservable bandwidth for MAM
                                
                                .. attribute:: value
                                
                                	Reservable Bandwidth (kbps)
                                	**type**\: int
                                
                                	**range:** 1..10000000
                                
                                .. attribute:: bc0
                                
                                	Reservable Bandwidth from global (BC0) pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                .. attribute:: bc1
                                
                                	Reservable Bandwidth from sub pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, self).__init__()

                                    self.yang_name = "max-reservable-bw"
                                    self.yang_parent_name = "mam"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                        ('bc0', (YLeaf(YType.uint32, 'bc0'), ['int'])),
                                        ('bc1', (YLeaf(YType.uint32, 'bc1'), ['int'])),
                                    ])
                                    self.value = None
                                    self.bc0 = None
                                    self.bc1 = None
                                    self._segment_path = lambda: "max-reservable-bw"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, ['value', 'bc0', 'bc1'], name, value)


                    class Neighbor(Entity):
                        """
                        Select permissible RSVP neighbors
                        
                        .. attribute:: acl_number
                        
                        	Access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                            ])
                            self.acl_number = None
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Neighbor, ['acl_number'], name, value)


                    class Precedence(Entity):
                        """
                        RSVP precedence setting
                        
                        .. attribute:: conform
                        
                        	Precedence for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: exceed
                        
                        	Precedence for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Precedence, ['conform', 'exceed'], name, value)


                    class Signalling(Entity):
                        """
                        RSVP signalling
                        
                        .. attribute:: dscp
                        
                        	DSCP for RSVP signalling messages
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: fast_local_repair
                        
                        	Fast Local Repair parameters
                        	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair>`
                        
                        .. attribute:: hello
                        
                        	Enable neighbor\-down detection
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling, self).__init__()

                            self.yang_name = "signalling"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.fast_local_repair = Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair()
                            self.fast_local_repair.parent = self
                            self._children_name_map["fast_local_repair"] = "fast-local-repair"

                            self.hello = None
                            self._children_name_map["hello"] = "hello"
                            self._segment_path = lambda: "signalling"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling, ['dscp'], name, value)


                        class FastLocalRepair(Entity):
                            """
                            Fast Local Repair parameters
                            
                            .. attribute:: wait_time
                            
                            	Wait Time for start of Fast Local Repair in msec
                            	**type**\: int
                            
                            	**range:** 0..5000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                                self.yang_name = "fast-local-repair"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint16, 'wait-time'), ['int'])),
                                ])
                                self.wait_time = None
                                self._segment_path = lambda: "fast-local-repair"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair, ['wait_time'], name, value)


                        class Hello(Entity):
                            """
                            Enable neighbor\-down detection
                            
                            .. attribute:: bfd
                            
                            	Configure BFD trigger for MPLS/TE FRR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	DSCP for RSVP Hello messages
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: graceful_restart
                            
                            	Configure RSVP Graceful Restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: refresh
                            
                            	Configure RSVP Hello refresh behavior for Fast\-Reroute
                            	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh>`
                            
                            .. attribute:: reroute
                            
                            	Configure RSVP Hello refresh behavior for Reroute
                            	**type**\:  :py:class:`Reroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh)), ("reroute", ("reroute", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ('graceful_restart', (YLeaf(YType.empty, 'graceful-restart'), ['Empty'])),
                                ])
                                self.bfd = None
                                self.dscp = None
                                self.graceful_restart = None

                                self.refresh = Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh()
                                self.refresh.parent = self
                                self._children_name_map["refresh"] = "refresh"

                                self.reroute = Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute()
                                self.reroute.parent = self
                                self._children_name_map["reroute"] = "reroute"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello, ['bfd', 'dscp', 'graceful_restart'], name, value)


                            class Refresh(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Fast\-Reroute
                                
                                .. attribute:: interval
                                
                                	Hello interval in msec
                                	**type**\: int
                                
                                	**range:** 10..30000
                                
                                .. attribute:: misses
                                
                                	Number of missed Hello Acks which triggers neighbor down
                                	**type**\: int
                                
                                	**range:** 4..10
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh, self).__init__()

                                    self.yang_name = "refresh"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.misses = None
                                    self._segment_path = lambda: "refresh"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh, ['interval', 'misses'], name, value)


                            class Reroute(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Reroute
                                
                                .. attribute:: dscp
                                
                                	DSCP for RSVP Hello messages
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: refresh
                                
                                	Configure RSVP Reroute Hello refresh behavior
                                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh>`
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute, self).__init__()

                                    self.yang_name = "reroute"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh))])
                                    self._leafs = OrderedDict([
                                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ])
                                    self.dscp = None

                                    self.refresh = Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh()
                                    self.refresh.parent = self
                                    self._children_name_map["refresh"] = "refresh"
                                    self._segment_path = lambda: "reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute, ['dscp'], name, value)


                                class Refresh(Entity):
                                    """
                                    Configure RSVP Reroute Hello refresh behavior
                                    
                                    .. attribute:: interval
                                    
                                    	Hello Reroute interval in msec
                                    	**type**\: int
                                    
                                    	**range:** 1000..30000
                                    
                                    .. attribute:: misses
                                    
                                    	Number of missed Hello Acks which triggers neighbor down
                                    	**type**\: int
                                    
                                    	**range:** 4..10
                                    
                                    

                                    """

                                    _prefix = 'ios-rsvp'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, self).__init__()

                                        self.yang_name = "refresh"
                                        self.yang_parent_name = "reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.misses = None
                                        self._segment_path = lambda: "refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, ['interval', 'misses'], name, value)


                    class Tos(Entity):
                        """
                        RSVP TOS setting
                        
                        .. attribute:: conform
                        
                        	TOS for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: exceed
                        
                        	TOS for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Rsvp.Tos, ['conform', 'exceed'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.FiveGigabitEthernet.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.FiveGigabitEthernet.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.FiveGigabitEthernet.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.FiveGigabitEthernet.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.FiveGigabitEthernet.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FiveGigabitEthernet.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.FiveGigabitEthernet.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FiveGigabitEthernet.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.FiveGigabitEthernet.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.FiveGigabitEthernet.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.FiveGigabitEthernet.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.TrafficFilter>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Flow>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Crypto>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Pim>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: rip
                
                	Configure RIP routing protocol
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Rip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.FiveGigabitEthernet.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.FiveGigabitEthernet.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp)), ("address", ("address", Native.Interface.FiveGigabitEthernet.Ipv6.Address)), ("nd", ("nd", Native.Interface.FiveGigabitEthernet.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.FiveGigabitEthernet.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.FiveGigabitEthernet.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.FiveGigabitEthernet.Ipv6.Flow)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.FiveGigabitEthernet.Ipv6.Crypto)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.FiveGigabitEthernet.Ipv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.FiveGigabitEthernet.Ipv6.Pim)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Interface.FiveGigabitEthernet.Ipv6.Rip))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None
                    self.unreachables = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.FiveGigabitEthernet.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.FiveGigabitEthernet.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.FiveGigabitEthernet.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.flow = Native.Interface.FiveGigabitEthernet.Ipv6.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.crypto = Native.Interface.FiveGigabitEthernet.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.ospf = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.no_pim = Native.Interface.FiveGigabitEthernet.Ipv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.FiveGigabitEthernet.Ipv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects', 'unreachables'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.FiveGigabitEthernet.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.FiveGigabitEthernet.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.FiveGigabitEthernet.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.FiveGigabitEthernet.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FiveGigabitEthernet.Ipv6.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.FiveGigabitEthernet.Ipv6.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ipv6.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ipv6.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Crypto, ['map'], name, value)


                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process
                    
                    	
                    	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Process>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: encryption
                    
                    	Enable encryption
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Network>`
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process", ("process", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Process)), ("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication)), ("bfd", ("bfd", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.DemandCircuit)), ("encryption", ("encryption", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption)), ("flood-reduction", ("flood_reduction", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.FloodReduction)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.MtuIgnore)), ("neighbor", ("neighbor", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Neighbor)), ("network", ("network", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Network)), ("shutdown", ("shutdown", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Shutdown))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.cost = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.encryption = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.network = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.process = YList(self)
                        self.neighbor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf, ['cost', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Process(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: instance
                        
                        	Set the OSPF instance
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..31
                        
                        		**type**\: int
                        
                        			**range:** 32..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Process, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['int','int'])),
                            ])
                            self.id = None
                            self.area = None
                            self.instance = None
                            self._segment_path = lambda: "process" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Process, ['id', 'area', 'instance'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec authentication
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec authentication
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 256..4294967295
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5>`
                            
                            .. attribute:: sha1
                            
                            	Use SHA\-1 authentication
                            	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ])
                                self.spi = None

                                self.md5 = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.sha1 = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1()
                                self.sha1.parent = self
                                self._children_name_map["sha1"] = "sha1"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec, ['spi'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Sha1(Entity):
                                """
                                Use SHA\-1 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, self).__init__()

                                    self.yang_name = "sha1"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "sha1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "sha1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ipv6.Ospf.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.DatabaseFilter, ['all', 'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.DemandCircuit, ['disable', 'ignore'], name, value)


                    class Encryption(Entity):
                        """
                        Enable encryption
                        
                        .. attribute:: null
                        
                        	No IPsec encryption on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec encryption
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec encryption
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: esp
                            
                            	Use ESP encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipsec_3des
                            
                            	Use 3DES encryption
                            	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des>`
                            
                            .. attribute:: aes_cbc
                            
                            	Use AES\-CBC encryption
                            	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                                ])
                                self.spi = None
                                self.esp = None

                                self.ipsec_3des = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des()
                                self.ipsec_3des.parent = self
                                self._children_name_map["ipsec_3des"] = "ipsec_3des"

                                self.aes_cbc = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc()
                                self.aes_cbc.parent = self
                                self._children_name_map["aes_cbc"] = "aes-cbc"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec, ['spi', 'esp'], name, value)


                            class Ipsec3des(Entity):
                                """
                                Use 3DES encryption
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, self).__init__()

                                    self.yang_name = "ipsec_3des"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "ipsec_3des"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "ipsec_3des"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class AesCbc(Entity):
                                """
                                Use AES\-CBC encryption
                                
                                .. attribute:: aes_cbc_128
                                
                                	Use 128 bit key
                                	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128>`
                                
                                .. attribute:: aes_192
                                
                                	Use 192 bit key
                                	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192>`
                                
                                .. attribute:: aes_256
                                
                                	Use 256 bit key
                                	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, self).__init__()

                                    self.yang_name = "aes-cbc"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256))])
                                    self._leafs = OrderedDict()

                                    self.aes_cbc_128 = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128()
                                    self.aes_cbc_128.parent = self
                                    self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                    self.aes_192 = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192()
                                    self.aes_192.parent = self
                                    self._children_name_map["aes_192"] = "aes-192"

                                    self.aes_256 = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256()
                                    self.aes_256.parent = self
                                    self._children_name_map["aes_256"] = "aes-256"
                                    self._segment_path = lambda: "aes-cbc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, [], name, value)


                                class AesCbc128(Entity):
                                    """
                                    Use 128 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                        self.yang_name = "aes-cbc-128"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-cbc-128"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-cbc-128"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes192(Entity):
                                    """
                                    Use 192 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                        self.yang_name = "aes-192"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-192"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-192"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes256(Entity):
                                    """
                                    Use 256 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                        self.yang_name = "aes-256"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-256"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	Disable Flood Reduction on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.FloodReduction, ['disable'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.MtuIgnore, ['disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Ospf.Shutdown, ['disable'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.FiveGigabitEthernet.Ipv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.FiveGigabitEthernet.Ipv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Pim.Bsr, ['border'], name, value)


                class Rip(Entity):
                    """
                    Configure RIP routing protocol
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable/disable RIP routing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default_information
                    
                    	Configure handling of default route
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Rip.DefaultInformation>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ipv6.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("default-information", ("default_information", Native.Interface.FiveGigabitEthernet.Ipv6.Rip.DefaultInformation))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.id = None
                        self.enable = None

                        self.default_information = Native.Interface.FiveGigabitEthernet.Ipv6.Rip.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Rip, ['id', 'enable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Configure handling of default route
                        
                        .. attribute:: route
                        
                        	
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ipv6.Rip.DefaultInformation.Route>`
                        
                        .. attribute:: metric
                        
                        	Default route metric
                        	**type**\: int
                        
                        	**range:** 1..15
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ipv6.Rip.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route', (YLeaf(YType.enumeration, 'route'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ipv6.Rip.DefaultInformation.Route')])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ])
                            self.route = None
                            self.metric = None
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ipv6.Rip.DefaultInformation, ['route', 'metric'], name, value)

                        class Route(Enum):
                            """
                            Route (Enum Class)

                            .. data:: only = 0

                            .. data:: originate = 1

                            """

                            only = Enum.YLeaf(0, "only")

                            originate = Enum.YLeaf(1, "originate")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FiveGigabitEthernet.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.FiveGigabitEthernet.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.FiveGigabitEthernet.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.FiveGigabitEthernet.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.FiveGigabitEthernet.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.FiveGigabitEthernet.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.FiveGigabitEthernet.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.FiveGigabitEthernet.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.FiveGigabitEthernet.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FiveGigabitEthernet.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.FiveGigabitEthernet.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.FiveGigabitEthernet.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.FiveGigabitEthernet.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.FiveGigabitEthernet.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.FiveGigabitEthernet.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.FiveGigabitEthernet.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.FiveGigabitEthernet.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.FiveGigabitEthernet.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.FiveGigabitEthernet.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.FiveGigabitEthernet.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.FiveGigabitEthernet.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.FiveGigabitEthernet.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.FiveGigabitEthernet.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.FiveGigabitEthernet.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.FiveGigabitEthernet.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.FiveGigabitEthernet.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.FiveGigabitEthernet.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.FiveGigabitEthernet.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.FiveGigabitEthernet.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.FiveGigabitEthernet.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.FiveGigabitEthernet.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.FiveGigabitEthernet.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.FiveGigabitEthernet.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.FiveGigabitEthernet.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.FiveGigabitEthernet.CarrierDelay.Down)), ("up", ("up", Native.Interface.FiveGigabitEthernet.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.FiveGigabitEthernet.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.FiveGigabitEthernet.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.FiveGigabitEthernet.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.FiveGigabitEthernet.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.FiveGigabitEthernet.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.FiveGigabitEthernet.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.FiveGigabitEthernet.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.FiveGigabitEthernet.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.FiveGigabitEthernet.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.FiveGigabitEthernet.Plim.Ethernet)), ("qos", ("qos", Native.Interface.FiveGigabitEthernet.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.FiveGigabitEthernet.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.FiveGigabitEthernet.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FiveGigabitEthernet.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.FiveGigabitEthernet.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.FiveGigabitEthernet.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.FiveGigabitEthernet.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.FiveGigabitEthernet.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.FiveGigabitEthernet.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.FiveGigabitEthernet.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.FiveGigabitEthernet.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.FiveGigabitEthernet.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.FiveGigabitEthernet.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.FiveGigabitEthernet.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.FiveGigabitEthernet.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect)), ("Cisco-IOS-XE-l2vpn:xconnect-pw-class", ("xconnect_pw_class", Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.FiveGigabitEthernet.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.FiveGigabitEthernet.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.FiveGigabitEthernet.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.FiveGigabitEthernet.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"

                        self.xconnect = Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                        self.xconnect_pw_class = Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.FiveGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.FiveGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Lacp(Entity):
                """
                LACP interface subcommands
                
                .. attribute:: port_priority
                
                	LACP priority on this interface 
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rate
                
                	Rate at which the LACP packets are requested to be ingressed to this interface
                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Lacp.Rate>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Lacp, self).__init__()

                    self.yang_name = "lacp"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_priority', (YLeaf(YType.uint32, 'port-priority'), ['int'])),
                        ('rate', (YLeaf(YType.enumeration, 'rate'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Lacp.Rate')])),
                    ])
                    self.port_priority = None
                    self.rate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:lacp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Lacp, ['port_priority', 'rate'], name, value)

                class Rate(Enum):
                    """
                    Rate (Enum Class)

                    Rate at which the LACP packets are requested to be ingressed to this interface

                    .. data:: fast = 0

                    .. data:: normal = 1

                    """

                    fast = Enum.YLeaf(0, "fast")

                    normal = Enum.YLeaf(1, "normal")



            class CiscoIOSXEEthernetMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: dot1q_in_clear
                    
                    	Dot1q in Clear option
                    	**type**\:  :py:class:`Dot1qInClear <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear>`
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('dot1q_in_clear', (YLeaf(YType.enumeration, 'dot1q-in-clear'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear')])),
                        ])
                        self.dot1q_in_clear = None

                        self.replay_protection = Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, ['dot1q_in_clear'], name, value)

                    class Dot1qInClear(Enum):
                        """
                        Dot1qInClear (Enum Class)

                        Dot1q in Clear option

                        .. data:: Y_1 = 0

                        """

                        Y_1 = Enum.YLeaf(0, "1")



                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, ['window_size'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.FiveGigabitEthernet.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.FiveGigabitEthernet.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Auto(Entity):
                """
                Configure Automation
                
                .. attribute:: qos
                
                	Configure AutoQoS
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Auto.Qos>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Auto, self).__init__()

                    self.yang_name = "auto"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("qos", ("qos", Native.Interface.FiveGigabitEthernet.Auto.Qos))])
                    self._leafs = OrderedDict()

                    self.qos = Native.Interface.FiveGigabitEthernet.Auto.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:auto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Auto, [], name, value)


                class Qos(Entity):
                    """
                    Configure AutoQoS
                    
                    .. attribute:: classify
                    
                    	Configure classification for untrusted devices
                    	**type**\:  :py:class:`Classify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Auto.Qos.Classify>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trust
                    
                    	Trust the DSCP/CoS marking
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Auto.Qos.Trust>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: video
                    
                    	Configure AutoQoS for video devices
                    	**type**\:  :py:class:`Video <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Auto.Qos.Video>`
                    
                    .. attribute:: voip
                    
                    	Configure AutoQoS for VoIP
                    	**type**\:  :py:class:`Voip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Auto.Qos.Voip>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Auto.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "auto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("classify", ("classify", Native.Interface.FiveGigabitEthernet.Auto.Qos.Classify)), ("trust", ("trust", Native.Interface.FiveGigabitEthernet.Auto.Qos.Trust)), ("video", ("video", Native.Interface.FiveGigabitEthernet.Auto.Qos.Video)), ("voip", ("voip", Native.Interface.FiveGigabitEthernet.Auto.Qos.Voip))])
                        self._leafs = OrderedDict()

                        self.classify = None
                        self._children_name_map["classify"] = "classify"

                        self.trust = None
                        self._children_name_map["trust"] = "trust"

                        self.video = Native.Interface.FiveGigabitEthernet.Auto.Qos.Video()
                        self.video.parent = self
                        self._children_name_map["video"] = "video"

                        self.voip = None
                        self._children_name_map["voip"] = "voip"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Auto.Qos, [], name, value)


                    class Classify(Entity):
                        """
                        Configure classification for untrusted devices
                        
                        .. attribute:: police
                        
                        	Configure QoS policing for untrusted devices
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Auto.Qos.Classify, self).__init__()

                            self.yang_name = "classify"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('police', (YLeaf(YType.empty, 'police'), ['Empty'])),
                            ])
                            self.police = None
                            self._segment_path = lambda: "classify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Auto.Qos.Classify, [u'police'], name, value)


                    class Trust(Entity):
                        """
                        Trust the DSCP/CoS marking
                        
                        .. attribute:: cos
                        
                        	Trust the CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	Trust the DSCP marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Auto.Qos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cos', (YLeaf(YType.empty, 'cos'), ['Empty'])),
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ])
                            self.cos = None
                            self.dscp = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Auto.Qos.Trust, [u'cos', u'dscp'], name, value)


                    class Video(Entity):
                        """
                        Configure AutoQoS for video devices
                        
                        .. attribute:: cts
                        
                        	Trust the QoS marking of the Cisco Telepresence System
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ip_camera
                        
                        	Trust the QoS marking of the Ip Video Surveillance camera
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: media_player
                        
                        	Trust the Qos marking of the Cisco Media Player
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Auto.Qos.Video, self).__init__()

                            self.yang_name = "video"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('cts', (YLeaf(YType.empty, 'cts'), ['Empty'])),
                                ('ip_camera', (YLeaf(YType.empty, 'ip-camera'), ['Empty'])),
                                ('media_player', (YLeaf(YType.empty, 'media-player'), ['Empty'])),
                            ])
                            self.cts = None
                            self.ip_camera = None
                            self.media_player = None
                            self._segment_path = lambda: "video"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Auto.Qos.Video, [u'cts', u'ip_camera', u'media_player'], name, value)


                    class Voip(Entity):
                        """
                        Configure AutoQoS for VoIP
                        
                        .. attribute:: cisco_phone
                        
                        	Trust the QoS marking of Cisco IP Phone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cisco_softphone
                        
                        	Trust the QoS marking of Cisco IP SoftPhone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trust
                        
                        	Trust the DSCP/CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Auto.Qos.Voip, self).__init__()

                            self.yang_name = "voip"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cisco_phone', (YLeaf(YType.empty, 'cisco-phone'), ['Empty'])),
                                ('cisco_softphone', (YLeaf(YType.empty, 'cisco-softphone'), ['Empty'])),
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.cisco_phone = None
                            self.cisco_softphone = None
                            self.trust = None
                            self._segment_path = lambda: "voip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Auto.Qos.Voip, [u'cisco_phone', u'cisco_softphone', u'trust'], name, value)


            class Datalink(Entity):
                """
                Interface Datalink commands
                
                .. attribute:: flow
                
                	Interface Flow configuration subcommands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Datalink.Flow>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Datalink, self).__init__()

                    self.yang_name = "datalink"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flow", ("flow", Native.Interface.FiveGigabitEthernet.Datalink.Flow))])
                    self._leafs = OrderedDict()

                    self.flow = Native.Interface.FiveGigabitEthernet.Datalink.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:datalink"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Datalink, [], name, value)


                class Flow(Entity):
                    """
                    Interface Flow configuration subcommands
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Datalink.Flow.Monitor>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Datalink.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "datalink"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FiveGigabitEthernet.Datalink.Flow.Monitor))])
                        self._leafs = OrderedDict()

                        self.monitor = None
                        self._children_name_map["monitor"] = "monitor"
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Datalink.Flow, [], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: user_defined_flow
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: input_output
                        
                        	Apply Flow Monitor on input/output traffic
                        	**type**\:  :py:class:`InputOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Datalink.Flow.Monitor.InputOutput>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Datalink.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('user_defined_flow', (YLeaf(YType.str, 'User-defined-flow'), ['str'])),
                                ('input_output', (YLeaf(YType.enumeration, 'input-output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Datalink.Flow.Monitor.InputOutput')])),
                            ])
                            self.user_defined_flow = None
                            self.input_output = None
                            self._segment_path = lambda: "monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Datalink.Flow.Monitor, [u'user_defined_flow', u'input_output'], name, value)

                        class InputOutput(Enum):
                            """
                            InputOutput (Enum Class)

                            Apply Flow Monitor on input/output traffic

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



            class Energywise(Entity):
                """
                EnergyWise interface configurations
                
                .. attribute:: activitycheck
                
                	Apply an activity check before turning off power    to this PoE port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: level
                
                	Set the EnergyWise level of this interface  or attached entity
                	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Energywise.Level>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Energywise, self).__init__()

                    self.yang_name = "energywise"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Interface.FiveGigabitEthernet.Energywise.Level))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('activitycheck', (YLeaf(YType.empty, 'activitycheck'), ['Empty'])),
                    ])
                    self.activitycheck = None

                    self.level = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:energywise"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Energywise, [u'activitycheck'], name, value)


                class Level(Entity):
                    """
                    Set the EnergyWise level of this interface 
                    or attached entity
                    
                    .. attribute:: range  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..10
                    
                    .. attribute:: recurrence
                    
                    	Specify that this level setting should  recur at the specified time
                    	**type**\:  :py:class:`Recurrence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Energywise.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "energywise"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("recurrence", ("recurrence", Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                        ])
                        self.range = None

                        self.recurrence = Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence()
                        self.recurrence.parent = self
                        self._children_name_map["recurrence"] = "recurrence"
                        self._segment_path = lambda: "level" + "[range='" + str(self.range) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Energywise.Level, [u'range'], name, value)


                    class Recurrence(Entity):
                        """
                        Specify that this level setting should 
                        recur at the specified time
                        
                        .. attribute:: importance
                        
                        	Specify the importance at which the event  should be sent when it recurs
                        	**type**\: list of  		 :py:class:`Importance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence.Importance>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence, self).__init__()

                            self.yang_name = "recurrence"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("importance", ("importance", Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence.Importance))])
                            self._leafs = OrderedDict()

                            self.importance = YList(self)
                            self._segment_path = lambda: "recurrence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence, [], name, value)


                        class Importance(Entity):
                            """
                            Specify the importance at which the event 
                            should be sent when it recurs
                            
                            .. attribute:: range  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: at
                            
                            	Specify the time(s) this level setting should occur
                            	**type**\:  :py:class:`At <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence.Importance.At>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence.Importance, self).__init__()

                                self.yang_name = "importance"
                                self.yang_parent_name = "recurrence"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("at", ("at", Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence.Importance.At))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.at = Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence.Importance.At()
                                self.at.parent = self
                                self._children_name_map["at"] = "at"
                                self._segment_path = lambda: "importance" + "[range='" + str(self.range) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence.Importance, [u'range'], name, value)


                            class At(Entity):
                                """
                                Specify the time(s) this level setting should occur
                                
                                .. attribute:: minute
                                
                                	cron format of minute(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..59
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: hour
                                
                                	cron format of hour(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..23
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: day
                                
                                	cron format of day(s) of month
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..31
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: month
                                
                                	cron format of month(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..12
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: weekday
                                
                                	cron format of weekday(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..7
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence.Importance.At, self).__init__()

                                    self.yang_name = "at"
                                    self.yang_parent_name = "importance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minute', (YLeaf(YType.str, 'minute'), ['int','str'])),
                                        ('hour', (YLeaf(YType.str, 'hour'), ['int','str'])),
                                        ('day', (YLeaf(YType.str, 'day'), ['int','str'])),
                                        ('month', (YLeaf(YType.str, 'month'), ['int','str'])),
                                        ('weekday', (YLeaf(YType.str, 'weekday'), ['int','str'])),
                                    ])
                                    self.minute = None
                                    self.hour = None
                                    self.day = None
                                    self.month = None
                                    self.weekday = None
                                    self._segment_path = lambda: "at"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Energywise.Level.Recurrence.Importance.At, [u'minute', u'hour', u'day', u'month', u'weekday'], name, value)


            class Location(Entity):
                """
                Interface location information
                
                .. attribute:: civic_location_id
                
                	Civic location information
                	**type**\:  :py:class:`CivicLocationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Location.CivicLocationId>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Location, self).__init__()

                    self.yang_name = "location"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("civic-location-id", ("civic_location_id", Native.Interface.FiveGigabitEthernet.Location.CivicLocationId))])
                    self._leafs = OrderedDict()

                    self.civic_location_id = Native.Interface.FiveGigabitEthernet.Location.CivicLocationId()
                    self.civic_location_id.parent = self
                    self._children_name_map["civic_location_id"] = "civic-location-id"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:location"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Location, [], name, value)


                class CivicLocationId(Entity):
                    """
                    Civic location information
                    
                    .. attribute:: location_identifier
                    
                    	civic location identifier string
                    	**type**\: str
                    
                    .. attribute:: host
                    
                    	Globally defined host location identifer
                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Location.CivicLocationId.Host>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: none
                    
                    	No globally defined location identifer
                    	**type**\:  :py:class:`Y_None <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Location.CivicLocationId.Y_None>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Location.CivicLocationId, self).__init__()

                        self.yang_name = "civic-location-id"
                        self.yang_parent_name = "location"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("host", ("host", Native.Interface.FiveGigabitEthernet.Location.CivicLocationId.Host)), ("none", ("none", Native.Interface.FiveGigabitEthernet.Location.CivicLocationId.Y_None))])
                        self._leafs = OrderedDict([
                            ('location_identifier', (YLeaf(YType.str, 'location-identifier'), ['str'])),
                        ])
                        self.location_identifier = None

                        self.host = None
                        self._children_name_map["host"] = "host"

                        self.none = None
                        self._children_name_map["none"] = "none"
                        self._segment_path = lambda: "civic-location-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Location.CivicLocationId, [u'location_identifier'], name, value)


                    class Host(Entity):
                        """
                        Globally defined host location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Location.CivicLocationId.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "host"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Location.CivicLocationId.Host, [u'port_location'], name, value)


                    class Y_None(Entity):
                        """
                        No globally defined location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Location.CivicLocationId.Y_None, self).__init__()

                            self.yang_name = "none"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Location.CivicLocationId.Y_None, [u'port_location'], name, value)


            class Mac(Entity):
                """
                MAC interface commands
                
                .. attribute:: access_group
                
                	MAC access\-group configuration commands
                	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mac.AccessGroup>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Mac, self).__init__()

                    self.yang_name = "mac"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.FiveGigabitEthernet.Mac.AccessGroup))])
                    self._leafs = OrderedDict()

                    self.access_group = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:mac"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mac, [], name, value)


                class AccessGroup(Entity):
                    """
                    MAC access\-group configuration commands
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mac.AccessGroup.Direction>`
                    
                    .. attribute:: acl_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Mac.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "mac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Mac.AccessGroup.Direction')])),
                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                        ])
                        self.direction = None
                        self.acl_name = None
                        self._segment_path = lambda: "access-group" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mac.AccessGroup, [u'direction', u'acl_name'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Macro(Entity):
                """
                Command macro
                
                .. attribute:: description
                
                	Macro description for this interface
                	**type**\: str
                
                .. attribute:: auto
                
                	Smartport interface macro configurations
                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Macro.Auto>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Macro, self).__init__()

                    self.yang_name = "macro"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.FiveGigabitEthernet.Macro.Auto))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.auto = Native.Interface.FiveGigabitEthernet.Macro.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "auto"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macro"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Macro, [u'description'], name, value)


                class Auto(Entity):
                    """
                    Smartport interface macro configurations
                    
                    .. attribute:: processing
                    
                    	Enable smartport macro auto execution on this interface
                    	**type**\: bool
                    
                    .. attribute:: port
                    
                    	Provide interface specific configuration for macro processing
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Macro.Auto.Port>`
                    
                    .. attribute:: control
                    
                    	Control macro auto execution
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Macro.Auto.Control>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Macro.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "macro"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port", ("port", Native.Interface.FiveGigabitEthernet.Macro.Auto.Port)), ("control", ("control", Native.Interface.FiveGigabitEthernet.Macro.Auto.Control))])
                        self._leafs = OrderedDict([
                            ('processing', (YLeaf(YType.boolean, 'processing'), ['bool'])),
                        ])
                        self.processing = None

                        self.port = Native.Interface.FiveGigabitEthernet.Macro.Auto.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.control = Native.Interface.FiveGigabitEthernet.Macro.Auto.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"
                        self._segment_path = lambda: "auto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Macro.Auto, [u'processing'], name, value)


                    class Port(Entity):
                        """
                        Provide interface specific configuration for macro processing
                        
                        .. attribute:: sticky
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Macro.Auto.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                            ])
                            self.sticky = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Macro.Auto.Port, [u'sticky'], name, value)


                    class Control(Entity):
                        """
                        Control macro auto execution
                        
                        .. attribute:: device
                        
                        	Enable macro auto execution for devices
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Macro.Auto.Control.Device>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Macro.Auto.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("device", ("device", Native.Interface.FiveGigabitEthernet.Macro.Auto.Control.Device))])
                            self._leafs = OrderedDict()

                            self.device = Native.Interface.FiveGigabitEthernet.Macro.Auto.Control.Device()
                            self.device.parent = self
                            self._children_name_map["device"] = "device"
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Macro.Auto.Control, [], name, value)


                        class Device(Entity):
                            """
                            Enable macro auto execution for devices
                            
                            .. attribute:: phone
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Macro.Auto.Control.Device, self).__init__()

                                self.yang_name = "device"
                                self.yang_parent_name = "control"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('phone', (YLeaf(YType.empty, 'phone'), ['Empty'])),
                                ])
                                self.phone = None
                                self._segment_path = lambda: "device"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Macro.Auto.Control.Device, [u'phone'], name, value)


            class DualActive(Entity):
                """
                
                
                .. attribute:: fast_hello
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.DualActive, self).__init__()

                    self.yang_name = "dual-active"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fast_hello', (YLeaf(YType.empty, 'fast-hello'), ['Empty'])),
                    ])
                    self.fast_hello = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:dual-active"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.DualActive, [u'fast_hello'], name, value)


            class LoadBalancing(Entity):
                """
                Etherchannel Load\-Balancing
                
                .. attribute:: flow
                
                	Based on the traffic flows identified by the packet headers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Based on the VLAN to member links manual configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.LoadBalancing, self).__init__()

                    self.yang_name = "load-balancing"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('flow', (YLeaf(YType.empty, 'flow'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.flow = None
                    self.vlan = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:load-balancing"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.LoadBalancing, [u'flow', u'vlan'], name, value)


            class VlanRange(Entity):
                """
                
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4096
                
                		**type**\: str
                
                .. attribute:: service_policy
                
                	Configure QoS Service Policy
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.VlanRange.ServicePolicy>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.VlanRange, self).__init__()

                    self.yang_name = "vlan-range"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.FiveGigabitEthernet.VlanRange.ServicePolicy))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                    ])
                    self.id = None

                    self.service_policy = Native.Interface.FiveGigabitEthernet.VlanRange.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:vlan-range" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.VlanRange, [u'id'], name, value)


                class ServicePolicy(Entity):
                    """
                    Configure QoS Service Policy
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.VlanRange.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "vlan-range"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.VlanRange.ServicePolicy, [u'input', u'output'], name, value)


            class Switch(Entity):
                """
                
                
                .. attribute:: virtual
                
                	
                	**type**\:  :py:class:`Virtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Switch.Virtual>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("virtual", ("virtual", Native.Interface.FiveGigabitEthernet.Switch.Virtual))])
                    self._leafs = OrderedDict()

                    self.virtual = Native.Interface.FiveGigabitEthernet.Switch.Virtual()
                    self.virtual.parent = self
                    self._children_name_map["virtual"] = "virtual"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:switch"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switch, [], name, value)


                class Virtual(Entity):
                    """
                    
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Switch.Virtual, self).__init__()

                        self.yang_name = "virtual"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ])
                        self.link = None
                        self._segment_path = lambda: "virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Switch.Virtual, [u'link'], name, value)


            class SrrQueue(Entity):
                """
                
                
                .. attribute:: bandwidth
                
                	
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.SrrQueue, self).__init__()

                    self.yang_name = "srr-queue"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth))])
                    self._leafs = OrderedDict()

                    self.bandwidth = Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:srr-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.SrrQueue, [], name, value)


                class Bandwidth(Entity):
                    """
                    
                    
                    .. attribute:: shape
                    
                    	
                    	**type**\:  :py:class:`Shape <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth.Shape>`
                    
                    .. attribute:: share
                    
                    	
                    	**type**\:  :py:class:`Share <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth.Share>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "srr-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("shape", ("shape", Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth.Shape)), ("share", ("share", Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth.Share))])
                        self._leafs = OrderedDict()

                        self.shape = Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"

                        self.share = Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth.Share()
                        self.share.parent = self
                        self._children_name_map["share"] = "share"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth, [], name, value)


                    class Shape(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint16, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint16, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint16, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint16, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "shape"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth.Shape, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


                    class Share(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth.Share, self).__init__()

                            self.yang_name = "share"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint8, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint8, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint8, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint8, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "share"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.SrrQueue.Bandwidth.Share, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


            class CiscoIOSXESwitchMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection>`
                    
                    .. attribute:: network_link
                    
                    	Enable macsec on switch connected interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('network_link', (YLeaf(YType.empty, 'network-link'), ['Empty'])),
                        ])
                        self.network_link = None

                        self.replay_protection = Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec, [u'network_link'], name, value)


                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, [u'window_size'], name, value)


            class DeviceTracking(Entity):
                """
                Configure device\-tracking on the interface
                
                .. attribute:: attach_policy
                
                	Apply a policy for feature device\-tracking
                	**type**\: str
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.DeviceTracking, self).__init__()

                    self.yang_name = "device-tracking"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                    ])
                    self.attach_policy = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:device-tracking"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.DeviceTracking, [u'attach_policy'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.FiveGigabitEthernet.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.FiveGigabitEthernet.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.FiveGigabitEthernet.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.FiveGigabitEthernet.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.FiveGigabitEthernet.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.FiveGigabitEthernet.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.FiveGigabitEthernet.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.FiveGigabitEthernet.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class Mka(Entity):
                """
                MACsec Key Agreement (MKA) interface configuration
                
                .. attribute:: policy
                
                	Apply MKA Policy
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mka.Policy>`
                
                .. attribute:: pre_shared_key
                
                	Configure MKA Pre\-Shared\-Key
                	**type**\:  :py:class:`PreSharedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mka.PreSharedKey>`
                
                

                """

                _prefix = 'ios-mka'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Mka, self).__init__()

                    self.yang_name = "mka"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.FiveGigabitEthernet.Mka.Policy)), ("pre-shared-key", ("pre_shared_key", Native.Interface.FiveGigabitEthernet.Mka.PreSharedKey))])
                    self._leafs = OrderedDict()

                    self.policy = Native.Interface.FiveGigabitEthernet.Mka.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.pre_shared_key = Native.Interface.FiveGigabitEthernet.Mka.PreSharedKey()
                    self.pre_shared_key.parent = self
                    self._children_name_map["pre_shared_key"] = "pre-shared-key"
                    self._segment_path = lambda: "Cisco-IOS-XE-mka:mka"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mka, [], name, value)


                class Policy(Entity):
                    """
                    Apply MKA Policy
                    
                    .. attribute:: name
                    
                    	MKA Policy NAME
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Mka.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mka.Policy, ['name'], name, value)


                class PreSharedKey(Entity):
                    """
                    Configure MKA Pre\-Shared\-Key
                    
                    .. attribute:: key_chain
                    
                    	Configure the key\-chain name
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mka.PreSharedKey.KeyChain>`
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Mka.PreSharedKey, self).__init__()

                        self.yang_name = "pre-shared-key"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.FiveGigabitEthernet.Mka.PreSharedKey.KeyChain))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.FiveGigabitEthernet.Mka.PreSharedKey.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"
                        self._segment_path = lambda: "pre-shared-key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mka.PreSharedKey, [], name, value)


                    class KeyChain(Entity):
                        """
                        Configure the key\-chain name
                        
                        .. attribute:: name
                        
                        	Name of key\-chain to be used to get keys
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mka'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Mka.PreSharedKey.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "pre-shared-key"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mka.PreSharedKey.KeyChain, ['name'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Utd, ['enable'], name, value)


            class Xconnect(Entity):
                """
                Xconnect commands
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: vcid
                
                	
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: encapsulation
                
                	Data encapsulation method
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Xconnect.Encapsulation>`
                
                .. attribute:: manual
                
                	Manually configure L2TP session parameters
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sequence
                
                	Configure sequencing options for xconnect
                	**type**\:  :py:class:`Sequence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Xconnect.Sequence>`
                
                .. attribute:: pw_class
                
                	Pseudowire\-class to use for encapsulation and protocol configuration
                	**type**\: str
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Xconnect.Encapsulation')])),
                        ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                        ('sequence', (YLeaf(YType.enumeration, 'sequence'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Xconnect.Sequence')])),
                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                    ])
                    self.address = None
                    self.vcid = None
                    self.encapsulation = None
                    self.manual = None
                    self.sequence = None
                    self.pw_class = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'sequence', 'pw_class'], name, value)

                class Encapsulation(Enum):
                    """
                    Encapsulation (Enum Class)

                    Data encapsulation method

                    .. data:: mpls = 0

                    .. data:: l2tpv3 = 1

                    """

                    mpls = Enum.YLeaf(0, "mpls")

                    l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                class Sequence(Enum):
                    """
                    Sequence (Enum Class)

                    Configure sequencing options for xconnect

                    .. data:: both = 0

                    .. data:: receive = 1

                    .. data:: transmit = 2

                    """

                    both = Enum.YLeaf(0, "both")

                    receive = Enum.YLeaf(1, "receive")

                    transmit = Enum.YLeaf(2, "transmit")



            class Evpn(Entity):
                """
                
                
                .. attribute:: ethernet_segment
                
                	Ethernet segment local discriminator value
                	**type**\: list of  		 :py:class:`EthernetSegment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Evpn, self).__init__()

                    self.yang_name = "evpn"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet-segment", ("ethernet_segment", Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment))])
                    self._leafs = OrderedDict()

                    self.ethernet_segment = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:evpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Evpn, [], name, value)


                class EthernetSegment(Entity):
                    """
                    Ethernet segment local discriminator value
                    
                    .. attribute:: es_value  (key)
                    
                    	Ethernet segment local discriminator value
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: df_election
                    
                    	Designated forwarder election parameters
                    	**type**\:  :py:class:`DfElection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment.DfElection>`
                    
                    .. attribute:: redundancy
                    
                    	Multi\-homing redundancy parameters
                    	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment.Redundancy>`
                    
                    .. attribute:: sytem_mac
                    
                    	System MAC address for generating the Ethernet Segment ID
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment, self).__init__()

                        self.yang_name = "ethernet-segment"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['es_value']
                        self._child_classes = OrderedDict([("df-election", ("df_election", Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment.DfElection)), ("redundancy", ("redundancy", Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment.Redundancy))])
                        self._leafs = OrderedDict([
                            ('es_value', (YLeaf(YType.uint16, 'es-value'), ['int'])),
                            ('sytem_mac', (YLeaf(YType.str, 'sytem-mac'), ['str'])),
                        ])
                        self.es_value = None
                        self.sytem_mac = None

                        self.df_election = Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment.DfElection()
                        self.df_election.parent = self
                        self._children_name_map["df_election"] = "df-election"

                        self.redundancy = Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                        self._segment_path = lambda: "ethernet-segment" + "[es-value='" + str(self.es_value) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment, ['es_value', 'sytem_mac'], name, value)


                    class DfElection(Entity):
                        """
                        Designated forwarder election parameters
                        
                        .. attribute:: wait_time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment.DfElection, self).__init__()

                            self.yang_name = "df-election"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wait_time', (YLeaf(YType.uint8, 'wait-time'), ['int'])),
                            ])
                            self.wait_time = None
                            self._segment_path = lambda: "df-election"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment.DfElection, ['wait_time'], name, value)


                    class Redundancy(Entity):
                        """
                        Multi\-homing redundancy parameters
                        
                        .. attribute:: all_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: single_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment.Redundancy, self).__init__()

                            self.yang_name = "redundancy"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all_active', (YLeaf(YType.empty, 'all-active'), ['Empty'])),
                                ('single_active', (YLeaf(YType.empty, 'single-active'), ['Empty'])),
                            ])
                            self.all_active = None
                            self.single_active = None
                            self._segment_path = lambda: "redundancy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Evpn.EthernetSegment.Redundancy, ['all_active', 'single_active'], name, value)


            class FabricDomain(Entity):
                """
                Fabric\-domain interface command
                
                .. attribute:: iwan_fabric
                
                	
                	**type**\:  :py:class:`IwanFabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.FabricDomain.IwanFabric>`
                
                

                """

                _prefix = 'ios-iwanfabric'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.FabricDomain, self).__init__()

                    self.yang_name = "fabric-domain"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("iwan-fabric", ("iwan_fabric", Native.Interface.FiveGigabitEthernet.FabricDomain.IwanFabric))])
                    self._leafs = OrderedDict()

                    self.iwan_fabric = Native.Interface.FiveGigabitEthernet.FabricDomain.IwanFabric()
                    self.iwan_fabric.parent = self
                    self._children_name_map["iwan_fabric"] = "iwan-fabric"
                    self._segment_path = lambda: "Cisco-IOS-XE-iwanfabric:fabric-domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.FabricDomain, [], name, value)


                class IwanFabric(Entity):
                    """
                    
                    
                    .. attribute:: word
                    
                    	
                    	**type**\: list of  		 :py:class:`Word <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.FabricDomain.IwanFabric.Word>`
                    
                    

                    """

                    _prefix = 'ios-iwanfabric'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.FabricDomain.IwanFabric, self).__init__()

                        self.yang_name = "iwan-fabric"
                        self.yang_parent_name = "fabric-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("word", ("word", Native.Interface.FiveGigabitEthernet.FabricDomain.IwanFabric.Word))])
                        self._leafs = OrderedDict()

                        self.word = YList(self)
                        self._segment_path = lambda: "iwan-fabric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.FabricDomain.IwanFabric, [], name, value)


                    class Word(Entity):
                        """
                        
                        
                        .. attribute:: word  (key)
                        
                        	Path name
                        	**type**\: str
                        
                        .. attribute:: interface_id
                        
                        	Specify the interface\-id value
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-iwanfabric'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.FabricDomain.IwanFabric.Word, self).__init__()

                            self.yang_name = "word"
                            self.yang_parent_name = "iwan-fabric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                            ])
                            self.word = None
                            self.interface_id = None
                            self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.FabricDomain.IwanFabric.Word, ['word', 'interface_id'], name, value)


            class Mvrp(Entity):
                """
                
                
                .. attribute:: mvrp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: registration
                
                	
                	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mvrp.Registration>`
                
                .. attribute:: timer
                
                	
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mvrp.Timer>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mvrp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Mvrp, self).__init__()

                    self.yang_name = "mvrp"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("registration", ("registration", Native.Interface.FiveGigabitEthernet.Mvrp.Registration)), ("timer", ("timer", Native.Interface.FiveGigabitEthernet.Mvrp.Timer))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mvrp', (YLeaf(YType.empty, 'mvrp'), ['Empty'])),
                    ])
                    self.mvrp = None

                    self.registration = Native.Interface.FiveGigabitEthernet.Mvrp.Registration()
                    self.registration.parent = self
                    self._children_name_map["registration"] = "registration"

                    self.timer = Native.Interface.FiveGigabitEthernet.Mvrp.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-mvrp:mvrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mvrp, ['mvrp'], name, value)


                class Registration(Entity):
                    """
                    
                    
                    .. attribute:: fixed
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: forbidden
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: normal
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Mvrp.Registration, self).__init__()

                        self.yang_name = "registration"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fixed', (YLeaf(YType.empty, 'fixed'), ['Empty'])),
                            ('forbidden', (YLeaf(YType.empty, 'forbidden'), ['Empty'])),
                            ('normal', (YLeaf(YType.empty, 'normal'), ['Empty'])),
                        ])
                        self.fixed = None
                        self.forbidden = None
                        self.normal = None
                        self._segment_path = lambda: "registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mvrp.Registration, ['fixed', 'forbidden', 'normal'], name, value)


                class Timer(Entity):
                    """
                    
                    
                    .. attribute:: join
                    
                    	
                    	**type**\:  :py:class:`Join <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mvrp.Timer.Join>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave
                    
                    	
                    	**type**\:  :py:class:`Leave <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mvrp.Timer.Leave>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave_all
                    
                    	
                    	**type**\:  :py:class:`LeaveAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Mvrp.Timer.LeaveAll>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: periodic
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Mvrp.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("join", ("join", Native.Interface.FiveGigabitEthernet.Mvrp.Timer.Join)), ("leave", ("leave", Native.Interface.FiveGigabitEthernet.Mvrp.Timer.Leave)), ("leave-all", ("leave_all", Native.Interface.FiveGigabitEthernet.Mvrp.Timer.LeaveAll))])
                        self._leafs = OrderedDict([
                            ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ])
                        self.periodic = None

                        self.join = None
                        self._children_name_map["join"] = "join"

                        self.leave = None
                        self._children_name_map["leave"] = "leave"

                        self.leave_all = None
                        self._children_name_map["leave_all"] = "leave-all"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mvrp.Timer, ['periodic'], name, value)


                    class Join(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 20..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Mvrp.Timer.Join, self).__init__()

                            self.yang_name = "join"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "join"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mvrp.Timer.Join, ['y_range'], name, value)


                    class Leave(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Mvrp.Timer.Leave, self).__init__()

                            self.yang_name = "leave"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mvrp.Timer.Leave, ['y_range'], name, value)


                    class LeaveAll(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1000..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Mvrp.Timer.LeaveAll, self).__init__()

                            self.yang_name = "leave-all"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave-all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mvrp.Timer.LeaveAll, ['y_range'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.FiveGigabitEthernet.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.FiveGigabitEthernet.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.FiveGigabitEthernet.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.FiveGigabitEthernet.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.FiveGigabitEthernet.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.FiveGigabitEthernet.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.FiveGigabitEthernet.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.FiveGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Power(Entity):
                """
                
                
                .. attribute:: inline
                
                	
                	**type**\:  :py:class:`Inline <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Power.Inline>`
                
                

                """

                _prefix = 'ios-power'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Power, self).__init__()

                    self.yang_name = "power"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("inline", ("inline", Native.Interface.FiveGigabitEthernet.Power.Inline))])
                    self._leafs = OrderedDict()

                    self.inline = Native.Interface.FiveGigabitEthernet.Power.Inline()
                    self.inline.parent = self
                    self._children_name_map["inline"] = "inline"
                    self._segment_path = lambda: "Cisco-IOS-XE-power:power"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Power, [], name, value)


                class Inline(Entity):
                    """
                    
                    
                    .. attribute:: consumption
                    
                    	
                    	**type**\: int
                    
                    	**range:** 4000..15400
                    
                    .. attribute:: never
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: auto
                    
                    	Automatically detect and power inline devices
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Power.Inline.Auto>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: four_pair
                    
                    	Four\-pair PoE power
                    	**type**\:  :py:class:`FourPair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Power.Inline.FourPair>`
                    
                    .. attribute:: police
                    
                    	Police the power drawn on the port
                    	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Power.Inline.Police>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: port
                    
                    	Configure Port Power Level
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Power.Inline.Port>`
                    
                    .. attribute:: static
                    
                    	High priority inline power interface
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Power.Inline.Static>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-power'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Power.Inline, self).__init__()

                        self.yang_name = "inline"
                        self.yang_parent_name = "power"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.FiveGigabitEthernet.Power.Inline.Auto)), ("four-pair", ("four_pair", Native.Interface.FiveGigabitEthernet.Power.Inline.FourPair)), ("police", ("police", Native.Interface.FiveGigabitEthernet.Power.Inline.Police)), ("port", ("port", Native.Interface.FiveGigabitEthernet.Power.Inline.Port)), ("static", ("static", Native.Interface.FiveGigabitEthernet.Power.Inline.Static))])
                        self._leafs = OrderedDict([
                            ('consumption', (YLeaf(YType.uint16, 'consumption'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.consumption = None
                        self.never = None

                        self.auto = None
                        self._children_name_map["auto"] = "auto"

                        self.four_pair = Native.Interface.FiveGigabitEthernet.Power.Inline.FourPair()
                        self.four_pair.parent = self
                        self._children_name_map["four_pair"] = "four-pair"

                        self.police = None
                        self._children_name_map["police"] = "police"

                        self.port = Native.Interface.FiveGigabitEthernet.Power.Inline.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.static = None
                        self._children_name_map["static"] = "static"
                        self._segment_path = lambda: "inline"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Power.Inline, ['consumption', 'never'], name, value)


                    class Auto(Entity):
                        """
                        Automatically detect and power inline devices
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Power.Inline.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "auto"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Power.Inline.Auto, ['max'], name, value)


                    class FourPair(Entity):
                        """
                        Four\-pair PoE power
                        
                        .. attribute:: forced
                        
                        	Enable Four\-pair PoE without L2 negotiation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Power.Inline.FourPair, self).__init__()

                            self.yang_name = "four-pair"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forced', (YLeaf(YType.empty, 'forced'), ['Empty'])),
                            ])
                            self.forced = None
                            self._segment_path = lambda: "four-pair"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Power.Inline.FourPair, ['forced'], name, value)


                    class Police(Entity):
                        """
                        Police the power drawn on the port
                        
                        .. attribute:: action
                        
                        	Action to be taken when power is overdrawn on the port
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Power.Inline.Police.Action>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Power.Inline.Police, self).__init__()

                            self.yang_name = "police"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.FiveGigabitEthernet.Power.Inline.Police.Action))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.FiveGigabitEthernet.Power.Inline.Police.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "police"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Power.Inline.Police, [], name, value)


                        class Action(Entity):
                            """
                            Action to be taken when power is overdrawn on the port
                            
                            .. attribute:: errdisable
                            
                            	Error\-disable the port when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log a message when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-power'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Power.Inline.Police.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "police"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('errdisable', (YLeaf(YType.empty, 'errdisable'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ])
                                self.errdisable = None
                                self.log = None
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Power.Inline.Police.Action, ['errdisable', 'log'], name, value)


                    class Port(Entity):
                        """
                        Configure Port Power Level
                        
                        .. attribute:: poe_ha
                        
                        	Apply poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: perpetual_poe_ha
                        
                        	Apply perpetual\-poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: two_event
                        
                        	Enable 2\-event classification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Power.Inline.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('poe_ha', (YLeaf(YType.empty, 'poe-ha'), ['Empty'])),
                                ('perpetual_poe_ha', (YLeaf(YType.empty, 'perpetual-poe-ha'), ['Empty'])),
                                ('two_event', (YLeaf(YType.empty, 'two-event'), ['Empty'])),
                            ])
                            self.poe_ha = None
                            self.perpetual_poe_ha = None
                            self.two_event = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Power.Inline.Port, ['poe_ha', 'perpetual_poe_ha', 'two_event'], name, value)


                    class Static(Entity):
                        """
                        High priority inline power interface
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Power.Inline.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "static"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Power.Inline.Static, ['max'], name, value)


            class Cdp(Entity):
                """
                CDP interface subcommands
                
                .. attribute:: enable
                
                	Enable CDP on interface
                	**type**\: bool
                
                .. attribute:: tlv
                
                	Enable exchange of specific tlv information
                	**type**\:  :py:class:`Tlv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cdp.Tlv>`
                
                

                """

                _prefix = 'ios-cdp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Cdp, self).__init__()

                    self.yang_name = "cdp"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tlv", ("tlv", Native.Interface.FiveGigabitEthernet.Cdp.Tlv))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                    ])
                    self.enable = None

                    self.tlv = Native.Interface.FiveGigabitEthernet.Cdp.Tlv()
                    self.tlv.parent = self
                    self._children_name_map["tlv"] = "tlv"
                    self._segment_path = lambda: "Cisco-IOS-XE-cdp:cdp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cdp, ['enable'], name, value)


                class Tlv(Entity):
                    """
                    Enable exchange of specific tlv information
                    
                    .. attribute:: app
                    
                    	Enable/Configure Application TLV
                    	**type**\:  :py:class:`App <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cdp.Tlv.App>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: server_location
                    
                    	Enable CDP location server on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	Exchange location information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cdp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Cdp.Tlv, self).__init__()

                        self.yang_name = "tlv"
                        self.yang_parent_name = "cdp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("app", ("app", Native.Interface.FiveGigabitEthernet.Cdp.Tlv.App))])
                        self._leafs = OrderedDict([
                            ('server_location', (YLeaf(YType.empty, 'server-location'), ['Empty'])),
                            ('location', (YLeaf(YType.empty, 'location'), ['Empty'])),
                        ])
                        self.server_location = None
                        self.location = None

                        self.app = None
                        self._children_name_map["app"] = "app"
                        self._segment_path = lambda: "tlv"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cdp.Tlv, ['server_location', 'location'], name, value)


                    class App(Entity):
                        """
                        Enable/Configure Application TLV
                        
                        .. attribute:: tlvtype
                        
                        	Configure APP TLV
                        	**type**\: int
                        
                        	**range:** 1001..65535
                        
                        .. attribute:: value
                        
                        	Configure App TLV Value information
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cdp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Cdp.Tlv.App, self).__init__()

                            self.yang_name = "app"
                            self.yang_parent_name = "tlv"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tlvtype', (YLeaf(YType.uint16, 'tlvtype'), ['int'])),
                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                            ])
                            self.tlvtype = None
                            self.value = None
                            self._segment_path = lambda: "app"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cdp.Tlv.App, ['tlvtype', 'value'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.FiveGigabitEthernet.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.FiveGigabitEthernet.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.FiveGigabitEthernet.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.FiveGigabitEthernet.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class Authentication(Entity):
                """
                Auth Manager Interface Configuration Commands
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.ControlDirection>`
                
                .. attribute:: event
                
                	Set action for authentication events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event>`
                
                .. attribute:: fallback
                
                	Enable the Webauth fallback mechanism
                	**type**\: str
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.HostMode>`
                
                .. attribute:: open
                
                	Enable or Disable open access on this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: order
                
                	Add an authentication method to the order list
                	**type**\:  :py:class:`Order <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Order>`
                
                .. attribute:: priority
                
                	Add an authentication method to the priority list
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Priority>`
                
                .. attribute:: port_control
                
                	set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.PortControl>`
                
                .. attribute:: periodic
                
                	Enable or Disable Reauthentication for this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timer
                
                	Set authentication timer values
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Timer>`
                
                .. attribute:: violation
                
                	Configure action to take on security violations
                	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Violation>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FiveGigabitEthernet.Authentication.Event)), ("order", ("order", Native.Interface.FiveGigabitEthernet.Authentication.Order)), ("priority", ("priority", Native.Interface.FiveGigabitEthernet.Authentication.Priority)), ("timer", ("timer", Native.Interface.FiveGigabitEthernet.Authentication.Timer))])
                    self._leafs = OrderedDict([
                        ('control_direction', (YLeaf(YType.enumeration, 'control-direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Authentication.ControlDirection')])),
                        ('fallback', (YLeaf(YType.str, 'fallback'), ['str'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Authentication.HostMode')])),
                        ('open', (YLeaf(YType.empty, 'open'), ['Empty'])),
                        ('port_control', (YLeaf(YType.enumeration, 'port-control'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Authentication.PortControl')])),
                        ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Authentication.Violation')])),
                    ])
                    self.control_direction = None
                    self.fallback = None
                    self.host_mode = None
                    self.open = None
                    self.port_control = None
                    self.periodic = None
                    self.violation = None

                    self.event = Native.Interface.FiveGigabitEthernet.Authentication.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.order = Native.Interface.FiveGigabitEthernet.Authentication.Order()
                    self.order.parent = self
                    self._children_name_map["order"] = "order"

                    self.priority = Native.Interface.FiveGigabitEthernet.Authentication.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "priority"

                    self.timer = Native.Interface.FiveGigabitEthernet.Authentication.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:authentication"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication, ['control_direction', 'fallback', 'host_mode', 'open', 'port_control', 'periodic', 'violation'], name, value)

                class ControlDirection(Enum):
                    """
                    ControlDirection (Enum Class)

                    Set the control\-direction on the interface

                    .. data:: both = 0

                    .. data:: in_ = 1

                    """

                    both = Enum.YLeaf(0, "both")

                    in_ = Enum.YLeaf(1, "in")


                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")


                class PortControl(Enum):
                    """
                    PortControl (Enum Class)

                    set the port\-control value

                    .. data:: auto = 0

                    .. data:: force_authorized = 1

                    .. data:: force_unauthorized = 2

                    """

                    auto = Enum.YLeaf(0, "auto")

                    force_authorized = Enum.YLeaf(1, "force-authorized")

                    force_unauthorized = Enum.YLeaf(2, "force-unauthorized")


                class Violation(Enum):
                    """
                    Violation (Enum Class)

                    Configure action to take on security violations

                    .. data:: protect = 0

                    .. data:: replace = 1

                    .. data:: restrict = 2

                    .. data:: shutdown = 3

                    """

                    protect = Enum.YLeaf(0, "protect")

                    replace = Enum.YLeaf(1, "replace")

                    restrict = Enum.YLeaf(2, "restrict")

                    shutdown = Enum.YLeaf(3, "shutdown")



                class Event(Entity):
                    """
                    Set action for authentication events
                    
                    .. attribute:: server
                    
                    	Configure actions for AAA server events
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.Server>`
                    
                    .. attribute:: fail
                    
                    	Configure actions for AAA fail events
                    	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail>`
                    
                    .. attribute:: no_response
                    
                    	Configure actions for AAA no\-response events
                    	**type**\:  :py:class:`NoResponse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Authentication.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("server", ("server", Native.Interface.FiveGigabitEthernet.Authentication.Event.Server)), ("fail", ("fail", Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail)), ("no-response", ("no_response", Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse))])
                        self._leafs = OrderedDict()

                        self.server = Native.Interface.FiveGigabitEthernet.Authentication.Event.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.fail = Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail()
                        self.fail.parent = self
                        self._children_name_map["fail"] = "fail"

                        self.no_response = Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse()
                        self.no_response.parent = self
                        self._children_name_map["no_response"] = "no-response"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event, [], name, value)


                    class Server(Entity):
                        """
                        Configure actions for AAA server events
                        
                        .. attribute:: alive
                        
                        	Configure AAA server alive action
                        	**type**\:  :py:class:`Alive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Alive>`
                        
                        .. attribute:: dead
                        
                        	Configure AAA server dead action
                        	**type**\:  :py:class:`Dead <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("alive", ("alive", Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Alive)), ("dead", ("dead", Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead))])
                            self._leafs = OrderedDict()

                            self.alive = Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Alive()
                            self.alive.parent = self
                            self._children_name_map["alive"] = "alive"

                            self.dead = Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead()
                            self.dead.parent = self
                            self._children_name_map["dead"] = "dead"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server, [], name, value)


                        class Alive(Entity):
                            """
                            Configure AAA server alive action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Alive.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Alive, self).__init__()

                                self.yang_name = "alive"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Alive.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Alive.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "alive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Alive, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all authorized clients
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Alive.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "alive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reinitialize', (YLeaf(YType.empty, 'reinitialize'), ['Empty'])),
                                    ])
                                    self.reinitialize = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Alive.Action, ['reinitialize'], name, value)


                        class Dead(Entity):
                            """
                            Configure AAA server dead action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead, self).__init__()

                                self.yang_name = "dead"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dead"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: authorize
                                
                                	Authorize the port
                                	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all client on the port
                                	**type**\:  :py:class:`Reinitialize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dead"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize)), ("reinitialize", ("reinitialize", Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize))])
                                    self._leafs = OrderedDict()

                                    self.authorize = None
                                    self._children_name_map["authorize"] = "authorize"

                                    self.reinitialize = Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize()
                                    self.reinitialize.parent = self
                                    self._children_name_map["reinitialize"] = "reinitialize"
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action, [], name, value)


                                class Authorize(Entity):
                                    """
                                    Authorize the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: voice
                                    
                                    	Authorize the port for VOICE traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize, self).__init__()

                                        self.yang_name = "authorize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ('voice', (YLeaf(YType.empty, 'voice'), ['Empty'])),
                                        ])
                                        self.vlan = None
                                        self.voice = None
                                        self._segment_path = lambda: "authorize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize, ['vlan', 'voice'], name, value)


                                class Reinitialize(Entity):
                                    """
                                    Reinitialize all client on the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, self).__init__()

                                        self.yang_name = "reinitialize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "reinitialize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, ['vlan'], name, value)


                    class Fail(Entity):
                        """
                        Configure actions for AAA fail events
                        
                        .. attribute:: action
                        
                        	Required action for fail event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail, self).__init__()

                            self.yang_name = "fail"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "fail"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail, [], name, value)


                        class Action(Entity):
                            """
                            Required action for fail event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "fail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.Fail.Action.Authorize, ['vlan'], name, value)


                    class NoResponse(Entity):
                        """
                        Configure actions for AAA no\-response events
                        
                        .. attribute:: action
                        
                        	Required action for no\-response event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse, self).__init__()

                            self.yang_name = "no-response"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "no-response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse, [], name, value)


                        class Action(Entity):
                            """
                            Required action for no\-response event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "no-response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize, ['vlan'], name, value)


                class Order(Entity):
                    """
                    Add an authentication method to the order list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Authentication.Order, self).__init__()

                        self.yang_name = "order"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "order"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Order, ['dot1x', 'mab', 'webauth'], name, value)


                class Priority(Entity):
                    """
                    Add an authentication method to the priority list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Authentication.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Priority, ['dot1x', 'mab', 'webauth'], name, value)


                class Timer(Entity):
                    """
                    Set authentication timer values
                    
                    .. attribute:: reauthenticate
                    
                    	Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                    	**type**\:  :py:class:`Reauthenticate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Timer.Reauthenticate>`
                    
                    .. attribute:: inactivity
                    
                    	Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                    	**type**\:  :py:class:`Inactivity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity>`
                    
                    .. attribute:: restart
                    
                    	Interval in seconds after which an attempt should be made toauthenticate an unauthorized port (default 60 sec)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Authentication.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reauthenticate", ("reauthenticate", Native.Interface.FiveGigabitEthernet.Authentication.Timer.Reauthenticate)), ("inactivity", ("inactivity", Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity))])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                        ])
                        self.restart = None

                        self.reauthenticate = Native.Interface.FiveGigabitEthernet.Authentication.Timer.Reauthenticate()
                        self.reauthenticate.parent = self
                        self._children_name_map["reauthenticate"] = "reauthenticate"

                        self.inactivity = Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity()
                        self.inactivity.parent = self
                        self._children_name_map["inactivity"] = "inactivity"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Timer, ['restart'], name, value)


                    class Reauthenticate(Entity):
                        """
                        Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: server
                        
                        	Obtain re\-authentication timeout value from the server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Authentication.Timer.Reauthenticate, self).__init__()

                            self.yang_name = "reauthenticate"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                            ])
                            self.value = None
                            self.server = None
                            self._segment_path = lambda: "reauthenticate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Timer.Reauthenticate, ['value', 'server'], name, value)


                    class Inactivity(Entity):
                        """
                        Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity.Value>`
                        
                        .. attribute:: server
                        
                        	Obtain inactivity timeout value from the server
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity.Server>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity, self).__init__()

                            self.yang_name = "inactivity"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity.Value)), ("server", ("server", Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity.Server))])
                            self._leafs = OrderedDict()

                            self.value = Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.server = None
                            self._children_name_map["server"] = "server"
                            self._segment_path = lambda: "inactivity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity, [], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.value = None
                                self.dynamic = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity.Value, ['value', 'dynamic'], name, value)


                        class Server(Entity):
                            """
                            Obtain inactivity timeout value from the server
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.dynamic = None
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Authentication.Timer.Inactivity.Server, ['dynamic'], name, value)


            class Mab(Entity):
                """
                
                
                .. attribute:: eap
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Mab, self).__init__()

                    self.yang_name = "mab"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                    ])
                    self.eap = None
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:mab"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Mab, ['eap'], name, value)


            class Dot1x(Entity):
                """
                Interface Config Commands for IEEE 802.1X
                
                .. attribute:: authenticator
                
                	Configure authenticator parameters
                	**type**\:  :py:class:`Authenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Dot1x.Authenticator>`
                
                .. attribute:: credentials
                
                	Credentials profile configuration
                	**type**\: str
                
                .. attribute:: max_reauth_req
                
                	Max No. of Reauthentication Attempts
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_req
                
                	Max No. of Retries
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_start
                
                	Max No. of EAPOL\-Start requests
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: pae
                
                	Set 802.1x interface pae type
                	**type**\:  :py:class:`Pae <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Dot1x.Pae>`
                
                .. attribute:: supplicant
                
                	Configure supplicant parameters
                	**type**\:  :py:class:`Supplicant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Dot1x.Supplicant>`
                
                .. attribute:: timeout
                
                	Various Timeouts
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Dot1x.Timeout>`
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Dot1x, self).__init__()

                    self.yang_name = "dot1x"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authenticator", ("authenticator", Native.Interface.FiveGigabitEthernet.Dot1x.Authenticator)), ("supplicant", ("supplicant", Native.Interface.FiveGigabitEthernet.Dot1x.Supplicant)), ("timeout", ("timeout", Native.Interface.FiveGigabitEthernet.Dot1x.Timeout))])
                    self._leafs = OrderedDict([
                        ('credentials', (YLeaf(YType.str, 'credentials'), ['str'])),
                        ('max_reauth_req', (YLeaf(YType.uint8, 'max-reauth-req'), ['int'])),
                        ('max_req', (YLeaf(YType.uint8, 'max-req'), ['int'])),
                        ('max_start', (YLeaf(YType.uint8, 'max-start'), ['int'])),
                        ('pae', (YLeaf(YType.enumeration, 'pae'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Dot1x.Pae')])),
                    ])
                    self.credentials = None
                    self.max_reauth_req = None
                    self.max_req = None
                    self.max_start = None
                    self.pae = None

                    self.authenticator = Native.Interface.FiveGigabitEthernet.Dot1x.Authenticator()
                    self.authenticator.parent = self
                    self._children_name_map["authenticator"] = "authenticator"

                    self.supplicant = Native.Interface.FiveGigabitEthernet.Dot1x.Supplicant()
                    self.supplicant.parent = self
                    self._children_name_map["supplicant"] = "supplicant"

                    self.timeout = Native.Interface.FiveGigabitEthernet.Dot1x.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"
                    self._segment_path = lambda: "Cisco-IOS-XE-dot1x:dot1x"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Dot1x, ['credentials', 'max_reauth_req', 'max_req', 'max_start', 'pae'], name, value)

                class Pae(Enum):
                    """
                    Pae (Enum Class)

                    Set 802.1x interface pae type

                    .. data:: authenticator = 0

                    .. data:: supplicant = 1

                    .. data:: both = 2

                    """

                    authenticator = Enum.YLeaf(0, "authenticator")

                    supplicant = Enum.YLeaf(1, "supplicant")

                    both = Enum.YLeaf(2, "both")



                class Authenticator(Entity):
                    """
                    Configure authenticator parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP authenticator parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Dot1x.Authenticator.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Dot1x.Authenticator, self).__init__()

                        self.yang_name = "authenticator"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.FiveGigabitEthernet.Dot1x.Authenticator.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.FiveGigabitEthernet.Dot1x.Authenticator.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "authenticator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Dot1x.Authenticator, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP authenticator parameters
                        
                        .. attribute:: profile
                        
                        	EAP authenticator profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Dot1x.Authenticator.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "authenticator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Dot1x.Authenticator.Eap, ['profile'], name, value)


                class Supplicant(Entity):
                    """
                    Configure supplicant parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP supplicant parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Dot1x.Supplicant.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Dot1x.Supplicant, self).__init__()

                        self.yang_name = "supplicant"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.FiveGigabitEthernet.Dot1x.Supplicant.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.FiveGigabitEthernet.Dot1x.Supplicant.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "supplicant"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Dot1x.Supplicant, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP supplicant parameters
                        
                        .. attribute:: profile
                        
                        	EAP supplicant profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Dot1x.Supplicant.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "supplicant"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Dot1x.Supplicant.Eap, ['profile'], name, value)


                class Timeout(Entity):
                    """
                    Various Timeouts
                    
                    .. attribute:: auth_period
                    
                    	Timeout for authenticator reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: held_period
                    
                    	Timeout for authentication retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: quiet_period
                    
                    	QuietPeriod in Seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ratelimit_period
                    
                    	Ratelimit Period in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: server_timeout
                    
                    	Timeout for Radius Retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: start_period
                    
                    	Timeout for EAPOL\-start retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: supp_timeout
                    
                    	Timeout for supplicant reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: tx_period
                    
                    	Timeout for supplicant retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Dot1x.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auth_period', (YLeaf(YType.uint16, 'auth-period'), ['int'])),
                            ('held_period', (YLeaf(YType.uint16, 'held-period'), ['int'])),
                            ('quiet_period', (YLeaf(YType.uint16, 'quiet-period'), ['int'])),
                            ('ratelimit_period', (YLeaf(YType.uint16, 'ratelimit-period'), ['int'])),
                            ('server_timeout', (YLeaf(YType.uint16, 'server-timeout'), ['int'])),
                            ('start_period', (YLeaf(YType.uint16, 'start-period'), ['int'])),
                            ('supp_timeout', (YLeaf(YType.uint16, 'supp-timeout'), ['int'])),
                            ('tx_period', (YLeaf(YType.uint16, 'tx-period'), ['int'])),
                        ])
                        self.auth_period = None
                        self.held_period = None
                        self.quiet_period = None
                        self.ratelimit_period = None
                        self.server_timeout = None
                        self.start_period = None
                        self.supp_timeout = None
                        self.tx_period = None
                        self._segment_path = lambda: "timeout"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Dot1x.Timeout, ['auth_period', 'held_period', 'quiet_period', 'ratelimit_period', 'server_timeout', 'start_period', 'supp_timeout', 'tx_period'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpdufilter
                
                	Don't send or receive BPDUs on this interface
                	**type**\:  :py:class:`Bpdufilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SpanningTree.Bpdufilter>`
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SpanningTree.Bpduguard>`
                
                .. attribute:: cost
                
                	To set the path cost of the interface
                	**type**\: int
                
                	**range:** 1..200000000
                
                .. attribute:: guard
                
                	Change an interface's spanning tree guard mode
                	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SpanningTree.Guard>`
                
                .. attribute:: link_type
                
                	Specify a link type for spanning tree tree protocol use
                	**type**\:  :py:class:`LinkType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SpanningTree.LinkType>`
                
                .. attribute:: portfast
                
                	Spanning tree portfast options
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                .. attribute:: port_priority
                
                	Spanning tree port\-priority options
                	**type**\: int
                
                	**range:** 0..240
                
                .. attribute:: vlan
                
                	VLAN Switch Spanning Tree
                	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SpanningTree.Vlan>`
                
                .. attribute:: loopguard
                
                	Spanning tree loopguard options
                	**type**\:  :py:class:`Loopguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SpanningTree.Loopguard>`
                
                .. attribute:: mst
                
                	Per interface MST configurations
                	**type**\:  :py:class:`Mst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SpanningTree.Mst>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Interface.FiveGigabitEthernet.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Interface.FiveGigabitEthernet.SpanningTree.Portfast)), ("vlan", ("vlan", Native.Interface.FiveGigabitEthernet.SpanningTree.Vlan)), ("loopguard", ("loopguard", Native.Interface.FiveGigabitEthernet.SpanningTree.Loopguard)), ("mst", ("mst", Native.Interface.FiveGigabitEthernet.SpanningTree.Mst))])
                    self._leafs = OrderedDict([
                        ('bpdufilter', (YLeaf(YType.enumeration, 'bpdufilter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.SpanningTree.Bpdufilter')])),
                        ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ('guard', (YLeaf(YType.enumeration, 'guard'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.SpanningTree.Guard')])),
                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.SpanningTree.LinkType')])),
                        ('port_priority', (YLeaf(YType.uint8, 'port-priority'), ['int'])),
                    ])
                    self.bpdufilter = None
                    self.cost = None
                    self.guard = None
                    self.link_type = None
                    self.port_priority = None

                    self.bpduguard = Native.Interface.FiveGigabitEthernet.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"

                    self.loopguard = Native.Interface.FiveGigabitEthernet.SpanningTree.Loopguard()
                    self.loopguard.parent = self
                    self._children_name_map["loopguard"] = "loopguard"

                    self.mst = Native.Interface.FiveGigabitEthernet.SpanningTree.Mst()
                    self.mst.parent = self
                    self._children_name_map["mst"] = "mst"

                    self.vlan = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:spanning-tree"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.SpanningTree, ['bpdufilter', 'cost', 'guard', 'link_type', 'port_priority'], name, value)

                class Bpdufilter(Enum):
                    """
                    Bpdufilter (Enum Class)

                    Don't send or receive BPDUs on this interface

                    .. data:: disable = 0

                    .. data:: enable = 1

                    """

                    disable = Enum.YLeaf(0, "disable")

                    enable = Enum.YLeaf(1, "enable")


                class Guard(Enum):
                    """
                    Guard (Enum Class)

                    Change an interface's spanning tree guard mode

                    .. data:: loop = 0

                    .. data:: none = 1

                    .. data:: root = 2

                    """

                    loop = Enum.YLeaf(0, "loop")

                    none = Enum.YLeaf(1, "none")

                    root = Enum.YLeaf(2, "root")


                class LinkType(Enum):
                    """
                    LinkType (Enum Class)

                    Specify a link type for spanning tree tree protocol use

                    .. data:: point_to_point = 0

                    .. data:: shared = 1

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")

                    shared = Enum.YLeaf(1, "shared")



                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.disable = None
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.SpanningTree.Bpduguard, ['disable', 'enable'], name, value)


                class Portfast(Entity):
                    """
                    Spanning tree portfast options
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk
                    
                    	Enable portfast on the interface even in trunk mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                        ])
                        self.disable = None
                        self.trunk = None
                        self.edge = None
                        self._segment_path = lambda: "portfast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.SpanningTree.Portfast, ['disable', 'trunk', 'edge'], name, value)


                class Vlan(Entity):
                    """
                    VLAN Switch Spanning Tree
                    
                    .. attribute:: vlan_ids  (key)
                    
                    	vlan range, example\: 1,3\-5,7,9\-11
                    	**type**\: str
                    
                    .. attribute:: cost
                    
                    	<1\-200000000> Spanning\-tree cost
                    	**type**\: int
                    
                    	**range:** 1..200000000
                    
                    .. attribute:: port_priority
                    
                    	<0\-240> port priority in increments of 16
                    	**type**\: int
                    
                    	**range:** 0..240
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.SpanningTree.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vlan_ids']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_ids', (YLeaf(YType.str, 'vlan-ids'), ['str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                        ])
                        self.vlan_ids = None
                        self.cost = None
                        self.port_priority = None
                        self._segment_path = lambda: "vlan" + "[vlan-ids='" + str(self.vlan_ids) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.SpanningTree.Vlan, ['vlan_ids', 'cost', 'port_priority'], name, value)


                class Loopguard(Entity):
                    """
                    Spanning tree loopguard options
                    
                    .. attribute:: default
                    
                    	Enable loopguard by default on all ports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.SpanningTree.Loopguard, self).__init__()

                        self.yang_name = "loopguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.default = None
                        self._segment_path = lambda: "loopguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.SpanningTree.Loopguard, ['default'], name, value)


                class Mst(Entity):
                    """
                    Per interface MST configurations
                    
                    .. attribute:: mst_instance
                    
                    	
                    	**type**\: list of  		 :py:class:`MstInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.SpanningTree.Mst.MstInstance>`
                    
                    .. attribute:: pre_standard
                    
                    	Force pre\-standard MST BPDU transmission on port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.SpanningTree.Mst, self).__init__()

                        self.yang_name = "mst"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mst-instance", ("mst_instance", Native.Interface.FiveGigabitEthernet.SpanningTree.Mst.MstInstance))])
                        self._leafs = OrderedDict([
                            ('pre_standard', (YLeaf(YType.empty, 'pre-standard'), ['Empty'])),
                        ])
                        self.pre_standard = None

                        self.mst_instance = YList(self)
                        self._segment_path = lambda: "mst"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.SpanningTree.Mst, ['pre_standard'], name, value)


                    class MstInstance(Entity):
                        """
                        
                        
                        .. attribute:: instance  (key)
                        
                        	MST instance list, example 0,2\-4,6,8\-12
                        	**type**\: str
                        
                        .. attribute:: cost
                        
                        	<1\-200000000> Spanning\-tree cost
                        	**type**\: int
                        
                        	**range:** 1..200000000
                        
                        .. attribute:: port_priority
                        
                        	<0\-240> port priority in increments of 16
                        	**type**\: int
                        
                        	**range:** 0..240
                        
                        

                        """

                        _prefix = 'ios-stp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.SpanningTree.Mst.MstInstance, self).__init__()

                            self.yang_name = "mst-instance"
                            self.yang_parent_name = "mst"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                            ])
                            self.instance = None
                            self.cost = None
                            self.port_priority = None
                            self._segment_path = lambda: "mst-instance" + "[instance='" + str(self.instance) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.SpanningTree.Mst.MstInstance, ['instance', 'cost', 'port_priority'], name, value)


            class Performance(Entity):
                """
                Global performance monitor configuration
                
                .. attribute:: monitor
                
                	monitor
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Performance.Monitor>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Performance, self).__init__()

                    self.yang_name = "performance"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FiveGigabitEthernet.Performance.Monitor))])
                    self._leafs = OrderedDict()

                    self.monitor = Native.Interface.FiveGigabitEthernet.Performance.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"
                    self._segment_path = lambda: "Cisco-IOS-XE-ezpm:performance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Performance, [], name, value)


                class Monitor(Entity):
                    """
                    monitor
                    
                    .. attribute:: context
                    
                    	Select ezPM context
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Performance.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "performance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('context', (YLeafList(YType.str, 'context'), ['str'])),
                        ])
                        self.context = []
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Performance.Monitor, ['context'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Umbrella, ['out', 'in_'], name, value)


            class Lldp(Entity):
                """
                LLDP interface subcommands
                
                .. attribute:: receive
                
                	Enable LLDP reception on interface
                	**type**\: bool
                
                .. attribute:: transmit
                
                	Enable LLDP transmission on interface
                	**type**\: bool
                
                

                """

                _prefix = 'ios-lldp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Lldp, self).__init__()

                    self.yang_name = "lldp"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                        ('transmit', (YLeaf(YType.boolean, 'transmit'), ['bool'])),
                    ])
                    self.receive = None
                    self.transmit = None
                    self._segment_path = lambda: "Cisco-IOS-XE-lldp:lldp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Lldp, ['receive', 'transmit'], name, value)


            class Vrrp(Entity):
                """
                Configure VRRP
                
                .. attribute:: vrrp_group
                
                	
                	**type**\: list of  		 :py:class:`VrrpGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup>`
                
                .. attribute:: vrrp_group_v2
                
                	vrrp version 2
                	**type**\: list of  		 :py:class:`VrrpGroupV2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2>`
                
                .. attribute:: delay
                
                	
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.Delay>`
                
                

                """

                _prefix = 'ios-vrrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Vrrp, self).__init__()

                    self.yang_name = "vrrp"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrrp-group", ("vrrp_group", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup)), ("vrrp-group-v2", ("vrrp_group_v2", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2)), ("delay", ("delay", Native.Interface.FiveGigabitEthernet.Vrrp.Delay))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.FiveGigabitEthernet.Vrrp.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.vrrp_group = YList(self)
                    self.vrrp_group_v2 = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vrrp:vrrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp, [], name, value)


                class VrrpGroup(Entity):
                    """
                    
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: address_family
                    
                    	Address family of the group
                    	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup, self).__init__()

                        self.yang_name = "vrrp-group"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("address-family", ("address_family", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                        ])
                        self.group_id = None

                        self.address_family = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"
                        self._segment_path = lambda: "vrrp-group" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup, ['group_id'], name, value)


                    class AddressFamily(Entity):
                        """
                        Address family of the group
                        
                        .. attribute:: ipv4
                        
                        	IPv4 Address family
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	IPv6 Address family
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily, self).__init__()

                            self.yang_name = "address-family"
                            self.yang_parent_name = "vrrp-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4)), ("ipv6", ("ipv6", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = None
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "address-family"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily, [], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 Address family
                            
                            .. attribute:: vrrpv2
                            
                            	Set VRRPv2 compatibility mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: address
                            
                            	Set the IPv4 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address)), ("preempt", ("preempt", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt)), ("timers", ("timers", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers)), ("track", ("track", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track)), ("vrrs", ("vrrs", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('vrrpv2', (YLeaf(YType.empty, 'vrrpv2'), ['Empty'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.vrrpv2 = None
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4, ['vrrpv2', 'description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv4 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary>`
                                
                                .. attribute:: secondary
                                
                                	
                                	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary)), ("secondary", ("secondary", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.secondary = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv4 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, ['address', 'primary'], name, value)


                                class Secondary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: secondary
                                    
                                    	Make this IPv4 address a secondary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, self).__init__()

                                        self.yang_name = "secondary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.secondary = None
                                        self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, ['address', 'secondary'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, ['leader'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 Address family
                            
                            .. attribute:: address
                            
                            	Set the IPv6 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address)), ("preempt", ("preempt", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt)), ("timers", ("timers", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers)), ("track", ("track", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track)), ("vrrs", ("vrrs", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6, ['description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv6 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary>`
                                
                                .. attribute:: ipv6_prefix
                                
                                	
                                	**type**\: list of  		 :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary)), ("ipv6-prefix", ("ipv6_prefix", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.ipv6_prefix = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipv6_link_local
                                    
                                    	IPv6 link\-local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv6 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_link_local', (YLeaf(YType.str, 'ipv6-link-local'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.ipv6_link_local = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, ['ipv6_link_local', 'primary'], name, value)


                                class Ipv6Prefix(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, self).__init__()

                                        self.yang_name = "ipv6-prefix"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                        ])
                                        self.prefix = None
                                        self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, ['prefix'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, ['leader'], name, value)


                class VrrpGroupV2(Entity):
                    """
                    vrrp version 2
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: authentication
                    
                    	
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Authentication>`
                    
                    .. attribute:: description
                    
                    	Up to 80 characters describing this group
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Ip>`
                    
                    .. attribute:: name
                    
                    	Unique VRRS identifier (max 48 characters)
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: shutdown
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: timers
                    
                    	
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Timers>`
                    
                    .. attribute:: track
                    
                    	
                    	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Track>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2, self).__init__()

                        self.yang_name = "vrrp-group-v2"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Authentication)), ("ip", ("ip", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Ip)), ("preempt", ("preempt", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Preempt)), ("timers", ("timers", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Timers)), ("track", ("track", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Track))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.group_id = None
                        self.description = None
                        self.name = None
                        self.priority = None
                        self.shutdown = None

                        self.authentication = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.timers = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Track()
                        self.track.parent = self
                        self._children_name_map["track"] = "track"
                        self._segment_path = lambda: "vrrp-group-v2" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2, ['group_id', 'description', 'name', 'priority', 'shutdown'], name, value)


                    class Authentication(Entity):
                        """
                        
                        
                        .. attribute:: text
                        
                        	authentication string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.text = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Authentication, ['text'], name, value)


                    class Ip(Entity):
                        """
                        
                        
                        .. attribute:: vrrp_ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`VrrpIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrrp-ipv4", ("vrrp_ipv4", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4))])
                            self._leafs = OrderedDict()

                            self.vrrp_ipv4 = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Ip, [], name, value)


                        class VrrpIpv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, self).__init__()

                                self.yang_name = "vrrp-ipv4"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.ipv4 = None
                                self.secondary = None
                                self._segment_path = lambda: "vrrp-ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, ['ipv4', 'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        
                        
                        .. attribute:: delay
                        
                        	
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            
                            
                            .. attribute:: minimum
                            
                            	Seconds to delay
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                ])
                                self.minimum = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay, ['minimum'], name, value)


                    class Timers(Entity):
                        """
                        
                        
                        .. attribute:: advertise
                        
                        	
                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise>`
                        
                        .. attribute:: learn
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise))])
                            self._leafs = OrderedDict([
                                ('learn', (YLeaf(YType.empty, 'learn'), ['Empty'])),
                            ])
                            self.learn = None

                            self.advertise = Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise()
                            self.advertise.parent = self
                            self._children_name_map["advertise"] = "advertise"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Timers, ['learn'], name, value)


                        class Advertise(Entity):
                            """
                            
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Advertisement interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..999
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise, self).__init__()

                                self.yang_name = "advertise"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint8, 'interval'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.interval = None
                                self.msec = None
                                self._segment_path = lambda: "advertise"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise, ['interval', 'msec'], name, value)


                    class Track(Entity):
                        """
                        
                        
                        .. attribute:: event
                        
                        	
                        	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("event", ("event", Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event))])
                            self._leafs = OrderedDict()

                            self.event = YList(self)
                            self._segment_path = lambda: "track"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Track, [], name, value)


                        class Event(Entity):
                            """
                            
                            
                            .. attribute:: object_id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: decrement
                            
                            	Decrement value
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event, self).__init__()

                                self.yang_name = "event"
                                self.yang_parent_name = "track"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['object_id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                    ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ])
                                self.object_id = None
                                self.decrement = None
                                self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event, ['object_id', 'decrement'], name, value)


                class Delay(Entity):
                    """
                    
                    
                    .. attribute:: reload
                    
                    	Seconds to delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: minimum
                    
                    	Seconds to delay after interface up
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Vrrp.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                        ])
                        self.reload = None
                        self.minimum = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Vrrp.Delay, ['reload', 'minimum'], name, value)


            class Ospfv3(Entity):
                """
                OSPFv3 interface commands
                
                .. attribute:: process_id
                
                	
                	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId>`
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication>`
                
                .. attribute:: bfd
                
                	Enable BFD on this interface
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: cost
                
                	Route cost of this interface
                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Cost>`
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: demand_circuit
                
                	OSPF Demand Circuit
                	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.DemandCircuit>`
                
                	**presence node**\: True
                
                .. attribute:: encryption
                
                	Enable encryption
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption>`
                
                .. attribute:: flood_reduction
                
                	OSPF Flood Reduction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: manet
                
                	Mobile Adhoc Networking options
                	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Manet>`
                
                .. attribute:: mtu_ignore
                
                	Ignores the MTU in DBD packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: multi_area
                
                	Set the OSPF multi\-area ID
                	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.MultiArea>`
                
                .. attribute:: neighbor
                
                	OSPF neighbor
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Neighbor>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Network>`
                
                .. attribute:: prefix_suppression
                
                	OSPF prefix suppression
                	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.PrefixSuppression>`
                
                	**presence node**\: True
                
                .. attribute:: priority
                
                	Router priority
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: retransmit_interval
                
                	Time between retransmitting lost link state advertisements
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Shut down the interface in OSPFv3
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transmit_delay
                
                	Link state transmit delay
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Ospfv3, self).__init__()

                    self.yang_name = "ospfv3"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId)), ("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication)), ("bfd", ("bfd", Native.Interface.FiveGigabitEthernet.Ospfv3.Bfd)), ("cost", ("cost", Native.Interface.FiveGigabitEthernet.Ospfv3.Cost)), ("database-filter", ("database_filter", Native.Interface.FiveGigabitEthernet.Ospfv3.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FiveGigabitEthernet.Ospfv3.DemandCircuit)), ("encryption", ("encryption", Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption)), ("manet", ("manet", Native.Interface.FiveGigabitEthernet.Ospfv3.Manet)), ("multi-area", ("multi_area", Native.Interface.FiveGigabitEthernet.Ospfv3.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FiveGigabitEthernet.Ospfv3.Neighbor)), ("network", ("network", Native.Interface.FiveGigabitEthernet.Ospfv3.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FiveGigabitEthernet.Ospfv3.PrefixSuppression))])
                    self._leafs = OrderedDict([
                        ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                        ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                        ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                    ])
                    self.dead_interval = None
                    self.flood_reduction = None
                    self.hello_interval = None
                    self.mtu_ignore = None
                    self.priority = None
                    self.retransmit_interval = None
                    self.shutdown = None
                    self.transmit_delay = None

                    self.authentication = Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"

                    self.cost = Native.Interface.FiveGigabitEthernet.Ospfv3.Cost()
                    self.cost.parent = self
                    self._children_name_map["cost"] = "cost"

                    self.database_filter = Native.Interface.FiveGigabitEthernet.Ospfv3.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"

                    self.demand_circuit = None
                    self._children_name_map["demand_circuit"] = "demand-circuit"

                    self.encryption = Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.manet = Native.Interface.FiveGigabitEthernet.Ospfv3.Manet()
                    self.manet.parent = self
                    self._children_name_map["manet"] = "manet"

                    self.multi_area = Native.Interface.FiveGigabitEthernet.Ospfv3.MultiArea()
                    self.multi_area.parent = self
                    self._children_name_map["multi_area"] = "multi-area"

                    self.network = Native.Interface.FiveGigabitEthernet.Ospfv3.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.prefix_suppression = None
                    self._children_name_map["prefix_suppression"] = "prefix-suppression"

                    self.process_id = YList(self)
                    self.neighbor = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3, ['dead_interval', u'flood_reduction', 'hello_interval', u'mtu_ignore', 'priority', 'retransmit_interval', u'shutdown', 'transmit_delay'], name, value)


                class ProcessId(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: manet
                    
                    	Mobile Adhoc Networking options
                    	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.MultiArea>`
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Network>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipv4
                    
                    	Specify parameters for IPv4
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Specify parameters for IPv6
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId, self).__init__()

                        self.yang_name = "process-id"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Authentication)), ("bfd", ("bfd", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Bfd)), ("cost", ("cost", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost)), ("database-filter", ("database_filter", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.FloodReduction)), ("manet", ("manet", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Neighbor)), ("network", ("network", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Shutdown)), ("ipv4", ("ipv4", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4)), ("ipv6", ("ipv6", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.id = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.cost = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.database_filter = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.manet = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet()
                        self.manet.parent = self
                        self._children_name_map["manet"] = "manet"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.multi_area = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.network = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.ipv4 = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId, [u'id', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\: str
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.null = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Authentication, [u'key_chain', u'null'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Bfd, ['disable'], name, value)


                    class Cost(Entity):
                        """
                        Route cost of this interface
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dynamic
                        
                        	Specify dynamic cost options
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.dynamic = None
                            self._children_name_map["dynamic"] = "dynamic"
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost, [u'value'], name, value)


                        class Dynamic(Entity):
                            """
                            Specify dynamic cost options
                            
                            .. attribute:: default
                            
                            	Specify default link metric value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: hysteresis
                            
                            	Specify hysteresis value for LSA dampening
                            	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: weight
                            
                            	Specify weight to be placed on individual metrics
                            	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ])
                                self.default = None

                                self.hysteresis = None
                                self._children_name_map["hysteresis"] = "hysteresis"

                                self.weight = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight()
                                self.weight.parent = self
                                self._children_name_map["weight"] = "weight"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic, [u'default'], name, value)


                            class Hysteresis(Entity):
                                """
                                Specify hysteresis value for LSA dampening
                                
                                .. attribute:: percent
                                
                                	Specify hysteresis percent changed
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold
                                
                                	Specify hysteresis threshold value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, self).__init__()

                                    self.yang_name = "hysteresis"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "hysteresis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                            class Weight(Entity):
                                """
                                Specify weight to be placed on individual metrics
                                
                                .. attribute:: l2_factor
                                
                                	Specify weight to be given to L2\-factor metric
                                	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: latency
                                
                                	Specify weight to be given to latency metric
                                	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: resources
                                
                                	Specify weight to be given to resources metric
                                	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: throughput
                                
                                	Specify weight to be given to throughput metric
                                	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, self).__init__()

                                    self.yang_name = "weight"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput))])
                                    self._leafs = OrderedDict()

                                    self.l2_factor = None
                                    self._children_name_map["l2_factor"] = "L2-factor"

                                    self.latency = None
                                    self._children_name_map["latency"] = "latency"

                                    self.resources = None
                                    self._children_name_map["resources"] = "resources"

                                    self.throughput = None
                                    self._children_name_map["throughput"] = "throughput"
                                    self._segment_path = lambda: "weight"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, [], name, value)


                                class L2Factor(Entity):
                                    """
                                    Specify weight to be given to L2\-factor metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                        self.yang_name = "L2-factor"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "L2-factor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                class Latency(Entity):
                                    """
                                    Specify weight to be given to latency metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, self).__init__()

                                        self.yang_name = "latency"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "latency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                class Resources(Entity):
                                    """
                                    Specify weight to be given to resources metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, self).__init__()

                                        self.yang_name = "resources"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "resources"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                class Throughput(Entity):
                                    """
                                    Specify weight to be given to throughput metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, self).__init__()

                                        self.yang_name = "throughput"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "throughput"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter, [u'all', u'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.DemandCircuit, [u'disable', u'ignore'], name, value)


                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.FloodReduction, [u'disable'], name, value)


                    class Manet(Entity):
                        """
                        Mobile Adhoc Networking options
                        
                        .. attribute:: peering
                        
                        	MANET Peering options
                        	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet.Peering>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet, self).__init__()

                            self.yang_name = "manet"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet.Peering))])
                            self._leafs = OrderedDict()

                            self.peering = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet.Peering()
                            self.peering.parent = self
                            self._children_name_map["peering"] = "peering"
                            self._segment_path = lambda: "manet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet, [], name, value)


                        class Peering(Entity):
                            """
                            MANET Peering options
                            
                            .. attribute:: cost
                            
                            	Redundant path cost improvement required to peer
                            	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost>`
                            
                            .. attribute:: link_metrics
                            
                            	Require link metrics
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet.Peering, self).__init__()

                                self.yang_name = "peering"
                                self.yang_parent_name = "manet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost))])
                                self._leafs = OrderedDict([
                                    ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                ])
                                self.link_metrics = None

                                self.cost = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost()
                                self.cost.parent = self
                                self._children_name_map["cost"] = "cost"
                                self._segment_path = lambda: "peering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet.Peering, [u'link_metrics'], name, value)


                            class Cost(Entity):
                                """
                                Redundant path cost improvement required to peer
                                
                                .. attribute:: percent
                                
                                	Relative incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                .. attribute:: threshold
                                
                                	Absolute incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, self).__init__()

                                    self.yang_name = "cost"
                                    self.yang_parent_name = "peering"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "cost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.MtuIgnore, [u'disable'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: disable
                        
                        	disable OSPF multi\-area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.disable = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.MultiArea, [u'id', u'cost', u'disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression, ['disable'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Shutdown, [u'disable'], name, value)


                    class Ipv4(Entity):
                        """
                        Specify parameters for IPv4
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area)), ("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication)), ("bfd", ("bfd", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd)), ("cost", ("cost", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost)), ("database-filter", ("database_filter", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction)), ("manet", ("manet", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor)), ("network", ("network", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 64..95
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, [u'disable'], name, value)


                    class Ipv6(Entity):
                        """
                        Specify parameters for IPv6
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area)), ("authentication", ("authentication", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication)), ("bfd", ("bfd", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd)), ("cost", ("cost", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost)), ("database-filter", ("database_filter", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction)), ("manet", ("manet", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor)), ("network", ("network", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 0..31
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, [u'disable'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: key_chain
                    
                    	Use a key\-chain for cryptographic authentication keys
                    	**type**\: str
                    
                    .. attribute:: null
                    
                    	Use no authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec authentication
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.null = None

                        self.ipsec = Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication, [u'key_chain', u'null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec authentication
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 256..4294967295
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5>`
                        
                        .. attribute:: sha1
                        
                        	Use SHA\-1 authentication
                        	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                            ])
                            self.spi = None

                            self.md5 = Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"

                            self.sha1 = Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1()
                            self.sha1.parent = self
                            self._children_name_map["sha1"] = "sha1"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec, ['spi'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class Sha1(Entity):
                            """
                            Use SHA\-1 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1, self).__init__()

                                self.yang_name = "sha1"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "sha1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "sha1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                class Bfd(Entity):
                    """
                    Enable BFD on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BFD on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Bfd, ['disable'], name, value)


                class Cost(Entity):
                    """
                    Route cost of this interface
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: dynamic
                    
                    	Specify dynamic cost options
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost, self).__init__()

                        self.yang_name = "cost"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.dynamic = None
                        self._children_name_map["dynamic"] = "dynamic"
                        self._segment_path = lambda: "cost"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost, [u'value'], name, value)


                    class Dynamic(Entity):
                        """
                        Specify dynamic cost options
                        
                        .. attribute:: default
                        
                        	Specify default link metric value
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hysteresis
                        
                        	Specify hysteresis value for LSA dampening
                        	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: weight
                        
                        	Specify weight to be placed on individual metrics
                        	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic, self).__init__()

                            self.yang_name = "dynamic"
                            self.yang_parent_name = "cost"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                            ])
                            self.default = None

                            self.hysteresis = None
                            self._children_name_map["hysteresis"] = "hysteresis"

                            self.weight = Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight()
                            self.weight.parent = self
                            self._children_name_map["weight"] = "weight"
                            self._segment_path = lambda: "dynamic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic, [u'default'], name, value)


                        class Hysteresis(Entity):
                            """
                            Specify hysteresis value for LSA dampening
                            
                            .. attribute:: percent
                            
                            	Specify hysteresis percent changed
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold
                            
                            	Specify hysteresis threshold value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis, self).__init__()

                                self.yang_name = "hysteresis"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "hysteresis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                        class Weight(Entity):
                            """
                            Specify weight to be placed on individual metrics
                            
                            .. attribute:: l2_factor
                            
                            	Specify weight to be given to L2\-factor metric
                            	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: latency
                            
                            	Specify weight to be given to latency metric
                            	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: resources
                            
                            	Specify weight to be given to resources metric
                            	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: throughput
                            
                            	Specify weight to be given to throughput metric
                            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight, self).__init__()

                                self.yang_name = "weight"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput))])
                                self._leafs = OrderedDict()

                                self.l2_factor = None
                                self._children_name_map["l2_factor"] = "L2-factor"

                                self.latency = None
                                self._children_name_map["latency"] = "latency"

                                self.resources = None
                                self._children_name_map["resources"] = "resources"

                                self.throughput = None
                                self._children_name_map["throughput"] = "throughput"
                                self._segment_path = lambda: "weight"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight, [], name, value)


                            class L2Factor(Entity):
                                """
                                Specify weight to be given to L2\-factor metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                    self.yang_name = "L2-factor"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "L2-factor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                            class Latency(Entity):
                                """
                                Specify weight to be given to latency metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, self).__init__()

                                    self.yang_name = "latency"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "latency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                            class Resources(Entity):
                                """
                                Specify weight to be given to resources metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, self).__init__()

                                    self.yang_name = "resources"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "resources"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                            class Throughput(Entity):
                                """
                                Specify weight to be given to throughput metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, self).__init__()

                                    self.yang_name = "throughput"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "throughput"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.DatabaseFilter.All')])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.DatabaseFilter, [u'all'], name, value)

                    class All(Enum):
                        """
                        All (Enum Class)

                        Filter all LSA

                        .. data:: out = 0

                        """

                        out = Enum.YLeaf(0, "out")



                class DemandCircuit(Entity):
                    """
                    OSPF Demand Circuit
                    
                    .. attribute:: ignore
                    
                    	Ignore demand circuit auto\-negotiation requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.DemandCircuit, self).__init__()

                        self.yang_name = "demand-circuit"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.ignore = None
                        self._segment_path = lambda: "demand-circuit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.DemandCircuit, [u'ignore'], name, value)


                class Encryption(Entity):
                    """
                    Enable encryption
                    
                    .. attribute:: null
                    
                    	No IPsec encryption on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec encryption
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec))])
                        self._leafs = OrderedDict([
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.null = None

                        self.ipsec = Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption, ['null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec encryption
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: esp
                        
                        	Use ESP encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec_3des
                        
                        	Use 3DES encryption
                        	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des>`
                        
                        .. attribute:: aes_cbc
                        
                        	Use AES\-CBC encryption
                        	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                            ])
                            self.spi = None
                            self.esp = None

                            self.ipsec_3des = Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des()
                            self.ipsec_3des.parent = self
                            self._children_name_map["ipsec_3des"] = "ipsec_3des"

                            self.aes_cbc = Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc()
                            self.aes_cbc.parent = self
                            self._children_name_map["aes_cbc"] = "aes-cbc"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec, ['spi', 'esp'], name, value)


                        class Ipsec3des(Entity):
                            """
                            Use 3DES encryption
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, self).__init__()

                                self.yang_name = "ipsec_3des"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "ipsec_3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "ipsec_3des"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class AesCbc(Entity):
                            """
                            Use AES\-CBC encryption
                            
                            .. attribute:: aes_cbc_128
                            
                            	Use 128 bit key
                            	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128>`
                            
                            .. attribute:: aes_192
                            
                            	Use 192 bit key
                            	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192>`
                            
                            .. attribute:: aes_256
                            
                            	Use 256 bit key
                            	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc, self).__init__()

                                self.yang_name = "aes-cbc"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256))])
                                self._leafs = OrderedDict()

                                self.aes_cbc_128 = Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128()
                                self.aes_cbc_128.parent = self
                                self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                self.aes_192 = Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192()
                                self.aes_192.parent = self
                                self._children_name_map["aes_192"] = "aes-192"

                                self.aes_256 = Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256()
                                self.aes_256.parent = self
                                self._children_name_map["aes_256"] = "aes-256"
                                self._segment_path = lambda: "aes-cbc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc, [], name, value)


                            class AesCbc128(Entity):
                                """
                                Use 128 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                    self.yang_name = "aes-cbc-128"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-cbc-128"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-cbc-128"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes192(Entity):
                                """
                                Use 192 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                    self.yang_name = "aes-192"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-192"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-192"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes256(Entity):
                                """
                                Use 256 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                    self.yang_name = "aes-256"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-256"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-256"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                class Manet(Entity):
                    """
                    Mobile Adhoc Networking options
                    
                    .. attribute:: peering
                    
                    	MANET Peering options
                    	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Manet.Peering>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.Manet, self).__init__()

                        self.yang_name = "manet"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FiveGigabitEthernet.Ospfv3.Manet.Peering))])
                        self._leafs = OrderedDict()

                        self.peering = Native.Interface.FiveGigabitEthernet.Ospfv3.Manet.Peering()
                        self.peering.parent = self
                        self._children_name_map["peering"] = "peering"
                        self._segment_path = lambda: "manet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Manet, [], name, value)


                    class Peering(Entity):
                        """
                        MANET Peering options
                        
                        .. attribute:: cost
                        
                        	Redundant path cost improvement required to peer
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Manet.Peering.Cost>`
                        
                        .. attribute:: link_metrics
                        
                        	Require link metrics
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.Manet.Peering, self).__init__()

                            self.yang_name = "peering"
                            self.yang_parent_name = "manet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FiveGigabitEthernet.Ospfv3.Manet.Peering.Cost))])
                            self._leafs = OrderedDict([
                                ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                            ])
                            self.link_metrics = None

                            self.cost = Native.Interface.FiveGigabitEthernet.Ospfv3.Manet.Peering.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"
                            self._segment_path = lambda: "peering"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Manet.Peering, [u'link_metrics'], name, value)


                        class Cost(Entity):
                            """
                            Redundant path cost improvement required to peer
                            
                            .. attribute:: percent
                            
                            	Relative incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: threshold
                            
                            	Absolute incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Ospfv3.Manet.Peering.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "peering"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                class MultiArea(Entity):
                    """
                    Set the OSPF multi\-area ID
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.MultiArea, self).__init__()

                        self.yang_name = "multi-area"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self._segment_path = lambda: "multi-area"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.MultiArea, [u'id', u'cost'], name, value)


                class Neighbor(Entity):
                    """
                    OSPF neighbor
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	OSPF cost for point\-to\-multipoint neighbor
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter>`
                    
                    .. attribute:: poll_interval
                    
                    	OSPF dead\-router polling interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: priority
                    
                    	OSPF priority of non\-broadcast neighbor
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FiveGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self.poll_interval = None
                        self.priority = None

                        self.database_filter = Native.Interface.FiveGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter.All')])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter, ['all'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                class Network(Entity):
                    """
                    Network type
                    
                    .. attribute:: broadcast
                    
                    	Specify OSPF broadcast multi\-access network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: manet
                    
                    	Specify MANET OSPF interface type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: non_broadcast
                    
                    	Specify OSPF NBMA network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: point_to_multipoint
                    
                    	Specify OSPF point\-to\-multipoint network
                    	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Ospfv3.Network.PointToMultipoint>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: point_to_point
                    
                    	Specify OSPF point\-to\-point network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FiveGigabitEthernet.Ospfv3.Network.PointToMultipoint))])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                            ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                        ])
                        self.broadcast = None
                        self.manet = None
                        self.non_broadcast = None
                        self.point_to_point = None

                        self.point_to_multipoint = None
                        self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                    class PointToMultipoint(Entity):
                        """
                        Specify OSPF point\-to\-multipoint network
                        
                        .. attribute:: non_broadcast
                        
                        	Specify non\-broadcast point\-to\-mpoint network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Ospfv3.Network.PointToMultipoint, self).__init__()

                            self.yang_name = "point-to-multipoint"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ])
                            self.non_broadcast = None
                            self._segment_path = lambda: "point-to-multipoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.Network.PointToMultipoint, ['non_broadcast'], name, value)


                class PrefixSuppression(Entity):
                    """
                    OSPF prefix suppression
                    
                    .. attribute:: disable
                    
                    	Disable prefix suppression
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Ospfv3.PrefixSuppression, self).__init__()

                        self.yang_name = "prefix-suppression"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "prefix-suppression"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Ospfv3.PrefixSuppression, ['disable'], name, value)


            class Udld(Entity):
                """
                Configure UDLD enabled or disabled and ignore global UDLD setting
                
                .. attribute:: port
                
                	Enable UDLD protocol on this interface despite global UDLD setting
                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Udld.Port>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-udld'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Udld, self).__init__()

                    self.yang_name = "udld"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.FiveGigabitEthernet.Udld.Port))])
                    self._leafs = OrderedDict()

                    self.port = None
                    self._children_name_map["port"] = "port"
                    self._segment_path = lambda: "Cisco-IOS-XE-udld:udld"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Udld, [], name, value)


                class Port(Entity):
                    """
                    Enable UDLD protocol on this interface despite global UDLD setting
                    
                    .. attribute:: aggressive
                    
                    	Enable UDLD protocol in aggressive mode on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	Disable UDLD protocol on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-udld'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Udld.Port, self).__init__()

                        self.yang_name = "port"
                        self.yang_parent_name = "udld"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aggressive', (YLeaf(YType.empty, 'aggressive'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.aggressive = None
                        self.disable = None
                        self._segment_path = lambda: "port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Udld.Port, ['aggressive', 'disable'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.Manual>`
                
                	**presence node**\: True
                
                .. attribute:: role_based
                
                	Role\-based Access Control per\-port config commands
                	**type**\:  :py:class:`RoleBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.RoleBased>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.FiveGigabitEthernet.Cts.Manual)), ("role-based", ("role_based", Native.Interface.FiveGigabitEthernet.Cts.RoleBased))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"

                    self.role_based = Native.Interface.FiveGigabitEthernet.Cts.RoleBased()
                    self.role_based.parent = self
                    self._children_name_map["role_based"] = "role-based"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.FiveGigabitEthernet.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.FiveGigabitEthernet.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.FiveGigabitEthernet.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.FiveGigabitEthernet.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.FiveGigabitEthernet.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.FiveGigabitEthernet.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.Manual.Propagate, ['sgt'], name, value)


                class RoleBased(Entity):
                    """
                    Role\-based Access Control per\-port config commands
                    
                    .. attribute:: sgt_cache
                    
                    	Enable SGT caching on the interface
                    	**type**\: list of   :py:class:`SgtCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.RoleBased.SgtCache>`
                    
                    .. attribute:: enforcement
                    
                    	Enable Role\-based Access Control enforcement
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sgt_map
                    
                    	Assign Security Group Tag (SGT) to IP host or network address
                    	**type**\:  :py:class:`SgtMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.Cts.RoleBased.SgtMap>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.Cts.RoleBased, self).__init__()

                        self.yang_name = "role-based"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sgt-map", ("sgt_map", Native.Interface.FiveGigabitEthernet.Cts.RoleBased.SgtMap))])
                        self._leafs = OrderedDict([
                            ('sgt_cache', (YLeafList(YType.enumeration, 'sgt-cache'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FiveGigabitEthernet.Cts.RoleBased.SgtCache')])),
                            ('enforcement', (YLeaf(YType.empty, 'enforcement'), ['Empty'])),
                        ])
                        self.sgt_cache = []
                        self.enforcement = None

                        self.sgt_map = Native.Interface.FiveGigabitEthernet.Cts.RoleBased.SgtMap()
                        self.sgt_map.parent = self
                        self._children_name_map["sgt_map"] = "sgt-map"
                        self._segment_path = lambda: "role-based"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.RoleBased, ['sgt_cache', 'enforcement'], name, value)

                    class SgtCache(Enum):
                        """
                        SgtCache (Enum Class)

                        Enable SGT caching on the interface

                        .. data:: egress = 0

                        .. data:: ingress = 1

                        """

                        egress = Enum.YLeaf(0, "egress")

                        ingress = Enum.YLeaf(1, "ingress")



                    class SgtMap(Entity):
                        """
                        Assign Security Group Tag (SGT) to IP host or network address
                        
                        .. attribute:: security_group
                        
                        	Security Group Name
                        	**type**\: str
                        
                        .. attribute:: sgt
                        
                        	Security Group Tag (SGT)
                        	**type**\: int
                        
                        	**range:** 2..65519
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FiveGigabitEthernet.Cts.RoleBased.SgtMap, self).__init__()

                            self.yang_name = "sgt-map"
                            self.yang_parent_name = "role-based"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('security_group', (YLeaf(YType.str, 'security-group'), ['str'])),
                                ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                            ])
                            self.security_group = None
                            self.sgt = None
                            self._segment_path = lambda: "sgt-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FiveGigabitEthernet.Cts.RoleBased.SgtMap, ['security_group', 'sgt'], name, value)


            class AnalysisModule(Entity):
                """
                Configure NAM on the interface
                
                .. attribute:: monitoring
                
                	Configure NAM monitoring on the interface
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FiveGigabitEthernet.AnalysisModule.Monitoring>`
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Interface.FiveGigabitEthernet.AnalysisModule, self).__init__()

                    self.yang_name = "analysis-module"
                    self.yang_parent_name = "FiveGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Interface.FiveGigabitEthernet.AnalysisModule.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = Native.Interface.FiveGigabitEthernet.AnalysisModule.Monitoring()
                    self.monitoring.parent = self
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FiveGigabitEthernet.AnalysisModule, [], name, value)


                class Monitoring(Entity):
                    """
                    Configure NAM monitoring on the interface
                    
                    .. attribute:: interface_name
                    
                    	The name of the output interface.  E.g., 'ucse 1/0/0'
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nam'
                    _revision = '2017-12-28'

                    def __init__(self):
                        super(Native.Interface.FiveGigabitEthernet.AnalysisModule.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "analysis-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "monitoring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FiveGigabitEthernet.AnalysisModule.Monitoring, ['interface_name'], name, value)


        class TenGigabitEthernet(Entity):
            """
            Ten Gigabit Ethernet
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: media_type
            
            	Media type
            	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.MediaType>`
            
            .. attribute:: port_type
            
            	
            	**type**\:  :py:class:`PortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.PortType>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service>`
            
            .. attribute:: lacp
            
            	LACP interface subcommands
            	**type**\:  :py:class:`Lacp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Lacp>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec_option
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXEEthernetMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ServicePolicy>`
            
            .. attribute:: auto
            
            	Configure Automation
            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Auto>`
            
            .. attribute:: datalink
            
            	Interface Datalink commands
            	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Datalink>`
            
            .. attribute:: energywise
            
            	EnergyWise interface configurations
            	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Energywise>`
            
            	**presence node**\: True
            
            .. attribute:: location
            
            	Interface location information
            	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Location>`
            
            .. attribute:: mac
            
            	MAC interface commands
            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mac>`
            
            .. attribute:: macro
            
            	Command macro
            	**type**\:  :py:class:`Macro <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Macro>`
            
            .. attribute:: dual_active
            
            	
            	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.DualActive>`
            
            .. attribute:: load_balancing
            
            	Etherchannel Load\-Balancing
            	**type**\:  :py:class:`LoadBalancing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.LoadBalancing>`
            
            .. attribute:: vlan_range
            
            	
            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.VlanRange>`
            
            .. attribute:: switch
            
            	
            	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switch>`
            
            .. attribute:: srr_queue
            
            	
            	**type**\:  :py:class:`SrrQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SrrQueue>`
            
            .. attribute:: cisco_ios_xe_switch_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_switch_macsec_option_
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXESwitchMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption>`
            
            .. attribute:: device_tracking
            
            	Configure device\-tracking on the interface
            	**type**\:  :py:class:`DeviceTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.DeviceTracking>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Snmp>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Crypto>`
            
            .. attribute:: mka
            
            	MACsec Key Agreement (MKA) interface configuration
            	**type**\:  :py:class:`Mka <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mka>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Utd>`
            
            .. attribute:: xconnect
            
            	Xconnect commands
            	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Xconnect>`
            
            .. attribute:: evpn
            
            	
            	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Evpn>`
            
            .. attribute:: fabric_domain
            
            	Fabric\-domain interface command
            	**type**\:  :py:class:`FabricDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.FabricDomain>`
            
            .. attribute:: mvrp
            
            	
            	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mvrp>`
            
            	**presence node**\: True
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Lisp>`
            
            .. attribute:: power
            
            	
            	**type**\:  :py:class:`Power <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Power>`
            
            .. attribute:: cdp
            
            	CDP interface subcommands
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cdp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ntp>`
            
            .. attribute:: authentication
            
            	Auth Manager Interface Configuration Commands
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication>`
            
            .. attribute:: mab
            
            	
            	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mab>`
            
            	**presence node**\: True
            
            .. attribute:: dot1x
            
            	Interface Config Commands for IEEE 802.1X
            	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Dot1x>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SpanningTree>`
            
            .. attribute:: performance
            
            	Global performance monitor configuration
            	**type**\:  :py:class:`Performance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Performance>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Umbrella>`
            
            .. attribute:: lldp
            
            	LLDP interface subcommands
            	**type**\:  :py:class:`Lldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Lldp>`
            
            .. attribute:: vrrp
            
            	Configure VRRP
            	**type**\:  :py:class:`Vrrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp>`
            
            .. attribute:: nat66
            
            	NAT66 interface commands
            	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Nat66>`
            
            .. attribute:: ospfv3
            
            	OSPFv3 interface commands
            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3>`
            
            .. attribute:: udld
            
            	Configure UDLD enabled or disabled and ignore global UDLD setting
            	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Udld>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts>`
            
            .. attribute:: analysis_module
            
            	Configure NAM on the interface
            	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.AnalysisModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.TenGigabitEthernet, self).__init__()

                self.yang_name = "TenGigabitEthernet"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.TenGigabitEthernet.SwitchportConf)), ("switchport", ("switchport", Native.Interface.TenGigabitEthernet.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.TenGigabitEthernet.StackwiseVirtual)), ("arp", ("arp", Native.Interface.TenGigabitEthernet.Arp)), ("backup", ("backup", Native.Interface.TenGigabitEthernet.Backup)), ("cemoudp", ("cemoudp", Native.Interface.TenGigabitEthernet.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.TenGigabitEthernet.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.TenGigabitEthernet.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.TenGigabitEthernet.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.TenGigabitEthernet.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.TenGigabitEthernet.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.TenGigabitEthernet.Flowcontrol)), ("isis", ("isis", Native.Interface.TenGigabitEthernet.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.TenGigabitEthernet.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.TenGigabitEthernet.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.TenGigabitEthernet.Bandwidth)), ("dampening", ("dampening", Native.Interface.TenGigabitEthernet.Dampening)), ("domain", ("domain", Native.Interface.TenGigabitEthernet.Domain)), ("hold-queue", ("hold_queue", Native.Interface.TenGigabitEthernet.HoldQueue)), ("mpls", ("mpls", Native.Interface.TenGigabitEthernet.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.TenGigabitEthernet.IpVrf)), ("vrf", ("vrf", Native.Interface.TenGigabitEthernet.Vrf)), ("ip", ("ip", Native.Interface.TenGigabitEthernet.Ip)), ("ipv6", ("ipv6", Native.Interface.TenGigabitEthernet.Ipv6)), ("logging", ("logging", Native.Interface.TenGigabitEthernet.Logging)), ("mdix", ("mdix", Native.Interface.TenGigabitEthernet.Mdix)), ("mop", ("mop", Native.Interface.TenGigabitEthernet.Mop)), ("interface_qos", ("interface_qos", Native.Interface.TenGigabitEthernet.InterfaceQos)), ("source", ("source", Native.Interface.TenGigabitEthernet.Source)), ("standby", ("standby", Native.Interface.TenGigabitEthernet.Standby)), ("access-session", ("access_session", Native.Interface.TenGigabitEthernet.AccessSession)), ("storm-control", ("storm_control", Native.Interface.TenGigabitEthernet.StormControl)), ("trust", ("trust", Native.Interface.TenGigabitEthernet.Trust)), ("priority-queue", ("priority_queue", Native.Interface.TenGigabitEthernet.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.TenGigabitEthernet.RcvQueue)), ("peer", ("peer", Native.Interface.TenGigabitEthernet.Peer)), ("pm-path", ("pm_path", Native.Interface.TenGigabitEthernet.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.TenGigabitEthernet.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.TenGigabitEthernet.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.TenGigabitEthernet.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.TenGigabitEthernet.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.TenGigabitEthernet.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.TenGigabitEthernet.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.TenGigabitEthernet.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.TenGigabitEthernet.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.TenGigabitEthernet.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.TenGigabitEthernet.Service)), ("Cisco-IOS-XE-ethernet:lacp", ("lacp", Native.Interface.TenGigabitEthernet.Lacp)), ("Cisco-IOS-XE-ethernet:macsec-option", ("cisco_ios_xe_ethernet_macsec_option", Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.TenGigabitEthernet.ServicePolicy)), ("Cisco-IOS-XE-switch:auto", ("auto", Native.Interface.TenGigabitEthernet.Auto)), ("Cisco-IOS-XE-switch:datalink", ("datalink", Native.Interface.TenGigabitEthernet.Datalink)), ("Cisco-IOS-XE-switch:energywise", ("energywise", Native.Interface.TenGigabitEthernet.Energywise)), ("Cisco-IOS-XE-switch:location", ("location", Native.Interface.TenGigabitEthernet.Location)), ("Cisco-IOS-XE-switch:mac", ("mac", Native.Interface.TenGigabitEthernet.Mac)), ("Cisco-IOS-XE-switch:macro", ("macro", Native.Interface.TenGigabitEthernet.Macro)), ("Cisco-IOS-XE-switch:dual-active", ("dual_active", Native.Interface.TenGigabitEthernet.DualActive)), ("Cisco-IOS-XE-switch:load-balancing", ("load_balancing", Native.Interface.TenGigabitEthernet.LoadBalancing)), ("Cisco-IOS-XE-switch:vlan-range", ("vlan_range", Native.Interface.TenGigabitEthernet.VlanRange)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Interface.TenGigabitEthernet.Switch)), ("Cisco-IOS-XE-switch:srr-queue", ("srr_queue", Native.Interface.TenGigabitEthernet.SrrQueue)), ("Cisco-IOS-XE-switch:macsec-option", ("cisco_ios_xe_switch_macsec_option_", Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption)), ("Cisco-IOS-XE-switch:device-tracking", ("device_tracking", Native.Interface.TenGigabitEthernet.DeviceTracking)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.TenGigabitEthernet.Snmp)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.TenGigabitEthernet.Crypto)), ("Cisco-IOS-XE-mka:mka", ("mka", Native.Interface.TenGigabitEthernet.Mka)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.TenGigabitEthernet.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.TenGigabitEthernet.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.TenGigabitEthernet.Utd)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.TenGigabitEthernet.Xconnect)), ("Cisco-IOS-XE-l2vpn:evpn", ("evpn", Native.Interface.TenGigabitEthernet.Evpn)), ("Cisco-IOS-XE-iwanfabric:fabric-domain", ("fabric_domain", Native.Interface.TenGigabitEthernet.FabricDomain)), ("Cisco-IOS-XE-mvrp:mvrp", ("mvrp", Native.Interface.TenGigabitEthernet.Mvrp)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.TenGigabitEthernet.Lisp)), ("Cisco-IOS-XE-power:power", ("power", Native.Interface.TenGigabitEthernet.Power)), ("Cisco-IOS-XE-cdp:cdp", ("cdp", Native.Interface.TenGigabitEthernet.Cdp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.TenGigabitEthernet.Ntp)), ("Cisco-IOS-XE-sanet:authentication", ("authentication", Native.Interface.TenGigabitEthernet.Authentication)), ("Cisco-IOS-XE-sanet:mab", ("mab", Native.Interface.TenGigabitEthernet.Mab)), ("Cisco-IOS-XE-dot1x:dot1x", ("dot1x", Native.Interface.TenGigabitEthernet.Dot1x)), ("Cisco-IOS-XE-spanning-tree:spanning-tree", ("spanning_tree", Native.Interface.TenGigabitEthernet.SpanningTree)), ("Cisco-IOS-XE-ezpm:performance", ("performance", Native.Interface.TenGigabitEthernet.Performance)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.TenGigabitEthernet.Umbrella)), ("Cisco-IOS-XE-lldp:lldp", ("lldp", Native.Interface.TenGigabitEthernet.Lldp)), ("Cisco-IOS-XE-vrrp:vrrp", ("vrrp", Native.Interface.TenGigabitEthernet.Vrrp)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Interface.TenGigabitEthernet.Ospfv3)), ("Cisco-IOS-XE-udld:udld", ("udld", Native.Interface.TenGigabitEthernet.Udld)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.TenGigabitEthernet.Cts)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Interface.TenGigabitEthernet.AnalysisModule))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('media_type', (YLeaf(YType.enumeration, 'media-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.MediaType')])),
                    ('port_type', (YLeaf(YType.enumeration, 'port-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.PortType')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Duplex')])),
                    ('cisco_ios_xe_ethernet_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-ethernet:macsec'), ['Empty'])),
                    ('cisco_ios_xe_switch_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:macsec'), ['Empty'])),
                    ('nat66', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-nat:nat66'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Nat66')])),
                ])
                self.name = None
                self.media_type = None
                self.port_type = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None
                self.cisco_ios_xe_ethernet_macsec = None
                self.cisco_ios_xe_switch_macsec = None
                self.nat66 = None

                self.switchport_conf = Native.Interface.TenGigabitEthernet.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.TenGigabitEthernet.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.TenGigabitEthernet.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.TenGigabitEthernet.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.TenGigabitEthernet.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.TenGigabitEthernet.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.TenGigabitEthernet.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.TenGigabitEthernet.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.TenGigabitEthernet.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.TenGigabitEthernet.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.TenGigabitEthernet.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.TenGigabitEthernet.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.TenGigabitEthernet.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.TenGigabitEthernet.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.TenGigabitEthernet.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.TenGigabitEthernet.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.TenGigabitEthernet.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.TenGigabitEthernet.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.TenGigabitEthernet.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.TenGigabitEthernet.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.TenGigabitEthernet.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.TenGigabitEthernet.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.TenGigabitEthernet.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.TenGigabitEthernet.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.TenGigabitEthernet.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.TenGigabitEthernet.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.TenGigabitEthernet.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.TenGigabitEthernet.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.TenGigabitEthernet.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.TenGigabitEthernet.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.TenGigabitEthernet.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.TenGigabitEthernet.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.TenGigabitEthernet.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.TenGigabitEthernet.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.TenGigabitEthernet.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.TenGigabitEthernet.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.TenGigabitEthernet.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.TenGigabitEthernet.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.TenGigabitEthernet.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.TenGigabitEthernet.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.TenGigabitEthernet.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.TenGigabitEthernet.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.TenGigabitEthernet.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.TenGigabitEthernet.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.TenGigabitEthernet.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.lacp = Native.Interface.TenGigabitEthernet.Lacp()
                self.lacp.parent = self
                self._children_name_map["lacp"] = "Cisco-IOS-XE-ethernet:lacp"

                self.cisco_ios_xe_ethernet_macsec_option = Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption()
                self.cisco_ios_xe_ethernet_macsec_option.parent = self
                self._children_name_map["cisco_ios_xe_ethernet_macsec_option"] = "Cisco-IOS-XE-ethernet:macsec-option"

                self.service_policy = Native.Interface.TenGigabitEthernet.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.auto = Native.Interface.TenGigabitEthernet.Auto()
                self.auto.parent = self
                self._children_name_map["auto"] = "Cisco-IOS-XE-switch:auto"

                self.datalink = Native.Interface.TenGigabitEthernet.Datalink()
                self.datalink.parent = self
                self._children_name_map["datalink"] = "Cisco-IOS-XE-switch:datalink"

                self.energywise = None
                self._children_name_map["energywise"] = "Cisco-IOS-XE-switch:energywise"

                self.location = Native.Interface.TenGigabitEthernet.Location()
                self.location.parent = self
                self._children_name_map["location"] = "Cisco-IOS-XE-switch:location"

                self.mac = Native.Interface.TenGigabitEthernet.Mac()
                self.mac.parent = self
                self._children_name_map["mac"] = "Cisco-IOS-XE-switch:mac"

                self.macro = Native.Interface.TenGigabitEthernet.Macro()
                self.macro.parent = self
                self._children_name_map["macro"] = "Cisco-IOS-XE-switch:macro"

                self.dual_active = Native.Interface.TenGigabitEthernet.DualActive()
                self.dual_active.parent = self
                self._children_name_map["dual_active"] = "Cisco-IOS-XE-switch:dual-active"

                self.load_balancing = Native.Interface.TenGigabitEthernet.LoadBalancing()
                self.load_balancing.parent = self
                self._children_name_map["load_balancing"] = "Cisco-IOS-XE-switch:load-balancing"

                self.switch = Native.Interface.TenGigabitEthernet.Switch()
                self.switch.parent = self
                self._children_name_map["switch"] = "Cisco-IOS-XE-switch:switch"

                self.srr_queue = Native.Interface.TenGigabitEthernet.SrrQueue()
                self.srr_queue.parent = self
                self._children_name_map["srr_queue"] = "Cisco-IOS-XE-switch:srr-queue"

                self.cisco_ios_xe_switch_macsec_option_ = Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption()
                self.cisco_ios_xe_switch_macsec_option_.parent = self
                self._children_name_map["cisco_ios_xe_switch_macsec_option_"] = "Cisco-IOS-XE-switch:macsec-option"

                self.device_tracking = Native.Interface.TenGigabitEthernet.DeviceTracking()
                self.device_tracking.parent = self
                self._children_name_map["device_tracking"] = "Cisco-IOS-XE-switch:device-tracking"

                self.snmp = Native.Interface.TenGigabitEthernet.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.crypto = Native.Interface.TenGigabitEthernet.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.mka = Native.Interface.TenGigabitEthernet.Mka()
                self.mka.parent = self
                self._children_name_map["mka"] = "Cisco-IOS-XE-mka:mka"

                self.et_analytics = Native.Interface.TenGigabitEthernet.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.TenGigabitEthernet.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.TenGigabitEthernet.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.xconnect = Native.Interface.TenGigabitEthernet.Xconnect()
                self.xconnect.parent = self
                self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                self.evpn = Native.Interface.TenGigabitEthernet.Evpn()
                self.evpn.parent = self
                self._children_name_map["evpn"] = "Cisco-IOS-XE-l2vpn:evpn"

                self.fabric_domain = Native.Interface.TenGigabitEthernet.FabricDomain()
                self.fabric_domain.parent = self
                self._children_name_map["fabric_domain"] = "Cisco-IOS-XE-iwanfabric:fabric-domain"

                self.mvrp = None
                self._children_name_map["mvrp"] = "Cisco-IOS-XE-mvrp:mvrp"

                self.lisp = Native.Interface.TenGigabitEthernet.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.power = Native.Interface.TenGigabitEthernet.Power()
                self.power.parent = self
                self._children_name_map["power"] = "Cisco-IOS-XE-power:power"

                self.cdp = Native.Interface.TenGigabitEthernet.Cdp()
                self.cdp.parent = self
                self._children_name_map["cdp"] = "Cisco-IOS-XE-cdp:cdp"

                self.ntp = Native.Interface.TenGigabitEthernet.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.authentication = Native.Interface.TenGigabitEthernet.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "Cisco-IOS-XE-sanet:authentication"

                self.mab = None
                self._children_name_map["mab"] = "Cisco-IOS-XE-sanet:mab"

                self.dot1x = Native.Interface.TenGigabitEthernet.Dot1x()
                self.dot1x.parent = self
                self._children_name_map["dot1x"] = "Cisco-IOS-XE-dot1x:dot1x"

                self.spanning_tree = Native.Interface.TenGigabitEthernet.SpanningTree()
                self.spanning_tree.parent = self
                self._children_name_map["spanning_tree"] = "Cisco-IOS-XE-spanning-tree:spanning-tree"

                self.performance = Native.Interface.TenGigabitEthernet.Performance()
                self.performance.parent = self
                self._children_name_map["performance"] = "Cisco-IOS-XE-ezpm:performance"

                self.umbrella = Native.Interface.TenGigabitEthernet.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.lldp = Native.Interface.TenGigabitEthernet.Lldp()
                self.lldp.parent = self
                self._children_name_map["lldp"] = "Cisco-IOS-XE-lldp:lldp"

                self.vrrp = Native.Interface.TenGigabitEthernet.Vrrp()
                self.vrrp.parent = self
                self._children_name_map["vrrp"] = "Cisco-IOS-XE-vrrp:vrrp"

                self.ospfv3 = Native.Interface.TenGigabitEthernet.Ospfv3()
                self.ospfv3.parent = self
                self._children_name_map["ospfv3"] = "Cisco-IOS-XE-ospfv3:ospfv3"

                self.udld = Native.Interface.TenGigabitEthernet.Udld()
                self.udld.parent = self
                self._children_name_map["udld"] = "Cisco-IOS-XE-udld:udld"

                self.cts = Native.Interface.TenGigabitEthernet.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.analysis_module = Native.Interface.TenGigabitEthernet.AnalysisModule()
                self.analysis_module.parent = self
                self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"

                self.hold_queue = YList(self)
                self.vlan_range = YList(self)
                self._segment_path = lambda: "TenGigabitEthernet" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.TenGigabitEthernet, [u'name', u'media_type', u'port_type', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex', 'cisco_ios_xe_ethernet_macsec', u'cisco_ios_xe_switch_macsec', 'nat66'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class MediaType(Enum):
                """
                MediaType (Enum Class)

                Media type

                .. data:: auto_select = 0

                .. data:: rj45 = 1

                .. data:: sfp = 2

                """

                auto_select = Enum.YLeaf(0, "auto-select")

                rj45 = Enum.YLeaf(1, "rj45")

                sfp = Enum.YLeaf(2, "sfp")


            class Nat66(Enum):
                """
                Nat66 (Enum Class)

                NAT66 interface commands

                .. data:: inside = 0

                .. data:: outside = 1

                """

                inside = Enum.YLeaf(0, "inside")

                outside = Enum.YLeaf(1, "outside")


            class PortType(Enum):
                """
                PortType (Enum Class)

                .. data:: nni = 0

                """

                nni = Enum.YLeaf(0, "nni")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Access>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Block>`
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: trunk
                
                	Set trunking characteristics of the interface
                	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Trunk>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Voice>`
                
                .. attribute:: priority
                
                	Set appliance 802.1p priority
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Priority>`
                
                .. attribute:: autostate
                
                	Include or exclude this port from vlan link up calculation
                	**type**\:  :py:class:`Autostate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Autostate>`
                
                .. attribute:: protected
                
                	Configure an interface to be a protected port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Set port host
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: private_vlan
                
                	Set the private VLAN configuration
                	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan>`
                
                .. attribute:: vepa
                
                	Reflective relay configuration
                	**type**\:  :py:class:`Vepa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Vepa>`
                
                .. attribute:: device_tracking
                
                	Configure device\-tracking on the interface
                	**type**\:  :py:class:`DeviceTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.DeviceTracking>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:access", ("access", Native.Interface.TenGigabitEthernet.Switchport.Access)), ("Cisco-IOS-XE-switch:block", ("block", Native.Interface.TenGigabitEthernet.Switchport.Block)), ("Cisco-IOS-XE-switch:mode", ("mode", Native.Interface.TenGigabitEthernet.Switchport.Mode)), ("Cisco-IOS-XE-switch:port-security", ("port_security", Native.Interface.TenGigabitEthernet.Switchport.PortSecurity)), ("Cisco-IOS-XE-switch:trunk", ("trunk", Native.Interface.TenGigabitEthernet.Switchport.Trunk)), ("Cisco-IOS-XE-switch:voice", ("voice", Native.Interface.TenGigabitEthernet.Switchport.Voice)), ("Cisco-IOS-XE-switch:priority", ("priority", Native.Interface.TenGigabitEthernet.Switchport.Priority)), ("Cisco-IOS-XE-switch:autostate", ("autostate", Native.Interface.TenGigabitEthernet.Switchport.Autostate)), ("Cisco-IOS-XE-switch:private-vlan", ("private_vlan", Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan)), ("Cisco-IOS-XE-switch:vepa", ("vepa", Native.Interface.TenGigabitEthernet.Switchport.Vepa)), ("Cisco-IOS-XE-switch:device-tracking", ("device_tracking", Native.Interface.TenGigabitEthernet.Switchport.DeviceTracking))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:nonegotiate'), ['Empty'])),
                        ('protected', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:protected'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:host'), ['Empty'])),
                    ])
                    self.nonegotiate = None
                    self.protected = None
                    self.host = None

                    self.access = Native.Interface.TenGigabitEthernet.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "Cisco-IOS-XE-switch:access"

                    self.block = Native.Interface.TenGigabitEthernet.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "Cisco-IOS-XE-switch:block"

                    self.mode = Native.Interface.TenGigabitEthernet.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "Cisco-IOS-XE-switch:mode"

                    self.port_security = None
                    self._children_name_map["port_security"] = "Cisco-IOS-XE-switch:port-security"

                    self.trunk = Native.Interface.TenGigabitEthernet.Switchport.Trunk()
                    self.trunk.parent = self
                    self._children_name_map["trunk"] = "Cisco-IOS-XE-switch:trunk"

                    self.voice = Native.Interface.TenGigabitEthernet.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "Cisco-IOS-XE-switch:voice"

                    self.priority = Native.Interface.TenGigabitEthernet.Switchport.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-switch:priority"

                    self.autostate = Native.Interface.TenGigabitEthernet.Switchport.Autostate()
                    self.autostate.parent = self
                    self._children_name_map["autostate"] = "Cisco-IOS-XE-switch:autostate"

                    self.private_vlan = Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan()
                    self.private_vlan.parent = self
                    self._children_name_map["private_vlan"] = "Cisco-IOS-XE-switch:private-vlan"

                    self.vepa = Native.Interface.TenGigabitEthernet.Switchport.Vepa()
                    self.vepa.parent = self
                    self._children_name_map["vepa"] = "Cisco-IOS-XE-switch:vepa"

                    self.device_tracking = Native.Interface.TenGigabitEthernet.Switchport.DeviceTracking()
                    self.device_tracking.parent = self
                    self._children_name_map["device_tracking"] = "Cisco-IOS-XE-switch:device-tracking"
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport, [u'nonegotiate', u'protected', u'host'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	Set VLAN when interface is in access mode
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Access.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TenGigabitEthernet.Switchport.Access.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.TenGigabitEthernet.Switchport.Access.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:access"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Access, [], name, value)


                    class Vlan(Entity):
                        """
                        Set VLAN when interface is in access mode
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_>`
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.Access.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "access"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Access.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dynamic = 0

                            """

                            dynamic = Enum.YLeaf(0, "dynamic")



                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: multicast
                    
                    	Block unknown multicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.multicast = None
                        self.unicast = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:block"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Block, [u'multicast', u'unicast'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Mode.Access>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dot1q_tunnel
                    
                    	set trunking mode to TUNNEL unconditionally
                    	**type**\:  :py:class:`Dot1qTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Mode.Dot1qTunnel>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dynamic
                    
                    	Set trunking mode to dynamically negotiate access or trunk mode
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Mode.Dynamic>`
                    
                    .. attribute:: private_vlan
                    
                    	Set private\-vlan mode
                    	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Mode.PrivateVlan>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Mode.Trunk>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.TenGigabitEthernet.Switchport.Mode.Access)), ("dot1q-tunnel", ("dot1q_tunnel", Native.Interface.TenGigabitEthernet.Switchport.Mode.Dot1qTunnel)), ("private-vlan", ("private_vlan", Native.Interface.TenGigabitEthernet.Switchport.Mode.PrivateVlan)), ("trunk", ("trunk", Native.Interface.TenGigabitEthernet.Switchport.Mode.Trunk))])
                        self._leafs = OrderedDict([
                            ('dynamic', (YLeaf(YType.enumeration, 'dynamic'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Switchport.Mode.Dynamic')])),
                        ])
                        self.dynamic = None

                        self.access = None
                        self._children_name_map["access"] = "access"

                        self.dot1q_tunnel = None
                        self._children_name_map["dot1q_tunnel"] = "dot1q-tunnel"

                        self.private_vlan = Native.Interface.TenGigabitEthernet.Switchport.Mode.PrivateVlan()
                        self.private_vlan.parent = self
                        self._children_name_map["private_vlan"] = "private-vlan"

                        self.trunk = None
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Mode, [u'dynamic'], name, value)

                    class Dynamic(Enum):
                        """
                        Dynamic (Enum Class)

                        Set trunking mode to dynamically negotiate access or trunk mode

                        .. data:: auto = 0

                        .. data:: desirable = 1

                        """

                        auto = Enum.YLeaf(0, "auto")

                        desirable = Enum.YLeaf(1, "desirable")



                    class Access(Entity):
                        """
                        Set trunking mode to ACCESS unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.Mode.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "access"
                            self._is_frozen = True


                    class Dot1qTunnel(Entity):
                        """
                        set trunking mode to TUNNEL unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.Mode.Dot1qTunnel, self).__init__()

                            self.yang_name = "dot1q-tunnel"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dot1q-tunnel"
                            self._is_frozen = True


                    class PrivateVlan(Entity):
                        """
                        Set private\-vlan mode
                        
                        .. attribute:: host
                        
                        	Set the mode to private\-vlan host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: promiscuous
                        
                        	Set the mode to private\-vlan promiscuous
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.Mode.PrivateVlan, self).__init__()

                            self.yang_name = "private-vlan"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('promiscuous', (YLeaf(YType.empty, 'promiscuous'), ['Empty'])),
                            ])
                            self.host = None
                            self.promiscuous = None
                            self._segment_path = lambda: "private-vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Mode.PrivateVlan, [u'host', u'promiscuous'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking mode to TRUNK unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.Mode.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: mac_address
                    
                    	Secure mac address
                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.MacAddress>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Aging)), ("mac-address", ("mac_address", Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.MacAddress)), ("maximum", ("maximum", Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Maximum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Switchport.PortSecurity.Violation')])),
                        ])
                        self.violation = None

                        self.aging = Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.mac_address = Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"

                        self.maximum = Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:port-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.PortSecurity, [u'violation'], name, value)

                    class Violation(Enum):
                        """
                        Violation (Enum Class)

                        Security violation mode

                        .. data:: protect = 0

                        .. data:: restrict = 1

                        .. data:: shutdown = 2

                        """

                        protect = Enum.YLeaf(0, "protect")

                        restrict = Enum.YLeaf(1, "restrict")

                        shutdown = Enum.YLeaf(2, "shutdown")



                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Aging.Type>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Switchport.PortSecurity.Aging.Type')])),
                            ])
                            self.static = None
                            self.time = None
                            self.type = None
                            self._segment_path = lambda: "aging"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Aging, [u'static', u'time', u'type'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Port\-security aging type

                            .. data:: absolute = 0

                            .. data:: inactivity = 1

                            """

                            absolute = Enum.YLeaf(0, "absolute")

                            inactivity = Enum.YLeaf(1, "inactivity")



                    class MacAddress(Entity):
                        """
                        Secure mac address
                        
                        .. attribute:: sticky
                        
                        	Configure dynamic secure addresses as sticky
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hw_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: vlan
                        
                        	set VLAN ID of the VLAN on which this address can be learned
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                ('hw_address', (YLeaf(YType.str, 'hw-address'), ['str'])),
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.sticky = None
                            self.hw_address = None
                            self.vlan = None
                            self._segment_path = lambda: "mac-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.MacAddress, [u'sticky', u'hw_address', u'vlan'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: max_addresses
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4097
                        
                        .. attribute:: vlan
                        
                        	Max secure addresses per vlan
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_addresses', (YLeaf(YType.uint16, 'max-addresses'), ['int'])),
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['str'])),
                            ])
                            self.max_addresses = None
                            self.vlan = None
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.PortSecurity.Maximum, [u'max_addresses', u'vlan'], name, value)


                class Trunk(Entity):
                    """
                    Set trunking characteristics of the interface
                    
                    .. attribute:: allowed
                    
                    	Set allowed VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Trunk.Allowed>`
                    
                    .. attribute:: encapsulation
                    
                    	Set encapsulation format on trunk port
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Trunk.Encapsulation>`
                    
                    .. attribute:: native
                    
                    	Set trunking native characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Trunk.Native_>`
                    
                    .. attribute:: pruning
                    
                    	Set pruning VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Pruning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Trunk.Pruning>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switchport.Trunk, self).__init__()

                        self.yang_name = "trunk"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.TenGigabitEthernet.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.TenGigabitEthernet.Switchport.Trunk.Native_)), ("pruning", ("pruning", Native.Interface.TenGigabitEthernet.Switchport.Trunk.Pruning))])
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Switchport.Trunk.Encapsulation')])),
                        ])
                        self.encapsulation = None

                        self.allowed = Native.Interface.TenGigabitEthernet.Switchport.Trunk.Allowed()
                        self.allowed.parent = self
                        self._children_name_map["allowed"] = "allowed"

                        self.native = Native.Interface.TenGigabitEthernet.Switchport.Trunk.Native_()
                        self.native.parent = self
                        self._children_name_map["native"] = "native"

                        self.pruning = Native.Interface.TenGigabitEthernet.Switchport.Trunk.Pruning()
                        self.pruning.parent = self
                        self._children_name_map["pruning"] = "pruning"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:trunk"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Trunk, [u'encapsulation'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Set encapsulation format on trunk port

                        .. data:: dot1q = 0

                        .. data:: isl = 1

                        .. data:: negotiate = 2

                        """

                        dot1q = Enum.YLeaf(0, "dot1q")

                        isl = Enum.YLeaf(1, "isl")

                        negotiate = Enum.YLeaf(2, "negotiate")



                    class Allowed(Entity):
                        """
                        Set allowed VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set allowed VLANs when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Trunk.Allowed.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.Trunk.Allowed, self).__init__()

                            self.yang_name = "allowed"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TenGigabitEthernet.Switchport.Trunk.Allowed.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.TenGigabitEthernet.Switchport.Trunk.Allowed.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "allowed"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Trunk.Allowed, [], name, value)


                        class Vlan(Entity):
                            """
                            Set allowed VLANs when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: all
                            
                            	all VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "allowed"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = None
                                self.add = None
                                self.all = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                    class Native_(Entity):
                        """
                        Set trunking native characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set native VLAN when interface is in trunking mode
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.Trunk.Native_, self).__init__()

                            self.yang_name = "native"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan'),'int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "native"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Trunk.Native_, [u'vlan'], name, value)

                        class Vlan(Enum):
                            """
                            Vlan (Enum Class)

                            Set native VLAN when interface is in trunking mode

                            .. data:: tag = 0

                            """

                            tag = Enum.YLeaf(0, "tag")



                    class Pruning(Entity):
                        """
                        Set pruning VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set VLANs enabled for pruning when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Trunk.Pruning.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.Trunk.Pruning, self).__init__()

                            self.yang_name = "pruning"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TenGigabitEthernet.Switchport.Trunk.Pruning.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.TenGigabitEthernet.Switchport.Trunk.Pruning.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "pruning"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Trunk.Pruning, [], name, value)


                        class Vlan(Entity):
                            """
                            Set VLANs enabled for pruning when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Switchport.Trunk.Pruning.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "pruning"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeafList(YType.str, 'vlans'), ['int','str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = []
                                self.add = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Trunk.Pruning.Vlan, [u'vlans', u'add', u'except_', u'none', u'remove'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Voice.Vlan>`
                    
                    .. attribute:: detect
                    
                    	detection enhancement keyword
                    	**type**\:  :py:class:`Detect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Voice.Detect>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TenGigabitEthernet.Switchport.Voice.Vlan)), ("detect", ("detect", Native.Interface.TenGigabitEthernet.Switchport.Voice.Detect))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.TenGigabitEthernet.Switchport.Voice.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"

                        self.detect = Native.Interface.TenGigabitEthernet.Switchport.Voice.Detect()
                        self.detect.parent = self
                        self._children_name_map["detect"] = "detect"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:voice"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Voice, [], name, value)


                    class Vlan(Entity):
                        """
                        Vlan for voice traffic
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\: str
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.Voice.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_'),'int','str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Voice.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dot1p = 0

                            .. data:: none = 1

                            .. data:: untagged = 2

                            """

                            dot1p = Enum.YLeaf(0, "dot1p")

                            none = Enum.YLeaf(1, "none")

                            untagged = Enum.YLeaf(2, "untagged")



                    class Detect(Entity):
                        """
                        detection enhancement keyword
                        
                        .. attribute:: cisco_phone
                        
                        	Cisco IP phone
                        	**type**\:  :py:class:`CiscoPhone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Voice.Detect.CiscoPhone>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.Voice.Detect, self).__init__()

                            self.yang_name = "detect"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cisco-phone", ("cisco_phone", Native.Interface.TenGigabitEthernet.Switchport.Voice.Detect.CiscoPhone))])
                            self._leafs = OrderedDict()

                            self.cisco_phone = None
                            self._children_name_map["cisco_phone"] = "cisco-phone"
                            self._segment_path = lambda: "detect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Voice.Detect, [], name, value)


                        class CiscoPhone(Entity):
                            """
                            Cisco IP phone
                            
                            .. attribute:: full_duplex
                            
                            	full duplex keyword
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Switchport.Voice.Detect.CiscoPhone, self).__init__()

                                self.yang_name = "cisco-phone"
                                self.yang_parent_name = "detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('full_duplex', (YLeaf(YType.empty, 'full-duplex'), ['Empty'])),
                                ])
                                self.full_duplex = None
                                self._segment_path = lambda: "cisco-phone"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Voice.Detect.CiscoPhone, [u'full_duplex'], name, value)


                class Priority(Entity):
                    """
                    Set appliance 802.1p priority
                    
                    .. attribute:: extend
                    
                    	Set appliance 802.1p priority
                    	**type**\:  :py:class:`Extend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.Priority.Extend>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switchport.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("extend", ("extend", Native.Interface.TenGigabitEthernet.Switchport.Priority.Extend))])
                        self._leafs = OrderedDict()

                        self.extend = Native.Interface.TenGigabitEthernet.Switchport.Priority.Extend()
                        self.extend.parent = self
                        self._children_name_map["extend"] = "extend"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Priority, [], name, value)


                    class Extend(Entity):
                        """
                        Set appliance 802.1p priority
                        
                        .. attribute:: trust
                        
                        	Trust 802.1p priorities of devices on appliance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cos
                        
                        	Override 802.1p priority of devices on appliance
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.Priority.Extend, self).__init__()

                            self.yang_name = "extend"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                            ])
                            self.trust = None
                            self.cos = None
                            self._segment_path = lambda: "extend"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Priority.Extend, [u'trust', u'cos'], name, value)


                class Autostate(Entity):
                    """
                    Include or exclude this port from vlan link up calculation
                    
                    .. attribute:: exclude
                    
                    	Exclude this port from vlan link up calculation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switchport.Autostate, self).__init__()

                        self.yang_name = "autostate"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('exclude', (YLeaf(YType.empty, 'exclude'), ['Empty'])),
                        ])
                        self.exclude = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:autostate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Autostate, [u'exclude'], name, value)


                class PrivateVlan(Entity):
                    """
                    Set the private VLAN configuration
                    
                    .. attribute:: association
                    
                    	Set the private VLAN association
                    	**type**\:  :py:class:`Association <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association>`
                    
                    .. attribute:: host_association
                    
                    	Set the private VLAN host association
                    	**type**\:  :py:class:`HostAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.HostAssociation>`
                    
                    .. attribute:: mapping
                    
                    	Set the private VLAN promiscuous mapping
                    	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Mapping>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan, self).__init__()

                        self.yang_name = "private-vlan"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("association", ("association", Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association)), ("host-association", ("host_association", Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.HostAssociation)), ("mapping", ("mapping", Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Mapping))])
                        self._leafs = OrderedDict()

                        self.association = Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association()
                        self.association.parent = self
                        self._children_name_map["association"] = "association"

                        self.host_association = Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.HostAssociation()
                        self.host_association.parent = self
                        self._children_name_map["host_association"] = "host-association"

                        self.mapping = Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Mapping()
                        self.mapping.parent = self
                        self._children_name_map["mapping"] = "mapping"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:private-vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan, [], name, value)


                    class Association(Entity):
                        """
                        Set the private VLAN association
                        
                        .. attribute:: host
                        
                        	Set the private VLAN host association
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association.Host>`
                        
                        .. attribute:: mapping
                        
                        	Set the private VLAN promiscuous mapping
                        	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association.Mapping>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association, self).__init__()

                            self.yang_name = "association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association.Host)), ("mapping", ("mapping", Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association.Mapping))])
                            self._leafs = OrderedDict()

                            self.host = Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.mapping = Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association.Mapping()
                            self.mapping.parent = self
                            self._children_name_map["mapping"] = "mapping"
                            self._segment_path = lambda: "association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association, [], name, value)


                        class Host(Entity):
                            """
                            Set the private VLAN host association
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary normal range VLAN ID of the private VLAN host port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association.Host, [u'primary_range', u'secondary_range'], name, value)


                        class Mapping(Entity):
                            """
                            Set the private VLAN promiscuous mapping
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: remove
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association.Mapping, self).__init__()

                                self.yang_name = "mapping"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self.add = None
                                self.remove = None
                                self._segment_path = lambda: "mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Association.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                    class HostAssociation(Entity):
                        """
                        Set the private VLAN host association
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary normal range VLAN ID of the private VLAN host port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.HostAssociation, self).__init__()

                            self.yang_name = "host-association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self._segment_path = lambda: "host-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.HostAssociation, [u'primary_range', u'secondary_range'], name, value)


                    class Mapping(Entity):
                        """
                        Set the private VLAN promiscuous mapping
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: add
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: remove
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Mapping, self).__init__()

                            self.yang_name = "mapping"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self.add = None
                            self.remove = None
                            self._segment_path = lambda: "mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.PrivateVlan.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                class Vepa(Entity):
                    """
                    Reflective relay configuration
                    
                    .. attribute:: enabled
                    
                    	Enable reflective relay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switchport.Vepa, self).__init__()

                        self.yang_name = "vepa"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                        ])
                        self.enabled = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:vepa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.Vepa, [u'enabled'], name, value)


                class DeviceTracking(Entity):
                    """
                    Configure device\-tracking on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature device\-tracking
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switchport.DeviceTracking, self).__init__()

                        self.yang_name = "device-tracking"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:device-tracking"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switchport.DeviceTracking, [u'attach_policy'], name, value)


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TenGigabitEthernet.Backup.Delay)), ("interface", ("interface", Native.Interface.TenGigabitEthernet.Backup.Interface_)), ("load", ("load", Native.Interface.TenGigabitEthernet.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.TenGigabitEthernet.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.TenGigabitEthernet.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.TenGigabitEthernet.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.TenGigabitEthernet.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.TenGigabitEthernet.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.TenGigabitEthernet.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.TenGigabitEthernet.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.TenGigabitEthernet.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.TenGigabitEthernet.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.TenGigabitEthernet.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.TenGigabitEthernet.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.TenGigabitEthernet.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.TenGigabitEthernet.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.TenGigabitEthernet.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.TenGigabitEthernet.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.TenGigabitEthernet.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.TenGigabitEthernet.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.TenGigabitEthernet.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.TenGigabitEthernet.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.TenGigabitEthernet.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.TenGigabitEthernet.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.TenGigabitEthernet.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.TenGigabitEthernet.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.TenGigabitEthernet.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.TenGigabitEthernet.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.TenGigabitEthernet.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.TenGigabitEthernet.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.TenGigabitEthernet.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.TenGigabitEthernet.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.TenGigabitEthernet.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.TenGigabitEthernet.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.TenGigabitEthernet.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.TenGigabitEthernet.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.TenGigabitEthernet.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.TenGigabitEthernet.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.TenGigabitEthernet.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.TenGigabitEthernet.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.TenGigabitEthernet.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.TenGigabitEthernet.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.TenGigabitEthernet.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.TenGigabitEthernet.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.TenGigabitEthernet.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.TenGigabitEthernet.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.TenGigabitEthernet.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.TenGigabitEthernet.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.TenGigabitEthernet.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.TenGigabitEthernet.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.TenGigabitEthernet.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.TenGigabitEthernet.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.TenGigabitEthernet.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.TenGigabitEthernet.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.TenGigabitEthernet.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.TenGigabitEthernet.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.TenGigabitEthernet.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.TenGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.TenGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.TenGigabitEthernet.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.TenGigabitEthernet.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.TenGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.TenGigabitEthernet.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.TenGigabitEthernet.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.TenGigabitEthernet.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.TenGigabitEthernet.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.TenGigabitEthernet.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.TenGigabitEthernet.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.TenGigabitEthernet.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.TenGigabitEthernet.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.TenGigabitEthernet.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.TenGigabitEthernet.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.TenGigabitEthernet.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.TenGigabitEthernet.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.TenGigabitEthernet.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.TenGigabitEthernet.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.TenGigabitEthernet.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.TenGigabitEthernet.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.TenGigabitEthernet.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.TenGigabitEthernet.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.TenGigabitEthernet.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.TenGigabitEthernet.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.TenGigabitEthernet.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.TenGigabitEthernet.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.TenGigabitEthernet.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.TenGigabitEthernet.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.TenGigabitEthernet.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.TenGigabitEthernet.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.TenGigabitEthernet.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.TenGigabitEthernet.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.TenGigabitEthernet.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.TenGigabitEthernet.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.TenGigabitEthernet.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.TenGigabitEthernet.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.TenGigabitEthernet.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.TenGigabitEthernet.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.TenGigabitEthernet.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.TenGigabitEthernet.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Igmp>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Flow>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Nbar>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf>`
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Lisp>`
                
                .. attribute:: rsvp
                
                	RSVP Interface Commands
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Nat>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.TenGigabitEthernet.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.TenGigabitEthernet.Ip.Arp)), ("vrf", ("vrf", Native.Interface.TenGigabitEthernet.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.TenGigabitEthernet.Ip.NoAddress)), ("address", ("address", Native.Interface.TenGigabitEthernet.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.TenGigabitEthernet.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.TenGigabitEthernet.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.TenGigabitEthernet.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.TenGigabitEthernet.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.TenGigabitEthernet.Ip.Pim)), ("policy", ("policy", Native.Interface.TenGigabitEthernet.Ip.Policy)), ("rip", ("rip", Native.Interface.TenGigabitEthernet.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.TenGigabitEthernet.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.TenGigabitEthernet.Ip.RouteCache)), ("router", ("router", Native.Interface.TenGigabitEthernet.Ip.Router)), ("tcp", ("tcp", Native.Interface.TenGigabitEthernet.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.TenGigabitEthernet.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.TenGigabitEthernet.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.TenGigabitEthernet.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.TenGigabitEthernet.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.TenGigabitEthernet.Ip.Igmp)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.TenGigabitEthernet.Ip.Flow)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.TenGigabitEthernet.Ip.Nbar)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.TenGigabitEthernet.Ip.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.TenGigabitEthernet.Ip.Lisp)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Interface.TenGigabitEthernet.Ip.Rsvp)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.TenGigabitEthernet.Ip.Nat)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.TenGigabitEthernet.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None
                    self.unreachables = None

                    self.access_group = Native.Interface.TenGigabitEthernet.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.TenGigabitEthernet.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.TenGigabitEthernet.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.TenGigabitEthernet.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.TenGigabitEthernet.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.TenGigabitEthernet.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.TenGigabitEthernet.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.TenGigabitEthernet.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.TenGigabitEthernet.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.TenGigabitEthernet.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.TenGigabitEthernet.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.TenGigabitEthernet.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.TenGigabitEthernet.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.TenGigabitEthernet.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.TenGigabitEthernet.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.TenGigabitEthernet.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.TenGigabitEthernet.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.TenGigabitEthernet.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.TenGigabitEthernet.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.flow = Native.Interface.TenGigabitEthernet.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.nbar = Native.Interface.TenGigabitEthernet.Ip.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.ospf = Native.Interface.TenGigabitEthernet.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.lisp = Native.Interface.TenGigabitEthernet.Ip.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                    self.rsvp = Native.Interface.TenGigabitEthernet.Ip.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

                    self.nat = Native.Interface.TenGigabitEthernet.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.wccp = Native.Interface.TenGigabitEthernet.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache', 'unreachables'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.TenGigabitEthernet.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.TenGigabitEthernet.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.TenGigabitEthernet.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.TenGigabitEthernet.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.TenGigabitEthernet.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.TenGigabitEthernet.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.TenGigabitEthernet.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.TenGigabitEthernet.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.TenGigabitEthernet.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.TenGigabitEthernet.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.TenGigabitEthernet.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.TenGigabitEthernet.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.TenGigabitEthernet.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.TenGigabitEthernet.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.TenGigabitEthernet.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.TenGigabitEthernet.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.TenGigabitEthernet.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.TenGigabitEthernet.Ip.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ip.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ip.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.TenGigabitEthernet.Ip.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.TenGigabitEthernet.Ip.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.TenGigabitEthernet.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.TenGigabitEthernet.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.TenGigabitEthernet.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.TenGigabitEthernet.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.TenGigabitEthernet.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.TenGigabitEthernet.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TenGigabitEthernet.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.TenGigabitEthernet.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.TenGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.TenGigabitEthernet.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TenGigabitEthernet.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.TenGigabitEthernet.Ip.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ip.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.TenGigabitEthernet.Ip.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.TenGigabitEthernet.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.TenGigabitEthernet.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.TenGigabitEthernet.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.TenGigabitEthernet.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.TenGigabitEthernet.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.TenGigabitEthernet.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.TenGigabitEthernet.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.TenGigabitEthernet.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.TenGigabitEthernet.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TenGigabitEthernet.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.TenGigabitEthernet.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.TenGigabitEthernet.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.TenGigabitEthernet.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.TenGigabitEthernet.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.TenGigabitEthernet.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.TenGigabitEthernet.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.TenGigabitEthernet.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.TenGigabitEthernet.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.TenGigabitEthernet.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TenGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.TenGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Lisp(Entity):
                    """
                    Locator/ID Separation Protocol
                    
                    .. attribute:: source_locator
                    
                    	Choose IP source address for LISP packets egressing this interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_locator', (YLeaf(YType.str, 'source-locator'), ['str'])),
                        ])
                        self.source_locator = None
                        self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Lisp, ['source_locator'], name, value)


                class Rsvp(Entity):
                    """
                    RSVP Interface Commands
                    
                    .. attribute:: authentication
                    
                    	Enables RSVP neighbor authentication (RFC 2747)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bandwidth
                    
                    	RSVP Reservable Bandwidth (kbps)
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	Select permissible RSVP neighbors
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Neighbor>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: precedence
                    
                    	RSVP precedence setting
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Precedence>`
                    
                    .. attribute:: signalling
                    
                    	RSVP signalling
                    	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling>`
                    
                    .. attribute:: tos
                    
                    	RSVP TOS setting
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Tos>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Authentication)), ("bandwidth", ("bandwidth", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth)), ("neighbor", ("neighbor", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Neighbor)), ("precedence", ("precedence", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Precedence)), ("signalling", ("signalling", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling)), ("tos", ("tos", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Tos))])
                        self._leafs = OrderedDict()

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.bandwidth = None
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.neighbor = None
                        self._children_name_map["neighbor"] = "neighbor"

                        self.precedence = Native.Interface.TenGigabitEthernet.Ip.Rsvp.Precedence()
                        self.precedence.parent = self
                        self._children_name_map["precedence"] = "precedence"

                        self.signalling = Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling()
                        self.signalling.parent = self
                        self._children_name_map["signalling"] = "signalling"

                        self.tos = Native.Interface.TenGigabitEthernet.Ip.Rsvp.Tos()
                        self.tos.parent = self
                        self._children_name_map["tos"] = "tos"
                        self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp, [], name, value)


                    class Authentication(Entity):
                        """
                        Enables RSVP neighbor authentication (RFC 2747)
                        
                        .. attribute:: key
                        
                        	Password (8 to 40 characters, spaces allowed)
                        	**type**\: str
                        
                        .. attribute:: challenge
                        
                        	Perform challenge/response handshake with new neighbor(s)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key_chain
                        
                        	Name of key chain to use (as created by global 'key chain' command)
                        	**type**\: str
                        
                        .. attribute:: lifetime
                        
                        	Maximum lifetime of neighbor authentication state
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Authentication.Lifetime>`
                        
                        .. attribute:: type
                        
                        	Type of authentication algorithm (default = md5)
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Authentication.Type>`
                        
                        .. attribute:: window_size
                        
                        	Maximum number of messages allowed in receive window (default = 1)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Authentication.Lifetime))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ip.Rsvp.Authentication.Type')])),
                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                            ])
                            self.key = None
                            self.challenge = None
                            self.key_chain = None
                            self.type = None
                            self.window_size = None

                            self.lifetime = Native.Interface.TenGigabitEthernet.Ip.Rsvp.Authentication.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Authentication, ['key', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Type of authentication algorithm (default = md5)

                            .. data:: md5 = 0

                            .. data:: sha_1 = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            sha_1 = Enum.YLeaf(1, "sha-1")



                        class Lifetime(Entity):
                            """
                            Maximum lifetime of neighbor authentication state
                            
                            .. attribute:: hh_mm_ss
                            
                            	Lifetime (default = 30 mins) in hh\:mm\:ss format
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ])
                                self.hh_mm_ss = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


                    class Bandwidth(Entity):
                        """
                        RSVP Reservable Bandwidth (kbps)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Value>`
                        
                        .. attribute:: percent
                        
                        	Percentage of interface bandwidth. Values higher than 100 represent overbooking
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: mam
                        
                        	Use bandwidth with MAM model of DSTE
                        	**type**\:  :py:class:`Mam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Mam>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Value)), ("mam", ("mam", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Mam))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                            ])
                            self.percent = None

                            self.value = Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.mam = Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Mam()
                            self.mam.parent = self
                            self._children_name_map["mam"] = "mam"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth, ['percent'], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	Reservable Bandwidth (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            .. attribute:: sub_pool
                            
                            	Reservable Bandwidth for Tunnel using sub (BC1) pool (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.value = None
                                self.sub_pool = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Value, ['value', 'sub_pool'], name, value)


                        class Mam(Entity):
                            """
                            Use bandwidth with MAM model of DSTE
                            
                            .. attribute:: max_reservable_bw
                            
                            	Maximum Reservable bandwidth for MAM
                            	**type**\:  :py:class:`MaxReservableBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Mam, self).__init__()

                                self.yang_name = "mam"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("max-reservable-bw", ("max_reservable_bw", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw))])
                                self._leafs = OrderedDict()

                                self.max_reservable_bw = None
                                self._children_name_map["max_reservable_bw"] = "max-reservable-bw"
                                self._segment_path = lambda: "mam"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Mam, [], name, value)


                            class MaxReservableBw(Entity):
                                """
                                Maximum Reservable bandwidth for MAM
                                
                                .. attribute:: value
                                
                                	Reservable Bandwidth (kbps)
                                	**type**\: int
                                
                                	**range:** 1..10000000
                                
                                .. attribute:: bc0
                                
                                	Reservable Bandwidth from global (BC0) pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                .. attribute:: bc1
                                
                                	Reservable Bandwidth from sub pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, self).__init__()

                                    self.yang_name = "max-reservable-bw"
                                    self.yang_parent_name = "mam"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                        ('bc0', (YLeaf(YType.uint32, 'bc0'), ['int'])),
                                        ('bc1', (YLeaf(YType.uint32, 'bc1'), ['int'])),
                                    ])
                                    self.value = None
                                    self.bc0 = None
                                    self.bc1 = None
                                    self._segment_path = lambda: "max-reservable-bw"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, ['value', 'bc0', 'bc1'], name, value)


                    class Neighbor(Entity):
                        """
                        Select permissible RSVP neighbors
                        
                        .. attribute:: acl_number
                        
                        	Access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                            ])
                            self.acl_number = None
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Neighbor, ['acl_number'], name, value)


                    class Precedence(Entity):
                        """
                        RSVP precedence setting
                        
                        .. attribute:: conform
                        
                        	Precedence for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: exceed
                        
                        	Precedence for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Precedence, ['conform', 'exceed'], name, value)


                    class Signalling(Entity):
                        """
                        RSVP signalling
                        
                        .. attribute:: dscp
                        
                        	DSCP for RSVP signalling messages
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: fast_local_repair
                        
                        	Fast Local Repair parameters
                        	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair>`
                        
                        .. attribute:: hello
                        
                        	Enable neighbor\-down detection
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling, self).__init__()

                            self.yang_name = "signalling"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.fast_local_repair = Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair()
                            self.fast_local_repair.parent = self
                            self._children_name_map["fast_local_repair"] = "fast-local-repair"

                            self.hello = None
                            self._children_name_map["hello"] = "hello"
                            self._segment_path = lambda: "signalling"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling, ['dscp'], name, value)


                        class FastLocalRepair(Entity):
                            """
                            Fast Local Repair parameters
                            
                            .. attribute:: wait_time
                            
                            	Wait Time for start of Fast Local Repair in msec
                            	**type**\: int
                            
                            	**range:** 0..5000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                                self.yang_name = "fast-local-repair"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint16, 'wait-time'), ['int'])),
                                ])
                                self.wait_time = None
                                self._segment_path = lambda: "fast-local-repair"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair, ['wait_time'], name, value)


                        class Hello(Entity):
                            """
                            Enable neighbor\-down detection
                            
                            .. attribute:: bfd
                            
                            	Configure BFD trigger for MPLS/TE FRR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	DSCP for RSVP Hello messages
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: graceful_restart
                            
                            	Configure RSVP Graceful Restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: refresh
                            
                            	Configure RSVP Hello refresh behavior for Fast\-Reroute
                            	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh>`
                            
                            .. attribute:: reroute
                            
                            	Configure RSVP Hello refresh behavior for Reroute
                            	**type**\:  :py:class:`Reroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh)), ("reroute", ("reroute", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ('graceful_restart', (YLeaf(YType.empty, 'graceful-restart'), ['Empty'])),
                                ])
                                self.bfd = None
                                self.dscp = None
                                self.graceful_restart = None

                                self.refresh = Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh()
                                self.refresh.parent = self
                                self._children_name_map["refresh"] = "refresh"

                                self.reroute = Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute()
                                self.reroute.parent = self
                                self._children_name_map["reroute"] = "reroute"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello, ['bfd', 'dscp', 'graceful_restart'], name, value)


                            class Refresh(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Fast\-Reroute
                                
                                .. attribute:: interval
                                
                                	Hello interval in msec
                                	**type**\: int
                                
                                	**range:** 10..30000
                                
                                .. attribute:: misses
                                
                                	Number of missed Hello Acks which triggers neighbor down
                                	**type**\: int
                                
                                	**range:** 4..10
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh, self).__init__()

                                    self.yang_name = "refresh"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.misses = None
                                    self._segment_path = lambda: "refresh"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh, ['interval', 'misses'], name, value)


                            class Reroute(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Reroute
                                
                                .. attribute:: dscp
                                
                                	DSCP for RSVP Hello messages
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: refresh
                                
                                	Configure RSVP Reroute Hello refresh behavior
                                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh>`
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute, self).__init__()

                                    self.yang_name = "reroute"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh))])
                                    self._leafs = OrderedDict([
                                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ])
                                    self.dscp = None

                                    self.refresh = Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh()
                                    self.refresh.parent = self
                                    self._children_name_map["refresh"] = "refresh"
                                    self._segment_path = lambda: "reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute, ['dscp'], name, value)


                                class Refresh(Entity):
                                    """
                                    Configure RSVP Reroute Hello refresh behavior
                                    
                                    .. attribute:: interval
                                    
                                    	Hello Reroute interval in msec
                                    	**type**\: int
                                    
                                    	**range:** 1000..30000
                                    
                                    .. attribute:: misses
                                    
                                    	Number of missed Hello Acks which triggers neighbor down
                                    	**type**\: int
                                    
                                    	**range:** 4..10
                                    
                                    

                                    """

                                    _prefix = 'ios-rsvp'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, self).__init__()

                                        self.yang_name = "refresh"
                                        self.yang_parent_name = "reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.misses = None
                                        self._segment_path = lambda: "refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, ['interval', 'misses'], name, value)


                    class Tos(Entity):
                        """
                        RSVP TOS setting
                        
                        .. attribute:: conform
                        
                        	TOS for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: exceed
                        
                        	TOS for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Rsvp.Tos, ['conform', 'exceed'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.TenGigabitEthernet.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.TenGigabitEthernet.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.TenGigabitEthernet.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.TenGigabitEthernet.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.TenGigabitEthernet.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TenGigabitEthernet.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.TenGigabitEthernet.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TenGigabitEthernet.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.TenGigabitEthernet.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.TenGigabitEthernet.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.TenGigabitEthernet.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.TrafficFilter>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Flow>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Crypto>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Pim>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: rip
                
                	Configure RIP routing protocol
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Rip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.TenGigabitEthernet.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.TenGigabitEthernet.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.TenGigabitEthernet.Ipv6.Dhcp)), ("address", ("address", Native.Interface.TenGigabitEthernet.Ipv6.Address)), ("nd", ("nd", Native.Interface.TenGigabitEthernet.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.TenGigabitEthernet.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.TenGigabitEthernet.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.TenGigabitEthernet.Ipv6.Flow)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.TenGigabitEthernet.Ipv6.Crypto)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.TenGigabitEthernet.Ipv6.Ospf)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.TenGigabitEthernet.Ipv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.TenGigabitEthernet.Ipv6.Pim)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Interface.TenGigabitEthernet.Ipv6.Rip))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None
                    self.unreachables = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.TenGigabitEthernet.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.TenGigabitEthernet.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.TenGigabitEthernet.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.TenGigabitEthernet.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.flow = Native.Interface.TenGigabitEthernet.Ipv6.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.crypto = Native.Interface.TenGigabitEthernet.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.ospf = Native.Interface.TenGigabitEthernet.Ipv6.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.no_pim = Native.Interface.TenGigabitEthernet.Ipv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.TenGigabitEthernet.Ipv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects', 'unreachables'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.TenGigabitEthernet.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.TenGigabitEthernet.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.TenGigabitEthernet.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.TenGigabitEthernet.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.TenGigabitEthernet.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.TenGigabitEthernet.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.TenGigabitEthernet.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.TenGigabitEthernet.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.TenGigabitEthernet.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.TenGigabitEthernet.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.TenGigabitEthernet.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TenGigabitEthernet.Ipv6.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.TenGigabitEthernet.Ipv6.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ipv6.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ipv6.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Crypto, ['map'], name, value)


                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process
                    
                    	
                    	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Process>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: encryption
                    
                    	Enable encryption
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Network>`
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process", ("process", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Process)), ("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication)), ("bfd", ("bfd", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.DemandCircuit)), ("encryption", ("encryption", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption)), ("flood-reduction", ("flood_reduction", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.FloodReduction)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.MtuIgnore)), ("neighbor", ("neighbor", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Neighbor)), ("network", ("network", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Network)), ("shutdown", ("shutdown", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Shutdown))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.cost = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.encryption = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.network = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.process = YList(self)
                        self.neighbor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf, ['cost', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Process(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: instance
                        
                        	Set the OSPF instance
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..31
                        
                        		**type**\: int
                        
                        			**range:** 32..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Process, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['int','int'])),
                            ])
                            self.id = None
                            self.area = None
                            self.instance = None
                            self._segment_path = lambda: "process" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Process, ['id', 'area', 'instance'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec authentication
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec authentication
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 256..4294967295
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5>`
                            
                            .. attribute:: sha1
                            
                            	Use SHA\-1 authentication
                            	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ])
                                self.spi = None

                                self.md5 = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.sha1 = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1()
                                self.sha1.parent = self
                                self._children_name_map["sha1"] = "sha1"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec, ['spi'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Sha1(Entity):
                                """
                                Use SHA\-1 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, self).__init__()

                                    self.yang_name = "sha1"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "sha1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "sha1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ipv6.Ospf.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.DatabaseFilter, ['all', 'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.DemandCircuit, ['disable', 'ignore'], name, value)


                    class Encryption(Entity):
                        """
                        Enable encryption
                        
                        .. attribute:: null
                        
                        	No IPsec encryption on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec encryption
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec encryption
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: esp
                            
                            	Use ESP encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipsec_3des
                            
                            	Use 3DES encryption
                            	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des>`
                            
                            .. attribute:: aes_cbc
                            
                            	Use AES\-CBC encryption
                            	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                                ])
                                self.spi = None
                                self.esp = None

                                self.ipsec_3des = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des()
                                self.ipsec_3des.parent = self
                                self._children_name_map["ipsec_3des"] = "ipsec_3des"

                                self.aes_cbc = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc()
                                self.aes_cbc.parent = self
                                self._children_name_map["aes_cbc"] = "aes-cbc"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec, ['spi', 'esp'], name, value)


                            class Ipsec3des(Entity):
                                """
                                Use 3DES encryption
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, self).__init__()

                                    self.yang_name = "ipsec_3des"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "ipsec_3des"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "ipsec_3des"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class AesCbc(Entity):
                                """
                                Use AES\-CBC encryption
                                
                                .. attribute:: aes_cbc_128
                                
                                	Use 128 bit key
                                	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128>`
                                
                                .. attribute:: aes_192
                                
                                	Use 192 bit key
                                	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192>`
                                
                                .. attribute:: aes_256
                                
                                	Use 256 bit key
                                	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, self).__init__()

                                    self.yang_name = "aes-cbc"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256))])
                                    self._leafs = OrderedDict()

                                    self.aes_cbc_128 = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128()
                                    self.aes_cbc_128.parent = self
                                    self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                    self.aes_192 = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192()
                                    self.aes_192.parent = self
                                    self._children_name_map["aes_192"] = "aes-192"

                                    self.aes_256 = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256()
                                    self.aes_256.parent = self
                                    self._children_name_map["aes_256"] = "aes-256"
                                    self._segment_path = lambda: "aes-cbc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, [], name, value)


                                class AesCbc128(Entity):
                                    """
                                    Use 128 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                        self.yang_name = "aes-cbc-128"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-cbc-128"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-cbc-128"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes192(Entity):
                                    """
                                    Use 192 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                        self.yang_name = "aes-192"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-192"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-192"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes256(Entity):
                                    """
                                    Use 256 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                        self.yang_name = "aes-256"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-256"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	Disable Flood Reduction on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.FloodReduction, ['disable'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.MtuIgnore, ['disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Ospf.Shutdown, ['disable'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.TenGigabitEthernet.Ipv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.TenGigabitEthernet.Ipv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Pim.Bsr, ['border'], name, value)


                class Rip(Entity):
                    """
                    Configure RIP routing protocol
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable/disable RIP routing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default_information
                    
                    	Configure handling of default route
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Rip.DefaultInformation>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ipv6.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("default-information", ("default_information", Native.Interface.TenGigabitEthernet.Ipv6.Rip.DefaultInformation))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.id = None
                        self.enable = None

                        self.default_information = Native.Interface.TenGigabitEthernet.Ipv6.Rip.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Rip, ['id', 'enable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Configure handling of default route
                        
                        .. attribute:: route
                        
                        	
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ipv6.Rip.DefaultInformation.Route>`
                        
                        .. attribute:: metric
                        
                        	Default route metric
                        	**type**\: int
                        
                        	**range:** 1..15
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ipv6.Rip.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route', (YLeaf(YType.enumeration, 'route'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ipv6.Rip.DefaultInformation.Route')])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ])
                            self.route = None
                            self.metric = None
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ipv6.Rip.DefaultInformation, ['route', 'metric'], name, value)

                        class Route(Enum):
                            """
                            Route (Enum Class)

                            .. data:: only = 0

                            .. data:: originate = 1

                            """

                            only = Enum.YLeaf(0, "only")

                            originate = Enum.YLeaf(1, "originate")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.TenGigabitEthernet.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.TenGigabitEthernet.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.TenGigabitEthernet.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.TenGigabitEthernet.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.TenGigabitEthernet.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.TenGigabitEthernet.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.TenGigabitEthernet.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.TenGigabitEthernet.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.TenGigabitEthernet.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TenGigabitEthernet.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.TenGigabitEthernet.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.TenGigabitEthernet.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.TenGigabitEthernet.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.TenGigabitEthernet.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.TenGigabitEthernet.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.TenGigabitEthernet.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.TenGigabitEthernet.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.TenGigabitEthernet.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.TenGigabitEthernet.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.TenGigabitEthernet.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.TenGigabitEthernet.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.TenGigabitEthernet.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.TenGigabitEthernet.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.TenGigabitEthernet.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.TenGigabitEthernet.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.TenGigabitEthernet.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.TenGigabitEthernet.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.TenGigabitEthernet.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.TenGigabitEthernet.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.TenGigabitEthernet.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.TenGigabitEthernet.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.TenGigabitEthernet.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.TenGigabitEthernet.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.TenGigabitEthernet.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.TenGigabitEthernet.CarrierDelay.Down)), ("up", ("up", Native.Interface.TenGigabitEthernet.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.TenGigabitEthernet.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.TenGigabitEthernet.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.TenGigabitEthernet.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.TenGigabitEthernet.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.TenGigabitEthernet.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.TenGigabitEthernet.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.TenGigabitEthernet.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.TenGigabitEthernet.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.TenGigabitEthernet.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.TenGigabitEthernet.Plim.Ethernet)), ("qos", ("qos", Native.Interface.TenGigabitEthernet.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.TenGigabitEthernet.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.TenGigabitEthernet.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TenGigabitEthernet.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.TenGigabitEthernet.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.TenGigabitEthernet.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.TenGigabitEthernet.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.TenGigabitEthernet.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.TenGigabitEthernet.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.TenGigabitEthernet.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.TenGigabitEthernet.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.TenGigabitEthernet.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.TenGigabitEthernet.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.TenGigabitEthernet.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.TenGigabitEthernet.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.TenGigabitEthernet.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.TenGigabitEthernet.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect)), ("Cisco-IOS-XE-l2vpn:xconnect-pw-class", ("xconnect_pw_class", Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.TenGigabitEthernet.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.TenGigabitEthernet.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.TenGigabitEthernet.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.TenGigabitEthernet.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.TenGigabitEthernet.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.TenGigabitEthernet.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"

                        self.xconnect = Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                        self.xconnect_pw_class = Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.TenGigabitEthernet.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.TenGigabitEthernet.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.TenGigabitEthernet.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.TenGigabitEthernet.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.TenGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.TenGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.TenGigabitEthernet.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.TenGigabitEthernet.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.TenGigabitEthernet.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.TenGigabitEthernet.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Service.Instance.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Lacp(Entity):
                """
                LACP interface subcommands
                
                .. attribute:: port_priority
                
                	LACP priority on this interface 
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rate
                
                	Rate at which the LACP packets are requested to be ingressed to this interface
                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Lacp.Rate>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Lacp, self).__init__()

                    self.yang_name = "lacp"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_priority', (YLeaf(YType.uint32, 'port-priority'), ['int'])),
                        ('rate', (YLeaf(YType.enumeration, 'rate'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Lacp.Rate')])),
                    ])
                    self.port_priority = None
                    self.rate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:lacp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Lacp, ['port_priority', 'rate'], name, value)

                class Rate(Enum):
                    """
                    Rate (Enum Class)

                    Rate at which the LACP packets are requested to be ingressed to this interface

                    .. data:: fast = 0

                    .. data:: normal = 1

                    """

                    fast = Enum.YLeaf(0, "fast")

                    normal = Enum.YLeaf(1, "normal")



            class CiscoIOSXEEthernetMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: dot1q_in_clear
                    
                    	Dot1q in Clear option
                    	**type**\:  :py:class:`Dot1qInClear <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear>`
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('dot1q_in_clear', (YLeaf(YType.enumeration, 'dot1q-in-clear'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear')])),
                        ])
                        self.dot1q_in_clear = None

                        self.replay_protection = Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, ['dot1q_in_clear'], name, value)

                    class Dot1qInClear(Enum):
                        """
                        Dot1qInClear (Enum Class)

                        Dot1q in Clear option

                        .. data:: Y_1 = 0

                        """

                        Y_1 = Enum.YLeaf(0, "1")



                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, ['window_size'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.TenGigabitEthernet.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.TenGigabitEthernet.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.TenGigabitEthernet.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.TenGigabitEthernet.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.TenGigabitEthernet.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.TenGigabitEthernet.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Auto(Entity):
                """
                Configure Automation
                
                .. attribute:: qos
                
                	Configure AutoQoS
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Auto.Qos>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Auto, self).__init__()

                    self.yang_name = "auto"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("qos", ("qos", Native.Interface.TenGigabitEthernet.Auto.Qos))])
                    self._leafs = OrderedDict()

                    self.qos = Native.Interface.TenGigabitEthernet.Auto.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:auto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Auto, [], name, value)


                class Qos(Entity):
                    """
                    Configure AutoQoS
                    
                    .. attribute:: classify
                    
                    	Configure classification for untrusted devices
                    	**type**\:  :py:class:`Classify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Auto.Qos.Classify>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trust
                    
                    	Trust the DSCP/CoS marking
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Auto.Qos.Trust>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: video
                    
                    	Configure AutoQoS for video devices
                    	**type**\:  :py:class:`Video <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Auto.Qos.Video>`
                    
                    .. attribute:: voip
                    
                    	Configure AutoQoS for VoIP
                    	**type**\:  :py:class:`Voip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Auto.Qos.Voip>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Auto.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "auto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("classify", ("classify", Native.Interface.TenGigabitEthernet.Auto.Qos.Classify)), ("trust", ("trust", Native.Interface.TenGigabitEthernet.Auto.Qos.Trust)), ("video", ("video", Native.Interface.TenGigabitEthernet.Auto.Qos.Video)), ("voip", ("voip", Native.Interface.TenGigabitEthernet.Auto.Qos.Voip))])
                        self._leafs = OrderedDict()

                        self.classify = None
                        self._children_name_map["classify"] = "classify"

                        self.trust = None
                        self._children_name_map["trust"] = "trust"

                        self.video = Native.Interface.TenGigabitEthernet.Auto.Qos.Video()
                        self.video.parent = self
                        self._children_name_map["video"] = "video"

                        self.voip = None
                        self._children_name_map["voip"] = "voip"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Auto.Qos, [], name, value)


                    class Classify(Entity):
                        """
                        Configure classification for untrusted devices
                        
                        .. attribute:: police
                        
                        	Configure QoS policing for untrusted devices
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Auto.Qos.Classify, self).__init__()

                            self.yang_name = "classify"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('police', (YLeaf(YType.empty, 'police'), ['Empty'])),
                            ])
                            self.police = None
                            self._segment_path = lambda: "classify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Auto.Qos.Classify, [u'police'], name, value)


                    class Trust(Entity):
                        """
                        Trust the DSCP/CoS marking
                        
                        .. attribute:: cos
                        
                        	Trust the CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	Trust the DSCP marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Auto.Qos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cos', (YLeaf(YType.empty, 'cos'), ['Empty'])),
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ])
                            self.cos = None
                            self.dscp = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Auto.Qos.Trust, [u'cos', u'dscp'], name, value)


                    class Video(Entity):
                        """
                        Configure AutoQoS for video devices
                        
                        .. attribute:: cts
                        
                        	Trust the QoS marking of the Cisco Telepresence System
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ip_camera
                        
                        	Trust the QoS marking of the Ip Video Surveillance camera
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: media_player
                        
                        	Trust the Qos marking of the Cisco Media Player
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Auto.Qos.Video, self).__init__()

                            self.yang_name = "video"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('cts', (YLeaf(YType.empty, 'cts'), ['Empty'])),
                                ('ip_camera', (YLeaf(YType.empty, 'ip-camera'), ['Empty'])),
                                ('media_player', (YLeaf(YType.empty, 'media-player'), ['Empty'])),
                            ])
                            self.cts = None
                            self.ip_camera = None
                            self.media_player = None
                            self._segment_path = lambda: "video"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Auto.Qos.Video, [u'cts', u'ip_camera', u'media_player'], name, value)


                    class Voip(Entity):
                        """
                        Configure AutoQoS for VoIP
                        
                        .. attribute:: cisco_phone
                        
                        	Trust the QoS marking of Cisco IP Phone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cisco_softphone
                        
                        	Trust the QoS marking of Cisco IP SoftPhone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trust
                        
                        	Trust the DSCP/CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Auto.Qos.Voip, self).__init__()

                            self.yang_name = "voip"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cisco_phone', (YLeaf(YType.empty, 'cisco-phone'), ['Empty'])),
                                ('cisco_softphone', (YLeaf(YType.empty, 'cisco-softphone'), ['Empty'])),
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.cisco_phone = None
                            self.cisco_softphone = None
                            self.trust = None
                            self._segment_path = lambda: "voip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Auto.Qos.Voip, [u'cisco_phone', u'cisco_softphone', u'trust'], name, value)


            class Datalink(Entity):
                """
                Interface Datalink commands
                
                .. attribute:: flow
                
                	Interface Flow configuration subcommands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Datalink.Flow>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Datalink, self).__init__()

                    self.yang_name = "datalink"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flow", ("flow", Native.Interface.TenGigabitEthernet.Datalink.Flow))])
                    self._leafs = OrderedDict()

                    self.flow = Native.Interface.TenGigabitEthernet.Datalink.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:datalink"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Datalink, [], name, value)


                class Flow(Entity):
                    """
                    Interface Flow configuration subcommands
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Datalink.Flow.Monitor>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Datalink.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "datalink"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TenGigabitEthernet.Datalink.Flow.Monitor))])
                        self._leafs = OrderedDict()

                        self.monitor = None
                        self._children_name_map["monitor"] = "monitor"
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Datalink.Flow, [], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: user_defined_flow
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: input_output
                        
                        	Apply Flow Monitor on input/output traffic
                        	**type**\:  :py:class:`InputOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Datalink.Flow.Monitor.InputOutput>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Datalink.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('user_defined_flow', (YLeaf(YType.str, 'User-defined-flow'), ['str'])),
                                ('input_output', (YLeaf(YType.enumeration, 'input-output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Datalink.Flow.Monitor.InputOutput')])),
                            ])
                            self.user_defined_flow = None
                            self.input_output = None
                            self._segment_path = lambda: "monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Datalink.Flow.Monitor, [u'user_defined_flow', u'input_output'], name, value)

                        class InputOutput(Enum):
                            """
                            InputOutput (Enum Class)

                            Apply Flow Monitor on input/output traffic

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



            class Energywise(Entity):
                """
                EnergyWise interface configurations
                
                .. attribute:: activitycheck
                
                	Apply an activity check before turning off power    to this PoE port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: level
                
                	Set the EnergyWise level of this interface  or attached entity
                	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Energywise.Level>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Energywise, self).__init__()

                    self.yang_name = "energywise"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Interface.TenGigabitEthernet.Energywise.Level))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('activitycheck', (YLeaf(YType.empty, 'activitycheck'), ['Empty'])),
                    ])
                    self.activitycheck = None

                    self.level = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:energywise"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Energywise, [u'activitycheck'], name, value)


                class Level(Entity):
                    """
                    Set the EnergyWise level of this interface 
                    or attached entity
                    
                    .. attribute:: range  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..10
                    
                    .. attribute:: recurrence
                    
                    	Specify that this level setting should  recur at the specified time
                    	**type**\:  :py:class:`Recurrence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Energywise.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "energywise"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("recurrence", ("recurrence", Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                        ])
                        self.range = None

                        self.recurrence = Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence()
                        self.recurrence.parent = self
                        self._children_name_map["recurrence"] = "recurrence"
                        self._segment_path = lambda: "level" + "[range='" + str(self.range) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Energywise.Level, [u'range'], name, value)


                    class Recurrence(Entity):
                        """
                        Specify that this level setting should 
                        recur at the specified time
                        
                        .. attribute:: importance
                        
                        	Specify the importance at which the event  should be sent when it recurs
                        	**type**\: list of  		 :py:class:`Importance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence.Importance>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence, self).__init__()

                            self.yang_name = "recurrence"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("importance", ("importance", Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence.Importance))])
                            self._leafs = OrderedDict()

                            self.importance = YList(self)
                            self._segment_path = lambda: "recurrence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence, [], name, value)


                        class Importance(Entity):
                            """
                            Specify the importance at which the event 
                            should be sent when it recurs
                            
                            .. attribute:: range  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: at
                            
                            	Specify the time(s) this level setting should occur
                            	**type**\:  :py:class:`At <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence.Importance.At>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence.Importance, self).__init__()

                                self.yang_name = "importance"
                                self.yang_parent_name = "recurrence"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("at", ("at", Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence.Importance.At))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.at = Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence.Importance.At()
                                self.at.parent = self
                                self._children_name_map["at"] = "at"
                                self._segment_path = lambda: "importance" + "[range='" + str(self.range) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence.Importance, [u'range'], name, value)


                            class At(Entity):
                                """
                                Specify the time(s) this level setting should occur
                                
                                .. attribute:: minute
                                
                                	cron format of minute(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..59
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: hour
                                
                                	cron format of hour(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..23
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: day
                                
                                	cron format of day(s) of month
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..31
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: month
                                
                                	cron format of month(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..12
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: weekday
                                
                                	cron format of weekday(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..7
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence.Importance.At, self).__init__()

                                    self.yang_name = "at"
                                    self.yang_parent_name = "importance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minute', (YLeaf(YType.str, 'minute'), ['int','str'])),
                                        ('hour', (YLeaf(YType.str, 'hour'), ['int','str'])),
                                        ('day', (YLeaf(YType.str, 'day'), ['int','str'])),
                                        ('month', (YLeaf(YType.str, 'month'), ['int','str'])),
                                        ('weekday', (YLeaf(YType.str, 'weekday'), ['int','str'])),
                                    ])
                                    self.minute = None
                                    self.hour = None
                                    self.day = None
                                    self.month = None
                                    self.weekday = None
                                    self._segment_path = lambda: "at"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Energywise.Level.Recurrence.Importance.At, [u'minute', u'hour', u'day', u'month', u'weekday'], name, value)


            class Location(Entity):
                """
                Interface location information
                
                .. attribute:: civic_location_id
                
                	Civic location information
                	**type**\:  :py:class:`CivicLocationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Location.CivicLocationId>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Location, self).__init__()

                    self.yang_name = "location"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("civic-location-id", ("civic_location_id", Native.Interface.TenGigabitEthernet.Location.CivicLocationId))])
                    self._leafs = OrderedDict()

                    self.civic_location_id = Native.Interface.TenGigabitEthernet.Location.CivicLocationId()
                    self.civic_location_id.parent = self
                    self._children_name_map["civic_location_id"] = "civic-location-id"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:location"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Location, [], name, value)


                class CivicLocationId(Entity):
                    """
                    Civic location information
                    
                    .. attribute:: location_identifier
                    
                    	civic location identifier string
                    	**type**\: str
                    
                    .. attribute:: host
                    
                    	Globally defined host location identifer
                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Location.CivicLocationId.Host>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: none
                    
                    	No globally defined location identifer
                    	**type**\:  :py:class:`Y_None <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Location.CivicLocationId.Y_None>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Location.CivicLocationId, self).__init__()

                        self.yang_name = "civic-location-id"
                        self.yang_parent_name = "location"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("host", ("host", Native.Interface.TenGigabitEthernet.Location.CivicLocationId.Host)), ("none", ("none", Native.Interface.TenGigabitEthernet.Location.CivicLocationId.Y_None))])
                        self._leafs = OrderedDict([
                            ('location_identifier', (YLeaf(YType.str, 'location-identifier'), ['str'])),
                        ])
                        self.location_identifier = None

                        self.host = None
                        self._children_name_map["host"] = "host"

                        self.none = None
                        self._children_name_map["none"] = "none"
                        self._segment_path = lambda: "civic-location-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Location.CivicLocationId, [u'location_identifier'], name, value)


                    class Host(Entity):
                        """
                        Globally defined host location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Location.CivicLocationId.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "host"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Location.CivicLocationId.Host, [u'port_location'], name, value)


                    class Y_None(Entity):
                        """
                        No globally defined location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Location.CivicLocationId.Y_None, self).__init__()

                            self.yang_name = "none"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Location.CivicLocationId.Y_None, [u'port_location'], name, value)


            class Mac(Entity):
                """
                MAC interface commands
                
                .. attribute:: access_group
                
                	MAC access\-group configuration commands
                	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mac.AccessGroup>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Mac, self).__init__()

                    self.yang_name = "mac"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.TenGigabitEthernet.Mac.AccessGroup))])
                    self._leafs = OrderedDict()

                    self.access_group = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:mac"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Mac, [], name, value)


                class AccessGroup(Entity):
                    """
                    MAC access\-group configuration commands
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mac.AccessGroup.Direction>`
                    
                    .. attribute:: acl_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Mac.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "mac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Mac.AccessGroup.Direction')])),
                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                        ])
                        self.direction = None
                        self.acl_name = None
                        self._segment_path = lambda: "access-group" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Mac.AccessGroup, [u'direction', u'acl_name'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Macro(Entity):
                """
                Command macro
                
                .. attribute:: description
                
                	Macro description for this interface
                	**type**\: str
                
                .. attribute:: auto
                
                	Smartport interface macro configurations
                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Macro.Auto>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Macro, self).__init__()

                    self.yang_name = "macro"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.TenGigabitEthernet.Macro.Auto))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.auto = Native.Interface.TenGigabitEthernet.Macro.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "auto"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macro"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Macro, [u'description'], name, value)


                class Auto(Entity):
                    """
                    Smartport interface macro configurations
                    
                    .. attribute:: processing
                    
                    	Enable smartport macro auto execution on this interface
                    	**type**\: bool
                    
                    .. attribute:: port
                    
                    	Provide interface specific configuration for macro processing
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Macro.Auto.Port>`
                    
                    .. attribute:: control
                    
                    	Control macro auto execution
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Macro.Auto.Control>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Macro.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "macro"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port", ("port", Native.Interface.TenGigabitEthernet.Macro.Auto.Port)), ("control", ("control", Native.Interface.TenGigabitEthernet.Macro.Auto.Control))])
                        self._leafs = OrderedDict([
                            ('processing', (YLeaf(YType.boolean, 'processing'), ['bool'])),
                        ])
                        self.processing = None

                        self.port = Native.Interface.TenGigabitEthernet.Macro.Auto.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.control = Native.Interface.TenGigabitEthernet.Macro.Auto.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"
                        self._segment_path = lambda: "auto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Macro.Auto, [u'processing'], name, value)


                    class Port(Entity):
                        """
                        Provide interface specific configuration for macro processing
                        
                        .. attribute:: sticky
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Macro.Auto.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                            ])
                            self.sticky = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Macro.Auto.Port, [u'sticky'], name, value)


                    class Control(Entity):
                        """
                        Control macro auto execution
                        
                        .. attribute:: device
                        
                        	Enable macro auto execution for devices
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Macro.Auto.Control.Device>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Macro.Auto.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("device", ("device", Native.Interface.TenGigabitEthernet.Macro.Auto.Control.Device))])
                            self._leafs = OrderedDict()

                            self.device = Native.Interface.TenGigabitEthernet.Macro.Auto.Control.Device()
                            self.device.parent = self
                            self._children_name_map["device"] = "device"
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Macro.Auto.Control, [], name, value)


                        class Device(Entity):
                            """
                            Enable macro auto execution for devices
                            
                            .. attribute:: phone
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Macro.Auto.Control.Device, self).__init__()

                                self.yang_name = "device"
                                self.yang_parent_name = "control"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('phone', (YLeaf(YType.empty, 'phone'), ['Empty'])),
                                ])
                                self.phone = None
                                self._segment_path = lambda: "device"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Macro.Auto.Control.Device, [u'phone'], name, value)


            class DualActive(Entity):
                """
                
                
                .. attribute:: fast_hello
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.DualActive, self).__init__()

                    self.yang_name = "dual-active"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fast_hello', (YLeaf(YType.empty, 'fast-hello'), ['Empty'])),
                    ])
                    self.fast_hello = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:dual-active"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.DualActive, [u'fast_hello'], name, value)


            class LoadBalancing(Entity):
                """
                Etherchannel Load\-Balancing
                
                .. attribute:: flow
                
                	Based on the traffic flows identified by the packet headers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Based on the VLAN to member links manual configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.LoadBalancing, self).__init__()

                    self.yang_name = "load-balancing"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('flow', (YLeaf(YType.empty, 'flow'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.flow = None
                    self.vlan = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:load-balancing"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.LoadBalancing, [u'flow', u'vlan'], name, value)


            class VlanRange(Entity):
                """
                
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4096
                
                		**type**\: str
                
                .. attribute:: service_policy
                
                	Configure QoS Service Policy
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.VlanRange.ServicePolicy>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.VlanRange, self).__init__()

                    self.yang_name = "vlan-range"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.TenGigabitEthernet.VlanRange.ServicePolicy))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                    ])
                    self.id = None

                    self.service_policy = Native.Interface.TenGigabitEthernet.VlanRange.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:vlan-range" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.VlanRange, [u'id'], name, value)


                class ServicePolicy(Entity):
                    """
                    Configure QoS Service Policy
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.VlanRange.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "vlan-range"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.VlanRange.ServicePolicy, [u'input', u'output'], name, value)


            class Switch(Entity):
                """
                
                
                .. attribute:: virtual
                
                	
                	**type**\:  :py:class:`Virtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Switch.Virtual>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("virtual", ("virtual", Native.Interface.TenGigabitEthernet.Switch.Virtual))])
                    self._leafs = OrderedDict()

                    self.virtual = Native.Interface.TenGigabitEthernet.Switch.Virtual()
                    self.virtual.parent = self
                    self._children_name_map["virtual"] = "virtual"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:switch"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Switch, [], name, value)


                class Virtual(Entity):
                    """
                    
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Switch.Virtual, self).__init__()

                        self.yang_name = "virtual"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ])
                        self.link = None
                        self._segment_path = lambda: "virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Switch.Virtual, [u'link'], name, value)


            class SrrQueue(Entity):
                """
                
                
                .. attribute:: bandwidth
                
                	
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.SrrQueue, self).__init__()

                    self.yang_name = "srr-queue"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth))])
                    self._leafs = OrderedDict()

                    self.bandwidth = Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:srr-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.SrrQueue, [], name, value)


                class Bandwidth(Entity):
                    """
                    
                    
                    .. attribute:: shape
                    
                    	
                    	**type**\:  :py:class:`Shape <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth.Shape>`
                    
                    .. attribute:: share
                    
                    	
                    	**type**\:  :py:class:`Share <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth.Share>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "srr-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("shape", ("shape", Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth.Shape)), ("share", ("share", Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth.Share))])
                        self._leafs = OrderedDict()

                        self.shape = Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"

                        self.share = Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth.Share()
                        self.share.parent = self
                        self._children_name_map["share"] = "share"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth, [], name, value)


                    class Shape(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint16, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint16, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint16, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint16, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "shape"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth.Shape, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


                    class Share(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth.Share, self).__init__()

                            self.yang_name = "share"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint8, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint8, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint8, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint8, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "share"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.SrrQueue.Bandwidth.Share, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


            class CiscoIOSXESwitchMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection>`
                    
                    .. attribute:: network_link
                    
                    	Enable macsec on switch connected interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('network_link', (YLeaf(YType.empty, 'network-link'), ['Empty'])),
                        ])
                        self.network_link = None

                        self.replay_protection = Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec, [u'network_link'], name, value)


                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, [u'window_size'], name, value)


            class DeviceTracking(Entity):
                """
                Configure device\-tracking on the interface
                
                .. attribute:: attach_policy
                
                	Apply a policy for feature device\-tracking
                	**type**\: str
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.DeviceTracking, self).__init__()

                    self.yang_name = "device-tracking"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                    ])
                    self.attach_policy = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:device-tracking"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.DeviceTracking, [u'attach_policy'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.TenGigabitEthernet.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.TenGigabitEthernet.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.TenGigabitEthernet.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.TenGigabitEthernet.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.TenGigabitEthernet.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.TenGigabitEthernet.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.TenGigabitEthernet.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.TenGigabitEthernet.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class Mka(Entity):
                """
                MACsec Key Agreement (MKA) interface configuration
                
                .. attribute:: policy
                
                	Apply MKA Policy
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mka.Policy>`
                
                .. attribute:: pre_shared_key
                
                	Configure MKA Pre\-Shared\-Key
                	**type**\:  :py:class:`PreSharedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mka.PreSharedKey>`
                
                

                """

                _prefix = 'ios-mka'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Mka, self).__init__()

                    self.yang_name = "mka"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.TenGigabitEthernet.Mka.Policy)), ("pre-shared-key", ("pre_shared_key", Native.Interface.TenGigabitEthernet.Mka.PreSharedKey))])
                    self._leafs = OrderedDict()

                    self.policy = Native.Interface.TenGigabitEthernet.Mka.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.pre_shared_key = Native.Interface.TenGigabitEthernet.Mka.PreSharedKey()
                    self.pre_shared_key.parent = self
                    self._children_name_map["pre_shared_key"] = "pre-shared-key"
                    self._segment_path = lambda: "Cisco-IOS-XE-mka:mka"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Mka, [], name, value)


                class Policy(Entity):
                    """
                    Apply MKA Policy
                    
                    .. attribute:: name
                    
                    	MKA Policy NAME
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Mka.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Mka.Policy, ['name'], name, value)


                class PreSharedKey(Entity):
                    """
                    Configure MKA Pre\-Shared\-Key
                    
                    .. attribute:: key_chain
                    
                    	Configure the key\-chain name
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mka.PreSharedKey.KeyChain>`
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Mka.PreSharedKey, self).__init__()

                        self.yang_name = "pre-shared-key"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.TenGigabitEthernet.Mka.PreSharedKey.KeyChain))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.TenGigabitEthernet.Mka.PreSharedKey.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"
                        self._segment_path = lambda: "pre-shared-key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Mka.PreSharedKey, [], name, value)


                    class KeyChain(Entity):
                        """
                        Configure the key\-chain name
                        
                        .. attribute:: name
                        
                        	Name of key\-chain to be used to get keys
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mka'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Mka.PreSharedKey.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "pre-shared-key"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Mka.PreSharedKey.KeyChain, ['name'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Utd, ['enable'], name, value)


            class Xconnect(Entity):
                """
                Xconnect commands
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: vcid
                
                	
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: encapsulation
                
                	Data encapsulation method
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Xconnect.Encapsulation>`
                
                .. attribute:: manual
                
                	Manually configure L2TP session parameters
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sequence
                
                	Configure sequencing options for xconnect
                	**type**\:  :py:class:`Sequence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Xconnect.Sequence>`
                
                .. attribute:: pw_class
                
                	Pseudowire\-class to use for encapsulation and protocol configuration
                	**type**\: str
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Xconnect.Encapsulation')])),
                        ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                        ('sequence', (YLeaf(YType.enumeration, 'sequence'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Xconnect.Sequence')])),
                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                    ])
                    self.address = None
                    self.vcid = None
                    self.encapsulation = None
                    self.manual = None
                    self.sequence = None
                    self.pw_class = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'sequence', 'pw_class'], name, value)

                class Encapsulation(Enum):
                    """
                    Encapsulation (Enum Class)

                    Data encapsulation method

                    .. data:: mpls = 0

                    .. data:: l2tpv3 = 1

                    """

                    mpls = Enum.YLeaf(0, "mpls")

                    l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                class Sequence(Enum):
                    """
                    Sequence (Enum Class)

                    Configure sequencing options for xconnect

                    .. data:: both = 0

                    .. data:: receive = 1

                    .. data:: transmit = 2

                    """

                    both = Enum.YLeaf(0, "both")

                    receive = Enum.YLeaf(1, "receive")

                    transmit = Enum.YLeaf(2, "transmit")



            class Evpn(Entity):
                """
                
                
                .. attribute:: ethernet_segment
                
                	Ethernet segment local discriminator value
                	**type**\: list of  		 :py:class:`EthernetSegment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Evpn, self).__init__()

                    self.yang_name = "evpn"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet-segment", ("ethernet_segment", Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment))])
                    self._leafs = OrderedDict()

                    self.ethernet_segment = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:evpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Evpn, [], name, value)


                class EthernetSegment(Entity):
                    """
                    Ethernet segment local discriminator value
                    
                    .. attribute:: es_value  (key)
                    
                    	Ethernet segment local discriminator value
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: df_election
                    
                    	Designated forwarder election parameters
                    	**type**\:  :py:class:`DfElection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment.DfElection>`
                    
                    .. attribute:: redundancy
                    
                    	Multi\-homing redundancy parameters
                    	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment.Redundancy>`
                    
                    .. attribute:: sytem_mac
                    
                    	System MAC address for generating the Ethernet Segment ID
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment, self).__init__()

                        self.yang_name = "ethernet-segment"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['es_value']
                        self._child_classes = OrderedDict([("df-election", ("df_election", Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment.DfElection)), ("redundancy", ("redundancy", Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment.Redundancy))])
                        self._leafs = OrderedDict([
                            ('es_value', (YLeaf(YType.uint16, 'es-value'), ['int'])),
                            ('sytem_mac', (YLeaf(YType.str, 'sytem-mac'), ['str'])),
                        ])
                        self.es_value = None
                        self.sytem_mac = None

                        self.df_election = Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment.DfElection()
                        self.df_election.parent = self
                        self._children_name_map["df_election"] = "df-election"

                        self.redundancy = Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                        self._segment_path = lambda: "ethernet-segment" + "[es-value='" + str(self.es_value) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment, ['es_value', 'sytem_mac'], name, value)


                    class DfElection(Entity):
                        """
                        Designated forwarder election parameters
                        
                        .. attribute:: wait_time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment.DfElection, self).__init__()

                            self.yang_name = "df-election"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wait_time', (YLeaf(YType.uint8, 'wait-time'), ['int'])),
                            ])
                            self.wait_time = None
                            self._segment_path = lambda: "df-election"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment.DfElection, ['wait_time'], name, value)


                    class Redundancy(Entity):
                        """
                        Multi\-homing redundancy parameters
                        
                        .. attribute:: all_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: single_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment.Redundancy, self).__init__()

                            self.yang_name = "redundancy"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all_active', (YLeaf(YType.empty, 'all-active'), ['Empty'])),
                                ('single_active', (YLeaf(YType.empty, 'single-active'), ['Empty'])),
                            ])
                            self.all_active = None
                            self.single_active = None
                            self._segment_path = lambda: "redundancy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Evpn.EthernetSegment.Redundancy, ['all_active', 'single_active'], name, value)


            class FabricDomain(Entity):
                """
                Fabric\-domain interface command
                
                .. attribute:: iwan_fabric
                
                	
                	**type**\:  :py:class:`IwanFabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.FabricDomain.IwanFabric>`
                
                

                """

                _prefix = 'ios-iwanfabric'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.FabricDomain, self).__init__()

                    self.yang_name = "fabric-domain"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("iwan-fabric", ("iwan_fabric", Native.Interface.TenGigabitEthernet.FabricDomain.IwanFabric))])
                    self._leafs = OrderedDict()

                    self.iwan_fabric = Native.Interface.TenGigabitEthernet.FabricDomain.IwanFabric()
                    self.iwan_fabric.parent = self
                    self._children_name_map["iwan_fabric"] = "iwan-fabric"
                    self._segment_path = lambda: "Cisco-IOS-XE-iwanfabric:fabric-domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.FabricDomain, [], name, value)


                class IwanFabric(Entity):
                    """
                    
                    
                    .. attribute:: word
                    
                    	
                    	**type**\: list of  		 :py:class:`Word <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.FabricDomain.IwanFabric.Word>`
                    
                    

                    """

                    _prefix = 'ios-iwanfabric'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.FabricDomain.IwanFabric, self).__init__()

                        self.yang_name = "iwan-fabric"
                        self.yang_parent_name = "fabric-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("word", ("word", Native.Interface.TenGigabitEthernet.FabricDomain.IwanFabric.Word))])
                        self._leafs = OrderedDict()

                        self.word = YList(self)
                        self._segment_path = lambda: "iwan-fabric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.FabricDomain.IwanFabric, [], name, value)


                    class Word(Entity):
                        """
                        
                        
                        .. attribute:: word  (key)
                        
                        	Path name
                        	**type**\: str
                        
                        .. attribute:: interface_id
                        
                        	Specify the interface\-id value
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-iwanfabric'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.FabricDomain.IwanFabric.Word, self).__init__()

                            self.yang_name = "word"
                            self.yang_parent_name = "iwan-fabric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                            ])
                            self.word = None
                            self.interface_id = None
                            self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.FabricDomain.IwanFabric.Word, ['word', 'interface_id'], name, value)


            class Mvrp(Entity):
                """
                
                
                .. attribute:: mvrp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: registration
                
                	
                	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mvrp.Registration>`
                
                .. attribute:: timer
                
                	
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mvrp.Timer>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mvrp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Mvrp, self).__init__()

                    self.yang_name = "mvrp"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("registration", ("registration", Native.Interface.TenGigabitEthernet.Mvrp.Registration)), ("timer", ("timer", Native.Interface.TenGigabitEthernet.Mvrp.Timer))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mvrp', (YLeaf(YType.empty, 'mvrp'), ['Empty'])),
                    ])
                    self.mvrp = None

                    self.registration = Native.Interface.TenGigabitEthernet.Mvrp.Registration()
                    self.registration.parent = self
                    self._children_name_map["registration"] = "registration"

                    self.timer = Native.Interface.TenGigabitEthernet.Mvrp.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-mvrp:mvrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Mvrp, ['mvrp'], name, value)


                class Registration(Entity):
                    """
                    
                    
                    .. attribute:: fixed
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: forbidden
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: normal
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Mvrp.Registration, self).__init__()

                        self.yang_name = "registration"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fixed', (YLeaf(YType.empty, 'fixed'), ['Empty'])),
                            ('forbidden', (YLeaf(YType.empty, 'forbidden'), ['Empty'])),
                            ('normal', (YLeaf(YType.empty, 'normal'), ['Empty'])),
                        ])
                        self.fixed = None
                        self.forbidden = None
                        self.normal = None
                        self._segment_path = lambda: "registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Mvrp.Registration, ['fixed', 'forbidden', 'normal'], name, value)


                class Timer(Entity):
                    """
                    
                    
                    .. attribute:: join
                    
                    	
                    	**type**\:  :py:class:`Join <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mvrp.Timer.Join>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave
                    
                    	
                    	**type**\:  :py:class:`Leave <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mvrp.Timer.Leave>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave_all
                    
                    	
                    	**type**\:  :py:class:`LeaveAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Mvrp.Timer.LeaveAll>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: periodic
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Mvrp.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("join", ("join", Native.Interface.TenGigabitEthernet.Mvrp.Timer.Join)), ("leave", ("leave", Native.Interface.TenGigabitEthernet.Mvrp.Timer.Leave)), ("leave-all", ("leave_all", Native.Interface.TenGigabitEthernet.Mvrp.Timer.LeaveAll))])
                        self._leafs = OrderedDict([
                            ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ])
                        self.periodic = None

                        self.join = None
                        self._children_name_map["join"] = "join"

                        self.leave = None
                        self._children_name_map["leave"] = "leave"

                        self.leave_all = None
                        self._children_name_map["leave_all"] = "leave-all"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Mvrp.Timer, ['periodic'], name, value)


                    class Join(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 20..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Mvrp.Timer.Join, self).__init__()

                            self.yang_name = "join"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "join"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Mvrp.Timer.Join, ['y_range'], name, value)


                    class Leave(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Mvrp.Timer.Leave, self).__init__()

                            self.yang_name = "leave"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Mvrp.Timer.Leave, ['y_range'], name, value)


                    class LeaveAll(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1000..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Mvrp.Timer.LeaveAll, self).__init__()

                            self.yang_name = "leave-all"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave-all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Mvrp.Timer.LeaveAll, ['y_range'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.TenGigabitEthernet.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.TenGigabitEthernet.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.TenGigabitEthernet.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.TenGigabitEthernet.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.TenGigabitEthernet.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.TenGigabitEthernet.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.TenGigabitEthernet.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.TenGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Power(Entity):
                """
                
                
                .. attribute:: inline
                
                	
                	**type**\:  :py:class:`Inline <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Power.Inline>`
                
                

                """

                _prefix = 'ios-power'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Power, self).__init__()

                    self.yang_name = "power"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("inline", ("inline", Native.Interface.TenGigabitEthernet.Power.Inline))])
                    self._leafs = OrderedDict()

                    self.inline = Native.Interface.TenGigabitEthernet.Power.Inline()
                    self.inline.parent = self
                    self._children_name_map["inline"] = "inline"
                    self._segment_path = lambda: "Cisco-IOS-XE-power:power"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Power, [], name, value)


                class Inline(Entity):
                    """
                    
                    
                    .. attribute:: consumption
                    
                    	
                    	**type**\: int
                    
                    	**range:** 4000..15400
                    
                    .. attribute:: never
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: auto
                    
                    	Automatically detect and power inline devices
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Power.Inline.Auto>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: four_pair
                    
                    	Four\-pair PoE power
                    	**type**\:  :py:class:`FourPair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Power.Inline.FourPair>`
                    
                    .. attribute:: police
                    
                    	Police the power drawn on the port
                    	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Power.Inline.Police>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: port
                    
                    	Configure Port Power Level
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Power.Inline.Port>`
                    
                    .. attribute:: static
                    
                    	High priority inline power interface
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Power.Inline.Static>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-power'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Power.Inline, self).__init__()

                        self.yang_name = "inline"
                        self.yang_parent_name = "power"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.TenGigabitEthernet.Power.Inline.Auto)), ("four-pair", ("four_pair", Native.Interface.TenGigabitEthernet.Power.Inline.FourPair)), ("police", ("police", Native.Interface.TenGigabitEthernet.Power.Inline.Police)), ("port", ("port", Native.Interface.TenGigabitEthernet.Power.Inline.Port)), ("static", ("static", Native.Interface.TenGigabitEthernet.Power.Inline.Static))])
                        self._leafs = OrderedDict([
                            ('consumption', (YLeaf(YType.uint16, 'consumption'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.consumption = None
                        self.never = None

                        self.auto = None
                        self._children_name_map["auto"] = "auto"

                        self.four_pair = Native.Interface.TenGigabitEthernet.Power.Inline.FourPair()
                        self.four_pair.parent = self
                        self._children_name_map["four_pair"] = "four-pair"

                        self.police = None
                        self._children_name_map["police"] = "police"

                        self.port = Native.Interface.TenGigabitEthernet.Power.Inline.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.static = None
                        self._children_name_map["static"] = "static"
                        self._segment_path = lambda: "inline"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Power.Inline, ['consumption', 'never'], name, value)


                    class Auto(Entity):
                        """
                        Automatically detect and power inline devices
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Power.Inline.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "auto"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Power.Inline.Auto, ['max'], name, value)


                    class FourPair(Entity):
                        """
                        Four\-pair PoE power
                        
                        .. attribute:: forced
                        
                        	Enable Four\-pair PoE without L2 negotiation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Power.Inline.FourPair, self).__init__()

                            self.yang_name = "four-pair"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forced', (YLeaf(YType.empty, 'forced'), ['Empty'])),
                            ])
                            self.forced = None
                            self._segment_path = lambda: "four-pair"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Power.Inline.FourPair, ['forced'], name, value)


                    class Police(Entity):
                        """
                        Police the power drawn on the port
                        
                        .. attribute:: action
                        
                        	Action to be taken when power is overdrawn on the port
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Power.Inline.Police.Action>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Power.Inline.Police, self).__init__()

                            self.yang_name = "police"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.TenGigabitEthernet.Power.Inline.Police.Action))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.TenGigabitEthernet.Power.Inline.Police.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "police"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Power.Inline.Police, [], name, value)


                        class Action(Entity):
                            """
                            Action to be taken when power is overdrawn on the port
                            
                            .. attribute:: errdisable
                            
                            	Error\-disable the port when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log a message when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-power'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Power.Inline.Police.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "police"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('errdisable', (YLeaf(YType.empty, 'errdisable'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ])
                                self.errdisable = None
                                self.log = None
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Power.Inline.Police.Action, ['errdisable', 'log'], name, value)


                    class Port(Entity):
                        """
                        Configure Port Power Level
                        
                        .. attribute:: poe_ha
                        
                        	Apply poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: perpetual_poe_ha
                        
                        	Apply perpetual\-poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: two_event
                        
                        	Enable 2\-event classification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Power.Inline.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('poe_ha', (YLeaf(YType.empty, 'poe-ha'), ['Empty'])),
                                ('perpetual_poe_ha', (YLeaf(YType.empty, 'perpetual-poe-ha'), ['Empty'])),
                                ('two_event', (YLeaf(YType.empty, 'two-event'), ['Empty'])),
                            ])
                            self.poe_ha = None
                            self.perpetual_poe_ha = None
                            self.two_event = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Power.Inline.Port, ['poe_ha', 'perpetual_poe_ha', 'two_event'], name, value)


                    class Static(Entity):
                        """
                        High priority inline power interface
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Power.Inline.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "static"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Power.Inline.Static, ['max'], name, value)


            class Cdp(Entity):
                """
                CDP interface subcommands
                
                .. attribute:: enable
                
                	Enable CDP on interface
                	**type**\: bool
                
                .. attribute:: tlv
                
                	Enable exchange of specific tlv information
                	**type**\:  :py:class:`Tlv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cdp.Tlv>`
                
                

                """

                _prefix = 'ios-cdp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Cdp, self).__init__()

                    self.yang_name = "cdp"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tlv", ("tlv", Native.Interface.TenGigabitEthernet.Cdp.Tlv))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                    ])
                    self.enable = None

                    self.tlv = Native.Interface.TenGigabitEthernet.Cdp.Tlv()
                    self.tlv.parent = self
                    self._children_name_map["tlv"] = "tlv"
                    self._segment_path = lambda: "Cisco-IOS-XE-cdp:cdp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Cdp, ['enable'], name, value)


                class Tlv(Entity):
                    """
                    Enable exchange of specific tlv information
                    
                    .. attribute:: app
                    
                    	Enable/Configure Application TLV
                    	**type**\:  :py:class:`App <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cdp.Tlv.App>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: server_location
                    
                    	Enable CDP location server on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	Exchange location information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cdp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Cdp.Tlv, self).__init__()

                        self.yang_name = "tlv"
                        self.yang_parent_name = "cdp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("app", ("app", Native.Interface.TenGigabitEthernet.Cdp.Tlv.App))])
                        self._leafs = OrderedDict([
                            ('server_location', (YLeaf(YType.empty, 'server-location'), ['Empty'])),
                            ('location', (YLeaf(YType.empty, 'location'), ['Empty'])),
                        ])
                        self.server_location = None
                        self.location = None

                        self.app = None
                        self._children_name_map["app"] = "app"
                        self._segment_path = lambda: "tlv"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Cdp.Tlv, ['server_location', 'location'], name, value)


                    class App(Entity):
                        """
                        Enable/Configure Application TLV
                        
                        .. attribute:: tlvtype
                        
                        	Configure APP TLV
                        	**type**\: int
                        
                        	**range:** 1001..65535
                        
                        .. attribute:: value
                        
                        	Configure App TLV Value information
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cdp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Cdp.Tlv.App, self).__init__()

                            self.yang_name = "app"
                            self.yang_parent_name = "tlv"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tlvtype', (YLeaf(YType.uint16, 'tlvtype'), ['int'])),
                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                            ])
                            self.tlvtype = None
                            self.value = None
                            self._segment_path = lambda: "app"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Cdp.Tlv.App, ['tlvtype', 'value'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.TenGigabitEthernet.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.TenGigabitEthernet.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.TenGigabitEthernet.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.TenGigabitEthernet.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class Authentication(Entity):
                """
                Auth Manager Interface Configuration Commands
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.ControlDirection>`
                
                .. attribute:: event
                
                	Set action for authentication events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event>`
                
                .. attribute:: fallback
                
                	Enable the Webauth fallback mechanism
                	**type**\: str
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.HostMode>`
                
                .. attribute:: open
                
                	Enable or Disable open access on this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: order
                
                	Add an authentication method to the order list
                	**type**\:  :py:class:`Order <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Order>`
                
                .. attribute:: priority
                
                	Add an authentication method to the priority list
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Priority>`
                
                .. attribute:: port_control
                
                	set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.PortControl>`
                
                .. attribute:: periodic
                
                	Enable or Disable Reauthentication for this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timer
                
                	Set authentication timer values
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Timer>`
                
                .. attribute:: violation
                
                	Configure action to take on security violations
                	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Violation>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.TenGigabitEthernet.Authentication.Event)), ("order", ("order", Native.Interface.TenGigabitEthernet.Authentication.Order)), ("priority", ("priority", Native.Interface.TenGigabitEthernet.Authentication.Priority)), ("timer", ("timer", Native.Interface.TenGigabitEthernet.Authentication.Timer))])
                    self._leafs = OrderedDict([
                        ('control_direction', (YLeaf(YType.enumeration, 'control-direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Authentication.ControlDirection')])),
                        ('fallback', (YLeaf(YType.str, 'fallback'), ['str'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Authentication.HostMode')])),
                        ('open', (YLeaf(YType.empty, 'open'), ['Empty'])),
                        ('port_control', (YLeaf(YType.enumeration, 'port-control'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Authentication.PortControl')])),
                        ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Authentication.Violation')])),
                    ])
                    self.control_direction = None
                    self.fallback = None
                    self.host_mode = None
                    self.open = None
                    self.port_control = None
                    self.periodic = None
                    self.violation = None

                    self.event = Native.Interface.TenGigabitEthernet.Authentication.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.order = Native.Interface.TenGigabitEthernet.Authentication.Order()
                    self.order.parent = self
                    self._children_name_map["order"] = "order"

                    self.priority = Native.Interface.TenGigabitEthernet.Authentication.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "priority"

                    self.timer = Native.Interface.TenGigabitEthernet.Authentication.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:authentication"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication, ['control_direction', 'fallback', 'host_mode', 'open', 'port_control', 'periodic', 'violation'], name, value)

                class ControlDirection(Enum):
                    """
                    ControlDirection (Enum Class)

                    Set the control\-direction on the interface

                    .. data:: both = 0

                    .. data:: in_ = 1

                    """

                    both = Enum.YLeaf(0, "both")

                    in_ = Enum.YLeaf(1, "in")


                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")


                class PortControl(Enum):
                    """
                    PortControl (Enum Class)

                    set the port\-control value

                    .. data:: auto = 0

                    .. data:: force_authorized = 1

                    .. data:: force_unauthorized = 2

                    """

                    auto = Enum.YLeaf(0, "auto")

                    force_authorized = Enum.YLeaf(1, "force-authorized")

                    force_unauthorized = Enum.YLeaf(2, "force-unauthorized")


                class Violation(Enum):
                    """
                    Violation (Enum Class)

                    Configure action to take on security violations

                    .. data:: protect = 0

                    .. data:: replace = 1

                    .. data:: restrict = 2

                    .. data:: shutdown = 3

                    """

                    protect = Enum.YLeaf(0, "protect")

                    replace = Enum.YLeaf(1, "replace")

                    restrict = Enum.YLeaf(2, "restrict")

                    shutdown = Enum.YLeaf(3, "shutdown")



                class Event(Entity):
                    """
                    Set action for authentication events
                    
                    .. attribute:: server
                    
                    	Configure actions for AAA server events
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.Server>`
                    
                    .. attribute:: fail
                    
                    	Configure actions for AAA fail events
                    	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.Fail>`
                    
                    .. attribute:: no_response
                    
                    	Configure actions for AAA no\-response events
                    	**type**\:  :py:class:`NoResponse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Authentication.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("server", ("server", Native.Interface.TenGigabitEthernet.Authentication.Event.Server)), ("fail", ("fail", Native.Interface.TenGigabitEthernet.Authentication.Event.Fail)), ("no-response", ("no_response", Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse))])
                        self._leafs = OrderedDict()

                        self.server = Native.Interface.TenGigabitEthernet.Authentication.Event.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.fail = Native.Interface.TenGigabitEthernet.Authentication.Event.Fail()
                        self.fail.parent = self
                        self._children_name_map["fail"] = "fail"

                        self.no_response = Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse()
                        self.no_response.parent = self
                        self._children_name_map["no_response"] = "no-response"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event, [], name, value)


                    class Server(Entity):
                        """
                        Configure actions for AAA server events
                        
                        .. attribute:: alive
                        
                        	Configure AAA server alive action
                        	**type**\:  :py:class:`Alive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Alive>`
                        
                        .. attribute:: dead
                        
                        	Configure AAA server dead action
                        	**type**\:  :py:class:`Dead <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Authentication.Event.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("alive", ("alive", Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Alive)), ("dead", ("dead", Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead))])
                            self._leafs = OrderedDict()

                            self.alive = Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Alive()
                            self.alive.parent = self
                            self._children_name_map["alive"] = "alive"

                            self.dead = Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead()
                            self.dead.parent = self
                            self._children_name_map["dead"] = "dead"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.Server, [], name, value)


                        class Alive(Entity):
                            """
                            Configure AAA server alive action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Alive.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Alive, self).__init__()

                                self.yang_name = "alive"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Alive.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Alive.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "alive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Alive, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all authorized clients
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Alive.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "alive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reinitialize', (YLeaf(YType.empty, 'reinitialize'), ['Empty'])),
                                    ])
                                    self.reinitialize = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Alive.Action, ['reinitialize'], name, value)


                        class Dead(Entity):
                            """
                            Configure AAA server dead action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead, self).__init__()

                                self.yang_name = "dead"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dead"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: authorize
                                
                                	Authorize the port
                                	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all client on the port
                                	**type**\:  :py:class:`Reinitialize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dead"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize)), ("reinitialize", ("reinitialize", Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize))])
                                    self._leafs = OrderedDict()

                                    self.authorize = None
                                    self._children_name_map["authorize"] = "authorize"

                                    self.reinitialize = Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize()
                                    self.reinitialize.parent = self
                                    self._children_name_map["reinitialize"] = "reinitialize"
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action, [], name, value)


                                class Authorize(Entity):
                                    """
                                    Authorize the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: voice
                                    
                                    	Authorize the port for VOICE traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize, self).__init__()

                                        self.yang_name = "authorize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ('voice', (YLeaf(YType.empty, 'voice'), ['Empty'])),
                                        ])
                                        self.vlan = None
                                        self.voice = None
                                        self._segment_path = lambda: "authorize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize, ['vlan', 'voice'], name, value)


                                class Reinitialize(Entity):
                                    """
                                    Reinitialize all client on the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, self).__init__()

                                        self.yang_name = "reinitialize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "reinitialize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, ['vlan'], name, value)


                    class Fail(Entity):
                        """
                        Configure actions for AAA fail events
                        
                        .. attribute:: action
                        
                        	Required action for fail event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.Fail.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Authentication.Event.Fail, self).__init__()

                            self.yang_name = "fail"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.TenGigabitEthernet.Authentication.Event.Fail.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.TenGigabitEthernet.Authentication.Event.Fail.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "fail"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.Fail, [], name, value)


                        class Action(Entity):
                            """
                            Required action for fail event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.Fail.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Authentication.Event.Fail.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "fail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.TenGigabitEthernet.Authentication.Event.Fail.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.TenGigabitEthernet.Authentication.Event.Fail.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.Fail.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Authentication.Event.Fail.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.Fail.Action.Authorize, ['vlan'], name, value)


                    class NoResponse(Entity):
                        """
                        Configure actions for AAA no\-response events
                        
                        .. attribute:: action
                        
                        	Required action for no\-response event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse, self).__init__()

                            self.yang_name = "no-response"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "no-response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse, [], name, value)


                        class Action(Entity):
                            """
                            Required action for no\-response event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "no-response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize, ['vlan'], name, value)


                class Order(Entity):
                    """
                    Add an authentication method to the order list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Authentication.Order, self).__init__()

                        self.yang_name = "order"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "order"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Order, ['dot1x', 'mab', 'webauth'], name, value)


                class Priority(Entity):
                    """
                    Add an authentication method to the priority list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Authentication.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Priority, ['dot1x', 'mab', 'webauth'], name, value)


                class Timer(Entity):
                    """
                    Set authentication timer values
                    
                    .. attribute:: reauthenticate
                    
                    	Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                    	**type**\:  :py:class:`Reauthenticate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Timer.Reauthenticate>`
                    
                    .. attribute:: inactivity
                    
                    	Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                    	**type**\:  :py:class:`Inactivity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity>`
                    
                    .. attribute:: restart
                    
                    	Interval in seconds after which an attempt should be made toauthenticate an unauthorized port (default 60 sec)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Authentication.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reauthenticate", ("reauthenticate", Native.Interface.TenGigabitEthernet.Authentication.Timer.Reauthenticate)), ("inactivity", ("inactivity", Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity))])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                        ])
                        self.restart = None

                        self.reauthenticate = Native.Interface.TenGigabitEthernet.Authentication.Timer.Reauthenticate()
                        self.reauthenticate.parent = self
                        self._children_name_map["reauthenticate"] = "reauthenticate"

                        self.inactivity = Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity()
                        self.inactivity.parent = self
                        self._children_name_map["inactivity"] = "inactivity"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Timer, ['restart'], name, value)


                    class Reauthenticate(Entity):
                        """
                        Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: server
                        
                        	Obtain re\-authentication timeout value from the server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Authentication.Timer.Reauthenticate, self).__init__()

                            self.yang_name = "reauthenticate"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                            ])
                            self.value = None
                            self.server = None
                            self._segment_path = lambda: "reauthenticate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Timer.Reauthenticate, ['value', 'server'], name, value)


                    class Inactivity(Entity):
                        """
                        Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity.Value>`
                        
                        .. attribute:: server
                        
                        	Obtain inactivity timeout value from the server
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity.Server>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity, self).__init__()

                            self.yang_name = "inactivity"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity.Value)), ("server", ("server", Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity.Server))])
                            self._leafs = OrderedDict()

                            self.value = Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.server = None
                            self._children_name_map["server"] = "server"
                            self._segment_path = lambda: "inactivity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity, [], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.value = None
                                self.dynamic = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity.Value, ['value', 'dynamic'], name, value)


                        class Server(Entity):
                            """
                            Obtain inactivity timeout value from the server
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.dynamic = None
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Authentication.Timer.Inactivity.Server, ['dynamic'], name, value)


            class Mab(Entity):
                """
                
                
                .. attribute:: eap
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Mab, self).__init__()

                    self.yang_name = "mab"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                    ])
                    self.eap = None
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:mab"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Mab, ['eap'], name, value)


            class Dot1x(Entity):
                """
                Interface Config Commands for IEEE 802.1X
                
                .. attribute:: authenticator
                
                	Configure authenticator parameters
                	**type**\:  :py:class:`Authenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Dot1x.Authenticator>`
                
                .. attribute:: credentials
                
                	Credentials profile configuration
                	**type**\: str
                
                .. attribute:: max_reauth_req
                
                	Max No. of Reauthentication Attempts
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_req
                
                	Max No. of Retries
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_start
                
                	Max No. of EAPOL\-Start requests
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: pae
                
                	Set 802.1x interface pae type
                	**type**\:  :py:class:`Pae <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Dot1x.Pae>`
                
                .. attribute:: supplicant
                
                	Configure supplicant parameters
                	**type**\:  :py:class:`Supplicant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Dot1x.Supplicant>`
                
                .. attribute:: timeout
                
                	Various Timeouts
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Dot1x.Timeout>`
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Dot1x, self).__init__()

                    self.yang_name = "dot1x"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authenticator", ("authenticator", Native.Interface.TenGigabitEthernet.Dot1x.Authenticator)), ("supplicant", ("supplicant", Native.Interface.TenGigabitEthernet.Dot1x.Supplicant)), ("timeout", ("timeout", Native.Interface.TenGigabitEthernet.Dot1x.Timeout))])
                    self._leafs = OrderedDict([
                        ('credentials', (YLeaf(YType.str, 'credentials'), ['str'])),
                        ('max_reauth_req', (YLeaf(YType.uint8, 'max-reauth-req'), ['int'])),
                        ('max_req', (YLeaf(YType.uint8, 'max-req'), ['int'])),
                        ('max_start', (YLeaf(YType.uint8, 'max-start'), ['int'])),
                        ('pae', (YLeaf(YType.enumeration, 'pae'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Dot1x.Pae')])),
                    ])
                    self.credentials = None
                    self.max_reauth_req = None
                    self.max_req = None
                    self.max_start = None
                    self.pae = None

                    self.authenticator = Native.Interface.TenGigabitEthernet.Dot1x.Authenticator()
                    self.authenticator.parent = self
                    self._children_name_map["authenticator"] = "authenticator"

                    self.supplicant = Native.Interface.TenGigabitEthernet.Dot1x.Supplicant()
                    self.supplicant.parent = self
                    self._children_name_map["supplicant"] = "supplicant"

                    self.timeout = Native.Interface.TenGigabitEthernet.Dot1x.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"
                    self._segment_path = lambda: "Cisco-IOS-XE-dot1x:dot1x"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Dot1x, ['credentials', 'max_reauth_req', 'max_req', 'max_start', 'pae'], name, value)

                class Pae(Enum):
                    """
                    Pae (Enum Class)

                    Set 802.1x interface pae type

                    .. data:: authenticator = 0

                    .. data:: supplicant = 1

                    .. data:: both = 2

                    """

                    authenticator = Enum.YLeaf(0, "authenticator")

                    supplicant = Enum.YLeaf(1, "supplicant")

                    both = Enum.YLeaf(2, "both")



                class Authenticator(Entity):
                    """
                    Configure authenticator parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP authenticator parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Dot1x.Authenticator.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Dot1x.Authenticator, self).__init__()

                        self.yang_name = "authenticator"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.TenGigabitEthernet.Dot1x.Authenticator.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.TenGigabitEthernet.Dot1x.Authenticator.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "authenticator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Dot1x.Authenticator, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP authenticator parameters
                        
                        .. attribute:: profile
                        
                        	EAP authenticator profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Dot1x.Authenticator.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "authenticator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Dot1x.Authenticator.Eap, ['profile'], name, value)


                class Supplicant(Entity):
                    """
                    Configure supplicant parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP supplicant parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Dot1x.Supplicant.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Dot1x.Supplicant, self).__init__()

                        self.yang_name = "supplicant"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.TenGigabitEthernet.Dot1x.Supplicant.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.TenGigabitEthernet.Dot1x.Supplicant.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "supplicant"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Dot1x.Supplicant, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP supplicant parameters
                        
                        .. attribute:: profile
                        
                        	EAP supplicant profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Dot1x.Supplicant.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "supplicant"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Dot1x.Supplicant.Eap, ['profile'], name, value)


                class Timeout(Entity):
                    """
                    Various Timeouts
                    
                    .. attribute:: auth_period
                    
                    	Timeout for authenticator reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: held_period
                    
                    	Timeout for authentication retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: quiet_period
                    
                    	QuietPeriod in Seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ratelimit_period
                    
                    	Ratelimit Period in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: server_timeout
                    
                    	Timeout for Radius Retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: start_period
                    
                    	Timeout for EAPOL\-start retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: supp_timeout
                    
                    	Timeout for supplicant reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: tx_period
                    
                    	Timeout for supplicant retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Dot1x.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auth_period', (YLeaf(YType.uint16, 'auth-period'), ['int'])),
                            ('held_period', (YLeaf(YType.uint16, 'held-period'), ['int'])),
                            ('quiet_period', (YLeaf(YType.uint16, 'quiet-period'), ['int'])),
                            ('ratelimit_period', (YLeaf(YType.uint16, 'ratelimit-period'), ['int'])),
                            ('server_timeout', (YLeaf(YType.uint16, 'server-timeout'), ['int'])),
                            ('start_period', (YLeaf(YType.uint16, 'start-period'), ['int'])),
                            ('supp_timeout', (YLeaf(YType.uint16, 'supp-timeout'), ['int'])),
                            ('tx_period', (YLeaf(YType.uint16, 'tx-period'), ['int'])),
                        ])
                        self.auth_period = None
                        self.held_period = None
                        self.quiet_period = None
                        self.ratelimit_period = None
                        self.server_timeout = None
                        self.start_period = None
                        self.supp_timeout = None
                        self.tx_period = None
                        self._segment_path = lambda: "timeout"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Dot1x.Timeout, ['auth_period', 'held_period', 'quiet_period', 'ratelimit_period', 'server_timeout', 'start_period', 'supp_timeout', 'tx_period'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpdufilter
                
                	Don't send or receive BPDUs on this interface
                	**type**\:  :py:class:`Bpdufilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SpanningTree.Bpdufilter>`
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SpanningTree.Bpduguard>`
                
                .. attribute:: cost
                
                	To set the path cost of the interface
                	**type**\: int
                
                	**range:** 1..200000000
                
                .. attribute:: guard
                
                	Change an interface's spanning tree guard mode
                	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SpanningTree.Guard>`
                
                .. attribute:: link_type
                
                	Specify a link type for spanning tree tree protocol use
                	**type**\:  :py:class:`LinkType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SpanningTree.LinkType>`
                
                .. attribute:: portfast
                
                	Spanning tree portfast options
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                .. attribute:: port_priority
                
                	Spanning tree port\-priority options
                	**type**\: int
                
                	**range:** 0..240
                
                .. attribute:: vlan
                
                	VLAN Switch Spanning Tree
                	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SpanningTree.Vlan>`
                
                .. attribute:: loopguard
                
                	Spanning tree loopguard options
                	**type**\:  :py:class:`Loopguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SpanningTree.Loopguard>`
                
                .. attribute:: mst
                
                	Per interface MST configurations
                	**type**\:  :py:class:`Mst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SpanningTree.Mst>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Interface.TenGigabitEthernet.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Interface.TenGigabitEthernet.SpanningTree.Portfast)), ("vlan", ("vlan", Native.Interface.TenGigabitEthernet.SpanningTree.Vlan)), ("loopguard", ("loopguard", Native.Interface.TenGigabitEthernet.SpanningTree.Loopguard)), ("mst", ("mst", Native.Interface.TenGigabitEthernet.SpanningTree.Mst))])
                    self._leafs = OrderedDict([
                        ('bpdufilter', (YLeaf(YType.enumeration, 'bpdufilter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.SpanningTree.Bpdufilter')])),
                        ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ('guard', (YLeaf(YType.enumeration, 'guard'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.SpanningTree.Guard')])),
                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.SpanningTree.LinkType')])),
                        ('port_priority', (YLeaf(YType.uint8, 'port-priority'), ['int'])),
                    ])
                    self.bpdufilter = None
                    self.cost = None
                    self.guard = None
                    self.link_type = None
                    self.port_priority = None

                    self.bpduguard = Native.Interface.TenGigabitEthernet.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"

                    self.loopguard = Native.Interface.TenGigabitEthernet.SpanningTree.Loopguard()
                    self.loopguard.parent = self
                    self._children_name_map["loopguard"] = "loopguard"

                    self.mst = Native.Interface.TenGigabitEthernet.SpanningTree.Mst()
                    self.mst.parent = self
                    self._children_name_map["mst"] = "mst"

                    self.vlan = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:spanning-tree"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.SpanningTree, ['bpdufilter', 'cost', 'guard', 'link_type', 'port_priority'], name, value)

                class Bpdufilter(Enum):
                    """
                    Bpdufilter (Enum Class)

                    Don't send or receive BPDUs on this interface

                    .. data:: disable = 0

                    .. data:: enable = 1

                    """

                    disable = Enum.YLeaf(0, "disable")

                    enable = Enum.YLeaf(1, "enable")


                class Guard(Enum):
                    """
                    Guard (Enum Class)

                    Change an interface's spanning tree guard mode

                    .. data:: loop = 0

                    .. data:: none = 1

                    .. data:: root = 2

                    """

                    loop = Enum.YLeaf(0, "loop")

                    none = Enum.YLeaf(1, "none")

                    root = Enum.YLeaf(2, "root")


                class LinkType(Enum):
                    """
                    LinkType (Enum Class)

                    Specify a link type for spanning tree tree protocol use

                    .. data:: point_to_point = 0

                    .. data:: shared = 1

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")

                    shared = Enum.YLeaf(1, "shared")



                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.disable = None
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.SpanningTree.Bpduguard, ['disable', 'enable'], name, value)


                class Portfast(Entity):
                    """
                    Spanning tree portfast options
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk
                    
                    	Enable portfast on the interface even in trunk mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                        ])
                        self.disable = None
                        self.trunk = None
                        self.edge = None
                        self._segment_path = lambda: "portfast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.SpanningTree.Portfast, ['disable', 'trunk', 'edge'], name, value)


                class Vlan(Entity):
                    """
                    VLAN Switch Spanning Tree
                    
                    .. attribute:: vlan_ids  (key)
                    
                    	vlan range, example\: 1,3\-5,7,9\-11
                    	**type**\: str
                    
                    .. attribute:: cost
                    
                    	<1\-200000000> Spanning\-tree cost
                    	**type**\: int
                    
                    	**range:** 1..200000000
                    
                    .. attribute:: port_priority
                    
                    	<0\-240> port priority in increments of 16
                    	**type**\: int
                    
                    	**range:** 0..240
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.SpanningTree.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vlan_ids']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_ids', (YLeaf(YType.str, 'vlan-ids'), ['str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                        ])
                        self.vlan_ids = None
                        self.cost = None
                        self.port_priority = None
                        self._segment_path = lambda: "vlan" + "[vlan-ids='" + str(self.vlan_ids) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.SpanningTree.Vlan, ['vlan_ids', 'cost', 'port_priority'], name, value)


                class Loopguard(Entity):
                    """
                    Spanning tree loopguard options
                    
                    .. attribute:: default
                    
                    	Enable loopguard by default on all ports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.SpanningTree.Loopguard, self).__init__()

                        self.yang_name = "loopguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.default = None
                        self._segment_path = lambda: "loopguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.SpanningTree.Loopguard, ['default'], name, value)


                class Mst(Entity):
                    """
                    Per interface MST configurations
                    
                    .. attribute:: mst_instance
                    
                    	
                    	**type**\: list of  		 :py:class:`MstInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.SpanningTree.Mst.MstInstance>`
                    
                    .. attribute:: pre_standard
                    
                    	Force pre\-standard MST BPDU transmission on port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.SpanningTree.Mst, self).__init__()

                        self.yang_name = "mst"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mst-instance", ("mst_instance", Native.Interface.TenGigabitEthernet.SpanningTree.Mst.MstInstance))])
                        self._leafs = OrderedDict([
                            ('pre_standard', (YLeaf(YType.empty, 'pre-standard'), ['Empty'])),
                        ])
                        self.pre_standard = None

                        self.mst_instance = YList(self)
                        self._segment_path = lambda: "mst"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.SpanningTree.Mst, ['pre_standard'], name, value)


                    class MstInstance(Entity):
                        """
                        
                        
                        .. attribute:: instance  (key)
                        
                        	MST instance list, example 0,2\-4,6,8\-12
                        	**type**\: str
                        
                        .. attribute:: cost
                        
                        	<1\-200000000> Spanning\-tree cost
                        	**type**\: int
                        
                        	**range:** 1..200000000
                        
                        .. attribute:: port_priority
                        
                        	<0\-240> port priority in increments of 16
                        	**type**\: int
                        
                        	**range:** 0..240
                        
                        

                        """

                        _prefix = 'ios-stp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.SpanningTree.Mst.MstInstance, self).__init__()

                            self.yang_name = "mst-instance"
                            self.yang_parent_name = "mst"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                            ])
                            self.instance = None
                            self.cost = None
                            self.port_priority = None
                            self._segment_path = lambda: "mst-instance" + "[instance='" + str(self.instance) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.SpanningTree.Mst.MstInstance, ['instance', 'cost', 'port_priority'], name, value)


            class Performance(Entity):
                """
                Global performance monitor configuration
                
                .. attribute:: monitor
                
                	monitor
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Performance.Monitor>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Performance, self).__init__()

                    self.yang_name = "performance"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TenGigabitEthernet.Performance.Monitor))])
                    self._leafs = OrderedDict()

                    self.monitor = Native.Interface.TenGigabitEthernet.Performance.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"
                    self._segment_path = lambda: "Cisco-IOS-XE-ezpm:performance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Performance, [], name, value)


                class Monitor(Entity):
                    """
                    monitor
                    
                    .. attribute:: context
                    
                    	Select ezPM context
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Performance.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "performance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('context', (YLeafList(YType.str, 'context'), ['str'])),
                        ])
                        self.context = []
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Performance.Monitor, ['context'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Umbrella, ['out', 'in_'], name, value)


            class Lldp(Entity):
                """
                LLDP interface subcommands
                
                .. attribute:: receive
                
                	Enable LLDP reception on interface
                	**type**\: bool
                
                .. attribute:: transmit
                
                	Enable LLDP transmission on interface
                	**type**\: bool
                
                

                """

                _prefix = 'ios-lldp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Lldp, self).__init__()

                    self.yang_name = "lldp"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                        ('transmit', (YLeaf(YType.boolean, 'transmit'), ['bool'])),
                    ])
                    self.receive = None
                    self.transmit = None
                    self._segment_path = lambda: "Cisco-IOS-XE-lldp:lldp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Lldp, ['receive', 'transmit'], name, value)


            class Vrrp(Entity):
                """
                Configure VRRP
                
                .. attribute:: vrrp_group
                
                	
                	**type**\: list of  		 :py:class:`VrrpGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup>`
                
                .. attribute:: vrrp_group_v2
                
                	vrrp version 2
                	**type**\: list of  		 :py:class:`VrrpGroupV2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2>`
                
                .. attribute:: delay
                
                	
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.Delay>`
                
                

                """

                _prefix = 'ios-vrrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Vrrp, self).__init__()

                    self.yang_name = "vrrp"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrrp-group", ("vrrp_group", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup)), ("vrrp-group-v2", ("vrrp_group_v2", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2)), ("delay", ("delay", Native.Interface.TenGigabitEthernet.Vrrp.Delay))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.TenGigabitEthernet.Vrrp.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.vrrp_group = YList(self)
                    self.vrrp_group_v2 = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vrrp:vrrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp, [], name, value)


                class VrrpGroup(Entity):
                    """
                    
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: address_family
                    
                    	Address family of the group
                    	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup, self).__init__()

                        self.yang_name = "vrrp-group"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("address-family", ("address_family", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                        ])
                        self.group_id = None

                        self.address_family = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"
                        self._segment_path = lambda: "vrrp-group" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup, ['group_id'], name, value)


                    class AddressFamily(Entity):
                        """
                        Address family of the group
                        
                        .. attribute:: ipv4
                        
                        	IPv4 Address family
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	IPv6 Address family
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily, self).__init__()

                            self.yang_name = "address-family"
                            self.yang_parent_name = "vrrp-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4)), ("ipv6", ("ipv6", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = None
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "address-family"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily, [], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 Address family
                            
                            .. attribute:: vrrpv2
                            
                            	Set VRRPv2 compatibility mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: address
                            
                            	Set the IPv4 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address)), ("preempt", ("preempt", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt)), ("timers", ("timers", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers)), ("track", ("track", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track)), ("vrrs", ("vrrs", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('vrrpv2', (YLeaf(YType.empty, 'vrrpv2'), ['Empty'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.vrrpv2 = None
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4, ['vrrpv2', 'description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv4 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary>`
                                
                                .. attribute:: secondary
                                
                                	
                                	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary)), ("secondary", ("secondary", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.secondary = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv4 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, ['address', 'primary'], name, value)


                                class Secondary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: secondary
                                    
                                    	Make this IPv4 address a secondary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, self).__init__()

                                        self.yang_name = "secondary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.secondary = None
                                        self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, ['address', 'secondary'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, ['leader'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 Address family
                            
                            .. attribute:: address
                            
                            	Set the IPv6 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address)), ("preempt", ("preempt", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt)), ("timers", ("timers", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers)), ("track", ("track", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track)), ("vrrs", ("vrrs", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6, ['description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv6 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary>`
                                
                                .. attribute:: ipv6_prefix
                                
                                	
                                	**type**\: list of  		 :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary)), ("ipv6-prefix", ("ipv6_prefix", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.ipv6_prefix = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipv6_link_local
                                    
                                    	IPv6 link\-local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv6 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_link_local', (YLeaf(YType.str, 'ipv6-link-local'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.ipv6_link_local = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, ['ipv6_link_local', 'primary'], name, value)


                                class Ipv6Prefix(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, self).__init__()

                                        self.yang_name = "ipv6-prefix"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                        ])
                                        self.prefix = None
                                        self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, ['prefix'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, ['leader'], name, value)


                class VrrpGroupV2(Entity):
                    """
                    vrrp version 2
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: authentication
                    
                    	
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Authentication>`
                    
                    .. attribute:: description
                    
                    	Up to 80 characters describing this group
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Ip>`
                    
                    .. attribute:: name
                    
                    	Unique VRRS identifier (max 48 characters)
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: shutdown
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: timers
                    
                    	
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Timers>`
                    
                    .. attribute:: track
                    
                    	
                    	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Track>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2, self).__init__()

                        self.yang_name = "vrrp-group-v2"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Authentication)), ("ip", ("ip", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Ip)), ("preempt", ("preempt", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Preempt)), ("timers", ("timers", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Timers)), ("track", ("track", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Track))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.group_id = None
                        self.description = None
                        self.name = None
                        self.priority = None
                        self.shutdown = None

                        self.authentication = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.timers = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Track()
                        self.track.parent = self
                        self._children_name_map["track"] = "track"
                        self._segment_path = lambda: "vrrp-group-v2" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2, ['group_id', 'description', 'name', 'priority', 'shutdown'], name, value)


                    class Authentication(Entity):
                        """
                        
                        
                        .. attribute:: text
                        
                        	authentication string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.text = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Authentication, ['text'], name, value)


                    class Ip(Entity):
                        """
                        
                        
                        .. attribute:: vrrp_ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`VrrpIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrrp-ipv4", ("vrrp_ipv4", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4))])
                            self._leafs = OrderedDict()

                            self.vrrp_ipv4 = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Ip, [], name, value)


                        class VrrpIpv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, self).__init__()

                                self.yang_name = "vrrp-ipv4"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.ipv4 = None
                                self.secondary = None
                                self._segment_path = lambda: "vrrp-ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, ['ipv4', 'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        
                        
                        .. attribute:: delay
                        
                        	
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            
                            
                            .. attribute:: minimum
                            
                            	Seconds to delay
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                ])
                                self.minimum = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay, ['minimum'], name, value)


                    class Timers(Entity):
                        """
                        
                        
                        .. attribute:: advertise
                        
                        	
                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise>`
                        
                        .. attribute:: learn
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise))])
                            self._leafs = OrderedDict([
                                ('learn', (YLeaf(YType.empty, 'learn'), ['Empty'])),
                            ])
                            self.learn = None

                            self.advertise = Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise()
                            self.advertise.parent = self
                            self._children_name_map["advertise"] = "advertise"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Timers, ['learn'], name, value)


                        class Advertise(Entity):
                            """
                            
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Advertisement interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..999
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise, self).__init__()

                                self.yang_name = "advertise"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint8, 'interval'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.interval = None
                                self.msec = None
                                self._segment_path = lambda: "advertise"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise, ['interval', 'msec'], name, value)


                    class Track(Entity):
                        """
                        
                        
                        .. attribute:: event
                        
                        	
                        	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("event", ("event", Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event))])
                            self._leafs = OrderedDict()

                            self.event = YList(self)
                            self._segment_path = lambda: "track"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Track, [], name, value)


                        class Event(Entity):
                            """
                            
                            
                            .. attribute:: object_id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: decrement
                            
                            	Decrement value
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event, self).__init__()

                                self.yang_name = "event"
                                self.yang_parent_name = "track"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['object_id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                    ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ])
                                self.object_id = None
                                self.decrement = None
                                self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event, ['object_id', 'decrement'], name, value)


                class Delay(Entity):
                    """
                    
                    
                    .. attribute:: reload
                    
                    	Seconds to delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: minimum
                    
                    	Seconds to delay after interface up
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Vrrp.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                        ])
                        self.reload = None
                        self.minimum = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Vrrp.Delay, ['reload', 'minimum'], name, value)


            class Ospfv3(Entity):
                """
                OSPFv3 interface commands
                
                .. attribute:: process_id
                
                	
                	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId>`
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Authentication>`
                
                .. attribute:: bfd
                
                	Enable BFD on this interface
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: cost
                
                	Route cost of this interface
                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Cost>`
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: demand_circuit
                
                	OSPF Demand Circuit
                	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.DemandCircuit>`
                
                	**presence node**\: True
                
                .. attribute:: encryption
                
                	Enable encryption
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption>`
                
                .. attribute:: flood_reduction
                
                	OSPF Flood Reduction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: manet
                
                	Mobile Adhoc Networking options
                	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Manet>`
                
                .. attribute:: mtu_ignore
                
                	Ignores the MTU in DBD packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: multi_area
                
                	Set the OSPF multi\-area ID
                	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.MultiArea>`
                
                .. attribute:: neighbor
                
                	OSPF neighbor
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Neighbor>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Network>`
                
                .. attribute:: prefix_suppression
                
                	OSPF prefix suppression
                	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.PrefixSuppression>`
                
                	**presence node**\: True
                
                .. attribute:: priority
                
                	Router priority
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: retransmit_interval
                
                	Time between retransmitting lost link state advertisements
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Shut down the interface in OSPFv3
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transmit_delay
                
                	Link state transmit delay
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Ospfv3, self).__init__()

                    self.yang_name = "ospfv3"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId)), ("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Ospfv3.Authentication)), ("bfd", ("bfd", Native.Interface.TenGigabitEthernet.Ospfv3.Bfd)), ("cost", ("cost", Native.Interface.TenGigabitEthernet.Ospfv3.Cost)), ("database-filter", ("database_filter", Native.Interface.TenGigabitEthernet.Ospfv3.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TenGigabitEthernet.Ospfv3.DemandCircuit)), ("encryption", ("encryption", Native.Interface.TenGigabitEthernet.Ospfv3.Encryption)), ("manet", ("manet", Native.Interface.TenGigabitEthernet.Ospfv3.Manet)), ("multi-area", ("multi_area", Native.Interface.TenGigabitEthernet.Ospfv3.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TenGigabitEthernet.Ospfv3.Neighbor)), ("network", ("network", Native.Interface.TenGigabitEthernet.Ospfv3.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TenGigabitEthernet.Ospfv3.PrefixSuppression))])
                    self._leafs = OrderedDict([
                        ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                        ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                        ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                    ])
                    self.dead_interval = None
                    self.flood_reduction = None
                    self.hello_interval = None
                    self.mtu_ignore = None
                    self.priority = None
                    self.retransmit_interval = None
                    self.shutdown = None
                    self.transmit_delay = None

                    self.authentication = Native.Interface.TenGigabitEthernet.Ospfv3.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"

                    self.cost = Native.Interface.TenGigabitEthernet.Ospfv3.Cost()
                    self.cost.parent = self
                    self._children_name_map["cost"] = "cost"

                    self.database_filter = Native.Interface.TenGigabitEthernet.Ospfv3.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"

                    self.demand_circuit = None
                    self._children_name_map["demand_circuit"] = "demand-circuit"

                    self.encryption = Native.Interface.TenGigabitEthernet.Ospfv3.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.manet = Native.Interface.TenGigabitEthernet.Ospfv3.Manet()
                    self.manet.parent = self
                    self._children_name_map["manet"] = "manet"

                    self.multi_area = Native.Interface.TenGigabitEthernet.Ospfv3.MultiArea()
                    self.multi_area.parent = self
                    self._children_name_map["multi_area"] = "multi-area"

                    self.network = Native.Interface.TenGigabitEthernet.Ospfv3.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.prefix_suppression = None
                    self._children_name_map["prefix_suppression"] = "prefix-suppression"

                    self.process_id = YList(self)
                    self.neighbor = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3, ['dead_interval', u'flood_reduction', 'hello_interval', u'mtu_ignore', 'priority', 'retransmit_interval', u'shutdown', 'transmit_delay'], name, value)


                class ProcessId(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: manet
                    
                    	Mobile Adhoc Networking options
                    	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.MultiArea>`
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Network>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipv4
                    
                    	Specify parameters for IPv4
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Specify parameters for IPv6
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId, self).__init__()

                        self.yang_name = "process-id"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Authentication)), ("bfd", ("bfd", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Bfd)), ("cost", ("cost", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost)), ("database-filter", ("database_filter", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.FloodReduction)), ("manet", ("manet", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Neighbor)), ("network", ("network", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Shutdown)), ("ipv4", ("ipv4", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4)), ("ipv6", ("ipv6", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.id = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.cost = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.database_filter = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.manet = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet()
                        self.manet.parent = self
                        self._children_name_map["manet"] = "manet"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.multi_area = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.network = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.ipv4 = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId, [u'id', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\: str
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.null = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Authentication, [u'key_chain', u'null'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Bfd, ['disable'], name, value)


                    class Cost(Entity):
                        """
                        Route cost of this interface
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dynamic
                        
                        	Specify dynamic cost options
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.dynamic = None
                            self._children_name_map["dynamic"] = "dynamic"
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost, [u'value'], name, value)


                        class Dynamic(Entity):
                            """
                            Specify dynamic cost options
                            
                            .. attribute:: default
                            
                            	Specify default link metric value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: hysteresis
                            
                            	Specify hysteresis value for LSA dampening
                            	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: weight
                            
                            	Specify weight to be placed on individual metrics
                            	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ])
                                self.default = None

                                self.hysteresis = None
                                self._children_name_map["hysteresis"] = "hysteresis"

                                self.weight = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight()
                                self.weight.parent = self
                                self._children_name_map["weight"] = "weight"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic, [u'default'], name, value)


                            class Hysteresis(Entity):
                                """
                                Specify hysteresis value for LSA dampening
                                
                                .. attribute:: percent
                                
                                	Specify hysteresis percent changed
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold
                                
                                	Specify hysteresis threshold value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, self).__init__()

                                    self.yang_name = "hysteresis"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "hysteresis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                            class Weight(Entity):
                                """
                                Specify weight to be placed on individual metrics
                                
                                .. attribute:: l2_factor
                                
                                	Specify weight to be given to L2\-factor metric
                                	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: latency
                                
                                	Specify weight to be given to latency metric
                                	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: resources
                                
                                	Specify weight to be given to resources metric
                                	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: throughput
                                
                                	Specify weight to be given to throughput metric
                                	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, self).__init__()

                                    self.yang_name = "weight"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput))])
                                    self._leafs = OrderedDict()

                                    self.l2_factor = None
                                    self._children_name_map["l2_factor"] = "L2-factor"

                                    self.latency = None
                                    self._children_name_map["latency"] = "latency"

                                    self.resources = None
                                    self._children_name_map["resources"] = "resources"

                                    self.throughput = None
                                    self._children_name_map["throughput"] = "throughput"
                                    self._segment_path = lambda: "weight"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, [], name, value)


                                class L2Factor(Entity):
                                    """
                                    Specify weight to be given to L2\-factor metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                        self.yang_name = "L2-factor"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "L2-factor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                class Latency(Entity):
                                    """
                                    Specify weight to be given to latency metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, self).__init__()

                                        self.yang_name = "latency"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "latency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                class Resources(Entity):
                                    """
                                    Specify weight to be given to resources metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, self).__init__()

                                        self.yang_name = "resources"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "resources"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                class Throughput(Entity):
                                    """
                                    Specify weight to be given to throughput metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, self).__init__()

                                        self.yang_name = "throughput"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "throughput"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter, [u'all', u'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.DemandCircuit, [u'disable', u'ignore'], name, value)


                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.FloodReduction, [u'disable'], name, value)


                    class Manet(Entity):
                        """
                        Mobile Adhoc Networking options
                        
                        .. attribute:: peering
                        
                        	MANET Peering options
                        	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet.Peering>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet, self).__init__()

                            self.yang_name = "manet"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet.Peering))])
                            self._leafs = OrderedDict()

                            self.peering = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet.Peering()
                            self.peering.parent = self
                            self._children_name_map["peering"] = "peering"
                            self._segment_path = lambda: "manet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet, [], name, value)


                        class Peering(Entity):
                            """
                            MANET Peering options
                            
                            .. attribute:: cost
                            
                            	Redundant path cost improvement required to peer
                            	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost>`
                            
                            .. attribute:: link_metrics
                            
                            	Require link metrics
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet.Peering, self).__init__()

                                self.yang_name = "peering"
                                self.yang_parent_name = "manet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost))])
                                self._leafs = OrderedDict([
                                    ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                ])
                                self.link_metrics = None

                                self.cost = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost()
                                self.cost.parent = self
                                self._children_name_map["cost"] = "cost"
                                self._segment_path = lambda: "peering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet.Peering, [u'link_metrics'], name, value)


                            class Cost(Entity):
                                """
                                Redundant path cost improvement required to peer
                                
                                .. attribute:: percent
                                
                                	Relative incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                .. attribute:: threshold
                                
                                	Absolute incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, self).__init__()

                                    self.yang_name = "cost"
                                    self.yang_parent_name = "peering"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "cost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.MtuIgnore, [u'disable'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: disable
                        
                        	disable OSPF multi\-area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.disable = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.MultiArea, [u'id', u'cost', u'disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression, ['disable'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Shutdown, [u'disable'], name, value)


                    class Ipv4(Entity):
                        """
                        Specify parameters for IPv4
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area)), ("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication)), ("bfd", ("bfd", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd)), ("cost", ("cost", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost)), ("database-filter", ("database_filter", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction)), ("manet", ("manet", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor)), ("network", ("network", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 64..95
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, [u'disable'], name, value)


                    class Ipv6(Entity):
                        """
                        Specify parameters for IPv6
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area)), ("authentication", ("authentication", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication)), ("bfd", ("bfd", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd)), ("cost", ("cost", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost)), ("database-filter", ("database_filter", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction)), ("manet", ("manet", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor)), ("network", ("network", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 0..31
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, [u'disable'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: key_chain
                    
                    	Use a key\-chain for cryptographic authentication keys
                    	**type**\: str
                    
                    .. attribute:: null
                    
                    	Use no authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec authentication
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.null = None

                        self.ipsec = Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication, [u'key_chain', u'null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec authentication
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 256..4294967295
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5>`
                        
                        .. attribute:: sha1
                        
                        	Use SHA\-1 authentication
                        	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                            ])
                            self.spi = None

                            self.md5 = Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"

                            self.sha1 = Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1()
                            self.sha1.parent = self
                            self._children_name_map["sha1"] = "sha1"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec, ['spi'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class Sha1(Entity):
                            """
                            Use SHA\-1 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1, self).__init__()

                                self.yang_name = "sha1"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "sha1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "sha1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                class Bfd(Entity):
                    """
                    Enable BFD on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BFD on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Bfd, ['disable'], name, value)


                class Cost(Entity):
                    """
                    Route cost of this interface
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: dynamic
                    
                    	Specify dynamic cost options
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.Cost, self).__init__()

                        self.yang_name = "cost"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.dynamic = None
                        self._children_name_map["dynamic"] = "dynamic"
                        self._segment_path = lambda: "cost"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Cost, [u'value'], name, value)


                    class Dynamic(Entity):
                        """
                        Specify dynamic cost options
                        
                        .. attribute:: default
                        
                        	Specify default link metric value
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hysteresis
                        
                        	Specify hysteresis value for LSA dampening
                        	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: weight
                        
                        	Specify weight to be placed on individual metrics
                        	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic, self).__init__()

                            self.yang_name = "dynamic"
                            self.yang_parent_name = "cost"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                            ])
                            self.default = None

                            self.hysteresis = None
                            self._children_name_map["hysteresis"] = "hysteresis"

                            self.weight = Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight()
                            self.weight.parent = self
                            self._children_name_map["weight"] = "weight"
                            self._segment_path = lambda: "dynamic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic, [u'default'], name, value)


                        class Hysteresis(Entity):
                            """
                            Specify hysteresis value for LSA dampening
                            
                            .. attribute:: percent
                            
                            	Specify hysteresis percent changed
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold
                            
                            	Specify hysteresis threshold value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis, self).__init__()

                                self.yang_name = "hysteresis"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "hysteresis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                        class Weight(Entity):
                            """
                            Specify weight to be placed on individual metrics
                            
                            .. attribute:: l2_factor
                            
                            	Specify weight to be given to L2\-factor metric
                            	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: latency
                            
                            	Specify weight to be given to latency metric
                            	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: resources
                            
                            	Specify weight to be given to resources metric
                            	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: throughput
                            
                            	Specify weight to be given to throughput metric
                            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight, self).__init__()

                                self.yang_name = "weight"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput))])
                                self._leafs = OrderedDict()

                                self.l2_factor = None
                                self._children_name_map["l2_factor"] = "L2-factor"

                                self.latency = None
                                self._children_name_map["latency"] = "latency"

                                self.resources = None
                                self._children_name_map["resources"] = "resources"

                                self.throughput = None
                                self._children_name_map["throughput"] = "throughput"
                                self._segment_path = lambda: "weight"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight, [], name, value)


                            class L2Factor(Entity):
                                """
                                Specify weight to be given to L2\-factor metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                    self.yang_name = "L2-factor"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "L2-factor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                            class Latency(Entity):
                                """
                                Specify weight to be given to latency metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, self).__init__()

                                    self.yang_name = "latency"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "latency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                            class Resources(Entity):
                                """
                                Specify weight to be given to resources metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, self).__init__()

                                    self.yang_name = "resources"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "resources"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                            class Throughput(Entity):
                                """
                                Specify weight to be given to throughput metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, self).__init__()

                                    self.yang_name = "throughput"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "throughput"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.DatabaseFilter.All')])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.DatabaseFilter, [u'all'], name, value)

                    class All(Enum):
                        """
                        All (Enum Class)

                        Filter all LSA

                        .. data:: out = 0

                        """

                        out = Enum.YLeaf(0, "out")



                class DemandCircuit(Entity):
                    """
                    OSPF Demand Circuit
                    
                    .. attribute:: ignore
                    
                    	Ignore demand circuit auto\-negotiation requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.DemandCircuit, self).__init__()

                        self.yang_name = "demand-circuit"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.ignore = None
                        self._segment_path = lambda: "demand-circuit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.DemandCircuit, [u'ignore'], name, value)


                class Encryption(Entity):
                    """
                    Enable encryption
                    
                    .. attribute:: null
                    
                    	No IPsec encryption on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec encryption
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec))])
                        self._leafs = OrderedDict([
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.null = None

                        self.ipsec = Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption, ['null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec encryption
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: esp
                        
                        	Use ESP encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec_3des
                        
                        	Use 3DES encryption
                        	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des>`
                        
                        .. attribute:: aes_cbc
                        
                        	Use AES\-CBC encryption
                        	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                            ])
                            self.spi = None
                            self.esp = None

                            self.ipsec_3des = Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des()
                            self.ipsec_3des.parent = self
                            self._children_name_map["ipsec_3des"] = "ipsec_3des"

                            self.aes_cbc = Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc()
                            self.aes_cbc.parent = self
                            self._children_name_map["aes_cbc"] = "aes-cbc"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec, ['spi', 'esp'], name, value)


                        class Ipsec3des(Entity):
                            """
                            Use 3DES encryption
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, self).__init__()

                                self.yang_name = "ipsec_3des"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "ipsec_3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "ipsec_3des"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class AesCbc(Entity):
                            """
                            Use AES\-CBC encryption
                            
                            .. attribute:: aes_cbc_128
                            
                            	Use 128 bit key
                            	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128>`
                            
                            .. attribute:: aes_192
                            
                            	Use 192 bit key
                            	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192>`
                            
                            .. attribute:: aes_256
                            
                            	Use 256 bit key
                            	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc, self).__init__()

                                self.yang_name = "aes-cbc"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256))])
                                self._leafs = OrderedDict()

                                self.aes_cbc_128 = Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128()
                                self.aes_cbc_128.parent = self
                                self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                self.aes_192 = Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192()
                                self.aes_192.parent = self
                                self._children_name_map["aes_192"] = "aes-192"

                                self.aes_256 = Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256()
                                self.aes_256.parent = self
                                self._children_name_map["aes_256"] = "aes-256"
                                self._segment_path = lambda: "aes-cbc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc, [], name, value)


                            class AesCbc128(Entity):
                                """
                                Use 128 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                    self.yang_name = "aes-cbc-128"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-cbc-128"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-cbc-128"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes192(Entity):
                                """
                                Use 192 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                    self.yang_name = "aes-192"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-192"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-192"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes256(Entity):
                                """
                                Use 256 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                    self.yang_name = "aes-256"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-256"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-256"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                class Manet(Entity):
                    """
                    Mobile Adhoc Networking options
                    
                    .. attribute:: peering
                    
                    	MANET Peering options
                    	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Manet.Peering>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.Manet, self).__init__()

                        self.yang_name = "manet"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TenGigabitEthernet.Ospfv3.Manet.Peering))])
                        self._leafs = OrderedDict()

                        self.peering = Native.Interface.TenGigabitEthernet.Ospfv3.Manet.Peering()
                        self.peering.parent = self
                        self._children_name_map["peering"] = "peering"
                        self._segment_path = lambda: "manet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Manet, [], name, value)


                    class Peering(Entity):
                        """
                        MANET Peering options
                        
                        .. attribute:: cost
                        
                        	Redundant path cost improvement required to peer
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Manet.Peering.Cost>`
                        
                        .. attribute:: link_metrics
                        
                        	Require link metrics
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.Manet.Peering, self).__init__()

                            self.yang_name = "peering"
                            self.yang_parent_name = "manet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TenGigabitEthernet.Ospfv3.Manet.Peering.Cost))])
                            self._leafs = OrderedDict([
                                ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                            ])
                            self.link_metrics = None

                            self.cost = Native.Interface.TenGigabitEthernet.Ospfv3.Manet.Peering.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"
                            self._segment_path = lambda: "peering"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Manet.Peering, [u'link_metrics'], name, value)


                        class Cost(Entity):
                            """
                            Redundant path cost improvement required to peer
                            
                            .. attribute:: percent
                            
                            	Relative incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: threshold
                            
                            	Absolute incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Ospfv3.Manet.Peering.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "peering"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                class MultiArea(Entity):
                    """
                    Set the OSPF multi\-area ID
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.MultiArea, self).__init__()

                        self.yang_name = "multi-area"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self._segment_path = lambda: "multi-area"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.MultiArea, [u'id', u'cost'], name, value)


                class Neighbor(Entity):
                    """
                    OSPF neighbor
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	OSPF cost for point\-to\-multipoint neighbor
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter>`
                    
                    .. attribute:: poll_interval
                    
                    	OSPF dead\-router polling interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: priority
                    
                    	OSPF priority of non\-broadcast neighbor
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TenGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self.poll_interval = None
                        self.priority = None

                        self.database_filter = Native.Interface.TenGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter.All')])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter, ['all'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                class Network(Entity):
                    """
                    Network type
                    
                    .. attribute:: broadcast
                    
                    	Specify OSPF broadcast multi\-access network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: manet
                    
                    	Specify MANET OSPF interface type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: non_broadcast
                    
                    	Specify OSPF NBMA network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: point_to_multipoint
                    
                    	Specify OSPF point\-to\-multipoint network
                    	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Ospfv3.Network.PointToMultipoint>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: point_to_point
                    
                    	Specify OSPF point\-to\-point network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TenGigabitEthernet.Ospfv3.Network.PointToMultipoint))])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                            ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                        ])
                        self.broadcast = None
                        self.manet = None
                        self.non_broadcast = None
                        self.point_to_point = None

                        self.point_to_multipoint = None
                        self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                    class PointToMultipoint(Entity):
                        """
                        Specify OSPF point\-to\-multipoint network
                        
                        .. attribute:: non_broadcast
                        
                        	Specify non\-broadcast point\-to\-mpoint network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Ospfv3.Network.PointToMultipoint, self).__init__()

                            self.yang_name = "point-to-multipoint"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ])
                            self.non_broadcast = None
                            self._segment_path = lambda: "point-to-multipoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.Network.PointToMultipoint, ['non_broadcast'], name, value)


                class PrefixSuppression(Entity):
                    """
                    OSPF prefix suppression
                    
                    .. attribute:: disable
                    
                    	Disable prefix suppression
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Ospfv3.PrefixSuppression, self).__init__()

                        self.yang_name = "prefix-suppression"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "prefix-suppression"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Ospfv3.PrefixSuppression, ['disable'], name, value)


            class Udld(Entity):
                """
                Configure UDLD enabled or disabled and ignore global UDLD setting
                
                .. attribute:: port
                
                	Enable UDLD protocol on this interface despite global UDLD setting
                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Udld.Port>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-udld'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Udld, self).__init__()

                    self.yang_name = "udld"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.TenGigabitEthernet.Udld.Port))])
                    self._leafs = OrderedDict()

                    self.port = None
                    self._children_name_map["port"] = "port"
                    self._segment_path = lambda: "Cisco-IOS-XE-udld:udld"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Udld, [], name, value)


                class Port(Entity):
                    """
                    Enable UDLD protocol on this interface despite global UDLD setting
                    
                    .. attribute:: aggressive
                    
                    	Enable UDLD protocol in aggressive mode on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	Disable UDLD protocol on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-udld'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Udld.Port, self).__init__()

                        self.yang_name = "port"
                        self.yang_parent_name = "udld"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aggressive', (YLeaf(YType.empty, 'aggressive'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.aggressive = None
                        self.disable = None
                        self._segment_path = lambda: "port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Udld.Port, ['aggressive', 'disable'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.Manual>`
                
                	**presence node**\: True
                
                .. attribute:: role_based
                
                	Role\-based Access Control per\-port config commands
                	**type**\:  :py:class:`RoleBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.RoleBased>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.TenGigabitEthernet.Cts.Manual)), ("role-based", ("role_based", Native.Interface.TenGigabitEthernet.Cts.RoleBased))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"

                    self.role_based = Native.Interface.TenGigabitEthernet.Cts.RoleBased()
                    self.role_based.parent = self
                    self._children_name_map["role_based"] = "role-based"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.TenGigabitEthernet.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.TenGigabitEthernet.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.TenGigabitEthernet.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.TenGigabitEthernet.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.TenGigabitEthernet.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.TenGigabitEthernet.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.TenGigabitEthernet.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.TenGigabitEthernet.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.Manual.Propagate, ['sgt'], name, value)


                class RoleBased(Entity):
                    """
                    Role\-based Access Control per\-port config commands
                    
                    .. attribute:: sgt_cache
                    
                    	Enable SGT caching on the interface
                    	**type**\: list of   :py:class:`SgtCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.RoleBased.SgtCache>`
                    
                    .. attribute:: enforcement
                    
                    	Enable Role\-based Access Control enforcement
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sgt_map
                    
                    	Assign Security Group Tag (SGT) to IP host or network address
                    	**type**\:  :py:class:`SgtMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.Cts.RoleBased.SgtMap>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.Cts.RoleBased, self).__init__()

                        self.yang_name = "role-based"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sgt-map", ("sgt_map", Native.Interface.TenGigabitEthernet.Cts.RoleBased.SgtMap))])
                        self._leafs = OrderedDict([
                            ('sgt_cache', (YLeafList(YType.enumeration, 'sgt-cache'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TenGigabitEthernet.Cts.RoleBased.SgtCache')])),
                            ('enforcement', (YLeaf(YType.empty, 'enforcement'), ['Empty'])),
                        ])
                        self.sgt_cache = []
                        self.enforcement = None

                        self.sgt_map = Native.Interface.TenGigabitEthernet.Cts.RoleBased.SgtMap()
                        self.sgt_map.parent = self
                        self._children_name_map["sgt_map"] = "sgt-map"
                        self._segment_path = lambda: "role-based"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.RoleBased, ['sgt_cache', 'enforcement'], name, value)

                    class SgtCache(Enum):
                        """
                        SgtCache (Enum Class)

                        Enable SGT caching on the interface

                        .. data:: egress = 0

                        .. data:: ingress = 1

                        """

                        egress = Enum.YLeaf(0, "egress")

                        ingress = Enum.YLeaf(1, "ingress")



                    class SgtMap(Entity):
                        """
                        Assign Security Group Tag (SGT) to IP host or network address
                        
                        .. attribute:: security_group
                        
                        	Security Group Name
                        	**type**\: str
                        
                        .. attribute:: sgt
                        
                        	Security Group Tag (SGT)
                        	**type**\: int
                        
                        	**range:** 2..65519
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TenGigabitEthernet.Cts.RoleBased.SgtMap, self).__init__()

                            self.yang_name = "sgt-map"
                            self.yang_parent_name = "role-based"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('security_group', (YLeaf(YType.str, 'security-group'), ['str'])),
                                ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                            ])
                            self.security_group = None
                            self.sgt = None
                            self._segment_path = lambda: "sgt-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TenGigabitEthernet.Cts.RoleBased.SgtMap, ['security_group', 'sgt'], name, value)


            class AnalysisModule(Entity):
                """
                Configure NAM on the interface
                
                .. attribute:: monitoring
                
                	Configure NAM monitoring on the interface
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TenGigabitEthernet.AnalysisModule.Monitoring>`
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Interface.TenGigabitEthernet.AnalysisModule, self).__init__()

                    self.yang_name = "analysis-module"
                    self.yang_parent_name = "TenGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Interface.TenGigabitEthernet.AnalysisModule.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = Native.Interface.TenGigabitEthernet.AnalysisModule.Monitoring()
                    self.monitoring.parent = self
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TenGigabitEthernet.AnalysisModule, [], name, value)


                class Monitoring(Entity):
                    """
                    Configure NAM monitoring on the interface
                    
                    .. attribute:: interface_name
                    
                    	The name of the output interface.  E.g., 'ucse 1/0/0'
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nam'
                    _revision = '2017-12-28'

                    def __init__(self):
                        super(Native.Interface.TenGigabitEthernet.AnalysisModule.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "analysis-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "monitoring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TenGigabitEthernet.AnalysisModule.Monitoring, ['interface_name'], name, value)


        class TwentyFiveGigE(Entity):
            """
            Twenty Five Gigabit Ethernet
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: media_type
            
            	Media type
            	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.MediaType>`
            
            .. attribute:: port_type
            
            	
            	**type**\:  :py:class:`PortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.PortType>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service>`
            
            .. attribute:: lacp
            
            	LACP interface subcommands
            	**type**\:  :py:class:`Lacp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Lacp>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec_option
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXEEthernetMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ServicePolicy>`
            
            .. attribute:: auto
            
            	Configure Automation
            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Auto>`
            
            .. attribute:: datalink
            
            	Interface Datalink commands
            	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Datalink>`
            
            .. attribute:: energywise
            
            	EnergyWise interface configurations
            	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Energywise>`
            
            	**presence node**\: True
            
            .. attribute:: location
            
            	Interface location information
            	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Location>`
            
            .. attribute:: mac
            
            	MAC interface commands
            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mac>`
            
            .. attribute:: macro
            
            	Command macro
            	**type**\:  :py:class:`Macro <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Macro>`
            
            .. attribute:: dual_active
            
            	
            	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.DualActive>`
            
            .. attribute:: load_balancing
            
            	Etherchannel Load\-Balancing
            	**type**\:  :py:class:`LoadBalancing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.LoadBalancing>`
            
            .. attribute:: vlan_range
            
            	
            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.VlanRange>`
            
            .. attribute:: switch
            
            	
            	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switch>`
            
            .. attribute:: srr_queue
            
            	
            	**type**\:  :py:class:`SrrQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SrrQueue>`
            
            .. attribute:: cisco_ios_xe_switch_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_switch_macsec_option_
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXESwitchMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Snmp>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Crypto>`
            
            .. attribute:: mka
            
            	MACsec Key Agreement (MKA) interface configuration
            	**type**\:  :py:class:`Mka <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mka>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Utd>`
            
            .. attribute:: xconnect
            
            	Xconnect commands
            	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Xconnect>`
            
            .. attribute:: evpn
            
            	
            	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Evpn>`
            
            .. attribute:: fabric_domain
            
            	Fabric\-domain interface command
            	**type**\:  :py:class:`FabricDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.FabricDomain>`
            
            .. attribute:: mvrp
            
            	
            	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mvrp>`
            
            	**presence node**\: True
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Lisp>`
            
            .. attribute:: power
            
            	
            	**type**\:  :py:class:`Power <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Power>`
            
            .. attribute:: cdp
            
            	CDP interface subcommands
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cdp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ntp>`
            
            .. attribute:: authentication
            
            	Auth Manager Interface Configuration Commands
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication>`
            
            .. attribute:: mab
            
            	
            	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mab>`
            
            	**presence node**\: True
            
            .. attribute:: dot1x
            
            	Interface Config Commands for IEEE 802.1X
            	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Dot1x>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SpanningTree>`
            
            .. attribute:: performance
            
            	Global performance monitor configuration
            	**type**\:  :py:class:`Performance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Performance>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Umbrella>`
            
            .. attribute:: lldp
            
            	LLDP interface subcommands
            	**type**\:  :py:class:`Lldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Lldp>`
            
            .. attribute:: nat66
            
            	NAT66 interface commands
            	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Nat66>`
            
            .. attribute:: ospfv3
            
            	OSPFv3 interface commands
            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3>`
            
            .. attribute:: udld
            
            	Configure UDLD enabled or disabled and ignore global UDLD setting
            	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Udld>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts>`
            
            .. attribute:: analysis_module
            
            	Configure NAM on the interface
            	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.AnalysisModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.TwentyFiveGigE, self).__init__()

                self.yang_name = "TwentyFiveGigE"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.TwentyFiveGigE.SwitchportConf)), ("switchport", ("switchport", Native.Interface.TwentyFiveGigE.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.TwentyFiveGigE.StackwiseVirtual)), ("arp", ("arp", Native.Interface.TwentyFiveGigE.Arp)), ("backup", ("backup", Native.Interface.TwentyFiveGigE.Backup)), ("cemoudp", ("cemoudp", Native.Interface.TwentyFiveGigE.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.TwentyFiveGigE.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.TwentyFiveGigE.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.TwentyFiveGigE.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.TwentyFiveGigE.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.TwentyFiveGigE.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.TwentyFiveGigE.Flowcontrol)), ("isis", ("isis", Native.Interface.TwentyFiveGigE.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.TwentyFiveGigE.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.TwentyFiveGigE.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.TwentyFiveGigE.Bandwidth)), ("dampening", ("dampening", Native.Interface.TwentyFiveGigE.Dampening)), ("domain", ("domain", Native.Interface.TwentyFiveGigE.Domain)), ("hold-queue", ("hold_queue", Native.Interface.TwentyFiveGigE.HoldQueue)), ("mpls", ("mpls", Native.Interface.TwentyFiveGigE.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.TwentyFiveGigE.IpVrf)), ("vrf", ("vrf", Native.Interface.TwentyFiveGigE.Vrf)), ("ip", ("ip", Native.Interface.TwentyFiveGigE.Ip)), ("ipv6", ("ipv6", Native.Interface.TwentyFiveGigE.Ipv6)), ("logging", ("logging", Native.Interface.TwentyFiveGigE.Logging)), ("mdix", ("mdix", Native.Interface.TwentyFiveGigE.Mdix)), ("mop", ("mop", Native.Interface.TwentyFiveGigE.Mop)), ("interface_qos", ("interface_qos", Native.Interface.TwentyFiveGigE.InterfaceQos)), ("source", ("source", Native.Interface.TwentyFiveGigE.Source)), ("standby", ("standby", Native.Interface.TwentyFiveGigE.Standby)), ("access-session", ("access_session", Native.Interface.TwentyFiveGigE.AccessSession)), ("storm-control", ("storm_control", Native.Interface.TwentyFiveGigE.StormControl)), ("trust", ("trust", Native.Interface.TwentyFiveGigE.Trust)), ("priority-queue", ("priority_queue", Native.Interface.TwentyFiveGigE.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.TwentyFiveGigE.RcvQueue)), ("peer", ("peer", Native.Interface.TwentyFiveGigE.Peer)), ("pm-path", ("pm_path", Native.Interface.TwentyFiveGigE.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.TwentyFiveGigE.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.TwentyFiveGigE.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.TwentyFiveGigE.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.TwentyFiveGigE.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.TwentyFiveGigE.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.TwentyFiveGigE.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.TwentyFiveGigE.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.TwentyFiveGigE.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.TwentyFiveGigE.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.TwentyFiveGigE.Service)), ("Cisco-IOS-XE-ethernet:lacp", ("lacp", Native.Interface.TwentyFiveGigE.Lacp)), ("Cisco-IOS-XE-ethernet:macsec-option", ("cisco_ios_xe_ethernet_macsec_option", Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.TwentyFiveGigE.ServicePolicy)), ("Cisco-IOS-XE-switch:auto", ("auto", Native.Interface.TwentyFiveGigE.Auto)), ("Cisco-IOS-XE-switch:datalink", ("datalink", Native.Interface.TwentyFiveGigE.Datalink)), ("Cisco-IOS-XE-switch:energywise", ("energywise", Native.Interface.TwentyFiveGigE.Energywise)), ("Cisco-IOS-XE-switch:location", ("location", Native.Interface.TwentyFiveGigE.Location)), ("Cisco-IOS-XE-switch:mac", ("mac", Native.Interface.TwentyFiveGigE.Mac)), ("Cisco-IOS-XE-switch:macro", ("macro", Native.Interface.TwentyFiveGigE.Macro)), ("Cisco-IOS-XE-switch:dual-active", ("dual_active", Native.Interface.TwentyFiveGigE.DualActive)), ("Cisco-IOS-XE-switch:load-balancing", ("load_balancing", Native.Interface.TwentyFiveGigE.LoadBalancing)), ("Cisco-IOS-XE-switch:vlan-range", ("vlan_range", Native.Interface.TwentyFiveGigE.VlanRange)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Interface.TwentyFiveGigE.Switch)), ("Cisco-IOS-XE-switch:srr-queue", ("srr_queue", Native.Interface.TwentyFiveGigE.SrrQueue)), ("Cisco-IOS-XE-switch:macsec-option", ("cisco_ios_xe_switch_macsec_option_", Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.TwentyFiveGigE.Snmp)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.TwentyFiveGigE.Crypto)), ("Cisco-IOS-XE-mka:mka", ("mka", Native.Interface.TwentyFiveGigE.Mka)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.TwentyFiveGigE.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.TwentyFiveGigE.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.TwentyFiveGigE.Utd)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.TwentyFiveGigE.Xconnect)), ("Cisco-IOS-XE-l2vpn:evpn", ("evpn", Native.Interface.TwentyFiveGigE.Evpn)), ("Cisco-IOS-XE-iwanfabric:fabric-domain", ("fabric_domain", Native.Interface.TwentyFiveGigE.FabricDomain)), ("Cisco-IOS-XE-mvrp:mvrp", ("mvrp", Native.Interface.TwentyFiveGigE.Mvrp)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.TwentyFiveGigE.Lisp)), ("Cisco-IOS-XE-power:power", ("power", Native.Interface.TwentyFiveGigE.Power)), ("Cisco-IOS-XE-cdp:cdp", ("cdp", Native.Interface.TwentyFiveGigE.Cdp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.TwentyFiveGigE.Ntp)), ("Cisco-IOS-XE-sanet:authentication", ("authentication", Native.Interface.TwentyFiveGigE.Authentication)), ("Cisco-IOS-XE-sanet:mab", ("mab", Native.Interface.TwentyFiveGigE.Mab)), ("Cisco-IOS-XE-dot1x:dot1x", ("dot1x", Native.Interface.TwentyFiveGigE.Dot1x)), ("Cisco-IOS-XE-spanning-tree:spanning-tree", ("spanning_tree", Native.Interface.TwentyFiveGigE.SpanningTree)), ("Cisco-IOS-XE-ezpm:performance", ("performance", Native.Interface.TwentyFiveGigE.Performance)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.TwentyFiveGigE.Umbrella)), ("Cisco-IOS-XE-lldp:lldp", ("lldp", Native.Interface.TwentyFiveGigE.Lldp)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Interface.TwentyFiveGigE.Ospfv3)), ("Cisco-IOS-XE-udld:udld", ("udld", Native.Interface.TwentyFiveGigE.Udld)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.TwentyFiveGigE.Cts)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Interface.TwentyFiveGigE.AnalysisModule))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('media_type', (YLeaf(YType.enumeration, 'media-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.MediaType')])),
                    ('port_type', (YLeaf(YType.enumeration, 'port-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.PortType')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Duplex')])),
                    ('cisco_ios_xe_ethernet_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-ethernet:macsec'), ['Empty'])),
                    ('cisco_ios_xe_switch_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:macsec'), ['Empty'])),
                    ('nat66', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-nat:nat66'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Nat66')])),
                ])
                self.name = None
                self.media_type = None
                self.port_type = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None
                self.cisco_ios_xe_ethernet_macsec = None
                self.cisco_ios_xe_switch_macsec = None
                self.nat66 = None

                self.switchport_conf = Native.Interface.TwentyFiveGigE.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.TwentyFiveGigE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.TwentyFiveGigE.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.TwentyFiveGigE.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.TwentyFiveGigE.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.TwentyFiveGigE.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.TwentyFiveGigE.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.TwentyFiveGigE.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.TwentyFiveGigE.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.TwentyFiveGigE.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.TwentyFiveGigE.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.TwentyFiveGigE.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.TwentyFiveGigE.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.TwentyFiveGigE.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.TwentyFiveGigE.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.TwentyFiveGigE.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.TwentyFiveGigE.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.TwentyFiveGigE.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.TwentyFiveGigE.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.TwentyFiveGigE.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.TwentyFiveGigE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.TwentyFiveGigE.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.TwentyFiveGigE.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.TwentyFiveGigE.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.TwentyFiveGigE.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.TwentyFiveGigE.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.TwentyFiveGigE.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.TwentyFiveGigE.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.TwentyFiveGigE.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.TwentyFiveGigE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.TwentyFiveGigE.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.TwentyFiveGigE.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.TwentyFiveGigE.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.TwentyFiveGigE.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.TwentyFiveGigE.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.TwentyFiveGigE.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.TwentyFiveGigE.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.TwentyFiveGigE.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.TwentyFiveGigE.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.TwentyFiveGigE.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.TwentyFiveGigE.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.TwentyFiveGigE.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.TwentyFiveGigE.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.TwentyFiveGigE.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.TwentyFiveGigE.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.lacp = Native.Interface.TwentyFiveGigE.Lacp()
                self.lacp.parent = self
                self._children_name_map["lacp"] = "Cisco-IOS-XE-ethernet:lacp"

                self.cisco_ios_xe_ethernet_macsec_option = Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption()
                self.cisco_ios_xe_ethernet_macsec_option.parent = self
                self._children_name_map["cisco_ios_xe_ethernet_macsec_option"] = "Cisco-IOS-XE-ethernet:macsec-option"

                self.service_policy = Native.Interface.TwentyFiveGigE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.auto = Native.Interface.TwentyFiveGigE.Auto()
                self.auto.parent = self
                self._children_name_map["auto"] = "Cisco-IOS-XE-switch:auto"

                self.datalink = Native.Interface.TwentyFiveGigE.Datalink()
                self.datalink.parent = self
                self._children_name_map["datalink"] = "Cisco-IOS-XE-switch:datalink"

                self.energywise = None
                self._children_name_map["energywise"] = "Cisco-IOS-XE-switch:energywise"

                self.location = Native.Interface.TwentyFiveGigE.Location()
                self.location.parent = self
                self._children_name_map["location"] = "Cisco-IOS-XE-switch:location"

                self.mac = Native.Interface.TwentyFiveGigE.Mac()
                self.mac.parent = self
                self._children_name_map["mac"] = "Cisco-IOS-XE-switch:mac"

                self.macro = Native.Interface.TwentyFiveGigE.Macro()
                self.macro.parent = self
                self._children_name_map["macro"] = "Cisco-IOS-XE-switch:macro"

                self.dual_active = Native.Interface.TwentyFiveGigE.DualActive()
                self.dual_active.parent = self
                self._children_name_map["dual_active"] = "Cisco-IOS-XE-switch:dual-active"

                self.load_balancing = Native.Interface.TwentyFiveGigE.LoadBalancing()
                self.load_balancing.parent = self
                self._children_name_map["load_balancing"] = "Cisco-IOS-XE-switch:load-balancing"

                self.switch = Native.Interface.TwentyFiveGigE.Switch()
                self.switch.parent = self
                self._children_name_map["switch"] = "Cisco-IOS-XE-switch:switch"

                self.srr_queue = Native.Interface.TwentyFiveGigE.SrrQueue()
                self.srr_queue.parent = self
                self._children_name_map["srr_queue"] = "Cisco-IOS-XE-switch:srr-queue"

                self.cisco_ios_xe_switch_macsec_option_ = Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption()
                self.cisco_ios_xe_switch_macsec_option_.parent = self
                self._children_name_map["cisco_ios_xe_switch_macsec_option_"] = "Cisco-IOS-XE-switch:macsec-option"

                self.snmp = Native.Interface.TwentyFiveGigE.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.crypto = Native.Interface.TwentyFiveGigE.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.mka = Native.Interface.TwentyFiveGigE.Mka()
                self.mka.parent = self
                self._children_name_map["mka"] = "Cisco-IOS-XE-mka:mka"

                self.et_analytics = Native.Interface.TwentyFiveGigE.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.TwentyFiveGigE.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.TwentyFiveGigE.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.xconnect = Native.Interface.TwentyFiveGigE.Xconnect()
                self.xconnect.parent = self
                self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                self.evpn = Native.Interface.TwentyFiveGigE.Evpn()
                self.evpn.parent = self
                self._children_name_map["evpn"] = "Cisco-IOS-XE-l2vpn:evpn"

                self.fabric_domain = Native.Interface.TwentyFiveGigE.FabricDomain()
                self.fabric_domain.parent = self
                self._children_name_map["fabric_domain"] = "Cisco-IOS-XE-iwanfabric:fabric-domain"

                self.mvrp = None
                self._children_name_map["mvrp"] = "Cisco-IOS-XE-mvrp:mvrp"

                self.lisp = Native.Interface.TwentyFiveGigE.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.power = Native.Interface.TwentyFiveGigE.Power()
                self.power.parent = self
                self._children_name_map["power"] = "Cisco-IOS-XE-power:power"

                self.cdp = Native.Interface.TwentyFiveGigE.Cdp()
                self.cdp.parent = self
                self._children_name_map["cdp"] = "Cisco-IOS-XE-cdp:cdp"

                self.ntp = Native.Interface.TwentyFiveGigE.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.authentication = Native.Interface.TwentyFiveGigE.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "Cisco-IOS-XE-sanet:authentication"

                self.mab = None
                self._children_name_map["mab"] = "Cisco-IOS-XE-sanet:mab"

                self.dot1x = Native.Interface.TwentyFiveGigE.Dot1x()
                self.dot1x.parent = self
                self._children_name_map["dot1x"] = "Cisco-IOS-XE-dot1x:dot1x"

                self.spanning_tree = Native.Interface.TwentyFiveGigE.SpanningTree()
                self.spanning_tree.parent = self
                self._children_name_map["spanning_tree"] = "Cisco-IOS-XE-spanning-tree:spanning-tree"

                self.performance = Native.Interface.TwentyFiveGigE.Performance()
                self.performance.parent = self
                self._children_name_map["performance"] = "Cisco-IOS-XE-ezpm:performance"

                self.umbrella = Native.Interface.TwentyFiveGigE.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.lldp = Native.Interface.TwentyFiveGigE.Lldp()
                self.lldp.parent = self
                self._children_name_map["lldp"] = "Cisco-IOS-XE-lldp:lldp"

                self.ospfv3 = Native.Interface.TwentyFiveGigE.Ospfv3()
                self.ospfv3.parent = self
                self._children_name_map["ospfv3"] = "Cisco-IOS-XE-ospfv3:ospfv3"

                self.udld = Native.Interface.TwentyFiveGigE.Udld()
                self.udld.parent = self
                self._children_name_map["udld"] = "Cisco-IOS-XE-udld:udld"

                self.cts = Native.Interface.TwentyFiveGigE.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.analysis_module = Native.Interface.TwentyFiveGigE.AnalysisModule()
                self.analysis_module.parent = self
                self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"

                self.hold_queue = YList(self)
                self.vlan_range = YList(self)
                self._segment_path = lambda: "TwentyFiveGigE" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.TwentyFiveGigE, [u'name', u'media_type', u'port_type', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex', 'cisco_ios_xe_ethernet_macsec', u'cisco_ios_xe_switch_macsec', 'nat66'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class MediaType(Enum):
                """
                MediaType (Enum Class)

                Media type

                .. data:: auto_select = 0

                .. data:: rj45 = 1

                .. data:: sfp = 2

                """

                auto_select = Enum.YLeaf(0, "auto-select")

                rj45 = Enum.YLeaf(1, "rj45")

                sfp = Enum.YLeaf(2, "sfp")


            class Nat66(Enum):
                """
                Nat66 (Enum Class)

                NAT66 interface commands

                .. data:: inside = 0

                .. data:: outside = 1

                """

                inside = Enum.YLeaf(0, "inside")

                outside = Enum.YLeaf(1, "outside")


            class PortType(Enum):
                """
                PortType (Enum Class)

                .. data:: nni = 0

                """

                nni = Enum.YLeaf(0, "nni")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Access>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Block>`
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: trunk
                
                	Set trunking characteristics of the interface
                	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Trunk>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Voice>`
                
                .. attribute:: priority
                
                	Set appliance 802.1p priority
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Priority>`
                
                .. attribute:: autostate
                
                	Include or exclude this port from vlan link up calculation
                	**type**\:  :py:class:`Autostate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Autostate>`
                
                .. attribute:: protected
                
                	Configure an interface to be a protected port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Set port host
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: private_vlan
                
                	Set the private VLAN configuration
                	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan>`
                
                .. attribute:: vepa
                
                	Reflective relay configuration
                	**type**\:  :py:class:`Vepa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Vepa>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:access", ("access", Native.Interface.TwentyFiveGigE.Switchport.Access)), ("Cisco-IOS-XE-switch:block", ("block", Native.Interface.TwentyFiveGigE.Switchport.Block)), ("Cisco-IOS-XE-switch:mode", ("mode", Native.Interface.TwentyFiveGigE.Switchport.Mode)), ("Cisco-IOS-XE-switch:port-security", ("port_security", Native.Interface.TwentyFiveGigE.Switchport.PortSecurity)), ("Cisco-IOS-XE-switch:trunk", ("trunk", Native.Interface.TwentyFiveGigE.Switchport.Trunk)), ("Cisco-IOS-XE-switch:voice", ("voice", Native.Interface.TwentyFiveGigE.Switchport.Voice)), ("Cisco-IOS-XE-switch:priority", ("priority", Native.Interface.TwentyFiveGigE.Switchport.Priority)), ("Cisco-IOS-XE-switch:autostate", ("autostate", Native.Interface.TwentyFiveGigE.Switchport.Autostate)), ("Cisco-IOS-XE-switch:private-vlan", ("private_vlan", Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan)), ("Cisco-IOS-XE-switch:vepa", ("vepa", Native.Interface.TwentyFiveGigE.Switchport.Vepa))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:nonegotiate'), ['Empty'])),
                        ('protected', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:protected'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:host'), ['Empty'])),
                    ])
                    self.nonegotiate = None
                    self.protected = None
                    self.host = None

                    self.access = Native.Interface.TwentyFiveGigE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "Cisco-IOS-XE-switch:access"

                    self.block = Native.Interface.TwentyFiveGigE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "Cisco-IOS-XE-switch:block"

                    self.mode = Native.Interface.TwentyFiveGigE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "Cisco-IOS-XE-switch:mode"

                    self.port_security = None
                    self._children_name_map["port_security"] = "Cisco-IOS-XE-switch:port-security"

                    self.trunk = Native.Interface.TwentyFiveGigE.Switchport.Trunk()
                    self.trunk.parent = self
                    self._children_name_map["trunk"] = "Cisco-IOS-XE-switch:trunk"

                    self.voice = Native.Interface.TwentyFiveGigE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "Cisco-IOS-XE-switch:voice"

                    self.priority = Native.Interface.TwentyFiveGigE.Switchport.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-switch:priority"

                    self.autostate = Native.Interface.TwentyFiveGigE.Switchport.Autostate()
                    self.autostate.parent = self
                    self._children_name_map["autostate"] = "Cisco-IOS-XE-switch:autostate"

                    self.private_vlan = Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan()
                    self.private_vlan.parent = self
                    self._children_name_map["private_vlan"] = "Cisco-IOS-XE-switch:private-vlan"

                    self.vepa = Native.Interface.TwentyFiveGigE.Switchport.Vepa()
                    self.vepa.parent = self
                    self._children_name_map["vepa"] = "Cisco-IOS-XE-switch:vepa"
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport, [u'nonegotiate', u'protected', u'host'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	Set VLAN when interface is in access mode
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Access.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwentyFiveGigE.Switchport.Access.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.TwentyFiveGigE.Switchport.Access.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:access"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Access, [], name, value)


                    class Vlan(Entity):
                        """
                        Set VLAN when interface is in access mode
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_>`
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.Access.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "access"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Access.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dynamic = 0

                            """

                            dynamic = Enum.YLeaf(0, "dynamic")



                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: multicast
                    
                    	Block unknown multicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.multicast = None
                        self.unicast = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:block"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Block, [u'multicast', u'unicast'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Mode.Access>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dot1q_tunnel
                    
                    	set trunking mode to TUNNEL unconditionally
                    	**type**\:  :py:class:`Dot1qTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Mode.Dot1qTunnel>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dynamic
                    
                    	Set trunking mode to dynamically negotiate access or trunk mode
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Mode.Dynamic>`
                    
                    .. attribute:: private_vlan
                    
                    	Set private\-vlan mode
                    	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Mode.PrivateVlan>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Mode.Trunk>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.TwentyFiveGigE.Switchport.Mode.Access)), ("dot1q-tunnel", ("dot1q_tunnel", Native.Interface.TwentyFiveGigE.Switchport.Mode.Dot1qTunnel)), ("private-vlan", ("private_vlan", Native.Interface.TwentyFiveGigE.Switchport.Mode.PrivateVlan)), ("trunk", ("trunk", Native.Interface.TwentyFiveGigE.Switchport.Mode.Trunk))])
                        self._leafs = OrderedDict([
                            ('dynamic', (YLeaf(YType.enumeration, 'dynamic'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Switchport.Mode.Dynamic')])),
                        ])
                        self.dynamic = None

                        self.access = None
                        self._children_name_map["access"] = "access"

                        self.dot1q_tunnel = None
                        self._children_name_map["dot1q_tunnel"] = "dot1q-tunnel"

                        self.private_vlan = Native.Interface.TwentyFiveGigE.Switchport.Mode.PrivateVlan()
                        self.private_vlan.parent = self
                        self._children_name_map["private_vlan"] = "private-vlan"

                        self.trunk = None
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Mode, [u'dynamic'], name, value)

                    class Dynamic(Enum):
                        """
                        Dynamic (Enum Class)

                        Set trunking mode to dynamically negotiate access or trunk mode

                        .. data:: auto = 0

                        .. data:: desirable = 1

                        """

                        auto = Enum.YLeaf(0, "auto")

                        desirable = Enum.YLeaf(1, "desirable")



                    class Access(Entity):
                        """
                        Set trunking mode to ACCESS unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.Mode.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "access"
                            self._is_frozen = True


                    class Dot1qTunnel(Entity):
                        """
                        set trunking mode to TUNNEL unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.Mode.Dot1qTunnel, self).__init__()

                            self.yang_name = "dot1q-tunnel"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dot1q-tunnel"
                            self._is_frozen = True


                    class PrivateVlan(Entity):
                        """
                        Set private\-vlan mode
                        
                        .. attribute:: host
                        
                        	Set the mode to private\-vlan host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: promiscuous
                        
                        	Set the mode to private\-vlan promiscuous
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.Mode.PrivateVlan, self).__init__()

                            self.yang_name = "private-vlan"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('promiscuous', (YLeaf(YType.empty, 'promiscuous'), ['Empty'])),
                            ])
                            self.host = None
                            self.promiscuous = None
                            self._segment_path = lambda: "private-vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Mode.PrivateVlan, [u'host', u'promiscuous'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking mode to TRUNK unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.Mode.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: mac_address
                    
                    	Secure mac address
                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.MacAddress>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Aging)), ("mac-address", ("mac_address", Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.MacAddress)), ("maximum", ("maximum", Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Maximum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Switchport.PortSecurity.Violation')])),
                        ])
                        self.violation = None

                        self.aging = Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.mac_address = Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"

                        self.maximum = Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:port-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.PortSecurity, [u'violation'], name, value)

                    class Violation(Enum):
                        """
                        Violation (Enum Class)

                        Security violation mode

                        .. data:: protect = 0

                        .. data:: restrict = 1

                        .. data:: shutdown = 2

                        """

                        protect = Enum.YLeaf(0, "protect")

                        restrict = Enum.YLeaf(1, "restrict")

                        shutdown = Enum.YLeaf(2, "shutdown")



                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Aging.Type>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Switchport.PortSecurity.Aging.Type')])),
                            ])
                            self.static = None
                            self.time = None
                            self.type = None
                            self._segment_path = lambda: "aging"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Aging, [u'static', u'time', u'type'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Port\-security aging type

                            .. data:: absolute = 0

                            .. data:: inactivity = 1

                            """

                            absolute = Enum.YLeaf(0, "absolute")

                            inactivity = Enum.YLeaf(1, "inactivity")



                    class MacAddress(Entity):
                        """
                        Secure mac address
                        
                        .. attribute:: sticky
                        
                        	Configure dynamic secure addresses as sticky
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hw_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: vlan
                        
                        	set VLAN ID of the VLAN on which this address can be learned
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                ('hw_address', (YLeaf(YType.str, 'hw-address'), ['str'])),
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.sticky = None
                            self.hw_address = None
                            self.vlan = None
                            self._segment_path = lambda: "mac-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.MacAddress, [u'sticky', u'hw_address', u'vlan'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: max_addresses
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4097
                        
                        .. attribute:: vlan
                        
                        	Max secure addresses per vlan
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_addresses', (YLeaf(YType.uint16, 'max-addresses'), ['int'])),
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['str'])),
                            ])
                            self.max_addresses = None
                            self.vlan = None
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.PortSecurity.Maximum, [u'max_addresses', u'vlan'], name, value)


                class Trunk(Entity):
                    """
                    Set trunking characteristics of the interface
                    
                    .. attribute:: allowed
                    
                    	Set allowed VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Trunk.Allowed>`
                    
                    .. attribute:: encapsulation
                    
                    	Set encapsulation format on trunk port
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Trunk.Encapsulation>`
                    
                    .. attribute:: native
                    
                    	Set trunking native characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Trunk.Native_>`
                    
                    .. attribute:: pruning
                    
                    	Set pruning VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Pruning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Trunk.Pruning>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Switchport.Trunk, self).__init__()

                        self.yang_name = "trunk"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.TwentyFiveGigE.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.TwentyFiveGigE.Switchport.Trunk.Native_)), ("pruning", ("pruning", Native.Interface.TwentyFiveGigE.Switchport.Trunk.Pruning))])
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Switchport.Trunk.Encapsulation')])),
                        ])
                        self.encapsulation = None

                        self.allowed = Native.Interface.TwentyFiveGigE.Switchport.Trunk.Allowed()
                        self.allowed.parent = self
                        self._children_name_map["allowed"] = "allowed"

                        self.native = Native.Interface.TwentyFiveGigE.Switchport.Trunk.Native_()
                        self.native.parent = self
                        self._children_name_map["native"] = "native"

                        self.pruning = Native.Interface.TwentyFiveGigE.Switchport.Trunk.Pruning()
                        self.pruning.parent = self
                        self._children_name_map["pruning"] = "pruning"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:trunk"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Trunk, [u'encapsulation'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Set encapsulation format on trunk port

                        .. data:: dot1q = 0

                        .. data:: isl = 1

                        .. data:: negotiate = 2

                        """

                        dot1q = Enum.YLeaf(0, "dot1q")

                        isl = Enum.YLeaf(1, "isl")

                        negotiate = Enum.YLeaf(2, "negotiate")



                    class Allowed(Entity):
                        """
                        Set allowed VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set allowed VLANs when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Trunk.Allowed.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.Trunk.Allowed, self).__init__()

                            self.yang_name = "allowed"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwentyFiveGigE.Switchport.Trunk.Allowed.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.TwentyFiveGigE.Switchport.Trunk.Allowed.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "allowed"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Trunk.Allowed, [], name, value)


                        class Vlan(Entity):
                            """
                            Set allowed VLANs when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: all
                            
                            	all VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "allowed"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = None
                                self.add = None
                                self.all = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                    class Native_(Entity):
                        """
                        Set trunking native characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set native VLAN when interface is in trunking mode
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.Trunk.Native_, self).__init__()

                            self.yang_name = "native"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan'),'int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "native"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Trunk.Native_, [u'vlan'], name, value)

                        class Vlan(Enum):
                            """
                            Vlan (Enum Class)

                            Set native VLAN when interface is in trunking mode

                            .. data:: tag = 0

                            """

                            tag = Enum.YLeaf(0, "tag")



                    class Pruning(Entity):
                        """
                        Set pruning VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set VLANs enabled for pruning when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Trunk.Pruning.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.Trunk.Pruning, self).__init__()

                            self.yang_name = "pruning"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwentyFiveGigE.Switchport.Trunk.Pruning.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.TwentyFiveGigE.Switchport.Trunk.Pruning.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "pruning"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Trunk.Pruning, [], name, value)


                        class Vlan(Entity):
                            """
                            Set VLANs enabled for pruning when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Switchport.Trunk.Pruning.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "pruning"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeafList(YType.str, 'vlans'), ['int','str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = []
                                self.add = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Trunk.Pruning.Vlan, [u'vlans', u'add', u'except_', u'none', u'remove'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Voice.Vlan>`
                    
                    .. attribute:: detect
                    
                    	detection enhancement keyword
                    	**type**\:  :py:class:`Detect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Voice.Detect>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwentyFiveGigE.Switchport.Voice.Vlan)), ("detect", ("detect", Native.Interface.TwentyFiveGigE.Switchport.Voice.Detect))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.TwentyFiveGigE.Switchport.Voice.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"

                        self.detect = Native.Interface.TwentyFiveGigE.Switchport.Voice.Detect()
                        self.detect.parent = self
                        self._children_name_map["detect"] = "detect"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:voice"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Voice, [], name, value)


                    class Vlan(Entity):
                        """
                        Vlan for voice traffic
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\: str
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.Voice.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_'),'int','str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Voice.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dot1p = 0

                            .. data:: none = 1

                            .. data:: untagged = 2

                            """

                            dot1p = Enum.YLeaf(0, "dot1p")

                            none = Enum.YLeaf(1, "none")

                            untagged = Enum.YLeaf(2, "untagged")



                    class Detect(Entity):
                        """
                        detection enhancement keyword
                        
                        .. attribute:: cisco_phone
                        
                        	Cisco IP phone
                        	**type**\:  :py:class:`CiscoPhone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Voice.Detect.CiscoPhone>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.Voice.Detect, self).__init__()

                            self.yang_name = "detect"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cisco-phone", ("cisco_phone", Native.Interface.TwentyFiveGigE.Switchport.Voice.Detect.CiscoPhone))])
                            self._leafs = OrderedDict()

                            self.cisco_phone = None
                            self._children_name_map["cisco_phone"] = "cisco-phone"
                            self._segment_path = lambda: "detect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Voice.Detect, [], name, value)


                        class CiscoPhone(Entity):
                            """
                            Cisco IP phone
                            
                            .. attribute:: full_duplex
                            
                            	full duplex keyword
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Switchport.Voice.Detect.CiscoPhone, self).__init__()

                                self.yang_name = "cisco-phone"
                                self.yang_parent_name = "detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('full_duplex', (YLeaf(YType.empty, 'full-duplex'), ['Empty'])),
                                ])
                                self.full_duplex = None
                                self._segment_path = lambda: "cisco-phone"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Voice.Detect.CiscoPhone, [u'full_duplex'], name, value)


                class Priority(Entity):
                    """
                    Set appliance 802.1p priority
                    
                    .. attribute:: extend
                    
                    	Set appliance 802.1p priority
                    	**type**\:  :py:class:`Extend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.Priority.Extend>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Switchport.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("extend", ("extend", Native.Interface.TwentyFiveGigE.Switchport.Priority.Extend))])
                        self._leafs = OrderedDict()

                        self.extend = Native.Interface.TwentyFiveGigE.Switchport.Priority.Extend()
                        self.extend.parent = self
                        self._children_name_map["extend"] = "extend"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Priority, [], name, value)


                    class Extend(Entity):
                        """
                        Set appliance 802.1p priority
                        
                        .. attribute:: trust
                        
                        	Trust 802.1p priorities of devices on appliance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cos
                        
                        	Override 802.1p priority of devices on appliance
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.Priority.Extend, self).__init__()

                            self.yang_name = "extend"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                            ])
                            self.trust = None
                            self.cos = None
                            self._segment_path = lambda: "extend"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Priority.Extend, [u'trust', u'cos'], name, value)


                class Autostate(Entity):
                    """
                    Include or exclude this port from vlan link up calculation
                    
                    .. attribute:: exclude
                    
                    	Exclude this port from vlan link up calculation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Switchport.Autostate, self).__init__()

                        self.yang_name = "autostate"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('exclude', (YLeaf(YType.empty, 'exclude'), ['Empty'])),
                        ])
                        self.exclude = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:autostate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Autostate, [u'exclude'], name, value)


                class PrivateVlan(Entity):
                    """
                    Set the private VLAN configuration
                    
                    .. attribute:: association
                    
                    	Set the private VLAN association
                    	**type**\:  :py:class:`Association <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association>`
                    
                    .. attribute:: host_association
                    
                    	Set the private VLAN host association
                    	**type**\:  :py:class:`HostAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.HostAssociation>`
                    
                    .. attribute:: mapping
                    
                    	Set the private VLAN promiscuous mapping
                    	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Mapping>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan, self).__init__()

                        self.yang_name = "private-vlan"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("association", ("association", Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association)), ("host-association", ("host_association", Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.HostAssociation)), ("mapping", ("mapping", Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Mapping))])
                        self._leafs = OrderedDict()

                        self.association = Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association()
                        self.association.parent = self
                        self._children_name_map["association"] = "association"

                        self.host_association = Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.HostAssociation()
                        self.host_association.parent = self
                        self._children_name_map["host_association"] = "host-association"

                        self.mapping = Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Mapping()
                        self.mapping.parent = self
                        self._children_name_map["mapping"] = "mapping"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:private-vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan, [], name, value)


                    class Association(Entity):
                        """
                        Set the private VLAN association
                        
                        .. attribute:: host
                        
                        	Set the private VLAN host association
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association.Host>`
                        
                        .. attribute:: mapping
                        
                        	Set the private VLAN promiscuous mapping
                        	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association.Mapping>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association, self).__init__()

                            self.yang_name = "association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association.Host)), ("mapping", ("mapping", Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association.Mapping))])
                            self._leafs = OrderedDict()

                            self.host = Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.mapping = Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association.Mapping()
                            self.mapping.parent = self
                            self._children_name_map["mapping"] = "mapping"
                            self._segment_path = lambda: "association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association, [], name, value)


                        class Host(Entity):
                            """
                            Set the private VLAN host association
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary normal range VLAN ID of the private VLAN host port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association.Host, [u'primary_range', u'secondary_range'], name, value)


                        class Mapping(Entity):
                            """
                            Set the private VLAN promiscuous mapping
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: remove
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association.Mapping, self).__init__()

                                self.yang_name = "mapping"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self.add = None
                                self.remove = None
                                self._segment_path = lambda: "mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Association.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                    class HostAssociation(Entity):
                        """
                        Set the private VLAN host association
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary normal range VLAN ID of the private VLAN host port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.HostAssociation, self).__init__()

                            self.yang_name = "host-association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self._segment_path = lambda: "host-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.HostAssociation, [u'primary_range', u'secondary_range'], name, value)


                    class Mapping(Entity):
                        """
                        Set the private VLAN promiscuous mapping
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: add
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: remove
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Mapping, self).__init__()

                            self.yang_name = "mapping"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self.add = None
                            self.remove = None
                            self._segment_path = lambda: "mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.PrivateVlan.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                class Vepa(Entity):
                    """
                    Reflective relay configuration
                    
                    .. attribute:: enabled
                    
                    	Enable reflective relay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Switchport.Vepa, self).__init__()

                        self.yang_name = "vepa"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                        ])
                        self.enabled = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:vepa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Switchport.Vepa, [u'enabled'], name, value)


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TwentyFiveGigE.Backup.Delay)), ("interface", ("interface", Native.Interface.TwentyFiveGigE.Backup.Interface_)), ("load", ("load", Native.Interface.TwentyFiveGigE.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.TwentyFiveGigE.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.TwentyFiveGigE.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.TwentyFiveGigE.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.TwentyFiveGigE.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.TwentyFiveGigE.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.TwentyFiveGigE.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.TwentyFiveGigE.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.TwentyFiveGigE.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.TwentyFiveGigE.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.TwentyFiveGigE.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.TwentyFiveGigE.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.TwentyFiveGigE.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.TwentyFiveGigE.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.TwentyFiveGigE.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.TwentyFiveGigE.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.TwentyFiveGigE.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.TwentyFiveGigE.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.TwentyFiveGigE.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.TwentyFiveGigE.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.TwentyFiveGigE.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.TwentyFiveGigE.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.TwentyFiveGigE.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.TwentyFiveGigE.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.TwentyFiveGigE.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.TwentyFiveGigE.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.TwentyFiveGigE.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.TwentyFiveGigE.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.TwentyFiveGigE.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.TwentyFiveGigE.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.TwentyFiveGigE.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.TwentyFiveGigE.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.TwentyFiveGigE.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.TwentyFiveGigE.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.TwentyFiveGigE.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.TwentyFiveGigE.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.TwentyFiveGigE.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.TwentyFiveGigE.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.TwentyFiveGigE.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.TwentyFiveGigE.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.TwentyFiveGigE.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.TwentyFiveGigE.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.TwentyFiveGigE.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.TwentyFiveGigE.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.TwentyFiveGigE.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.TwentyFiveGigE.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.TwentyFiveGigE.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.TwentyFiveGigE.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.TwentyFiveGigE.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.TwentyFiveGigE.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.TwentyFiveGigE.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.TwentyFiveGigE.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.TwentyFiveGigE.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.TwentyFiveGigE.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.TwentyFiveGigE.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.TwentyFiveGigE.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.TwentyFiveGigE.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.TwentyFiveGigE.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.TwentyFiveGigE.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.TwentyFiveGigE.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.TwentyFiveGigE.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.TwentyFiveGigE.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.TwentyFiveGigE.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.TwentyFiveGigE.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.TwentyFiveGigE.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.TwentyFiveGigE.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.TwentyFiveGigE.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.TwentyFiveGigE.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.TwentyFiveGigE.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.TwentyFiveGigE.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.TwentyFiveGigE.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.TwentyFiveGigE.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.TwentyFiveGigE.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.TwentyFiveGigE.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.TwentyFiveGigE.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.TwentyFiveGigE.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.TwentyFiveGigE.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.TwentyFiveGigE.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.TwentyFiveGigE.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.TwentyFiveGigE.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.TwentyFiveGigE.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.TwentyFiveGigE.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.TwentyFiveGigE.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.TwentyFiveGigE.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.TwentyFiveGigE.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.TwentyFiveGigE.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.TwentyFiveGigE.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.TwentyFiveGigE.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.TwentyFiveGigE.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.TwentyFiveGigE.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.TwentyFiveGigE.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.TwentyFiveGigE.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.TwentyFiveGigE.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.TwentyFiveGigE.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.TwentyFiveGigE.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.TwentyFiveGigE.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Igmp>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Flow>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Nbar>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf>`
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Lisp>`
                
                .. attribute:: rsvp
                
                	RSVP Interface Commands
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Nat>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.TwentyFiveGigE.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.TwentyFiveGigE.Ip.Arp)), ("vrf", ("vrf", Native.Interface.TwentyFiveGigE.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.TwentyFiveGigE.Ip.NoAddress)), ("address", ("address", Native.Interface.TwentyFiveGigE.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.TwentyFiveGigE.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.TwentyFiveGigE.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.TwentyFiveGigE.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.TwentyFiveGigE.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.TwentyFiveGigE.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.TwentyFiveGigE.Ip.Pim)), ("policy", ("policy", Native.Interface.TwentyFiveGigE.Ip.Policy)), ("rip", ("rip", Native.Interface.TwentyFiveGigE.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.TwentyFiveGigE.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.TwentyFiveGigE.Ip.RouteCache)), ("router", ("router", Native.Interface.TwentyFiveGigE.Ip.Router)), ("tcp", ("tcp", Native.Interface.TwentyFiveGigE.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.TwentyFiveGigE.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.TwentyFiveGigE.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.TwentyFiveGigE.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.TwentyFiveGigE.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.TwentyFiveGigE.Ip.Igmp)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.TwentyFiveGigE.Ip.Flow)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.TwentyFiveGigE.Ip.Nbar)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.TwentyFiveGigE.Ip.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.TwentyFiveGigE.Ip.Lisp)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Interface.TwentyFiveGigE.Ip.Rsvp)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.TwentyFiveGigE.Ip.Nat)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.TwentyFiveGigE.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None
                    self.unreachables = None

                    self.access_group = Native.Interface.TwentyFiveGigE.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.TwentyFiveGigE.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.TwentyFiveGigE.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.TwentyFiveGigE.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.TwentyFiveGigE.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.TwentyFiveGigE.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.TwentyFiveGigE.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.TwentyFiveGigE.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.TwentyFiveGigE.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.TwentyFiveGigE.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.TwentyFiveGigE.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.TwentyFiveGigE.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.TwentyFiveGigE.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.TwentyFiveGigE.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.TwentyFiveGigE.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.TwentyFiveGigE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.TwentyFiveGigE.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.TwentyFiveGigE.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.TwentyFiveGigE.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.flow = Native.Interface.TwentyFiveGigE.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.nbar = Native.Interface.TwentyFiveGigE.Ip.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.ospf = Native.Interface.TwentyFiveGigE.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.lisp = Native.Interface.TwentyFiveGigE.Ip.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                    self.rsvp = Native.Interface.TwentyFiveGigE.Ip.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

                    self.nat = Native.Interface.TwentyFiveGigE.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.wccp = Native.Interface.TwentyFiveGigE.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache', 'unreachables'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.TwentyFiveGigE.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.TwentyFiveGigE.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.TwentyFiveGigE.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.TwentyFiveGigE.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.TwentyFiveGigE.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.TwentyFiveGigE.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.TwentyFiveGigE.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.TwentyFiveGigE.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.TwentyFiveGigE.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.TwentyFiveGigE.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.TwentyFiveGigE.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.TwentyFiveGigE.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.TwentyFiveGigE.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.TwentyFiveGigE.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.TwentyFiveGigE.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.TwentyFiveGigE.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.TwentyFiveGigE.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.TwentyFiveGigE.Ip.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ip.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ip.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.TwentyFiveGigE.Ip.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.TwentyFiveGigE.Ip.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TwentyFiveGigE.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.TwentyFiveGigE.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.TwentyFiveGigE.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.TwentyFiveGigE.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.TwentyFiveGigE.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.TwentyFiveGigE.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.TwentyFiveGigE.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwentyFiveGigE.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.TwentyFiveGigE.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.TwentyFiveGigE.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.TwentyFiveGigE.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TwentyFiveGigE.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.TwentyFiveGigE.Ip.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ip.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.TwentyFiveGigE.Ip.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.TwentyFiveGigE.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.TwentyFiveGigE.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.TwentyFiveGigE.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.TwentyFiveGigE.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.TwentyFiveGigE.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.TwentyFiveGigE.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.TwentyFiveGigE.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.TwentyFiveGigE.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.TwentyFiveGigE.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.TwentyFiveGigE.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TwentyFiveGigE.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.TwentyFiveGigE.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.TwentyFiveGigE.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.TwentyFiveGigE.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.TwentyFiveGigE.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.TwentyFiveGigE.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.TwentyFiveGigE.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.TwentyFiveGigE.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.TwentyFiveGigE.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.TwentyFiveGigE.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwentyFiveGigE.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.TwentyFiveGigE.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Lisp(Entity):
                    """
                    Locator/ID Separation Protocol
                    
                    .. attribute:: source_locator
                    
                    	Choose IP source address for LISP packets egressing this interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_locator', (YLeaf(YType.str, 'source-locator'), ['str'])),
                        ])
                        self.source_locator = None
                        self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Lisp, ['source_locator'], name, value)


                class Rsvp(Entity):
                    """
                    RSVP Interface Commands
                    
                    .. attribute:: authentication
                    
                    	Enables RSVP neighbor authentication (RFC 2747)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bandwidth
                    
                    	RSVP Reservable Bandwidth (kbps)
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	Select permissible RSVP neighbors
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Neighbor>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: precedence
                    
                    	RSVP precedence setting
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Precedence>`
                    
                    .. attribute:: signalling
                    
                    	RSVP signalling
                    	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling>`
                    
                    .. attribute:: tos
                    
                    	RSVP TOS setting
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Tos>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Authentication)), ("bandwidth", ("bandwidth", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth)), ("neighbor", ("neighbor", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Neighbor)), ("precedence", ("precedence", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Precedence)), ("signalling", ("signalling", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling)), ("tos", ("tos", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Tos))])
                        self._leafs = OrderedDict()

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.bandwidth = None
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.neighbor = None
                        self._children_name_map["neighbor"] = "neighbor"

                        self.precedence = Native.Interface.TwentyFiveGigE.Ip.Rsvp.Precedence()
                        self.precedence.parent = self
                        self._children_name_map["precedence"] = "precedence"

                        self.signalling = Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling()
                        self.signalling.parent = self
                        self._children_name_map["signalling"] = "signalling"

                        self.tos = Native.Interface.TwentyFiveGigE.Ip.Rsvp.Tos()
                        self.tos.parent = self
                        self._children_name_map["tos"] = "tos"
                        self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp, [], name, value)


                    class Authentication(Entity):
                        """
                        Enables RSVP neighbor authentication (RFC 2747)
                        
                        .. attribute:: key
                        
                        	Password (8 to 40 characters, spaces allowed)
                        	**type**\: str
                        
                        .. attribute:: challenge
                        
                        	Perform challenge/response handshake with new neighbor(s)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key_chain
                        
                        	Name of key chain to use (as created by global 'key chain' command)
                        	**type**\: str
                        
                        .. attribute:: lifetime
                        
                        	Maximum lifetime of neighbor authentication state
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Authentication.Lifetime>`
                        
                        .. attribute:: type
                        
                        	Type of authentication algorithm (default = md5)
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Authentication.Type>`
                        
                        .. attribute:: window_size
                        
                        	Maximum number of messages allowed in receive window (default = 1)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Authentication.Lifetime))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ip.Rsvp.Authentication.Type')])),
                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                            ])
                            self.key = None
                            self.challenge = None
                            self.key_chain = None
                            self.type = None
                            self.window_size = None

                            self.lifetime = Native.Interface.TwentyFiveGigE.Ip.Rsvp.Authentication.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Authentication, ['key', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Type of authentication algorithm (default = md5)

                            .. data:: md5 = 0

                            .. data:: sha_1 = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            sha_1 = Enum.YLeaf(1, "sha-1")



                        class Lifetime(Entity):
                            """
                            Maximum lifetime of neighbor authentication state
                            
                            .. attribute:: hh_mm_ss
                            
                            	Lifetime (default = 30 mins) in hh\:mm\:ss format
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ])
                                self.hh_mm_ss = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


                    class Bandwidth(Entity):
                        """
                        RSVP Reservable Bandwidth (kbps)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Value>`
                        
                        .. attribute:: percent
                        
                        	Percentage of interface bandwidth. Values higher than 100 represent overbooking
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: mam
                        
                        	Use bandwidth with MAM model of DSTE
                        	**type**\:  :py:class:`Mam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Mam>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Value)), ("mam", ("mam", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Mam))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                            ])
                            self.percent = None

                            self.value = Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.mam = Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Mam()
                            self.mam.parent = self
                            self._children_name_map["mam"] = "mam"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth, ['percent'], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	Reservable Bandwidth (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            .. attribute:: sub_pool
                            
                            	Reservable Bandwidth for Tunnel using sub (BC1) pool (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.value = None
                                self.sub_pool = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Value, ['value', 'sub_pool'], name, value)


                        class Mam(Entity):
                            """
                            Use bandwidth with MAM model of DSTE
                            
                            .. attribute:: max_reservable_bw
                            
                            	Maximum Reservable bandwidth for MAM
                            	**type**\:  :py:class:`MaxReservableBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Mam, self).__init__()

                                self.yang_name = "mam"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("max-reservable-bw", ("max_reservable_bw", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw))])
                                self._leafs = OrderedDict()

                                self.max_reservable_bw = None
                                self._children_name_map["max_reservable_bw"] = "max-reservable-bw"
                                self._segment_path = lambda: "mam"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Mam, [], name, value)


                            class MaxReservableBw(Entity):
                                """
                                Maximum Reservable bandwidth for MAM
                                
                                .. attribute:: value
                                
                                	Reservable Bandwidth (kbps)
                                	**type**\: int
                                
                                	**range:** 1..10000000
                                
                                .. attribute:: bc0
                                
                                	Reservable Bandwidth from global (BC0) pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                .. attribute:: bc1
                                
                                	Reservable Bandwidth from sub pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, self).__init__()

                                    self.yang_name = "max-reservable-bw"
                                    self.yang_parent_name = "mam"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                        ('bc0', (YLeaf(YType.uint32, 'bc0'), ['int'])),
                                        ('bc1', (YLeaf(YType.uint32, 'bc1'), ['int'])),
                                    ])
                                    self.value = None
                                    self.bc0 = None
                                    self.bc1 = None
                                    self._segment_path = lambda: "max-reservable-bw"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, ['value', 'bc0', 'bc1'], name, value)


                    class Neighbor(Entity):
                        """
                        Select permissible RSVP neighbors
                        
                        .. attribute:: acl_number
                        
                        	Access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                            ])
                            self.acl_number = None
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Neighbor, ['acl_number'], name, value)


                    class Precedence(Entity):
                        """
                        RSVP precedence setting
                        
                        .. attribute:: conform
                        
                        	Precedence for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: exceed
                        
                        	Precedence for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Precedence, ['conform', 'exceed'], name, value)


                    class Signalling(Entity):
                        """
                        RSVP signalling
                        
                        .. attribute:: dscp
                        
                        	DSCP for RSVP signalling messages
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: fast_local_repair
                        
                        	Fast Local Repair parameters
                        	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.FastLocalRepair>`
                        
                        .. attribute:: hello
                        
                        	Enable neighbor\-down detection
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling, self).__init__()

                            self.yang_name = "signalling"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.fast_local_repair = Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.FastLocalRepair()
                            self.fast_local_repair.parent = self
                            self._children_name_map["fast_local_repair"] = "fast-local-repair"

                            self.hello = None
                            self._children_name_map["hello"] = "hello"
                            self._segment_path = lambda: "signalling"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling, ['dscp'], name, value)


                        class FastLocalRepair(Entity):
                            """
                            Fast Local Repair parameters
                            
                            .. attribute:: wait_time
                            
                            	Wait Time for start of Fast Local Repair in msec
                            	**type**\: int
                            
                            	**range:** 0..5000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                                self.yang_name = "fast-local-repair"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint16, 'wait-time'), ['int'])),
                                ])
                                self.wait_time = None
                                self._segment_path = lambda: "fast-local-repair"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.FastLocalRepair, ['wait_time'], name, value)


                        class Hello(Entity):
                            """
                            Enable neighbor\-down detection
                            
                            .. attribute:: bfd
                            
                            	Configure BFD trigger for MPLS/TE FRR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	DSCP for RSVP Hello messages
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: graceful_restart
                            
                            	Configure RSVP Graceful Restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: refresh
                            
                            	Configure RSVP Hello refresh behavior for Fast\-Reroute
                            	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Refresh>`
                            
                            .. attribute:: reroute
                            
                            	Configure RSVP Hello refresh behavior for Reroute
                            	**type**\:  :py:class:`Reroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Reroute>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Refresh)), ("reroute", ("reroute", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Reroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ('graceful_restart', (YLeaf(YType.empty, 'graceful-restart'), ['Empty'])),
                                ])
                                self.bfd = None
                                self.dscp = None
                                self.graceful_restart = None

                                self.refresh = Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Refresh()
                                self.refresh.parent = self
                                self._children_name_map["refresh"] = "refresh"

                                self.reroute = Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Reroute()
                                self.reroute.parent = self
                                self._children_name_map["reroute"] = "reroute"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello, ['bfd', 'dscp', 'graceful_restart'], name, value)


                            class Refresh(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Fast\-Reroute
                                
                                .. attribute:: interval
                                
                                	Hello interval in msec
                                	**type**\: int
                                
                                	**range:** 10..30000
                                
                                .. attribute:: misses
                                
                                	Number of missed Hello Acks which triggers neighbor down
                                	**type**\: int
                                
                                	**range:** 4..10
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Refresh, self).__init__()

                                    self.yang_name = "refresh"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.misses = None
                                    self._segment_path = lambda: "refresh"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Refresh, ['interval', 'misses'], name, value)


                            class Reroute(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Reroute
                                
                                .. attribute:: dscp
                                
                                	DSCP for RSVP Hello messages
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: refresh
                                
                                	Configure RSVP Reroute Hello refresh behavior
                                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Reroute.Refresh>`
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Reroute, self).__init__()

                                    self.yang_name = "reroute"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Reroute.Refresh))])
                                    self._leafs = OrderedDict([
                                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ])
                                    self.dscp = None

                                    self.refresh = Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Reroute.Refresh()
                                    self.refresh.parent = self
                                    self._children_name_map["refresh"] = "refresh"
                                    self._segment_path = lambda: "reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Reroute, ['dscp'], name, value)


                                class Refresh(Entity):
                                    """
                                    Configure RSVP Reroute Hello refresh behavior
                                    
                                    .. attribute:: interval
                                    
                                    	Hello Reroute interval in msec
                                    	**type**\: int
                                    
                                    	**range:** 1000..30000
                                    
                                    .. attribute:: misses
                                    
                                    	Number of missed Hello Acks which triggers neighbor down
                                    	**type**\: int
                                    
                                    	**range:** 4..10
                                    
                                    

                                    """

                                    _prefix = 'ios-rsvp'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, self).__init__()

                                        self.yang_name = "refresh"
                                        self.yang_parent_name = "reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.misses = None
                                        self._segment_path = lambda: "refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, ['interval', 'misses'], name, value)


                    class Tos(Entity):
                        """
                        RSVP TOS setting
                        
                        .. attribute:: conform
                        
                        	TOS for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: exceed
                        
                        	TOS for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Rsvp.Tos, ['conform', 'exceed'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.TwentyFiveGigE.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.TwentyFiveGigE.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.TwentyFiveGigE.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.TwentyFiveGigE.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.TwentyFiveGigE.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TwentyFiveGigE.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.TwentyFiveGigE.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TwentyFiveGigE.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.TwentyFiveGigE.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.TwentyFiveGigE.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.TwentyFiveGigE.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.TrafficFilter>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Flow>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Crypto>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Pim>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: rip
                
                	Configure RIP routing protocol
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Rip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.TwentyFiveGigE.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.TwentyFiveGigE.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.TwentyFiveGigE.Ipv6.Dhcp)), ("address", ("address", Native.Interface.TwentyFiveGigE.Ipv6.Address)), ("nd", ("nd", Native.Interface.TwentyFiveGigE.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.TwentyFiveGigE.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.TwentyFiveGigE.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.TwentyFiveGigE.Ipv6.Flow)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.TwentyFiveGigE.Ipv6.Crypto)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.TwentyFiveGigE.Ipv6.Ospf)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.TwentyFiveGigE.Ipv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.TwentyFiveGigE.Ipv6.Pim)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Interface.TwentyFiveGigE.Ipv6.Rip))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None
                    self.unreachables = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.TwentyFiveGigE.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.TwentyFiveGigE.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.TwentyFiveGigE.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.TwentyFiveGigE.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.flow = Native.Interface.TwentyFiveGigE.Ipv6.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.crypto = Native.Interface.TwentyFiveGigE.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.ospf = Native.Interface.TwentyFiveGigE.Ipv6.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.no_pim = Native.Interface.TwentyFiveGigE.Ipv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.TwentyFiveGigE.Ipv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects', 'unreachables'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.TwentyFiveGigE.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.TwentyFiveGigE.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.TwentyFiveGigE.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.TwentyFiveGigE.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.TwentyFiveGigE.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.TwentyFiveGigE.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.TwentyFiveGigE.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.TwentyFiveGigE.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.TwentyFiveGigE.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.TwentyFiveGigE.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.TwentyFiveGigE.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TwentyFiveGigE.Ipv6.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.TwentyFiveGigE.Ipv6.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ipv6.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ipv6.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Crypto, ['map'], name, value)


                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process
                    
                    	
                    	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Process>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: encryption
                    
                    	Enable encryption
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Network>`
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process", ("process", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Process)), ("authentication", ("authentication", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication)), ("bfd", ("bfd", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.DemandCircuit)), ("encryption", ("encryption", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption)), ("flood-reduction", ("flood_reduction", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.FloodReduction)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.MtuIgnore)), ("neighbor", ("neighbor", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Neighbor)), ("network", ("network", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Network)), ("shutdown", ("shutdown", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Shutdown))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.cost = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.encryption = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.network = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.process = YList(self)
                        self.neighbor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf, ['cost', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Process(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: instance
                        
                        	Set the OSPF instance
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..31
                        
                        		**type**\: int
                        
                        			**range:** 32..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Process, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['int','int'])),
                            ])
                            self.id = None
                            self.area = None
                            self.instance = None
                            self._segment_path = lambda: "process" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Process, ['id', 'area', 'instance'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec authentication
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec authentication
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 256..4294967295
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5>`
                            
                            .. attribute:: sha1
                            
                            	Use SHA\-1 authentication
                            	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ])
                                self.spi = None

                                self.md5 = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.sha1 = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1()
                                self.sha1.parent = self
                                self._children_name_map["sha1"] = "sha1"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec, ['spi'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Sha1(Entity):
                                """
                                Use SHA\-1 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1, self).__init__()

                                    self.yang_name = "sha1"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "sha1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "sha1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ipv6.Ospf.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.DatabaseFilter, ['all', 'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.DemandCircuit, ['disable', 'ignore'], name, value)


                    class Encryption(Entity):
                        """
                        Enable encryption
                        
                        .. attribute:: null
                        
                        	No IPsec encryption on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec encryption
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec encryption
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: esp
                            
                            	Use ESP encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipsec_3des
                            
                            	Use 3DES encryption
                            	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des>`
                            
                            .. attribute:: aes_cbc
                            
                            	Use AES\-CBC encryption
                            	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                                ])
                                self.spi = None
                                self.esp = None

                                self.ipsec_3des = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des()
                                self.ipsec_3des.parent = self
                                self._children_name_map["ipsec_3des"] = "ipsec_3des"

                                self.aes_cbc = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc()
                                self.aes_cbc.parent = self
                                self._children_name_map["aes_cbc"] = "aes-cbc"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec, ['spi', 'esp'], name, value)


                            class Ipsec3des(Entity):
                                """
                                Use 3DES encryption
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, self).__init__()

                                    self.yang_name = "ipsec_3des"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "ipsec_3des"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "ipsec_3des"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class AesCbc(Entity):
                                """
                                Use AES\-CBC encryption
                                
                                .. attribute:: aes_cbc_128
                                
                                	Use 128 bit key
                                	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128>`
                                
                                .. attribute:: aes_192
                                
                                	Use 192 bit key
                                	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192>`
                                
                                .. attribute:: aes_256
                                
                                	Use 256 bit key
                                	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc, self).__init__()

                                    self.yang_name = "aes-cbc"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256))])
                                    self._leafs = OrderedDict()

                                    self.aes_cbc_128 = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128()
                                    self.aes_cbc_128.parent = self
                                    self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                    self.aes_192 = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192()
                                    self.aes_192.parent = self
                                    self._children_name_map["aes_192"] = "aes-192"

                                    self.aes_256 = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256()
                                    self.aes_256.parent = self
                                    self._children_name_map["aes_256"] = "aes-256"
                                    self._segment_path = lambda: "aes-cbc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc, [], name, value)


                                class AesCbc128(Entity):
                                    """
                                    Use 128 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                        self.yang_name = "aes-cbc-128"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-cbc-128"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-cbc-128"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes192(Entity):
                                    """
                                    Use 192 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                        self.yang_name = "aes-192"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-192"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-192"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes256(Entity):
                                    """
                                    Use 256 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                        self.yang_name = "aes-256"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-256"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	Disable Flood Reduction on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.FloodReduction, ['disable'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.MtuIgnore, ['disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ipv6.Ospf.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Ospf.Shutdown, ['disable'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.TwentyFiveGigE.Ipv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.TwentyFiveGigE.Ipv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Pim.Bsr, ['border'], name, value)


                class Rip(Entity):
                    """
                    Configure RIP routing protocol
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable/disable RIP routing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default_information
                    
                    	Configure handling of default route
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Rip.DefaultInformation>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ipv6.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("default-information", ("default_information", Native.Interface.TwentyFiveGigE.Ipv6.Rip.DefaultInformation))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.id = None
                        self.enable = None

                        self.default_information = Native.Interface.TwentyFiveGigE.Ipv6.Rip.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Rip, ['id', 'enable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Configure handling of default route
                        
                        .. attribute:: route
                        
                        	
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ipv6.Rip.DefaultInformation.Route>`
                        
                        .. attribute:: metric
                        
                        	Default route metric
                        	**type**\: int
                        
                        	**range:** 1..15
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ipv6.Rip.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route', (YLeaf(YType.enumeration, 'route'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ipv6.Rip.DefaultInformation.Route')])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ])
                            self.route = None
                            self.metric = None
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ipv6.Rip.DefaultInformation, ['route', 'metric'], name, value)

                        class Route(Enum):
                            """
                            Route (Enum Class)

                            .. data:: only = 0

                            .. data:: originate = 1

                            """

                            only = Enum.YLeaf(0, "only")

                            originate = Enum.YLeaf(1, "originate")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.TwentyFiveGigE.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.TwentyFiveGigE.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.TwentyFiveGigE.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.TwentyFiveGigE.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.TwentyFiveGigE.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.TwentyFiveGigE.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.TwentyFiveGigE.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.TwentyFiveGigE.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.TwentyFiveGigE.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TwentyFiveGigE.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.TwentyFiveGigE.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.TwentyFiveGigE.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.TwentyFiveGigE.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.TwentyFiveGigE.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.TwentyFiveGigE.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.TwentyFiveGigE.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.TwentyFiveGigE.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.TwentyFiveGigE.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.TwentyFiveGigE.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwentyFiveGigE.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.TwentyFiveGigE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.TwentyFiveGigE.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.TwentyFiveGigE.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.TwentyFiveGigE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.TwentyFiveGigE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.TwentyFiveGigE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.TwentyFiveGigE.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.TwentyFiveGigE.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.TwentyFiveGigE.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.TwentyFiveGigE.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.TwentyFiveGigE.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.TwentyFiveGigE.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.TwentyFiveGigE.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.TwentyFiveGigE.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.TwentyFiveGigE.CarrierDelay.Down)), ("up", ("up", Native.Interface.TwentyFiveGigE.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.TwentyFiveGigE.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.TwentyFiveGigE.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.TwentyFiveGigE.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.TwentyFiveGigE.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.TwentyFiveGigE.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.TwentyFiveGigE.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.TwentyFiveGigE.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.TwentyFiveGigE.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.TwentyFiveGigE.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.TwentyFiveGigE.Plim.Ethernet)), ("qos", ("qos", Native.Interface.TwentyFiveGigE.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.TwentyFiveGigE.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.TwentyFiveGigE.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.TwentyFiveGigE.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.TwentyFiveGigE.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.TwentyFiveGigE.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.TwentyFiveGigE.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.TwentyFiveGigE.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.TwentyFiveGigE.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.TwentyFiveGigE.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.TwentyFiveGigE.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.TwentyFiveGigE.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.TwentyFiveGigE.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.TwentyFiveGigE.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.TwentyFiveGigE.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.TwentyFiveGigE.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.TwentyFiveGigE.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect)), ("Cisco-IOS-XE-l2vpn:xconnect-pw-class", ("xconnect_pw_class", Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.TwentyFiveGigE.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.TwentyFiveGigE.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.TwentyFiveGigE.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.TwentyFiveGigE.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.TwentyFiveGigE.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.TwentyFiveGigE.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"

                        self.xconnect = Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                        self.xconnect_pw_class = Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.TwentyFiveGigE.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.TwentyFiveGigE.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.TwentyFiveGigE.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.TwentyFiveGigE.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.TwentyFiveGigE.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.TwentyFiveGigE.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.TwentyFiveGigE.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.TwentyFiveGigE.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.TwentyFiveGigE.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.TwentyFiveGigE.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Service.Instance.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Lacp(Entity):
                """
                LACP interface subcommands
                
                .. attribute:: port_priority
                
                	LACP priority on this interface 
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rate
                
                	Rate at which the LACP packets are requested to be ingressed to this interface
                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Lacp.Rate>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Lacp, self).__init__()

                    self.yang_name = "lacp"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_priority', (YLeaf(YType.uint32, 'port-priority'), ['int'])),
                        ('rate', (YLeaf(YType.enumeration, 'rate'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Lacp.Rate')])),
                    ])
                    self.port_priority = None
                    self.rate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:lacp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Lacp, ['port_priority', 'rate'], name, value)

                class Rate(Enum):
                    """
                    Rate (Enum Class)

                    Rate at which the LACP packets are requested to be ingressed to this interface

                    .. data:: fast = 0

                    .. data:: normal = 1

                    """

                    fast = Enum.YLeaf(0, "fast")

                    normal = Enum.YLeaf(1, "normal")



            class CiscoIOSXEEthernetMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: dot1q_in_clear
                    
                    	Dot1q in Clear option
                    	**type**\:  :py:class:`Dot1qInClear <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear>`
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('dot1q_in_clear', (YLeaf(YType.enumeration, 'dot1q-in-clear'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear')])),
                        ])
                        self.dot1q_in_clear = None

                        self.replay_protection = Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec, ['dot1q_in_clear'], name, value)

                    class Dot1qInClear(Enum):
                        """
                        Dot1qInClear (Enum Class)

                        Dot1q in Clear option

                        .. data:: Y_1 = 0

                        """

                        Y_1 = Enum.YLeaf(0, "1")



                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, ['window_size'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.TwentyFiveGigE.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.TwentyFiveGigE.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.TwentyFiveGigE.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.TwentyFiveGigE.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.TwentyFiveGigE.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.TwentyFiveGigE.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Auto(Entity):
                """
                Configure Automation
                
                .. attribute:: qos
                
                	Configure AutoQoS
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Auto.Qos>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Auto, self).__init__()

                    self.yang_name = "auto"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("qos", ("qos", Native.Interface.TwentyFiveGigE.Auto.Qos))])
                    self._leafs = OrderedDict()

                    self.qos = Native.Interface.TwentyFiveGigE.Auto.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:auto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Auto, [], name, value)


                class Qos(Entity):
                    """
                    Configure AutoQoS
                    
                    .. attribute:: classify
                    
                    	Configure classification for untrusted devices
                    	**type**\:  :py:class:`Classify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Auto.Qos.Classify>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trust
                    
                    	Trust the DSCP/CoS marking
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Auto.Qos.Trust>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: video
                    
                    	Configure AutoQoS for video devices
                    	**type**\:  :py:class:`Video <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Auto.Qos.Video>`
                    
                    .. attribute:: voip
                    
                    	Configure AutoQoS for VoIP
                    	**type**\:  :py:class:`Voip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Auto.Qos.Voip>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Auto.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "auto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("classify", ("classify", Native.Interface.TwentyFiveGigE.Auto.Qos.Classify)), ("trust", ("trust", Native.Interface.TwentyFiveGigE.Auto.Qos.Trust)), ("video", ("video", Native.Interface.TwentyFiveGigE.Auto.Qos.Video)), ("voip", ("voip", Native.Interface.TwentyFiveGigE.Auto.Qos.Voip))])
                        self._leafs = OrderedDict()

                        self.classify = None
                        self._children_name_map["classify"] = "classify"

                        self.trust = None
                        self._children_name_map["trust"] = "trust"

                        self.video = Native.Interface.TwentyFiveGigE.Auto.Qos.Video()
                        self.video.parent = self
                        self._children_name_map["video"] = "video"

                        self.voip = None
                        self._children_name_map["voip"] = "voip"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Auto.Qos, [], name, value)


                    class Classify(Entity):
                        """
                        Configure classification for untrusted devices
                        
                        .. attribute:: police
                        
                        	Configure QoS policing for untrusted devices
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Auto.Qos.Classify, self).__init__()

                            self.yang_name = "classify"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('police', (YLeaf(YType.empty, 'police'), ['Empty'])),
                            ])
                            self.police = None
                            self._segment_path = lambda: "classify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Auto.Qos.Classify, [u'police'], name, value)


                    class Trust(Entity):
                        """
                        Trust the DSCP/CoS marking
                        
                        .. attribute:: cos
                        
                        	Trust the CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	Trust the DSCP marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Auto.Qos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cos', (YLeaf(YType.empty, 'cos'), ['Empty'])),
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ])
                            self.cos = None
                            self.dscp = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Auto.Qos.Trust, [u'cos', u'dscp'], name, value)


                    class Video(Entity):
                        """
                        Configure AutoQoS for video devices
                        
                        .. attribute:: cts
                        
                        	Trust the QoS marking of the Cisco Telepresence System
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ip_camera
                        
                        	Trust the QoS marking of the Ip Video Surveillance camera
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: media_player
                        
                        	Trust the Qos marking of the Cisco Media Player
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Auto.Qos.Video, self).__init__()

                            self.yang_name = "video"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('cts', (YLeaf(YType.empty, 'cts'), ['Empty'])),
                                ('ip_camera', (YLeaf(YType.empty, 'ip-camera'), ['Empty'])),
                                ('media_player', (YLeaf(YType.empty, 'media-player'), ['Empty'])),
                            ])
                            self.cts = None
                            self.ip_camera = None
                            self.media_player = None
                            self._segment_path = lambda: "video"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Auto.Qos.Video, [u'cts', u'ip_camera', u'media_player'], name, value)


                    class Voip(Entity):
                        """
                        Configure AutoQoS for VoIP
                        
                        .. attribute:: cisco_phone
                        
                        	Trust the QoS marking of Cisco IP Phone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cisco_softphone
                        
                        	Trust the QoS marking of Cisco IP SoftPhone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trust
                        
                        	Trust the DSCP/CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Auto.Qos.Voip, self).__init__()

                            self.yang_name = "voip"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cisco_phone', (YLeaf(YType.empty, 'cisco-phone'), ['Empty'])),
                                ('cisco_softphone', (YLeaf(YType.empty, 'cisco-softphone'), ['Empty'])),
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.cisco_phone = None
                            self.cisco_softphone = None
                            self.trust = None
                            self._segment_path = lambda: "voip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Auto.Qos.Voip, [u'cisco_phone', u'cisco_softphone', u'trust'], name, value)


            class Datalink(Entity):
                """
                Interface Datalink commands
                
                .. attribute:: flow
                
                	Interface Flow configuration subcommands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Datalink.Flow>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Datalink, self).__init__()

                    self.yang_name = "datalink"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flow", ("flow", Native.Interface.TwentyFiveGigE.Datalink.Flow))])
                    self._leafs = OrderedDict()

                    self.flow = Native.Interface.TwentyFiveGigE.Datalink.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:datalink"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Datalink, [], name, value)


                class Flow(Entity):
                    """
                    Interface Flow configuration subcommands
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Datalink.Flow.Monitor>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Datalink.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "datalink"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TwentyFiveGigE.Datalink.Flow.Monitor))])
                        self._leafs = OrderedDict()

                        self.monitor = None
                        self._children_name_map["monitor"] = "monitor"
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Datalink.Flow, [], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: user_defined_flow
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: input_output
                        
                        	Apply Flow Monitor on input/output traffic
                        	**type**\:  :py:class:`InputOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Datalink.Flow.Monitor.InputOutput>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Datalink.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('user_defined_flow', (YLeaf(YType.str, 'User-defined-flow'), ['str'])),
                                ('input_output', (YLeaf(YType.enumeration, 'input-output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Datalink.Flow.Monitor.InputOutput')])),
                            ])
                            self.user_defined_flow = None
                            self.input_output = None
                            self._segment_path = lambda: "monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Datalink.Flow.Monitor, [u'user_defined_flow', u'input_output'], name, value)

                        class InputOutput(Enum):
                            """
                            InputOutput (Enum Class)

                            Apply Flow Monitor on input/output traffic

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



            class Energywise(Entity):
                """
                EnergyWise interface configurations
                
                .. attribute:: activitycheck
                
                	Apply an activity check before turning off power    to this PoE port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: level
                
                	Set the EnergyWise level of this interface  or attached entity
                	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Energywise.Level>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Energywise, self).__init__()

                    self.yang_name = "energywise"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Interface.TwentyFiveGigE.Energywise.Level))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('activitycheck', (YLeaf(YType.empty, 'activitycheck'), ['Empty'])),
                    ])
                    self.activitycheck = None

                    self.level = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:energywise"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Energywise, [u'activitycheck'], name, value)


                class Level(Entity):
                    """
                    Set the EnergyWise level of this interface 
                    or attached entity
                    
                    .. attribute:: range  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..10
                    
                    .. attribute:: recurrence
                    
                    	Specify that this level setting should  recur at the specified time
                    	**type**\:  :py:class:`Recurrence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Energywise.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "energywise"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("recurrence", ("recurrence", Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                        ])
                        self.range = None

                        self.recurrence = Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence()
                        self.recurrence.parent = self
                        self._children_name_map["recurrence"] = "recurrence"
                        self._segment_path = lambda: "level" + "[range='" + str(self.range) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Energywise.Level, [u'range'], name, value)


                    class Recurrence(Entity):
                        """
                        Specify that this level setting should 
                        recur at the specified time
                        
                        .. attribute:: importance
                        
                        	Specify the importance at which the event  should be sent when it recurs
                        	**type**\: list of  		 :py:class:`Importance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence.Importance>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence, self).__init__()

                            self.yang_name = "recurrence"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("importance", ("importance", Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence.Importance))])
                            self._leafs = OrderedDict()

                            self.importance = YList(self)
                            self._segment_path = lambda: "recurrence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence, [], name, value)


                        class Importance(Entity):
                            """
                            Specify the importance at which the event 
                            should be sent when it recurs
                            
                            .. attribute:: range  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: at
                            
                            	Specify the time(s) this level setting should occur
                            	**type**\:  :py:class:`At <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence.Importance.At>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence.Importance, self).__init__()

                                self.yang_name = "importance"
                                self.yang_parent_name = "recurrence"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("at", ("at", Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence.Importance.At))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.at = Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence.Importance.At()
                                self.at.parent = self
                                self._children_name_map["at"] = "at"
                                self._segment_path = lambda: "importance" + "[range='" + str(self.range) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence.Importance, [u'range'], name, value)


                            class At(Entity):
                                """
                                Specify the time(s) this level setting should occur
                                
                                .. attribute:: minute
                                
                                	cron format of minute(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..59
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: hour
                                
                                	cron format of hour(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..23
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: day
                                
                                	cron format of day(s) of month
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..31
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: month
                                
                                	cron format of month(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..12
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: weekday
                                
                                	cron format of weekday(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..7
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence.Importance.At, self).__init__()

                                    self.yang_name = "at"
                                    self.yang_parent_name = "importance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minute', (YLeaf(YType.str, 'minute'), ['int','str'])),
                                        ('hour', (YLeaf(YType.str, 'hour'), ['int','str'])),
                                        ('day', (YLeaf(YType.str, 'day'), ['int','str'])),
                                        ('month', (YLeaf(YType.str, 'month'), ['int','str'])),
                                        ('weekday', (YLeaf(YType.str, 'weekday'), ['int','str'])),
                                    ])
                                    self.minute = None
                                    self.hour = None
                                    self.day = None
                                    self.month = None
                                    self.weekday = None
                                    self._segment_path = lambda: "at"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Energywise.Level.Recurrence.Importance.At, [u'minute', u'hour', u'day', u'month', u'weekday'], name, value)


            class Location(Entity):
                """
                Interface location information
                
                .. attribute:: civic_location_id
                
                	Civic location information
                	**type**\:  :py:class:`CivicLocationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Location.CivicLocationId>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Location, self).__init__()

                    self.yang_name = "location"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("civic-location-id", ("civic_location_id", Native.Interface.TwentyFiveGigE.Location.CivicLocationId))])
                    self._leafs = OrderedDict()

                    self.civic_location_id = Native.Interface.TwentyFiveGigE.Location.CivicLocationId()
                    self.civic_location_id.parent = self
                    self._children_name_map["civic_location_id"] = "civic-location-id"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:location"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Location, [], name, value)


                class CivicLocationId(Entity):
                    """
                    Civic location information
                    
                    .. attribute:: location_identifier
                    
                    	civic location identifier string
                    	**type**\: str
                    
                    .. attribute:: host
                    
                    	Globally defined host location identifer
                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Location.CivicLocationId.Host>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: none
                    
                    	No globally defined location identifer
                    	**type**\:  :py:class:`Y_None <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Location.CivicLocationId.Y_None>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Location.CivicLocationId, self).__init__()

                        self.yang_name = "civic-location-id"
                        self.yang_parent_name = "location"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("host", ("host", Native.Interface.TwentyFiveGigE.Location.CivicLocationId.Host)), ("none", ("none", Native.Interface.TwentyFiveGigE.Location.CivicLocationId.Y_None))])
                        self._leafs = OrderedDict([
                            ('location_identifier', (YLeaf(YType.str, 'location-identifier'), ['str'])),
                        ])
                        self.location_identifier = None

                        self.host = None
                        self._children_name_map["host"] = "host"

                        self.none = None
                        self._children_name_map["none"] = "none"
                        self._segment_path = lambda: "civic-location-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Location.CivicLocationId, [u'location_identifier'], name, value)


                    class Host(Entity):
                        """
                        Globally defined host location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Location.CivicLocationId.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "host"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Location.CivicLocationId.Host, [u'port_location'], name, value)


                    class Y_None(Entity):
                        """
                        No globally defined location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Location.CivicLocationId.Y_None, self).__init__()

                            self.yang_name = "none"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Location.CivicLocationId.Y_None, [u'port_location'], name, value)


            class Mac(Entity):
                """
                MAC interface commands
                
                .. attribute:: access_group
                
                	MAC access\-group configuration commands
                	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mac.AccessGroup>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Mac, self).__init__()

                    self.yang_name = "mac"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.TwentyFiveGigE.Mac.AccessGroup))])
                    self._leafs = OrderedDict()

                    self.access_group = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:mac"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Mac, [], name, value)


                class AccessGroup(Entity):
                    """
                    MAC access\-group configuration commands
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mac.AccessGroup.Direction>`
                    
                    .. attribute:: acl_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Mac.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "mac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Mac.AccessGroup.Direction')])),
                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                        ])
                        self.direction = None
                        self.acl_name = None
                        self._segment_path = lambda: "access-group" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Mac.AccessGroup, [u'direction', u'acl_name'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Macro(Entity):
                """
                Command macro
                
                .. attribute:: description
                
                	Macro description for this interface
                	**type**\: str
                
                .. attribute:: auto
                
                	Smartport interface macro configurations
                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Macro.Auto>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Macro, self).__init__()

                    self.yang_name = "macro"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.TwentyFiveGigE.Macro.Auto))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.auto = Native.Interface.TwentyFiveGigE.Macro.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "auto"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macro"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Macro, [u'description'], name, value)


                class Auto(Entity):
                    """
                    Smartport interface macro configurations
                    
                    .. attribute:: processing
                    
                    	Enable smartport macro auto execution on this interface
                    	**type**\: bool
                    
                    .. attribute:: port
                    
                    	Provide interface specific configuration for macro processing
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Macro.Auto.Port>`
                    
                    .. attribute:: control
                    
                    	Control macro auto execution
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Macro.Auto.Control>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Macro.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "macro"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port", ("port", Native.Interface.TwentyFiveGigE.Macro.Auto.Port)), ("control", ("control", Native.Interface.TwentyFiveGigE.Macro.Auto.Control))])
                        self._leafs = OrderedDict([
                            ('processing', (YLeaf(YType.boolean, 'processing'), ['bool'])),
                        ])
                        self.processing = None

                        self.port = Native.Interface.TwentyFiveGigE.Macro.Auto.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.control = Native.Interface.TwentyFiveGigE.Macro.Auto.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"
                        self._segment_path = lambda: "auto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Macro.Auto, [u'processing'], name, value)


                    class Port(Entity):
                        """
                        Provide interface specific configuration for macro processing
                        
                        .. attribute:: sticky
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Macro.Auto.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                            ])
                            self.sticky = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Macro.Auto.Port, [u'sticky'], name, value)


                    class Control(Entity):
                        """
                        Control macro auto execution
                        
                        .. attribute:: device
                        
                        	Enable macro auto execution for devices
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Macro.Auto.Control.Device>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Macro.Auto.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("device", ("device", Native.Interface.TwentyFiveGigE.Macro.Auto.Control.Device))])
                            self._leafs = OrderedDict()

                            self.device = Native.Interface.TwentyFiveGigE.Macro.Auto.Control.Device()
                            self.device.parent = self
                            self._children_name_map["device"] = "device"
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Macro.Auto.Control, [], name, value)


                        class Device(Entity):
                            """
                            Enable macro auto execution for devices
                            
                            .. attribute:: phone
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Macro.Auto.Control.Device, self).__init__()

                                self.yang_name = "device"
                                self.yang_parent_name = "control"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('phone', (YLeaf(YType.empty, 'phone'), ['Empty'])),
                                ])
                                self.phone = None
                                self._segment_path = lambda: "device"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Macro.Auto.Control.Device, [u'phone'], name, value)


            class DualActive(Entity):
                """
                
                
                .. attribute:: fast_hello
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.DualActive, self).__init__()

                    self.yang_name = "dual-active"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fast_hello', (YLeaf(YType.empty, 'fast-hello'), ['Empty'])),
                    ])
                    self.fast_hello = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:dual-active"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.DualActive, [u'fast_hello'], name, value)


            class LoadBalancing(Entity):
                """
                Etherchannel Load\-Balancing
                
                .. attribute:: flow
                
                	Based on the traffic flows identified by the packet headers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Based on the VLAN to member links manual configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.LoadBalancing, self).__init__()

                    self.yang_name = "load-balancing"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('flow', (YLeaf(YType.empty, 'flow'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.flow = None
                    self.vlan = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:load-balancing"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.LoadBalancing, [u'flow', u'vlan'], name, value)


            class VlanRange(Entity):
                """
                
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4096
                
                		**type**\: str
                
                .. attribute:: service_policy
                
                	Configure QoS Service Policy
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.VlanRange.ServicePolicy>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.VlanRange, self).__init__()

                    self.yang_name = "vlan-range"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.TwentyFiveGigE.VlanRange.ServicePolicy))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                    ])
                    self.id = None

                    self.service_policy = Native.Interface.TwentyFiveGigE.VlanRange.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:vlan-range" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.VlanRange, [u'id'], name, value)


                class ServicePolicy(Entity):
                    """
                    Configure QoS Service Policy
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.VlanRange.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "vlan-range"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.VlanRange.ServicePolicy, [u'input', u'output'], name, value)


            class Switch(Entity):
                """
                
                
                .. attribute:: virtual
                
                	
                	**type**\:  :py:class:`Virtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Switch.Virtual>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("virtual", ("virtual", Native.Interface.TwentyFiveGigE.Switch.Virtual))])
                    self._leafs = OrderedDict()

                    self.virtual = Native.Interface.TwentyFiveGigE.Switch.Virtual()
                    self.virtual.parent = self
                    self._children_name_map["virtual"] = "virtual"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:switch"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Switch, [], name, value)


                class Virtual(Entity):
                    """
                    
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Switch.Virtual, self).__init__()

                        self.yang_name = "virtual"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ])
                        self.link = None
                        self._segment_path = lambda: "virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Switch.Virtual, [u'link'], name, value)


            class SrrQueue(Entity):
                """
                
                
                .. attribute:: bandwidth
                
                	
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.SrrQueue, self).__init__()

                    self.yang_name = "srr-queue"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth))])
                    self._leafs = OrderedDict()

                    self.bandwidth = Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:srr-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.SrrQueue, [], name, value)


                class Bandwidth(Entity):
                    """
                    
                    
                    .. attribute:: shape
                    
                    	
                    	**type**\:  :py:class:`Shape <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth.Shape>`
                    
                    .. attribute:: share
                    
                    	
                    	**type**\:  :py:class:`Share <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth.Share>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "srr-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("shape", ("shape", Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth.Shape)), ("share", ("share", Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth.Share))])
                        self._leafs = OrderedDict()

                        self.shape = Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"

                        self.share = Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth.Share()
                        self.share.parent = self
                        self._children_name_map["share"] = "share"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth, [], name, value)


                    class Shape(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint16, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint16, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint16, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint16, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "shape"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth.Shape, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


                    class Share(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth.Share, self).__init__()

                            self.yang_name = "share"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint8, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint8, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint8, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint8, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "share"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.SrrQueue.Bandwidth.Share, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


            class CiscoIOSXESwitchMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection>`
                    
                    .. attribute:: network_link
                    
                    	Enable macsec on switch connected interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('network_link', (YLeaf(YType.empty, 'network-link'), ['Empty'])),
                        ])
                        self.network_link = None

                        self.replay_protection = Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption.Macsec, [u'network_link'], name, value)


                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, [u'window_size'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.TwentyFiveGigE.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.TwentyFiveGigE.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.TwentyFiveGigE.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.TwentyFiveGigE.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.TwentyFiveGigE.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.TwentyFiveGigE.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.TwentyFiveGigE.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.TwentyFiveGigE.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class Mka(Entity):
                """
                MACsec Key Agreement (MKA) interface configuration
                
                .. attribute:: policy
                
                	Apply MKA Policy
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mka.Policy>`
                
                .. attribute:: pre_shared_key
                
                	Configure MKA Pre\-Shared\-Key
                	**type**\:  :py:class:`PreSharedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mka.PreSharedKey>`
                
                

                """

                _prefix = 'ios-mka'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Mka, self).__init__()

                    self.yang_name = "mka"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.TwentyFiveGigE.Mka.Policy)), ("pre-shared-key", ("pre_shared_key", Native.Interface.TwentyFiveGigE.Mka.PreSharedKey))])
                    self._leafs = OrderedDict()

                    self.policy = Native.Interface.TwentyFiveGigE.Mka.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.pre_shared_key = Native.Interface.TwentyFiveGigE.Mka.PreSharedKey()
                    self.pre_shared_key.parent = self
                    self._children_name_map["pre_shared_key"] = "pre-shared-key"
                    self._segment_path = lambda: "Cisco-IOS-XE-mka:mka"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Mka, [], name, value)


                class Policy(Entity):
                    """
                    Apply MKA Policy
                    
                    .. attribute:: name
                    
                    	MKA Policy NAME
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Mka.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Mka.Policy, ['name'], name, value)


                class PreSharedKey(Entity):
                    """
                    Configure MKA Pre\-Shared\-Key
                    
                    .. attribute:: key_chain
                    
                    	Configure the key\-chain name
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mka.PreSharedKey.KeyChain>`
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Mka.PreSharedKey, self).__init__()

                        self.yang_name = "pre-shared-key"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.TwentyFiveGigE.Mka.PreSharedKey.KeyChain))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.TwentyFiveGigE.Mka.PreSharedKey.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"
                        self._segment_path = lambda: "pre-shared-key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Mka.PreSharedKey, [], name, value)


                    class KeyChain(Entity):
                        """
                        Configure the key\-chain name
                        
                        .. attribute:: name
                        
                        	Name of key\-chain to be used to get keys
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mka'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Mka.PreSharedKey.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "pre-shared-key"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Mka.PreSharedKey.KeyChain, ['name'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Utd, ['enable'], name, value)


            class Xconnect(Entity):
                """
                Xconnect commands
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: vcid
                
                	
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: encapsulation
                
                	Data encapsulation method
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Xconnect.Encapsulation>`
                
                .. attribute:: manual
                
                	Manually configure L2TP session parameters
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sequence
                
                	Configure sequencing options for xconnect
                	**type**\:  :py:class:`Sequence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Xconnect.Sequence>`
                
                .. attribute:: pw_class
                
                	Pseudowire\-class to use for encapsulation and protocol configuration
                	**type**\: str
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Xconnect.Encapsulation')])),
                        ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                        ('sequence', (YLeaf(YType.enumeration, 'sequence'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Xconnect.Sequence')])),
                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                    ])
                    self.address = None
                    self.vcid = None
                    self.encapsulation = None
                    self.manual = None
                    self.sequence = None
                    self.pw_class = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'sequence', 'pw_class'], name, value)

                class Encapsulation(Enum):
                    """
                    Encapsulation (Enum Class)

                    Data encapsulation method

                    .. data:: mpls = 0

                    .. data:: l2tpv3 = 1

                    """

                    mpls = Enum.YLeaf(0, "mpls")

                    l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                class Sequence(Enum):
                    """
                    Sequence (Enum Class)

                    Configure sequencing options for xconnect

                    .. data:: both = 0

                    .. data:: receive = 1

                    .. data:: transmit = 2

                    """

                    both = Enum.YLeaf(0, "both")

                    receive = Enum.YLeaf(1, "receive")

                    transmit = Enum.YLeaf(2, "transmit")



            class Evpn(Entity):
                """
                
                
                .. attribute:: ethernet_segment
                
                	Ethernet segment local discriminator value
                	**type**\: list of  		 :py:class:`EthernetSegment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Evpn, self).__init__()

                    self.yang_name = "evpn"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet-segment", ("ethernet_segment", Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment))])
                    self._leafs = OrderedDict()

                    self.ethernet_segment = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:evpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Evpn, [], name, value)


                class EthernetSegment(Entity):
                    """
                    Ethernet segment local discriminator value
                    
                    .. attribute:: es_value  (key)
                    
                    	Ethernet segment local discriminator value
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: df_election
                    
                    	Designated forwarder election parameters
                    	**type**\:  :py:class:`DfElection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment.DfElection>`
                    
                    .. attribute:: redundancy
                    
                    	Multi\-homing redundancy parameters
                    	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment.Redundancy>`
                    
                    .. attribute:: sytem_mac
                    
                    	System MAC address for generating the Ethernet Segment ID
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment, self).__init__()

                        self.yang_name = "ethernet-segment"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['es_value']
                        self._child_classes = OrderedDict([("df-election", ("df_election", Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment.DfElection)), ("redundancy", ("redundancy", Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment.Redundancy))])
                        self._leafs = OrderedDict([
                            ('es_value', (YLeaf(YType.uint16, 'es-value'), ['int'])),
                            ('sytem_mac', (YLeaf(YType.str, 'sytem-mac'), ['str'])),
                        ])
                        self.es_value = None
                        self.sytem_mac = None

                        self.df_election = Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment.DfElection()
                        self.df_election.parent = self
                        self._children_name_map["df_election"] = "df-election"

                        self.redundancy = Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                        self._segment_path = lambda: "ethernet-segment" + "[es-value='" + str(self.es_value) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment, ['es_value', 'sytem_mac'], name, value)


                    class DfElection(Entity):
                        """
                        Designated forwarder election parameters
                        
                        .. attribute:: wait_time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment.DfElection, self).__init__()

                            self.yang_name = "df-election"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wait_time', (YLeaf(YType.uint8, 'wait-time'), ['int'])),
                            ])
                            self.wait_time = None
                            self._segment_path = lambda: "df-election"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment.DfElection, ['wait_time'], name, value)


                    class Redundancy(Entity):
                        """
                        Multi\-homing redundancy parameters
                        
                        .. attribute:: all_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: single_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment.Redundancy, self).__init__()

                            self.yang_name = "redundancy"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all_active', (YLeaf(YType.empty, 'all-active'), ['Empty'])),
                                ('single_active', (YLeaf(YType.empty, 'single-active'), ['Empty'])),
                            ])
                            self.all_active = None
                            self.single_active = None
                            self._segment_path = lambda: "redundancy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Evpn.EthernetSegment.Redundancy, ['all_active', 'single_active'], name, value)


            class FabricDomain(Entity):
                """
                Fabric\-domain interface command
                
                .. attribute:: iwan_fabric
                
                	
                	**type**\:  :py:class:`IwanFabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.FabricDomain.IwanFabric>`
                
                

                """

                _prefix = 'ios-iwanfabric'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.FabricDomain, self).__init__()

                    self.yang_name = "fabric-domain"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("iwan-fabric", ("iwan_fabric", Native.Interface.TwentyFiveGigE.FabricDomain.IwanFabric))])
                    self._leafs = OrderedDict()

                    self.iwan_fabric = Native.Interface.TwentyFiveGigE.FabricDomain.IwanFabric()
                    self.iwan_fabric.parent = self
                    self._children_name_map["iwan_fabric"] = "iwan-fabric"
                    self._segment_path = lambda: "Cisco-IOS-XE-iwanfabric:fabric-domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.FabricDomain, [], name, value)


                class IwanFabric(Entity):
                    """
                    
                    
                    .. attribute:: word
                    
                    	
                    	**type**\: list of  		 :py:class:`Word <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.FabricDomain.IwanFabric.Word>`
                    
                    

                    """

                    _prefix = 'ios-iwanfabric'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.FabricDomain.IwanFabric, self).__init__()

                        self.yang_name = "iwan-fabric"
                        self.yang_parent_name = "fabric-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("word", ("word", Native.Interface.TwentyFiveGigE.FabricDomain.IwanFabric.Word))])
                        self._leafs = OrderedDict()

                        self.word = YList(self)
                        self._segment_path = lambda: "iwan-fabric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.FabricDomain.IwanFabric, [], name, value)


                    class Word(Entity):
                        """
                        
                        
                        .. attribute:: word  (key)
                        
                        	Path name
                        	**type**\: str
                        
                        .. attribute:: interface_id
                        
                        	Specify the interface\-id value
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-iwanfabric'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.FabricDomain.IwanFabric.Word, self).__init__()

                            self.yang_name = "word"
                            self.yang_parent_name = "iwan-fabric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                            ])
                            self.word = None
                            self.interface_id = None
                            self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.FabricDomain.IwanFabric.Word, ['word', 'interface_id'], name, value)


            class Mvrp(Entity):
                """
                
                
                .. attribute:: mvrp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: registration
                
                	
                	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mvrp.Registration>`
                
                .. attribute:: timer
                
                	
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mvrp.Timer>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mvrp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Mvrp, self).__init__()

                    self.yang_name = "mvrp"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("registration", ("registration", Native.Interface.TwentyFiveGigE.Mvrp.Registration)), ("timer", ("timer", Native.Interface.TwentyFiveGigE.Mvrp.Timer))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mvrp', (YLeaf(YType.empty, 'mvrp'), ['Empty'])),
                    ])
                    self.mvrp = None

                    self.registration = Native.Interface.TwentyFiveGigE.Mvrp.Registration()
                    self.registration.parent = self
                    self._children_name_map["registration"] = "registration"

                    self.timer = Native.Interface.TwentyFiveGigE.Mvrp.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-mvrp:mvrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Mvrp, ['mvrp'], name, value)


                class Registration(Entity):
                    """
                    
                    
                    .. attribute:: fixed
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: forbidden
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: normal
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Mvrp.Registration, self).__init__()

                        self.yang_name = "registration"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fixed', (YLeaf(YType.empty, 'fixed'), ['Empty'])),
                            ('forbidden', (YLeaf(YType.empty, 'forbidden'), ['Empty'])),
                            ('normal', (YLeaf(YType.empty, 'normal'), ['Empty'])),
                        ])
                        self.fixed = None
                        self.forbidden = None
                        self.normal = None
                        self._segment_path = lambda: "registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Mvrp.Registration, ['fixed', 'forbidden', 'normal'], name, value)


                class Timer(Entity):
                    """
                    
                    
                    .. attribute:: join
                    
                    	
                    	**type**\:  :py:class:`Join <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mvrp.Timer.Join>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave
                    
                    	
                    	**type**\:  :py:class:`Leave <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mvrp.Timer.Leave>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave_all
                    
                    	
                    	**type**\:  :py:class:`LeaveAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Mvrp.Timer.LeaveAll>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: periodic
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Mvrp.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("join", ("join", Native.Interface.TwentyFiveGigE.Mvrp.Timer.Join)), ("leave", ("leave", Native.Interface.TwentyFiveGigE.Mvrp.Timer.Leave)), ("leave-all", ("leave_all", Native.Interface.TwentyFiveGigE.Mvrp.Timer.LeaveAll))])
                        self._leafs = OrderedDict([
                            ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ])
                        self.periodic = None

                        self.join = None
                        self._children_name_map["join"] = "join"

                        self.leave = None
                        self._children_name_map["leave"] = "leave"

                        self.leave_all = None
                        self._children_name_map["leave_all"] = "leave-all"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Mvrp.Timer, ['periodic'], name, value)


                    class Join(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 20..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Mvrp.Timer.Join, self).__init__()

                            self.yang_name = "join"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "join"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Mvrp.Timer.Join, ['y_range'], name, value)


                    class Leave(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Mvrp.Timer.Leave, self).__init__()

                            self.yang_name = "leave"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Mvrp.Timer.Leave, ['y_range'], name, value)


                    class LeaveAll(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1000..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Mvrp.Timer.LeaveAll, self).__init__()

                            self.yang_name = "leave-all"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave-all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Mvrp.Timer.LeaveAll, ['y_range'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.TwentyFiveGigE.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.TwentyFiveGigE.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.TwentyFiveGigE.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.TwentyFiveGigE.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.TwentyFiveGigE.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.TwentyFiveGigE.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.TwentyFiveGigE.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.TwentyFiveGigE.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Power(Entity):
                """
                
                
                .. attribute:: inline
                
                	
                	**type**\:  :py:class:`Inline <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Power.Inline>`
                
                

                """

                _prefix = 'ios-power'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Power, self).__init__()

                    self.yang_name = "power"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("inline", ("inline", Native.Interface.TwentyFiveGigE.Power.Inline))])
                    self._leafs = OrderedDict()

                    self.inline = Native.Interface.TwentyFiveGigE.Power.Inline()
                    self.inline.parent = self
                    self._children_name_map["inline"] = "inline"
                    self._segment_path = lambda: "Cisco-IOS-XE-power:power"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Power, [], name, value)


                class Inline(Entity):
                    """
                    
                    
                    .. attribute:: consumption
                    
                    	
                    	**type**\: int
                    
                    	**range:** 4000..15400
                    
                    .. attribute:: never
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: auto
                    
                    	Automatically detect and power inline devices
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Power.Inline.Auto>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: four_pair
                    
                    	Four\-pair PoE power
                    	**type**\:  :py:class:`FourPair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Power.Inline.FourPair>`
                    
                    .. attribute:: police
                    
                    	Police the power drawn on the port
                    	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Power.Inline.Police>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: port
                    
                    	Configure Port Power Level
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Power.Inline.Port>`
                    
                    .. attribute:: static
                    
                    	High priority inline power interface
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Power.Inline.Static>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-power'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Power.Inline, self).__init__()

                        self.yang_name = "inline"
                        self.yang_parent_name = "power"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.TwentyFiveGigE.Power.Inline.Auto)), ("four-pair", ("four_pair", Native.Interface.TwentyFiveGigE.Power.Inline.FourPair)), ("police", ("police", Native.Interface.TwentyFiveGigE.Power.Inline.Police)), ("port", ("port", Native.Interface.TwentyFiveGigE.Power.Inline.Port)), ("static", ("static", Native.Interface.TwentyFiveGigE.Power.Inline.Static))])
                        self._leafs = OrderedDict([
                            ('consumption', (YLeaf(YType.uint16, 'consumption'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.consumption = None
                        self.never = None

                        self.auto = None
                        self._children_name_map["auto"] = "auto"

                        self.four_pair = Native.Interface.TwentyFiveGigE.Power.Inline.FourPair()
                        self.four_pair.parent = self
                        self._children_name_map["four_pair"] = "four-pair"

                        self.police = None
                        self._children_name_map["police"] = "police"

                        self.port = Native.Interface.TwentyFiveGigE.Power.Inline.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.static = None
                        self._children_name_map["static"] = "static"
                        self._segment_path = lambda: "inline"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Power.Inline, ['consumption', 'never'], name, value)


                    class Auto(Entity):
                        """
                        Automatically detect and power inline devices
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Power.Inline.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "auto"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Power.Inline.Auto, ['max'], name, value)


                    class FourPair(Entity):
                        """
                        Four\-pair PoE power
                        
                        .. attribute:: forced
                        
                        	Enable Four\-pair PoE without L2 negotiation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Power.Inline.FourPair, self).__init__()

                            self.yang_name = "four-pair"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forced', (YLeaf(YType.empty, 'forced'), ['Empty'])),
                            ])
                            self.forced = None
                            self._segment_path = lambda: "four-pair"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Power.Inline.FourPair, ['forced'], name, value)


                    class Police(Entity):
                        """
                        Police the power drawn on the port
                        
                        .. attribute:: action
                        
                        	Action to be taken when power is overdrawn on the port
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Power.Inline.Police.Action>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Power.Inline.Police, self).__init__()

                            self.yang_name = "police"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwentyFiveGigE.Power.Inline.Police.Action))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.TwentyFiveGigE.Power.Inline.Police.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "police"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Power.Inline.Police, [], name, value)


                        class Action(Entity):
                            """
                            Action to be taken when power is overdrawn on the port
                            
                            .. attribute:: errdisable
                            
                            	Error\-disable the port when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log a message when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-power'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Power.Inline.Police.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "police"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('errdisable', (YLeaf(YType.empty, 'errdisable'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ])
                                self.errdisable = None
                                self.log = None
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Power.Inline.Police.Action, ['errdisable', 'log'], name, value)


                    class Port(Entity):
                        """
                        Configure Port Power Level
                        
                        .. attribute:: poe_ha
                        
                        	Apply poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: perpetual_poe_ha
                        
                        	Apply perpetual\-poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: two_event
                        
                        	Enable 2\-event classification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Power.Inline.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('poe_ha', (YLeaf(YType.empty, 'poe-ha'), ['Empty'])),
                                ('perpetual_poe_ha', (YLeaf(YType.empty, 'perpetual-poe-ha'), ['Empty'])),
                                ('two_event', (YLeaf(YType.empty, 'two-event'), ['Empty'])),
                            ])
                            self.poe_ha = None
                            self.perpetual_poe_ha = None
                            self.two_event = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Power.Inline.Port, ['poe_ha', 'perpetual_poe_ha', 'two_event'], name, value)


                    class Static(Entity):
                        """
                        High priority inline power interface
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Power.Inline.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "static"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Power.Inline.Static, ['max'], name, value)


            class Cdp(Entity):
                """
                CDP interface subcommands
                
                .. attribute:: enable
                
                	Enable CDP on interface
                	**type**\: bool
                
                .. attribute:: tlv
                
                	Enable exchange of specific tlv information
                	**type**\:  :py:class:`Tlv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cdp.Tlv>`
                
                

                """

                _prefix = 'ios-cdp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Cdp, self).__init__()

                    self.yang_name = "cdp"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tlv", ("tlv", Native.Interface.TwentyFiveGigE.Cdp.Tlv))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                    ])
                    self.enable = None

                    self.tlv = Native.Interface.TwentyFiveGigE.Cdp.Tlv()
                    self.tlv.parent = self
                    self._children_name_map["tlv"] = "tlv"
                    self._segment_path = lambda: "Cisco-IOS-XE-cdp:cdp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Cdp, ['enable'], name, value)


                class Tlv(Entity):
                    """
                    Enable exchange of specific tlv information
                    
                    .. attribute:: app
                    
                    	Enable/Configure Application TLV
                    	**type**\:  :py:class:`App <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cdp.Tlv.App>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: server_location
                    
                    	Enable CDP location server on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	Exchange location information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cdp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Cdp.Tlv, self).__init__()

                        self.yang_name = "tlv"
                        self.yang_parent_name = "cdp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("app", ("app", Native.Interface.TwentyFiveGigE.Cdp.Tlv.App))])
                        self._leafs = OrderedDict([
                            ('server_location', (YLeaf(YType.empty, 'server-location'), ['Empty'])),
                            ('location', (YLeaf(YType.empty, 'location'), ['Empty'])),
                        ])
                        self.server_location = None
                        self.location = None

                        self.app = None
                        self._children_name_map["app"] = "app"
                        self._segment_path = lambda: "tlv"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Cdp.Tlv, ['server_location', 'location'], name, value)


                    class App(Entity):
                        """
                        Enable/Configure Application TLV
                        
                        .. attribute:: tlvtype
                        
                        	Configure APP TLV
                        	**type**\: int
                        
                        	**range:** 1001..65535
                        
                        .. attribute:: value
                        
                        	Configure App TLV Value information
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cdp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Cdp.Tlv.App, self).__init__()

                            self.yang_name = "app"
                            self.yang_parent_name = "tlv"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tlvtype', (YLeaf(YType.uint16, 'tlvtype'), ['int'])),
                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                            ])
                            self.tlvtype = None
                            self.value = None
                            self._segment_path = lambda: "app"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Cdp.Tlv.App, ['tlvtype', 'value'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.TwentyFiveGigE.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.TwentyFiveGigE.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.TwentyFiveGigE.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.TwentyFiveGigE.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class Authentication(Entity):
                """
                Auth Manager Interface Configuration Commands
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.ControlDirection>`
                
                .. attribute:: event
                
                	Set action for authentication events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event>`
                
                .. attribute:: fallback
                
                	Enable the Webauth fallback mechanism
                	**type**\: str
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.HostMode>`
                
                .. attribute:: open
                
                	Enable or Disable open access on this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: order
                
                	Add an authentication method to the order list
                	**type**\:  :py:class:`Order <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Order>`
                
                .. attribute:: priority
                
                	Add an authentication method to the priority list
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Priority>`
                
                .. attribute:: port_control
                
                	set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.PortControl>`
                
                .. attribute:: periodic
                
                	Enable or Disable Reauthentication for this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timer
                
                	Set authentication timer values
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Timer>`
                
                .. attribute:: violation
                
                	Configure action to take on security violations
                	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Violation>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.TwentyFiveGigE.Authentication.Event)), ("order", ("order", Native.Interface.TwentyFiveGigE.Authentication.Order)), ("priority", ("priority", Native.Interface.TwentyFiveGigE.Authentication.Priority)), ("timer", ("timer", Native.Interface.TwentyFiveGigE.Authentication.Timer))])
                    self._leafs = OrderedDict([
                        ('control_direction', (YLeaf(YType.enumeration, 'control-direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Authentication.ControlDirection')])),
                        ('fallback', (YLeaf(YType.str, 'fallback'), ['str'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Authentication.HostMode')])),
                        ('open', (YLeaf(YType.empty, 'open'), ['Empty'])),
                        ('port_control', (YLeaf(YType.enumeration, 'port-control'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Authentication.PortControl')])),
                        ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Authentication.Violation')])),
                    ])
                    self.control_direction = None
                    self.fallback = None
                    self.host_mode = None
                    self.open = None
                    self.port_control = None
                    self.periodic = None
                    self.violation = None

                    self.event = Native.Interface.TwentyFiveGigE.Authentication.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.order = Native.Interface.TwentyFiveGigE.Authentication.Order()
                    self.order.parent = self
                    self._children_name_map["order"] = "order"

                    self.priority = Native.Interface.TwentyFiveGigE.Authentication.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "priority"

                    self.timer = Native.Interface.TwentyFiveGigE.Authentication.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:authentication"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication, ['control_direction', 'fallback', 'host_mode', 'open', 'port_control', 'periodic', 'violation'], name, value)

                class ControlDirection(Enum):
                    """
                    ControlDirection (Enum Class)

                    Set the control\-direction on the interface

                    .. data:: both = 0

                    .. data:: in_ = 1

                    """

                    both = Enum.YLeaf(0, "both")

                    in_ = Enum.YLeaf(1, "in")


                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")


                class PortControl(Enum):
                    """
                    PortControl (Enum Class)

                    set the port\-control value

                    .. data:: auto = 0

                    .. data:: force_authorized = 1

                    .. data:: force_unauthorized = 2

                    """

                    auto = Enum.YLeaf(0, "auto")

                    force_authorized = Enum.YLeaf(1, "force-authorized")

                    force_unauthorized = Enum.YLeaf(2, "force-unauthorized")


                class Violation(Enum):
                    """
                    Violation (Enum Class)

                    Configure action to take on security violations

                    .. data:: protect = 0

                    .. data:: replace = 1

                    .. data:: restrict = 2

                    .. data:: shutdown = 3

                    """

                    protect = Enum.YLeaf(0, "protect")

                    replace = Enum.YLeaf(1, "replace")

                    restrict = Enum.YLeaf(2, "restrict")

                    shutdown = Enum.YLeaf(3, "shutdown")



                class Event(Entity):
                    """
                    Set action for authentication events
                    
                    .. attribute:: server
                    
                    	Configure actions for AAA server events
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.Server>`
                    
                    .. attribute:: fail
                    
                    	Configure actions for AAA fail events
                    	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.Fail>`
                    
                    .. attribute:: no_response
                    
                    	Configure actions for AAA no\-response events
                    	**type**\:  :py:class:`NoResponse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Authentication.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("server", ("server", Native.Interface.TwentyFiveGigE.Authentication.Event.Server)), ("fail", ("fail", Native.Interface.TwentyFiveGigE.Authentication.Event.Fail)), ("no-response", ("no_response", Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse))])
                        self._leafs = OrderedDict()

                        self.server = Native.Interface.TwentyFiveGigE.Authentication.Event.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.fail = Native.Interface.TwentyFiveGigE.Authentication.Event.Fail()
                        self.fail.parent = self
                        self._children_name_map["fail"] = "fail"

                        self.no_response = Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse()
                        self.no_response.parent = self
                        self._children_name_map["no_response"] = "no-response"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event, [], name, value)


                    class Server(Entity):
                        """
                        Configure actions for AAA server events
                        
                        .. attribute:: alive
                        
                        	Configure AAA server alive action
                        	**type**\:  :py:class:`Alive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Alive>`
                        
                        .. attribute:: dead
                        
                        	Configure AAA server dead action
                        	**type**\:  :py:class:`Dead <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Authentication.Event.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("alive", ("alive", Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Alive)), ("dead", ("dead", Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead))])
                            self._leafs = OrderedDict()

                            self.alive = Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Alive()
                            self.alive.parent = self
                            self._children_name_map["alive"] = "alive"

                            self.dead = Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead()
                            self.dead.parent = self
                            self._children_name_map["dead"] = "dead"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.Server, [], name, value)


                        class Alive(Entity):
                            """
                            Configure AAA server alive action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Alive.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Alive, self).__init__()

                                self.yang_name = "alive"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Alive.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Alive.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "alive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Alive, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all authorized clients
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Alive.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "alive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reinitialize', (YLeaf(YType.empty, 'reinitialize'), ['Empty'])),
                                    ])
                                    self.reinitialize = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Alive.Action, ['reinitialize'], name, value)


                        class Dead(Entity):
                            """
                            Configure AAA server dead action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead, self).__init__()

                                self.yang_name = "dead"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dead"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: authorize
                                
                                	Authorize the port
                                	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action.Authorize>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all client on the port
                                	**type**\:  :py:class:`Reinitialize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action.Reinitialize>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dead"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action.Authorize)), ("reinitialize", ("reinitialize", Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action.Reinitialize))])
                                    self._leafs = OrderedDict()

                                    self.authorize = None
                                    self._children_name_map["authorize"] = "authorize"

                                    self.reinitialize = Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action.Reinitialize()
                                    self.reinitialize.parent = self
                                    self._children_name_map["reinitialize"] = "reinitialize"
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action, [], name, value)


                                class Authorize(Entity):
                                    """
                                    Authorize the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: voice
                                    
                                    	Authorize the port for VOICE traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action.Authorize, self).__init__()

                                        self.yang_name = "authorize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ('voice', (YLeaf(YType.empty, 'voice'), ['Empty'])),
                                        ])
                                        self.vlan = None
                                        self.voice = None
                                        self._segment_path = lambda: "authorize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action.Authorize, ['vlan', 'voice'], name, value)


                                class Reinitialize(Entity):
                                    """
                                    Reinitialize all client on the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action.Reinitialize, self).__init__()

                                        self.yang_name = "reinitialize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "reinitialize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.Server.Dead.Action.Reinitialize, ['vlan'], name, value)


                    class Fail(Entity):
                        """
                        Configure actions for AAA fail events
                        
                        .. attribute:: action
                        
                        	Required action for fail event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.Fail.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Authentication.Event.Fail, self).__init__()

                            self.yang_name = "fail"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwentyFiveGigE.Authentication.Event.Fail.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.TwentyFiveGigE.Authentication.Event.Fail.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "fail"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.Fail, [], name, value)


                        class Action(Entity):
                            """
                            Required action for fail event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.Fail.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Authentication.Event.Fail.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "fail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.TwentyFiveGigE.Authentication.Event.Fail.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.TwentyFiveGigE.Authentication.Event.Fail.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.Fail.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Authentication.Event.Fail.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.Fail.Action.Authorize, ['vlan'], name, value)


                    class NoResponse(Entity):
                        """
                        Configure actions for AAA no\-response events
                        
                        .. attribute:: action
                        
                        	Required action for no\-response event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse, self).__init__()

                            self.yang_name = "no-response"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "no-response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse, [], name, value)


                        class Action(Entity):
                            """
                            Required action for no\-response event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "no-response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Event.NoResponse.Action.Authorize, ['vlan'], name, value)


                class Order(Entity):
                    """
                    Add an authentication method to the order list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Authentication.Order, self).__init__()

                        self.yang_name = "order"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "order"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Order, ['dot1x', 'mab', 'webauth'], name, value)


                class Priority(Entity):
                    """
                    Add an authentication method to the priority list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Authentication.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Priority, ['dot1x', 'mab', 'webauth'], name, value)


                class Timer(Entity):
                    """
                    Set authentication timer values
                    
                    .. attribute:: reauthenticate
                    
                    	Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                    	**type**\:  :py:class:`Reauthenticate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Timer.Reauthenticate>`
                    
                    .. attribute:: inactivity
                    
                    	Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                    	**type**\:  :py:class:`Inactivity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity>`
                    
                    .. attribute:: restart
                    
                    	Interval in seconds after which an attempt should be made toauthenticate an unauthorized port (default 60 sec)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Authentication.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reauthenticate", ("reauthenticate", Native.Interface.TwentyFiveGigE.Authentication.Timer.Reauthenticate)), ("inactivity", ("inactivity", Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity))])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                        ])
                        self.restart = None

                        self.reauthenticate = Native.Interface.TwentyFiveGigE.Authentication.Timer.Reauthenticate()
                        self.reauthenticate.parent = self
                        self._children_name_map["reauthenticate"] = "reauthenticate"

                        self.inactivity = Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity()
                        self.inactivity.parent = self
                        self._children_name_map["inactivity"] = "inactivity"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Timer, ['restart'], name, value)


                    class Reauthenticate(Entity):
                        """
                        Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: server
                        
                        	Obtain re\-authentication timeout value from the server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Authentication.Timer.Reauthenticate, self).__init__()

                            self.yang_name = "reauthenticate"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                            ])
                            self.value = None
                            self.server = None
                            self._segment_path = lambda: "reauthenticate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Timer.Reauthenticate, ['value', 'server'], name, value)


                    class Inactivity(Entity):
                        """
                        Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity.Value>`
                        
                        .. attribute:: server
                        
                        	Obtain inactivity timeout value from the server
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity.Server>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity, self).__init__()

                            self.yang_name = "inactivity"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity.Value)), ("server", ("server", Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity.Server))])
                            self._leafs = OrderedDict()

                            self.value = Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.server = None
                            self._children_name_map["server"] = "server"
                            self._segment_path = lambda: "inactivity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity, [], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.value = None
                                self.dynamic = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity.Value, ['value', 'dynamic'], name, value)


                        class Server(Entity):
                            """
                            Obtain inactivity timeout value from the server
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.dynamic = None
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Authentication.Timer.Inactivity.Server, ['dynamic'], name, value)


            class Mab(Entity):
                """
                
                
                .. attribute:: eap
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Mab, self).__init__()

                    self.yang_name = "mab"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                    ])
                    self.eap = None
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:mab"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Mab, ['eap'], name, value)


            class Dot1x(Entity):
                """
                Interface Config Commands for IEEE 802.1X
                
                .. attribute:: authenticator
                
                	Configure authenticator parameters
                	**type**\:  :py:class:`Authenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Dot1x.Authenticator>`
                
                .. attribute:: credentials
                
                	Credentials profile configuration
                	**type**\: str
                
                .. attribute:: max_reauth_req
                
                	Max No. of Reauthentication Attempts
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_req
                
                	Max No. of Retries
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_start
                
                	Max No. of EAPOL\-Start requests
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: pae
                
                	Set 802.1x interface pae type
                	**type**\:  :py:class:`Pae <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Dot1x.Pae>`
                
                .. attribute:: supplicant
                
                	Configure supplicant parameters
                	**type**\:  :py:class:`Supplicant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Dot1x.Supplicant>`
                
                .. attribute:: timeout
                
                	Various Timeouts
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Dot1x.Timeout>`
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Dot1x, self).__init__()

                    self.yang_name = "dot1x"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authenticator", ("authenticator", Native.Interface.TwentyFiveGigE.Dot1x.Authenticator)), ("supplicant", ("supplicant", Native.Interface.TwentyFiveGigE.Dot1x.Supplicant)), ("timeout", ("timeout", Native.Interface.TwentyFiveGigE.Dot1x.Timeout))])
                    self._leafs = OrderedDict([
                        ('credentials', (YLeaf(YType.str, 'credentials'), ['str'])),
                        ('max_reauth_req', (YLeaf(YType.uint8, 'max-reauth-req'), ['int'])),
                        ('max_req', (YLeaf(YType.uint8, 'max-req'), ['int'])),
                        ('max_start', (YLeaf(YType.uint8, 'max-start'), ['int'])),
                        ('pae', (YLeaf(YType.enumeration, 'pae'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Dot1x.Pae')])),
                    ])
                    self.credentials = None
                    self.max_reauth_req = None
                    self.max_req = None
                    self.max_start = None
                    self.pae = None

                    self.authenticator = Native.Interface.TwentyFiveGigE.Dot1x.Authenticator()
                    self.authenticator.parent = self
                    self._children_name_map["authenticator"] = "authenticator"

                    self.supplicant = Native.Interface.TwentyFiveGigE.Dot1x.Supplicant()
                    self.supplicant.parent = self
                    self._children_name_map["supplicant"] = "supplicant"

                    self.timeout = Native.Interface.TwentyFiveGigE.Dot1x.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"
                    self._segment_path = lambda: "Cisco-IOS-XE-dot1x:dot1x"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Dot1x, ['credentials', 'max_reauth_req', 'max_req', 'max_start', 'pae'], name, value)

                class Pae(Enum):
                    """
                    Pae (Enum Class)

                    Set 802.1x interface pae type

                    .. data:: authenticator = 0

                    .. data:: supplicant = 1

                    .. data:: both = 2

                    """

                    authenticator = Enum.YLeaf(0, "authenticator")

                    supplicant = Enum.YLeaf(1, "supplicant")

                    both = Enum.YLeaf(2, "both")



                class Authenticator(Entity):
                    """
                    Configure authenticator parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP authenticator parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Dot1x.Authenticator.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Dot1x.Authenticator, self).__init__()

                        self.yang_name = "authenticator"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.TwentyFiveGigE.Dot1x.Authenticator.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.TwentyFiveGigE.Dot1x.Authenticator.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "authenticator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Dot1x.Authenticator, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP authenticator parameters
                        
                        .. attribute:: profile
                        
                        	EAP authenticator profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Dot1x.Authenticator.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "authenticator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Dot1x.Authenticator.Eap, ['profile'], name, value)


                class Supplicant(Entity):
                    """
                    Configure supplicant parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP supplicant parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Dot1x.Supplicant.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Dot1x.Supplicant, self).__init__()

                        self.yang_name = "supplicant"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.TwentyFiveGigE.Dot1x.Supplicant.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.TwentyFiveGigE.Dot1x.Supplicant.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "supplicant"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Dot1x.Supplicant, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP supplicant parameters
                        
                        .. attribute:: profile
                        
                        	EAP supplicant profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Dot1x.Supplicant.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "supplicant"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Dot1x.Supplicant.Eap, ['profile'], name, value)


                class Timeout(Entity):
                    """
                    Various Timeouts
                    
                    .. attribute:: auth_period
                    
                    	Timeout for authenticator reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: held_period
                    
                    	Timeout for authentication retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: quiet_period
                    
                    	QuietPeriod in Seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ratelimit_period
                    
                    	Ratelimit Period in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: server_timeout
                    
                    	Timeout for Radius Retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: start_period
                    
                    	Timeout for EAPOL\-start retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: supp_timeout
                    
                    	Timeout for supplicant reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: tx_period
                    
                    	Timeout for supplicant retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Dot1x.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auth_period', (YLeaf(YType.uint16, 'auth-period'), ['int'])),
                            ('held_period', (YLeaf(YType.uint16, 'held-period'), ['int'])),
                            ('quiet_period', (YLeaf(YType.uint16, 'quiet-period'), ['int'])),
                            ('ratelimit_period', (YLeaf(YType.uint16, 'ratelimit-period'), ['int'])),
                            ('server_timeout', (YLeaf(YType.uint16, 'server-timeout'), ['int'])),
                            ('start_period', (YLeaf(YType.uint16, 'start-period'), ['int'])),
                            ('supp_timeout', (YLeaf(YType.uint16, 'supp-timeout'), ['int'])),
                            ('tx_period', (YLeaf(YType.uint16, 'tx-period'), ['int'])),
                        ])
                        self.auth_period = None
                        self.held_period = None
                        self.quiet_period = None
                        self.ratelimit_period = None
                        self.server_timeout = None
                        self.start_period = None
                        self.supp_timeout = None
                        self.tx_period = None
                        self._segment_path = lambda: "timeout"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Dot1x.Timeout, ['auth_period', 'held_period', 'quiet_period', 'ratelimit_period', 'server_timeout', 'start_period', 'supp_timeout', 'tx_period'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpdufilter
                
                	Don't send or receive BPDUs on this interface
                	**type**\:  :py:class:`Bpdufilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SpanningTree.Bpdufilter>`
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SpanningTree.Bpduguard>`
                
                .. attribute:: cost
                
                	To set the path cost of the interface
                	**type**\: int
                
                	**range:** 1..200000000
                
                .. attribute:: guard
                
                	Change an interface's spanning tree guard mode
                	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SpanningTree.Guard>`
                
                .. attribute:: link_type
                
                	Specify a link type for spanning tree tree protocol use
                	**type**\:  :py:class:`LinkType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SpanningTree.LinkType>`
                
                .. attribute:: portfast
                
                	Spanning tree portfast options
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                .. attribute:: port_priority
                
                	Spanning tree port\-priority options
                	**type**\: int
                
                	**range:** 0..240
                
                .. attribute:: vlan
                
                	VLAN Switch Spanning Tree
                	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SpanningTree.Vlan>`
                
                .. attribute:: loopguard
                
                	Spanning tree loopguard options
                	**type**\:  :py:class:`Loopguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SpanningTree.Loopguard>`
                
                .. attribute:: mst
                
                	Per interface MST configurations
                	**type**\:  :py:class:`Mst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SpanningTree.Mst>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Interface.TwentyFiveGigE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Interface.TwentyFiveGigE.SpanningTree.Portfast)), ("vlan", ("vlan", Native.Interface.TwentyFiveGigE.SpanningTree.Vlan)), ("loopguard", ("loopguard", Native.Interface.TwentyFiveGigE.SpanningTree.Loopguard)), ("mst", ("mst", Native.Interface.TwentyFiveGigE.SpanningTree.Mst))])
                    self._leafs = OrderedDict([
                        ('bpdufilter', (YLeaf(YType.enumeration, 'bpdufilter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.SpanningTree.Bpdufilter')])),
                        ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ('guard', (YLeaf(YType.enumeration, 'guard'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.SpanningTree.Guard')])),
                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.SpanningTree.LinkType')])),
                        ('port_priority', (YLeaf(YType.uint8, 'port-priority'), ['int'])),
                    ])
                    self.bpdufilter = None
                    self.cost = None
                    self.guard = None
                    self.link_type = None
                    self.port_priority = None

                    self.bpduguard = Native.Interface.TwentyFiveGigE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"

                    self.loopguard = Native.Interface.TwentyFiveGigE.SpanningTree.Loopguard()
                    self.loopguard.parent = self
                    self._children_name_map["loopguard"] = "loopguard"

                    self.mst = Native.Interface.TwentyFiveGigE.SpanningTree.Mst()
                    self.mst.parent = self
                    self._children_name_map["mst"] = "mst"

                    self.vlan = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:spanning-tree"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.SpanningTree, ['bpdufilter', 'cost', 'guard', 'link_type', 'port_priority'], name, value)

                class Bpdufilter(Enum):
                    """
                    Bpdufilter (Enum Class)

                    Don't send or receive BPDUs on this interface

                    .. data:: disable = 0

                    .. data:: enable = 1

                    """

                    disable = Enum.YLeaf(0, "disable")

                    enable = Enum.YLeaf(1, "enable")


                class Guard(Enum):
                    """
                    Guard (Enum Class)

                    Change an interface's spanning tree guard mode

                    .. data:: loop = 0

                    .. data:: none = 1

                    .. data:: root = 2

                    """

                    loop = Enum.YLeaf(0, "loop")

                    none = Enum.YLeaf(1, "none")

                    root = Enum.YLeaf(2, "root")


                class LinkType(Enum):
                    """
                    LinkType (Enum Class)

                    Specify a link type for spanning tree tree protocol use

                    .. data:: point_to_point = 0

                    .. data:: shared = 1

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")

                    shared = Enum.YLeaf(1, "shared")



                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.disable = None
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.SpanningTree.Bpduguard, ['disable', 'enable'], name, value)


                class Portfast(Entity):
                    """
                    Spanning tree portfast options
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk
                    
                    	Enable portfast on the interface even in trunk mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                        ])
                        self.disable = None
                        self.trunk = None
                        self.edge = None
                        self._segment_path = lambda: "portfast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.SpanningTree.Portfast, ['disable', 'trunk', 'edge'], name, value)


                class Vlan(Entity):
                    """
                    VLAN Switch Spanning Tree
                    
                    .. attribute:: vlan_ids  (key)
                    
                    	vlan range, example\: 1,3\-5,7,9\-11
                    	**type**\: str
                    
                    .. attribute:: cost
                    
                    	<1\-200000000> Spanning\-tree cost
                    	**type**\: int
                    
                    	**range:** 1..200000000
                    
                    .. attribute:: port_priority
                    
                    	<0\-240> port priority in increments of 16
                    	**type**\: int
                    
                    	**range:** 0..240
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.SpanningTree.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vlan_ids']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_ids', (YLeaf(YType.str, 'vlan-ids'), ['str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                        ])
                        self.vlan_ids = None
                        self.cost = None
                        self.port_priority = None
                        self._segment_path = lambda: "vlan" + "[vlan-ids='" + str(self.vlan_ids) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.SpanningTree.Vlan, ['vlan_ids', 'cost', 'port_priority'], name, value)


                class Loopguard(Entity):
                    """
                    Spanning tree loopguard options
                    
                    .. attribute:: default
                    
                    	Enable loopguard by default on all ports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.SpanningTree.Loopguard, self).__init__()

                        self.yang_name = "loopguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.default = None
                        self._segment_path = lambda: "loopguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.SpanningTree.Loopguard, ['default'], name, value)


                class Mst(Entity):
                    """
                    Per interface MST configurations
                    
                    .. attribute:: mst_instance
                    
                    	
                    	**type**\: list of  		 :py:class:`MstInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.SpanningTree.Mst.MstInstance>`
                    
                    .. attribute:: pre_standard
                    
                    	Force pre\-standard MST BPDU transmission on port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.SpanningTree.Mst, self).__init__()

                        self.yang_name = "mst"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mst-instance", ("mst_instance", Native.Interface.TwentyFiveGigE.SpanningTree.Mst.MstInstance))])
                        self._leafs = OrderedDict([
                            ('pre_standard', (YLeaf(YType.empty, 'pre-standard'), ['Empty'])),
                        ])
                        self.pre_standard = None

                        self.mst_instance = YList(self)
                        self._segment_path = lambda: "mst"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.SpanningTree.Mst, ['pre_standard'], name, value)


                    class MstInstance(Entity):
                        """
                        
                        
                        .. attribute:: instance  (key)
                        
                        	MST instance list, example 0,2\-4,6,8\-12
                        	**type**\: str
                        
                        .. attribute:: cost
                        
                        	<1\-200000000> Spanning\-tree cost
                        	**type**\: int
                        
                        	**range:** 1..200000000
                        
                        .. attribute:: port_priority
                        
                        	<0\-240> port priority in increments of 16
                        	**type**\: int
                        
                        	**range:** 0..240
                        
                        

                        """

                        _prefix = 'ios-stp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.SpanningTree.Mst.MstInstance, self).__init__()

                            self.yang_name = "mst-instance"
                            self.yang_parent_name = "mst"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                            ])
                            self.instance = None
                            self.cost = None
                            self.port_priority = None
                            self._segment_path = lambda: "mst-instance" + "[instance='" + str(self.instance) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.SpanningTree.Mst.MstInstance, ['instance', 'cost', 'port_priority'], name, value)


            class Performance(Entity):
                """
                Global performance monitor configuration
                
                .. attribute:: monitor
                
                	monitor
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Performance.Monitor>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Performance, self).__init__()

                    self.yang_name = "performance"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.TwentyFiveGigE.Performance.Monitor))])
                    self._leafs = OrderedDict()

                    self.monitor = Native.Interface.TwentyFiveGigE.Performance.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"
                    self._segment_path = lambda: "Cisco-IOS-XE-ezpm:performance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Performance, [], name, value)


                class Monitor(Entity):
                    """
                    monitor
                    
                    .. attribute:: context
                    
                    	Select ezPM context
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Performance.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "performance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('context', (YLeafList(YType.str, 'context'), ['str'])),
                        ])
                        self.context = []
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Performance.Monitor, ['context'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Umbrella, ['out', 'in_'], name, value)


            class Lldp(Entity):
                """
                LLDP interface subcommands
                
                .. attribute:: receive
                
                	Enable LLDP reception on interface
                	**type**\: bool
                
                .. attribute:: transmit
                
                	Enable LLDP transmission on interface
                	**type**\: bool
                
                

                """

                _prefix = 'ios-lldp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Lldp, self).__init__()

                    self.yang_name = "lldp"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                        ('transmit', (YLeaf(YType.boolean, 'transmit'), ['bool'])),
                    ])
                    self.receive = None
                    self.transmit = None
                    self._segment_path = lambda: "Cisco-IOS-XE-lldp:lldp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Lldp, ['receive', 'transmit'], name, value)


            class Ospfv3(Entity):
                """
                OSPFv3 interface commands
                
                .. attribute:: process_id
                
                	
                	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId>`
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Authentication>`
                
                .. attribute:: bfd
                
                	Enable BFD on this interface
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: cost
                
                	Route cost of this interface
                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Cost>`
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: demand_circuit
                
                	OSPF Demand Circuit
                	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.DemandCircuit>`
                
                	**presence node**\: True
                
                .. attribute:: encryption
                
                	Enable encryption
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption>`
                
                .. attribute:: flood_reduction
                
                	OSPF Flood Reduction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: manet
                
                	Mobile Adhoc Networking options
                	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Manet>`
                
                .. attribute:: mtu_ignore
                
                	Ignores the MTU in DBD packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: multi_area
                
                	Set the OSPF multi\-area ID
                	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.MultiArea>`
                
                .. attribute:: neighbor
                
                	OSPF neighbor
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Neighbor>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Network>`
                
                .. attribute:: prefix_suppression
                
                	OSPF prefix suppression
                	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.PrefixSuppression>`
                
                	**presence node**\: True
                
                .. attribute:: priority
                
                	Router priority
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: retransmit_interval
                
                	Time between retransmitting lost link state advertisements
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Shut down the interface in OSPFv3
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transmit_delay
                
                	Link state transmit delay
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Ospfv3, self).__init__()

                    self.yang_name = "ospfv3"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId)), ("authentication", ("authentication", Native.Interface.TwentyFiveGigE.Ospfv3.Authentication)), ("bfd", ("bfd", Native.Interface.TwentyFiveGigE.Ospfv3.Bfd)), ("cost", ("cost", Native.Interface.TwentyFiveGigE.Ospfv3.Cost)), ("database-filter", ("database_filter", Native.Interface.TwentyFiveGigE.Ospfv3.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TwentyFiveGigE.Ospfv3.DemandCircuit)), ("encryption", ("encryption", Native.Interface.TwentyFiveGigE.Ospfv3.Encryption)), ("manet", ("manet", Native.Interface.TwentyFiveGigE.Ospfv3.Manet)), ("multi-area", ("multi_area", Native.Interface.TwentyFiveGigE.Ospfv3.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TwentyFiveGigE.Ospfv3.Neighbor)), ("network", ("network", Native.Interface.TwentyFiveGigE.Ospfv3.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TwentyFiveGigE.Ospfv3.PrefixSuppression))])
                    self._leafs = OrderedDict([
                        ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                        ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                        ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                    ])
                    self.dead_interval = None
                    self.flood_reduction = None
                    self.hello_interval = None
                    self.mtu_ignore = None
                    self.priority = None
                    self.retransmit_interval = None
                    self.shutdown = None
                    self.transmit_delay = None

                    self.authentication = Native.Interface.TwentyFiveGigE.Ospfv3.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"

                    self.cost = Native.Interface.TwentyFiveGigE.Ospfv3.Cost()
                    self.cost.parent = self
                    self._children_name_map["cost"] = "cost"

                    self.database_filter = Native.Interface.TwentyFiveGigE.Ospfv3.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"

                    self.demand_circuit = None
                    self._children_name_map["demand_circuit"] = "demand-circuit"

                    self.encryption = Native.Interface.TwentyFiveGigE.Ospfv3.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.manet = Native.Interface.TwentyFiveGigE.Ospfv3.Manet()
                    self.manet.parent = self
                    self._children_name_map["manet"] = "manet"

                    self.multi_area = Native.Interface.TwentyFiveGigE.Ospfv3.MultiArea()
                    self.multi_area.parent = self
                    self._children_name_map["multi_area"] = "multi-area"

                    self.network = Native.Interface.TwentyFiveGigE.Ospfv3.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.prefix_suppression = None
                    self._children_name_map["prefix_suppression"] = "prefix-suppression"

                    self.process_id = YList(self)
                    self.neighbor = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3, ['dead_interval', u'flood_reduction', 'hello_interval', u'mtu_ignore', 'priority', 'retransmit_interval', u'shutdown', 'transmit_delay'], name, value)


                class ProcessId(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: manet
                    
                    	Mobile Adhoc Networking options
                    	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.MultiArea>`
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Network>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipv4
                    
                    	Specify parameters for IPv4
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Specify parameters for IPv6
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId, self).__init__()

                        self.yang_name = "process-id"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Authentication)), ("bfd", ("bfd", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Bfd)), ("cost", ("cost", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost)), ("database-filter", ("database_filter", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.FloodReduction)), ("manet", ("manet", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Neighbor)), ("network", ("network", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Shutdown)), ("ipv4", ("ipv4", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4)), ("ipv6", ("ipv6", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.id = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.cost = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.database_filter = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.manet = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet()
                        self.manet.parent = self
                        self._children_name_map["manet"] = "manet"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.multi_area = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.network = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.ipv4 = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId, [u'id', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\: str
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.null = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Authentication, [u'key_chain', u'null'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Bfd, ['disable'], name, value)


                    class Cost(Entity):
                        """
                        Route cost of this interface
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dynamic
                        
                        	Specify dynamic cost options
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.dynamic = None
                            self._children_name_map["dynamic"] = "dynamic"
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost, [u'value'], name, value)


                        class Dynamic(Entity):
                            """
                            Specify dynamic cost options
                            
                            .. attribute:: default
                            
                            	Specify default link metric value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: hysteresis
                            
                            	Specify hysteresis value for LSA dampening
                            	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: weight
                            
                            	Specify weight to be placed on individual metrics
                            	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ])
                                self.default = None

                                self.hysteresis = None
                                self._children_name_map["hysteresis"] = "hysteresis"

                                self.weight = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight()
                                self.weight.parent = self
                                self._children_name_map["weight"] = "weight"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic, [u'default'], name, value)


                            class Hysteresis(Entity):
                                """
                                Specify hysteresis value for LSA dampening
                                
                                .. attribute:: percent
                                
                                	Specify hysteresis percent changed
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold
                                
                                	Specify hysteresis threshold value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, self).__init__()

                                    self.yang_name = "hysteresis"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "hysteresis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                            class Weight(Entity):
                                """
                                Specify weight to be placed on individual metrics
                                
                                .. attribute:: l2_factor
                                
                                	Specify weight to be given to L2\-factor metric
                                	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: latency
                                
                                	Specify weight to be given to latency metric
                                	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: resources
                                
                                	Specify weight to be given to resources metric
                                	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: throughput
                                
                                	Specify weight to be given to throughput metric
                                	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight, self).__init__()

                                    self.yang_name = "weight"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput))])
                                    self._leafs = OrderedDict()

                                    self.l2_factor = None
                                    self._children_name_map["l2_factor"] = "L2-factor"

                                    self.latency = None
                                    self._children_name_map["latency"] = "latency"

                                    self.resources = None
                                    self._children_name_map["resources"] = "resources"

                                    self.throughput = None
                                    self._children_name_map["throughput"] = "throughput"
                                    self._segment_path = lambda: "weight"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight, [], name, value)


                                class L2Factor(Entity):
                                    """
                                    Specify weight to be given to L2\-factor metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                        self.yang_name = "L2-factor"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "L2-factor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                class Latency(Entity):
                                    """
                                    Specify weight to be given to latency metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, self).__init__()

                                        self.yang_name = "latency"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "latency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                class Resources(Entity):
                                    """
                                    Specify weight to be given to resources metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, self).__init__()

                                        self.yang_name = "resources"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "resources"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                class Throughput(Entity):
                                    """
                                    Specify weight to be given to throughput metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, self).__init__()

                                        self.yang_name = "throughput"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "throughput"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.ProcessId.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.DatabaseFilter, [u'all', u'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.DemandCircuit, [u'disable', u'ignore'], name, value)


                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.FloodReduction, [u'disable'], name, value)


                    class Manet(Entity):
                        """
                        Mobile Adhoc Networking options
                        
                        .. attribute:: peering
                        
                        	MANET Peering options
                        	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet.Peering>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet, self).__init__()

                            self.yang_name = "manet"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet.Peering))])
                            self._leafs = OrderedDict()

                            self.peering = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet.Peering()
                            self.peering.parent = self
                            self._children_name_map["peering"] = "peering"
                            self._segment_path = lambda: "manet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet, [], name, value)


                        class Peering(Entity):
                            """
                            MANET Peering options
                            
                            .. attribute:: cost
                            
                            	Redundant path cost improvement required to peer
                            	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet.Peering.Cost>`
                            
                            .. attribute:: link_metrics
                            
                            	Require link metrics
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet.Peering, self).__init__()

                                self.yang_name = "peering"
                                self.yang_parent_name = "manet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet.Peering.Cost))])
                                self._leafs = OrderedDict([
                                    ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                ])
                                self.link_metrics = None

                                self.cost = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet.Peering.Cost()
                                self.cost.parent = self
                                self._children_name_map["cost"] = "cost"
                                self._segment_path = lambda: "peering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet.Peering, [u'link_metrics'], name, value)


                            class Cost(Entity):
                                """
                                Redundant path cost improvement required to peer
                                
                                .. attribute:: percent
                                
                                	Relative incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                .. attribute:: threshold
                                
                                	Absolute incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet.Peering.Cost, self).__init__()

                                    self.yang_name = "cost"
                                    self.yang_parent_name = "peering"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "cost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.MtuIgnore, [u'disable'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: disable
                        
                        	disable OSPF multi\-area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.disable = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.MultiArea, [u'id', u'cost', u'disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.PrefixSuppression, ['disable'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Shutdown, [u'disable'], name, value)


                    class Ipv4(Entity):
                        """
                        Specify parameters for IPv4
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Area)), ("authentication", ("authentication", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Authentication)), ("bfd", ("bfd", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Bfd)), ("cost", ("cost", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost)), ("database-filter", ("database_filter", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.FloodReduction)), ("manet", ("manet", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Neighbor)), ("network", ("network", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 64..95
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv4.Shutdown, [u'disable'], name, value)


                    class Ipv6(Entity):
                        """
                        Specify parameters for IPv6
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Area)), ("authentication", ("authentication", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Authentication)), ("bfd", ("bfd", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Bfd)), ("cost", ("cost", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost)), ("database-filter", ("database_filter", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.FloodReduction)), ("manet", ("manet", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.MultiArea)), ("neighbor", ("neighbor", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Neighbor)), ("network", ("network", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 0..31
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.ProcessId.Ipv6.Shutdown, [u'disable'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: key_chain
                    
                    	Use a key\-chain for cryptographic authentication keys
                    	**type**\: str
                    
                    .. attribute:: null
                    
                    	Use no authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec authentication
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.null = None

                        self.ipsec = Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication, [u'key_chain', u'null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec authentication
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 256..4294967295
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5>`
                        
                        .. attribute:: sha1
                        
                        	Use SHA\-1 authentication
                        	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                            ])
                            self.spi = None

                            self.md5 = Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"

                            self.sha1 = Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1()
                            self.sha1.parent = self
                            self._children_name_map["sha1"] = "sha1"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec, ['spi'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class Sha1(Entity):
                            """
                            Use SHA\-1 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1, self).__init__()

                                self.yang_name = "sha1"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "sha1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "sha1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                class Bfd(Entity):
                    """
                    Enable BFD on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BFD on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Bfd, ['disable'], name, value)


                class Cost(Entity):
                    """
                    Route cost of this interface
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: dynamic
                    
                    	Specify dynamic cost options
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.Cost, self).__init__()

                        self.yang_name = "cost"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.dynamic = None
                        self._children_name_map["dynamic"] = "dynamic"
                        self._segment_path = lambda: "cost"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Cost, [u'value'], name, value)


                    class Dynamic(Entity):
                        """
                        Specify dynamic cost options
                        
                        .. attribute:: default
                        
                        	Specify default link metric value
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hysteresis
                        
                        	Specify hysteresis value for LSA dampening
                        	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Hysteresis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: weight
                        
                        	Specify weight to be placed on individual metrics
                        	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic, self).__init__()

                            self.yang_name = "dynamic"
                            self.yang_parent_name = "cost"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                            ])
                            self.default = None

                            self.hysteresis = None
                            self._children_name_map["hysteresis"] = "hysteresis"

                            self.weight = Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight()
                            self.weight.parent = self
                            self._children_name_map["weight"] = "weight"
                            self._segment_path = lambda: "dynamic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic, [u'default'], name, value)


                        class Hysteresis(Entity):
                            """
                            Specify hysteresis value for LSA dampening
                            
                            .. attribute:: percent
                            
                            	Specify hysteresis percent changed
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold
                            
                            	Specify hysteresis threshold value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Hysteresis, self).__init__()

                                self.yang_name = "hysteresis"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "hysteresis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                        class Weight(Entity):
                            """
                            Specify weight to be placed on individual metrics
                            
                            .. attribute:: l2_factor
                            
                            	Specify weight to be given to L2\-factor metric
                            	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.L2Factor>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: latency
                            
                            	Specify weight to be given to latency metric
                            	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Latency>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: resources
                            
                            	Specify weight to be given to resources metric
                            	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Resources>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: throughput
                            
                            	Specify weight to be given to throughput metric
                            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Throughput>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight, self).__init__()

                                self.yang_name = "weight"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Throughput))])
                                self._leafs = OrderedDict()

                                self.l2_factor = None
                                self._children_name_map["l2_factor"] = "L2-factor"

                                self.latency = None
                                self._children_name_map["latency"] = "latency"

                                self.resources = None
                                self._children_name_map["resources"] = "resources"

                                self.throughput = None
                                self._children_name_map["throughput"] = "throughput"
                                self._segment_path = lambda: "weight"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight, [], name, value)


                            class L2Factor(Entity):
                                """
                                Specify weight to be given to L2\-factor metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                    self.yang_name = "L2-factor"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "L2-factor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                            class Latency(Entity):
                                """
                                Specify weight to be given to latency metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Latency, self).__init__()

                                    self.yang_name = "latency"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "latency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                            class Resources(Entity):
                                """
                                Specify weight to be given to resources metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Resources, self).__init__()

                                    self.yang_name = "resources"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "resources"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                            class Throughput(Entity):
                                """
                                Specify weight to be given to throughput metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Throughput, self).__init__()

                                    self.yang_name = "throughput"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "throughput"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.DatabaseFilter.All')])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.DatabaseFilter, [u'all'], name, value)

                    class All(Enum):
                        """
                        All (Enum Class)

                        Filter all LSA

                        .. data:: out = 0

                        """

                        out = Enum.YLeaf(0, "out")



                class DemandCircuit(Entity):
                    """
                    OSPF Demand Circuit
                    
                    .. attribute:: ignore
                    
                    	Ignore demand circuit auto\-negotiation requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.DemandCircuit, self).__init__()

                        self.yang_name = "demand-circuit"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.ignore = None
                        self._segment_path = lambda: "demand-circuit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.DemandCircuit, [u'ignore'], name, value)


                class Encryption(Entity):
                    """
                    Enable encryption
                    
                    .. attribute:: null
                    
                    	No IPsec encryption on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec encryption
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec))])
                        self._leafs = OrderedDict([
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.null = None

                        self.ipsec = Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption, ['null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec encryption
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: esp
                        
                        	Use ESP encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec_3des
                        
                        	Use 3DES encryption
                        	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des>`
                        
                        .. attribute:: aes_cbc
                        
                        	Use AES\-CBC encryption
                        	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                            ])
                            self.spi = None
                            self.esp = None

                            self.ipsec_3des = Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des()
                            self.ipsec_3des.parent = self
                            self._children_name_map["ipsec_3des"] = "ipsec_3des"

                            self.aes_cbc = Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc()
                            self.aes_cbc.parent = self
                            self._children_name_map["aes_cbc"] = "aes-cbc"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec, ['spi', 'esp'], name, value)


                        class Ipsec3des(Entity):
                            """
                            Use 3DES encryption
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des, self).__init__()

                                self.yang_name = "ipsec_3des"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "ipsec_3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "ipsec_3des"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class AesCbc(Entity):
                            """
                            Use AES\-CBC encryption
                            
                            .. attribute:: aes_cbc_128
                            
                            	Use 128 bit key
                            	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128>`
                            
                            .. attribute:: aes_192
                            
                            	Use 192 bit key
                            	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192>`
                            
                            .. attribute:: aes_256
                            
                            	Use 256 bit key
                            	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc, self).__init__()

                                self.yang_name = "aes-cbc"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256))])
                                self._leafs = OrderedDict()

                                self.aes_cbc_128 = Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128()
                                self.aes_cbc_128.parent = self
                                self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                self.aes_192 = Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192()
                                self.aes_192.parent = self
                                self._children_name_map["aes_192"] = "aes-192"

                                self.aes_256 = Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256()
                                self.aes_256.parent = self
                                self._children_name_map["aes_256"] = "aes-256"
                                self._segment_path = lambda: "aes-cbc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc, [], name, value)


                            class AesCbc128(Entity):
                                """
                                Use 128 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                    self.yang_name = "aes-cbc-128"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-cbc-128"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-cbc-128"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes192(Entity):
                                """
                                Use 192 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                    self.yang_name = "aes-192"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-192"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-192"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes256(Entity):
                                """
                                Use 256 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                    self.yang_name = "aes-256"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-256"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-256"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                class Manet(Entity):
                    """
                    Mobile Adhoc Networking options
                    
                    .. attribute:: peering
                    
                    	MANET Peering options
                    	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Manet.Peering>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.Manet, self).__init__()

                        self.yang_name = "manet"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.TwentyFiveGigE.Ospfv3.Manet.Peering))])
                        self._leafs = OrderedDict()

                        self.peering = Native.Interface.TwentyFiveGigE.Ospfv3.Manet.Peering()
                        self.peering.parent = self
                        self._children_name_map["peering"] = "peering"
                        self._segment_path = lambda: "manet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Manet, [], name, value)


                    class Peering(Entity):
                        """
                        MANET Peering options
                        
                        .. attribute:: cost
                        
                        	Redundant path cost improvement required to peer
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Manet.Peering.Cost>`
                        
                        .. attribute:: link_metrics
                        
                        	Require link metrics
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.Manet.Peering, self).__init__()

                            self.yang_name = "peering"
                            self.yang_parent_name = "manet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.TwentyFiveGigE.Ospfv3.Manet.Peering.Cost))])
                            self._leafs = OrderedDict([
                                ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                            ])
                            self.link_metrics = None

                            self.cost = Native.Interface.TwentyFiveGigE.Ospfv3.Manet.Peering.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"
                            self._segment_path = lambda: "peering"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Manet.Peering, [u'link_metrics'], name, value)


                        class Cost(Entity):
                            """
                            Redundant path cost improvement required to peer
                            
                            .. attribute:: percent
                            
                            	Relative incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: threshold
                            
                            	Absolute incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Ospfv3.Manet.Peering.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "peering"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                class MultiArea(Entity):
                    """
                    Set the OSPF multi\-area ID
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.MultiArea, self).__init__()

                        self.yang_name = "multi-area"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self._segment_path = lambda: "multi-area"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.MultiArea, [u'id', u'cost'], name, value)


                class Neighbor(Entity):
                    """
                    OSPF neighbor
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	OSPF cost for point\-to\-multipoint neighbor
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Neighbor.DatabaseFilter>`
                    
                    .. attribute:: poll_interval
                    
                    	OSPF dead\-router polling interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: priority
                    
                    	OSPF priority of non\-broadcast neighbor
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.TwentyFiveGigE.Ospfv3.Neighbor.DatabaseFilter))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self.poll_interval = None
                        self.priority = None

                        self.database_filter = Native.Interface.TwentyFiveGigE.Ospfv3.Neighbor.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Neighbor.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.Neighbor.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Ospfv3.Neighbor.DatabaseFilter.All')])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Neighbor.DatabaseFilter, ['all'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                class Network(Entity):
                    """
                    Network type
                    
                    .. attribute:: broadcast
                    
                    	Specify OSPF broadcast multi\-access network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: manet
                    
                    	Specify MANET OSPF interface type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: non_broadcast
                    
                    	Specify OSPF NBMA network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: point_to_multipoint
                    
                    	Specify OSPF point\-to\-multipoint network
                    	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Ospfv3.Network.PointToMultipoint>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: point_to_point
                    
                    	Specify OSPF point\-to\-point network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.TwentyFiveGigE.Ospfv3.Network.PointToMultipoint))])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                            ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                        ])
                        self.broadcast = None
                        self.manet = None
                        self.non_broadcast = None
                        self.point_to_point = None

                        self.point_to_multipoint = None
                        self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                    class PointToMultipoint(Entity):
                        """
                        Specify OSPF point\-to\-multipoint network
                        
                        .. attribute:: non_broadcast
                        
                        	Specify non\-broadcast point\-to\-mpoint network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Ospfv3.Network.PointToMultipoint, self).__init__()

                            self.yang_name = "point-to-multipoint"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ])
                            self.non_broadcast = None
                            self._segment_path = lambda: "point-to-multipoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.Network.PointToMultipoint, ['non_broadcast'], name, value)


                class PrefixSuppression(Entity):
                    """
                    OSPF prefix suppression
                    
                    .. attribute:: disable
                    
                    	Disable prefix suppression
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Ospfv3.PrefixSuppression, self).__init__()

                        self.yang_name = "prefix-suppression"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "prefix-suppression"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Ospfv3.PrefixSuppression, ['disable'], name, value)


            class Udld(Entity):
                """
                Configure UDLD enabled or disabled and ignore global UDLD setting
                
                .. attribute:: port
                
                	Enable UDLD protocol on this interface despite global UDLD setting
                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Udld.Port>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-udld'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Udld, self).__init__()

                    self.yang_name = "udld"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.TwentyFiveGigE.Udld.Port))])
                    self._leafs = OrderedDict()

                    self.port = None
                    self._children_name_map["port"] = "port"
                    self._segment_path = lambda: "Cisco-IOS-XE-udld:udld"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Udld, [], name, value)


                class Port(Entity):
                    """
                    Enable UDLD protocol on this interface despite global UDLD setting
                    
                    .. attribute:: aggressive
                    
                    	Enable UDLD protocol in aggressive mode on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	Disable UDLD protocol on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-udld'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Udld.Port, self).__init__()

                        self.yang_name = "port"
                        self.yang_parent_name = "udld"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aggressive', (YLeaf(YType.empty, 'aggressive'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.aggressive = None
                        self.disable = None
                        self._segment_path = lambda: "port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Udld.Port, ['aggressive', 'disable'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.Manual>`
                
                	**presence node**\: True
                
                .. attribute:: role_based
                
                	Role\-based Access Control per\-port config commands
                	**type**\:  :py:class:`RoleBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.RoleBased>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.TwentyFiveGigE.Cts.Manual)), ("role-based", ("role_based", Native.Interface.TwentyFiveGigE.Cts.RoleBased))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"

                    self.role_based = Native.Interface.TwentyFiveGigE.Cts.RoleBased()
                    self.role_based.parent = self
                    self._children_name_map["role_based"] = "role-based"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.TwentyFiveGigE.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.TwentyFiveGigE.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.TwentyFiveGigE.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.TwentyFiveGigE.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.TwentyFiveGigE.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.TwentyFiveGigE.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.TwentyFiveGigE.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.TwentyFiveGigE.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.Manual.Propagate, ['sgt'], name, value)


                class RoleBased(Entity):
                    """
                    Role\-based Access Control per\-port config commands
                    
                    .. attribute:: sgt_cache
                    
                    	Enable SGT caching on the interface
                    	**type**\: list of   :py:class:`SgtCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.RoleBased.SgtCache>`
                    
                    .. attribute:: enforcement
                    
                    	Enable Role\-based Access Control enforcement
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sgt_map
                    
                    	Assign Security Group Tag (SGT) to IP host or network address
                    	**type**\:  :py:class:`SgtMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.Cts.RoleBased.SgtMap>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.Cts.RoleBased, self).__init__()

                        self.yang_name = "role-based"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sgt-map", ("sgt_map", Native.Interface.TwentyFiveGigE.Cts.RoleBased.SgtMap))])
                        self._leafs = OrderedDict([
                            ('sgt_cache', (YLeafList(YType.enumeration, 'sgt-cache'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.TwentyFiveGigE.Cts.RoleBased.SgtCache')])),
                            ('enforcement', (YLeaf(YType.empty, 'enforcement'), ['Empty'])),
                        ])
                        self.sgt_cache = []
                        self.enforcement = None

                        self.sgt_map = Native.Interface.TwentyFiveGigE.Cts.RoleBased.SgtMap()
                        self.sgt_map.parent = self
                        self._children_name_map["sgt_map"] = "sgt-map"
                        self._segment_path = lambda: "role-based"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.RoleBased, ['sgt_cache', 'enforcement'], name, value)

                    class SgtCache(Enum):
                        """
                        SgtCache (Enum Class)

                        Enable SGT caching on the interface

                        .. data:: egress = 0

                        .. data:: ingress = 1

                        """

                        egress = Enum.YLeaf(0, "egress")

                        ingress = Enum.YLeaf(1, "ingress")



                    class SgtMap(Entity):
                        """
                        Assign Security Group Tag (SGT) to IP host or network address
                        
                        .. attribute:: security_group
                        
                        	Security Group Name
                        	**type**\: str
                        
                        .. attribute:: sgt
                        
                        	Security Group Tag (SGT)
                        	**type**\: int
                        
                        	**range:** 2..65519
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.TwentyFiveGigE.Cts.RoleBased.SgtMap, self).__init__()

                            self.yang_name = "sgt-map"
                            self.yang_parent_name = "role-based"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('security_group', (YLeaf(YType.str, 'security-group'), ['str'])),
                                ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                            ])
                            self.security_group = None
                            self.sgt = None
                            self._segment_path = lambda: "sgt-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.TwentyFiveGigE.Cts.RoleBased.SgtMap, ['security_group', 'sgt'], name, value)


            class AnalysisModule(Entity):
                """
                Configure NAM on the interface
                
                .. attribute:: monitoring
                
                	Configure NAM monitoring on the interface
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.TwentyFiveGigE.AnalysisModule.Monitoring>`
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Interface.TwentyFiveGigE.AnalysisModule, self).__init__()

                    self.yang_name = "analysis-module"
                    self.yang_parent_name = "TwentyFiveGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Interface.TwentyFiveGigE.AnalysisModule.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = Native.Interface.TwentyFiveGigE.AnalysisModule.Monitoring()
                    self.monitoring.parent = self
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.TwentyFiveGigE.AnalysisModule, [], name, value)


                class Monitoring(Entity):
                    """
                    Configure NAM monitoring on the interface
                    
                    .. attribute:: interface_name
                    
                    	The name of the output interface.  E.g., 'ucse 1/0/0'
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nam'
                    _revision = '2017-12-28'

                    def __init__(self):
                        super(Native.Interface.TwentyFiveGigE.AnalysisModule.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "analysis-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "monitoring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.TwentyFiveGigE.AnalysisModule.Monitoring, ['interface_name'], name, value)


        class FortyGigabitEthernet(Entity):
            """
            Forty Gigabit Ethernet
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: media_type
            
            	Media type
            	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.MediaType>`
            
            .. attribute:: port_type
            
            	
            	**type**\:  :py:class:`PortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.PortType>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service>`
            
            .. attribute:: lacp
            
            	LACP interface subcommands
            	**type**\:  :py:class:`Lacp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Lacp>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec_option
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXEEthernetMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ServicePolicy>`
            
            .. attribute:: auto
            
            	Configure Automation
            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Auto>`
            
            .. attribute:: datalink
            
            	Interface Datalink commands
            	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Datalink>`
            
            .. attribute:: energywise
            
            	EnergyWise interface configurations
            	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Energywise>`
            
            	**presence node**\: True
            
            .. attribute:: location
            
            	Interface location information
            	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Location>`
            
            .. attribute:: mac
            
            	MAC interface commands
            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mac>`
            
            .. attribute:: macro
            
            	Command macro
            	**type**\:  :py:class:`Macro <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Macro>`
            
            .. attribute:: dual_active
            
            	
            	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.DualActive>`
            
            .. attribute:: load_balancing
            
            	Etherchannel Load\-Balancing
            	**type**\:  :py:class:`LoadBalancing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.LoadBalancing>`
            
            .. attribute:: vlan_range
            
            	
            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.VlanRange>`
            
            .. attribute:: switch
            
            	
            	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switch>`
            
            .. attribute:: srr_queue
            
            	
            	**type**\:  :py:class:`SrrQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SrrQueue>`
            
            .. attribute:: cisco_ios_xe_switch_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_switch_macsec_option_
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXESwitchMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Snmp>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Crypto>`
            
            .. attribute:: mka
            
            	MACsec Key Agreement (MKA) interface configuration
            	**type**\:  :py:class:`Mka <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mka>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Utd>`
            
            .. attribute:: xconnect
            
            	Xconnect commands
            	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Xconnect>`
            
            .. attribute:: evpn
            
            	
            	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Evpn>`
            
            .. attribute:: fabric_domain
            
            	Fabric\-domain interface command
            	**type**\:  :py:class:`FabricDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.FabricDomain>`
            
            .. attribute:: mvrp
            
            	
            	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mvrp>`
            
            	**presence node**\: True
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Lisp>`
            
            .. attribute:: power
            
            	
            	**type**\:  :py:class:`Power <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Power>`
            
            .. attribute:: cdp
            
            	CDP interface subcommands
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cdp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ntp>`
            
            .. attribute:: authentication
            
            	Auth Manager Interface Configuration Commands
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication>`
            
            .. attribute:: mab
            
            	
            	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mab>`
            
            	**presence node**\: True
            
            .. attribute:: dot1x
            
            	Interface Config Commands for IEEE 802.1X
            	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Dot1x>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SpanningTree>`
            
            .. attribute:: performance
            
            	Global performance monitor configuration
            	**type**\:  :py:class:`Performance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Performance>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Umbrella>`
            
            .. attribute:: lldp
            
            	LLDP interface subcommands
            	**type**\:  :py:class:`Lldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Lldp>`
            
            .. attribute:: vrrp
            
            	Configure VRRP
            	**type**\:  :py:class:`Vrrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp>`
            
            .. attribute:: nat66
            
            	NAT66 interface commands
            	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Nat66>`
            
            .. attribute:: ospfv3
            
            	OSPFv3 interface commands
            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3>`
            
            .. attribute:: udld
            
            	Configure UDLD enabled or disabled and ignore global UDLD setting
            	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Udld>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts>`
            
            .. attribute:: analysis_module
            
            	Configure NAM on the interface
            	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.AnalysisModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.FortyGigabitEthernet, self).__init__()

                self.yang_name = "FortyGigabitEthernet"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.FortyGigabitEthernet.SwitchportConf)), ("switchport", ("switchport", Native.Interface.FortyGigabitEthernet.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.FortyGigabitEthernet.StackwiseVirtual)), ("arp", ("arp", Native.Interface.FortyGigabitEthernet.Arp)), ("backup", ("backup", Native.Interface.FortyGigabitEthernet.Backup)), ("cemoudp", ("cemoudp", Native.Interface.FortyGigabitEthernet.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.FortyGigabitEthernet.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.FortyGigabitEthernet.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.FortyGigabitEthernet.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.FortyGigabitEthernet.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.FortyGigabitEthernet.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.FortyGigabitEthernet.Flowcontrol)), ("isis", ("isis", Native.Interface.FortyGigabitEthernet.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.FortyGigabitEthernet.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.FortyGigabitEthernet.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.FortyGigabitEthernet.Bandwidth)), ("dampening", ("dampening", Native.Interface.FortyGigabitEthernet.Dampening)), ("domain", ("domain", Native.Interface.FortyGigabitEthernet.Domain)), ("hold-queue", ("hold_queue", Native.Interface.FortyGigabitEthernet.HoldQueue)), ("mpls", ("mpls", Native.Interface.FortyGigabitEthernet.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.FortyGigabitEthernet.IpVrf)), ("vrf", ("vrf", Native.Interface.FortyGigabitEthernet.Vrf)), ("ip", ("ip", Native.Interface.FortyGigabitEthernet.Ip)), ("ipv6", ("ipv6", Native.Interface.FortyGigabitEthernet.Ipv6)), ("logging", ("logging", Native.Interface.FortyGigabitEthernet.Logging)), ("mdix", ("mdix", Native.Interface.FortyGigabitEthernet.Mdix)), ("mop", ("mop", Native.Interface.FortyGigabitEthernet.Mop)), ("interface_qos", ("interface_qos", Native.Interface.FortyGigabitEthernet.InterfaceQos)), ("source", ("source", Native.Interface.FortyGigabitEthernet.Source)), ("standby", ("standby", Native.Interface.FortyGigabitEthernet.Standby)), ("access-session", ("access_session", Native.Interface.FortyGigabitEthernet.AccessSession)), ("storm-control", ("storm_control", Native.Interface.FortyGigabitEthernet.StormControl)), ("trust", ("trust", Native.Interface.FortyGigabitEthernet.Trust)), ("priority-queue", ("priority_queue", Native.Interface.FortyGigabitEthernet.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.FortyGigabitEthernet.RcvQueue)), ("peer", ("peer", Native.Interface.FortyGigabitEthernet.Peer)), ("pm-path", ("pm_path", Native.Interface.FortyGigabitEthernet.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.FortyGigabitEthernet.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.FortyGigabitEthernet.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.FortyGigabitEthernet.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.FortyGigabitEthernet.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.FortyGigabitEthernet.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.FortyGigabitEthernet.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.FortyGigabitEthernet.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.FortyGigabitEthernet.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.FortyGigabitEthernet.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.FortyGigabitEthernet.Service)), ("Cisco-IOS-XE-ethernet:lacp", ("lacp", Native.Interface.FortyGigabitEthernet.Lacp)), ("Cisco-IOS-XE-ethernet:macsec-option", ("cisco_ios_xe_ethernet_macsec_option", Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.FortyGigabitEthernet.ServicePolicy)), ("Cisco-IOS-XE-switch:auto", ("auto", Native.Interface.FortyGigabitEthernet.Auto)), ("Cisco-IOS-XE-switch:datalink", ("datalink", Native.Interface.FortyGigabitEthernet.Datalink)), ("Cisco-IOS-XE-switch:energywise", ("energywise", Native.Interface.FortyGigabitEthernet.Energywise)), ("Cisco-IOS-XE-switch:location", ("location", Native.Interface.FortyGigabitEthernet.Location)), ("Cisco-IOS-XE-switch:mac", ("mac", Native.Interface.FortyGigabitEthernet.Mac)), ("Cisco-IOS-XE-switch:macro", ("macro", Native.Interface.FortyGigabitEthernet.Macro)), ("Cisco-IOS-XE-switch:dual-active", ("dual_active", Native.Interface.FortyGigabitEthernet.DualActive)), ("Cisco-IOS-XE-switch:load-balancing", ("load_balancing", Native.Interface.FortyGigabitEthernet.LoadBalancing)), ("Cisco-IOS-XE-switch:vlan-range", ("vlan_range", Native.Interface.FortyGigabitEthernet.VlanRange)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Interface.FortyGigabitEthernet.Switch)), ("Cisco-IOS-XE-switch:srr-queue", ("srr_queue", Native.Interface.FortyGigabitEthernet.SrrQueue)), ("Cisco-IOS-XE-switch:macsec-option", ("cisco_ios_xe_switch_macsec_option_", Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.FortyGigabitEthernet.Snmp)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.FortyGigabitEthernet.Crypto)), ("Cisco-IOS-XE-mka:mka", ("mka", Native.Interface.FortyGigabitEthernet.Mka)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.FortyGigabitEthernet.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.FortyGigabitEthernet.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.FortyGigabitEthernet.Utd)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.FortyGigabitEthernet.Xconnect)), ("Cisco-IOS-XE-l2vpn:evpn", ("evpn", Native.Interface.FortyGigabitEthernet.Evpn)), ("Cisco-IOS-XE-iwanfabric:fabric-domain", ("fabric_domain", Native.Interface.FortyGigabitEthernet.FabricDomain)), ("Cisco-IOS-XE-mvrp:mvrp", ("mvrp", Native.Interface.FortyGigabitEthernet.Mvrp)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.FortyGigabitEthernet.Lisp)), ("Cisco-IOS-XE-power:power", ("power", Native.Interface.FortyGigabitEthernet.Power)), ("Cisco-IOS-XE-cdp:cdp", ("cdp", Native.Interface.FortyGigabitEthernet.Cdp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.FortyGigabitEthernet.Ntp)), ("Cisco-IOS-XE-sanet:authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Authentication)), ("Cisco-IOS-XE-sanet:mab", ("mab", Native.Interface.FortyGigabitEthernet.Mab)), ("Cisco-IOS-XE-dot1x:dot1x", ("dot1x", Native.Interface.FortyGigabitEthernet.Dot1x)), ("Cisco-IOS-XE-spanning-tree:spanning-tree", ("spanning_tree", Native.Interface.FortyGigabitEthernet.SpanningTree)), ("Cisco-IOS-XE-ezpm:performance", ("performance", Native.Interface.FortyGigabitEthernet.Performance)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.FortyGigabitEthernet.Umbrella)), ("Cisco-IOS-XE-lldp:lldp", ("lldp", Native.Interface.FortyGigabitEthernet.Lldp)), ("Cisco-IOS-XE-vrrp:vrrp", ("vrrp", Native.Interface.FortyGigabitEthernet.Vrrp)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Interface.FortyGigabitEthernet.Ospfv3)), ("Cisco-IOS-XE-udld:udld", ("udld", Native.Interface.FortyGigabitEthernet.Udld)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.FortyGigabitEthernet.Cts)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Interface.FortyGigabitEthernet.AnalysisModule))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('media_type', (YLeaf(YType.enumeration, 'media-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.MediaType')])),
                    ('port_type', (YLeaf(YType.enumeration, 'port-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.PortType')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Duplex')])),
                    ('cisco_ios_xe_ethernet_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-ethernet:macsec'), ['Empty'])),
                    ('cisco_ios_xe_switch_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:macsec'), ['Empty'])),
                    ('nat66', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-nat:nat66'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Nat66')])),
                ])
                self.name = None
                self.media_type = None
                self.port_type = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None
                self.cisco_ios_xe_ethernet_macsec = None
                self.cisco_ios_xe_switch_macsec = None
                self.nat66 = None

                self.switchport_conf = Native.Interface.FortyGigabitEthernet.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.FortyGigabitEthernet.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.FortyGigabitEthernet.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.FortyGigabitEthernet.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.FortyGigabitEthernet.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.FortyGigabitEthernet.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.FortyGigabitEthernet.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.FortyGigabitEthernet.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.FortyGigabitEthernet.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.FortyGigabitEthernet.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.FortyGigabitEthernet.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.FortyGigabitEthernet.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.FortyGigabitEthernet.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.FortyGigabitEthernet.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.FortyGigabitEthernet.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.FortyGigabitEthernet.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.FortyGigabitEthernet.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.FortyGigabitEthernet.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.FortyGigabitEthernet.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.FortyGigabitEthernet.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.FortyGigabitEthernet.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.FortyGigabitEthernet.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.FortyGigabitEthernet.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.FortyGigabitEthernet.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.FortyGigabitEthernet.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.FortyGigabitEthernet.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.FortyGigabitEthernet.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.FortyGigabitEthernet.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.FortyGigabitEthernet.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.FortyGigabitEthernet.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.FortyGigabitEthernet.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.FortyGigabitEthernet.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.FortyGigabitEthernet.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.FortyGigabitEthernet.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.FortyGigabitEthernet.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.FortyGigabitEthernet.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.FortyGigabitEthernet.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.FortyGigabitEthernet.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.FortyGigabitEthernet.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.FortyGigabitEthernet.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.FortyGigabitEthernet.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.FortyGigabitEthernet.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.FortyGigabitEthernet.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.FortyGigabitEthernet.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.FortyGigabitEthernet.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.lacp = Native.Interface.FortyGigabitEthernet.Lacp()
                self.lacp.parent = self
                self._children_name_map["lacp"] = "Cisco-IOS-XE-ethernet:lacp"

                self.cisco_ios_xe_ethernet_macsec_option = Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption()
                self.cisco_ios_xe_ethernet_macsec_option.parent = self
                self._children_name_map["cisco_ios_xe_ethernet_macsec_option"] = "Cisco-IOS-XE-ethernet:macsec-option"

                self.service_policy = Native.Interface.FortyGigabitEthernet.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.auto = Native.Interface.FortyGigabitEthernet.Auto()
                self.auto.parent = self
                self._children_name_map["auto"] = "Cisco-IOS-XE-switch:auto"

                self.datalink = Native.Interface.FortyGigabitEthernet.Datalink()
                self.datalink.parent = self
                self._children_name_map["datalink"] = "Cisco-IOS-XE-switch:datalink"

                self.energywise = None
                self._children_name_map["energywise"] = "Cisco-IOS-XE-switch:energywise"

                self.location = Native.Interface.FortyGigabitEthernet.Location()
                self.location.parent = self
                self._children_name_map["location"] = "Cisco-IOS-XE-switch:location"

                self.mac = Native.Interface.FortyGigabitEthernet.Mac()
                self.mac.parent = self
                self._children_name_map["mac"] = "Cisco-IOS-XE-switch:mac"

                self.macro = Native.Interface.FortyGigabitEthernet.Macro()
                self.macro.parent = self
                self._children_name_map["macro"] = "Cisco-IOS-XE-switch:macro"

                self.dual_active = Native.Interface.FortyGigabitEthernet.DualActive()
                self.dual_active.parent = self
                self._children_name_map["dual_active"] = "Cisco-IOS-XE-switch:dual-active"

                self.load_balancing = Native.Interface.FortyGigabitEthernet.LoadBalancing()
                self.load_balancing.parent = self
                self._children_name_map["load_balancing"] = "Cisco-IOS-XE-switch:load-balancing"

                self.switch = Native.Interface.FortyGigabitEthernet.Switch()
                self.switch.parent = self
                self._children_name_map["switch"] = "Cisco-IOS-XE-switch:switch"

                self.srr_queue = Native.Interface.FortyGigabitEthernet.SrrQueue()
                self.srr_queue.parent = self
                self._children_name_map["srr_queue"] = "Cisco-IOS-XE-switch:srr-queue"

                self.cisco_ios_xe_switch_macsec_option_ = Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption()
                self.cisco_ios_xe_switch_macsec_option_.parent = self
                self._children_name_map["cisco_ios_xe_switch_macsec_option_"] = "Cisco-IOS-XE-switch:macsec-option"

                self.snmp = Native.Interface.FortyGigabitEthernet.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.crypto = Native.Interface.FortyGigabitEthernet.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.mka = Native.Interface.FortyGigabitEthernet.Mka()
                self.mka.parent = self
                self._children_name_map["mka"] = "Cisco-IOS-XE-mka:mka"

                self.et_analytics = Native.Interface.FortyGigabitEthernet.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.FortyGigabitEthernet.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.FortyGigabitEthernet.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.xconnect = Native.Interface.FortyGigabitEthernet.Xconnect()
                self.xconnect.parent = self
                self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                self.evpn = Native.Interface.FortyGigabitEthernet.Evpn()
                self.evpn.parent = self
                self._children_name_map["evpn"] = "Cisco-IOS-XE-l2vpn:evpn"

                self.fabric_domain = Native.Interface.FortyGigabitEthernet.FabricDomain()
                self.fabric_domain.parent = self
                self._children_name_map["fabric_domain"] = "Cisco-IOS-XE-iwanfabric:fabric-domain"

                self.mvrp = None
                self._children_name_map["mvrp"] = "Cisco-IOS-XE-mvrp:mvrp"

                self.lisp = Native.Interface.FortyGigabitEthernet.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.power = Native.Interface.FortyGigabitEthernet.Power()
                self.power.parent = self
                self._children_name_map["power"] = "Cisco-IOS-XE-power:power"

                self.cdp = Native.Interface.FortyGigabitEthernet.Cdp()
                self.cdp.parent = self
                self._children_name_map["cdp"] = "Cisco-IOS-XE-cdp:cdp"

                self.ntp = Native.Interface.FortyGigabitEthernet.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.authentication = Native.Interface.FortyGigabitEthernet.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "Cisco-IOS-XE-sanet:authentication"

                self.mab = None
                self._children_name_map["mab"] = "Cisco-IOS-XE-sanet:mab"

                self.dot1x = Native.Interface.FortyGigabitEthernet.Dot1x()
                self.dot1x.parent = self
                self._children_name_map["dot1x"] = "Cisco-IOS-XE-dot1x:dot1x"

                self.spanning_tree = Native.Interface.FortyGigabitEthernet.SpanningTree()
                self.spanning_tree.parent = self
                self._children_name_map["spanning_tree"] = "Cisco-IOS-XE-spanning-tree:spanning-tree"

                self.performance = Native.Interface.FortyGigabitEthernet.Performance()
                self.performance.parent = self
                self._children_name_map["performance"] = "Cisco-IOS-XE-ezpm:performance"

                self.umbrella = Native.Interface.FortyGigabitEthernet.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.lldp = Native.Interface.FortyGigabitEthernet.Lldp()
                self.lldp.parent = self
                self._children_name_map["lldp"] = "Cisco-IOS-XE-lldp:lldp"

                self.vrrp = Native.Interface.FortyGigabitEthernet.Vrrp()
                self.vrrp.parent = self
                self._children_name_map["vrrp"] = "Cisco-IOS-XE-vrrp:vrrp"

                self.ospfv3 = Native.Interface.FortyGigabitEthernet.Ospfv3()
                self.ospfv3.parent = self
                self._children_name_map["ospfv3"] = "Cisco-IOS-XE-ospfv3:ospfv3"

                self.udld = Native.Interface.FortyGigabitEthernet.Udld()
                self.udld.parent = self
                self._children_name_map["udld"] = "Cisco-IOS-XE-udld:udld"

                self.cts = Native.Interface.FortyGigabitEthernet.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.analysis_module = Native.Interface.FortyGigabitEthernet.AnalysisModule()
                self.analysis_module.parent = self
                self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"

                self.hold_queue = YList(self)
                self.vlan_range = YList(self)
                self._segment_path = lambda: "FortyGigabitEthernet" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.FortyGigabitEthernet, [u'name', u'media_type', u'port_type', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex', 'cisco_ios_xe_ethernet_macsec', u'cisco_ios_xe_switch_macsec', 'nat66'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class MediaType(Enum):
                """
                MediaType (Enum Class)

                Media type

                .. data:: auto_select = 0

                .. data:: rj45 = 1

                .. data:: sfp = 2

                """

                auto_select = Enum.YLeaf(0, "auto-select")

                rj45 = Enum.YLeaf(1, "rj45")

                sfp = Enum.YLeaf(2, "sfp")


            class Nat66(Enum):
                """
                Nat66 (Enum Class)

                NAT66 interface commands

                .. data:: inside = 0

                .. data:: outside = 1

                """

                inside = Enum.YLeaf(0, "inside")

                outside = Enum.YLeaf(1, "outside")


            class PortType(Enum):
                """
                PortType (Enum Class)

                .. data:: nni = 0

                """

                nni = Enum.YLeaf(0, "nni")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Access>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Block>`
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: trunk
                
                	Set trunking characteristics of the interface
                	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Trunk>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Voice>`
                
                .. attribute:: priority
                
                	Set appliance 802.1p priority
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Priority>`
                
                .. attribute:: autostate
                
                	Include or exclude this port from vlan link up calculation
                	**type**\:  :py:class:`Autostate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Autostate>`
                
                .. attribute:: protected
                
                	Configure an interface to be a protected port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Set port host
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: private_vlan
                
                	Set the private VLAN configuration
                	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan>`
                
                .. attribute:: vepa
                
                	Reflective relay configuration
                	**type**\:  :py:class:`Vepa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Vepa>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:access", ("access", Native.Interface.FortyGigabitEthernet.Switchport.Access)), ("Cisco-IOS-XE-switch:block", ("block", Native.Interface.FortyGigabitEthernet.Switchport.Block)), ("Cisco-IOS-XE-switch:mode", ("mode", Native.Interface.FortyGigabitEthernet.Switchport.Mode)), ("Cisco-IOS-XE-switch:port-security", ("port_security", Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity)), ("Cisco-IOS-XE-switch:trunk", ("trunk", Native.Interface.FortyGigabitEthernet.Switchport.Trunk)), ("Cisco-IOS-XE-switch:voice", ("voice", Native.Interface.FortyGigabitEthernet.Switchport.Voice)), ("Cisco-IOS-XE-switch:priority", ("priority", Native.Interface.FortyGigabitEthernet.Switchport.Priority)), ("Cisco-IOS-XE-switch:autostate", ("autostate", Native.Interface.FortyGigabitEthernet.Switchport.Autostate)), ("Cisco-IOS-XE-switch:private-vlan", ("private_vlan", Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan)), ("Cisco-IOS-XE-switch:vepa", ("vepa", Native.Interface.FortyGigabitEthernet.Switchport.Vepa))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:nonegotiate'), ['Empty'])),
                        ('protected', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:protected'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:host'), ['Empty'])),
                    ])
                    self.nonegotiate = None
                    self.protected = None
                    self.host = None

                    self.access = Native.Interface.FortyGigabitEthernet.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "Cisco-IOS-XE-switch:access"

                    self.block = Native.Interface.FortyGigabitEthernet.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "Cisco-IOS-XE-switch:block"

                    self.mode = Native.Interface.FortyGigabitEthernet.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "Cisco-IOS-XE-switch:mode"

                    self.port_security = None
                    self._children_name_map["port_security"] = "Cisco-IOS-XE-switch:port-security"

                    self.trunk = Native.Interface.FortyGigabitEthernet.Switchport.Trunk()
                    self.trunk.parent = self
                    self._children_name_map["trunk"] = "Cisco-IOS-XE-switch:trunk"

                    self.voice = Native.Interface.FortyGigabitEthernet.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "Cisco-IOS-XE-switch:voice"

                    self.priority = Native.Interface.FortyGigabitEthernet.Switchport.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-switch:priority"

                    self.autostate = Native.Interface.FortyGigabitEthernet.Switchport.Autostate()
                    self.autostate.parent = self
                    self._children_name_map["autostate"] = "Cisco-IOS-XE-switch:autostate"

                    self.private_vlan = Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan()
                    self.private_vlan.parent = self
                    self._children_name_map["private_vlan"] = "Cisco-IOS-XE-switch:private-vlan"

                    self.vepa = Native.Interface.FortyGigabitEthernet.Switchport.Vepa()
                    self.vepa.parent = self
                    self._children_name_map["vepa"] = "Cisco-IOS-XE-switch:vepa"
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport, [u'nonegotiate', u'protected', u'host'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	Set VLAN when interface is in access mode
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Access.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FortyGigabitEthernet.Switchport.Access.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.FortyGigabitEthernet.Switchport.Access.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:access"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Access, [], name, value)


                    class Vlan(Entity):
                        """
                        Set VLAN when interface is in access mode
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_>`
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.Access.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "access"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Access.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dynamic = 0

                            """

                            dynamic = Enum.YLeaf(0, "dynamic")



                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: multicast
                    
                    	Block unknown multicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.multicast = None
                        self.unicast = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:block"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Block, [u'multicast', u'unicast'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Mode.Access>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dot1q_tunnel
                    
                    	set trunking mode to TUNNEL unconditionally
                    	**type**\:  :py:class:`Dot1qTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Mode.Dot1qTunnel>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dynamic
                    
                    	Set trunking mode to dynamically negotiate access or trunk mode
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Mode.Dynamic>`
                    
                    .. attribute:: private_vlan
                    
                    	Set private\-vlan mode
                    	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Mode.PrivateVlan>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Mode.Trunk>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.FortyGigabitEthernet.Switchport.Mode.Access)), ("dot1q-tunnel", ("dot1q_tunnel", Native.Interface.FortyGigabitEthernet.Switchport.Mode.Dot1qTunnel)), ("private-vlan", ("private_vlan", Native.Interface.FortyGigabitEthernet.Switchport.Mode.PrivateVlan)), ("trunk", ("trunk", Native.Interface.FortyGigabitEthernet.Switchport.Mode.Trunk))])
                        self._leafs = OrderedDict([
                            ('dynamic', (YLeaf(YType.enumeration, 'dynamic'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Switchport.Mode.Dynamic')])),
                        ])
                        self.dynamic = None

                        self.access = None
                        self._children_name_map["access"] = "access"

                        self.dot1q_tunnel = None
                        self._children_name_map["dot1q_tunnel"] = "dot1q-tunnel"

                        self.private_vlan = Native.Interface.FortyGigabitEthernet.Switchport.Mode.PrivateVlan()
                        self.private_vlan.parent = self
                        self._children_name_map["private_vlan"] = "private-vlan"

                        self.trunk = None
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Mode, [u'dynamic'], name, value)

                    class Dynamic(Enum):
                        """
                        Dynamic (Enum Class)

                        Set trunking mode to dynamically negotiate access or trunk mode

                        .. data:: auto = 0

                        .. data:: desirable = 1

                        """

                        auto = Enum.YLeaf(0, "auto")

                        desirable = Enum.YLeaf(1, "desirable")



                    class Access(Entity):
                        """
                        Set trunking mode to ACCESS unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.Mode.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "access"
                            self._is_frozen = True


                    class Dot1qTunnel(Entity):
                        """
                        set trunking mode to TUNNEL unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.Mode.Dot1qTunnel, self).__init__()

                            self.yang_name = "dot1q-tunnel"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dot1q-tunnel"
                            self._is_frozen = True


                    class PrivateVlan(Entity):
                        """
                        Set private\-vlan mode
                        
                        .. attribute:: host
                        
                        	Set the mode to private\-vlan host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: promiscuous
                        
                        	Set the mode to private\-vlan promiscuous
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.Mode.PrivateVlan, self).__init__()

                            self.yang_name = "private-vlan"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('promiscuous', (YLeaf(YType.empty, 'promiscuous'), ['Empty'])),
                            ])
                            self.host = None
                            self.promiscuous = None
                            self._segment_path = lambda: "private-vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Mode.PrivateVlan, [u'host', u'promiscuous'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking mode to TRUNK unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.Mode.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: mac_address
                    
                    	Secure mac address
                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.MacAddress>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Aging)), ("mac-address", ("mac_address", Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.MacAddress)), ("maximum", ("maximum", Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Maximum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Switchport.PortSecurity.Violation')])),
                        ])
                        self.violation = None

                        self.aging = Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.mac_address = Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"

                        self.maximum = Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:port-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity, [u'violation'], name, value)

                    class Violation(Enum):
                        """
                        Violation (Enum Class)

                        Security violation mode

                        .. data:: protect = 0

                        .. data:: restrict = 1

                        .. data:: shutdown = 2

                        """

                        protect = Enum.YLeaf(0, "protect")

                        restrict = Enum.YLeaf(1, "restrict")

                        shutdown = Enum.YLeaf(2, "shutdown")



                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Aging.Type>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Switchport.PortSecurity.Aging.Type')])),
                            ])
                            self.static = None
                            self.time = None
                            self.type = None
                            self._segment_path = lambda: "aging"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Aging, [u'static', u'time', u'type'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Port\-security aging type

                            .. data:: absolute = 0

                            .. data:: inactivity = 1

                            """

                            absolute = Enum.YLeaf(0, "absolute")

                            inactivity = Enum.YLeaf(1, "inactivity")



                    class MacAddress(Entity):
                        """
                        Secure mac address
                        
                        .. attribute:: sticky
                        
                        	Configure dynamic secure addresses as sticky
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hw_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: vlan
                        
                        	set VLAN ID of the VLAN on which this address can be learned
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                ('hw_address', (YLeaf(YType.str, 'hw-address'), ['str'])),
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.sticky = None
                            self.hw_address = None
                            self.vlan = None
                            self._segment_path = lambda: "mac-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.MacAddress, [u'sticky', u'hw_address', u'vlan'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: max_addresses
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4097
                        
                        .. attribute:: vlan
                        
                        	Max secure addresses per vlan
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_addresses', (YLeaf(YType.uint16, 'max-addresses'), ['int'])),
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['str'])),
                            ])
                            self.max_addresses = None
                            self.vlan = None
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.PortSecurity.Maximum, [u'max_addresses', u'vlan'], name, value)


                class Trunk(Entity):
                    """
                    Set trunking characteristics of the interface
                    
                    .. attribute:: allowed
                    
                    	Set allowed VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Allowed>`
                    
                    .. attribute:: encapsulation
                    
                    	Set encapsulation format on trunk port
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Encapsulation>`
                    
                    .. attribute:: native
                    
                    	Set trunking native characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Native_>`
                    
                    .. attribute:: pruning
                    
                    	Set pruning VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Pruning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Pruning>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Switchport.Trunk, self).__init__()

                        self.yang_name = "trunk"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Native_)), ("pruning", ("pruning", Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Pruning))])
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Switchport.Trunk.Encapsulation')])),
                        ])
                        self.encapsulation = None

                        self.allowed = Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Allowed()
                        self.allowed.parent = self
                        self._children_name_map["allowed"] = "allowed"

                        self.native = Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Native_()
                        self.native.parent = self
                        self._children_name_map["native"] = "native"

                        self.pruning = Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Pruning()
                        self.pruning.parent = self
                        self._children_name_map["pruning"] = "pruning"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:trunk"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Trunk, [u'encapsulation'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Set encapsulation format on trunk port

                        .. data:: dot1q = 0

                        .. data:: isl = 1

                        .. data:: negotiate = 2

                        """

                        dot1q = Enum.YLeaf(0, "dot1q")

                        isl = Enum.YLeaf(1, "isl")

                        negotiate = Enum.YLeaf(2, "negotiate")



                    class Allowed(Entity):
                        """
                        Set allowed VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set allowed VLANs when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Allowed.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Allowed, self).__init__()

                            self.yang_name = "allowed"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Allowed.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Allowed.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "allowed"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Allowed, [], name, value)


                        class Vlan(Entity):
                            """
                            Set allowed VLANs when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: all
                            
                            	all VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "allowed"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = None
                                self.add = None
                                self.all = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                    class Native_(Entity):
                        """
                        Set trunking native characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set native VLAN when interface is in trunking mode
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Native_, self).__init__()

                            self.yang_name = "native"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan'),'int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "native"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Native_, [u'vlan'], name, value)

                        class Vlan(Enum):
                            """
                            Vlan (Enum Class)

                            Set native VLAN when interface is in trunking mode

                            .. data:: tag = 0

                            """

                            tag = Enum.YLeaf(0, "tag")



                    class Pruning(Entity):
                        """
                        Set pruning VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set VLANs enabled for pruning when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Pruning.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Pruning, self).__init__()

                            self.yang_name = "pruning"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Pruning.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Pruning.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "pruning"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Pruning, [], name, value)


                        class Vlan(Entity):
                            """
                            Set VLANs enabled for pruning when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Pruning.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "pruning"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeafList(YType.str, 'vlans'), ['int','str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = []
                                self.add = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Trunk.Pruning.Vlan, [u'vlans', u'add', u'except_', u'none', u'remove'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Voice.Vlan>`
                    
                    .. attribute:: detect
                    
                    	detection enhancement keyword
                    	**type**\:  :py:class:`Detect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Voice.Detect>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FortyGigabitEthernet.Switchport.Voice.Vlan)), ("detect", ("detect", Native.Interface.FortyGigabitEthernet.Switchport.Voice.Detect))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.FortyGigabitEthernet.Switchport.Voice.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"

                        self.detect = Native.Interface.FortyGigabitEthernet.Switchport.Voice.Detect()
                        self.detect.parent = self
                        self._children_name_map["detect"] = "detect"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:voice"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Voice, [], name, value)


                    class Vlan(Entity):
                        """
                        Vlan for voice traffic
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\: str
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.Voice.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_'),'int','str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Voice.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dot1p = 0

                            .. data:: none = 1

                            .. data:: untagged = 2

                            """

                            dot1p = Enum.YLeaf(0, "dot1p")

                            none = Enum.YLeaf(1, "none")

                            untagged = Enum.YLeaf(2, "untagged")



                    class Detect(Entity):
                        """
                        detection enhancement keyword
                        
                        .. attribute:: cisco_phone
                        
                        	Cisco IP phone
                        	**type**\:  :py:class:`CiscoPhone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Voice.Detect.CiscoPhone>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.Voice.Detect, self).__init__()

                            self.yang_name = "detect"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cisco-phone", ("cisco_phone", Native.Interface.FortyGigabitEthernet.Switchport.Voice.Detect.CiscoPhone))])
                            self._leafs = OrderedDict()

                            self.cisco_phone = None
                            self._children_name_map["cisco_phone"] = "cisco-phone"
                            self._segment_path = lambda: "detect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Voice.Detect, [], name, value)


                        class CiscoPhone(Entity):
                            """
                            Cisco IP phone
                            
                            .. attribute:: full_duplex
                            
                            	full duplex keyword
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Switchport.Voice.Detect.CiscoPhone, self).__init__()

                                self.yang_name = "cisco-phone"
                                self.yang_parent_name = "detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('full_duplex', (YLeaf(YType.empty, 'full-duplex'), ['Empty'])),
                                ])
                                self.full_duplex = None
                                self._segment_path = lambda: "cisco-phone"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Voice.Detect.CiscoPhone, [u'full_duplex'], name, value)


                class Priority(Entity):
                    """
                    Set appliance 802.1p priority
                    
                    .. attribute:: extend
                    
                    	Set appliance 802.1p priority
                    	**type**\:  :py:class:`Extend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.Priority.Extend>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Switchport.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("extend", ("extend", Native.Interface.FortyGigabitEthernet.Switchport.Priority.Extend))])
                        self._leafs = OrderedDict()

                        self.extend = Native.Interface.FortyGigabitEthernet.Switchport.Priority.Extend()
                        self.extend.parent = self
                        self._children_name_map["extend"] = "extend"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Priority, [], name, value)


                    class Extend(Entity):
                        """
                        Set appliance 802.1p priority
                        
                        .. attribute:: trust
                        
                        	Trust 802.1p priorities of devices on appliance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cos
                        
                        	Override 802.1p priority of devices on appliance
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.Priority.Extend, self).__init__()

                            self.yang_name = "extend"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                            ])
                            self.trust = None
                            self.cos = None
                            self._segment_path = lambda: "extend"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Priority.Extend, [u'trust', u'cos'], name, value)


                class Autostate(Entity):
                    """
                    Include or exclude this port from vlan link up calculation
                    
                    .. attribute:: exclude
                    
                    	Exclude this port from vlan link up calculation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Switchport.Autostate, self).__init__()

                        self.yang_name = "autostate"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('exclude', (YLeaf(YType.empty, 'exclude'), ['Empty'])),
                        ])
                        self.exclude = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:autostate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Autostate, [u'exclude'], name, value)


                class PrivateVlan(Entity):
                    """
                    Set the private VLAN configuration
                    
                    .. attribute:: association
                    
                    	Set the private VLAN association
                    	**type**\:  :py:class:`Association <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association>`
                    
                    .. attribute:: host_association
                    
                    	Set the private VLAN host association
                    	**type**\:  :py:class:`HostAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.HostAssociation>`
                    
                    .. attribute:: mapping
                    
                    	Set the private VLAN promiscuous mapping
                    	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Mapping>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan, self).__init__()

                        self.yang_name = "private-vlan"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("association", ("association", Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association)), ("host-association", ("host_association", Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.HostAssociation)), ("mapping", ("mapping", Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Mapping))])
                        self._leafs = OrderedDict()

                        self.association = Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association()
                        self.association.parent = self
                        self._children_name_map["association"] = "association"

                        self.host_association = Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.HostAssociation()
                        self.host_association.parent = self
                        self._children_name_map["host_association"] = "host-association"

                        self.mapping = Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Mapping()
                        self.mapping.parent = self
                        self._children_name_map["mapping"] = "mapping"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:private-vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan, [], name, value)


                    class Association(Entity):
                        """
                        Set the private VLAN association
                        
                        .. attribute:: host
                        
                        	Set the private VLAN host association
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association.Host>`
                        
                        .. attribute:: mapping
                        
                        	Set the private VLAN promiscuous mapping
                        	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association.Mapping>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association, self).__init__()

                            self.yang_name = "association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association.Host)), ("mapping", ("mapping", Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association.Mapping))])
                            self._leafs = OrderedDict()

                            self.host = Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.mapping = Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association.Mapping()
                            self.mapping.parent = self
                            self._children_name_map["mapping"] = "mapping"
                            self._segment_path = lambda: "association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association, [], name, value)


                        class Host(Entity):
                            """
                            Set the private VLAN host association
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary normal range VLAN ID of the private VLAN host port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association.Host, [u'primary_range', u'secondary_range'], name, value)


                        class Mapping(Entity):
                            """
                            Set the private VLAN promiscuous mapping
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: remove
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association.Mapping, self).__init__()

                                self.yang_name = "mapping"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self.add = None
                                self.remove = None
                                self._segment_path = lambda: "mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Association.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                    class HostAssociation(Entity):
                        """
                        Set the private VLAN host association
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary normal range VLAN ID of the private VLAN host port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.HostAssociation, self).__init__()

                            self.yang_name = "host-association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self._segment_path = lambda: "host-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.HostAssociation, [u'primary_range', u'secondary_range'], name, value)


                    class Mapping(Entity):
                        """
                        Set the private VLAN promiscuous mapping
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: add
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: remove
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Mapping, self).__init__()

                            self.yang_name = "mapping"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self.add = None
                            self.remove = None
                            self._segment_path = lambda: "mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.PrivateVlan.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                class Vepa(Entity):
                    """
                    Reflective relay configuration
                    
                    .. attribute:: enabled
                    
                    	Enable reflective relay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Switchport.Vepa, self).__init__()

                        self.yang_name = "vepa"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                        ])
                        self.enabled = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:vepa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switchport.Vepa, [u'enabled'], name, value)


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FortyGigabitEthernet.Backup.Delay)), ("interface", ("interface", Native.Interface.FortyGigabitEthernet.Backup.Interface_)), ("load", ("load", Native.Interface.FortyGigabitEthernet.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.FortyGigabitEthernet.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.FortyGigabitEthernet.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.FortyGigabitEthernet.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.FortyGigabitEthernet.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.FortyGigabitEthernet.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.FortyGigabitEthernet.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.FortyGigabitEthernet.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.FortyGigabitEthernet.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.FortyGigabitEthernet.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.FortyGigabitEthernet.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.FortyGigabitEthernet.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.FortyGigabitEthernet.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.FortyGigabitEthernet.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.FortyGigabitEthernet.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.FortyGigabitEthernet.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.FortyGigabitEthernet.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.FortyGigabitEthernet.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.FortyGigabitEthernet.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.FortyGigabitEthernet.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.FortyGigabitEthernet.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.FortyGigabitEthernet.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.FortyGigabitEthernet.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.FortyGigabitEthernet.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.FortyGigabitEthernet.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.FortyGigabitEthernet.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.FortyGigabitEthernet.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.FortyGigabitEthernet.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.FortyGigabitEthernet.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.FortyGigabitEthernet.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.FortyGigabitEthernet.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.FortyGigabitEthernet.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.FortyGigabitEthernet.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.FortyGigabitEthernet.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.FortyGigabitEthernet.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.FortyGigabitEthernet.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.FortyGigabitEthernet.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.FortyGigabitEthernet.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.FortyGigabitEthernet.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.FortyGigabitEthernet.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.FortyGigabitEthernet.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.FortyGigabitEthernet.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.FortyGigabitEthernet.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.FortyGigabitEthernet.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.FortyGigabitEthernet.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.FortyGigabitEthernet.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.FortyGigabitEthernet.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.FortyGigabitEthernet.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.FortyGigabitEthernet.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.FortyGigabitEthernet.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.FortyGigabitEthernet.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.FortyGigabitEthernet.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.FortyGigabitEthernet.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.FortyGigabitEthernet.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.FortyGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.FortyGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.FortyGigabitEthernet.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.FortyGigabitEthernet.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.FortyGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.FortyGigabitEthernet.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.FortyGigabitEthernet.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.FortyGigabitEthernet.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.FortyGigabitEthernet.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.FortyGigabitEthernet.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.FortyGigabitEthernet.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.FortyGigabitEthernet.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.FortyGigabitEthernet.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.FortyGigabitEthernet.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.FortyGigabitEthernet.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.FortyGigabitEthernet.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.FortyGigabitEthernet.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.FortyGigabitEthernet.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.FortyGigabitEthernet.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.FortyGigabitEthernet.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.FortyGigabitEthernet.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.FortyGigabitEthernet.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.FortyGigabitEthernet.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.FortyGigabitEthernet.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.FortyGigabitEthernet.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.FortyGigabitEthernet.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.FortyGigabitEthernet.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.FortyGigabitEthernet.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.FortyGigabitEthernet.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.FortyGigabitEthernet.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Igmp>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Flow>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Nbar>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf>`
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Lisp>`
                
                .. attribute:: rsvp
                
                	RSVP Interface Commands
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Nat>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.FortyGigabitEthernet.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.FortyGigabitEthernet.Ip.Arp)), ("vrf", ("vrf", Native.Interface.FortyGigabitEthernet.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.FortyGigabitEthernet.Ip.NoAddress)), ("address", ("address", Native.Interface.FortyGigabitEthernet.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.FortyGigabitEthernet.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.FortyGigabitEthernet.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.FortyGigabitEthernet.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.FortyGigabitEthernet.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.FortyGigabitEthernet.Ip.Pim)), ("policy", ("policy", Native.Interface.FortyGigabitEthernet.Ip.Policy)), ("rip", ("rip", Native.Interface.FortyGigabitEthernet.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.FortyGigabitEthernet.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.FortyGigabitEthernet.Ip.RouteCache)), ("router", ("router", Native.Interface.FortyGigabitEthernet.Ip.Router)), ("tcp", ("tcp", Native.Interface.FortyGigabitEthernet.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.FortyGigabitEthernet.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.FortyGigabitEthernet.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.FortyGigabitEthernet.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.FortyGigabitEthernet.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.FortyGigabitEthernet.Ip.Igmp)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.FortyGigabitEthernet.Ip.Flow)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.FortyGigabitEthernet.Ip.Nbar)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.FortyGigabitEthernet.Ip.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.FortyGigabitEthernet.Ip.Lisp)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Interface.FortyGigabitEthernet.Ip.Rsvp)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.FortyGigabitEthernet.Ip.Nat)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.FortyGigabitEthernet.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None
                    self.unreachables = None

                    self.access_group = Native.Interface.FortyGigabitEthernet.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.FortyGigabitEthernet.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.FortyGigabitEthernet.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.FortyGigabitEthernet.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.FortyGigabitEthernet.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.FortyGigabitEthernet.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.FortyGigabitEthernet.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.FortyGigabitEthernet.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.FortyGigabitEthernet.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.FortyGigabitEthernet.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.FortyGigabitEthernet.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.FortyGigabitEthernet.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.FortyGigabitEthernet.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.FortyGigabitEthernet.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.FortyGigabitEthernet.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.FortyGigabitEthernet.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.FortyGigabitEthernet.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.FortyGigabitEthernet.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.FortyGigabitEthernet.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.flow = Native.Interface.FortyGigabitEthernet.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.nbar = Native.Interface.FortyGigabitEthernet.Ip.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.ospf = Native.Interface.FortyGigabitEthernet.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.lisp = Native.Interface.FortyGigabitEthernet.Ip.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                    self.rsvp = Native.Interface.FortyGigabitEthernet.Ip.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

                    self.nat = Native.Interface.FortyGigabitEthernet.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.wccp = Native.Interface.FortyGigabitEthernet.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache', 'unreachables'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.FortyGigabitEthernet.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.FortyGigabitEthernet.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.FortyGigabitEthernet.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.FortyGigabitEthernet.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.FortyGigabitEthernet.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.FortyGigabitEthernet.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.FortyGigabitEthernet.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.FortyGigabitEthernet.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.FortyGigabitEthernet.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.FortyGigabitEthernet.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.FortyGigabitEthernet.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.FortyGigabitEthernet.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.FortyGigabitEthernet.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.FortyGigabitEthernet.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.FortyGigabitEthernet.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.FortyGigabitEthernet.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.FortyGigabitEthernet.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.FortyGigabitEthernet.Ip.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ip.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ip.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.FortyGigabitEthernet.Ip.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.FortyGigabitEthernet.Ip.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.FortyGigabitEthernet.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.FortyGigabitEthernet.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.FortyGigabitEthernet.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.FortyGigabitEthernet.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.FortyGigabitEthernet.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.FortyGigabitEthernet.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FortyGigabitEthernet.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.FortyGigabitEthernet.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.FortyGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.FortyGigabitEthernet.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FortyGigabitEthernet.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.FortyGigabitEthernet.Ip.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ip.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.FortyGigabitEthernet.Ip.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.FortyGigabitEthernet.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.FortyGigabitEthernet.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.FortyGigabitEthernet.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.FortyGigabitEthernet.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.FortyGigabitEthernet.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.FortyGigabitEthernet.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.FortyGigabitEthernet.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.FortyGigabitEthernet.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.FortyGigabitEthernet.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FortyGigabitEthernet.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.FortyGigabitEthernet.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.FortyGigabitEthernet.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.FortyGigabitEthernet.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.FortyGigabitEthernet.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.FortyGigabitEthernet.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.FortyGigabitEthernet.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.FortyGigabitEthernet.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.FortyGigabitEthernet.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.FortyGigabitEthernet.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FortyGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.FortyGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Lisp(Entity):
                    """
                    Locator/ID Separation Protocol
                    
                    .. attribute:: source_locator
                    
                    	Choose IP source address for LISP packets egressing this interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_locator', (YLeaf(YType.str, 'source-locator'), ['str'])),
                        ])
                        self.source_locator = None
                        self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Lisp, ['source_locator'], name, value)


                class Rsvp(Entity):
                    """
                    RSVP Interface Commands
                    
                    .. attribute:: authentication
                    
                    	Enables RSVP neighbor authentication (RFC 2747)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bandwidth
                    
                    	RSVP Reservable Bandwidth (kbps)
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	Select permissible RSVP neighbors
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Neighbor>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: precedence
                    
                    	RSVP precedence setting
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Precedence>`
                    
                    .. attribute:: signalling
                    
                    	RSVP signalling
                    	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling>`
                    
                    .. attribute:: tos
                    
                    	RSVP TOS setting
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Tos>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Authentication)), ("bandwidth", ("bandwidth", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth)), ("neighbor", ("neighbor", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Neighbor)), ("precedence", ("precedence", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Precedence)), ("signalling", ("signalling", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling)), ("tos", ("tos", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Tos))])
                        self._leafs = OrderedDict()

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.bandwidth = None
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.neighbor = None
                        self._children_name_map["neighbor"] = "neighbor"

                        self.precedence = Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Precedence()
                        self.precedence.parent = self
                        self._children_name_map["precedence"] = "precedence"

                        self.signalling = Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling()
                        self.signalling.parent = self
                        self._children_name_map["signalling"] = "signalling"

                        self.tos = Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Tos()
                        self.tos.parent = self
                        self._children_name_map["tos"] = "tos"
                        self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp, [], name, value)


                    class Authentication(Entity):
                        """
                        Enables RSVP neighbor authentication (RFC 2747)
                        
                        .. attribute:: key
                        
                        	Password (8 to 40 characters, spaces allowed)
                        	**type**\: str
                        
                        .. attribute:: challenge
                        
                        	Perform challenge/response handshake with new neighbor(s)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key_chain
                        
                        	Name of key chain to use (as created by global 'key chain' command)
                        	**type**\: str
                        
                        .. attribute:: lifetime
                        
                        	Maximum lifetime of neighbor authentication state
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Authentication.Lifetime>`
                        
                        .. attribute:: type
                        
                        	Type of authentication algorithm (default = md5)
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Authentication.Type>`
                        
                        .. attribute:: window_size
                        
                        	Maximum number of messages allowed in receive window (default = 1)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Authentication.Lifetime))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ip.Rsvp.Authentication.Type')])),
                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                            ])
                            self.key = None
                            self.challenge = None
                            self.key_chain = None
                            self.type = None
                            self.window_size = None

                            self.lifetime = Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Authentication.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Authentication, ['key', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Type of authentication algorithm (default = md5)

                            .. data:: md5 = 0

                            .. data:: sha_1 = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            sha_1 = Enum.YLeaf(1, "sha-1")



                        class Lifetime(Entity):
                            """
                            Maximum lifetime of neighbor authentication state
                            
                            .. attribute:: hh_mm_ss
                            
                            	Lifetime (default = 30 mins) in hh\:mm\:ss format
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ])
                                self.hh_mm_ss = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


                    class Bandwidth(Entity):
                        """
                        RSVP Reservable Bandwidth (kbps)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Value>`
                        
                        .. attribute:: percent
                        
                        	Percentage of interface bandwidth. Values higher than 100 represent overbooking
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: mam
                        
                        	Use bandwidth with MAM model of DSTE
                        	**type**\:  :py:class:`Mam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Mam>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Value)), ("mam", ("mam", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Mam))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                            ])
                            self.percent = None

                            self.value = Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.mam = Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Mam()
                            self.mam.parent = self
                            self._children_name_map["mam"] = "mam"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth, ['percent'], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	Reservable Bandwidth (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            .. attribute:: sub_pool
                            
                            	Reservable Bandwidth for Tunnel using sub (BC1) pool (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.value = None
                                self.sub_pool = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Value, ['value', 'sub_pool'], name, value)


                        class Mam(Entity):
                            """
                            Use bandwidth with MAM model of DSTE
                            
                            .. attribute:: max_reservable_bw
                            
                            	Maximum Reservable bandwidth for MAM
                            	**type**\:  :py:class:`MaxReservableBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Mam, self).__init__()

                                self.yang_name = "mam"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("max-reservable-bw", ("max_reservable_bw", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw))])
                                self._leafs = OrderedDict()

                                self.max_reservable_bw = None
                                self._children_name_map["max_reservable_bw"] = "max-reservable-bw"
                                self._segment_path = lambda: "mam"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Mam, [], name, value)


                            class MaxReservableBw(Entity):
                                """
                                Maximum Reservable bandwidth for MAM
                                
                                .. attribute:: value
                                
                                	Reservable Bandwidth (kbps)
                                	**type**\: int
                                
                                	**range:** 1..10000000
                                
                                .. attribute:: bc0
                                
                                	Reservable Bandwidth from global (BC0) pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                .. attribute:: bc1
                                
                                	Reservable Bandwidth from sub pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, self).__init__()

                                    self.yang_name = "max-reservable-bw"
                                    self.yang_parent_name = "mam"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                        ('bc0', (YLeaf(YType.uint32, 'bc0'), ['int'])),
                                        ('bc1', (YLeaf(YType.uint32, 'bc1'), ['int'])),
                                    ])
                                    self.value = None
                                    self.bc0 = None
                                    self.bc1 = None
                                    self._segment_path = lambda: "max-reservable-bw"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, ['value', 'bc0', 'bc1'], name, value)


                    class Neighbor(Entity):
                        """
                        Select permissible RSVP neighbors
                        
                        .. attribute:: acl_number
                        
                        	Access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                            ])
                            self.acl_number = None
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Neighbor, ['acl_number'], name, value)


                    class Precedence(Entity):
                        """
                        RSVP precedence setting
                        
                        .. attribute:: conform
                        
                        	Precedence for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: exceed
                        
                        	Precedence for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Precedence, ['conform', 'exceed'], name, value)


                    class Signalling(Entity):
                        """
                        RSVP signalling
                        
                        .. attribute:: dscp
                        
                        	DSCP for RSVP signalling messages
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: fast_local_repair
                        
                        	Fast Local Repair parameters
                        	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair>`
                        
                        .. attribute:: hello
                        
                        	Enable neighbor\-down detection
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling, self).__init__()

                            self.yang_name = "signalling"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.fast_local_repair = Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair()
                            self.fast_local_repair.parent = self
                            self._children_name_map["fast_local_repair"] = "fast-local-repair"

                            self.hello = None
                            self._children_name_map["hello"] = "hello"
                            self._segment_path = lambda: "signalling"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling, ['dscp'], name, value)


                        class FastLocalRepair(Entity):
                            """
                            Fast Local Repair parameters
                            
                            .. attribute:: wait_time
                            
                            	Wait Time for start of Fast Local Repair in msec
                            	**type**\: int
                            
                            	**range:** 0..5000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                                self.yang_name = "fast-local-repair"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint16, 'wait-time'), ['int'])),
                                ])
                                self.wait_time = None
                                self._segment_path = lambda: "fast-local-repair"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.FastLocalRepair, ['wait_time'], name, value)


                        class Hello(Entity):
                            """
                            Enable neighbor\-down detection
                            
                            .. attribute:: bfd
                            
                            	Configure BFD trigger for MPLS/TE FRR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	DSCP for RSVP Hello messages
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: graceful_restart
                            
                            	Configure RSVP Graceful Restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: refresh
                            
                            	Configure RSVP Hello refresh behavior for Fast\-Reroute
                            	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh>`
                            
                            .. attribute:: reroute
                            
                            	Configure RSVP Hello refresh behavior for Reroute
                            	**type**\:  :py:class:`Reroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh)), ("reroute", ("reroute", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ('graceful_restart', (YLeaf(YType.empty, 'graceful-restart'), ['Empty'])),
                                ])
                                self.bfd = None
                                self.dscp = None
                                self.graceful_restart = None

                                self.refresh = Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh()
                                self.refresh.parent = self
                                self._children_name_map["refresh"] = "refresh"

                                self.reroute = Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute()
                                self.reroute.parent = self
                                self._children_name_map["reroute"] = "reroute"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello, ['bfd', 'dscp', 'graceful_restart'], name, value)


                            class Refresh(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Fast\-Reroute
                                
                                .. attribute:: interval
                                
                                	Hello interval in msec
                                	**type**\: int
                                
                                	**range:** 10..30000
                                
                                .. attribute:: misses
                                
                                	Number of missed Hello Acks which triggers neighbor down
                                	**type**\: int
                                
                                	**range:** 4..10
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh, self).__init__()

                                    self.yang_name = "refresh"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.misses = None
                                    self._segment_path = lambda: "refresh"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Refresh, ['interval', 'misses'], name, value)


                            class Reroute(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Reroute
                                
                                .. attribute:: dscp
                                
                                	DSCP for RSVP Hello messages
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: refresh
                                
                                	Configure RSVP Reroute Hello refresh behavior
                                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh>`
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute, self).__init__()

                                    self.yang_name = "reroute"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh))])
                                    self._leafs = OrderedDict([
                                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ])
                                    self.dscp = None

                                    self.refresh = Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh()
                                    self.refresh.parent = self
                                    self._children_name_map["refresh"] = "refresh"
                                    self._segment_path = lambda: "reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute, ['dscp'], name, value)


                                class Refresh(Entity):
                                    """
                                    Configure RSVP Reroute Hello refresh behavior
                                    
                                    .. attribute:: interval
                                    
                                    	Hello Reroute interval in msec
                                    	**type**\: int
                                    
                                    	**range:** 1000..30000
                                    
                                    .. attribute:: misses
                                    
                                    	Number of missed Hello Acks which triggers neighbor down
                                    	**type**\: int
                                    
                                    	**range:** 4..10
                                    
                                    

                                    """

                                    _prefix = 'ios-rsvp'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, self).__init__()

                                        self.yang_name = "refresh"
                                        self.yang_parent_name = "reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.misses = None
                                        self._segment_path = lambda: "refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, ['interval', 'misses'], name, value)


                    class Tos(Entity):
                        """
                        RSVP TOS setting
                        
                        .. attribute:: conform
                        
                        	TOS for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: exceed
                        
                        	TOS for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Rsvp.Tos, ['conform', 'exceed'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.FortyGigabitEthernet.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.FortyGigabitEthernet.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.FortyGigabitEthernet.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.FortyGigabitEthernet.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.FortyGigabitEthernet.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FortyGigabitEthernet.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.FortyGigabitEthernet.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FortyGigabitEthernet.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.FortyGigabitEthernet.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.FortyGigabitEthernet.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.FortyGigabitEthernet.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.TrafficFilter>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Flow>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Crypto>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Pim>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: rip
                
                	Configure RIP routing protocol
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Rip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.FortyGigabitEthernet.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.FortyGigabitEthernet.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp)), ("address", ("address", Native.Interface.FortyGigabitEthernet.Ipv6.Address)), ("nd", ("nd", Native.Interface.FortyGigabitEthernet.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.FortyGigabitEthernet.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.FortyGigabitEthernet.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.FortyGigabitEthernet.Ipv6.Flow)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.FortyGigabitEthernet.Ipv6.Crypto)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.FortyGigabitEthernet.Ipv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.FortyGigabitEthernet.Ipv6.Pim)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Interface.FortyGigabitEthernet.Ipv6.Rip))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None
                    self.unreachables = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.FortyGigabitEthernet.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.FortyGigabitEthernet.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.FortyGigabitEthernet.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.flow = Native.Interface.FortyGigabitEthernet.Ipv6.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.crypto = Native.Interface.FortyGigabitEthernet.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.ospf = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.no_pim = Native.Interface.FortyGigabitEthernet.Ipv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.FortyGigabitEthernet.Ipv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects', 'unreachables'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.FortyGigabitEthernet.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.FortyGigabitEthernet.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.FortyGigabitEthernet.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.FortyGigabitEthernet.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FortyGigabitEthernet.Ipv6.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.FortyGigabitEthernet.Ipv6.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ipv6.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ipv6.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Crypto, ['map'], name, value)


                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process
                    
                    	
                    	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Process>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: encryption
                    
                    	Enable encryption
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Network>`
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process", ("process", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Process)), ("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication)), ("bfd", ("bfd", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.DemandCircuit)), ("encryption", ("encryption", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption)), ("flood-reduction", ("flood_reduction", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.FloodReduction)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.MtuIgnore)), ("neighbor", ("neighbor", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Neighbor)), ("network", ("network", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Network)), ("shutdown", ("shutdown", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Shutdown))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.cost = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.encryption = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.network = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.process = YList(self)
                        self.neighbor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf, ['cost', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Process(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: instance
                        
                        	Set the OSPF instance
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..31
                        
                        		**type**\: int
                        
                        			**range:** 32..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Process, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['int','int'])),
                            ])
                            self.id = None
                            self.area = None
                            self.instance = None
                            self._segment_path = lambda: "process" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Process, ['id', 'area', 'instance'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec authentication
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec authentication
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 256..4294967295
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5>`
                            
                            .. attribute:: sha1
                            
                            	Use SHA\-1 authentication
                            	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ])
                                self.spi = None

                                self.md5 = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.sha1 = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1()
                                self.sha1.parent = self
                                self._children_name_map["sha1"] = "sha1"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec, ['spi'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Sha1(Entity):
                                """
                                Use SHA\-1 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, self).__init__()

                                    self.yang_name = "sha1"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "sha1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "sha1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ipv6.Ospf.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.DatabaseFilter, ['all', 'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.DemandCircuit, ['disable', 'ignore'], name, value)


                    class Encryption(Entity):
                        """
                        Enable encryption
                        
                        .. attribute:: null
                        
                        	No IPsec encryption on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec encryption
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec encryption
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: esp
                            
                            	Use ESP encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipsec_3des
                            
                            	Use 3DES encryption
                            	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des>`
                            
                            .. attribute:: aes_cbc
                            
                            	Use AES\-CBC encryption
                            	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                                ])
                                self.spi = None
                                self.esp = None

                                self.ipsec_3des = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des()
                                self.ipsec_3des.parent = self
                                self._children_name_map["ipsec_3des"] = "ipsec_3des"

                                self.aes_cbc = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc()
                                self.aes_cbc.parent = self
                                self._children_name_map["aes_cbc"] = "aes-cbc"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec, ['spi', 'esp'], name, value)


                            class Ipsec3des(Entity):
                                """
                                Use 3DES encryption
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, self).__init__()

                                    self.yang_name = "ipsec_3des"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "ipsec_3des"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "ipsec_3des"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class AesCbc(Entity):
                                """
                                Use AES\-CBC encryption
                                
                                .. attribute:: aes_cbc_128
                                
                                	Use 128 bit key
                                	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128>`
                                
                                .. attribute:: aes_192
                                
                                	Use 192 bit key
                                	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192>`
                                
                                .. attribute:: aes_256
                                
                                	Use 256 bit key
                                	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, self).__init__()

                                    self.yang_name = "aes-cbc"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256))])
                                    self._leafs = OrderedDict()

                                    self.aes_cbc_128 = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128()
                                    self.aes_cbc_128.parent = self
                                    self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                    self.aes_192 = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192()
                                    self.aes_192.parent = self
                                    self._children_name_map["aes_192"] = "aes-192"

                                    self.aes_256 = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256()
                                    self.aes_256.parent = self
                                    self._children_name_map["aes_256"] = "aes-256"
                                    self._segment_path = lambda: "aes-cbc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc, [], name, value)


                                class AesCbc128(Entity):
                                    """
                                    Use 128 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                        self.yang_name = "aes-cbc-128"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-cbc-128"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-cbc-128"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes192(Entity):
                                    """
                                    Use 192 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                        self.yang_name = "aes-192"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-192"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-192"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes256(Entity):
                                    """
                                    Use 256 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                        self.yang_name = "aes-256"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-256"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	Disable Flood Reduction on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.FloodReduction, ['disable'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.MtuIgnore, ['disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Ospf.Shutdown, ['disable'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.FortyGigabitEthernet.Ipv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.FortyGigabitEthernet.Ipv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Pim.Bsr, ['border'], name, value)


                class Rip(Entity):
                    """
                    Configure RIP routing protocol
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable/disable RIP routing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default_information
                    
                    	Configure handling of default route
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Rip.DefaultInformation>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ipv6.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("default-information", ("default_information", Native.Interface.FortyGigabitEthernet.Ipv6.Rip.DefaultInformation))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.id = None
                        self.enable = None

                        self.default_information = Native.Interface.FortyGigabitEthernet.Ipv6.Rip.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Rip, ['id', 'enable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Configure handling of default route
                        
                        .. attribute:: route
                        
                        	
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ipv6.Rip.DefaultInformation.Route>`
                        
                        .. attribute:: metric
                        
                        	Default route metric
                        	**type**\: int
                        
                        	**range:** 1..15
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ipv6.Rip.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route', (YLeaf(YType.enumeration, 'route'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ipv6.Rip.DefaultInformation.Route')])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ])
                            self.route = None
                            self.metric = None
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ipv6.Rip.DefaultInformation, ['route', 'metric'], name, value)

                        class Route(Enum):
                            """
                            Route (Enum Class)

                            .. data:: only = 0

                            .. data:: originate = 1

                            """

                            only = Enum.YLeaf(0, "only")

                            originate = Enum.YLeaf(1, "originate")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FortyGigabitEthernet.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.FortyGigabitEthernet.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.FortyGigabitEthernet.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.FortyGigabitEthernet.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.FortyGigabitEthernet.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.FortyGigabitEthernet.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.FortyGigabitEthernet.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.FortyGigabitEthernet.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.FortyGigabitEthernet.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FortyGigabitEthernet.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.FortyGigabitEthernet.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.FortyGigabitEthernet.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.FortyGigabitEthernet.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.FortyGigabitEthernet.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.FortyGigabitEthernet.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.FortyGigabitEthernet.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.FortyGigabitEthernet.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.FortyGigabitEthernet.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.FortyGigabitEthernet.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.FortyGigabitEthernet.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.FortyGigabitEthernet.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.FortyGigabitEthernet.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.FortyGigabitEthernet.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.FortyGigabitEthernet.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.FortyGigabitEthernet.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.FortyGigabitEthernet.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.FortyGigabitEthernet.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.FortyGigabitEthernet.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.FortyGigabitEthernet.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.FortyGigabitEthernet.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.FortyGigabitEthernet.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.FortyGigabitEthernet.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.FortyGigabitEthernet.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.FortyGigabitEthernet.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.FortyGigabitEthernet.CarrierDelay.Down)), ("up", ("up", Native.Interface.FortyGigabitEthernet.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.FortyGigabitEthernet.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.FortyGigabitEthernet.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.FortyGigabitEthernet.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.FortyGigabitEthernet.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.FortyGigabitEthernet.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.FortyGigabitEthernet.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.FortyGigabitEthernet.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.FortyGigabitEthernet.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.FortyGigabitEthernet.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.FortyGigabitEthernet.Plim.Ethernet)), ("qos", ("qos", Native.Interface.FortyGigabitEthernet.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.FortyGigabitEthernet.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.FortyGigabitEthernet.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.FortyGigabitEthernet.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.FortyGigabitEthernet.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.FortyGigabitEthernet.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.FortyGigabitEthernet.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.FortyGigabitEthernet.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.FortyGigabitEthernet.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.FortyGigabitEthernet.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.FortyGigabitEthernet.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.FortyGigabitEthernet.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.FortyGigabitEthernet.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.FortyGigabitEthernet.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.FortyGigabitEthernet.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect)), ("Cisco-IOS-XE-l2vpn:xconnect-pw-class", ("xconnect_pw_class", Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.FortyGigabitEthernet.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.FortyGigabitEthernet.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.FortyGigabitEthernet.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.FortyGigabitEthernet.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"

                        self.xconnect = Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                        self.xconnect_pw_class = Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.FortyGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.FortyGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Lacp(Entity):
                """
                LACP interface subcommands
                
                .. attribute:: port_priority
                
                	LACP priority on this interface 
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rate
                
                	Rate at which the LACP packets are requested to be ingressed to this interface
                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Lacp.Rate>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Lacp, self).__init__()

                    self.yang_name = "lacp"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_priority', (YLeaf(YType.uint32, 'port-priority'), ['int'])),
                        ('rate', (YLeaf(YType.enumeration, 'rate'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Lacp.Rate')])),
                    ])
                    self.port_priority = None
                    self.rate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:lacp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Lacp, ['port_priority', 'rate'], name, value)

                class Rate(Enum):
                    """
                    Rate (Enum Class)

                    Rate at which the LACP packets are requested to be ingressed to this interface

                    .. data:: fast = 0

                    .. data:: normal = 1

                    """

                    fast = Enum.YLeaf(0, "fast")

                    normal = Enum.YLeaf(1, "normal")



            class CiscoIOSXEEthernetMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: dot1q_in_clear
                    
                    	Dot1q in Clear option
                    	**type**\:  :py:class:`Dot1qInClear <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear>`
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('dot1q_in_clear', (YLeaf(YType.enumeration, 'dot1q-in-clear'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear')])),
                        ])
                        self.dot1q_in_clear = None

                        self.replay_protection = Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec, ['dot1q_in_clear'], name, value)

                    class Dot1qInClear(Enum):
                        """
                        Dot1qInClear (Enum Class)

                        Dot1q in Clear option

                        .. data:: Y_1 = 0

                        """

                        Y_1 = Enum.YLeaf(0, "1")



                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, ['window_size'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.FortyGigabitEthernet.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.FortyGigabitEthernet.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Auto(Entity):
                """
                Configure Automation
                
                .. attribute:: qos
                
                	Configure AutoQoS
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Auto.Qos>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Auto, self).__init__()

                    self.yang_name = "auto"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("qos", ("qos", Native.Interface.FortyGigabitEthernet.Auto.Qos))])
                    self._leafs = OrderedDict()

                    self.qos = Native.Interface.FortyGigabitEthernet.Auto.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:auto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Auto, [], name, value)


                class Qos(Entity):
                    """
                    Configure AutoQoS
                    
                    .. attribute:: classify
                    
                    	Configure classification for untrusted devices
                    	**type**\:  :py:class:`Classify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Auto.Qos.Classify>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trust
                    
                    	Trust the DSCP/CoS marking
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Auto.Qos.Trust>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: video
                    
                    	Configure AutoQoS for video devices
                    	**type**\:  :py:class:`Video <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Auto.Qos.Video>`
                    
                    .. attribute:: voip
                    
                    	Configure AutoQoS for VoIP
                    	**type**\:  :py:class:`Voip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Auto.Qos.Voip>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Auto.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "auto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("classify", ("classify", Native.Interface.FortyGigabitEthernet.Auto.Qos.Classify)), ("trust", ("trust", Native.Interface.FortyGigabitEthernet.Auto.Qos.Trust)), ("video", ("video", Native.Interface.FortyGigabitEthernet.Auto.Qos.Video)), ("voip", ("voip", Native.Interface.FortyGigabitEthernet.Auto.Qos.Voip))])
                        self._leafs = OrderedDict()

                        self.classify = None
                        self._children_name_map["classify"] = "classify"

                        self.trust = None
                        self._children_name_map["trust"] = "trust"

                        self.video = Native.Interface.FortyGigabitEthernet.Auto.Qos.Video()
                        self.video.parent = self
                        self._children_name_map["video"] = "video"

                        self.voip = None
                        self._children_name_map["voip"] = "voip"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Auto.Qos, [], name, value)


                    class Classify(Entity):
                        """
                        Configure classification for untrusted devices
                        
                        .. attribute:: police
                        
                        	Configure QoS policing for untrusted devices
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Auto.Qos.Classify, self).__init__()

                            self.yang_name = "classify"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('police', (YLeaf(YType.empty, 'police'), ['Empty'])),
                            ])
                            self.police = None
                            self._segment_path = lambda: "classify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Auto.Qos.Classify, [u'police'], name, value)


                    class Trust(Entity):
                        """
                        Trust the DSCP/CoS marking
                        
                        .. attribute:: cos
                        
                        	Trust the CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	Trust the DSCP marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Auto.Qos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cos', (YLeaf(YType.empty, 'cos'), ['Empty'])),
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ])
                            self.cos = None
                            self.dscp = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Auto.Qos.Trust, [u'cos', u'dscp'], name, value)


                    class Video(Entity):
                        """
                        Configure AutoQoS for video devices
                        
                        .. attribute:: cts
                        
                        	Trust the QoS marking of the Cisco Telepresence System
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ip_camera
                        
                        	Trust the QoS marking of the Ip Video Surveillance camera
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: media_player
                        
                        	Trust the Qos marking of the Cisco Media Player
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Auto.Qos.Video, self).__init__()

                            self.yang_name = "video"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('cts', (YLeaf(YType.empty, 'cts'), ['Empty'])),
                                ('ip_camera', (YLeaf(YType.empty, 'ip-camera'), ['Empty'])),
                                ('media_player', (YLeaf(YType.empty, 'media-player'), ['Empty'])),
                            ])
                            self.cts = None
                            self.ip_camera = None
                            self.media_player = None
                            self._segment_path = lambda: "video"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Auto.Qos.Video, [u'cts', u'ip_camera', u'media_player'], name, value)


                    class Voip(Entity):
                        """
                        Configure AutoQoS for VoIP
                        
                        .. attribute:: cisco_phone
                        
                        	Trust the QoS marking of Cisco IP Phone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cisco_softphone
                        
                        	Trust the QoS marking of Cisco IP SoftPhone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trust
                        
                        	Trust the DSCP/CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Auto.Qos.Voip, self).__init__()

                            self.yang_name = "voip"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cisco_phone', (YLeaf(YType.empty, 'cisco-phone'), ['Empty'])),
                                ('cisco_softphone', (YLeaf(YType.empty, 'cisco-softphone'), ['Empty'])),
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.cisco_phone = None
                            self.cisco_softphone = None
                            self.trust = None
                            self._segment_path = lambda: "voip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Auto.Qos.Voip, [u'cisco_phone', u'cisco_softphone', u'trust'], name, value)


            class Datalink(Entity):
                """
                Interface Datalink commands
                
                .. attribute:: flow
                
                	Interface Flow configuration subcommands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Datalink.Flow>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Datalink, self).__init__()

                    self.yang_name = "datalink"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flow", ("flow", Native.Interface.FortyGigabitEthernet.Datalink.Flow))])
                    self._leafs = OrderedDict()

                    self.flow = Native.Interface.FortyGigabitEthernet.Datalink.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:datalink"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Datalink, [], name, value)


                class Flow(Entity):
                    """
                    Interface Flow configuration subcommands
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Datalink.Flow.Monitor>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Datalink.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "datalink"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FortyGigabitEthernet.Datalink.Flow.Monitor))])
                        self._leafs = OrderedDict()

                        self.monitor = None
                        self._children_name_map["monitor"] = "monitor"
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Datalink.Flow, [], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: user_defined_flow
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: input_output
                        
                        	Apply Flow Monitor on input/output traffic
                        	**type**\:  :py:class:`InputOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Datalink.Flow.Monitor.InputOutput>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Datalink.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('user_defined_flow', (YLeaf(YType.str, 'User-defined-flow'), ['str'])),
                                ('input_output', (YLeaf(YType.enumeration, 'input-output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Datalink.Flow.Monitor.InputOutput')])),
                            ])
                            self.user_defined_flow = None
                            self.input_output = None
                            self._segment_path = lambda: "monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Datalink.Flow.Monitor, [u'user_defined_flow', u'input_output'], name, value)

                        class InputOutput(Enum):
                            """
                            InputOutput (Enum Class)

                            Apply Flow Monitor on input/output traffic

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



            class Energywise(Entity):
                """
                EnergyWise interface configurations
                
                .. attribute:: activitycheck
                
                	Apply an activity check before turning off power    to this PoE port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: level
                
                	Set the EnergyWise level of this interface  or attached entity
                	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Energywise.Level>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Energywise, self).__init__()

                    self.yang_name = "energywise"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Interface.FortyGigabitEthernet.Energywise.Level))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('activitycheck', (YLeaf(YType.empty, 'activitycheck'), ['Empty'])),
                    ])
                    self.activitycheck = None

                    self.level = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:energywise"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Energywise, [u'activitycheck'], name, value)


                class Level(Entity):
                    """
                    Set the EnergyWise level of this interface 
                    or attached entity
                    
                    .. attribute:: range  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..10
                    
                    .. attribute:: recurrence
                    
                    	Specify that this level setting should  recur at the specified time
                    	**type**\:  :py:class:`Recurrence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Energywise.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "energywise"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("recurrence", ("recurrence", Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                        ])
                        self.range = None

                        self.recurrence = Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence()
                        self.recurrence.parent = self
                        self._children_name_map["recurrence"] = "recurrence"
                        self._segment_path = lambda: "level" + "[range='" + str(self.range) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Energywise.Level, [u'range'], name, value)


                    class Recurrence(Entity):
                        """
                        Specify that this level setting should 
                        recur at the specified time
                        
                        .. attribute:: importance
                        
                        	Specify the importance at which the event  should be sent when it recurs
                        	**type**\: list of  		 :py:class:`Importance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence.Importance>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence, self).__init__()

                            self.yang_name = "recurrence"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("importance", ("importance", Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence.Importance))])
                            self._leafs = OrderedDict()

                            self.importance = YList(self)
                            self._segment_path = lambda: "recurrence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence, [], name, value)


                        class Importance(Entity):
                            """
                            Specify the importance at which the event 
                            should be sent when it recurs
                            
                            .. attribute:: range  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: at
                            
                            	Specify the time(s) this level setting should occur
                            	**type**\:  :py:class:`At <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence.Importance.At>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence.Importance, self).__init__()

                                self.yang_name = "importance"
                                self.yang_parent_name = "recurrence"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("at", ("at", Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence.Importance.At))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.at = Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence.Importance.At()
                                self.at.parent = self
                                self._children_name_map["at"] = "at"
                                self._segment_path = lambda: "importance" + "[range='" + str(self.range) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence.Importance, [u'range'], name, value)


                            class At(Entity):
                                """
                                Specify the time(s) this level setting should occur
                                
                                .. attribute:: minute
                                
                                	cron format of minute(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..59
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: hour
                                
                                	cron format of hour(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..23
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: day
                                
                                	cron format of day(s) of month
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..31
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: month
                                
                                	cron format of month(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..12
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: weekday
                                
                                	cron format of weekday(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..7
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence.Importance.At, self).__init__()

                                    self.yang_name = "at"
                                    self.yang_parent_name = "importance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minute', (YLeaf(YType.str, 'minute'), ['int','str'])),
                                        ('hour', (YLeaf(YType.str, 'hour'), ['int','str'])),
                                        ('day', (YLeaf(YType.str, 'day'), ['int','str'])),
                                        ('month', (YLeaf(YType.str, 'month'), ['int','str'])),
                                        ('weekday', (YLeaf(YType.str, 'weekday'), ['int','str'])),
                                    ])
                                    self.minute = None
                                    self.hour = None
                                    self.day = None
                                    self.month = None
                                    self.weekday = None
                                    self._segment_path = lambda: "at"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Energywise.Level.Recurrence.Importance.At, [u'minute', u'hour', u'day', u'month', u'weekday'], name, value)


            class Location(Entity):
                """
                Interface location information
                
                .. attribute:: civic_location_id
                
                	Civic location information
                	**type**\:  :py:class:`CivicLocationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Location.CivicLocationId>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Location, self).__init__()

                    self.yang_name = "location"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("civic-location-id", ("civic_location_id", Native.Interface.FortyGigabitEthernet.Location.CivicLocationId))])
                    self._leafs = OrderedDict()

                    self.civic_location_id = Native.Interface.FortyGigabitEthernet.Location.CivicLocationId()
                    self.civic_location_id.parent = self
                    self._children_name_map["civic_location_id"] = "civic-location-id"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:location"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Location, [], name, value)


                class CivicLocationId(Entity):
                    """
                    Civic location information
                    
                    .. attribute:: location_identifier
                    
                    	civic location identifier string
                    	**type**\: str
                    
                    .. attribute:: host
                    
                    	Globally defined host location identifer
                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Location.CivicLocationId.Host>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: none
                    
                    	No globally defined location identifer
                    	**type**\:  :py:class:`Y_None <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Location.CivicLocationId.Y_None>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Location.CivicLocationId, self).__init__()

                        self.yang_name = "civic-location-id"
                        self.yang_parent_name = "location"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("host", ("host", Native.Interface.FortyGigabitEthernet.Location.CivicLocationId.Host)), ("none", ("none", Native.Interface.FortyGigabitEthernet.Location.CivicLocationId.Y_None))])
                        self._leafs = OrderedDict([
                            ('location_identifier', (YLeaf(YType.str, 'location-identifier'), ['str'])),
                        ])
                        self.location_identifier = None

                        self.host = None
                        self._children_name_map["host"] = "host"

                        self.none = None
                        self._children_name_map["none"] = "none"
                        self._segment_path = lambda: "civic-location-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Location.CivicLocationId, [u'location_identifier'], name, value)


                    class Host(Entity):
                        """
                        Globally defined host location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Location.CivicLocationId.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "host"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Location.CivicLocationId.Host, [u'port_location'], name, value)


                    class Y_None(Entity):
                        """
                        No globally defined location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Location.CivicLocationId.Y_None, self).__init__()

                            self.yang_name = "none"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Location.CivicLocationId.Y_None, [u'port_location'], name, value)


            class Mac(Entity):
                """
                MAC interface commands
                
                .. attribute:: access_group
                
                	MAC access\-group configuration commands
                	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mac.AccessGroup>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Mac, self).__init__()

                    self.yang_name = "mac"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.FortyGigabitEthernet.Mac.AccessGroup))])
                    self._leafs = OrderedDict()

                    self.access_group = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:mac"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mac, [], name, value)


                class AccessGroup(Entity):
                    """
                    MAC access\-group configuration commands
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mac.AccessGroup.Direction>`
                    
                    .. attribute:: acl_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Mac.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "mac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Mac.AccessGroup.Direction')])),
                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                        ])
                        self.direction = None
                        self.acl_name = None
                        self._segment_path = lambda: "access-group" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mac.AccessGroup, [u'direction', u'acl_name'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Macro(Entity):
                """
                Command macro
                
                .. attribute:: description
                
                	Macro description for this interface
                	**type**\: str
                
                .. attribute:: auto
                
                	Smartport interface macro configurations
                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Macro.Auto>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Macro, self).__init__()

                    self.yang_name = "macro"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.FortyGigabitEthernet.Macro.Auto))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.auto = Native.Interface.FortyGigabitEthernet.Macro.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "auto"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macro"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Macro, [u'description'], name, value)


                class Auto(Entity):
                    """
                    Smartport interface macro configurations
                    
                    .. attribute:: processing
                    
                    	Enable smartport macro auto execution on this interface
                    	**type**\: bool
                    
                    .. attribute:: port
                    
                    	Provide interface specific configuration for macro processing
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Macro.Auto.Port>`
                    
                    .. attribute:: control
                    
                    	Control macro auto execution
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Macro.Auto.Control>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Macro.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "macro"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port", ("port", Native.Interface.FortyGigabitEthernet.Macro.Auto.Port)), ("control", ("control", Native.Interface.FortyGigabitEthernet.Macro.Auto.Control))])
                        self._leafs = OrderedDict([
                            ('processing', (YLeaf(YType.boolean, 'processing'), ['bool'])),
                        ])
                        self.processing = None

                        self.port = Native.Interface.FortyGigabitEthernet.Macro.Auto.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.control = Native.Interface.FortyGigabitEthernet.Macro.Auto.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"
                        self._segment_path = lambda: "auto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Macro.Auto, [u'processing'], name, value)


                    class Port(Entity):
                        """
                        Provide interface specific configuration for macro processing
                        
                        .. attribute:: sticky
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Macro.Auto.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                            ])
                            self.sticky = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Macro.Auto.Port, [u'sticky'], name, value)


                    class Control(Entity):
                        """
                        Control macro auto execution
                        
                        .. attribute:: device
                        
                        	Enable macro auto execution for devices
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Macro.Auto.Control.Device>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Macro.Auto.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("device", ("device", Native.Interface.FortyGigabitEthernet.Macro.Auto.Control.Device))])
                            self._leafs = OrderedDict()

                            self.device = Native.Interface.FortyGigabitEthernet.Macro.Auto.Control.Device()
                            self.device.parent = self
                            self._children_name_map["device"] = "device"
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Macro.Auto.Control, [], name, value)


                        class Device(Entity):
                            """
                            Enable macro auto execution for devices
                            
                            .. attribute:: phone
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Macro.Auto.Control.Device, self).__init__()

                                self.yang_name = "device"
                                self.yang_parent_name = "control"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('phone', (YLeaf(YType.empty, 'phone'), ['Empty'])),
                                ])
                                self.phone = None
                                self._segment_path = lambda: "device"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Macro.Auto.Control.Device, [u'phone'], name, value)


            class DualActive(Entity):
                """
                
                
                .. attribute:: fast_hello
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.DualActive, self).__init__()

                    self.yang_name = "dual-active"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fast_hello', (YLeaf(YType.empty, 'fast-hello'), ['Empty'])),
                    ])
                    self.fast_hello = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:dual-active"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.DualActive, [u'fast_hello'], name, value)


            class LoadBalancing(Entity):
                """
                Etherchannel Load\-Balancing
                
                .. attribute:: flow
                
                	Based on the traffic flows identified by the packet headers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Based on the VLAN to member links manual configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.LoadBalancing, self).__init__()

                    self.yang_name = "load-balancing"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('flow', (YLeaf(YType.empty, 'flow'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.flow = None
                    self.vlan = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:load-balancing"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.LoadBalancing, [u'flow', u'vlan'], name, value)


            class VlanRange(Entity):
                """
                
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4096
                
                		**type**\: str
                
                .. attribute:: service_policy
                
                	Configure QoS Service Policy
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.VlanRange.ServicePolicy>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.VlanRange, self).__init__()

                    self.yang_name = "vlan-range"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.FortyGigabitEthernet.VlanRange.ServicePolicy))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                    ])
                    self.id = None

                    self.service_policy = Native.Interface.FortyGigabitEthernet.VlanRange.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:vlan-range" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.VlanRange, [u'id'], name, value)


                class ServicePolicy(Entity):
                    """
                    Configure QoS Service Policy
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.VlanRange.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "vlan-range"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.VlanRange.ServicePolicy, [u'input', u'output'], name, value)


            class Switch(Entity):
                """
                
                
                .. attribute:: virtual
                
                	
                	**type**\:  :py:class:`Virtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Switch.Virtual>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("virtual", ("virtual", Native.Interface.FortyGigabitEthernet.Switch.Virtual))])
                    self._leafs = OrderedDict()

                    self.virtual = Native.Interface.FortyGigabitEthernet.Switch.Virtual()
                    self.virtual.parent = self
                    self._children_name_map["virtual"] = "virtual"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:switch"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switch, [], name, value)


                class Virtual(Entity):
                    """
                    
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Switch.Virtual, self).__init__()

                        self.yang_name = "virtual"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ])
                        self.link = None
                        self._segment_path = lambda: "virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Switch.Virtual, [u'link'], name, value)


            class SrrQueue(Entity):
                """
                
                
                .. attribute:: bandwidth
                
                	
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.SrrQueue, self).__init__()

                    self.yang_name = "srr-queue"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth))])
                    self._leafs = OrderedDict()

                    self.bandwidth = Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:srr-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.SrrQueue, [], name, value)


                class Bandwidth(Entity):
                    """
                    
                    
                    .. attribute:: shape
                    
                    	
                    	**type**\:  :py:class:`Shape <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth.Shape>`
                    
                    .. attribute:: share
                    
                    	
                    	**type**\:  :py:class:`Share <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth.Share>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "srr-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("shape", ("shape", Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth.Shape)), ("share", ("share", Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth.Share))])
                        self._leafs = OrderedDict()

                        self.shape = Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"

                        self.share = Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth.Share()
                        self.share.parent = self
                        self._children_name_map["share"] = "share"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth, [], name, value)


                    class Shape(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint16, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint16, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint16, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint16, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "shape"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth.Shape, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


                    class Share(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth.Share, self).__init__()

                            self.yang_name = "share"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint8, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint8, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint8, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint8, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "share"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.SrrQueue.Bandwidth.Share, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


            class CiscoIOSXESwitchMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection>`
                    
                    .. attribute:: network_link
                    
                    	Enable macsec on switch connected interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('network_link', (YLeaf(YType.empty, 'network-link'), ['Empty'])),
                        ])
                        self.network_link = None

                        self.replay_protection = Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec, [u'network_link'], name, value)


                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, [u'window_size'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.FortyGigabitEthernet.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.FortyGigabitEthernet.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.FortyGigabitEthernet.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.FortyGigabitEthernet.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.FortyGigabitEthernet.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.FortyGigabitEthernet.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.FortyGigabitEthernet.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.FortyGigabitEthernet.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class Mka(Entity):
                """
                MACsec Key Agreement (MKA) interface configuration
                
                .. attribute:: policy
                
                	Apply MKA Policy
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mka.Policy>`
                
                .. attribute:: pre_shared_key
                
                	Configure MKA Pre\-Shared\-Key
                	**type**\:  :py:class:`PreSharedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mka.PreSharedKey>`
                
                

                """

                _prefix = 'ios-mka'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Mka, self).__init__()

                    self.yang_name = "mka"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.FortyGigabitEthernet.Mka.Policy)), ("pre-shared-key", ("pre_shared_key", Native.Interface.FortyGigabitEthernet.Mka.PreSharedKey))])
                    self._leafs = OrderedDict()

                    self.policy = Native.Interface.FortyGigabitEthernet.Mka.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.pre_shared_key = Native.Interface.FortyGigabitEthernet.Mka.PreSharedKey()
                    self.pre_shared_key.parent = self
                    self._children_name_map["pre_shared_key"] = "pre-shared-key"
                    self._segment_path = lambda: "Cisco-IOS-XE-mka:mka"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mka, [], name, value)


                class Policy(Entity):
                    """
                    Apply MKA Policy
                    
                    .. attribute:: name
                    
                    	MKA Policy NAME
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Mka.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mka.Policy, ['name'], name, value)


                class PreSharedKey(Entity):
                    """
                    Configure MKA Pre\-Shared\-Key
                    
                    .. attribute:: key_chain
                    
                    	Configure the key\-chain name
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mka.PreSharedKey.KeyChain>`
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Mka.PreSharedKey, self).__init__()

                        self.yang_name = "pre-shared-key"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.FortyGigabitEthernet.Mka.PreSharedKey.KeyChain))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.FortyGigabitEthernet.Mka.PreSharedKey.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"
                        self._segment_path = lambda: "pre-shared-key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mka.PreSharedKey, [], name, value)


                    class KeyChain(Entity):
                        """
                        Configure the key\-chain name
                        
                        .. attribute:: name
                        
                        	Name of key\-chain to be used to get keys
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mka'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Mka.PreSharedKey.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "pre-shared-key"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mka.PreSharedKey.KeyChain, ['name'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Utd, ['enable'], name, value)


            class Xconnect(Entity):
                """
                Xconnect commands
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: vcid
                
                	
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: encapsulation
                
                	Data encapsulation method
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Xconnect.Encapsulation>`
                
                .. attribute:: manual
                
                	Manually configure L2TP session parameters
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sequence
                
                	Configure sequencing options for xconnect
                	**type**\:  :py:class:`Sequence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Xconnect.Sequence>`
                
                .. attribute:: pw_class
                
                	Pseudowire\-class to use for encapsulation and protocol configuration
                	**type**\: str
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Xconnect.Encapsulation')])),
                        ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                        ('sequence', (YLeaf(YType.enumeration, 'sequence'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Xconnect.Sequence')])),
                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                    ])
                    self.address = None
                    self.vcid = None
                    self.encapsulation = None
                    self.manual = None
                    self.sequence = None
                    self.pw_class = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'sequence', 'pw_class'], name, value)

                class Encapsulation(Enum):
                    """
                    Encapsulation (Enum Class)

                    Data encapsulation method

                    .. data:: mpls = 0

                    .. data:: l2tpv3 = 1

                    """

                    mpls = Enum.YLeaf(0, "mpls")

                    l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                class Sequence(Enum):
                    """
                    Sequence (Enum Class)

                    Configure sequencing options for xconnect

                    .. data:: both = 0

                    .. data:: receive = 1

                    .. data:: transmit = 2

                    """

                    both = Enum.YLeaf(0, "both")

                    receive = Enum.YLeaf(1, "receive")

                    transmit = Enum.YLeaf(2, "transmit")



            class Evpn(Entity):
                """
                
                
                .. attribute:: ethernet_segment
                
                	Ethernet segment local discriminator value
                	**type**\: list of  		 :py:class:`EthernetSegment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Evpn, self).__init__()

                    self.yang_name = "evpn"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet-segment", ("ethernet_segment", Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment))])
                    self._leafs = OrderedDict()

                    self.ethernet_segment = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:evpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Evpn, [], name, value)


                class EthernetSegment(Entity):
                    """
                    Ethernet segment local discriminator value
                    
                    .. attribute:: es_value  (key)
                    
                    	Ethernet segment local discriminator value
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: df_election
                    
                    	Designated forwarder election parameters
                    	**type**\:  :py:class:`DfElection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment.DfElection>`
                    
                    .. attribute:: redundancy
                    
                    	Multi\-homing redundancy parameters
                    	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment.Redundancy>`
                    
                    .. attribute:: sytem_mac
                    
                    	System MAC address for generating the Ethernet Segment ID
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment, self).__init__()

                        self.yang_name = "ethernet-segment"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['es_value']
                        self._child_classes = OrderedDict([("df-election", ("df_election", Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment.DfElection)), ("redundancy", ("redundancy", Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment.Redundancy))])
                        self._leafs = OrderedDict([
                            ('es_value', (YLeaf(YType.uint16, 'es-value'), ['int'])),
                            ('sytem_mac', (YLeaf(YType.str, 'sytem-mac'), ['str'])),
                        ])
                        self.es_value = None
                        self.sytem_mac = None

                        self.df_election = Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment.DfElection()
                        self.df_election.parent = self
                        self._children_name_map["df_election"] = "df-election"

                        self.redundancy = Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                        self._segment_path = lambda: "ethernet-segment" + "[es-value='" + str(self.es_value) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment, ['es_value', 'sytem_mac'], name, value)


                    class DfElection(Entity):
                        """
                        Designated forwarder election parameters
                        
                        .. attribute:: wait_time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment.DfElection, self).__init__()

                            self.yang_name = "df-election"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wait_time', (YLeaf(YType.uint8, 'wait-time'), ['int'])),
                            ])
                            self.wait_time = None
                            self._segment_path = lambda: "df-election"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment.DfElection, ['wait_time'], name, value)


                    class Redundancy(Entity):
                        """
                        Multi\-homing redundancy parameters
                        
                        .. attribute:: all_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: single_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment.Redundancy, self).__init__()

                            self.yang_name = "redundancy"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all_active', (YLeaf(YType.empty, 'all-active'), ['Empty'])),
                                ('single_active', (YLeaf(YType.empty, 'single-active'), ['Empty'])),
                            ])
                            self.all_active = None
                            self.single_active = None
                            self._segment_path = lambda: "redundancy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Evpn.EthernetSegment.Redundancy, ['all_active', 'single_active'], name, value)


            class FabricDomain(Entity):
                """
                Fabric\-domain interface command
                
                .. attribute:: iwan_fabric
                
                	
                	**type**\:  :py:class:`IwanFabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.FabricDomain.IwanFabric>`
                
                

                """

                _prefix = 'ios-iwanfabric'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.FabricDomain, self).__init__()

                    self.yang_name = "fabric-domain"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("iwan-fabric", ("iwan_fabric", Native.Interface.FortyGigabitEthernet.FabricDomain.IwanFabric))])
                    self._leafs = OrderedDict()

                    self.iwan_fabric = Native.Interface.FortyGigabitEthernet.FabricDomain.IwanFabric()
                    self.iwan_fabric.parent = self
                    self._children_name_map["iwan_fabric"] = "iwan-fabric"
                    self._segment_path = lambda: "Cisco-IOS-XE-iwanfabric:fabric-domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.FabricDomain, [], name, value)


                class IwanFabric(Entity):
                    """
                    
                    
                    .. attribute:: word
                    
                    	
                    	**type**\: list of  		 :py:class:`Word <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.FabricDomain.IwanFabric.Word>`
                    
                    

                    """

                    _prefix = 'ios-iwanfabric'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.FabricDomain.IwanFabric, self).__init__()

                        self.yang_name = "iwan-fabric"
                        self.yang_parent_name = "fabric-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("word", ("word", Native.Interface.FortyGigabitEthernet.FabricDomain.IwanFabric.Word))])
                        self._leafs = OrderedDict()

                        self.word = YList(self)
                        self._segment_path = lambda: "iwan-fabric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.FabricDomain.IwanFabric, [], name, value)


                    class Word(Entity):
                        """
                        
                        
                        .. attribute:: word  (key)
                        
                        	Path name
                        	**type**\: str
                        
                        .. attribute:: interface_id
                        
                        	Specify the interface\-id value
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-iwanfabric'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.FabricDomain.IwanFabric.Word, self).__init__()

                            self.yang_name = "word"
                            self.yang_parent_name = "iwan-fabric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                            ])
                            self.word = None
                            self.interface_id = None
                            self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.FabricDomain.IwanFabric.Word, ['word', 'interface_id'], name, value)


            class Mvrp(Entity):
                """
                
                
                .. attribute:: mvrp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: registration
                
                	
                	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mvrp.Registration>`
                
                .. attribute:: timer
                
                	
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mvrp.Timer>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mvrp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Mvrp, self).__init__()

                    self.yang_name = "mvrp"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("registration", ("registration", Native.Interface.FortyGigabitEthernet.Mvrp.Registration)), ("timer", ("timer", Native.Interface.FortyGigabitEthernet.Mvrp.Timer))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mvrp', (YLeaf(YType.empty, 'mvrp'), ['Empty'])),
                    ])
                    self.mvrp = None

                    self.registration = Native.Interface.FortyGigabitEthernet.Mvrp.Registration()
                    self.registration.parent = self
                    self._children_name_map["registration"] = "registration"

                    self.timer = Native.Interface.FortyGigabitEthernet.Mvrp.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-mvrp:mvrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mvrp, ['mvrp'], name, value)


                class Registration(Entity):
                    """
                    
                    
                    .. attribute:: fixed
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: forbidden
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: normal
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Mvrp.Registration, self).__init__()

                        self.yang_name = "registration"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fixed', (YLeaf(YType.empty, 'fixed'), ['Empty'])),
                            ('forbidden', (YLeaf(YType.empty, 'forbidden'), ['Empty'])),
                            ('normal', (YLeaf(YType.empty, 'normal'), ['Empty'])),
                        ])
                        self.fixed = None
                        self.forbidden = None
                        self.normal = None
                        self._segment_path = lambda: "registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mvrp.Registration, ['fixed', 'forbidden', 'normal'], name, value)


                class Timer(Entity):
                    """
                    
                    
                    .. attribute:: join
                    
                    	
                    	**type**\:  :py:class:`Join <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mvrp.Timer.Join>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave
                    
                    	
                    	**type**\:  :py:class:`Leave <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mvrp.Timer.Leave>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave_all
                    
                    	
                    	**type**\:  :py:class:`LeaveAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Mvrp.Timer.LeaveAll>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: periodic
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Mvrp.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("join", ("join", Native.Interface.FortyGigabitEthernet.Mvrp.Timer.Join)), ("leave", ("leave", Native.Interface.FortyGigabitEthernet.Mvrp.Timer.Leave)), ("leave-all", ("leave_all", Native.Interface.FortyGigabitEthernet.Mvrp.Timer.LeaveAll))])
                        self._leafs = OrderedDict([
                            ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ])
                        self.periodic = None

                        self.join = None
                        self._children_name_map["join"] = "join"

                        self.leave = None
                        self._children_name_map["leave"] = "leave"

                        self.leave_all = None
                        self._children_name_map["leave_all"] = "leave-all"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mvrp.Timer, ['periodic'], name, value)


                    class Join(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 20..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Mvrp.Timer.Join, self).__init__()

                            self.yang_name = "join"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "join"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mvrp.Timer.Join, ['y_range'], name, value)


                    class Leave(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Mvrp.Timer.Leave, self).__init__()

                            self.yang_name = "leave"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mvrp.Timer.Leave, ['y_range'], name, value)


                    class LeaveAll(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1000..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Mvrp.Timer.LeaveAll, self).__init__()

                            self.yang_name = "leave-all"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave-all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mvrp.Timer.LeaveAll, ['y_range'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.FortyGigabitEthernet.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.FortyGigabitEthernet.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.FortyGigabitEthernet.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.FortyGigabitEthernet.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.FortyGigabitEthernet.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.FortyGigabitEthernet.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.FortyGigabitEthernet.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.FortyGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Power(Entity):
                """
                
                
                .. attribute:: inline
                
                	
                	**type**\:  :py:class:`Inline <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Power.Inline>`
                
                

                """

                _prefix = 'ios-power'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Power, self).__init__()

                    self.yang_name = "power"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("inline", ("inline", Native.Interface.FortyGigabitEthernet.Power.Inline))])
                    self._leafs = OrderedDict()

                    self.inline = Native.Interface.FortyGigabitEthernet.Power.Inline()
                    self.inline.parent = self
                    self._children_name_map["inline"] = "inline"
                    self._segment_path = lambda: "Cisco-IOS-XE-power:power"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Power, [], name, value)


                class Inline(Entity):
                    """
                    
                    
                    .. attribute:: consumption
                    
                    	
                    	**type**\: int
                    
                    	**range:** 4000..15400
                    
                    .. attribute:: never
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: auto
                    
                    	Automatically detect and power inline devices
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Power.Inline.Auto>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: four_pair
                    
                    	Four\-pair PoE power
                    	**type**\:  :py:class:`FourPair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Power.Inline.FourPair>`
                    
                    .. attribute:: police
                    
                    	Police the power drawn on the port
                    	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Power.Inline.Police>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: port
                    
                    	Configure Port Power Level
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Power.Inline.Port>`
                    
                    .. attribute:: static
                    
                    	High priority inline power interface
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Power.Inline.Static>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-power'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Power.Inline, self).__init__()

                        self.yang_name = "inline"
                        self.yang_parent_name = "power"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.FortyGigabitEthernet.Power.Inline.Auto)), ("four-pair", ("four_pair", Native.Interface.FortyGigabitEthernet.Power.Inline.FourPair)), ("police", ("police", Native.Interface.FortyGigabitEthernet.Power.Inline.Police)), ("port", ("port", Native.Interface.FortyGigabitEthernet.Power.Inline.Port)), ("static", ("static", Native.Interface.FortyGigabitEthernet.Power.Inline.Static))])
                        self._leafs = OrderedDict([
                            ('consumption', (YLeaf(YType.uint16, 'consumption'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.consumption = None
                        self.never = None

                        self.auto = None
                        self._children_name_map["auto"] = "auto"

                        self.four_pair = Native.Interface.FortyGigabitEthernet.Power.Inline.FourPair()
                        self.four_pair.parent = self
                        self._children_name_map["four_pair"] = "four-pair"

                        self.police = None
                        self._children_name_map["police"] = "police"

                        self.port = Native.Interface.FortyGigabitEthernet.Power.Inline.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.static = None
                        self._children_name_map["static"] = "static"
                        self._segment_path = lambda: "inline"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Power.Inline, ['consumption', 'never'], name, value)


                    class Auto(Entity):
                        """
                        Automatically detect and power inline devices
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Power.Inline.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "auto"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Power.Inline.Auto, ['max'], name, value)


                    class FourPair(Entity):
                        """
                        Four\-pair PoE power
                        
                        .. attribute:: forced
                        
                        	Enable Four\-pair PoE without L2 negotiation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Power.Inline.FourPair, self).__init__()

                            self.yang_name = "four-pair"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forced', (YLeaf(YType.empty, 'forced'), ['Empty'])),
                            ])
                            self.forced = None
                            self._segment_path = lambda: "four-pair"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Power.Inline.FourPair, ['forced'], name, value)


                    class Police(Entity):
                        """
                        Police the power drawn on the port
                        
                        .. attribute:: action
                        
                        	Action to be taken when power is overdrawn on the port
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Power.Inline.Police.Action>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Power.Inline.Police, self).__init__()

                            self.yang_name = "police"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.FortyGigabitEthernet.Power.Inline.Police.Action))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.FortyGigabitEthernet.Power.Inline.Police.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "police"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Power.Inline.Police, [], name, value)


                        class Action(Entity):
                            """
                            Action to be taken when power is overdrawn on the port
                            
                            .. attribute:: errdisable
                            
                            	Error\-disable the port when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log a message when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-power'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Power.Inline.Police.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "police"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('errdisable', (YLeaf(YType.empty, 'errdisable'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ])
                                self.errdisable = None
                                self.log = None
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Power.Inline.Police.Action, ['errdisable', 'log'], name, value)


                    class Port(Entity):
                        """
                        Configure Port Power Level
                        
                        .. attribute:: poe_ha
                        
                        	Apply poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: perpetual_poe_ha
                        
                        	Apply perpetual\-poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: two_event
                        
                        	Enable 2\-event classification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Power.Inline.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('poe_ha', (YLeaf(YType.empty, 'poe-ha'), ['Empty'])),
                                ('perpetual_poe_ha', (YLeaf(YType.empty, 'perpetual-poe-ha'), ['Empty'])),
                                ('two_event', (YLeaf(YType.empty, 'two-event'), ['Empty'])),
                            ])
                            self.poe_ha = None
                            self.perpetual_poe_ha = None
                            self.two_event = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Power.Inline.Port, ['poe_ha', 'perpetual_poe_ha', 'two_event'], name, value)


                    class Static(Entity):
                        """
                        High priority inline power interface
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Power.Inline.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "static"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Power.Inline.Static, ['max'], name, value)


            class Cdp(Entity):
                """
                CDP interface subcommands
                
                .. attribute:: enable
                
                	Enable CDP on interface
                	**type**\: bool
                
                .. attribute:: tlv
                
                	Enable exchange of specific tlv information
                	**type**\:  :py:class:`Tlv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cdp.Tlv>`
                
                

                """

                _prefix = 'ios-cdp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Cdp, self).__init__()

                    self.yang_name = "cdp"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tlv", ("tlv", Native.Interface.FortyGigabitEthernet.Cdp.Tlv))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                    ])
                    self.enable = None

                    self.tlv = Native.Interface.FortyGigabitEthernet.Cdp.Tlv()
                    self.tlv.parent = self
                    self._children_name_map["tlv"] = "tlv"
                    self._segment_path = lambda: "Cisco-IOS-XE-cdp:cdp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cdp, ['enable'], name, value)


                class Tlv(Entity):
                    """
                    Enable exchange of specific tlv information
                    
                    .. attribute:: app
                    
                    	Enable/Configure Application TLV
                    	**type**\:  :py:class:`App <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cdp.Tlv.App>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: server_location
                    
                    	Enable CDP location server on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	Exchange location information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cdp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Cdp.Tlv, self).__init__()

                        self.yang_name = "tlv"
                        self.yang_parent_name = "cdp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("app", ("app", Native.Interface.FortyGigabitEthernet.Cdp.Tlv.App))])
                        self._leafs = OrderedDict([
                            ('server_location', (YLeaf(YType.empty, 'server-location'), ['Empty'])),
                            ('location', (YLeaf(YType.empty, 'location'), ['Empty'])),
                        ])
                        self.server_location = None
                        self.location = None

                        self.app = None
                        self._children_name_map["app"] = "app"
                        self._segment_path = lambda: "tlv"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cdp.Tlv, ['server_location', 'location'], name, value)


                    class App(Entity):
                        """
                        Enable/Configure Application TLV
                        
                        .. attribute:: tlvtype
                        
                        	Configure APP TLV
                        	**type**\: int
                        
                        	**range:** 1001..65535
                        
                        .. attribute:: value
                        
                        	Configure App TLV Value information
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cdp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Cdp.Tlv.App, self).__init__()

                            self.yang_name = "app"
                            self.yang_parent_name = "tlv"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tlvtype', (YLeaf(YType.uint16, 'tlvtype'), ['int'])),
                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                            ])
                            self.tlvtype = None
                            self.value = None
                            self._segment_path = lambda: "app"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cdp.Tlv.App, ['tlvtype', 'value'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.FortyGigabitEthernet.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.FortyGigabitEthernet.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.FortyGigabitEthernet.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.FortyGigabitEthernet.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class Authentication(Entity):
                """
                Auth Manager Interface Configuration Commands
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.ControlDirection>`
                
                .. attribute:: event
                
                	Set action for authentication events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event>`
                
                .. attribute:: fallback
                
                	Enable the Webauth fallback mechanism
                	**type**\: str
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.HostMode>`
                
                .. attribute:: open
                
                	Enable or Disable open access on this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: order
                
                	Add an authentication method to the order list
                	**type**\:  :py:class:`Order <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Order>`
                
                .. attribute:: priority
                
                	Add an authentication method to the priority list
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Priority>`
                
                .. attribute:: port_control
                
                	set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.PortControl>`
                
                .. attribute:: periodic
                
                	Enable or Disable Reauthentication for this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timer
                
                	Set authentication timer values
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Timer>`
                
                .. attribute:: violation
                
                	Configure action to take on security violations
                	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Violation>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FortyGigabitEthernet.Authentication.Event)), ("order", ("order", Native.Interface.FortyGigabitEthernet.Authentication.Order)), ("priority", ("priority", Native.Interface.FortyGigabitEthernet.Authentication.Priority)), ("timer", ("timer", Native.Interface.FortyGigabitEthernet.Authentication.Timer))])
                    self._leafs = OrderedDict([
                        ('control_direction', (YLeaf(YType.enumeration, 'control-direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Authentication.ControlDirection')])),
                        ('fallback', (YLeaf(YType.str, 'fallback'), ['str'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Authentication.HostMode')])),
                        ('open', (YLeaf(YType.empty, 'open'), ['Empty'])),
                        ('port_control', (YLeaf(YType.enumeration, 'port-control'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Authentication.PortControl')])),
                        ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Authentication.Violation')])),
                    ])
                    self.control_direction = None
                    self.fallback = None
                    self.host_mode = None
                    self.open = None
                    self.port_control = None
                    self.periodic = None
                    self.violation = None

                    self.event = Native.Interface.FortyGigabitEthernet.Authentication.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.order = Native.Interface.FortyGigabitEthernet.Authentication.Order()
                    self.order.parent = self
                    self._children_name_map["order"] = "order"

                    self.priority = Native.Interface.FortyGigabitEthernet.Authentication.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "priority"

                    self.timer = Native.Interface.FortyGigabitEthernet.Authentication.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:authentication"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication, ['control_direction', 'fallback', 'host_mode', 'open', 'port_control', 'periodic', 'violation'], name, value)

                class ControlDirection(Enum):
                    """
                    ControlDirection (Enum Class)

                    Set the control\-direction on the interface

                    .. data:: both = 0

                    .. data:: in_ = 1

                    """

                    both = Enum.YLeaf(0, "both")

                    in_ = Enum.YLeaf(1, "in")


                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")


                class PortControl(Enum):
                    """
                    PortControl (Enum Class)

                    set the port\-control value

                    .. data:: auto = 0

                    .. data:: force_authorized = 1

                    .. data:: force_unauthorized = 2

                    """

                    auto = Enum.YLeaf(0, "auto")

                    force_authorized = Enum.YLeaf(1, "force-authorized")

                    force_unauthorized = Enum.YLeaf(2, "force-unauthorized")


                class Violation(Enum):
                    """
                    Violation (Enum Class)

                    Configure action to take on security violations

                    .. data:: protect = 0

                    .. data:: replace = 1

                    .. data:: restrict = 2

                    .. data:: shutdown = 3

                    """

                    protect = Enum.YLeaf(0, "protect")

                    replace = Enum.YLeaf(1, "replace")

                    restrict = Enum.YLeaf(2, "restrict")

                    shutdown = Enum.YLeaf(3, "shutdown")



                class Event(Entity):
                    """
                    Set action for authentication events
                    
                    .. attribute:: server
                    
                    	Configure actions for AAA server events
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.Server>`
                    
                    .. attribute:: fail
                    
                    	Configure actions for AAA fail events
                    	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail>`
                    
                    .. attribute:: no_response
                    
                    	Configure actions for AAA no\-response events
                    	**type**\:  :py:class:`NoResponse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Authentication.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("server", ("server", Native.Interface.FortyGigabitEthernet.Authentication.Event.Server)), ("fail", ("fail", Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail)), ("no-response", ("no_response", Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse))])
                        self._leafs = OrderedDict()

                        self.server = Native.Interface.FortyGigabitEthernet.Authentication.Event.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.fail = Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail()
                        self.fail.parent = self
                        self._children_name_map["fail"] = "fail"

                        self.no_response = Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse()
                        self.no_response.parent = self
                        self._children_name_map["no_response"] = "no-response"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event, [], name, value)


                    class Server(Entity):
                        """
                        Configure actions for AAA server events
                        
                        .. attribute:: alive
                        
                        	Configure AAA server alive action
                        	**type**\:  :py:class:`Alive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Alive>`
                        
                        .. attribute:: dead
                        
                        	Configure AAA server dead action
                        	**type**\:  :py:class:`Dead <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("alive", ("alive", Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Alive)), ("dead", ("dead", Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead))])
                            self._leafs = OrderedDict()

                            self.alive = Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Alive()
                            self.alive.parent = self
                            self._children_name_map["alive"] = "alive"

                            self.dead = Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead()
                            self.dead.parent = self
                            self._children_name_map["dead"] = "dead"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server, [], name, value)


                        class Alive(Entity):
                            """
                            Configure AAA server alive action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Alive.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Alive, self).__init__()

                                self.yang_name = "alive"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Alive.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Alive.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "alive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Alive, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all authorized clients
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Alive.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "alive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reinitialize', (YLeaf(YType.empty, 'reinitialize'), ['Empty'])),
                                    ])
                                    self.reinitialize = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Alive.Action, ['reinitialize'], name, value)


                        class Dead(Entity):
                            """
                            Configure AAA server dead action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead, self).__init__()

                                self.yang_name = "dead"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dead"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: authorize
                                
                                	Authorize the port
                                	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all client on the port
                                	**type**\:  :py:class:`Reinitialize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dead"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize)), ("reinitialize", ("reinitialize", Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize))])
                                    self._leafs = OrderedDict()

                                    self.authorize = None
                                    self._children_name_map["authorize"] = "authorize"

                                    self.reinitialize = Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize()
                                    self.reinitialize.parent = self
                                    self._children_name_map["reinitialize"] = "reinitialize"
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action, [], name, value)


                                class Authorize(Entity):
                                    """
                                    Authorize the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: voice
                                    
                                    	Authorize the port for VOICE traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize, self).__init__()

                                        self.yang_name = "authorize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ('voice', (YLeaf(YType.empty, 'voice'), ['Empty'])),
                                        ])
                                        self.vlan = None
                                        self.voice = None
                                        self._segment_path = lambda: "authorize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action.Authorize, ['vlan', 'voice'], name, value)


                                class Reinitialize(Entity):
                                    """
                                    Reinitialize all client on the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, self).__init__()

                                        self.yang_name = "reinitialize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "reinitialize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.Server.Dead.Action.Reinitialize, ['vlan'], name, value)


                    class Fail(Entity):
                        """
                        Configure actions for AAA fail events
                        
                        .. attribute:: action
                        
                        	Required action for fail event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail, self).__init__()

                            self.yang_name = "fail"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "fail"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail, [], name, value)


                        class Action(Entity):
                            """
                            Required action for fail event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "fail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.Fail.Action.Authorize, ['vlan'], name, value)


                    class NoResponse(Entity):
                        """
                        Configure actions for AAA no\-response events
                        
                        .. attribute:: action
                        
                        	Required action for no\-response event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse, self).__init__()

                            self.yang_name = "no-response"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "no-response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse, [], name, value)


                        class Action(Entity):
                            """
                            Required action for no\-response event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "no-response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Event.NoResponse.Action.Authorize, ['vlan'], name, value)


                class Order(Entity):
                    """
                    Add an authentication method to the order list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Authentication.Order, self).__init__()

                        self.yang_name = "order"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "order"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Order, ['dot1x', 'mab', 'webauth'], name, value)


                class Priority(Entity):
                    """
                    Add an authentication method to the priority list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Authentication.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Priority, ['dot1x', 'mab', 'webauth'], name, value)


                class Timer(Entity):
                    """
                    Set authentication timer values
                    
                    .. attribute:: reauthenticate
                    
                    	Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                    	**type**\:  :py:class:`Reauthenticate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Timer.Reauthenticate>`
                    
                    .. attribute:: inactivity
                    
                    	Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                    	**type**\:  :py:class:`Inactivity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity>`
                    
                    .. attribute:: restart
                    
                    	Interval in seconds after which an attempt should be made toauthenticate an unauthorized port (default 60 sec)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Authentication.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reauthenticate", ("reauthenticate", Native.Interface.FortyGigabitEthernet.Authentication.Timer.Reauthenticate)), ("inactivity", ("inactivity", Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity))])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                        ])
                        self.restart = None

                        self.reauthenticate = Native.Interface.FortyGigabitEthernet.Authentication.Timer.Reauthenticate()
                        self.reauthenticate.parent = self
                        self._children_name_map["reauthenticate"] = "reauthenticate"

                        self.inactivity = Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity()
                        self.inactivity.parent = self
                        self._children_name_map["inactivity"] = "inactivity"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Timer, ['restart'], name, value)


                    class Reauthenticate(Entity):
                        """
                        Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: server
                        
                        	Obtain re\-authentication timeout value from the server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Authentication.Timer.Reauthenticate, self).__init__()

                            self.yang_name = "reauthenticate"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                            ])
                            self.value = None
                            self.server = None
                            self._segment_path = lambda: "reauthenticate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Timer.Reauthenticate, ['value', 'server'], name, value)


                    class Inactivity(Entity):
                        """
                        Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity.Value>`
                        
                        .. attribute:: server
                        
                        	Obtain inactivity timeout value from the server
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity.Server>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity, self).__init__()

                            self.yang_name = "inactivity"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity.Value)), ("server", ("server", Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity.Server))])
                            self._leafs = OrderedDict()

                            self.value = Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.server = None
                            self._children_name_map["server"] = "server"
                            self._segment_path = lambda: "inactivity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity, [], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.value = None
                                self.dynamic = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity.Value, ['value', 'dynamic'], name, value)


                        class Server(Entity):
                            """
                            Obtain inactivity timeout value from the server
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.dynamic = None
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Authentication.Timer.Inactivity.Server, ['dynamic'], name, value)


            class Mab(Entity):
                """
                
                
                .. attribute:: eap
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Mab, self).__init__()

                    self.yang_name = "mab"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                    ])
                    self.eap = None
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:mab"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Mab, ['eap'], name, value)


            class Dot1x(Entity):
                """
                Interface Config Commands for IEEE 802.1X
                
                .. attribute:: authenticator
                
                	Configure authenticator parameters
                	**type**\:  :py:class:`Authenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Dot1x.Authenticator>`
                
                .. attribute:: credentials
                
                	Credentials profile configuration
                	**type**\: str
                
                .. attribute:: max_reauth_req
                
                	Max No. of Reauthentication Attempts
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_req
                
                	Max No. of Retries
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_start
                
                	Max No. of EAPOL\-Start requests
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: pae
                
                	Set 802.1x interface pae type
                	**type**\:  :py:class:`Pae <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Dot1x.Pae>`
                
                .. attribute:: supplicant
                
                	Configure supplicant parameters
                	**type**\:  :py:class:`Supplicant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Dot1x.Supplicant>`
                
                .. attribute:: timeout
                
                	Various Timeouts
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Dot1x.Timeout>`
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Dot1x, self).__init__()

                    self.yang_name = "dot1x"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authenticator", ("authenticator", Native.Interface.FortyGigabitEthernet.Dot1x.Authenticator)), ("supplicant", ("supplicant", Native.Interface.FortyGigabitEthernet.Dot1x.Supplicant)), ("timeout", ("timeout", Native.Interface.FortyGigabitEthernet.Dot1x.Timeout))])
                    self._leafs = OrderedDict([
                        ('credentials', (YLeaf(YType.str, 'credentials'), ['str'])),
                        ('max_reauth_req', (YLeaf(YType.uint8, 'max-reauth-req'), ['int'])),
                        ('max_req', (YLeaf(YType.uint8, 'max-req'), ['int'])),
                        ('max_start', (YLeaf(YType.uint8, 'max-start'), ['int'])),
                        ('pae', (YLeaf(YType.enumeration, 'pae'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Dot1x.Pae')])),
                    ])
                    self.credentials = None
                    self.max_reauth_req = None
                    self.max_req = None
                    self.max_start = None
                    self.pae = None

                    self.authenticator = Native.Interface.FortyGigabitEthernet.Dot1x.Authenticator()
                    self.authenticator.parent = self
                    self._children_name_map["authenticator"] = "authenticator"

                    self.supplicant = Native.Interface.FortyGigabitEthernet.Dot1x.Supplicant()
                    self.supplicant.parent = self
                    self._children_name_map["supplicant"] = "supplicant"

                    self.timeout = Native.Interface.FortyGigabitEthernet.Dot1x.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"
                    self._segment_path = lambda: "Cisco-IOS-XE-dot1x:dot1x"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Dot1x, ['credentials', 'max_reauth_req', 'max_req', 'max_start', 'pae'], name, value)

                class Pae(Enum):
                    """
                    Pae (Enum Class)

                    Set 802.1x interface pae type

                    .. data:: authenticator = 0

                    .. data:: supplicant = 1

                    .. data:: both = 2

                    """

                    authenticator = Enum.YLeaf(0, "authenticator")

                    supplicant = Enum.YLeaf(1, "supplicant")

                    both = Enum.YLeaf(2, "both")



                class Authenticator(Entity):
                    """
                    Configure authenticator parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP authenticator parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Dot1x.Authenticator.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Dot1x.Authenticator, self).__init__()

                        self.yang_name = "authenticator"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.FortyGigabitEthernet.Dot1x.Authenticator.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.FortyGigabitEthernet.Dot1x.Authenticator.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "authenticator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Dot1x.Authenticator, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP authenticator parameters
                        
                        .. attribute:: profile
                        
                        	EAP authenticator profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Dot1x.Authenticator.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "authenticator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Dot1x.Authenticator.Eap, ['profile'], name, value)


                class Supplicant(Entity):
                    """
                    Configure supplicant parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP supplicant parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Dot1x.Supplicant.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Dot1x.Supplicant, self).__init__()

                        self.yang_name = "supplicant"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.FortyGigabitEthernet.Dot1x.Supplicant.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.FortyGigabitEthernet.Dot1x.Supplicant.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "supplicant"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Dot1x.Supplicant, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP supplicant parameters
                        
                        .. attribute:: profile
                        
                        	EAP supplicant profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Dot1x.Supplicant.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "supplicant"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Dot1x.Supplicant.Eap, ['profile'], name, value)


                class Timeout(Entity):
                    """
                    Various Timeouts
                    
                    .. attribute:: auth_period
                    
                    	Timeout for authenticator reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: held_period
                    
                    	Timeout for authentication retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: quiet_period
                    
                    	QuietPeriod in Seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ratelimit_period
                    
                    	Ratelimit Period in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: server_timeout
                    
                    	Timeout for Radius Retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: start_period
                    
                    	Timeout for EAPOL\-start retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: supp_timeout
                    
                    	Timeout for supplicant reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: tx_period
                    
                    	Timeout for supplicant retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Dot1x.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auth_period', (YLeaf(YType.uint16, 'auth-period'), ['int'])),
                            ('held_period', (YLeaf(YType.uint16, 'held-period'), ['int'])),
                            ('quiet_period', (YLeaf(YType.uint16, 'quiet-period'), ['int'])),
                            ('ratelimit_period', (YLeaf(YType.uint16, 'ratelimit-period'), ['int'])),
                            ('server_timeout', (YLeaf(YType.uint16, 'server-timeout'), ['int'])),
                            ('start_period', (YLeaf(YType.uint16, 'start-period'), ['int'])),
                            ('supp_timeout', (YLeaf(YType.uint16, 'supp-timeout'), ['int'])),
                            ('tx_period', (YLeaf(YType.uint16, 'tx-period'), ['int'])),
                        ])
                        self.auth_period = None
                        self.held_period = None
                        self.quiet_period = None
                        self.ratelimit_period = None
                        self.server_timeout = None
                        self.start_period = None
                        self.supp_timeout = None
                        self.tx_period = None
                        self._segment_path = lambda: "timeout"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Dot1x.Timeout, ['auth_period', 'held_period', 'quiet_period', 'ratelimit_period', 'server_timeout', 'start_period', 'supp_timeout', 'tx_period'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpdufilter
                
                	Don't send or receive BPDUs on this interface
                	**type**\:  :py:class:`Bpdufilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SpanningTree.Bpdufilter>`
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SpanningTree.Bpduguard>`
                
                .. attribute:: cost
                
                	To set the path cost of the interface
                	**type**\: int
                
                	**range:** 1..200000000
                
                .. attribute:: guard
                
                	Change an interface's spanning tree guard mode
                	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SpanningTree.Guard>`
                
                .. attribute:: link_type
                
                	Specify a link type for spanning tree tree protocol use
                	**type**\:  :py:class:`LinkType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SpanningTree.LinkType>`
                
                .. attribute:: portfast
                
                	Spanning tree portfast options
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                .. attribute:: port_priority
                
                	Spanning tree port\-priority options
                	**type**\: int
                
                	**range:** 0..240
                
                .. attribute:: vlan
                
                	VLAN Switch Spanning Tree
                	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SpanningTree.Vlan>`
                
                .. attribute:: loopguard
                
                	Spanning tree loopguard options
                	**type**\:  :py:class:`Loopguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SpanningTree.Loopguard>`
                
                .. attribute:: mst
                
                	Per interface MST configurations
                	**type**\:  :py:class:`Mst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SpanningTree.Mst>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Interface.FortyGigabitEthernet.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Interface.FortyGigabitEthernet.SpanningTree.Portfast)), ("vlan", ("vlan", Native.Interface.FortyGigabitEthernet.SpanningTree.Vlan)), ("loopguard", ("loopguard", Native.Interface.FortyGigabitEthernet.SpanningTree.Loopguard)), ("mst", ("mst", Native.Interface.FortyGigabitEthernet.SpanningTree.Mst))])
                    self._leafs = OrderedDict([
                        ('bpdufilter', (YLeaf(YType.enumeration, 'bpdufilter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.SpanningTree.Bpdufilter')])),
                        ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ('guard', (YLeaf(YType.enumeration, 'guard'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.SpanningTree.Guard')])),
                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.SpanningTree.LinkType')])),
                        ('port_priority', (YLeaf(YType.uint8, 'port-priority'), ['int'])),
                    ])
                    self.bpdufilter = None
                    self.cost = None
                    self.guard = None
                    self.link_type = None
                    self.port_priority = None

                    self.bpduguard = Native.Interface.FortyGigabitEthernet.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"

                    self.loopguard = Native.Interface.FortyGigabitEthernet.SpanningTree.Loopguard()
                    self.loopguard.parent = self
                    self._children_name_map["loopguard"] = "loopguard"

                    self.mst = Native.Interface.FortyGigabitEthernet.SpanningTree.Mst()
                    self.mst.parent = self
                    self._children_name_map["mst"] = "mst"

                    self.vlan = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:spanning-tree"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.SpanningTree, ['bpdufilter', 'cost', 'guard', 'link_type', 'port_priority'], name, value)

                class Bpdufilter(Enum):
                    """
                    Bpdufilter (Enum Class)

                    Don't send or receive BPDUs on this interface

                    .. data:: disable = 0

                    .. data:: enable = 1

                    """

                    disable = Enum.YLeaf(0, "disable")

                    enable = Enum.YLeaf(1, "enable")


                class Guard(Enum):
                    """
                    Guard (Enum Class)

                    Change an interface's spanning tree guard mode

                    .. data:: loop = 0

                    .. data:: none = 1

                    .. data:: root = 2

                    """

                    loop = Enum.YLeaf(0, "loop")

                    none = Enum.YLeaf(1, "none")

                    root = Enum.YLeaf(2, "root")


                class LinkType(Enum):
                    """
                    LinkType (Enum Class)

                    Specify a link type for spanning tree tree protocol use

                    .. data:: point_to_point = 0

                    .. data:: shared = 1

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")

                    shared = Enum.YLeaf(1, "shared")



                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.disable = None
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.SpanningTree.Bpduguard, ['disable', 'enable'], name, value)


                class Portfast(Entity):
                    """
                    Spanning tree portfast options
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk
                    
                    	Enable portfast on the interface even in trunk mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                        ])
                        self.disable = None
                        self.trunk = None
                        self.edge = None
                        self._segment_path = lambda: "portfast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.SpanningTree.Portfast, ['disable', 'trunk', 'edge'], name, value)


                class Vlan(Entity):
                    """
                    VLAN Switch Spanning Tree
                    
                    .. attribute:: vlan_ids  (key)
                    
                    	vlan range, example\: 1,3\-5,7,9\-11
                    	**type**\: str
                    
                    .. attribute:: cost
                    
                    	<1\-200000000> Spanning\-tree cost
                    	**type**\: int
                    
                    	**range:** 1..200000000
                    
                    .. attribute:: port_priority
                    
                    	<0\-240> port priority in increments of 16
                    	**type**\: int
                    
                    	**range:** 0..240
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.SpanningTree.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vlan_ids']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_ids', (YLeaf(YType.str, 'vlan-ids'), ['str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                        ])
                        self.vlan_ids = None
                        self.cost = None
                        self.port_priority = None
                        self._segment_path = lambda: "vlan" + "[vlan-ids='" + str(self.vlan_ids) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.SpanningTree.Vlan, ['vlan_ids', 'cost', 'port_priority'], name, value)


                class Loopguard(Entity):
                    """
                    Spanning tree loopguard options
                    
                    .. attribute:: default
                    
                    	Enable loopguard by default on all ports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.SpanningTree.Loopguard, self).__init__()

                        self.yang_name = "loopguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.default = None
                        self._segment_path = lambda: "loopguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.SpanningTree.Loopguard, ['default'], name, value)


                class Mst(Entity):
                    """
                    Per interface MST configurations
                    
                    .. attribute:: mst_instance
                    
                    	
                    	**type**\: list of  		 :py:class:`MstInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.SpanningTree.Mst.MstInstance>`
                    
                    .. attribute:: pre_standard
                    
                    	Force pre\-standard MST BPDU transmission on port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.SpanningTree.Mst, self).__init__()

                        self.yang_name = "mst"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mst-instance", ("mst_instance", Native.Interface.FortyGigabitEthernet.SpanningTree.Mst.MstInstance))])
                        self._leafs = OrderedDict([
                            ('pre_standard', (YLeaf(YType.empty, 'pre-standard'), ['Empty'])),
                        ])
                        self.pre_standard = None

                        self.mst_instance = YList(self)
                        self._segment_path = lambda: "mst"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.SpanningTree.Mst, ['pre_standard'], name, value)


                    class MstInstance(Entity):
                        """
                        
                        
                        .. attribute:: instance  (key)
                        
                        	MST instance list, example 0,2\-4,6,8\-12
                        	**type**\: str
                        
                        .. attribute:: cost
                        
                        	<1\-200000000> Spanning\-tree cost
                        	**type**\: int
                        
                        	**range:** 1..200000000
                        
                        .. attribute:: port_priority
                        
                        	<0\-240> port priority in increments of 16
                        	**type**\: int
                        
                        	**range:** 0..240
                        
                        

                        """

                        _prefix = 'ios-stp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.SpanningTree.Mst.MstInstance, self).__init__()

                            self.yang_name = "mst-instance"
                            self.yang_parent_name = "mst"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                            ])
                            self.instance = None
                            self.cost = None
                            self.port_priority = None
                            self._segment_path = lambda: "mst-instance" + "[instance='" + str(self.instance) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.SpanningTree.Mst.MstInstance, ['instance', 'cost', 'port_priority'], name, value)


            class Performance(Entity):
                """
                Global performance monitor configuration
                
                .. attribute:: monitor
                
                	monitor
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Performance.Monitor>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Performance, self).__init__()

                    self.yang_name = "performance"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.FortyGigabitEthernet.Performance.Monitor))])
                    self._leafs = OrderedDict()

                    self.monitor = Native.Interface.FortyGigabitEthernet.Performance.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"
                    self._segment_path = lambda: "Cisco-IOS-XE-ezpm:performance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Performance, [], name, value)


                class Monitor(Entity):
                    """
                    monitor
                    
                    .. attribute:: context
                    
                    	Select ezPM context
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Performance.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "performance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('context', (YLeafList(YType.str, 'context'), ['str'])),
                        ])
                        self.context = []
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Performance.Monitor, ['context'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Umbrella, ['out', 'in_'], name, value)


            class Lldp(Entity):
                """
                LLDP interface subcommands
                
                .. attribute:: receive
                
                	Enable LLDP reception on interface
                	**type**\: bool
                
                .. attribute:: transmit
                
                	Enable LLDP transmission on interface
                	**type**\: bool
                
                

                """

                _prefix = 'ios-lldp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Lldp, self).__init__()

                    self.yang_name = "lldp"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                        ('transmit', (YLeaf(YType.boolean, 'transmit'), ['bool'])),
                    ])
                    self.receive = None
                    self.transmit = None
                    self._segment_path = lambda: "Cisco-IOS-XE-lldp:lldp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Lldp, ['receive', 'transmit'], name, value)


            class Vrrp(Entity):
                """
                Configure VRRP
                
                .. attribute:: vrrp_group
                
                	
                	**type**\: list of  		 :py:class:`VrrpGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup>`
                
                .. attribute:: vrrp_group_v2
                
                	vrrp version 2
                	**type**\: list of  		 :py:class:`VrrpGroupV2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2>`
                
                .. attribute:: delay
                
                	
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.Delay>`
                
                

                """

                _prefix = 'ios-vrrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Vrrp, self).__init__()

                    self.yang_name = "vrrp"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrrp-group", ("vrrp_group", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup)), ("vrrp-group-v2", ("vrrp_group_v2", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2)), ("delay", ("delay", Native.Interface.FortyGigabitEthernet.Vrrp.Delay))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.FortyGigabitEthernet.Vrrp.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.vrrp_group = YList(self)
                    self.vrrp_group_v2 = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vrrp:vrrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp, [], name, value)


                class VrrpGroup(Entity):
                    """
                    
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: address_family
                    
                    	Address family of the group
                    	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup, self).__init__()

                        self.yang_name = "vrrp-group"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("address-family", ("address_family", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                        ])
                        self.group_id = None

                        self.address_family = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"
                        self._segment_path = lambda: "vrrp-group" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup, ['group_id'], name, value)


                    class AddressFamily(Entity):
                        """
                        Address family of the group
                        
                        .. attribute:: ipv4
                        
                        	IPv4 Address family
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	IPv6 Address family
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily, self).__init__()

                            self.yang_name = "address-family"
                            self.yang_parent_name = "vrrp-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4)), ("ipv6", ("ipv6", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = None
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "address-family"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily, [], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 Address family
                            
                            .. attribute:: vrrpv2
                            
                            	Set VRRPv2 compatibility mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: address
                            
                            	Set the IPv4 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address)), ("preempt", ("preempt", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt)), ("timers", ("timers", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers)), ("track", ("track", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track)), ("vrrs", ("vrrs", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('vrrpv2', (YLeaf(YType.empty, 'vrrpv2'), ['Empty'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.vrrpv2 = None
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4, ['vrrpv2', 'description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv4 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary>`
                                
                                .. attribute:: secondary
                                
                                	
                                	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary)), ("secondary", ("secondary", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.secondary = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv4 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, ['address', 'primary'], name, value)


                                class Secondary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: secondary
                                    
                                    	Make this IPv4 address a secondary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, self).__init__()

                                        self.yang_name = "secondary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.secondary = None
                                        self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, ['address', 'secondary'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, ['leader'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 Address family
                            
                            .. attribute:: address
                            
                            	Set the IPv6 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address)), ("preempt", ("preempt", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt)), ("timers", ("timers", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers)), ("track", ("track", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track)), ("vrrs", ("vrrs", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6, ['description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv6 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary>`
                                
                                .. attribute:: ipv6_prefix
                                
                                	
                                	**type**\: list of  		 :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary)), ("ipv6-prefix", ("ipv6_prefix", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.ipv6_prefix = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipv6_link_local
                                    
                                    	IPv6 link\-local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv6 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_link_local', (YLeaf(YType.str, 'ipv6-link-local'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.ipv6_link_local = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, ['ipv6_link_local', 'primary'], name, value)


                                class Ipv6Prefix(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, self).__init__()

                                        self.yang_name = "ipv6-prefix"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                        ])
                                        self.prefix = None
                                        self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, ['prefix'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, ['leader'], name, value)


                class VrrpGroupV2(Entity):
                    """
                    vrrp version 2
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: authentication
                    
                    	
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Authentication>`
                    
                    .. attribute:: description
                    
                    	Up to 80 characters describing this group
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Ip>`
                    
                    .. attribute:: name
                    
                    	Unique VRRS identifier (max 48 characters)
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: shutdown
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: timers
                    
                    	
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Timers>`
                    
                    .. attribute:: track
                    
                    	
                    	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Track>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2, self).__init__()

                        self.yang_name = "vrrp-group-v2"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Authentication)), ("ip", ("ip", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Ip)), ("preempt", ("preempt", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Preempt)), ("timers", ("timers", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Timers)), ("track", ("track", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Track))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.group_id = None
                        self.description = None
                        self.name = None
                        self.priority = None
                        self.shutdown = None

                        self.authentication = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.timers = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Track()
                        self.track.parent = self
                        self._children_name_map["track"] = "track"
                        self._segment_path = lambda: "vrrp-group-v2" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2, ['group_id', 'description', 'name', 'priority', 'shutdown'], name, value)


                    class Authentication(Entity):
                        """
                        
                        
                        .. attribute:: text
                        
                        	authentication string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.text = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Authentication, ['text'], name, value)


                    class Ip(Entity):
                        """
                        
                        
                        .. attribute:: vrrp_ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`VrrpIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrrp-ipv4", ("vrrp_ipv4", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4))])
                            self._leafs = OrderedDict()

                            self.vrrp_ipv4 = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Ip, [], name, value)


                        class VrrpIpv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, self).__init__()

                                self.yang_name = "vrrp-ipv4"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.ipv4 = None
                                self.secondary = None
                                self._segment_path = lambda: "vrrp-ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, ['ipv4', 'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        
                        
                        .. attribute:: delay
                        
                        	
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            
                            
                            .. attribute:: minimum
                            
                            	Seconds to delay
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                ])
                                self.minimum = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Preempt.Delay, ['minimum'], name, value)


                    class Timers(Entity):
                        """
                        
                        
                        .. attribute:: advertise
                        
                        	
                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise>`
                        
                        .. attribute:: learn
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise))])
                            self._leafs = OrderedDict([
                                ('learn', (YLeaf(YType.empty, 'learn'), ['Empty'])),
                            ])
                            self.learn = None

                            self.advertise = Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise()
                            self.advertise.parent = self
                            self._children_name_map["advertise"] = "advertise"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Timers, ['learn'], name, value)


                        class Advertise(Entity):
                            """
                            
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Advertisement interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..999
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise, self).__init__()

                                self.yang_name = "advertise"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint8, 'interval'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.interval = None
                                self.msec = None
                                self._segment_path = lambda: "advertise"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Timers.Advertise, ['interval', 'msec'], name, value)


                    class Track(Entity):
                        """
                        
                        
                        .. attribute:: event
                        
                        	
                        	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("event", ("event", Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event))])
                            self._leafs = OrderedDict()

                            self.event = YList(self)
                            self._segment_path = lambda: "track"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Track, [], name, value)


                        class Event(Entity):
                            """
                            
                            
                            .. attribute:: object_id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: decrement
                            
                            	Decrement value
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event, self).__init__()

                                self.yang_name = "event"
                                self.yang_parent_name = "track"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['object_id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                    ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ])
                                self.object_id = None
                                self.decrement = None
                                self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.VrrpGroupV2.Track.Event, ['object_id', 'decrement'], name, value)


                class Delay(Entity):
                    """
                    
                    
                    .. attribute:: reload
                    
                    	Seconds to delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: minimum
                    
                    	Seconds to delay after interface up
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Vrrp.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                        ])
                        self.reload = None
                        self.minimum = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Vrrp.Delay, ['reload', 'minimum'], name, value)


            class Ospfv3(Entity):
                """
                OSPFv3 interface commands
                
                .. attribute:: process_id
                
                	
                	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId>`
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication>`
                
                .. attribute:: bfd
                
                	Enable BFD on this interface
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: cost
                
                	Route cost of this interface
                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Cost>`
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: demand_circuit
                
                	OSPF Demand Circuit
                	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.DemandCircuit>`
                
                	**presence node**\: True
                
                .. attribute:: encryption
                
                	Enable encryption
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption>`
                
                .. attribute:: flood_reduction
                
                	OSPF Flood Reduction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: manet
                
                	Mobile Adhoc Networking options
                	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Manet>`
                
                .. attribute:: mtu_ignore
                
                	Ignores the MTU in DBD packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: multi_area
                
                	Set the OSPF multi\-area ID
                	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.MultiArea>`
                
                .. attribute:: neighbor
                
                	OSPF neighbor
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Neighbor>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Network>`
                
                .. attribute:: prefix_suppression
                
                	OSPF prefix suppression
                	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.PrefixSuppression>`
                
                	**presence node**\: True
                
                .. attribute:: priority
                
                	Router priority
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: retransmit_interval
                
                	Time between retransmitting lost link state advertisements
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Shut down the interface in OSPFv3
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transmit_delay
                
                	Link state transmit delay
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Ospfv3, self).__init__()

                    self.yang_name = "ospfv3"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId)), ("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication)), ("bfd", ("bfd", Native.Interface.FortyGigabitEthernet.Ospfv3.Bfd)), ("cost", ("cost", Native.Interface.FortyGigabitEthernet.Ospfv3.Cost)), ("database-filter", ("database_filter", Native.Interface.FortyGigabitEthernet.Ospfv3.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FortyGigabitEthernet.Ospfv3.DemandCircuit)), ("encryption", ("encryption", Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption)), ("manet", ("manet", Native.Interface.FortyGigabitEthernet.Ospfv3.Manet)), ("multi-area", ("multi_area", Native.Interface.FortyGigabitEthernet.Ospfv3.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FortyGigabitEthernet.Ospfv3.Neighbor)), ("network", ("network", Native.Interface.FortyGigabitEthernet.Ospfv3.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FortyGigabitEthernet.Ospfv3.PrefixSuppression))])
                    self._leafs = OrderedDict([
                        ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                        ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                        ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                    ])
                    self.dead_interval = None
                    self.flood_reduction = None
                    self.hello_interval = None
                    self.mtu_ignore = None
                    self.priority = None
                    self.retransmit_interval = None
                    self.shutdown = None
                    self.transmit_delay = None

                    self.authentication = Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"

                    self.cost = Native.Interface.FortyGigabitEthernet.Ospfv3.Cost()
                    self.cost.parent = self
                    self._children_name_map["cost"] = "cost"

                    self.database_filter = Native.Interface.FortyGigabitEthernet.Ospfv3.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"

                    self.demand_circuit = None
                    self._children_name_map["demand_circuit"] = "demand-circuit"

                    self.encryption = Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.manet = Native.Interface.FortyGigabitEthernet.Ospfv3.Manet()
                    self.manet.parent = self
                    self._children_name_map["manet"] = "manet"

                    self.multi_area = Native.Interface.FortyGigabitEthernet.Ospfv3.MultiArea()
                    self.multi_area.parent = self
                    self._children_name_map["multi_area"] = "multi-area"

                    self.network = Native.Interface.FortyGigabitEthernet.Ospfv3.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.prefix_suppression = None
                    self._children_name_map["prefix_suppression"] = "prefix-suppression"

                    self.process_id = YList(self)
                    self.neighbor = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3, ['dead_interval', u'flood_reduction', 'hello_interval', u'mtu_ignore', 'priority', 'retransmit_interval', u'shutdown', 'transmit_delay'], name, value)


                class ProcessId(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: manet
                    
                    	Mobile Adhoc Networking options
                    	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.MultiArea>`
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Network>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipv4
                    
                    	Specify parameters for IPv4
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Specify parameters for IPv6
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId, self).__init__()

                        self.yang_name = "process-id"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Authentication)), ("bfd", ("bfd", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Bfd)), ("cost", ("cost", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost)), ("database-filter", ("database_filter", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.FloodReduction)), ("manet", ("manet", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Neighbor)), ("network", ("network", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Shutdown)), ("ipv4", ("ipv4", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4)), ("ipv6", ("ipv6", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.id = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.cost = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.database_filter = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.manet = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet()
                        self.manet.parent = self
                        self._children_name_map["manet"] = "manet"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.multi_area = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.network = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.ipv4 = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId, [u'id', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\: str
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.null = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Authentication, [u'key_chain', u'null'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Bfd, ['disable'], name, value)


                    class Cost(Entity):
                        """
                        Route cost of this interface
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dynamic
                        
                        	Specify dynamic cost options
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.dynamic = None
                            self._children_name_map["dynamic"] = "dynamic"
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost, [u'value'], name, value)


                        class Dynamic(Entity):
                            """
                            Specify dynamic cost options
                            
                            .. attribute:: default
                            
                            	Specify default link metric value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: hysteresis
                            
                            	Specify hysteresis value for LSA dampening
                            	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: weight
                            
                            	Specify weight to be placed on individual metrics
                            	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ])
                                self.default = None

                                self.hysteresis = None
                                self._children_name_map["hysteresis"] = "hysteresis"

                                self.weight = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight()
                                self.weight.parent = self
                                self._children_name_map["weight"] = "weight"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic, [u'default'], name, value)


                            class Hysteresis(Entity):
                                """
                                Specify hysteresis value for LSA dampening
                                
                                .. attribute:: percent
                                
                                	Specify hysteresis percent changed
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold
                                
                                	Specify hysteresis threshold value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, self).__init__()

                                    self.yang_name = "hysteresis"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "hysteresis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                            class Weight(Entity):
                                """
                                Specify weight to be placed on individual metrics
                                
                                .. attribute:: l2_factor
                                
                                	Specify weight to be given to L2\-factor metric
                                	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: latency
                                
                                	Specify weight to be given to latency metric
                                	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: resources
                                
                                	Specify weight to be given to resources metric
                                	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: throughput
                                
                                	Specify weight to be given to throughput metric
                                	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, self).__init__()

                                    self.yang_name = "weight"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput))])
                                    self._leafs = OrderedDict()

                                    self.l2_factor = None
                                    self._children_name_map["l2_factor"] = "L2-factor"

                                    self.latency = None
                                    self._children_name_map["latency"] = "latency"

                                    self.resources = None
                                    self._children_name_map["resources"] = "resources"

                                    self.throughput = None
                                    self._children_name_map["throughput"] = "throughput"
                                    self._segment_path = lambda: "weight"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight, [], name, value)


                                class L2Factor(Entity):
                                    """
                                    Specify weight to be given to L2\-factor metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                        self.yang_name = "L2-factor"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "L2-factor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                class Latency(Entity):
                                    """
                                    Specify weight to be given to latency metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, self).__init__()

                                        self.yang_name = "latency"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "latency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                class Resources(Entity):
                                    """
                                    Specify weight to be given to resources metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, self).__init__()

                                        self.yang_name = "resources"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "resources"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                class Throughput(Entity):
                                    """
                                    Specify weight to be given to throughput metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, self).__init__()

                                        self.yang_name = "throughput"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "throughput"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.DatabaseFilter, [u'all', u'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.DemandCircuit, [u'disable', u'ignore'], name, value)


                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.FloodReduction, [u'disable'], name, value)


                    class Manet(Entity):
                        """
                        Mobile Adhoc Networking options
                        
                        .. attribute:: peering
                        
                        	MANET Peering options
                        	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet.Peering>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet, self).__init__()

                            self.yang_name = "manet"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet.Peering))])
                            self._leafs = OrderedDict()

                            self.peering = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet.Peering()
                            self.peering.parent = self
                            self._children_name_map["peering"] = "peering"
                            self._segment_path = lambda: "manet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet, [], name, value)


                        class Peering(Entity):
                            """
                            MANET Peering options
                            
                            .. attribute:: cost
                            
                            	Redundant path cost improvement required to peer
                            	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost>`
                            
                            .. attribute:: link_metrics
                            
                            	Require link metrics
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet.Peering, self).__init__()

                                self.yang_name = "peering"
                                self.yang_parent_name = "manet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost))])
                                self._leafs = OrderedDict([
                                    ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                ])
                                self.link_metrics = None

                                self.cost = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost()
                                self.cost.parent = self
                                self._children_name_map["cost"] = "cost"
                                self._segment_path = lambda: "peering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet.Peering, [u'link_metrics'], name, value)


                            class Cost(Entity):
                                """
                                Redundant path cost improvement required to peer
                                
                                .. attribute:: percent
                                
                                	Relative incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                .. attribute:: threshold
                                
                                	Absolute incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, self).__init__()

                                    self.yang_name = "cost"
                                    self.yang_parent_name = "peering"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "cost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.MtuIgnore, [u'disable'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: disable
                        
                        	disable OSPF multi\-area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.disable = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.MultiArea, [u'id', u'cost', u'disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.PrefixSuppression, ['disable'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Shutdown, [u'disable'], name, value)


                    class Ipv4(Entity):
                        """
                        Specify parameters for IPv4
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area)), ("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication)), ("bfd", ("bfd", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd)), ("cost", ("cost", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost)), ("database-filter", ("database_filter", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction)), ("manet", ("manet", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor)), ("network", ("network", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 64..95
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv4.Shutdown, [u'disable'], name, value)


                    class Ipv6(Entity):
                        """
                        Specify parameters for IPv6
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area)), ("authentication", ("authentication", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication)), ("bfd", ("bfd", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd)), ("cost", ("cost", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost)), ("database-filter", ("database_filter", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction)), ("manet", ("manet", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea)), ("neighbor", ("neighbor", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor)), ("network", ("network", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 0..31
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.ProcessId.Ipv6.Shutdown, [u'disable'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: key_chain
                    
                    	Use a key\-chain for cryptographic authentication keys
                    	**type**\: str
                    
                    .. attribute:: null
                    
                    	Use no authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec authentication
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.null = None

                        self.ipsec = Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication, [u'key_chain', u'null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec authentication
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 256..4294967295
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5>`
                        
                        .. attribute:: sha1
                        
                        	Use SHA\-1 authentication
                        	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                            ])
                            self.spi = None

                            self.md5 = Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"

                            self.sha1 = Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1()
                            self.sha1.parent = self
                            self._children_name_map["sha1"] = "sha1"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec, ['spi'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class Sha1(Entity):
                            """
                            Use SHA\-1 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1, self).__init__()

                                self.yang_name = "sha1"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "sha1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "sha1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                class Bfd(Entity):
                    """
                    Enable BFD on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BFD on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Bfd, ['disable'], name, value)


                class Cost(Entity):
                    """
                    Route cost of this interface
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: dynamic
                    
                    	Specify dynamic cost options
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost, self).__init__()

                        self.yang_name = "cost"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.dynamic = None
                        self._children_name_map["dynamic"] = "dynamic"
                        self._segment_path = lambda: "cost"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost, [u'value'], name, value)


                    class Dynamic(Entity):
                        """
                        Specify dynamic cost options
                        
                        .. attribute:: default
                        
                        	Specify default link metric value
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hysteresis
                        
                        	Specify hysteresis value for LSA dampening
                        	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: weight
                        
                        	Specify weight to be placed on individual metrics
                        	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic, self).__init__()

                            self.yang_name = "dynamic"
                            self.yang_parent_name = "cost"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                            ])
                            self.default = None

                            self.hysteresis = None
                            self._children_name_map["hysteresis"] = "hysteresis"

                            self.weight = Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight()
                            self.weight.parent = self
                            self._children_name_map["weight"] = "weight"
                            self._segment_path = lambda: "dynamic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic, [u'default'], name, value)


                        class Hysteresis(Entity):
                            """
                            Specify hysteresis value for LSA dampening
                            
                            .. attribute:: percent
                            
                            	Specify hysteresis percent changed
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold
                            
                            	Specify hysteresis threshold value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis, self).__init__()

                                self.yang_name = "hysteresis"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "hysteresis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                        class Weight(Entity):
                            """
                            Specify weight to be placed on individual metrics
                            
                            .. attribute:: l2_factor
                            
                            	Specify weight to be given to L2\-factor metric
                            	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: latency
                            
                            	Specify weight to be given to latency metric
                            	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: resources
                            
                            	Specify weight to be given to resources metric
                            	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: throughput
                            
                            	Specify weight to be given to throughput metric
                            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight, self).__init__()

                                self.yang_name = "weight"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput))])
                                self._leafs = OrderedDict()

                                self.l2_factor = None
                                self._children_name_map["l2_factor"] = "L2-factor"

                                self.latency = None
                                self._children_name_map["latency"] = "latency"

                                self.resources = None
                                self._children_name_map["resources"] = "resources"

                                self.throughput = None
                                self._children_name_map["throughput"] = "throughput"
                                self._segment_path = lambda: "weight"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight, [], name, value)


                            class L2Factor(Entity):
                                """
                                Specify weight to be given to L2\-factor metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                    self.yang_name = "L2-factor"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "L2-factor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                            class Latency(Entity):
                                """
                                Specify weight to be given to latency metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, self).__init__()

                                    self.yang_name = "latency"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "latency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                            class Resources(Entity):
                                """
                                Specify weight to be given to resources metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, self).__init__()

                                    self.yang_name = "resources"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "resources"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                            class Throughput(Entity):
                                """
                                Specify weight to be given to throughput metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, self).__init__()

                                    self.yang_name = "throughput"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "throughput"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.DatabaseFilter.All')])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.DatabaseFilter, [u'all'], name, value)

                    class All(Enum):
                        """
                        All (Enum Class)

                        Filter all LSA

                        .. data:: out = 0

                        """

                        out = Enum.YLeaf(0, "out")



                class DemandCircuit(Entity):
                    """
                    OSPF Demand Circuit
                    
                    .. attribute:: ignore
                    
                    	Ignore demand circuit auto\-negotiation requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.DemandCircuit, self).__init__()

                        self.yang_name = "demand-circuit"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.ignore = None
                        self._segment_path = lambda: "demand-circuit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.DemandCircuit, [u'ignore'], name, value)


                class Encryption(Entity):
                    """
                    Enable encryption
                    
                    .. attribute:: null
                    
                    	No IPsec encryption on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec encryption
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec))])
                        self._leafs = OrderedDict([
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.null = None

                        self.ipsec = Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption, ['null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec encryption
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: esp
                        
                        	Use ESP encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec_3des
                        
                        	Use 3DES encryption
                        	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des>`
                        
                        .. attribute:: aes_cbc
                        
                        	Use AES\-CBC encryption
                        	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                            ])
                            self.spi = None
                            self.esp = None

                            self.ipsec_3des = Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des()
                            self.ipsec_3des.parent = self
                            self._children_name_map["ipsec_3des"] = "ipsec_3des"

                            self.aes_cbc = Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc()
                            self.aes_cbc.parent = self
                            self._children_name_map["aes_cbc"] = "aes-cbc"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec, ['spi', 'esp'], name, value)


                        class Ipsec3des(Entity):
                            """
                            Use 3DES encryption
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, self).__init__()

                                self.yang_name = "ipsec_3des"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "ipsec_3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "ipsec_3des"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class AesCbc(Entity):
                            """
                            Use AES\-CBC encryption
                            
                            .. attribute:: aes_cbc_128
                            
                            	Use 128 bit key
                            	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128>`
                            
                            .. attribute:: aes_192
                            
                            	Use 192 bit key
                            	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192>`
                            
                            .. attribute:: aes_256
                            
                            	Use 256 bit key
                            	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc, self).__init__()

                                self.yang_name = "aes-cbc"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256))])
                                self._leafs = OrderedDict()

                                self.aes_cbc_128 = Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128()
                                self.aes_cbc_128.parent = self
                                self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                self.aes_192 = Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192()
                                self.aes_192.parent = self
                                self._children_name_map["aes_192"] = "aes-192"

                                self.aes_256 = Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256()
                                self.aes_256.parent = self
                                self._children_name_map["aes_256"] = "aes-256"
                                self._segment_path = lambda: "aes-cbc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc, [], name, value)


                            class AesCbc128(Entity):
                                """
                                Use 128 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                    self.yang_name = "aes-cbc-128"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-cbc-128"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-cbc-128"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes192(Entity):
                                """
                                Use 192 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                    self.yang_name = "aes-192"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-192"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-192"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes256(Entity):
                                """
                                Use 256 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                    self.yang_name = "aes-256"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-256"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-256"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                class Manet(Entity):
                    """
                    Mobile Adhoc Networking options
                    
                    .. attribute:: peering
                    
                    	MANET Peering options
                    	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Manet.Peering>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.Manet, self).__init__()

                        self.yang_name = "manet"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.FortyGigabitEthernet.Ospfv3.Manet.Peering))])
                        self._leafs = OrderedDict()

                        self.peering = Native.Interface.FortyGigabitEthernet.Ospfv3.Manet.Peering()
                        self.peering.parent = self
                        self._children_name_map["peering"] = "peering"
                        self._segment_path = lambda: "manet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Manet, [], name, value)


                    class Peering(Entity):
                        """
                        MANET Peering options
                        
                        .. attribute:: cost
                        
                        	Redundant path cost improvement required to peer
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Manet.Peering.Cost>`
                        
                        .. attribute:: link_metrics
                        
                        	Require link metrics
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.Manet.Peering, self).__init__()

                            self.yang_name = "peering"
                            self.yang_parent_name = "manet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.FortyGigabitEthernet.Ospfv3.Manet.Peering.Cost))])
                            self._leafs = OrderedDict([
                                ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                            ])
                            self.link_metrics = None

                            self.cost = Native.Interface.FortyGigabitEthernet.Ospfv3.Manet.Peering.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"
                            self._segment_path = lambda: "peering"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Manet.Peering, [u'link_metrics'], name, value)


                        class Cost(Entity):
                            """
                            Redundant path cost improvement required to peer
                            
                            .. attribute:: percent
                            
                            	Relative incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: threshold
                            
                            	Absolute incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Ospfv3.Manet.Peering.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "peering"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                class MultiArea(Entity):
                    """
                    Set the OSPF multi\-area ID
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.MultiArea, self).__init__()

                        self.yang_name = "multi-area"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self._segment_path = lambda: "multi-area"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.MultiArea, [u'id', u'cost'], name, value)


                class Neighbor(Entity):
                    """
                    OSPF neighbor
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	OSPF cost for point\-to\-multipoint neighbor
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter>`
                    
                    .. attribute:: poll_interval
                    
                    	OSPF dead\-router polling interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: priority
                    
                    	OSPF priority of non\-broadcast neighbor
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.FortyGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self.poll_interval = None
                        self.priority = None

                        self.database_filter = Native.Interface.FortyGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.FortyGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter.All')])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Neighbor.DatabaseFilter, ['all'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                class Network(Entity):
                    """
                    Network type
                    
                    .. attribute:: broadcast
                    
                    	Specify OSPF broadcast multi\-access network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: manet
                    
                    	Specify MANET OSPF interface type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: non_broadcast
                    
                    	Specify OSPF NBMA network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: point_to_multipoint
                    
                    	Specify OSPF point\-to\-multipoint network
                    	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Ospfv3.Network.PointToMultipoint>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: point_to_point
                    
                    	Specify OSPF point\-to\-point network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.FortyGigabitEthernet.Ospfv3.Network.PointToMultipoint))])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                            ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                        ])
                        self.broadcast = None
                        self.manet = None
                        self.non_broadcast = None
                        self.point_to_point = None

                        self.point_to_multipoint = None
                        self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                    class PointToMultipoint(Entity):
                        """
                        Specify OSPF point\-to\-multipoint network
                        
                        .. attribute:: non_broadcast
                        
                        	Specify non\-broadcast point\-to\-mpoint network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Ospfv3.Network.PointToMultipoint, self).__init__()

                            self.yang_name = "point-to-multipoint"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ])
                            self.non_broadcast = None
                            self._segment_path = lambda: "point-to-multipoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.Network.PointToMultipoint, ['non_broadcast'], name, value)


                class PrefixSuppression(Entity):
                    """
                    OSPF prefix suppression
                    
                    .. attribute:: disable
                    
                    	Disable prefix suppression
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Ospfv3.PrefixSuppression, self).__init__()

                        self.yang_name = "prefix-suppression"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "prefix-suppression"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Ospfv3.PrefixSuppression, ['disable'], name, value)


            class Udld(Entity):
                """
                Configure UDLD enabled or disabled and ignore global UDLD setting
                
                .. attribute:: port
                
                	Enable UDLD protocol on this interface despite global UDLD setting
                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Udld.Port>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-udld'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Udld, self).__init__()

                    self.yang_name = "udld"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.FortyGigabitEthernet.Udld.Port))])
                    self._leafs = OrderedDict()

                    self.port = None
                    self._children_name_map["port"] = "port"
                    self._segment_path = lambda: "Cisco-IOS-XE-udld:udld"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Udld, [], name, value)


                class Port(Entity):
                    """
                    Enable UDLD protocol on this interface despite global UDLD setting
                    
                    .. attribute:: aggressive
                    
                    	Enable UDLD protocol in aggressive mode on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	Disable UDLD protocol on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-udld'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Udld.Port, self).__init__()

                        self.yang_name = "port"
                        self.yang_parent_name = "udld"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aggressive', (YLeaf(YType.empty, 'aggressive'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.aggressive = None
                        self.disable = None
                        self._segment_path = lambda: "port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Udld.Port, ['aggressive', 'disable'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.Manual>`
                
                	**presence node**\: True
                
                .. attribute:: role_based
                
                	Role\-based Access Control per\-port config commands
                	**type**\:  :py:class:`RoleBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.RoleBased>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.FortyGigabitEthernet.Cts.Manual)), ("role-based", ("role_based", Native.Interface.FortyGigabitEthernet.Cts.RoleBased))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"

                    self.role_based = Native.Interface.FortyGigabitEthernet.Cts.RoleBased()
                    self.role_based.parent = self
                    self._children_name_map["role_based"] = "role-based"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.FortyGigabitEthernet.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.FortyGigabitEthernet.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.FortyGigabitEthernet.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.FortyGigabitEthernet.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.FortyGigabitEthernet.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.FortyGigabitEthernet.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.FortyGigabitEthernet.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.Manual.Propagate, ['sgt'], name, value)


                class RoleBased(Entity):
                    """
                    Role\-based Access Control per\-port config commands
                    
                    .. attribute:: enforcement
                    
                    	Enable Role\-based Access Control enforcement
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.Cts.RoleBased, self).__init__()

                        self.yang_name = "role-based"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enforcement', (YLeaf(YType.empty, 'enforcement'), ['Empty'])),
                        ])
                        self.enforcement = None
                        self._segment_path = lambda: "role-based"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.Cts.RoleBased, ['enforcement'], name, value)


            class AnalysisModule(Entity):
                """
                Configure NAM on the interface
                
                .. attribute:: monitoring
                
                	Configure NAM monitoring on the interface
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.FortyGigabitEthernet.AnalysisModule.Monitoring>`
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Interface.FortyGigabitEthernet.AnalysisModule, self).__init__()

                    self.yang_name = "analysis-module"
                    self.yang_parent_name = "FortyGigabitEthernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Interface.FortyGigabitEthernet.AnalysisModule.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = Native.Interface.FortyGigabitEthernet.AnalysisModule.Monitoring()
                    self.monitoring.parent = self
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.FortyGigabitEthernet.AnalysisModule, [], name, value)


                class Monitoring(Entity):
                    """
                    Configure NAM monitoring on the interface
                    
                    .. attribute:: interface_name
                    
                    	The name of the output interface.  E.g., 'ucse 1/0/0'
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nam'
                    _revision = '2017-12-28'

                    def __init__(self):
                        super(Native.Interface.FortyGigabitEthernet.AnalysisModule.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "analysis-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "monitoring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.FortyGigabitEthernet.AnalysisModule.Monitoring, ['interface_name'], name, value)


        class HundredGigE(Entity):
            """
            Hundred Gigabit Ethernet
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: enable
            
            	To enable or disable HundredGig Traffic
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_ethernet_macsec_option
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXEEthernetMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ServicePolicy>`
            
            .. attribute:: auto
            
            	Configure Automation
            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Auto>`
            
            .. attribute:: datalink
            
            	Interface Datalink commands
            	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Datalink>`
            
            .. attribute:: energywise
            
            	EnergyWise interface configurations
            	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Energywise>`
            
            	**presence node**\: True
            
            .. attribute:: location
            
            	Interface location information
            	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Location>`
            
            .. attribute:: mac
            
            	MAC interface commands
            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mac>`
            
            .. attribute:: macro
            
            	Command macro
            	**type**\:  :py:class:`Macro <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Macro>`
            
            .. attribute:: dual_active
            
            	
            	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.DualActive>`
            
            .. attribute:: load_balancing
            
            	Etherchannel Load\-Balancing
            	**type**\:  :py:class:`LoadBalancing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.LoadBalancing>`
            
            .. attribute:: vlan_range
            
            	
            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.VlanRange>`
            
            .. attribute:: switch
            
            	
            	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switch>`
            
            .. attribute:: srr_queue
            
            	
            	**type**\:  :py:class:`SrrQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SrrQueue>`
            
            .. attribute:: cisco_ios_xe_switch_macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_switch_macsec_option_
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`CiscoIOSXESwitchMacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Snmp>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Crypto>`
            
            .. attribute:: mka
            
            	MACsec Key Agreement (MKA) interface configuration
            	**type**\:  :py:class:`Mka <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mka>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Utd>`
            
            .. attribute:: xconnect
            
            	Xconnect commands
            	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Xconnect>`
            
            .. attribute:: evpn
            
            	
            	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Evpn>`
            
            .. attribute:: fabric_domain
            
            	Fabric\-domain interface command
            	**type**\:  :py:class:`FabricDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.FabricDomain>`
            
            .. attribute:: mvrp
            
            	
            	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mvrp>`
            
            	**presence node**\: True
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Lisp>`
            
            .. attribute:: power
            
            	
            	**type**\:  :py:class:`Power <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Power>`
            
            .. attribute:: cdp
            
            	CDP interface subcommands
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cdp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ntp>`
            
            .. attribute:: authentication
            
            	Auth Manager Interface Configuration Commands
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication>`
            
            .. attribute:: mab
            
            	
            	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mab>`
            
            	**presence node**\: True
            
            .. attribute:: dot1x
            
            	Interface Config Commands for IEEE 802.1X
            	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Dot1x>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SpanningTree>`
            
            .. attribute:: performance
            
            	Global performance monitor configuration
            	**type**\:  :py:class:`Performance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Performance>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Umbrella>`
            
            .. attribute:: lldp
            
            	LLDP interface subcommands
            	**type**\:  :py:class:`Lldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Lldp>`
            
            .. attribute:: vrrp
            
            	Configure VRRP
            	**type**\:  :py:class:`Vrrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp>`
            
            .. attribute:: nat66
            
            	NAT66 interface commands
            	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Nat66>`
            
            .. attribute:: ospfv3
            
            	OSPFv3 interface commands
            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3>`
            
            .. attribute:: udld
            
            	Configure UDLD enabled or disabled and ignore global UDLD setting
            	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Udld>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts>`
            
            .. attribute:: analysis_module
            
            	Configure NAM on the interface
            	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.AnalysisModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.HundredGigE, self).__init__()

                self.yang_name = "HundredGigE"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.HundredGigE.SwitchportConf)), ("switchport", ("switchport", Native.Interface.HundredGigE.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.HundredGigE.StackwiseVirtual)), ("arp", ("arp", Native.Interface.HundredGigE.Arp)), ("backup", ("backup", Native.Interface.HundredGigE.Backup)), ("cemoudp", ("cemoudp", Native.Interface.HundredGigE.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.HundredGigE.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.HundredGigE.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.HundredGigE.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.HundredGigE.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.HundredGigE.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.HundredGigE.Flowcontrol)), ("isis", ("isis", Native.Interface.HundredGigE.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.HundredGigE.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.HundredGigE.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.HundredGigE.Bandwidth)), ("dampening", ("dampening", Native.Interface.HundredGigE.Dampening)), ("domain", ("domain", Native.Interface.HundredGigE.Domain)), ("hold-queue", ("hold_queue", Native.Interface.HundredGigE.HoldQueue)), ("mpls", ("mpls", Native.Interface.HundredGigE.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.HundredGigE.IpVrf)), ("vrf", ("vrf", Native.Interface.HundredGigE.Vrf)), ("ip", ("ip", Native.Interface.HundredGigE.Ip)), ("ipv6", ("ipv6", Native.Interface.HundredGigE.Ipv6)), ("logging", ("logging", Native.Interface.HundredGigE.Logging)), ("mdix", ("mdix", Native.Interface.HundredGigE.Mdix)), ("mop", ("mop", Native.Interface.HundredGigE.Mop)), ("interface_qos", ("interface_qos", Native.Interface.HundredGigE.InterfaceQos)), ("source", ("source", Native.Interface.HundredGigE.Source)), ("standby", ("standby", Native.Interface.HundredGigE.Standby)), ("access-session", ("access_session", Native.Interface.HundredGigE.AccessSession)), ("storm-control", ("storm_control", Native.Interface.HundredGigE.StormControl)), ("trust", ("trust", Native.Interface.HundredGigE.Trust)), ("priority-queue", ("priority_queue", Native.Interface.HundredGigE.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.HundredGigE.RcvQueue)), ("peer", ("peer", Native.Interface.HundredGigE.Peer)), ("pm-path", ("pm_path", Native.Interface.HundredGigE.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.HundredGigE.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.HundredGigE.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.HundredGigE.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.HundredGigE.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.HundredGigE.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.HundredGigE.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.HundredGigE.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.HundredGigE.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.HundredGigE.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.HundredGigE.Service)), ("Cisco-IOS-XE-ethernet:macsec-option", ("cisco_ios_xe_ethernet_macsec_option", Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.HundredGigE.ServicePolicy)), ("Cisco-IOS-XE-switch:auto", ("auto", Native.Interface.HundredGigE.Auto)), ("Cisco-IOS-XE-switch:datalink", ("datalink", Native.Interface.HundredGigE.Datalink)), ("Cisco-IOS-XE-switch:energywise", ("energywise", Native.Interface.HundredGigE.Energywise)), ("Cisco-IOS-XE-switch:location", ("location", Native.Interface.HundredGigE.Location)), ("Cisco-IOS-XE-switch:mac", ("mac", Native.Interface.HundredGigE.Mac)), ("Cisco-IOS-XE-switch:macro", ("macro", Native.Interface.HundredGigE.Macro)), ("Cisco-IOS-XE-switch:dual-active", ("dual_active", Native.Interface.HundredGigE.DualActive)), ("Cisco-IOS-XE-switch:load-balancing", ("load_balancing", Native.Interface.HundredGigE.LoadBalancing)), ("Cisco-IOS-XE-switch:vlan-range", ("vlan_range", Native.Interface.HundredGigE.VlanRange)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Interface.HundredGigE.Switch)), ("Cisco-IOS-XE-switch:srr-queue", ("srr_queue", Native.Interface.HundredGigE.SrrQueue)), ("Cisco-IOS-XE-switch:macsec-option", ("cisco_ios_xe_switch_macsec_option_", Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.HundredGigE.Snmp)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.HundredGigE.Crypto)), ("Cisco-IOS-XE-mka:mka", ("mka", Native.Interface.HundredGigE.Mka)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.HundredGigE.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.HundredGigE.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.HundredGigE.Utd)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.HundredGigE.Xconnect)), ("Cisco-IOS-XE-l2vpn:evpn", ("evpn", Native.Interface.HundredGigE.Evpn)), ("Cisco-IOS-XE-iwanfabric:fabric-domain", ("fabric_domain", Native.Interface.HundredGigE.FabricDomain)), ("Cisco-IOS-XE-mvrp:mvrp", ("mvrp", Native.Interface.HundredGigE.Mvrp)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.HundredGigE.Lisp)), ("Cisco-IOS-XE-power:power", ("power", Native.Interface.HundredGigE.Power)), ("Cisco-IOS-XE-cdp:cdp", ("cdp", Native.Interface.HundredGigE.Cdp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.HundredGigE.Ntp)), ("Cisco-IOS-XE-sanet:authentication", ("authentication", Native.Interface.HundredGigE.Authentication)), ("Cisco-IOS-XE-sanet:mab", ("mab", Native.Interface.HundredGigE.Mab)), ("Cisco-IOS-XE-dot1x:dot1x", ("dot1x", Native.Interface.HundredGigE.Dot1x)), ("Cisco-IOS-XE-spanning-tree:spanning-tree", ("spanning_tree", Native.Interface.HundredGigE.SpanningTree)), ("Cisco-IOS-XE-ezpm:performance", ("performance", Native.Interface.HundredGigE.Performance)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.HundredGigE.Umbrella)), ("Cisco-IOS-XE-lldp:lldp", ("lldp", Native.Interface.HundredGigE.Lldp)), ("Cisco-IOS-XE-vrrp:vrrp", ("vrrp", Native.Interface.HundredGigE.Vrrp)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Interface.HundredGigE.Ospfv3)), ("Cisco-IOS-XE-udld:udld", ("udld", Native.Interface.HundredGigE.Udld)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.HundredGigE.Cts)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Interface.HundredGigE.AnalysisModule))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Duplex')])),
                    ('cisco_ios_xe_ethernet_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-ethernet:macsec'), ['Empty'])),
                    ('cisco_ios_xe_switch_macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:macsec'), ['Empty'])),
                    ('nat66', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-nat:nat66'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Nat66')])),
                ])
                self.name = None
                self.enable = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None
                self.cisco_ios_xe_ethernet_macsec = None
                self.cisco_ios_xe_switch_macsec = None
                self.nat66 = None

                self.switchport_conf = Native.Interface.HundredGigE.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.HundredGigE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.HundredGigE.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.HundredGigE.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.HundredGigE.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.HundredGigE.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.HundredGigE.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.HundredGigE.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.HundredGigE.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.HundredGigE.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.HundredGigE.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.HundredGigE.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.HundredGigE.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.HundredGigE.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.HundredGigE.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.HundredGigE.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.HundredGigE.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.HundredGigE.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.HundredGigE.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.HundredGigE.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.HundredGigE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.HundredGigE.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.HundredGigE.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.HundredGigE.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.HundredGigE.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.HundredGigE.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.HundredGigE.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.HundredGigE.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.HundredGigE.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.HundredGigE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.HundredGigE.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.HundredGigE.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.HundredGigE.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.HundredGigE.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.HundredGigE.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.HundredGigE.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.HundredGigE.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.HundredGigE.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.HundredGigE.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.HundredGigE.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.HundredGigE.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.HundredGigE.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.HundredGigE.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.HundredGigE.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.HundredGigE.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.cisco_ios_xe_ethernet_macsec_option = Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption()
                self.cisco_ios_xe_ethernet_macsec_option.parent = self
                self._children_name_map["cisco_ios_xe_ethernet_macsec_option"] = "Cisco-IOS-XE-ethernet:macsec-option"

                self.service_policy = Native.Interface.HundredGigE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.auto = Native.Interface.HundredGigE.Auto()
                self.auto.parent = self
                self._children_name_map["auto"] = "Cisco-IOS-XE-switch:auto"

                self.datalink = Native.Interface.HundredGigE.Datalink()
                self.datalink.parent = self
                self._children_name_map["datalink"] = "Cisco-IOS-XE-switch:datalink"

                self.energywise = None
                self._children_name_map["energywise"] = "Cisco-IOS-XE-switch:energywise"

                self.location = Native.Interface.HundredGigE.Location()
                self.location.parent = self
                self._children_name_map["location"] = "Cisco-IOS-XE-switch:location"

                self.mac = Native.Interface.HundredGigE.Mac()
                self.mac.parent = self
                self._children_name_map["mac"] = "Cisco-IOS-XE-switch:mac"

                self.macro = Native.Interface.HundredGigE.Macro()
                self.macro.parent = self
                self._children_name_map["macro"] = "Cisco-IOS-XE-switch:macro"

                self.dual_active = Native.Interface.HundredGigE.DualActive()
                self.dual_active.parent = self
                self._children_name_map["dual_active"] = "Cisco-IOS-XE-switch:dual-active"

                self.load_balancing = Native.Interface.HundredGigE.LoadBalancing()
                self.load_balancing.parent = self
                self._children_name_map["load_balancing"] = "Cisco-IOS-XE-switch:load-balancing"

                self.switch = Native.Interface.HundredGigE.Switch()
                self.switch.parent = self
                self._children_name_map["switch"] = "Cisco-IOS-XE-switch:switch"

                self.srr_queue = Native.Interface.HundredGigE.SrrQueue()
                self.srr_queue.parent = self
                self._children_name_map["srr_queue"] = "Cisco-IOS-XE-switch:srr-queue"

                self.cisco_ios_xe_switch_macsec_option_ = Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption()
                self.cisco_ios_xe_switch_macsec_option_.parent = self
                self._children_name_map["cisco_ios_xe_switch_macsec_option_"] = "Cisco-IOS-XE-switch:macsec-option"

                self.snmp = Native.Interface.HundredGigE.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.crypto = Native.Interface.HundredGigE.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.mka = Native.Interface.HundredGigE.Mka()
                self.mka.parent = self
                self._children_name_map["mka"] = "Cisco-IOS-XE-mka:mka"

                self.et_analytics = Native.Interface.HundredGigE.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.HundredGigE.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.HundredGigE.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.xconnect = Native.Interface.HundredGigE.Xconnect()
                self.xconnect.parent = self
                self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                self.evpn = Native.Interface.HundredGigE.Evpn()
                self.evpn.parent = self
                self._children_name_map["evpn"] = "Cisco-IOS-XE-l2vpn:evpn"

                self.fabric_domain = Native.Interface.HundredGigE.FabricDomain()
                self.fabric_domain.parent = self
                self._children_name_map["fabric_domain"] = "Cisco-IOS-XE-iwanfabric:fabric-domain"

                self.mvrp = None
                self._children_name_map["mvrp"] = "Cisco-IOS-XE-mvrp:mvrp"

                self.lisp = Native.Interface.HundredGigE.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.power = Native.Interface.HundredGigE.Power()
                self.power.parent = self
                self._children_name_map["power"] = "Cisco-IOS-XE-power:power"

                self.cdp = Native.Interface.HundredGigE.Cdp()
                self.cdp.parent = self
                self._children_name_map["cdp"] = "Cisco-IOS-XE-cdp:cdp"

                self.ntp = Native.Interface.HundredGigE.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.authentication = Native.Interface.HundredGigE.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "Cisco-IOS-XE-sanet:authentication"

                self.mab = None
                self._children_name_map["mab"] = "Cisco-IOS-XE-sanet:mab"

                self.dot1x = Native.Interface.HundredGigE.Dot1x()
                self.dot1x.parent = self
                self._children_name_map["dot1x"] = "Cisco-IOS-XE-dot1x:dot1x"

                self.spanning_tree = Native.Interface.HundredGigE.SpanningTree()
                self.spanning_tree.parent = self
                self._children_name_map["spanning_tree"] = "Cisco-IOS-XE-spanning-tree:spanning-tree"

                self.performance = Native.Interface.HundredGigE.Performance()
                self.performance.parent = self
                self._children_name_map["performance"] = "Cisco-IOS-XE-ezpm:performance"

                self.umbrella = Native.Interface.HundredGigE.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.lldp = Native.Interface.HundredGigE.Lldp()
                self.lldp.parent = self
                self._children_name_map["lldp"] = "Cisco-IOS-XE-lldp:lldp"

                self.vrrp = Native.Interface.HundredGigE.Vrrp()
                self.vrrp.parent = self
                self._children_name_map["vrrp"] = "Cisco-IOS-XE-vrrp:vrrp"

                self.ospfv3 = Native.Interface.HundredGigE.Ospfv3()
                self.ospfv3.parent = self
                self._children_name_map["ospfv3"] = "Cisco-IOS-XE-ospfv3:ospfv3"

                self.udld = Native.Interface.HundredGigE.Udld()
                self.udld.parent = self
                self._children_name_map["udld"] = "Cisco-IOS-XE-udld:udld"

                self.cts = Native.Interface.HundredGigE.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.analysis_module = Native.Interface.HundredGigE.AnalysisModule()
                self.analysis_module.parent = self
                self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"

                self.hold_queue = YList(self)
                self.vlan_range = YList(self)
                self._segment_path = lambda: "HundredGigE" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.HundredGigE, [u'name', u'enable', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex', 'cisco_ios_xe_ethernet_macsec', u'cisco_ios_xe_switch_macsec', 'nat66'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class Nat66(Enum):
                """
                Nat66 (Enum Class)

                NAT66 interface commands

                .. data:: inside = 0

                .. data:: outside = 1

                """

                inside = Enum.YLeaf(0, "inside")

                outside = Enum.YLeaf(1, "outside")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Access>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Block>`
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: trunk
                
                	Set trunking characteristics of the interface
                	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Trunk>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Voice>`
                
                .. attribute:: priority
                
                	Set appliance 802.1p priority
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Priority>`
                
                .. attribute:: autostate
                
                	Include or exclude this port from vlan link up calculation
                	**type**\:  :py:class:`Autostate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Autostate>`
                
                .. attribute:: protected
                
                	Configure an interface to be a protected port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Set port host
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: private_vlan
                
                	Set the private VLAN configuration
                	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PrivateVlan>`
                
                .. attribute:: vepa
                
                	Reflective relay configuration
                	**type**\:  :py:class:`Vepa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Vepa>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:access", ("access", Native.Interface.HundredGigE.Switchport.Access)), ("Cisco-IOS-XE-switch:block", ("block", Native.Interface.HundredGigE.Switchport.Block)), ("Cisco-IOS-XE-switch:mode", ("mode", Native.Interface.HundredGigE.Switchport.Mode)), ("Cisco-IOS-XE-switch:port-security", ("port_security", Native.Interface.HundredGigE.Switchport.PortSecurity)), ("Cisco-IOS-XE-switch:trunk", ("trunk", Native.Interface.HundredGigE.Switchport.Trunk)), ("Cisco-IOS-XE-switch:voice", ("voice", Native.Interface.HundredGigE.Switchport.Voice)), ("Cisco-IOS-XE-switch:priority", ("priority", Native.Interface.HundredGigE.Switchport.Priority)), ("Cisco-IOS-XE-switch:autostate", ("autostate", Native.Interface.HundredGigE.Switchport.Autostate)), ("Cisco-IOS-XE-switch:private-vlan", ("private_vlan", Native.Interface.HundredGigE.Switchport.PrivateVlan)), ("Cisco-IOS-XE-switch:vepa", ("vepa", Native.Interface.HundredGigE.Switchport.Vepa))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:nonegotiate'), ['Empty'])),
                        ('protected', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:protected'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:host'), ['Empty'])),
                    ])
                    self.nonegotiate = None
                    self.protected = None
                    self.host = None

                    self.access = Native.Interface.HundredGigE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "Cisco-IOS-XE-switch:access"

                    self.block = Native.Interface.HundredGigE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "Cisco-IOS-XE-switch:block"

                    self.mode = Native.Interface.HundredGigE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "Cisco-IOS-XE-switch:mode"

                    self.port_security = None
                    self._children_name_map["port_security"] = "Cisco-IOS-XE-switch:port-security"

                    self.trunk = Native.Interface.HundredGigE.Switchport.Trunk()
                    self.trunk.parent = self
                    self._children_name_map["trunk"] = "Cisco-IOS-XE-switch:trunk"

                    self.voice = Native.Interface.HundredGigE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "Cisco-IOS-XE-switch:voice"

                    self.priority = Native.Interface.HundredGigE.Switchport.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-switch:priority"

                    self.autostate = Native.Interface.HundredGigE.Switchport.Autostate()
                    self.autostate.parent = self
                    self._children_name_map["autostate"] = "Cisco-IOS-XE-switch:autostate"

                    self.private_vlan = Native.Interface.HundredGigE.Switchport.PrivateVlan()
                    self.private_vlan.parent = self
                    self._children_name_map["private_vlan"] = "Cisco-IOS-XE-switch:private-vlan"

                    self.vepa = Native.Interface.HundredGigE.Switchport.Vepa()
                    self.vepa.parent = self
                    self._children_name_map["vepa"] = "Cisco-IOS-XE-switch:vepa"
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Switchport, [u'nonegotiate', u'protected', u'host'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	Set VLAN when interface is in access mode
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Access.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.HundredGigE.Switchport.Access.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.HundredGigE.Switchport.Access.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:access"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Switchport.Access, [], name, value)


                    class Vlan(Entity):
                        """
                        Set VLAN when interface is in access mode
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_>`
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.Access.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "access"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.Access.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dynamic = 0

                            """

                            dynamic = Enum.YLeaf(0, "dynamic")



                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: multicast
                    
                    	Block unknown multicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.multicast = None
                        self.unicast = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:block"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Switchport.Block, [u'multicast', u'unicast'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Mode.Access>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dot1q_tunnel
                    
                    	set trunking mode to TUNNEL unconditionally
                    	**type**\:  :py:class:`Dot1qTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Mode.Dot1qTunnel>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dynamic
                    
                    	Set trunking mode to dynamically negotiate access or trunk mode
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Mode.Dynamic>`
                    
                    .. attribute:: private_vlan
                    
                    	Set private\-vlan mode
                    	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Mode.PrivateVlan>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Mode.Trunk>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.HundredGigE.Switchport.Mode.Access)), ("dot1q-tunnel", ("dot1q_tunnel", Native.Interface.HundredGigE.Switchport.Mode.Dot1qTunnel)), ("private-vlan", ("private_vlan", Native.Interface.HundredGigE.Switchport.Mode.PrivateVlan)), ("trunk", ("trunk", Native.Interface.HundredGigE.Switchport.Mode.Trunk))])
                        self._leafs = OrderedDict([
                            ('dynamic', (YLeaf(YType.enumeration, 'dynamic'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Switchport.Mode.Dynamic')])),
                        ])
                        self.dynamic = None

                        self.access = None
                        self._children_name_map["access"] = "access"

                        self.dot1q_tunnel = None
                        self._children_name_map["dot1q_tunnel"] = "dot1q-tunnel"

                        self.private_vlan = Native.Interface.HundredGigE.Switchport.Mode.PrivateVlan()
                        self.private_vlan.parent = self
                        self._children_name_map["private_vlan"] = "private-vlan"

                        self.trunk = None
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Switchport.Mode, [u'dynamic'], name, value)

                    class Dynamic(Enum):
                        """
                        Dynamic (Enum Class)

                        Set trunking mode to dynamically negotiate access or trunk mode

                        .. data:: auto = 0

                        .. data:: desirable = 1

                        """

                        auto = Enum.YLeaf(0, "auto")

                        desirable = Enum.YLeaf(1, "desirable")



                    class Access(Entity):
                        """
                        Set trunking mode to ACCESS unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.Mode.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "access"
                            self._is_frozen = True


                    class Dot1qTunnel(Entity):
                        """
                        set trunking mode to TUNNEL unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.Mode.Dot1qTunnel, self).__init__()

                            self.yang_name = "dot1q-tunnel"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dot1q-tunnel"
                            self._is_frozen = True


                    class PrivateVlan(Entity):
                        """
                        Set private\-vlan mode
                        
                        .. attribute:: host
                        
                        	Set the mode to private\-vlan host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: promiscuous
                        
                        	Set the mode to private\-vlan promiscuous
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.Mode.PrivateVlan, self).__init__()

                            self.yang_name = "private-vlan"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('promiscuous', (YLeaf(YType.empty, 'promiscuous'), ['Empty'])),
                            ])
                            self.host = None
                            self.promiscuous = None
                            self._segment_path = lambda: "private-vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.Mode.PrivateVlan, [u'host', u'promiscuous'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking mode to TRUNK unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.Mode.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: mac_address
                    
                    	Secure mac address
                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PortSecurity.MacAddress>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Interface.HundredGigE.Switchport.PortSecurity.Aging)), ("mac-address", ("mac_address", Native.Interface.HundredGigE.Switchport.PortSecurity.MacAddress)), ("maximum", ("maximum", Native.Interface.HundredGigE.Switchport.PortSecurity.Maximum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Switchport.PortSecurity.Violation')])),
                        ])
                        self.violation = None

                        self.aging = Native.Interface.HundredGigE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.mac_address = Native.Interface.HundredGigE.Switchport.PortSecurity.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"

                        self.maximum = Native.Interface.HundredGigE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:port-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Switchport.PortSecurity, [u'violation'], name, value)

                    class Violation(Enum):
                        """
                        Violation (Enum Class)

                        Security violation mode

                        .. data:: protect = 0

                        .. data:: restrict = 1

                        .. data:: shutdown = 2

                        """

                        protect = Enum.YLeaf(0, "protect")

                        restrict = Enum.YLeaf(1, "restrict")

                        shutdown = Enum.YLeaf(2, "shutdown")



                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PortSecurity.Aging.Type>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Switchport.PortSecurity.Aging.Type')])),
                            ])
                            self.static = None
                            self.time = None
                            self.type = None
                            self._segment_path = lambda: "aging"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.PortSecurity.Aging, [u'static', u'time', u'type'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Port\-security aging type

                            .. data:: absolute = 0

                            .. data:: inactivity = 1

                            """

                            absolute = Enum.YLeaf(0, "absolute")

                            inactivity = Enum.YLeaf(1, "inactivity")



                    class MacAddress(Entity):
                        """
                        Secure mac address
                        
                        .. attribute:: sticky
                        
                        	Configure dynamic secure addresses as sticky
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hw_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: vlan
                        
                        	set VLAN ID of the VLAN on which this address can be learned
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.PortSecurity.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                ('hw_address', (YLeaf(YType.str, 'hw-address'), ['str'])),
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.sticky = None
                            self.hw_address = None
                            self.vlan = None
                            self._segment_path = lambda: "mac-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.PortSecurity.MacAddress, [u'sticky', u'hw_address', u'vlan'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: max_addresses
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4097
                        
                        .. attribute:: vlan
                        
                        	Max secure addresses per vlan
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_addresses', (YLeaf(YType.uint16, 'max-addresses'), ['int'])),
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['str'])),
                            ])
                            self.max_addresses = None
                            self.vlan = None
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.PortSecurity.Maximum, [u'max_addresses', u'vlan'], name, value)


                class Trunk(Entity):
                    """
                    Set trunking characteristics of the interface
                    
                    .. attribute:: allowed
                    
                    	Set allowed VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Trunk.Allowed>`
                    
                    .. attribute:: encapsulation
                    
                    	Set encapsulation format on trunk port
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Trunk.Encapsulation>`
                    
                    .. attribute:: native
                    
                    	Set trunking native characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Trunk.Native_>`
                    
                    .. attribute:: pruning
                    
                    	Set pruning VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Pruning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Trunk.Pruning>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Switchport.Trunk, self).__init__()

                        self.yang_name = "trunk"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.HundredGigE.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.HundredGigE.Switchport.Trunk.Native_)), ("pruning", ("pruning", Native.Interface.HundredGigE.Switchport.Trunk.Pruning))])
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Switchport.Trunk.Encapsulation')])),
                        ])
                        self.encapsulation = None

                        self.allowed = Native.Interface.HundredGigE.Switchport.Trunk.Allowed()
                        self.allowed.parent = self
                        self._children_name_map["allowed"] = "allowed"

                        self.native = Native.Interface.HundredGigE.Switchport.Trunk.Native_()
                        self.native.parent = self
                        self._children_name_map["native"] = "native"

                        self.pruning = Native.Interface.HundredGigE.Switchport.Trunk.Pruning()
                        self.pruning.parent = self
                        self._children_name_map["pruning"] = "pruning"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:trunk"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Switchport.Trunk, [u'encapsulation'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Set encapsulation format on trunk port

                        .. data:: dot1q = 0

                        .. data:: isl = 1

                        .. data:: negotiate = 2

                        """

                        dot1q = Enum.YLeaf(0, "dot1q")

                        isl = Enum.YLeaf(1, "isl")

                        negotiate = Enum.YLeaf(2, "negotiate")



                    class Allowed(Entity):
                        """
                        Set allowed VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set allowed VLANs when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Trunk.Allowed.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.Trunk.Allowed, self).__init__()

                            self.yang_name = "allowed"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.HundredGigE.Switchport.Trunk.Allowed.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.HundredGigE.Switchport.Trunk.Allowed.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "allowed"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.Trunk.Allowed, [], name, value)


                        class Vlan(Entity):
                            """
                            Set allowed VLANs when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: all
                            
                            	all VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "allowed"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = None
                                self.add = None
                                self.all = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                    class Native_(Entity):
                        """
                        Set trunking native characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set native VLAN when interface is in trunking mode
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.Trunk.Native_, self).__init__()

                            self.yang_name = "native"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan'),'int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "native"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.Trunk.Native_, [u'vlan'], name, value)

                        class Vlan(Enum):
                            """
                            Vlan (Enum Class)

                            Set native VLAN when interface is in trunking mode

                            .. data:: tag = 0

                            """

                            tag = Enum.YLeaf(0, "tag")



                    class Pruning(Entity):
                        """
                        Set pruning VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set VLANs enabled for pruning when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Trunk.Pruning.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.Trunk.Pruning, self).__init__()

                            self.yang_name = "pruning"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.HundredGigE.Switchport.Trunk.Pruning.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.HundredGigE.Switchport.Trunk.Pruning.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "pruning"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.Trunk.Pruning, [], name, value)


                        class Vlan(Entity):
                            """
                            Set VLANs enabled for pruning when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Switchport.Trunk.Pruning.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "pruning"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeafList(YType.str, 'vlans'), ['int','str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = []
                                self.add = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Switchport.Trunk.Pruning.Vlan, [u'vlans', u'add', u'except_', u'none', u'remove'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Voice.Vlan>`
                    
                    .. attribute:: detect
                    
                    	detection enhancement keyword
                    	**type**\:  :py:class:`Detect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Voice.Detect>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.HundredGigE.Switchport.Voice.Vlan)), ("detect", ("detect", Native.Interface.HundredGigE.Switchport.Voice.Detect))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.HundredGigE.Switchport.Voice.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"

                        self.detect = Native.Interface.HundredGigE.Switchport.Voice.Detect()
                        self.detect.parent = self
                        self._children_name_map["detect"] = "detect"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:voice"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Switchport.Voice, [], name, value)


                    class Vlan(Entity):
                        """
                        Vlan for voice traffic
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\: str
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.Voice.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_'),'int','str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.Voice.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dot1p = 0

                            .. data:: none = 1

                            .. data:: untagged = 2

                            """

                            dot1p = Enum.YLeaf(0, "dot1p")

                            none = Enum.YLeaf(1, "none")

                            untagged = Enum.YLeaf(2, "untagged")



                    class Detect(Entity):
                        """
                        detection enhancement keyword
                        
                        .. attribute:: cisco_phone
                        
                        	Cisco IP phone
                        	**type**\:  :py:class:`CiscoPhone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Voice.Detect.CiscoPhone>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.Voice.Detect, self).__init__()

                            self.yang_name = "detect"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cisco-phone", ("cisco_phone", Native.Interface.HundredGigE.Switchport.Voice.Detect.CiscoPhone))])
                            self._leafs = OrderedDict()

                            self.cisco_phone = None
                            self._children_name_map["cisco_phone"] = "cisco-phone"
                            self._segment_path = lambda: "detect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.Voice.Detect, [], name, value)


                        class CiscoPhone(Entity):
                            """
                            Cisco IP phone
                            
                            .. attribute:: full_duplex
                            
                            	full duplex keyword
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Switchport.Voice.Detect.CiscoPhone, self).__init__()

                                self.yang_name = "cisco-phone"
                                self.yang_parent_name = "detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('full_duplex', (YLeaf(YType.empty, 'full-duplex'), ['Empty'])),
                                ])
                                self.full_duplex = None
                                self._segment_path = lambda: "cisco-phone"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Switchport.Voice.Detect.CiscoPhone, [u'full_duplex'], name, value)


                class Priority(Entity):
                    """
                    Set appliance 802.1p priority
                    
                    .. attribute:: extend
                    
                    	Set appliance 802.1p priority
                    	**type**\:  :py:class:`Extend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.Priority.Extend>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Switchport.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("extend", ("extend", Native.Interface.HundredGigE.Switchport.Priority.Extend))])
                        self._leafs = OrderedDict()

                        self.extend = Native.Interface.HundredGigE.Switchport.Priority.Extend()
                        self.extend.parent = self
                        self._children_name_map["extend"] = "extend"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Switchport.Priority, [], name, value)


                    class Extend(Entity):
                        """
                        Set appliance 802.1p priority
                        
                        .. attribute:: trust
                        
                        	Trust 802.1p priorities of devices on appliance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cos
                        
                        	Override 802.1p priority of devices on appliance
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.Priority.Extend, self).__init__()

                            self.yang_name = "extend"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                            ])
                            self.trust = None
                            self.cos = None
                            self._segment_path = lambda: "extend"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.Priority.Extend, [u'trust', u'cos'], name, value)


                class Autostate(Entity):
                    """
                    Include or exclude this port from vlan link up calculation
                    
                    .. attribute:: exclude
                    
                    	Exclude this port from vlan link up calculation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Switchport.Autostate, self).__init__()

                        self.yang_name = "autostate"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('exclude', (YLeaf(YType.empty, 'exclude'), ['Empty'])),
                        ])
                        self.exclude = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:autostate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Switchport.Autostate, [u'exclude'], name, value)


                class PrivateVlan(Entity):
                    """
                    Set the private VLAN configuration
                    
                    .. attribute:: association
                    
                    	Set the private VLAN association
                    	**type**\:  :py:class:`Association <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PrivateVlan.Association>`
                    
                    .. attribute:: host_association
                    
                    	Set the private VLAN host association
                    	**type**\:  :py:class:`HostAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PrivateVlan.HostAssociation>`
                    
                    .. attribute:: mapping
                    
                    	Set the private VLAN promiscuous mapping
                    	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PrivateVlan.Mapping>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Switchport.PrivateVlan, self).__init__()

                        self.yang_name = "private-vlan"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("association", ("association", Native.Interface.HundredGigE.Switchport.PrivateVlan.Association)), ("host-association", ("host_association", Native.Interface.HundredGigE.Switchport.PrivateVlan.HostAssociation)), ("mapping", ("mapping", Native.Interface.HundredGigE.Switchport.PrivateVlan.Mapping))])
                        self._leafs = OrderedDict()

                        self.association = Native.Interface.HundredGigE.Switchport.PrivateVlan.Association()
                        self.association.parent = self
                        self._children_name_map["association"] = "association"

                        self.host_association = Native.Interface.HundredGigE.Switchport.PrivateVlan.HostAssociation()
                        self.host_association.parent = self
                        self._children_name_map["host_association"] = "host-association"

                        self.mapping = Native.Interface.HundredGigE.Switchport.PrivateVlan.Mapping()
                        self.mapping.parent = self
                        self._children_name_map["mapping"] = "mapping"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:private-vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Switchport.PrivateVlan, [], name, value)


                    class Association(Entity):
                        """
                        Set the private VLAN association
                        
                        .. attribute:: host
                        
                        	Set the private VLAN host association
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PrivateVlan.Association.Host>`
                        
                        .. attribute:: mapping
                        
                        	Set the private VLAN promiscuous mapping
                        	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switchport.PrivateVlan.Association.Mapping>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.PrivateVlan.Association, self).__init__()

                            self.yang_name = "association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.Interface.HundredGigE.Switchport.PrivateVlan.Association.Host)), ("mapping", ("mapping", Native.Interface.HundredGigE.Switchport.PrivateVlan.Association.Mapping))])
                            self._leafs = OrderedDict()

                            self.host = Native.Interface.HundredGigE.Switchport.PrivateVlan.Association.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.mapping = Native.Interface.HundredGigE.Switchport.PrivateVlan.Association.Mapping()
                            self.mapping.parent = self
                            self._children_name_map["mapping"] = "mapping"
                            self._segment_path = lambda: "association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.PrivateVlan.Association, [], name, value)


                        class Host(Entity):
                            """
                            Set the private VLAN host association
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary normal range VLAN ID of the private VLAN host port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Switchport.PrivateVlan.Association.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Switchport.PrivateVlan.Association.Host, [u'primary_range', u'secondary_range'], name, value)


                        class Mapping(Entity):
                            """
                            Set the private VLAN promiscuous mapping
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: remove
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Switchport.PrivateVlan.Association.Mapping, self).__init__()

                                self.yang_name = "mapping"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self.add = None
                                self.remove = None
                                self._segment_path = lambda: "mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Switchport.PrivateVlan.Association.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                    class HostAssociation(Entity):
                        """
                        Set the private VLAN host association
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary normal range VLAN ID of the private VLAN host port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.PrivateVlan.HostAssociation, self).__init__()

                            self.yang_name = "host-association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self._segment_path = lambda: "host-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.PrivateVlan.HostAssociation, [u'primary_range', u'secondary_range'], name, value)


                    class Mapping(Entity):
                        """
                        Set the private VLAN promiscuous mapping
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: add
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: remove
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Switchport.PrivateVlan.Mapping, self).__init__()

                            self.yang_name = "mapping"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self.add = None
                            self.remove = None
                            self._segment_path = lambda: "mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Switchport.PrivateVlan.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                class Vepa(Entity):
                    """
                    Reflective relay configuration
                    
                    .. attribute:: enabled
                    
                    	Enable reflective relay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Switchport.Vepa, self).__init__()

                        self.yang_name = "vepa"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                        ])
                        self.enabled = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:vepa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Switchport.Vepa, [u'enabled'], name, value)


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.HundredGigE.Backup.Delay)), ("interface", ("interface", Native.Interface.HundredGigE.Backup.Interface_)), ("load", ("load", Native.Interface.HundredGigE.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.HundredGigE.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.HundredGigE.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.HundredGigE.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.HundredGigE.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.HundredGigE.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.HundredGigE.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.HundredGigE.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.HundredGigE.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.HundredGigE.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.HundredGigE.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.HundredGigE.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.HundredGigE.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.HundredGigE.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.HundredGigE.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.HundredGigE.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.HundredGigE.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.HundredGigE.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.HundredGigE.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.HundredGigE.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.HundredGigE.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.HundredGigE.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.HundredGigE.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.HundredGigE.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.HundredGigE.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.HundredGigE.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.HundredGigE.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.HundredGigE.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.HundredGigE.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.HundredGigE.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.HundredGigE.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.HundredGigE.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.HundredGigE.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.HundredGigE.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.HundredGigE.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.HundredGigE.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.HundredGigE.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.HundredGigE.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.HundredGigE.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.HundredGigE.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.HundredGigE.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.HundredGigE.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.HundredGigE.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.HundredGigE.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.HundredGigE.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.HundredGigE.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.HundredGigE.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.HundredGigE.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.HundredGigE.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.HundredGigE.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.HundredGigE.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.HundredGigE.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.HundredGigE.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.HundredGigE.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.HundredGigE.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.HundredGigE.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.HundredGigE.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.HundredGigE.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.HundredGigE.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.HundredGigE.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.HundredGigE.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.HundredGigE.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.HundredGigE.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.HundredGigE.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.HundredGigE.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.HundredGigE.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.HundredGigE.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.HundredGigE.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.HundredGigE.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.HundredGigE.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.HundredGigE.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.HundredGigE.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.HundredGigE.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.HundredGigE.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.HundredGigE.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.HundredGigE.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.HundredGigE.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.HundredGigE.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.HundredGigE.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.HundredGigE.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.HundredGigE.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.HundredGigE.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.HundredGigE.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.HundredGigE.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.HundredGigE.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.HundredGigE.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.HundredGigE.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.HundredGigE.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.HundredGigE.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.HundredGigE.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.HundredGigE.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.HundredGigE.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.HundredGigE.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.HundredGigE.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.HundredGigE.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.HundredGigE.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.HundredGigE.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.HundredGigE.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.HundredGigE.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.HundredGigE.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.HundredGigE.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.HundredGigE.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.HundredGigE.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.HundredGigE.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.HundredGigE.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.HundredGigE.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.HundredGigE.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.HundredGigE.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.HundredGigE.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.HundredGigE.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Igmp>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Flow>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Nbar>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf>`
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Lisp>`
                
                .. attribute:: rsvp
                
                	RSVP Interface Commands
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Nat>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.HundredGigE.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.HundredGigE.Ip.Arp)), ("vrf", ("vrf", Native.Interface.HundredGigE.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.HundredGigE.Ip.NoAddress)), ("address", ("address", Native.Interface.HundredGigE.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.HundredGigE.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.HundredGigE.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.HundredGigE.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.HundredGigE.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.HundredGigE.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.HundredGigE.Ip.Pim)), ("policy", ("policy", Native.Interface.HundredGigE.Ip.Policy)), ("rip", ("rip", Native.Interface.HundredGigE.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.HundredGigE.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.HundredGigE.Ip.RouteCache)), ("router", ("router", Native.Interface.HundredGigE.Ip.Router)), ("tcp", ("tcp", Native.Interface.HundredGigE.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.HundredGigE.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.HundredGigE.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.HundredGigE.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.HundredGigE.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.HundredGigE.Ip.Igmp)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.HundredGigE.Ip.Flow)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.HundredGigE.Ip.Nbar)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.HundredGigE.Ip.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.HundredGigE.Ip.Lisp)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Interface.HundredGigE.Ip.Rsvp)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.HundredGigE.Ip.Nat)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.HundredGigE.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None
                    self.unreachables = None

                    self.access_group = Native.Interface.HundredGigE.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.HundredGigE.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.HundredGigE.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.HundredGigE.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.HundredGigE.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.HundredGigE.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.HundredGigE.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.HundredGigE.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.HundredGigE.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.HundredGigE.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.HundredGigE.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.HundredGigE.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.HundredGigE.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.HundredGigE.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.HundredGigE.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.HundredGigE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.HundredGigE.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.HundredGigE.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.HundredGigE.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.flow = Native.Interface.HundredGigE.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.nbar = Native.Interface.HundredGigE.Ip.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.ospf = Native.Interface.HundredGigE.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.lisp = Native.Interface.HundredGigE.Ip.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                    self.rsvp = Native.Interface.HundredGigE.Ip.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

                    self.nat = Native.Interface.HundredGigE.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.wccp = Native.Interface.HundredGigE.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache', 'unreachables'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.HundredGigE.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.HundredGigE.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.HundredGigE.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.HundredGigE.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.HundredGigE.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.HundredGigE.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.HundredGigE.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.HundredGigE.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.HundredGigE.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.HundredGigE.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.HundredGigE.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.HundredGigE.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.HundredGigE.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.HundredGigE.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.HundredGigE.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.HundredGigE.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.HundredGigE.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.HundredGigE.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.HundredGigE.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.HundredGigE.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.HundredGigE.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.HundredGigE.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.HundredGigE.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.HundredGigE.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.HundredGigE.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.HundredGigE.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.HundredGigE.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.HundredGigE.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.HundredGigE.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.HundredGigE.Ip.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ip.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ip.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.HundredGigE.Ip.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.HundredGigE.Ip.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.HundredGigE.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.HundredGigE.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.HundredGigE.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.HundredGigE.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.HundredGigE.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.HundredGigE.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.HundredGigE.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.HundredGigE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.HundredGigE.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.HundredGigE.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.HundredGigE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.HundredGigE.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.HundredGigE.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.HundredGigE.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.HundredGigE.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.HundredGigE.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.HundredGigE.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.HundredGigE.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.HundredGigE.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.HundredGigE.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.HundredGigE.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.HundredGigE.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.HundredGigE.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.HundredGigE.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.HundredGigE.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.HundredGigE.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.HundredGigE.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.HundredGigE.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.HundredGigE.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.HundredGigE.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.HundredGigE.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.HundredGigE.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.HundredGigE.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.HundredGigE.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.HundredGigE.Ip.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ip.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.HundredGigE.Ip.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.HundredGigE.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.HundredGigE.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.HundredGigE.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.HundredGigE.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.HundredGigE.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.HundredGigE.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.HundredGigE.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.HundredGigE.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.HundredGigE.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.HundredGigE.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.HundredGigE.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.HundredGigE.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.HundredGigE.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.HundredGigE.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.HundredGigE.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.HundredGigE.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.HundredGigE.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.HundredGigE.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.HundredGigE.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.HundredGigE.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.HundredGigE.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.HundredGigE.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.HundredGigE.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.HundredGigE.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Lisp(Entity):
                    """
                    Locator/ID Separation Protocol
                    
                    .. attribute:: source_locator
                    
                    	Choose IP source address for LISP packets egressing this interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_locator', (YLeaf(YType.str, 'source-locator'), ['str'])),
                        ])
                        self.source_locator = None
                        self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Lisp, ['source_locator'], name, value)


                class Rsvp(Entity):
                    """
                    RSVP Interface Commands
                    
                    .. attribute:: authentication
                    
                    	Enables RSVP neighbor authentication (RFC 2747)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bandwidth
                    
                    	RSVP Reservable Bandwidth (kbps)
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	Select permissible RSVP neighbors
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Neighbor>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: precedence
                    
                    	RSVP precedence setting
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Precedence>`
                    
                    .. attribute:: signalling
                    
                    	RSVP signalling
                    	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Signalling>`
                    
                    .. attribute:: tos
                    
                    	RSVP TOS setting
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Tos>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.HundredGigE.Ip.Rsvp.Authentication)), ("bandwidth", ("bandwidth", Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth)), ("neighbor", ("neighbor", Native.Interface.HundredGigE.Ip.Rsvp.Neighbor)), ("precedence", ("precedence", Native.Interface.HundredGigE.Ip.Rsvp.Precedence)), ("signalling", ("signalling", Native.Interface.HundredGigE.Ip.Rsvp.Signalling)), ("tos", ("tos", Native.Interface.HundredGigE.Ip.Rsvp.Tos))])
                        self._leafs = OrderedDict()

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.bandwidth = None
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.neighbor = None
                        self._children_name_map["neighbor"] = "neighbor"

                        self.precedence = Native.Interface.HundredGigE.Ip.Rsvp.Precedence()
                        self.precedence.parent = self
                        self._children_name_map["precedence"] = "precedence"

                        self.signalling = Native.Interface.HundredGigE.Ip.Rsvp.Signalling()
                        self.signalling.parent = self
                        self._children_name_map["signalling"] = "signalling"

                        self.tos = Native.Interface.HundredGigE.Ip.Rsvp.Tos()
                        self.tos.parent = self
                        self._children_name_map["tos"] = "tos"
                        self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp, [], name, value)


                    class Authentication(Entity):
                        """
                        Enables RSVP neighbor authentication (RFC 2747)
                        
                        .. attribute:: key
                        
                        	Password (8 to 40 characters, spaces allowed)
                        	**type**\: str
                        
                        .. attribute:: challenge
                        
                        	Perform challenge/response handshake with new neighbor(s)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key_chain
                        
                        	Name of key chain to use (as created by global 'key chain' command)
                        	**type**\: str
                        
                        .. attribute:: lifetime
                        
                        	Maximum lifetime of neighbor authentication state
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Authentication.Lifetime>`
                        
                        .. attribute:: type
                        
                        	Type of authentication algorithm (default = md5)
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Authentication.Type>`
                        
                        .. attribute:: window_size
                        
                        	Maximum number of messages allowed in receive window (default = 1)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Rsvp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Interface.HundredGigE.Ip.Rsvp.Authentication.Lifetime))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ip.Rsvp.Authentication.Type')])),
                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                            ])
                            self.key = None
                            self.challenge = None
                            self.key_chain = None
                            self.type = None
                            self.window_size = None

                            self.lifetime = Native.Interface.HundredGigE.Ip.Rsvp.Authentication.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Authentication, ['key', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Type of authentication algorithm (default = md5)

                            .. data:: md5 = 0

                            .. data:: sha_1 = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            sha_1 = Enum.YLeaf(1, "sha-1")



                        class Lifetime(Entity):
                            """
                            Maximum lifetime of neighbor authentication state
                            
                            .. attribute:: hh_mm_ss
                            
                            	Lifetime (default = 30 mins) in hh\:mm\:ss format
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ])
                                self.hh_mm_ss = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


                    class Bandwidth(Entity):
                        """
                        RSVP Reservable Bandwidth (kbps)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Value>`
                        
                        .. attribute:: percent
                        
                        	Percentage of interface bandwidth. Values higher than 100 represent overbooking
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: mam
                        
                        	Use bandwidth with MAM model of DSTE
                        	**type**\:  :py:class:`Mam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Mam>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Value)), ("mam", ("mam", Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Mam))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                            ])
                            self.percent = None

                            self.value = Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.mam = Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Mam()
                            self.mam.parent = self
                            self._children_name_map["mam"] = "mam"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth, ['percent'], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	Reservable Bandwidth (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            .. attribute:: sub_pool
                            
                            	Reservable Bandwidth for Tunnel using sub (BC1) pool (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.value = None
                                self.sub_pool = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Value, ['value', 'sub_pool'], name, value)


                        class Mam(Entity):
                            """
                            Use bandwidth with MAM model of DSTE
                            
                            .. attribute:: max_reservable_bw
                            
                            	Maximum Reservable bandwidth for MAM
                            	**type**\:  :py:class:`MaxReservableBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Mam, self).__init__()

                                self.yang_name = "mam"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("max-reservable-bw", ("max_reservable_bw", Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw))])
                                self._leafs = OrderedDict()

                                self.max_reservable_bw = None
                                self._children_name_map["max_reservable_bw"] = "max-reservable-bw"
                                self._segment_path = lambda: "mam"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Mam, [], name, value)


                            class MaxReservableBw(Entity):
                                """
                                Maximum Reservable bandwidth for MAM
                                
                                .. attribute:: value
                                
                                	Reservable Bandwidth (kbps)
                                	**type**\: int
                                
                                	**range:** 1..10000000
                                
                                .. attribute:: bc0
                                
                                	Reservable Bandwidth from global (BC0) pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                .. attribute:: bc1
                                
                                	Reservable Bandwidth from sub pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, self).__init__()

                                    self.yang_name = "max-reservable-bw"
                                    self.yang_parent_name = "mam"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                        ('bc0', (YLeaf(YType.uint32, 'bc0'), ['int'])),
                                        ('bc1', (YLeaf(YType.uint32, 'bc1'), ['int'])),
                                    ])
                                    self.value = None
                                    self.bc0 = None
                                    self.bc1 = None
                                    self._segment_path = lambda: "max-reservable-bw"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, ['value', 'bc0', 'bc1'], name, value)


                    class Neighbor(Entity):
                        """
                        Select permissible RSVP neighbors
                        
                        .. attribute:: acl_number
                        
                        	Access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Rsvp.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                            ])
                            self.acl_number = None
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Neighbor, ['acl_number'], name, value)


                    class Precedence(Entity):
                        """
                        RSVP precedence setting
                        
                        .. attribute:: conform
                        
                        	Precedence for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: exceed
                        
                        	Precedence for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Rsvp.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Precedence, ['conform', 'exceed'], name, value)


                    class Signalling(Entity):
                        """
                        RSVP signalling
                        
                        .. attribute:: dscp
                        
                        	DSCP for RSVP signalling messages
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: fast_local_repair
                        
                        	Fast Local Repair parameters
                        	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Signalling.FastLocalRepair>`
                        
                        .. attribute:: hello
                        
                        	Enable neighbor\-down detection
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Rsvp.Signalling, self).__init__()

                            self.yang_name = "signalling"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Interface.HundredGigE.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.fast_local_repair = Native.Interface.HundredGigE.Ip.Rsvp.Signalling.FastLocalRepair()
                            self.fast_local_repair.parent = self
                            self._children_name_map["fast_local_repair"] = "fast-local-repair"

                            self.hello = None
                            self._children_name_map["hello"] = "hello"
                            self._segment_path = lambda: "signalling"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Signalling, ['dscp'], name, value)


                        class FastLocalRepair(Entity):
                            """
                            Fast Local Repair parameters
                            
                            .. attribute:: wait_time
                            
                            	Wait Time for start of Fast Local Repair in msec
                            	**type**\: int
                            
                            	**range:** 0..5000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                                self.yang_name = "fast-local-repair"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint16, 'wait-time'), ['int'])),
                                ])
                                self.wait_time = None
                                self._segment_path = lambda: "fast-local-repair"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Signalling.FastLocalRepair, ['wait_time'], name, value)


                        class Hello(Entity):
                            """
                            Enable neighbor\-down detection
                            
                            .. attribute:: bfd
                            
                            	Configure BFD trigger for MPLS/TE FRR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	DSCP for RSVP Hello messages
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: graceful_restart
                            
                            	Configure RSVP Graceful Restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: refresh
                            
                            	Configure RSVP Hello refresh behavior for Fast\-Reroute
                            	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Refresh>`
                            
                            .. attribute:: reroute
                            
                            	Configure RSVP Hello refresh behavior for Reroute
                            	**type**\:  :py:class:`Reroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Reroute>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Refresh)), ("reroute", ("reroute", Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Reroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ('graceful_restart', (YLeaf(YType.empty, 'graceful-restart'), ['Empty'])),
                                ])
                                self.bfd = None
                                self.dscp = None
                                self.graceful_restart = None

                                self.refresh = Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Refresh()
                                self.refresh.parent = self
                                self._children_name_map["refresh"] = "refresh"

                                self.reroute = Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Reroute()
                                self.reroute.parent = self
                                self._children_name_map["reroute"] = "reroute"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello, ['bfd', 'dscp', 'graceful_restart'], name, value)


                            class Refresh(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Fast\-Reroute
                                
                                .. attribute:: interval
                                
                                	Hello interval in msec
                                	**type**\: int
                                
                                	**range:** 10..30000
                                
                                .. attribute:: misses
                                
                                	Number of missed Hello Acks which triggers neighbor down
                                	**type**\: int
                                
                                	**range:** 4..10
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Refresh, self).__init__()

                                    self.yang_name = "refresh"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.misses = None
                                    self._segment_path = lambda: "refresh"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Refresh, ['interval', 'misses'], name, value)


                            class Reroute(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Reroute
                                
                                .. attribute:: dscp
                                
                                	DSCP for RSVP Hello messages
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: refresh
                                
                                	Configure RSVP Reroute Hello refresh behavior
                                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Reroute.Refresh>`
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Reroute, self).__init__()

                                    self.yang_name = "reroute"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Reroute.Refresh))])
                                    self._leafs = OrderedDict([
                                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ])
                                    self.dscp = None

                                    self.refresh = Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Reroute.Refresh()
                                    self.refresh.parent = self
                                    self._children_name_map["refresh"] = "refresh"
                                    self._segment_path = lambda: "reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Reroute, ['dscp'], name, value)


                                class Refresh(Entity):
                                    """
                                    Configure RSVP Reroute Hello refresh behavior
                                    
                                    .. attribute:: interval
                                    
                                    	Hello Reroute interval in msec
                                    	**type**\: int
                                    
                                    	**range:** 1000..30000
                                    
                                    .. attribute:: misses
                                    
                                    	Number of missed Hello Acks which triggers neighbor down
                                    	**type**\: int
                                    
                                    	**range:** 4..10
                                    
                                    

                                    """

                                    _prefix = 'ios-rsvp'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, self).__init__()

                                        self.yang_name = "refresh"
                                        self.yang_parent_name = "reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.misses = None
                                        self._segment_path = lambda: "refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, ['interval', 'misses'], name, value)


                    class Tos(Entity):
                        """
                        RSVP TOS setting
                        
                        .. attribute:: conform
                        
                        	TOS for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: exceed
                        
                        	TOS for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Rsvp.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Rsvp.Tos, ['conform', 'exceed'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.HundredGigE.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.HundredGigE.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.HundredGigE.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.HundredGigE.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.HundredGigE.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.HundredGigE.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.HundredGigE.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.HundredGigE.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.HundredGigE.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.HundredGigE.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.HundredGigE.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.HundredGigE.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.HundredGigE.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.HundredGigE.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.HundredGigE.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.HundredGigE.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.HundredGigE.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.HundredGigE.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.HundredGigE.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.TrafficFilter>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Flow>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Crypto>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Pim>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: rip
                
                	Configure RIP routing protocol
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Rip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.HundredGigE.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.HundredGigE.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.HundredGigE.Ipv6.Dhcp)), ("address", ("address", Native.Interface.HundredGigE.Ipv6.Address)), ("nd", ("nd", Native.Interface.HundredGigE.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.HundredGigE.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.HundredGigE.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.HundredGigE.Ipv6.Flow)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.HundredGigE.Ipv6.Crypto)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.HundredGigE.Ipv6.Ospf)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.HundredGigE.Ipv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.HundredGigE.Ipv6.Pim)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Interface.HundredGigE.Ipv6.Rip))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None
                    self.unreachables = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.HundredGigE.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.HundredGigE.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.HundredGigE.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.HundredGigE.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.flow = Native.Interface.HundredGigE.Ipv6.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.crypto = Native.Interface.HundredGigE.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.ospf = Native.Interface.HundredGigE.Ipv6.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.no_pim = Native.Interface.HundredGigE.Ipv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.HundredGigE.Ipv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects', 'unreachables'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.HundredGigE.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.HundredGigE.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.HundredGigE.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.HundredGigE.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.HundredGigE.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.HundredGigE.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.HundredGigE.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.HundredGigE.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.HundredGigE.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.HundredGigE.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.HundredGigE.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.HundredGigE.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.HundredGigE.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.HundredGigE.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.HundredGigE.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.HundredGigE.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.HundredGigE.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.HundredGigE.Ipv6.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.HundredGigE.Ipv6.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ipv6.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ipv6.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Crypto, ['map'], name, value)


                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process
                    
                    	
                    	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Process>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: encryption
                    
                    	Enable encryption
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Network>`
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process", ("process", Native.Interface.HundredGigE.Ipv6.Ospf.Process)), ("authentication", ("authentication", Native.Interface.HundredGigE.Ipv6.Ospf.Authentication)), ("bfd", ("bfd", Native.Interface.HundredGigE.Ipv6.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.HundredGigE.Ipv6.Ospf.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.HundredGigE.Ipv6.Ospf.DemandCircuit)), ("encryption", ("encryption", Native.Interface.HundredGigE.Ipv6.Ospf.Encryption)), ("flood-reduction", ("flood_reduction", Native.Interface.HundredGigE.Ipv6.Ospf.FloodReduction)), ("mtu-ignore", ("mtu_ignore", Native.Interface.HundredGigE.Ipv6.Ospf.MtuIgnore)), ("neighbor", ("neighbor", Native.Interface.HundredGigE.Ipv6.Ospf.Neighbor)), ("network", ("network", Native.Interface.HundredGigE.Ipv6.Ospf.Network)), ("shutdown", ("shutdown", Native.Interface.HundredGigE.Ipv6.Ospf.Shutdown))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.cost = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.HundredGigE.Ipv6.Ospf.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.HundredGigE.Ipv6.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.encryption = Native.Interface.HundredGigE.Ipv6.Ospf.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.network = Native.Interface.HundredGigE.Ipv6.Ospf.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.process = YList(self)
                        self.neighbor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf, ['cost', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Process(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: instance
                        
                        	Set the OSPF instance
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..31
                        
                        		**type**\: int
                        
                        			**range:** 32..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Ospf.Process, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['int','int'])),
                            ])
                            self.id = None
                            self.area = None
                            self.instance = None
                            self._segment_path = lambda: "process" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Process, ['id', 'area', 'instance'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec authentication
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec authentication
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 256..4294967295
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5>`
                            
                            .. attribute:: sha1
                            
                            	Use SHA\-1 authentication
                            	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ])
                                self.spi = None

                                self.md5 = Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.sha1 = Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1()
                                self.sha1.parent = self
                                self._children_name_map["sha1"] = "sha1"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec, ['spi'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Sha1(Entity):
                                """
                                Use SHA\-1 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1, self).__init__()

                                    self.yang_name = "sha1"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "sha1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "sha1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ipv6.Ospf.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.DatabaseFilter, ['all', 'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.DemandCircuit, ['disable', 'ignore'], name, value)


                    class Encryption(Entity):
                        """
                        Enable encryption
                        
                        .. attribute:: null
                        
                        	No IPsec encryption on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec encryption
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec encryption
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: esp
                            
                            	Use ESP encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipsec_3des
                            
                            	Use 3DES encryption
                            	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des>`
                            
                            .. attribute:: aes_cbc
                            
                            	Use AES\-CBC encryption
                            	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                                ])
                                self.spi = None
                                self.esp = None

                                self.ipsec_3des = Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des()
                                self.ipsec_3des.parent = self
                                self._children_name_map["ipsec_3des"] = "ipsec_3des"

                                self.aes_cbc = Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc()
                                self.aes_cbc.parent = self
                                self._children_name_map["aes_cbc"] = "aes-cbc"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec, ['spi', 'esp'], name, value)


                            class Ipsec3des(Entity):
                                """
                                Use 3DES encryption
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, self).__init__()

                                    self.yang_name = "ipsec_3des"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "ipsec_3des"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "ipsec_3des"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class AesCbc(Entity):
                                """
                                Use AES\-CBC encryption
                                
                                .. attribute:: aes_cbc_128
                                
                                	Use 128 bit key
                                	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128>`
                                
                                .. attribute:: aes_192
                                
                                	Use 192 bit key
                                	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192>`
                                
                                .. attribute:: aes_256
                                
                                	Use 256 bit key
                                	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc, self).__init__()

                                    self.yang_name = "aes-cbc"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256))])
                                    self._leafs = OrderedDict()

                                    self.aes_cbc_128 = Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128()
                                    self.aes_cbc_128.parent = self
                                    self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                    self.aes_192 = Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192()
                                    self.aes_192.parent = self
                                    self._children_name_map["aes_192"] = "aes-192"

                                    self.aes_256 = Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256()
                                    self.aes_256.parent = self
                                    self._children_name_map["aes_256"] = "aes-256"
                                    self._segment_path = lambda: "aes-cbc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc, [], name, value)


                                class AesCbc128(Entity):
                                    """
                                    Use 128 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                        self.yang_name = "aes-cbc-128"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-cbc-128"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-cbc-128"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes192(Entity):
                                    """
                                    Use 192 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                        self.yang_name = "aes-192"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-192"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-192"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes256(Entity):
                                    """
                                    Use 256 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                        self.yang_name = "aes-256"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-256"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	Disable Flood Reduction on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Ospf.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.FloodReduction, ['disable'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Ospf.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.MtuIgnore, ['disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Ospf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.HundredGigE.Ipv6.Ospf.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.HundredGigE.Ipv6.Ospf.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ipv6.Ospf.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ipv6.Ospf.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Ospf.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Ospf.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.HundredGigE.Ipv6.Ospf.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ipv6.Ospf.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Ospf.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Ospf.Shutdown, ['disable'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.HundredGigE.Ipv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.HundredGigE.Ipv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Pim.Bsr, ['border'], name, value)


                class Rip(Entity):
                    """
                    Configure RIP routing protocol
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable/disable RIP routing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default_information
                    
                    	Configure handling of default route
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Rip.DefaultInformation>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ipv6.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("default-information", ("default_information", Native.Interface.HundredGigE.Ipv6.Rip.DefaultInformation))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.id = None
                        self.enable = None

                        self.default_information = Native.Interface.HundredGigE.Ipv6.Rip.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Rip, ['id', 'enable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Configure handling of default route
                        
                        .. attribute:: route
                        
                        	
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ipv6.Rip.DefaultInformation.Route>`
                        
                        .. attribute:: metric
                        
                        	Default route metric
                        	**type**\: int
                        
                        	**range:** 1..15
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ipv6.Rip.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route', (YLeaf(YType.enumeration, 'route'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ipv6.Rip.DefaultInformation.Route')])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ])
                            self.route = None
                            self.metric = None
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ipv6.Rip.DefaultInformation, ['route', 'metric'], name, value)

                        class Route(Enum):
                            """
                            Route (Enum Class)

                            .. data:: only = 0

                            .. data:: originate = 1

                            """

                            only = Enum.YLeaf(0, "only")

                            originate = Enum.YLeaf(1, "originate")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.HundredGigE.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.HundredGigE.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.HundredGigE.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.HundredGigE.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.HundredGigE.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.HundredGigE.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.HundredGigE.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.HundredGigE.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.HundredGigE.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.HundredGigE.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.HundredGigE.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.HundredGigE.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.HundredGigE.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.HundredGigE.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.HundredGigE.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.HundredGigE.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.HundredGigE.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.HundredGigE.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.HundredGigE.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.HundredGigE.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.HundredGigE.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.HundredGigE.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.HundredGigE.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.HundredGigE.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.HundredGigE.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.HundredGigE.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.HundredGigE.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.HundredGigE.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.HundredGigE.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.HundredGigE.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.HundredGigE.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.HundredGigE.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.HundredGigE.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.HundredGigE.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.HundredGigE.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.HundredGigE.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.HundredGigE.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.HundredGigE.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.HundredGigE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.HundredGigE.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.HundredGigE.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.HundredGigE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.HundredGigE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.HundredGigE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.HundredGigE.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.HundredGigE.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.HundredGigE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.HundredGigE.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.HundredGigE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.HundredGigE.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.HundredGigE.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.HundredGigE.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.HundredGigE.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.HundredGigE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.HundredGigE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.HundredGigE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.HundredGigE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.HundredGigE.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.HundredGigE.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.HundredGigE.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.HundredGigE.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.HundredGigE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.HundredGigE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.HundredGigE.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.HundredGigE.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.HundredGigE.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.HundredGigE.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.HundredGigE.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.HundredGigE.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.HundredGigE.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.HundredGigE.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.HundredGigE.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.HundredGigE.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.HundredGigE.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.HundredGigE.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.HundredGigE.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.HundredGigE.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.HundredGigE.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.HundredGigE.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.HundredGigE.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.HundredGigE.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.HundredGigE.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.HundredGigE.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.HundredGigE.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.HundredGigE.CarrierDelay.Down)), ("up", ("up", Native.Interface.HundredGigE.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.HundredGigE.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.HundredGigE.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.HundredGigE.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.HundredGigE.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.HundredGigE.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.HundredGigE.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.HundredGigE.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.HundredGigE.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.HundredGigE.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.HundredGigE.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.HundredGigE.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.HundredGigE.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.HundredGigE.Plim.Ethernet)), ("qos", ("qos", Native.Interface.HundredGigE.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.HundredGigE.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.HundredGigE.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.HundredGigE.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.HundredGigE.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.HundredGigE.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.HundredGigE.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.HundredGigE.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.HundredGigE.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.HundredGigE.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.HundredGigE.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.HundredGigE.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.HundredGigE.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.HundredGigE.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.HundredGigE.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.HundredGigE.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.HundredGigE.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.HundredGigE.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.HundredGigE.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.HundredGigE.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.HundredGigE.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.L2protocol>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.HundredGigE.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.HundredGigE.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.HundredGigE.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.HundredGigE.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.HundredGigE.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.HundredGigE.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.HundredGigE.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.HundredGigE.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.HundredGigE.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.HundredGigE.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.HundredGigE.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.HundredGigE.Service.Instance.L2protocol)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.HundredGigE.Service.Instance.Xconnect)), ("Cisco-IOS-XE-l2vpn:xconnect-pw-class", ("xconnect_pw_class", Native.Interface.HundredGigE.Service.Instance.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.HundredGigE.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.HundredGigE.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.HundredGigE.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.HundredGigE.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.HundredGigE.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.HundredGigE.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.HundredGigE.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.HundredGigE.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.HundredGigE.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.HundredGigE.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.HundredGigE.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.HundredGigE.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"

                        self.xconnect = Native.Interface.HundredGigE.Service.Instance.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                        self.xconnect_pw_class = Native.Interface.HundredGigE.Service.Instance.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.HundredGigE.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.HundredGigE.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.HundredGigE.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.HundredGigE.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.HundredGigE.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.HundredGigE.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.HundredGigE.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.HundredGigE.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.HundredGigE.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.HundredGigE.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.HundredGigE.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.HundredGigE.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.HundredGigE.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.HundredGigE.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.HundredGigE.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.HundredGigE.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.HundredGigE.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.HundredGigE.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.HundredGigE.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.HundredGigE.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.HundredGigE.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.HundredGigE.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.HundredGigE.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.HundredGigE.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.HundredGigE.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.HundredGigE.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.HundredGigE.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.HundredGigE.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.HundredGigE.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.HundredGigE.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.HundredGigE.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.HundredGigE.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Service.Instance.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Service.Instance.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class CiscoIOSXEEthernetMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: dot1q_in_clear
                    
                    	Dot1q in Clear option
                    	**type**\:  :py:class:`Dot1qInClear <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear>`
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('dot1q_in_clear', (YLeaf(YType.enumeration, 'dot1q-in-clear'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec.Dot1qInClear')])),
                        ])
                        self.dot1q_in_clear = None

                        self.replay_protection = Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec, ['dot1q_in_clear'], name, value)

                    class Dot1qInClear(Enum):
                        """
                        Dot1qInClear (Enum Class)

                        Dot1q in Clear option

                        .. data:: Y_1 = 0

                        """

                        Y_1 = Enum.YLeaf(0, "1")



                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.CiscoIOSXEEthernetMacsecOption.Macsec.ReplayProtection, ['window_size'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.HundredGigE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.HundredGigE.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.HundredGigE.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.HundredGigE.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.HundredGigE.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.HundredGigE.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.HundredGigE.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Auto(Entity):
                """
                Configure Automation
                
                .. attribute:: qos
                
                	Configure AutoQoS
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Auto.Qos>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Auto, self).__init__()

                    self.yang_name = "auto"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("qos", ("qos", Native.Interface.HundredGigE.Auto.Qos))])
                    self._leafs = OrderedDict()

                    self.qos = Native.Interface.HundredGigE.Auto.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:auto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Auto, [], name, value)


                class Qos(Entity):
                    """
                    Configure AutoQoS
                    
                    .. attribute:: classify
                    
                    	Configure classification for untrusted devices
                    	**type**\:  :py:class:`Classify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Auto.Qos.Classify>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trust
                    
                    	Trust the DSCP/CoS marking
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Auto.Qos.Trust>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: video
                    
                    	Configure AutoQoS for video devices
                    	**type**\:  :py:class:`Video <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Auto.Qos.Video>`
                    
                    .. attribute:: voip
                    
                    	Configure AutoQoS for VoIP
                    	**type**\:  :py:class:`Voip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Auto.Qos.Voip>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Auto.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "auto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("classify", ("classify", Native.Interface.HundredGigE.Auto.Qos.Classify)), ("trust", ("trust", Native.Interface.HundredGigE.Auto.Qos.Trust)), ("video", ("video", Native.Interface.HundredGigE.Auto.Qos.Video)), ("voip", ("voip", Native.Interface.HundredGigE.Auto.Qos.Voip))])
                        self._leafs = OrderedDict()

                        self.classify = None
                        self._children_name_map["classify"] = "classify"

                        self.trust = None
                        self._children_name_map["trust"] = "trust"

                        self.video = Native.Interface.HundredGigE.Auto.Qos.Video()
                        self.video.parent = self
                        self._children_name_map["video"] = "video"

                        self.voip = None
                        self._children_name_map["voip"] = "voip"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Auto.Qos, [], name, value)


                    class Classify(Entity):
                        """
                        Configure classification for untrusted devices
                        
                        .. attribute:: police
                        
                        	Configure QoS policing for untrusted devices
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Auto.Qos.Classify, self).__init__()

                            self.yang_name = "classify"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('police', (YLeaf(YType.empty, 'police'), ['Empty'])),
                            ])
                            self.police = None
                            self._segment_path = lambda: "classify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Auto.Qos.Classify, [u'police'], name, value)


                    class Trust(Entity):
                        """
                        Trust the DSCP/CoS marking
                        
                        .. attribute:: cos
                        
                        	Trust the CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	Trust the DSCP marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Auto.Qos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cos', (YLeaf(YType.empty, 'cos'), ['Empty'])),
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ])
                            self.cos = None
                            self.dscp = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Auto.Qos.Trust, [u'cos', u'dscp'], name, value)


                    class Video(Entity):
                        """
                        Configure AutoQoS for video devices
                        
                        .. attribute:: cts
                        
                        	Trust the QoS marking of the Cisco Telepresence System
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ip_camera
                        
                        	Trust the QoS marking of the Ip Video Surveillance camera
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: media_player
                        
                        	Trust the Qos marking of the Cisco Media Player
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Auto.Qos.Video, self).__init__()

                            self.yang_name = "video"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('cts', (YLeaf(YType.empty, 'cts'), ['Empty'])),
                                ('ip_camera', (YLeaf(YType.empty, 'ip-camera'), ['Empty'])),
                                ('media_player', (YLeaf(YType.empty, 'media-player'), ['Empty'])),
                            ])
                            self.cts = None
                            self.ip_camera = None
                            self.media_player = None
                            self._segment_path = lambda: "video"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Auto.Qos.Video, [u'cts', u'ip_camera', u'media_player'], name, value)


                    class Voip(Entity):
                        """
                        Configure AutoQoS for VoIP
                        
                        .. attribute:: cisco_phone
                        
                        	Trust the QoS marking of Cisco IP Phone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cisco_softphone
                        
                        	Trust the QoS marking of Cisco IP SoftPhone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trust
                        
                        	Trust the DSCP/CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Auto.Qos.Voip, self).__init__()

                            self.yang_name = "voip"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cisco_phone', (YLeaf(YType.empty, 'cisco-phone'), ['Empty'])),
                                ('cisco_softphone', (YLeaf(YType.empty, 'cisco-softphone'), ['Empty'])),
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.cisco_phone = None
                            self.cisco_softphone = None
                            self.trust = None
                            self._segment_path = lambda: "voip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Auto.Qos.Voip, [u'cisco_phone', u'cisco_softphone', u'trust'], name, value)


            class Datalink(Entity):
                """
                Interface Datalink commands
                
                .. attribute:: flow
                
                	Interface Flow configuration subcommands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Datalink.Flow>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Datalink, self).__init__()

                    self.yang_name = "datalink"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flow", ("flow", Native.Interface.HundredGigE.Datalink.Flow))])
                    self._leafs = OrderedDict()

                    self.flow = Native.Interface.HundredGigE.Datalink.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:datalink"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Datalink, [], name, value)


                class Flow(Entity):
                    """
                    Interface Flow configuration subcommands
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Datalink.Flow.Monitor>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Datalink.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "datalink"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.HundredGigE.Datalink.Flow.Monitor))])
                        self._leafs = OrderedDict()

                        self.monitor = None
                        self._children_name_map["monitor"] = "monitor"
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Datalink.Flow, [], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: user_defined_flow
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: input_output
                        
                        	Apply Flow Monitor on input/output traffic
                        	**type**\:  :py:class:`InputOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Datalink.Flow.Monitor.InputOutput>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Datalink.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('user_defined_flow', (YLeaf(YType.str, 'User-defined-flow'), ['str'])),
                                ('input_output', (YLeaf(YType.enumeration, 'input-output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Datalink.Flow.Monitor.InputOutput')])),
                            ])
                            self.user_defined_flow = None
                            self.input_output = None
                            self._segment_path = lambda: "monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Datalink.Flow.Monitor, [u'user_defined_flow', u'input_output'], name, value)

                        class InputOutput(Enum):
                            """
                            InputOutput (Enum Class)

                            Apply Flow Monitor on input/output traffic

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



            class Energywise(Entity):
                """
                EnergyWise interface configurations
                
                .. attribute:: activitycheck
                
                	Apply an activity check before turning off power    to this PoE port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: level
                
                	Set the EnergyWise level of this interface  or attached entity
                	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Energywise.Level>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Energywise, self).__init__()

                    self.yang_name = "energywise"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Interface.HundredGigE.Energywise.Level))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('activitycheck', (YLeaf(YType.empty, 'activitycheck'), ['Empty'])),
                    ])
                    self.activitycheck = None

                    self.level = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:energywise"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Energywise, [u'activitycheck'], name, value)


                class Level(Entity):
                    """
                    Set the EnergyWise level of this interface 
                    or attached entity
                    
                    .. attribute:: range  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..10
                    
                    .. attribute:: recurrence
                    
                    	Specify that this level setting should  recur at the specified time
                    	**type**\:  :py:class:`Recurrence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Energywise.Level.Recurrence>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Energywise.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "energywise"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("recurrence", ("recurrence", Native.Interface.HundredGigE.Energywise.Level.Recurrence))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                        ])
                        self.range = None

                        self.recurrence = Native.Interface.HundredGigE.Energywise.Level.Recurrence()
                        self.recurrence.parent = self
                        self._children_name_map["recurrence"] = "recurrence"
                        self._segment_path = lambda: "level" + "[range='" + str(self.range) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Energywise.Level, [u'range'], name, value)


                    class Recurrence(Entity):
                        """
                        Specify that this level setting should 
                        recur at the specified time
                        
                        .. attribute:: importance
                        
                        	Specify the importance at which the event  should be sent when it recurs
                        	**type**\: list of  		 :py:class:`Importance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Energywise.Level.Recurrence.Importance>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Energywise.Level.Recurrence, self).__init__()

                            self.yang_name = "recurrence"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("importance", ("importance", Native.Interface.HundredGigE.Energywise.Level.Recurrence.Importance))])
                            self._leafs = OrderedDict()

                            self.importance = YList(self)
                            self._segment_path = lambda: "recurrence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Energywise.Level.Recurrence, [], name, value)


                        class Importance(Entity):
                            """
                            Specify the importance at which the event 
                            should be sent when it recurs
                            
                            .. attribute:: range  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: at
                            
                            	Specify the time(s) this level setting should occur
                            	**type**\:  :py:class:`At <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Energywise.Level.Recurrence.Importance.At>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Energywise.Level.Recurrence.Importance, self).__init__()

                                self.yang_name = "importance"
                                self.yang_parent_name = "recurrence"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("at", ("at", Native.Interface.HundredGigE.Energywise.Level.Recurrence.Importance.At))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.at = Native.Interface.HundredGigE.Energywise.Level.Recurrence.Importance.At()
                                self.at.parent = self
                                self._children_name_map["at"] = "at"
                                self._segment_path = lambda: "importance" + "[range='" + str(self.range) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Energywise.Level.Recurrence.Importance, [u'range'], name, value)


                            class At(Entity):
                                """
                                Specify the time(s) this level setting should occur
                                
                                .. attribute:: minute
                                
                                	cron format of minute(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..59
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: hour
                                
                                	cron format of hour(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..23
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: day
                                
                                	cron format of day(s) of month
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..31
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: month
                                
                                	cron format of month(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..12
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: weekday
                                
                                	cron format of weekday(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..7
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Energywise.Level.Recurrence.Importance.At, self).__init__()

                                    self.yang_name = "at"
                                    self.yang_parent_name = "importance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minute', (YLeaf(YType.str, 'minute'), ['int','str'])),
                                        ('hour', (YLeaf(YType.str, 'hour'), ['int','str'])),
                                        ('day', (YLeaf(YType.str, 'day'), ['int','str'])),
                                        ('month', (YLeaf(YType.str, 'month'), ['int','str'])),
                                        ('weekday', (YLeaf(YType.str, 'weekday'), ['int','str'])),
                                    ])
                                    self.minute = None
                                    self.hour = None
                                    self.day = None
                                    self.month = None
                                    self.weekday = None
                                    self._segment_path = lambda: "at"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Energywise.Level.Recurrence.Importance.At, [u'minute', u'hour', u'day', u'month', u'weekday'], name, value)


            class Location(Entity):
                """
                Interface location information
                
                .. attribute:: civic_location_id
                
                	Civic location information
                	**type**\:  :py:class:`CivicLocationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Location.CivicLocationId>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Location, self).__init__()

                    self.yang_name = "location"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("civic-location-id", ("civic_location_id", Native.Interface.HundredGigE.Location.CivicLocationId))])
                    self._leafs = OrderedDict()

                    self.civic_location_id = Native.Interface.HundredGigE.Location.CivicLocationId()
                    self.civic_location_id.parent = self
                    self._children_name_map["civic_location_id"] = "civic-location-id"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:location"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Location, [], name, value)


                class CivicLocationId(Entity):
                    """
                    Civic location information
                    
                    .. attribute:: location_identifier
                    
                    	civic location identifier string
                    	**type**\: str
                    
                    .. attribute:: host
                    
                    	Globally defined host location identifer
                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Location.CivicLocationId.Host>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: none
                    
                    	No globally defined location identifer
                    	**type**\:  :py:class:`Y_None <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Location.CivicLocationId.Y_None>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Location.CivicLocationId, self).__init__()

                        self.yang_name = "civic-location-id"
                        self.yang_parent_name = "location"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("host", ("host", Native.Interface.HundredGigE.Location.CivicLocationId.Host)), ("none", ("none", Native.Interface.HundredGigE.Location.CivicLocationId.Y_None))])
                        self._leafs = OrderedDict([
                            ('location_identifier', (YLeaf(YType.str, 'location-identifier'), ['str'])),
                        ])
                        self.location_identifier = None

                        self.host = None
                        self._children_name_map["host"] = "host"

                        self.none = None
                        self._children_name_map["none"] = "none"
                        self._segment_path = lambda: "civic-location-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Location.CivicLocationId, [u'location_identifier'], name, value)


                    class Host(Entity):
                        """
                        Globally defined host location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Location.CivicLocationId.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "host"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Location.CivicLocationId.Host, [u'port_location'], name, value)


                    class Y_None(Entity):
                        """
                        No globally defined location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Location.CivicLocationId.Y_None, self).__init__()

                            self.yang_name = "none"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Location.CivicLocationId.Y_None, [u'port_location'], name, value)


            class Mac(Entity):
                """
                MAC interface commands
                
                .. attribute:: access_group
                
                	MAC access\-group configuration commands
                	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mac.AccessGroup>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Mac, self).__init__()

                    self.yang_name = "mac"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.HundredGigE.Mac.AccessGroup))])
                    self._leafs = OrderedDict()

                    self.access_group = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:mac"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Mac, [], name, value)


                class AccessGroup(Entity):
                    """
                    MAC access\-group configuration commands
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mac.AccessGroup.Direction>`
                    
                    .. attribute:: acl_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Mac.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "mac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Mac.AccessGroup.Direction')])),
                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                        ])
                        self.direction = None
                        self.acl_name = None
                        self._segment_path = lambda: "access-group" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Mac.AccessGroup, [u'direction', u'acl_name'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Macro(Entity):
                """
                Command macro
                
                .. attribute:: description
                
                	Macro description for this interface
                	**type**\: str
                
                .. attribute:: auto
                
                	Smartport interface macro configurations
                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Macro.Auto>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Macro, self).__init__()

                    self.yang_name = "macro"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.HundredGigE.Macro.Auto))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.auto = Native.Interface.HundredGigE.Macro.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "auto"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macro"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Macro, [u'description'], name, value)


                class Auto(Entity):
                    """
                    Smartport interface macro configurations
                    
                    .. attribute:: processing
                    
                    	Enable smartport macro auto execution on this interface
                    	**type**\: bool
                    
                    .. attribute:: port
                    
                    	Provide interface specific configuration for macro processing
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Macro.Auto.Port>`
                    
                    .. attribute:: control
                    
                    	Control macro auto execution
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Macro.Auto.Control>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Macro.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "macro"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port", ("port", Native.Interface.HundredGigE.Macro.Auto.Port)), ("control", ("control", Native.Interface.HundredGigE.Macro.Auto.Control))])
                        self._leafs = OrderedDict([
                            ('processing', (YLeaf(YType.boolean, 'processing'), ['bool'])),
                        ])
                        self.processing = None

                        self.port = Native.Interface.HundredGigE.Macro.Auto.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.control = Native.Interface.HundredGigE.Macro.Auto.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"
                        self._segment_path = lambda: "auto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Macro.Auto, [u'processing'], name, value)


                    class Port(Entity):
                        """
                        Provide interface specific configuration for macro processing
                        
                        .. attribute:: sticky
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Macro.Auto.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                            ])
                            self.sticky = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Macro.Auto.Port, [u'sticky'], name, value)


                    class Control(Entity):
                        """
                        Control macro auto execution
                        
                        .. attribute:: device
                        
                        	Enable macro auto execution for devices
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Macro.Auto.Control.Device>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Macro.Auto.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("device", ("device", Native.Interface.HundredGigE.Macro.Auto.Control.Device))])
                            self._leafs = OrderedDict()

                            self.device = Native.Interface.HundredGigE.Macro.Auto.Control.Device()
                            self.device.parent = self
                            self._children_name_map["device"] = "device"
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Macro.Auto.Control, [], name, value)


                        class Device(Entity):
                            """
                            Enable macro auto execution for devices
                            
                            .. attribute:: phone
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Macro.Auto.Control.Device, self).__init__()

                                self.yang_name = "device"
                                self.yang_parent_name = "control"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('phone', (YLeaf(YType.empty, 'phone'), ['Empty'])),
                                ])
                                self.phone = None
                                self._segment_path = lambda: "device"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Macro.Auto.Control.Device, [u'phone'], name, value)


            class DualActive(Entity):
                """
                
                
                .. attribute:: fast_hello
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.DualActive, self).__init__()

                    self.yang_name = "dual-active"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fast_hello', (YLeaf(YType.empty, 'fast-hello'), ['Empty'])),
                    ])
                    self.fast_hello = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:dual-active"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.DualActive, [u'fast_hello'], name, value)


            class LoadBalancing(Entity):
                """
                Etherchannel Load\-Balancing
                
                .. attribute:: flow
                
                	Based on the traffic flows identified by the packet headers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Based on the VLAN to member links manual configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.LoadBalancing, self).__init__()

                    self.yang_name = "load-balancing"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('flow', (YLeaf(YType.empty, 'flow'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.flow = None
                    self.vlan = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:load-balancing"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.LoadBalancing, [u'flow', u'vlan'], name, value)


            class VlanRange(Entity):
                """
                
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4096
                
                		**type**\: str
                
                .. attribute:: service_policy
                
                	Configure QoS Service Policy
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.VlanRange.ServicePolicy>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.VlanRange, self).__init__()

                    self.yang_name = "vlan-range"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.HundredGigE.VlanRange.ServicePolicy))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                    ])
                    self.id = None

                    self.service_policy = Native.Interface.HundredGigE.VlanRange.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:vlan-range" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.VlanRange, [u'id'], name, value)


                class ServicePolicy(Entity):
                    """
                    Configure QoS Service Policy
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.VlanRange.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "vlan-range"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.VlanRange.ServicePolicy, [u'input', u'output'], name, value)


            class Switch(Entity):
                """
                
                
                .. attribute:: virtual
                
                	
                	**type**\:  :py:class:`Virtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Switch.Virtual>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("virtual", ("virtual", Native.Interface.HundredGigE.Switch.Virtual))])
                    self._leafs = OrderedDict()

                    self.virtual = Native.Interface.HundredGigE.Switch.Virtual()
                    self.virtual.parent = self
                    self._children_name_map["virtual"] = "virtual"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:switch"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Switch, [], name, value)


                class Virtual(Entity):
                    """
                    
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Switch.Virtual, self).__init__()

                        self.yang_name = "virtual"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ])
                        self.link = None
                        self._segment_path = lambda: "virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Switch.Virtual, [u'link'], name, value)


            class SrrQueue(Entity):
                """
                
                
                .. attribute:: bandwidth
                
                	
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SrrQueue.Bandwidth>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.SrrQueue, self).__init__()

                    self.yang_name = "srr-queue"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.HundredGigE.SrrQueue.Bandwidth))])
                    self._leafs = OrderedDict()

                    self.bandwidth = Native.Interface.HundredGigE.SrrQueue.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:srr-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.SrrQueue, [], name, value)


                class Bandwidth(Entity):
                    """
                    
                    
                    .. attribute:: shape
                    
                    	
                    	**type**\:  :py:class:`Shape <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SrrQueue.Bandwidth.Shape>`
                    
                    .. attribute:: share
                    
                    	
                    	**type**\:  :py:class:`Share <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SrrQueue.Bandwidth.Share>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.SrrQueue.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "srr-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("shape", ("shape", Native.Interface.HundredGigE.SrrQueue.Bandwidth.Shape)), ("share", ("share", Native.Interface.HundredGigE.SrrQueue.Bandwidth.Share))])
                        self._leafs = OrderedDict()

                        self.shape = Native.Interface.HundredGigE.SrrQueue.Bandwidth.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"

                        self.share = Native.Interface.HundredGigE.SrrQueue.Bandwidth.Share()
                        self.share.parent = self
                        self._children_name_map["share"] = "share"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.SrrQueue.Bandwidth, [], name, value)


                    class Shape(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.SrrQueue.Bandwidth.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint16, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint16, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint16, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint16, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "shape"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.SrrQueue.Bandwidth.Shape, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


                    class Share(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.SrrQueue.Bandwidth.Share, self).__init__()

                            self.yang_name = "share"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint8, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint8, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint8, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint8, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "share"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.SrrQueue.Bandwidth.Share, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


            class CiscoIOSXESwitchMacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection>`
                    
                    .. attribute:: network_link
                    
                    	Enable macsec on switch connected interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('network_link', (YLeaf(YType.empty, 'network-link'), ['Empty'])),
                        ])
                        self.network_link = None

                        self.replay_protection = Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption.Macsec, [u'network_link'], name, value)


                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.CiscoIOSXESwitchMacsecOption.Macsec.ReplayProtection, [u'window_size'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.HundredGigE.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.HundredGigE.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.HundredGigE.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.HundredGigE.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.HundredGigE.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.HundredGigE.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.HundredGigE.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.HundredGigE.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class Mka(Entity):
                """
                MACsec Key Agreement (MKA) interface configuration
                
                .. attribute:: policy
                
                	Apply MKA Policy
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mka.Policy>`
                
                .. attribute:: pre_shared_key
                
                	Configure MKA Pre\-Shared\-Key
                	**type**\:  :py:class:`PreSharedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mka.PreSharedKey>`
                
                

                """

                _prefix = 'ios-mka'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Mka, self).__init__()

                    self.yang_name = "mka"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.HundredGigE.Mka.Policy)), ("pre-shared-key", ("pre_shared_key", Native.Interface.HundredGigE.Mka.PreSharedKey))])
                    self._leafs = OrderedDict()

                    self.policy = Native.Interface.HundredGigE.Mka.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.pre_shared_key = Native.Interface.HundredGigE.Mka.PreSharedKey()
                    self.pre_shared_key.parent = self
                    self._children_name_map["pre_shared_key"] = "pre-shared-key"
                    self._segment_path = lambda: "Cisco-IOS-XE-mka:mka"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Mka, [], name, value)


                class Policy(Entity):
                    """
                    Apply MKA Policy
                    
                    .. attribute:: name
                    
                    	MKA Policy NAME
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Mka.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Mka.Policy, ['name'], name, value)


                class PreSharedKey(Entity):
                    """
                    Configure MKA Pre\-Shared\-Key
                    
                    .. attribute:: key_chain
                    
                    	Configure the key\-chain name
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mka.PreSharedKey.KeyChain>`
                    
                    

                    """

                    _prefix = 'ios-mka'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Mka.PreSharedKey, self).__init__()

                        self.yang_name = "pre-shared-key"
                        self.yang_parent_name = "mka"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.HundredGigE.Mka.PreSharedKey.KeyChain))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.HundredGigE.Mka.PreSharedKey.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"
                        self._segment_path = lambda: "pre-shared-key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Mka.PreSharedKey, [], name, value)


                    class KeyChain(Entity):
                        """
                        Configure the key\-chain name
                        
                        .. attribute:: name
                        
                        	Name of key\-chain to be used to get keys
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mka'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Mka.PreSharedKey.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "pre-shared-key"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Mka.PreSharedKey.KeyChain, ['name'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.HundredGigE.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.HundredGigE.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Utd, ['enable'], name, value)


            class Xconnect(Entity):
                """
                Xconnect commands
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: vcid
                
                	
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: encapsulation
                
                	Data encapsulation method
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Xconnect.Encapsulation>`
                
                .. attribute:: manual
                
                	Manually configure L2TP session parameters
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sequence
                
                	Configure sequencing options for xconnect
                	**type**\:  :py:class:`Sequence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Xconnect.Sequence>`
                
                .. attribute:: pw_class
                
                	Pseudowire\-class to use for encapsulation and protocol configuration
                	**type**\: str
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Xconnect.Encapsulation')])),
                        ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                        ('sequence', (YLeaf(YType.enumeration, 'sequence'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Xconnect.Sequence')])),
                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                    ])
                    self.address = None
                    self.vcid = None
                    self.encapsulation = None
                    self.manual = None
                    self.sequence = None
                    self.pw_class = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'sequence', 'pw_class'], name, value)

                class Encapsulation(Enum):
                    """
                    Encapsulation (Enum Class)

                    Data encapsulation method

                    .. data:: mpls = 0

                    .. data:: l2tpv3 = 1

                    """

                    mpls = Enum.YLeaf(0, "mpls")

                    l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                class Sequence(Enum):
                    """
                    Sequence (Enum Class)

                    Configure sequencing options for xconnect

                    .. data:: both = 0

                    .. data:: receive = 1

                    .. data:: transmit = 2

                    """

                    both = Enum.YLeaf(0, "both")

                    receive = Enum.YLeaf(1, "receive")

                    transmit = Enum.YLeaf(2, "transmit")



            class Evpn(Entity):
                """
                
                
                .. attribute:: ethernet_segment
                
                	Ethernet segment local discriminator value
                	**type**\: list of  		 :py:class:`EthernetSegment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Evpn.EthernetSegment>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Evpn, self).__init__()

                    self.yang_name = "evpn"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet-segment", ("ethernet_segment", Native.Interface.HundredGigE.Evpn.EthernetSegment))])
                    self._leafs = OrderedDict()

                    self.ethernet_segment = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:evpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Evpn, [], name, value)


                class EthernetSegment(Entity):
                    """
                    Ethernet segment local discriminator value
                    
                    .. attribute:: es_value  (key)
                    
                    	Ethernet segment local discriminator value
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: df_election
                    
                    	Designated forwarder election parameters
                    	**type**\:  :py:class:`DfElection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Evpn.EthernetSegment.DfElection>`
                    
                    .. attribute:: redundancy
                    
                    	Multi\-homing redundancy parameters
                    	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Evpn.EthernetSegment.Redundancy>`
                    
                    .. attribute:: sytem_mac
                    
                    	System MAC address for generating the Ethernet Segment ID
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Evpn.EthernetSegment, self).__init__()

                        self.yang_name = "ethernet-segment"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['es_value']
                        self._child_classes = OrderedDict([("df-election", ("df_election", Native.Interface.HundredGigE.Evpn.EthernetSegment.DfElection)), ("redundancy", ("redundancy", Native.Interface.HundredGigE.Evpn.EthernetSegment.Redundancy))])
                        self._leafs = OrderedDict([
                            ('es_value', (YLeaf(YType.uint16, 'es-value'), ['int'])),
                            ('sytem_mac', (YLeaf(YType.str, 'sytem-mac'), ['str'])),
                        ])
                        self.es_value = None
                        self.sytem_mac = None

                        self.df_election = Native.Interface.HundredGigE.Evpn.EthernetSegment.DfElection()
                        self.df_election.parent = self
                        self._children_name_map["df_election"] = "df-election"

                        self.redundancy = Native.Interface.HundredGigE.Evpn.EthernetSegment.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                        self._segment_path = lambda: "ethernet-segment" + "[es-value='" + str(self.es_value) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Evpn.EthernetSegment, ['es_value', 'sytem_mac'], name, value)


                    class DfElection(Entity):
                        """
                        Designated forwarder election parameters
                        
                        .. attribute:: wait_time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Evpn.EthernetSegment.DfElection, self).__init__()

                            self.yang_name = "df-election"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wait_time', (YLeaf(YType.uint8, 'wait-time'), ['int'])),
                            ])
                            self.wait_time = None
                            self._segment_path = lambda: "df-election"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Evpn.EthernetSegment.DfElection, ['wait_time'], name, value)


                    class Redundancy(Entity):
                        """
                        Multi\-homing redundancy parameters
                        
                        .. attribute:: all_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: single_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Evpn.EthernetSegment.Redundancy, self).__init__()

                            self.yang_name = "redundancy"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all_active', (YLeaf(YType.empty, 'all-active'), ['Empty'])),
                                ('single_active', (YLeaf(YType.empty, 'single-active'), ['Empty'])),
                            ])
                            self.all_active = None
                            self.single_active = None
                            self._segment_path = lambda: "redundancy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Evpn.EthernetSegment.Redundancy, ['all_active', 'single_active'], name, value)


            class FabricDomain(Entity):
                """
                Fabric\-domain interface command
                
                .. attribute:: iwan_fabric
                
                	
                	**type**\:  :py:class:`IwanFabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.FabricDomain.IwanFabric>`
                
                

                """

                _prefix = 'ios-iwanfabric'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.FabricDomain, self).__init__()

                    self.yang_name = "fabric-domain"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("iwan-fabric", ("iwan_fabric", Native.Interface.HundredGigE.FabricDomain.IwanFabric))])
                    self._leafs = OrderedDict()

                    self.iwan_fabric = Native.Interface.HundredGigE.FabricDomain.IwanFabric()
                    self.iwan_fabric.parent = self
                    self._children_name_map["iwan_fabric"] = "iwan-fabric"
                    self._segment_path = lambda: "Cisco-IOS-XE-iwanfabric:fabric-domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.FabricDomain, [], name, value)


                class IwanFabric(Entity):
                    """
                    
                    
                    .. attribute:: word
                    
                    	
                    	**type**\: list of  		 :py:class:`Word <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.FabricDomain.IwanFabric.Word>`
                    
                    

                    """

                    _prefix = 'ios-iwanfabric'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.FabricDomain.IwanFabric, self).__init__()

                        self.yang_name = "iwan-fabric"
                        self.yang_parent_name = "fabric-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("word", ("word", Native.Interface.HundredGigE.FabricDomain.IwanFabric.Word))])
                        self._leafs = OrderedDict()

                        self.word = YList(self)
                        self._segment_path = lambda: "iwan-fabric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.FabricDomain.IwanFabric, [], name, value)


                    class Word(Entity):
                        """
                        
                        
                        .. attribute:: word  (key)
                        
                        	Path name
                        	**type**\: str
                        
                        .. attribute:: interface_id
                        
                        	Specify the interface\-id value
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-iwanfabric'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.FabricDomain.IwanFabric.Word, self).__init__()

                            self.yang_name = "word"
                            self.yang_parent_name = "iwan-fabric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                            ])
                            self.word = None
                            self.interface_id = None
                            self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.FabricDomain.IwanFabric.Word, ['word', 'interface_id'], name, value)


            class Mvrp(Entity):
                """
                
                
                .. attribute:: mvrp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: registration
                
                	
                	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mvrp.Registration>`
                
                .. attribute:: timer
                
                	
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mvrp.Timer>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mvrp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Mvrp, self).__init__()

                    self.yang_name = "mvrp"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("registration", ("registration", Native.Interface.HundredGigE.Mvrp.Registration)), ("timer", ("timer", Native.Interface.HundredGigE.Mvrp.Timer))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mvrp', (YLeaf(YType.empty, 'mvrp'), ['Empty'])),
                    ])
                    self.mvrp = None

                    self.registration = Native.Interface.HundredGigE.Mvrp.Registration()
                    self.registration.parent = self
                    self._children_name_map["registration"] = "registration"

                    self.timer = Native.Interface.HundredGigE.Mvrp.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-mvrp:mvrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Mvrp, ['mvrp'], name, value)


                class Registration(Entity):
                    """
                    
                    
                    .. attribute:: fixed
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: forbidden
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: normal
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Mvrp.Registration, self).__init__()

                        self.yang_name = "registration"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fixed', (YLeaf(YType.empty, 'fixed'), ['Empty'])),
                            ('forbidden', (YLeaf(YType.empty, 'forbidden'), ['Empty'])),
                            ('normal', (YLeaf(YType.empty, 'normal'), ['Empty'])),
                        ])
                        self.fixed = None
                        self.forbidden = None
                        self.normal = None
                        self._segment_path = lambda: "registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Mvrp.Registration, ['fixed', 'forbidden', 'normal'], name, value)


                class Timer(Entity):
                    """
                    
                    
                    .. attribute:: join
                    
                    	
                    	**type**\:  :py:class:`Join <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mvrp.Timer.Join>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave
                    
                    	
                    	**type**\:  :py:class:`Leave <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mvrp.Timer.Leave>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave_all
                    
                    	
                    	**type**\:  :py:class:`LeaveAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Mvrp.Timer.LeaveAll>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: periodic
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Mvrp.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("join", ("join", Native.Interface.HundredGigE.Mvrp.Timer.Join)), ("leave", ("leave", Native.Interface.HundredGigE.Mvrp.Timer.Leave)), ("leave-all", ("leave_all", Native.Interface.HundredGigE.Mvrp.Timer.LeaveAll))])
                        self._leafs = OrderedDict([
                            ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ])
                        self.periodic = None

                        self.join = None
                        self._children_name_map["join"] = "join"

                        self.leave = None
                        self._children_name_map["leave"] = "leave"

                        self.leave_all = None
                        self._children_name_map["leave_all"] = "leave-all"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Mvrp.Timer, ['periodic'], name, value)


                    class Join(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 20..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Mvrp.Timer.Join, self).__init__()

                            self.yang_name = "join"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "join"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Mvrp.Timer.Join, ['y_range'], name, value)


                    class Leave(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Mvrp.Timer.Leave, self).__init__()

                            self.yang_name = "leave"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Mvrp.Timer.Leave, ['y_range'], name, value)


                    class LeaveAll(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1000..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Mvrp.Timer.LeaveAll, self).__init__()

                            self.yang_name = "leave-all"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave-all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Mvrp.Timer.LeaveAll, ['y_range'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.HundredGigE.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.HundredGigE.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.HundredGigE.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.HundredGigE.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.HundredGigE.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.HundredGigE.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.HundredGigE.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.HundredGigE.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Power(Entity):
                """
                
                
                .. attribute:: inline
                
                	
                	**type**\:  :py:class:`Inline <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Power.Inline>`
                
                

                """

                _prefix = 'ios-power'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Power, self).__init__()

                    self.yang_name = "power"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("inline", ("inline", Native.Interface.HundredGigE.Power.Inline))])
                    self._leafs = OrderedDict()

                    self.inline = Native.Interface.HundredGigE.Power.Inline()
                    self.inline.parent = self
                    self._children_name_map["inline"] = "inline"
                    self._segment_path = lambda: "Cisco-IOS-XE-power:power"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Power, [], name, value)


                class Inline(Entity):
                    """
                    
                    
                    .. attribute:: consumption
                    
                    	
                    	**type**\: int
                    
                    	**range:** 4000..15400
                    
                    .. attribute:: never
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: auto
                    
                    	Automatically detect and power inline devices
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Power.Inline.Auto>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: four_pair
                    
                    	Four\-pair PoE power
                    	**type**\:  :py:class:`FourPair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Power.Inline.FourPair>`
                    
                    .. attribute:: police
                    
                    	Police the power drawn on the port
                    	**type**\:  :py:class:`Police <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Power.Inline.Police>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: port
                    
                    	Configure Port Power Level
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Power.Inline.Port>`
                    
                    .. attribute:: static
                    
                    	High priority inline power interface
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Power.Inline.Static>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-power'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Power.Inline, self).__init__()

                        self.yang_name = "inline"
                        self.yang_parent_name = "power"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.HundredGigE.Power.Inline.Auto)), ("four-pair", ("four_pair", Native.Interface.HundredGigE.Power.Inline.FourPair)), ("police", ("police", Native.Interface.HundredGigE.Power.Inline.Police)), ("port", ("port", Native.Interface.HundredGigE.Power.Inline.Port)), ("static", ("static", Native.Interface.HundredGigE.Power.Inline.Static))])
                        self._leafs = OrderedDict([
                            ('consumption', (YLeaf(YType.uint16, 'consumption'), ['int'])),
                            ('never', (YLeaf(YType.empty, 'never'), ['Empty'])),
                        ])
                        self.consumption = None
                        self.never = None

                        self.auto = None
                        self._children_name_map["auto"] = "auto"

                        self.four_pair = Native.Interface.HundredGigE.Power.Inline.FourPair()
                        self.four_pair.parent = self
                        self._children_name_map["four_pair"] = "four-pair"

                        self.police = None
                        self._children_name_map["police"] = "police"

                        self.port = Native.Interface.HundredGigE.Power.Inline.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.static = None
                        self._children_name_map["static"] = "static"
                        self._segment_path = lambda: "inline"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Power.Inline, ['consumption', 'never'], name, value)


                    class Auto(Entity):
                        """
                        Automatically detect and power inline devices
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Power.Inline.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "auto"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Power.Inline.Auto, ['max'], name, value)


                    class FourPair(Entity):
                        """
                        Four\-pair PoE power
                        
                        .. attribute:: forced
                        
                        	Enable Four\-pair PoE without L2 negotiation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Power.Inline.FourPair, self).__init__()

                            self.yang_name = "four-pair"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forced', (YLeaf(YType.empty, 'forced'), ['Empty'])),
                            ])
                            self.forced = None
                            self._segment_path = lambda: "four-pair"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Power.Inline.FourPair, ['forced'], name, value)


                    class Police(Entity):
                        """
                        Police the power drawn on the port
                        
                        .. attribute:: action
                        
                        	Action to be taken when power is overdrawn on the port
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Power.Inline.Police.Action>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Power.Inline.Police, self).__init__()

                            self.yang_name = "police"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.HundredGigE.Power.Inline.Police.Action))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.HundredGigE.Power.Inline.Police.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "police"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Power.Inline.Police, [], name, value)


                        class Action(Entity):
                            """
                            Action to be taken when power is overdrawn on the port
                            
                            .. attribute:: errdisable
                            
                            	Error\-disable the port when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: log
                            
                            	Log a message when power is overdrawn on the port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-power'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Power.Inline.Police.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "police"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('errdisable', (YLeaf(YType.empty, 'errdisable'), ['Empty'])),
                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                ])
                                self.errdisable = None
                                self.log = None
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Power.Inline.Police.Action, ['errdisable', 'log'], name, value)


                    class Port(Entity):
                        """
                        Configure Port Power Level
                        
                        .. attribute:: poe_ha
                        
                        	Apply poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: perpetual_poe_ha
                        
                        	Apply perpetual\-poe\-ha to the port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: two_event
                        
                        	Enable 2\-event classification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Power.Inline.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('poe_ha', (YLeaf(YType.empty, 'poe-ha'), ['Empty'])),
                                ('perpetual_poe_ha', (YLeaf(YType.empty, 'perpetual-poe-ha'), ['Empty'])),
                                ('two_event', (YLeaf(YType.empty, 'two-event'), ['Empty'])),
                            ])
                            self.poe_ha = None
                            self.perpetual_poe_ha = None
                            self.two_event = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Power.Inline.Port, ['poe_ha', 'perpetual_poe_ha', 'two_event'], name, value)


                    class Static(Entity):
                        """
                        High priority inline power interface
                        
                        .. attribute:: max
                        
                        	Maximum power allowed on this interface
                        	**type**\: int
                        
                        	**range:** 4000..60000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-power'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Power.Inline.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "inline"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.int32, 'max'), ['int'])),
                            ])
                            self.max = None
                            self._segment_path = lambda: "static"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Power.Inline.Static, ['max'], name, value)


            class Cdp(Entity):
                """
                CDP interface subcommands
                
                .. attribute:: enable
                
                	Enable CDP on interface
                	**type**\: bool
                
                .. attribute:: tlv
                
                	Enable exchange of specific tlv information
                	**type**\:  :py:class:`Tlv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cdp.Tlv>`
                
                

                """

                _prefix = 'ios-cdp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Cdp, self).__init__()

                    self.yang_name = "cdp"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tlv", ("tlv", Native.Interface.HundredGigE.Cdp.Tlv))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                    ])
                    self.enable = None

                    self.tlv = Native.Interface.HundredGigE.Cdp.Tlv()
                    self.tlv.parent = self
                    self._children_name_map["tlv"] = "tlv"
                    self._segment_path = lambda: "Cisco-IOS-XE-cdp:cdp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Cdp, ['enable'], name, value)


                class Tlv(Entity):
                    """
                    Enable exchange of specific tlv information
                    
                    .. attribute:: app
                    
                    	Enable/Configure Application TLV
                    	**type**\:  :py:class:`App <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cdp.Tlv.App>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: server_location
                    
                    	Enable CDP location server on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	Exchange location information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cdp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Cdp.Tlv, self).__init__()

                        self.yang_name = "tlv"
                        self.yang_parent_name = "cdp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("app", ("app", Native.Interface.HundredGigE.Cdp.Tlv.App))])
                        self._leafs = OrderedDict([
                            ('server_location', (YLeaf(YType.empty, 'server-location'), ['Empty'])),
                            ('location', (YLeaf(YType.empty, 'location'), ['Empty'])),
                        ])
                        self.server_location = None
                        self.location = None

                        self.app = None
                        self._children_name_map["app"] = "app"
                        self._segment_path = lambda: "tlv"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Cdp.Tlv, ['server_location', 'location'], name, value)


                    class App(Entity):
                        """
                        Enable/Configure Application TLV
                        
                        .. attribute:: tlvtype
                        
                        	Configure APP TLV
                        	**type**\: int
                        
                        	**range:** 1001..65535
                        
                        .. attribute:: value
                        
                        	Configure App TLV Value information
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cdp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Cdp.Tlv.App, self).__init__()

                            self.yang_name = "app"
                            self.yang_parent_name = "tlv"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tlvtype', (YLeaf(YType.uint16, 'tlvtype'), ['int'])),
                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                            ])
                            self.tlvtype = None
                            self.value = None
                            self._segment_path = lambda: "app"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Cdp.Tlv.App, ['tlvtype', 'value'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.HundredGigE.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.HundredGigE.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.HundredGigE.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.HundredGigE.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class Authentication(Entity):
                """
                Auth Manager Interface Configuration Commands
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.ControlDirection>`
                
                .. attribute:: event
                
                	Set action for authentication events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event>`
                
                .. attribute:: fallback
                
                	Enable the Webauth fallback mechanism
                	**type**\: str
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.HostMode>`
                
                .. attribute:: open
                
                	Enable or Disable open access on this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: order
                
                	Add an authentication method to the order list
                	**type**\:  :py:class:`Order <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Order>`
                
                .. attribute:: priority
                
                	Add an authentication method to the priority list
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Priority>`
                
                .. attribute:: port_control
                
                	set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.PortControl>`
                
                .. attribute:: periodic
                
                	Enable or Disable Reauthentication for this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timer
                
                	Set authentication timer values
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Timer>`
                
                .. attribute:: violation
                
                	Configure action to take on security violations
                	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Violation>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.HundredGigE.Authentication.Event)), ("order", ("order", Native.Interface.HundredGigE.Authentication.Order)), ("priority", ("priority", Native.Interface.HundredGigE.Authentication.Priority)), ("timer", ("timer", Native.Interface.HundredGigE.Authentication.Timer))])
                    self._leafs = OrderedDict([
                        ('control_direction', (YLeaf(YType.enumeration, 'control-direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Authentication.ControlDirection')])),
                        ('fallback', (YLeaf(YType.str, 'fallback'), ['str'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Authentication.HostMode')])),
                        ('open', (YLeaf(YType.empty, 'open'), ['Empty'])),
                        ('port_control', (YLeaf(YType.enumeration, 'port-control'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Authentication.PortControl')])),
                        ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Authentication.Violation')])),
                    ])
                    self.control_direction = None
                    self.fallback = None
                    self.host_mode = None
                    self.open = None
                    self.port_control = None
                    self.periodic = None
                    self.violation = None

                    self.event = Native.Interface.HundredGigE.Authentication.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.order = Native.Interface.HundredGigE.Authentication.Order()
                    self.order.parent = self
                    self._children_name_map["order"] = "order"

                    self.priority = Native.Interface.HundredGigE.Authentication.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "priority"

                    self.timer = Native.Interface.HundredGigE.Authentication.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:authentication"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Authentication, ['control_direction', 'fallback', 'host_mode', 'open', 'port_control', 'periodic', 'violation'], name, value)

                class ControlDirection(Enum):
                    """
                    ControlDirection (Enum Class)

                    Set the control\-direction on the interface

                    .. data:: both = 0

                    .. data:: in_ = 1

                    """

                    both = Enum.YLeaf(0, "both")

                    in_ = Enum.YLeaf(1, "in")


                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")


                class PortControl(Enum):
                    """
                    PortControl (Enum Class)

                    set the port\-control value

                    .. data:: auto = 0

                    .. data:: force_authorized = 1

                    .. data:: force_unauthorized = 2

                    """

                    auto = Enum.YLeaf(0, "auto")

                    force_authorized = Enum.YLeaf(1, "force-authorized")

                    force_unauthorized = Enum.YLeaf(2, "force-unauthorized")


                class Violation(Enum):
                    """
                    Violation (Enum Class)

                    Configure action to take on security violations

                    .. data:: protect = 0

                    .. data:: replace = 1

                    .. data:: restrict = 2

                    .. data:: shutdown = 3

                    """

                    protect = Enum.YLeaf(0, "protect")

                    replace = Enum.YLeaf(1, "replace")

                    restrict = Enum.YLeaf(2, "restrict")

                    shutdown = Enum.YLeaf(3, "shutdown")



                class Event(Entity):
                    """
                    Set action for authentication events
                    
                    .. attribute:: server
                    
                    	Configure actions for AAA server events
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.Server>`
                    
                    .. attribute:: fail
                    
                    	Configure actions for AAA fail events
                    	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.Fail>`
                    
                    .. attribute:: no_response
                    
                    	Configure actions for AAA no\-response events
                    	**type**\:  :py:class:`NoResponse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.NoResponse>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Authentication.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("server", ("server", Native.Interface.HundredGigE.Authentication.Event.Server)), ("fail", ("fail", Native.Interface.HundredGigE.Authentication.Event.Fail)), ("no-response", ("no_response", Native.Interface.HundredGigE.Authentication.Event.NoResponse))])
                        self._leafs = OrderedDict()

                        self.server = Native.Interface.HundredGigE.Authentication.Event.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.fail = Native.Interface.HundredGigE.Authentication.Event.Fail()
                        self.fail.parent = self
                        self._children_name_map["fail"] = "fail"

                        self.no_response = Native.Interface.HundredGigE.Authentication.Event.NoResponse()
                        self.no_response.parent = self
                        self._children_name_map["no_response"] = "no-response"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event, [], name, value)


                    class Server(Entity):
                        """
                        Configure actions for AAA server events
                        
                        .. attribute:: alive
                        
                        	Configure AAA server alive action
                        	**type**\:  :py:class:`Alive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.Server.Alive>`
                        
                        .. attribute:: dead
                        
                        	Configure AAA server dead action
                        	**type**\:  :py:class:`Dead <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.Server.Dead>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Authentication.Event.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("alive", ("alive", Native.Interface.HundredGigE.Authentication.Event.Server.Alive)), ("dead", ("dead", Native.Interface.HundredGigE.Authentication.Event.Server.Dead))])
                            self._leafs = OrderedDict()

                            self.alive = Native.Interface.HundredGigE.Authentication.Event.Server.Alive()
                            self.alive.parent = self
                            self._children_name_map["alive"] = "alive"

                            self.dead = Native.Interface.HundredGigE.Authentication.Event.Server.Dead()
                            self.dead.parent = self
                            self._children_name_map["dead"] = "dead"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.Server, [], name, value)


                        class Alive(Entity):
                            """
                            Configure AAA server alive action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.Server.Alive.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Authentication.Event.Server.Alive, self).__init__()

                                self.yang_name = "alive"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.HundredGigE.Authentication.Event.Server.Alive.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.HundredGigE.Authentication.Event.Server.Alive.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "alive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.Server.Alive, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all authorized clients
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Authentication.Event.Server.Alive.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "alive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reinitialize', (YLeaf(YType.empty, 'reinitialize'), ['Empty'])),
                                    ])
                                    self.reinitialize = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.Server.Alive.Action, ['reinitialize'], name, value)


                        class Dead(Entity):
                            """
                            Configure AAA server dead action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Authentication.Event.Server.Dead, self).__init__()

                                self.yang_name = "dead"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dead"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.Server.Dead, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: authorize
                                
                                	Authorize the port
                                	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action.Authorize>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all client on the port
                                	**type**\:  :py:class:`Reinitialize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action.Reinitialize>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dead"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action.Authorize)), ("reinitialize", ("reinitialize", Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action.Reinitialize))])
                                    self._leafs = OrderedDict()

                                    self.authorize = None
                                    self._children_name_map["authorize"] = "authorize"

                                    self.reinitialize = Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action.Reinitialize()
                                    self.reinitialize.parent = self
                                    self._children_name_map["reinitialize"] = "reinitialize"
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action, [], name, value)


                                class Authorize(Entity):
                                    """
                                    Authorize the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: voice
                                    
                                    	Authorize the port for VOICE traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action.Authorize, self).__init__()

                                        self.yang_name = "authorize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ('voice', (YLeaf(YType.empty, 'voice'), ['Empty'])),
                                        ])
                                        self.vlan = None
                                        self.voice = None
                                        self._segment_path = lambda: "authorize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action.Authorize, ['vlan', 'voice'], name, value)


                                class Reinitialize(Entity):
                                    """
                                    Reinitialize all client on the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action.Reinitialize, self).__init__()

                                        self.yang_name = "reinitialize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "reinitialize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.Server.Dead.Action.Reinitialize, ['vlan'], name, value)


                    class Fail(Entity):
                        """
                        Configure actions for AAA fail events
                        
                        .. attribute:: action
                        
                        	Required action for fail event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.Fail.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Authentication.Event.Fail, self).__init__()

                            self.yang_name = "fail"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.HundredGigE.Authentication.Event.Fail.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.HundredGigE.Authentication.Event.Fail.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "fail"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.Fail, [], name, value)


                        class Action(Entity):
                            """
                            Required action for fail event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.Fail.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Authentication.Event.Fail.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "fail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.HundredGigE.Authentication.Event.Fail.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.HundredGigE.Authentication.Event.Fail.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.Fail.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Authentication.Event.Fail.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.Fail.Action.Authorize, ['vlan'], name, value)


                    class NoResponse(Entity):
                        """
                        Configure actions for AAA no\-response events
                        
                        .. attribute:: action
                        
                        	Required action for no\-response event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.NoResponse.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Authentication.Event.NoResponse, self).__init__()

                            self.yang_name = "no-response"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.HundredGigE.Authentication.Event.NoResponse.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.HundredGigE.Authentication.Event.NoResponse.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "no-response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.NoResponse, [], name, value)


                        class Action(Entity):
                            """
                            Required action for no\-response event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Event.NoResponse.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Authentication.Event.NoResponse.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "no-response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.HundredGigE.Authentication.Event.NoResponse.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.HundredGigE.Authentication.Event.NoResponse.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.NoResponse.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Authentication.Event.NoResponse.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Authentication.Event.NoResponse.Action.Authorize, ['vlan'], name, value)


                class Order(Entity):
                    """
                    Add an authentication method to the order list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Authentication.Order, self).__init__()

                        self.yang_name = "order"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "order"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Authentication.Order, ['dot1x', 'mab', 'webauth'], name, value)


                class Priority(Entity):
                    """
                    Add an authentication method to the priority list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Authentication.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Authentication.Priority, ['dot1x', 'mab', 'webauth'], name, value)


                class Timer(Entity):
                    """
                    Set authentication timer values
                    
                    .. attribute:: reauthenticate
                    
                    	Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                    	**type**\:  :py:class:`Reauthenticate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Timer.Reauthenticate>`
                    
                    .. attribute:: inactivity
                    
                    	Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                    	**type**\:  :py:class:`Inactivity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Timer.Inactivity>`
                    
                    .. attribute:: restart
                    
                    	Interval in seconds after which an attempt should be made toauthenticate an unauthorized port (default 60 sec)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Authentication.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reauthenticate", ("reauthenticate", Native.Interface.HundredGigE.Authentication.Timer.Reauthenticate)), ("inactivity", ("inactivity", Native.Interface.HundredGigE.Authentication.Timer.Inactivity))])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                        ])
                        self.restart = None

                        self.reauthenticate = Native.Interface.HundredGigE.Authentication.Timer.Reauthenticate()
                        self.reauthenticate.parent = self
                        self._children_name_map["reauthenticate"] = "reauthenticate"

                        self.inactivity = Native.Interface.HundredGigE.Authentication.Timer.Inactivity()
                        self.inactivity.parent = self
                        self._children_name_map["inactivity"] = "inactivity"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Authentication.Timer, ['restart'], name, value)


                    class Reauthenticate(Entity):
                        """
                        Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: server
                        
                        	Obtain re\-authentication timeout value from the server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Authentication.Timer.Reauthenticate, self).__init__()

                            self.yang_name = "reauthenticate"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                            ])
                            self.value = None
                            self.server = None
                            self._segment_path = lambda: "reauthenticate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Authentication.Timer.Reauthenticate, ['value', 'server'], name, value)


                    class Inactivity(Entity):
                        """
                        Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Timer.Inactivity.Value>`
                        
                        .. attribute:: server
                        
                        	Obtain inactivity timeout value from the server
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Authentication.Timer.Inactivity.Server>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Authentication.Timer.Inactivity, self).__init__()

                            self.yang_name = "inactivity"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.HundredGigE.Authentication.Timer.Inactivity.Value)), ("server", ("server", Native.Interface.HundredGigE.Authentication.Timer.Inactivity.Server))])
                            self._leafs = OrderedDict()

                            self.value = Native.Interface.HundredGigE.Authentication.Timer.Inactivity.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.server = None
                            self._children_name_map["server"] = "server"
                            self._segment_path = lambda: "inactivity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Authentication.Timer.Inactivity, [], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Authentication.Timer.Inactivity.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.value = None
                                self.dynamic = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Authentication.Timer.Inactivity.Value, ['value', 'dynamic'], name, value)


                        class Server(Entity):
                            """
                            Obtain inactivity timeout value from the server
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Authentication.Timer.Inactivity.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.dynamic = None
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Authentication.Timer.Inactivity.Server, ['dynamic'], name, value)


            class Mab(Entity):
                """
                
                
                .. attribute:: eap
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Mab, self).__init__()

                    self.yang_name = "mab"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                    ])
                    self.eap = None
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:mab"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Mab, ['eap'], name, value)


            class Dot1x(Entity):
                """
                Interface Config Commands for IEEE 802.1X
                
                .. attribute:: authenticator
                
                	Configure authenticator parameters
                	**type**\:  :py:class:`Authenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Dot1x.Authenticator>`
                
                .. attribute:: credentials
                
                	Credentials profile configuration
                	**type**\: str
                
                .. attribute:: max_reauth_req
                
                	Max No. of Reauthentication Attempts
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_req
                
                	Max No. of Retries
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_start
                
                	Max No. of EAPOL\-Start requests
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: pae
                
                	Set 802.1x interface pae type
                	**type**\:  :py:class:`Pae <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Dot1x.Pae>`
                
                .. attribute:: supplicant
                
                	Configure supplicant parameters
                	**type**\:  :py:class:`Supplicant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Dot1x.Supplicant>`
                
                .. attribute:: timeout
                
                	Various Timeouts
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Dot1x.Timeout>`
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Dot1x, self).__init__()

                    self.yang_name = "dot1x"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authenticator", ("authenticator", Native.Interface.HundredGigE.Dot1x.Authenticator)), ("supplicant", ("supplicant", Native.Interface.HundredGigE.Dot1x.Supplicant)), ("timeout", ("timeout", Native.Interface.HundredGigE.Dot1x.Timeout))])
                    self._leafs = OrderedDict([
                        ('credentials', (YLeaf(YType.str, 'credentials'), ['str'])),
                        ('max_reauth_req', (YLeaf(YType.uint8, 'max-reauth-req'), ['int'])),
                        ('max_req', (YLeaf(YType.uint8, 'max-req'), ['int'])),
                        ('max_start', (YLeaf(YType.uint8, 'max-start'), ['int'])),
                        ('pae', (YLeaf(YType.enumeration, 'pae'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Dot1x.Pae')])),
                    ])
                    self.credentials = None
                    self.max_reauth_req = None
                    self.max_req = None
                    self.max_start = None
                    self.pae = None

                    self.authenticator = Native.Interface.HundredGigE.Dot1x.Authenticator()
                    self.authenticator.parent = self
                    self._children_name_map["authenticator"] = "authenticator"

                    self.supplicant = Native.Interface.HundredGigE.Dot1x.Supplicant()
                    self.supplicant.parent = self
                    self._children_name_map["supplicant"] = "supplicant"

                    self.timeout = Native.Interface.HundredGigE.Dot1x.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"
                    self._segment_path = lambda: "Cisco-IOS-XE-dot1x:dot1x"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Dot1x, ['credentials', 'max_reauth_req', 'max_req', 'max_start', 'pae'], name, value)

                class Pae(Enum):
                    """
                    Pae (Enum Class)

                    Set 802.1x interface pae type

                    .. data:: authenticator = 0

                    .. data:: supplicant = 1

                    .. data:: both = 2

                    """

                    authenticator = Enum.YLeaf(0, "authenticator")

                    supplicant = Enum.YLeaf(1, "supplicant")

                    both = Enum.YLeaf(2, "both")



                class Authenticator(Entity):
                    """
                    Configure authenticator parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP authenticator parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Dot1x.Authenticator.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Dot1x.Authenticator, self).__init__()

                        self.yang_name = "authenticator"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.HundredGigE.Dot1x.Authenticator.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.HundredGigE.Dot1x.Authenticator.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "authenticator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Dot1x.Authenticator, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP authenticator parameters
                        
                        .. attribute:: profile
                        
                        	EAP authenticator profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Dot1x.Authenticator.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "authenticator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Dot1x.Authenticator.Eap, ['profile'], name, value)


                class Supplicant(Entity):
                    """
                    Configure supplicant parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP supplicant parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Dot1x.Supplicant.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Dot1x.Supplicant, self).__init__()

                        self.yang_name = "supplicant"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.HundredGigE.Dot1x.Supplicant.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.HundredGigE.Dot1x.Supplicant.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "supplicant"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Dot1x.Supplicant, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP supplicant parameters
                        
                        .. attribute:: profile
                        
                        	EAP supplicant profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Dot1x.Supplicant.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "supplicant"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Dot1x.Supplicant.Eap, ['profile'], name, value)


                class Timeout(Entity):
                    """
                    Various Timeouts
                    
                    .. attribute:: auth_period
                    
                    	Timeout for authenticator reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: held_period
                    
                    	Timeout for authentication retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: quiet_period
                    
                    	QuietPeriod in Seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ratelimit_period
                    
                    	Ratelimit Period in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: server_timeout
                    
                    	Timeout for Radius Retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: start_period
                    
                    	Timeout for EAPOL\-start retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: supp_timeout
                    
                    	Timeout for supplicant reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: tx_period
                    
                    	Timeout for supplicant retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Dot1x.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auth_period', (YLeaf(YType.uint16, 'auth-period'), ['int'])),
                            ('held_period', (YLeaf(YType.uint16, 'held-period'), ['int'])),
                            ('quiet_period', (YLeaf(YType.uint16, 'quiet-period'), ['int'])),
                            ('ratelimit_period', (YLeaf(YType.uint16, 'ratelimit-period'), ['int'])),
                            ('server_timeout', (YLeaf(YType.uint16, 'server-timeout'), ['int'])),
                            ('start_period', (YLeaf(YType.uint16, 'start-period'), ['int'])),
                            ('supp_timeout', (YLeaf(YType.uint16, 'supp-timeout'), ['int'])),
                            ('tx_period', (YLeaf(YType.uint16, 'tx-period'), ['int'])),
                        ])
                        self.auth_period = None
                        self.held_period = None
                        self.quiet_period = None
                        self.ratelimit_period = None
                        self.server_timeout = None
                        self.start_period = None
                        self.supp_timeout = None
                        self.tx_period = None
                        self._segment_path = lambda: "timeout"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Dot1x.Timeout, ['auth_period', 'held_period', 'quiet_period', 'ratelimit_period', 'server_timeout', 'start_period', 'supp_timeout', 'tx_period'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpdufilter
                
                	Don't send or receive BPDUs on this interface
                	**type**\:  :py:class:`Bpdufilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SpanningTree.Bpdufilter>`
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SpanningTree.Bpduguard>`
                
                .. attribute:: cost
                
                	To set the path cost of the interface
                	**type**\: int
                
                	**range:** 1..200000000
                
                .. attribute:: guard
                
                	Change an interface's spanning tree guard mode
                	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SpanningTree.Guard>`
                
                .. attribute:: link_type
                
                	Specify a link type for spanning tree tree protocol use
                	**type**\:  :py:class:`LinkType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SpanningTree.LinkType>`
                
                .. attribute:: portfast
                
                	Spanning tree portfast options
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                .. attribute:: port_priority
                
                	Spanning tree port\-priority options
                	**type**\: int
                
                	**range:** 0..240
                
                .. attribute:: vlan
                
                	VLAN Switch Spanning Tree
                	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SpanningTree.Vlan>`
                
                .. attribute:: loopguard
                
                	Spanning tree loopguard options
                	**type**\:  :py:class:`Loopguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SpanningTree.Loopguard>`
                
                .. attribute:: mst
                
                	Per interface MST configurations
                	**type**\:  :py:class:`Mst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SpanningTree.Mst>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Interface.HundredGigE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Interface.HundredGigE.SpanningTree.Portfast)), ("vlan", ("vlan", Native.Interface.HundredGigE.SpanningTree.Vlan)), ("loopguard", ("loopguard", Native.Interface.HundredGigE.SpanningTree.Loopguard)), ("mst", ("mst", Native.Interface.HundredGigE.SpanningTree.Mst))])
                    self._leafs = OrderedDict([
                        ('bpdufilter', (YLeaf(YType.enumeration, 'bpdufilter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.SpanningTree.Bpdufilter')])),
                        ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ('guard', (YLeaf(YType.enumeration, 'guard'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.SpanningTree.Guard')])),
                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.SpanningTree.LinkType')])),
                        ('port_priority', (YLeaf(YType.uint8, 'port-priority'), ['int'])),
                    ])
                    self.bpdufilter = None
                    self.cost = None
                    self.guard = None
                    self.link_type = None
                    self.port_priority = None

                    self.bpduguard = Native.Interface.HundredGigE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"

                    self.loopguard = Native.Interface.HundredGigE.SpanningTree.Loopguard()
                    self.loopguard.parent = self
                    self._children_name_map["loopguard"] = "loopguard"

                    self.mst = Native.Interface.HundredGigE.SpanningTree.Mst()
                    self.mst.parent = self
                    self._children_name_map["mst"] = "mst"

                    self.vlan = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:spanning-tree"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.SpanningTree, ['bpdufilter', 'cost', 'guard', 'link_type', 'port_priority'], name, value)

                class Bpdufilter(Enum):
                    """
                    Bpdufilter (Enum Class)

                    Don't send or receive BPDUs on this interface

                    .. data:: disable = 0

                    .. data:: enable = 1

                    """

                    disable = Enum.YLeaf(0, "disable")

                    enable = Enum.YLeaf(1, "enable")


                class Guard(Enum):
                    """
                    Guard (Enum Class)

                    Change an interface's spanning tree guard mode

                    .. data:: loop = 0

                    .. data:: none = 1

                    .. data:: root = 2

                    """

                    loop = Enum.YLeaf(0, "loop")

                    none = Enum.YLeaf(1, "none")

                    root = Enum.YLeaf(2, "root")


                class LinkType(Enum):
                    """
                    LinkType (Enum Class)

                    Specify a link type for spanning tree tree protocol use

                    .. data:: point_to_point = 0

                    .. data:: shared = 1

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")

                    shared = Enum.YLeaf(1, "shared")



                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.disable = None
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.SpanningTree.Bpduguard, ['disable', 'enable'], name, value)


                class Portfast(Entity):
                    """
                    Spanning tree portfast options
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk
                    
                    	Enable portfast on the interface even in trunk mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                        ])
                        self.disable = None
                        self.trunk = None
                        self.edge = None
                        self._segment_path = lambda: "portfast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.SpanningTree.Portfast, ['disable', 'trunk', 'edge'], name, value)


                class Vlan(Entity):
                    """
                    VLAN Switch Spanning Tree
                    
                    .. attribute:: vlan_ids  (key)
                    
                    	vlan range, example\: 1,3\-5,7,9\-11
                    	**type**\: str
                    
                    .. attribute:: cost
                    
                    	<1\-200000000> Spanning\-tree cost
                    	**type**\: int
                    
                    	**range:** 1..200000000
                    
                    .. attribute:: port_priority
                    
                    	<0\-240> port priority in increments of 16
                    	**type**\: int
                    
                    	**range:** 0..240
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.SpanningTree.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vlan_ids']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_ids', (YLeaf(YType.str, 'vlan-ids'), ['str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                        ])
                        self.vlan_ids = None
                        self.cost = None
                        self.port_priority = None
                        self._segment_path = lambda: "vlan" + "[vlan-ids='" + str(self.vlan_ids) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.SpanningTree.Vlan, ['vlan_ids', 'cost', 'port_priority'], name, value)


                class Loopguard(Entity):
                    """
                    Spanning tree loopguard options
                    
                    .. attribute:: default
                    
                    	Enable loopguard by default on all ports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.SpanningTree.Loopguard, self).__init__()

                        self.yang_name = "loopguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.default = None
                        self._segment_path = lambda: "loopguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.SpanningTree.Loopguard, ['default'], name, value)


                class Mst(Entity):
                    """
                    Per interface MST configurations
                    
                    .. attribute:: mst_instance
                    
                    	
                    	**type**\: list of  		 :py:class:`MstInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.SpanningTree.Mst.MstInstance>`
                    
                    .. attribute:: pre_standard
                    
                    	Force pre\-standard MST BPDU transmission on port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.SpanningTree.Mst, self).__init__()

                        self.yang_name = "mst"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mst-instance", ("mst_instance", Native.Interface.HundredGigE.SpanningTree.Mst.MstInstance))])
                        self._leafs = OrderedDict([
                            ('pre_standard', (YLeaf(YType.empty, 'pre-standard'), ['Empty'])),
                        ])
                        self.pre_standard = None

                        self.mst_instance = YList(self)
                        self._segment_path = lambda: "mst"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.SpanningTree.Mst, ['pre_standard'], name, value)


                    class MstInstance(Entity):
                        """
                        
                        
                        .. attribute:: instance  (key)
                        
                        	MST instance list, example 0,2\-4,6,8\-12
                        	**type**\: str
                        
                        .. attribute:: cost
                        
                        	<1\-200000000> Spanning\-tree cost
                        	**type**\: int
                        
                        	**range:** 1..200000000
                        
                        .. attribute:: port_priority
                        
                        	<0\-240> port priority in increments of 16
                        	**type**\: int
                        
                        	**range:** 0..240
                        
                        

                        """

                        _prefix = 'ios-stp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.SpanningTree.Mst.MstInstance, self).__init__()

                            self.yang_name = "mst-instance"
                            self.yang_parent_name = "mst"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                            ])
                            self.instance = None
                            self.cost = None
                            self.port_priority = None
                            self._segment_path = lambda: "mst-instance" + "[instance='" + str(self.instance) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.SpanningTree.Mst.MstInstance, ['instance', 'cost', 'port_priority'], name, value)


            class Performance(Entity):
                """
                Global performance monitor configuration
                
                .. attribute:: monitor
                
                	monitor
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Performance.Monitor>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Performance, self).__init__()

                    self.yang_name = "performance"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.HundredGigE.Performance.Monitor))])
                    self._leafs = OrderedDict()

                    self.monitor = Native.Interface.HundredGigE.Performance.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"
                    self._segment_path = lambda: "Cisco-IOS-XE-ezpm:performance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Performance, [], name, value)


                class Monitor(Entity):
                    """
                    monitor
                    
                    .. attribute:: context
                    
                    	Select ezPM context
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Performance.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "performance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('context', (YLeafList(YType.str, 'context'), ['str'])),
                        ])
                        self.context = []
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Performance.Monitor, ['context'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Umbrella, ['out', 'in_'], name, value)


            class Lldp(Entity):
                """
                LLDP interface subcommands
                
                .. attribute:: receive
                
                	Enable LLDP reception on interface
                	**type**\: bool
                
                .. attribute:: transmit
                
                	Enable LLDP transmission on interface
                	**type**\: bool
                
                

                """

                _prefix = 'ios-lldp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Lldp, self).__init__()

                    self.yang_name = "lldp"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                        ('transmit', (YLeaf(YType.boolean, 'transmit'), ['bool'])),
                    ])
                    self.receive = None
                    self.transmit = None
                    self._segment_path = lambda: "Cisco-IOS-XE-lldp:lldp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Lldp, ['receive', 'transmit'], name, value)


            class Vrrp(Entity):
                """
                Configure VRRP
                
                .. attribute:: vrrp_group
                
                	
                	**type**\: list of  		 :py:class:`VrrpGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup>`
                
                .. attribute:: vrrp_group_v2
                
                	vrrp version 2
                	**type**\: list of  		 :py:class:`VrrpGroupV2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroupV2>`
                
                .. attribute:: delay
                
                	
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.Delay>`
                
                

                """

                _prefix = 'ios-vrrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Vrrp, self).__init__()

                    self.yang_name = "vrrp"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrrp-group", ("vrrp_group", Native.Interface.HundredGigE.Vrrp.VrrpGroup)), ("vrrp-group-v2", ("vrrp_group_v2", Native.Interface.HundredGigE.Vrrp.VrrpGroupV2)), ("delay", ("delay", Native.Interface.HundredGigE.Vrrp.Delay))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.HundredGigE.Vrrp.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.vrrp_group = YList(self)
                    self.vrrp_group_v2 = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vrrp:vrrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Vrrp, [], name, value)


                class VrrpGroup(Entity):
                    """
                    
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: address_family
                    
                    	Address family of the group
                    	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Vrrp.VrrpGroup, self).__init__()

                        self.yang_name = "vrrp-group"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("address-family", ("address_family", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                        ])
                        self.group_id = None

                        self.address_family = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"
                        self._segment_path = lambda: "vrrp-group" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup, ['group_id'], name, value)


                    class AddressFamily(Entity):
                        """
                        Address family of the group
                        
                        .. attribute:: ipv4
                        
                        	IPv4 Address family
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	IPv6 Address family
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily, self).__init__()

                            self.yang_name = "address-family"
                            self.yang_parent_name = "vrrp-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4)), ("ipv6", ("ipv6", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = None
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "address-family"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily, [], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 Address family
                            
                            .. attribute:: vrrpv2
                            
                            	Set VRRPv2 compatibility mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: address
                            
                            	Set the IPv4 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address)), ("preempt", ("preempt", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt)), ("timers", ("timers", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers)), ("track", ("track", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track)), ("vrrs", ("vrrs", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('vrrpv2', (YLeaf(YType.empty, 'vrrpv2'), ['Empty'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.vrrpv2 = None
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4, ['vrrpv2', 'description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv4 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary>`
                                
                                .. attribute:: secondary
                                
                                	
                                	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary)), ("secondary", ("secondary", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.secondary = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv4 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, ['address', 'primary'], name, value)


                                class Secondary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: secondary
                                    
                                    	Make this IPv4 address a secondary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, self).__init__()

                                        self.yang_name = "secondary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.secondary = None
                                        self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, ['address', 'secondary'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, ['leader'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 Address family
                            
                            .. attribute:: address
                            
                            	Set the IPv6 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address)), ("preempt", ("preempt", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt)), ("timers", ("timers", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers)), ("track", ("track", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track)), ("vrrs", ("vrrs", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6, ['description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv6 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary>`
                                
                                .. attribute:: ipv6_prefix
                                
                                	
                                	**type**\: list of  		 :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary)), ("ipv6-prefix", ("ipv6_prefix", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.ipv6_prefix = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipv6_link_local
                                    
                                    	IPv6 link\-local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv6 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_link_local', (YLeaf(YType.str, 'ipv6-link-local'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.ipv6_link_local = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, ['ipv6_link_local', 'primary'], name, value)


                                class Ipv6Prefix(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, self).__init__()

                                        self.yang_name = "ipv6-prefix"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                        ])
                                        self.prefix = None
                                        self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, ['prefix'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, ['leader'], name, value)


                class VrrpGroupV2(Entity):
                    """
                    vrrp version 2
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: authentication
                    
                    	
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Authentication>`
                    
                    .. attribute:: description
                    
                    	Up to 80 characters describing this group
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Ip>`
                    
                    .. attribute:: name
                    
                    	Unique VRRS identifier (max 48 characters)
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: shutdown
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: timers
                    
                    	
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Timers>`
                    
                    .. attribute:: track
                    
                    	
                    	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Track>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2, self).__init__()

                        self.yang_name = "vrrp-group-v2"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Authentication)), ("ip", ("ip", Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Ip)), ("preempt", ("preempt", Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Preempt)), ("timers", ("timers", Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Timers)), ("track", ("track", Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Track))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.group_id = None
                        self.description = None
                        self.name = None
                        self.priority = None
                        self.shutdown = None

                        self.authentication = Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.timers = Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Track()
                        self.track.parent = self
                        self._children_name_map["track"] = "track"
                        self._segment_path = lambda: "vrrp-group-v2" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2, ['group_id', 'description', 'name', 'priority', 'shutdown'], name, value)


                    class Authentication(Entity):
                        """
                        
                        
                        .. attribute:: text
                        
                        	authentication string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.text = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Authentication, ['text'], name, value)


                    class Ip(Entity):
                        """
                        
                        
                        .. attribute:: vrrp_ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`VrrpIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Ip.VrrpIpv4>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrrp-ipv4", ("vrrp_ipv4", Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Ip.VrrpIpv4))])
                            self._leafs = OrderedDict()

                            self.vrrp_ipv4 = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Ip, [], name, value)


                        class VrrpIpv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, self).__init__()

                                self.yang_name = "vrrp-ipv4"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.ipv4 = None
                                self.secondary = None
                                self._segment_path = lambda: "vrrp-ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, ['ipv4', 'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        
                        
                        .. attribute:: delay
                        
                        	
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            
                            
                            .. attribute:: minimum
                            
                            	Seconds to delay
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                ])
                                self.minimum = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Preempt.Delay, ['minimum'], name, value)


                    class Timers(Entity):
                        """
                        
                        
                        .. attribute:: advertise
                        
                        	
                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Timers.Advertise>`
                        
                        .. attribute:: learn
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Timers.Advertise))])
                            self._leafs = OrderedDict([
                                ('learn', (YLeaf(YType.empty, 'learn'), ['Empty'])),
                            ])
                            self.learn = None

                            self.advertise = Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Timers.Advertise()
                            self.advertise.parent = self
                            self._children_name_map["advertise"] = "advertise"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Timers, ['learn'], name, value)


                        class Advertise(Entity):
                            """
                            
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Advertisement interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..999
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Timers.Advertise, self).__init__()

                                self.yang_name = "advertise"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint8, 'interval'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.interval = None
                                self.msec = None
                                self._segment_path = lambda: "advertise"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Timers.Advertise, ['interval', 'msec'], name, value)


                    class Track(Entity):
                        """
                        
                        
                        .. attribute:: event
                        
                        	
                        	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Track.Event>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("event", ("event", Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Track.Event))])
                            self._leafs = OrderedDict()

                            self.event = YList(self)
                            self._segment_path = lambda: "track"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Track, [], name, value)


                        class Event(Entity):
                            """
                            
                            
                            .. attribute:: object_id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: decrement
                            
                            	Decrement value
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Track.Event, self).__init__()

                                self.yang_name = "event"
                                self.yang_parent_name = "track"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['object_id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                    ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ])
                                self.object_id = None
                                self.decrement = None
                                self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Vrrp.VrrpGroupV2.Track.Event, ['object_id', 'decrement'], name, value)


                class Delay(Entity):
                    """
                    
                    
                    .. attribute:: reload
                    
                    	Seconds to delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: minimum
                    
                    	Seconds to delay after interface up
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Vrrp.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                        ])
                        self.reload = None
                        self.minimum = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Vrrp.Delay, ['reload', 'minimum'], name, value)


            class Ospfv3(Entity):
                """
                OSPFv3 interface commands
                
                .. attribute:: process_id
                
                	
                	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId>`
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Authentication>`
                
                .. attribute:: bfd
                
                	Enable BFD on this interface
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: cost
                
                	Route cost of this interface
                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Cost>`
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: demand_circuit
                
                	OSPF Demand Circuit
                	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.DemandCircuit>`
                
                	**presence node**\: True
                
                .. attribute:: encryption
                
                	Enable encryption
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption>`
                
                .. attribute:: flood_reduction
                
                	OSPF Flood Reduction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: manet
                
                	Mobile Adhoc Networking options
                	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Manet>`
                
                .. attribute:: mtu_ignore
                
                	Ignores the MTU in DBD packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: multi_area
                
                	Set the OSPF multi\-area ID
                	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.MultiArea>`
                
                .. attribute:: neighbor
                
                	OSPF neighbor
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Neighbor>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Network>`
                
                .. attribute:: prefix_suppression
                
                	OSPF prefix suppression
                	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.PrefixSuppression>`
                
                	**presence node**\: True
                
                .. attribute:: priority
                
                	Router priority
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: retransmit_interval
                
                	Time between retransmitting lost link state advertisements
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Shut down the interface in OSPFv3
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transmit_delay
                
                	Link state transmit delay
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Ospfv3, self).__init__()

                    self.yang_name = "ospfv3"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.HundredGigE.Ospfv3.ProcessId)), ("authentication", ("authentication", Native.Interface.HundredGigE.Ospfv3.Authentication)), ("bfd", ("bfd", Native.Interface.HundredGigE.Ospfv3.Bfd)), ("cost", ("cost", Native.Interface.HundredGigE.Ospfv3.Cost)), ("database-filter", ("database_filter", Native.Interface.HundredGigE.Ospfv3.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.HundredGigE.Ospfv3.DemandCircuit)), ("encryption", ("encryption", Native.Interface.HundredGigE.Ospfv3.Encryption)), ("manet", ("manet", Native.Interface.HundredGigE.Ospfv3.Manet)), ("multi-area", ("multi_area", Native.Interface.HundredGigE.Ospfv3.MultiArea)), ("neighbor", ("neighbor", Native.Interface.HundredGigE.Ospfv3.Neighbor)), ("network", ("network", Native.Interface.HundredGigE.Ospfv3.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.HundredGigE.Ospfv3.PrefixSuppression))])
                    self._leafs = OrderedDict([
                        ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                        ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                        ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                    ])
                    self.dead_interval = None
                    self.flood_reduction = None
                    self.hello_interval = None
                    self.mtu_ignore = None
                    self.priority = None
                    self.retransmit_interval = None
                    self.shutdown = None
                    self.transmit_delay = None

                    self.authentication = Native.Interface.HundredGigE.Ospfv3.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"

                    self.cost = Native.Interface.HundredGigE.Ospfv3.Cost()
                    self.cost.parent = self
                    self._children_name_map["cost"] = "cost"

                    self.database_filter = Native.Interface.HundredGigE.Ospfv3.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"

                    self.demand_circuit = None
                    self._children_name_map["demand_circuit"] = "demand-circuit"

                    self.encryption = Native.Interface.HundredGigE.Ospfv3.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.manet = Native.Interface.HundredGigE.Ospfv3.Manet()
                    self.manet.parent = self
                    self._children_name_map["manet"] = "manet"

                    self.multi_area = Native.Interface.HundredGigE.Ospfv3.MultiArea()
                    self.multi_area.parent = self
                    self._children_name_map["multi_area"] = "multi-area"

                    self.network = Native.Interface.HundredGigE.Ospfv3.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.prefix_suppression = None
                    self._children_name_map["prefix_suppression"] = "prefix-suppression"

                    self.process_id = YList(self)
                    self.neighbor = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3, ['dead_interval', u'flood_reduction', 'hello_interval', u'mtu_ignore', 'priority', 'retransmit_interval', u'shutdown', 'transmit_delay'], name, value)


                class ProcessId(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: manet
                    
                    	Mobile Adhoc Networking options
                    	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.MultiArea>`
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Network>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipv4
                    
                    	Specify parameters for IPv4
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Specify parameters for IPv6
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.ProcessId, self).__init__()

                        self.yang_name = "process-id"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.HundredGigE.Ospfv3.ProcessId.Authentication)), ("bfd", ("bfd", Native.Interface.HundredGigE.Ospfv3.ProcessId.Bfd)), ("cost", ("cost", Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost)), ("database-filter", ("database_filter", Native.Interface.HundredGigE.Ospfv3.ProcessId.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.HundredGigE.Ospfv3.ProcessId.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.HundredGigE.Ospfv3.ProcessId.FloodReduction)), ("manet", ("manet", Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.HundredGigE.Ospfv3.ProcessId.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.HundredGigE.Ospfv3.ProcessId.MultiArea)), ("neighbor", ("neighbor", Native.Interface.HundredGigE.Ospfv3.ProcessId.Neighbor)), ("network", ("network", Native.Interface.HundredGigE.Ospfv3.ProcessId.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.HundredGigE.Ospfv3.ProcessId.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.HundredGigE.Ospfv3.ProcessId.Shutdown)), ("ipv4", ("ipv4", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4)), ("ipv6", ("ipv6", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.id = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.HundredGigE.Ospfv3.ProcessId.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.cost = Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.database_filter = Native.Interface.HundredGigE.Ospfv3.ProcessId.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.manet = Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet()
                        self.manet.parent = self
                        self._children_name_map["manet"] = "manet"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.multi_area = Native.Interface.HundredGigE.Ospfv3.ProcessId.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.network = Native.Interface.HundredGigE.Ospfv3.ProcessId.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.ipv4 = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId, [u'id', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\: str
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.null = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Authentication, [u'key_chain', u'null'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Bfd, ['disable'], name, value)


                    class Cost(Entity):
                        """
                        Route cost of this interface
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dynamic
                        
                        	Specify dynamic cost options
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.dynamic = None
                            self._children_name_map["dynamic"] = "dynamic"
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost, [u'value'], name, value)


                        class Dynamic(Entity):
                            """
                            Specify dynamic cost options
                            
                            .. attribute:: default
                            
                            	Specify default link metric value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: hysteresis
                            
                            	Specify hysteresis value for LSA dampening
                            	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: weight
                            
                            	Specify weight to be placed on individual metrics
                            	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ])
                                self.default = None

                                self.hysteresis = None
                                self._children_name_map["hysteresis"] = "hysteresis"

                                self.weight = Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight()
                                self.weight.parent = self
                                self._children_name_map["weight"] = "weight"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic, [u'default'], name, value)


                            class Hysteresis(Entity):
                                """
                                Specify hysteresis value for LSA dampening
                                
                                .. attribute:: percent
                                
                                	Specify hysteresis percent changed
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold
                                
                                	Specify hysteresis threshold value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, self).__init__()

                                    self.yang_name = "hysteresis"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "hysteresis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                            class Weight(Entity):
                                """
                                Specify weight to be placed on individual metrics
                                
                                .. attribute:: l2_factor
                                
                                	Specify weight to be given to L2\-factor metric
                                	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: latency
                                
                                	Specify weight to be given to latency metric
                                	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: resources
                                
                                	Specify weight to be given to resources metric
                                	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: throughput
                                
                                	Specify weight to be given to throughput metric
                                	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight, self).__init__()

                                    self.yang_name = "weight"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput))])
                                    self._leafs = OrderedDict()

                                    self.l2_factor = None
                                    self._children_name_map["l2_factor"] = "L2-factor"

                                    self.latency = None
                                    self._children_name_map["latency"] = "latency"

                                    self.resources = None
                                    self._children_name_map["resources"] = "resources"

                                    self.throughput = None
                                    self._children_name_map["throughput"] = "throughput"
                                    self._segment_path = lambda: "weight"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight, [], name, value)


                                class L2Factor(Entity):
                                    """
                                    Specify weight to be given to L2\-factor metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                        self.yang_name = "L2-factor"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "L2-factor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                class Latency(Entity):
                                    """
                                    Specify weight to be given to latency metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, self).__init__()

                                        self.yang_name = "latency"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "latency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                class Resources(Entity):
                                    """
                                    Specify weight to be given to resources metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, self).__init__()

                                        self.yang_name = "resources"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "resources"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                class Throughput(Entity):
                                    """
                                    Specify weight to be given to throughput metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, self).__init__()

                                        self.yang_name = "throughput"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "throughput"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.ProcessId.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.DatabaseFilter, [u'all', u'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.DemandCircuit, [u'disable', u'ignore'], name, value)


                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.FloodReduction, [u'disable'], name, value)


                    class Manet(Entity):
                        """
                        Mobile Adhoc Networking options
                        
                        .. attribute:: peering
                        
                        	MANET Peering options
                        	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet.Peering>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet, self).__init__()

                            self.yang_name = "manet"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet.Peering))])
                            self._leafs = OrderedDict()

                            self.peering = Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet.Peering()
                            self.peering.parent = self
                            self._children_name_map["peering"] = "peering"
                            self._segment_path = lambda: "manet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet, [], name, value)


                        class Peering(Entity):
                            """
                            MANET Peering options
                            
                            .. attribute:: cost
                            
                            	Redundant path cost improvement required to peer
                            	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet.Peering.Cost>`
                            
                            .. attribute:: link_metrics
                            
                            	Require link metrics
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet.Peering, self).__init__()

                                self.yang_name = "peering"
                                self.yang_parent_name = "manet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet.Peering.Cost))])
                                self._leafs = OrderedDict([
                                    ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                ])
                                self.link_metrics = None

                                self.cost = Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet.Peering.Cost()
                                self.cost.parent = self
                                self._children_name_map["cost"] = "cost"
                                self._segment_path = lambda: "peering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet.Peering, [u'link_metrics'], name, value)


                            class Cost(Entity):
                                """
                                Redundant path cost improvement required to peer
                                
                                .. attribute:: percent
                                
                                	Relative incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                .. attribute:: threshold
                                
                                	Absolute incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet.Peering.Cost, self).__init__()

                                    self.yang_name = "cost"
                                    self.yang_parent_name = "peering"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "cost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.MtuIgnore, [u'disable'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: disable
                        
                        	disable OSPF multi\-area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.disable = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.MultiArea, [u'id', u'cost', u'disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.HundredGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.HundredGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.HundredGigE.Ospfv3.ProcessId.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.PrefixSuppression, ['disable'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Shutdown, [u'disable'], name, value)


                    class Ipv4(Entity):
                        """
                        Specify parameters for IPv4
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Area)), ("authentication", ("authentication", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Authentication)), ("bfd", ("bfd", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Bfd)), ("cost", ("cost", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost)), ("database-filter", ("database_filter", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.FloodReduction)), ("manet", ("manet", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.MultiArea)), ("neighbor", ("neighbor", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Neighbor)), ("network", ("network", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 64..95
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv4.Shutdown, [u'disable'], name, value)


                    class Ipv6(Entity):
                        """
                        Specify parameters for IPv6
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Area)), ("authentication", ("authentication", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Authentication)), ("bfd", ("bfd", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Bfd)), ("cost", ("cost", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost)), ("database-filter", ("database_filter", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.FloodReduction)), ("manet", ("manet", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.MultiArea)), ("neighbor", ("neighbor", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Neighbor)), ("network", ("network", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 0..31
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.ProcessId.Ipv6.Shutdown, [u'disable'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: key_chain
                    
                    	Use a key\-chain for cryptographic authentication keys
                    	**type**\: str
                    
                    .. attribute:: null
                    
                    	Use no authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec authentication
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.null = None

                        self.ipsec = Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Authentication, [u'key_chain', u'null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec authentication
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 256..4294967295
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5>`
                        
                        .. attribute:: sha1
                        
                        	Use SHA\-1 authentication
                        	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                            ])
                            self.spi = None

                            self.md5 = Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"

                            self.sha1 = Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1()
                            self.sha1.parent = self
                            self._children_name_map["sha1"] = "sha1"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec, ['spi'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class Sha1(Entity):
                            """
                            Use SHA\-1 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1, self).__init__()

                                self.yang_name = "sha1"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "sha1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "sha1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                class Bfd(Entity):
                    """
                    Enable BFD on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BFD on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Bfd, ['disable'], name, value)


                class Cost(Entity):
                    """
                    Route cost of this interface
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: dynamic
                    
                    	Specify dynamic cost options
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.Cost, self).__init__()

                        self.yang_name = "cost"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.dynamic = None
                        self._children_name_map["dynamic"] = "dynamic"
                        self._segment_path = lambda: "cost"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Cost, [u'value'], name, value)


                    class Dynamic(Entity):
                        """
                        Specify dynamic cost options
                        
                        .. attribute:: default
                        
                        	Specify default link metric value
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hysteresis
                        
                        	Specify hysteresis value for LSA dampening
                        	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Hysteresis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: weight
                        
                        	Specify weight to be placed on individual metrics
                        	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic, self).__init__()

                            self.yang_name = "dynamic"
                            self.yang_parent_name = "cost"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                            ])
                            self.default = None

                            self.hysteresis = None
                            self._children_name_map["hysteresis"] = "hysteresis"

                            self.weight = Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight()
                            self.weight.parent = self
                            self._children_name_map["weight"] = "weight"
                            self._segment_path = lambda: "dynamic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic, [u'default'], name, value)


                        class Hysteresis(Entity):
                            """
                            Specify hysteresis value for LSA dampening
                            
                            .. attribute:: percent
                            
                            	Specify hysteresis percent changed
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold
                            
                            	Specify hysteresis threshold value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Hysteresis, self).__init__()

                                self.yang_name = "hysteresis"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "hysteresis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                        class Weight(Entity):
                            """
                            Specify weight to be placed on individual metrics
                            
                            .. attribute:: l2_factor
                            
                            	Specify weight to be given to L2\-factor metric
                            	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.L2Factor>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: latency
                            
                            	Specify weight to be given to latency metric
                            	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Latency>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: resources
                            
                            	Specify weight to be given to resources metric
                            	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Resources>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: throughput
                            
                            	Specify weight to be given to throughput metric
                            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Throughput>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight, self).__init__()

                                self.yang_name = "weight"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Throughput))])
                                self._leafs = OrderedDict()

                                self.l2_factor = None
                                self._children_name_map["l2_factor"] = "L2-factor"

                                self.latency = None
                                self._children_name_map["latency"] = "latency"

                                self.resources = None
                                self._children_name_map["resources"] = "resources"

                                self.throughput = None
                                self._children_name_map["throughput"] = "throughput"
                                self._segment_path = lambda: "weight"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight, [], name, value)


                            class L2Factor(Entity):
                                """
                                Specify weight to be given to L2\-factor metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                    self.yang_name = "L2-factor"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "L2-factor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                            class Latency(Entity):
                                """
                                Specify weight to be given to latency metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Latency, self).__init__()

                                    self.yang_name = "latency"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "latency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                            class Resources(Entity):
                                """
                                Specify weight to be given to resources metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Resources, self).__init__()

                                    self.yang_name = "resources"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "resources"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                            class Throughput(Entity):
                                """
                                Specify weight to be given to throughput metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Throughput, self).__init__()

                                    self.yang_name = "throughput"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "throughput"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.DatabaseFilter.All')])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.DatabaseFilter, [u'all'], name, value)

                    class All(Enum):
                        """
                        All (Enum Class)

                        Filter all LSA

                        .. data:: out = 0

                        """

                        out = Enum.YLeaf(0, "out")



                class DemandCircuit(Entity):
                    """
                    OSPF Demand Circuit
                    
                    .. attribute:: ignore
                    
                    	Ignore demand circuit auto\-negotiation requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.DemandCircuit, self).__init__()

                        self.yang_name = "demand-circuit"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.ignore = None
                        self._segment_path = lambda: "demand-circuit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.DemandCircuit, [u'ignore'], name, value)


                class Encryption(Entity):
                    """
                    Enable encryption
                    
                    .. attribute:: null
                    
                    	No IPsec encryption on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec encryption
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec))])
                        self._leafs = OrderedDict([
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.null = None

                        self.ipsec = Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Encryption, ['null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec encryption
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: esp
                        
                        	Use ESP encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec_3des
                        
                        	Use 3DES encryption
                        	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des>`
                        
                        .. attribute:: aes_cbc
                        
                        	Use AES\-CBC encryption
                        	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                            ])
                            self.spi = None
                            self.esp = None

                            self.ipsec_3des = Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des()
                            self.ipsec_3des.parent = self
                            self._children_name_map["ipsec_3des"] = "ipsec_3des"

                            self.aes_cbc = Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc()
                            self.aes_cbc.parent = self
                            self._children_name_map["aes_cbc"] = "aes-cbc"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec, ['spi', 'esp'], name, value)


                        class Ipsec3des(Entity):
                            """
                            Use 3DES encryption
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des, self).__init__()

                                self.yang_name = "ipsec_3des"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "ipsec_3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "ipsec_3des"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class AesCbc(Entity):
                            """
                            Use AES\-CBC encryption
                            
                            .. attribute:: aes_cbc_128
                            
                            	Use 128 bit key
                            	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128>`
                            
                            .. attribute:: aes_192
                            
                            	Use 192 bit key
                            	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192>`
                            
                            .. attribute:: aes_256
                            
                            	Use 256 bit key
                            	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc, self).__init__()

                                self.yang_name = "aes-cbc"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256))])
                                self._leafs = OrderedDict()

                                self.aes_cbc_128 = Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128()
                                self.aes_cbc_128.parent = self
                                self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                self.aes_192 = Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192()
                                self.aes_192.parent = self
                                self._children_name_map["aes_192"] = "aes-192"

                                self.aes_256 = Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256()
                                self.aes_256.parent = self
                                self._children_name_map["aes_256"] = "aes-256"
                                self._segment_path = lambda: "aes-cbc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc, [], name, value)


                            class AesCbc128(Entity):
                                """
                                Use 128 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                    self.yang_name = "aes-cbc-128"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-cbc-128"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-cbc-128"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes192(Entity):
                                """
                                Use 192 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                    self.yang_name = "aes-192"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-192"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-192"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes256(Entity):
                                """
                                Use 256 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                    self.yang_name = "aes-256"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-256"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-256"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                class Manet(Entity):
                    """
                    Mobile Adhoc Networking options
                    
                    .. attribute:: peering
                    
                    	MANET Peering options
                    	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Manet.Peering>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.Manet, self).__init__()

                        self.yang_name = "manet"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.HundredGigE.Ospfv3.Manet.Peering))])
                        self._leafs = OrderedDict()

                        self.peering = Native.Interface.HundredGigE.Ospfv3.Manet.Peering()
                        self.peering.parent = self
                        self._children_name_map["peering"] = "peering"
                        self._segment_path = lambda: "manet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Manet, [], name, value)


                    class Peering(Entity):
                        """
                        MANET Peering options
                        
                        .. attribute:: cost
                        
                        	Redundant path cost improvement required to peer
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Manet.Peering.Cost>`
                        
                        .. attribute:: link_metrics
                        
                        	Require link metrics
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.Manet.Peering, self).__init__()

                            self.yang_name = "peering"
                            self.yang_parent_name = "manet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.HundredGigE.Ospfv3.Manet.Peering.Cost))])
                            self._leafs = OrderedDict([
                                ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                            ])
                            self.link_metrics = None

                            self.cost = Native.Interface.HundredGigE.Ospfv3.Manet.Peering.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"
                            self._segment_path = lambda: "peering"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Manet.Peering, [u'link_metrics'], name, value)


                        class Cost(Entity):
                            """
                            Redundant path cost improvement required to peer
                            
                            .. attribute:: percent
                            
                            	Relative incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: threshold
                            
                            	Absolute incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Ospfv3.Manet.Peering.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "peering"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                class MultiArea(Entity):
                    """
                    Set the OSPF multi\-area ID
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.MultiArea, self).__init__()

                        self.yang_name = "multi-area"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self._segment_path = lambda: "multi-area"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.MultiArea, [u'id', u'cost'], name, value)


                class Neighbor(Entity):
                    """
                    OSPF neighbor
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	OSPF cost for point\-to\-multipoint neighbor
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Neighbor.DatabaseFilter>`
                    
                    .. attribute:: poll_interval
                    
                    	OSPF dead\-router polling interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: priority
                    
                    	OSPF priority of non\-broadcast neighbor
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.HundredGigE.Ospfv3.Neighbor.DatabaseFilter))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self.poll_interval = None
                        self.priority = None

                        self.database_filter = Native.Interface.HundredGigE.Ospfv3.Neighbor.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Neighbor.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.Neighbor.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.HundredGigE.Ospfv3.Neighbor.DatabaseFilter.All')])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Neighbor.DatabaseFilter, ['all'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                class Network(Entity):
                    """
                    Network type
                    
                    .. attribute:: broadcast
                    
                    	Specify OSPF broadcast multi\-access network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: manet
                    
                    	Specify MANET OSPF interface type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: non_broadcast
                    
                    	Specify OSPF NBMA network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: point_to_multipoint
                    
                    	Specify OSPF point\-to\-multipoint network
                    	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Ospfv3.Network.PointToMultipoint>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: point_to_point
                    
                    	Specify OSPF point\-to\-point network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.HundredGigE.Ospfv3.Network.PointToMultipoint))])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                            ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                        ])
                        self.broadcast = None
                        self.manet = None
                        self.non_broadcast = None
                        self.point_to_point = None

                        self.point_to_multipoint = None
                        self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                    class PointToMultipoint(Entity):
                        """
                        Specify OSPF point\-to\-multipoint network
                        
                        .. attribute:: non_broadcast
                        
                        	Specify non\-broadcast point\-to\-mpoint network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Ospfv3.Network.PointToMultipoint, self).__init__()

                            self.yang_name = "point-to-multipoint"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ])
                            self.non_broadcast = None
                            self._segment_path = lambda: "point-to-multipoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.Network.PointToMultipoint, ['non_broadcast'], name, value)


                class PrefixSuppression(Entity):
                    """
                    OSPF prefix suppression
                    
                    .. attribute:: disable
                    
                    	Disable prefix suppression
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Ospfv3.PrefixSuppression, self).__init__()

                        self.yang_name = "prefix-suppression"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "prefix-suppression"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Ospfv3.PrefixSuppression, ['disable'], name, value)


            class Udld(Entity):
                """
                Configure UDLD enabled or disabled and ignore global UDLD setting
                
                .. attribute:: port
                
                	Enable UDLD protocol on this interface despite global UDLD setting
                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Udld.Port>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-udld'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Udld, self).__init__()

                    self.yang_name = "udld"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.HundredGigE.Udld.Port))])
                    self._leafs = OrderedDict()

                    self.port = None
                    self._children_name_map["port"] = "port"
                    self._segment_path = lambda: "Cisco-IOS-XE-udld:udld"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Udld, [], name, value)


                class Port(Entity):
                    """
                    Enable UDLD protocol on this interface despite global UDLD setting
                    
                    .. attribute:: aggressive
                    
                    	Enable UDLD protocol in aggressive mode on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	Disable UDLD protocol on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-udld'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Udld.Port, self).__init__()

                        self.yang_name = "port"
                        self.yang_parent_name = "udld"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aggressive', (YLeaf(YType.empty, 'aggressive'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.aggressive = None
                        self.disable = None
                        self._segment_path = lambda: "port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Udld.Port, ['aggressive', 'disable'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.Manual>`
                
                	**presence node**\: True
                
                .. attribute:: role_based
                
                	Role\-based Access Control per\-port config commands
                	**type**\:  :py:class:`RoleBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.RoleBased>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.HundredGigE.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.HundredGigE.Cts.Manual)), ("role-based", ("role_based", Native.Interface.HundredGigE.Cts.RoleBased))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"

                    self.role_based = Native.Interface.HundredGigE.Cts.RoleBased()
                    self.role_based.parent = self
                    self._children_name_map["role_based"] = "role-based"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.HundredGigE.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.HundredGigE.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.HundredGigE.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.HundredGigE.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.HundredGigE.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.HundredGigE.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.HundredGigE.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.HundredGigE.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.HundredGigE.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.HundredGigE.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.HundredGigE.Cts.Manual.Propagate, ['sgt'], name, value)


                class RoleBased(Entity):
                    """
                    Role\-based Access Control per\-port config commands
                    
                    .. attribute:: enforcement
                    
                    	Enable Role\-based Access Control enforcement
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.Cts.RoleBased, self).__init__()

                        self.yang_name = "role-based"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enforcement', (YLeaf(YType.empty, 'enforcement'), ['Empty'])),
                        ])
                        self.enforcement = None
                        self._segment_path = lambda: "role-based"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.Cts.RoleBased, ['enforcement'], name, value)


            class AnalysisModule(Entity):
                """
                Configure NAM on the interface
                
                .. attribute:: monitoring
                
                	Configure NAM monitoring on the interface
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.HundredGigE.AnalysisModule.Monitoring>`
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Interface.HundredGigE.AnalysisModule, self).__init__()

                    self.yang_name = "analysis-module"
                    self.yang_parent_name = "HundredGigE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Interface.HundredGigE.AnalysisModule.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = Native.Interface.HundredGigE.AnalysisModule.Monitoring()
                    self.monitoring.parent = self
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.HundredGigE.AnalysisModule, [], name, value)


                class Monitoring(Entity):
                    """
                    Configure NAM monitoring on the interface
                    
                    .. attribute:: interface_name
                    
                    	The name of the output interface.  E.g., 'ucse 1/0/0'
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nam'
                    _revision = '2017-12-28'

                    def __init__(self):
                        super(Native.Interface.HundredGigE.AnalysisModule.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "analysis-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "monitoring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.HundredGigE.AnalysisModule.Monitoring, ['interface_name'], name, value)


        class Loopback(Entity):
            """
            Loopback interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.PmPath>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.ServicePolicy>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Snmp>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Crypto>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Utd>`
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Lisp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ntp>`
            
            .. attribute:: performance
            
            	Global performance monitor configuration
            	**type**\:  :py:class:`Performance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Performance>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Umbrella>`
            
            .. attribute:: nat66
            
            	NAT66 interface commands
            	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Nat66>`
            
            .. attribute:: ospfv3
            
            	OSPFv3 interface commands
            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3>`
            
            .. attribute:: udld
            
            	Configure UDLD enabled or disabled and ignore global UDLD setting
            	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Udld>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Loopback, self).__init__()

                self.yang_name = "Loopback"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.Loopback.SwitchportConf)), ("switchport", ("switchport", Native.Interface.Loopback.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.Loopback.StackwiseVirtual)), ("arp", ("arp", Native.Interface.Loopback.Arp)), ("backup", ("backup", Native.Interface.Loopback.Backup)), ("cemoudp", ("cemoudp", Native.Interface.Loopback.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.Loopback.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.Loopback.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.Loopback.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.Loopback.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.Loopback.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.Loopback.Flowcontrol)), ("isis", ("isis", Native.Interface.Loopback.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.Loopback.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.Loopback.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.Loopback.Bandwidth)), ("dampening", ("dampening", Native.Interface.Loopback.Dampening)), ("domain", ("domain", Native.Interface.Loopback.Domain)), ("hold-queue", ("hold_queue", Native.Interface.Loopback.HoldQueue)), ("mpls", ("mpls", Native.Interface.Loopback.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.Loopback.IpVrf)), ("vrf", ("vrf", Native.Interface.Loopback.Vrf)), ("ip", ("ip", Native.Interface.Loopback.Ip)), ("ipv6", ("ipv6", Native.Interface.Loopback.Ipv6)), ("logging", ("logging", Native.Interface.Loopback.Logging)), ("mdix", ("mdix", Native.Interface.Loopback.Mdix)), ("mop", ("mop", Native.Interface.Loopback.Mop)), ("interface_qos", ("interface_qos", Native.Interface.Loopback.InterfaceQos)), ("source", ("source", Native.Interface.Loopback.Source)), ("standby", ("standby", Native.Interface.Loopback.Standby)), ("access-session", ("access_session", Native.Interface.Loopback.AccessSession)), ("storm-control", ("storm_control", Native.Interface.Loopback.StormControl)), ("trust", ("trust", Native.Interface.Loopback.Trust)), ("priority-queue", ("priority_queue", Native.Interface.Loopback.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.Loopback.RcvQueue)), ("peer", ("peer", Native.Interface.Loopback.Peer)), ("pm-path", ("pm_path", Native.Interface.Loopback.PmPath)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.Loopback.ServicePolicy)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.Loopback.Snmp)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.Loopback.Crypto)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.Loopback.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.Loopback.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.Loopback.Utd)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.Loopback.Lisp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.Loopback.Ntp)), ("Cisco-IOS-XE-ezpm:performance", ("performance", Native.Interface.Loopback.Performance)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.Loopback.Umbrella)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Interface.Loopback.Ospfv3)), ("Cisco-IOS-XE-udld:udld", ("udld", Native.Interface.Loopback.Udld)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.Loopback.Cts))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint32, 'name'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.ServiceInsertion')])),
                    ('nat66', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-nat:nat66'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Nat66')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.nat66 = None

                self.switchport_conf = Native.Interface.Loopback.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.Loopback.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.Loopback.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.Loopback.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.Loopback.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.Loopback.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.Loopback.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.Loopback.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.Loopback.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.Loopback.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.Loopback.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.Loopback.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.Loopback.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.Loopback.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.Loopback.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.Loopback.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.Loopback.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.Loopback.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.Loopback.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.Loopback.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.Loopback.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.Loopback.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.Loopback.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.Loopback.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.Loopback.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.Loopback.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.Loopback.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.Loopback.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.Loopback.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.Loopback.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.Loopback.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.Loopback.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.Loopback.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.Loopback.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.Loopback.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.service_policy = Native.Interface.Loopback.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.snmp = Native.Interface.Loopback.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.crypto = Native.Interface.Loopback.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.et_analytics = Native.Interface.Loopback.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.Loopback.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.Loopback.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.lisp = Native.Interface.Loopback.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.ntp = Native.Interface.Loopback.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.performance = Native.Interface.Loopback.Performance()
                self.performance.parent = self
                self._children_name_map["performance"] = "Cisco-IOS-XE-ezpm:performance"

                self.umbrella = Native.Interface.Loopback.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.ospfv3 = Native.Interface.Loopback.Ospfv3()
                self.ospfv3.parent = self
                self._children_name_map["ospfv3"] = "Cisco-IOS-XE-ospfv3:ospfv3"

                self.udld = Native.Interface.Loopback.Udld()
                self.udld.parent = self
                self._children_name_map["udld"] = "Cisco-IOS-XE-udld:udld"

                self.cts = Native.Interface.Loopback.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "Loopback" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Loopback, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'nat66'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class Nat66(Enum):
                """
                Nat66 (Enum Class)

                NAT66 interface commands

                .. data:: inside = 0

                .. data:: outside = 1

                """

                inside = Enum.YLeaf(0, "inside")

                outside = Enum.YLeaf(1, "outside")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Loopback.Backup.Delay)), ("interface", ("interface", Native.Interface.Loopback.Backup.Interface_)), ("load", ("load", Native.Interface.Loopback.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Loopback.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Loopback.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Loopback.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Loopback.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Loopback.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Loopback.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Loopback.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Loopback.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Loopback.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Loopback.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Loopback.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Loopback.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Loopback.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Loopback.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Loopback.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Loopback.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Loopback.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Loopback.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Loopback.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Loopback.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Loopback.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Loopback.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.Loopback.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Loopback.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Loopback.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Loopback.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.Loopback.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.Loopback.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.Loopback.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.Loopback.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.Loopback.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.Loopback.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.Loopback.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.Loopback.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.Loopback.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.Loopback.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.Loopback.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.Loopback.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.Loopback.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.Loopback.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.Loopback.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.Loopback.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.Loopback.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.Loopback.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.Loopback.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.Loopback.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.Loopback.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.Loopback.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.Loopback.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.Loopback.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.Loopback.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Loopback.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.Loopback.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.Loopback.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.Loopback.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.Loopback.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Loopback.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.Loopback.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.Loopback.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.Loopback.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.Loopback.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.Loopback.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.Loopback.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.Loopback.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.Loopback.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.Loopback.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.Loopback.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.Loopback.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.Loopback.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.Loopback.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Loopback.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Loopback.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Loopback.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Loopback.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Loopback.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Loopback.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.Loopback.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.Loopback.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.Loopback.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.Loopback.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.Loopback.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.Loopback.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.Loopback.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.Loopback.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.Loopback.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.Loopback.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.Loopback.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.Loopback.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.Loopback.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.Loopback.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.Loopback.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.Loopback.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.Loopback.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.Loopback.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.Loopback.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.Loopback.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.Loopback.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.Loopback.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.Loopback.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.Loopback.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.Loopback.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.Loopback.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.Loopback.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Loopback.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Loopback.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Loopback.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Loopback.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Igmp>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Flow>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Nbar>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf>`
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Lisp>`
                
                .. attribute:: rsvp
                
                	RSVP Interface Commands
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Nat>`
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Loopback.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.Loopback.Ip.Arp)), ("vrf", ("vrf", Native.Interface.Loopback.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.Loopback.Ip.NoAddress)), ("address", ("address", Native.Interface.Loopback.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Loopback.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Loopback.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.Loopback.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.Loopback.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Loopback.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.Loopback.Ip.Pim)), ("policy", ("policy", Native.Interface.Loopback.Ip.Policy)), ("rip", ("rip", Native.Interface.Loopback.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Loopback.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Loopback.Ip.RouteCache)), ("router", ("router", Native.Interface.Loopback.Ip.Router)), ("tcp", ("tcp", Native.Interface.Loopback.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Loopback.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Loopback.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Loopback.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.Loopback.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.Loopback.Ip.Igmp)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.Loopback.Ip.Flow)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.Loopback.Ip.Nbar)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.Loopback.Ip.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.Loopback.Ip.Lisp)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Interface.Loopback.Ip.Rsvp)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.Loopback.Ip.Nat)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.Loopback.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.Loopback.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Loopback.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Loopback.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Loopback.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Loopback.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Loopback.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Loopback.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Loopback.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Loopback.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Loopback.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Loopback.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Loopback.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Loopback.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Loopback.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Loopback.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Loopback.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Loopback.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Loopback.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.Loopback.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.flow = Native.Interface.Loopback.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.nbar = Native.Interface.Loopback.Ip.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.ospf = Native.Interface.Loopback.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.lisp = Native.Interface.Loopback.Ip.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                    self.rsvp = Native.Interface.Loopback.Ip.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

                    self.nat = Native.Interface.Loopback.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.wccp = Native.Interface.Loopback.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Loopback.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.Loopback.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Loopback.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Loopback.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Loopback.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Loopback.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Loopback.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Loopback.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Loopback.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Loopback.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Loopback.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Loopback.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Loopback.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Loopback.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Loopback.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Loopback.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Loopback.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Loopback.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Loopback.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.Loopback.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Loopback.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Loopback.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Loopback.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Loopback.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Loopback.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Loopback.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Loopback.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Loopback.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.Loopback.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.Loopback.Ip.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ip.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ip.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.Loopback.Ip.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.Loopback.Ip.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Loopback.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Loopback.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Loopback.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Loopback.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Loopback.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.Loopback.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.Loopback.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.Loopback.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.Loopback.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.Loopback.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.Loopback.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.Loopback.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.Loopback.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.Loopback.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.Loopback.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.Loopback.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.Loopback.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.Loopback.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.Loopback.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.Loopback.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.Loopback.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.Loopback.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.Loopback.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.Loopback.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Loopback.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Loopback.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Loopback.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Loopback.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Loopback.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.Loopback.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Loopback.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Loopback.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Loopback.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Loopback.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Loopback.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Loopback.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Loopback.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.Loopback.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.Loopback.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.Loopback.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.Loopback.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.Loopback.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.Loopback.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.Loopback.Ip.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ip.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.Loopback.Ip.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.Loopback.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.Loopback.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.Loopback.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.Loopback.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.Loopback.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.Loopback.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.Loopback.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.Loopback.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.Loopback.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.Loopback.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.Loopback.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.Loopback.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.Loopback.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.Loopback.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.Loopback.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.Loopback.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.Loopback.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.Loopback.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Loopback.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.Loopback.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.Loopback.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.Loopback.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Loopback.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.Loopback.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Lisp(Entity):
                    """
                    Locator/ID Separation Protocol
                    
                    .. attribute:: source_locator
                    
                    	Choose IP source address for LISP packets egressing this interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_locator', (YLeaf(YType.str, 'source-locator'), ['str'])),
                        ])
                        self.source_locator = None
                        self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Lisp, ['source_locator'], name, value)


                class Rsvp(Entity):
                    """
                    RSVP Interface Commands
                    
                    .. attribute:: authentication
                    
                    	Enables RSVP neighbor authentication (RFC 2747)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bandwidth
                    
                    	RSVP Reservable Bandwidth (kbps)
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Bandwidth>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	Select permissible RSVP neighbors
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Neighbor>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: precedence
                    
                    	RSVP precedence setting
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Precedence>`
                    
                    .. attribute:: signalling
                    
                    	RSVP signalling
                    	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Signalling>`
                    
                    .. attribute:: tos
                    
                    	RSVP TOS setting
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Tos>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Loopback.Ip.Rsvp.Authentication)), ("bandwidth", ("bandwidth", Native.Interface.Loopback.Ip.Rsvp.Bandwidth)), ("neighbor", ("neighbor", Native.Interface.Loopback.Ip.Rsvp.Neighbor)), ("precedence", ("precedence", Native.Interface.Loopback.Ip.Rsvp.Precedence)), ("signalling", ("signalling", Native.Interface.Loopback.Ip.Rsvp.Signalling)), ("tos", ("tos", Native.Interface.Loopback.Ip.Rsvp.Tos))])
                        self._leafs = OrderedDict()

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.bandwidth = None
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.neighbor = None
                        self._children_name_map["neighbor"] = "neighbor"

                        self.precedence = Native.Interface.Loopback.Ip.Rsvp.Precedence()
                        self.precedence.parent = self
                        self._children_name_map["precedence"] = "precedence"

                        self.signalling = Native.Interface.Loopback.Ip.Rsvp.Signalling()
                        self.signalling.parent = self
                        self._children_name_map["signalling"] = "signalling"

                        self.tos = Native.Interface.Loopback.Ip.Rsvp.Tos()
                        self.tos.parent = self
                        self._children_name_map["tos"] = "tos"
                        self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp, [], name, value)


                    class Authentication(Entity):
                        """
                        Enables RSVP neighbor authentication (RFC 2747)
                        
                        .. attribute:: key
                        
                        	Password (8 to 40 characters, spaces allowed)
                        	**type**\: str
                        
                        .. attribute:: challenge
                        
                        	Perform challenge/response handshake with new neighbor(s)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key_chain
                        
                        	Name of key chain to use (as created by global 'key chain' command)
                        	**type**\: str
                        
                        .. attribute:: lifetime
                        
                        	Maximum lifetime of neighbor authentication state
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Authentication.Lifetime>`
                        
                        .. attribute:: type
                        
                        	Type of authentication algorithm (default = md5)
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Authentication.Type>`
                        
                        .. attribute:: window_size
                        
                        	Maximum number of messages allowed in receive window (default = 1)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Rsvp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Interface.Loopback.Ip.Rsvp.Authentication.Lifetime))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ip.Rsvp.Authentication.Type')])),
                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                            ])
                            self.key = None
                            self.challenge = None
                            self.key_chain = None
                            self.type = None
                            self.window_size = None

                            self.lifetime = Native.Interface.Loopback.Ip.Rsvp.Authentication.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Authentication, ['key', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Type of authentication algorithm (default = md5)

                            .. data:: md5 = 0

                            .. data:: sha_1 = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            sha_1 = Enum.YLeaf(1, "sha-1")



                        class Lifetime(Entity):
                            """
                            Maximum lifetime of neighbor authentication state
                            
                            .. attribute:: hh_mm_ss
                            
                            	Lifetime (default = 30 mins) in hh\:mm\:ss format
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ])
                                self.hh_mm_ss = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


                    class Bandwidth(Entity):
                        """
                        RSVP Reservable Bandwidth (kbps)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Value>`
                        
                        .. attribute:: percent
                        
                        	Percentage of interface bandwidth. Values higher than 100 represent overbooking
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: mam
                        
                        	Use bandwidth with MAM model of DSTE
                        	**type**\:  :py:class:`Mam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Mam>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Rsvp.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Value)), ("mam", ("mam", Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Mam))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                            ])
                            self.percent = None

                            self.value = Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.mam = Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Mam()
                            self.mam.parent = self
                            self._children_name_map["mam"] = "mam"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Bandwidth, ['percent'], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	Reservable Bandwidth (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            .. attribute:: sub_pool
                            
                            	Reservable Bandwidth for Tunnel using sub (BC1) pool (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.value = None
                                self.sub_pool = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Value, ['value', 'sub_pool'], name, value)


                        class Mam(Entity):
                            """
                            Use bandwidth with MAM model of DSTE
                            
                            .. attribute:: max_reservable_bw
                            
                            	Maximum Reservable bandwidth for MAM
                            	**type**\:  :py:class:`MaxReservableBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Mam, self).__init__()

                                self.yang_name = "mam"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("max-reservable-bw", ("max_reservable_bw", Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw))])
                                self._leafs = OrderedDict()

                                self.max_reservable_bw = None
                                self._children_name_map["max_reservable_bw"] = "max-reservable-bw"
                                self._segment_path = lambda: "mam"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Mam, [], name, value)


                            class MaxReservableBw(Entity):
                                """
                                Maximum Reservable bandwidth for MAM
                                
                                .. attribute:: value
                                
                                	Reservable Bandwidth (kbps)
                                	**type**\: int
                                
                                	**range:** 1..10000000
                                
                                .. attribute:: bc0
                                
                                	Reservable Bandwidth from global (BC0) pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                .. attribute:: bc1
                                
                                	Reservable Bandwidth from sub pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, self).__init__()

                                    self.yang_name = "max-reservable-bw"
                                    self.yang_parent_name = "mam"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                        ('bc0', (YLeaf(YType.uint32, 'bc0'), ['int'])),
                                        ('bc1', (YLeaf(YType.uint32, 'bc1'), ['int'])),
                                    ])
                                    self.value = None
                                    self.bc0 = None
                                    self.bc1 = None
                                    self._segment_path = lambda: "max-reservable-bw"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, ['value', 'bc0', 'bc1'], name, value)


                    class Neighbor(Entity):
                        """
                        Select permissible RSVP neighbors
                        
                        .. attribute:: acl_number
                        
                        	Access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Rsvp.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                            ])
                            self.acl_number = None
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Neighbor, ['acl_number'], name, value)


                    class Precedence(Entity):
                        """
                        RSVP precedence setting
                        
                        .. attribute:: conform
                        
                        	Precedence for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: exceed
                        
                        	Precedence for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Rsvp.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Precedence, ['conform', 'exceed'], name, value)


                    class Signalling(Entity):
                        """
                        RSVP signalling
                        
                        .. attribute:: dscp
                        
                        	DSCP for RSVP signalling messages
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: fast_local_repair
                        
                        	Fast Local Repair parameters
                        	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Signalling.FastLocalRepair>`
                        
                        .. attribute:: hello
                        
                        	Enable neighbor\-down detection
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Rsvp.Signalling, self).__init__()

                            self.yang_name = "signalling"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Interface.Loopback.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.fast_local_repair = Native.Interface.Loopback.Ip.Rsvp.Signalling.FastLocalRepair()
                            self.fast_local_repair.parent = self
                            self._children_name_map["fast_local_repair"] = "fast-local-repair"

                            self.hello = None
                            self._children_name_map["hello"] = "hello"
                            self._segment_path = lambda: "signalling"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Signalling, ['dscp'], name, value)


                        class FastLocalRepair(Entity):
                            """
                            Fast Local Repair parameters
                            
                            .. attribute:: wait_time
                            
                            	Wait Time for start of Fast Local Repair in msec
                            	**type**\: int
                            
                            	**range:** 0..5000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                                self.yang_name = "fast-local-repair"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint16, 'wait-time'), ['int'])),
                                ])
                                self.wait_time = None
                                self._segment_path = lambda: "fast-local-repair"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Signalling.FastLocalRepair, ['wait_time'], name, value)


                        class Hello(Entity):
                            """
                            Enable neighbor\-down detection
                            
                            .. attribute:: bfd
                            
                            	Configure BFD trigger for MPLS/TE FRR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	DSCP for RSVP Hello messages
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: graceful_restart
                            
                            	Configure RSVP Graceful Restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: refresh
                            
                            	Configure RSVP Hello refresh behavior for Fast\-Reroute
                            	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Refresh>`
                            
                            .. attribute:: reroute
                            
                            	Configure RSVP Hello refresh behavior for Reroute
                            	**type**\:  :py:class:`Reroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Reroute>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Refresh)), ("reroute", ("reroute", Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Reroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ('graceful_restart', (YLeaf(YType.empty, 'graceful-restart'), ['Empty'])),
                                ])
                                self.bfd = None
                                self.dscp = None
                                self.graceful_restart = None

                                self.refresh = Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Refresh()
                                self.refresh.parent = self
                                self._children_name_map["refresh"] = "refresh"

                                self.reroute = Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Reroute()
                                self.reroute.parent = self
                                self._children_name_map["reroute"] = "reroute"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello, ['bfd', 'dscp', 'graceful_restart'], name, value)


                            class Refresh(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Fast\-Reroute
                                
                                .. attribute:: interval
                                
                                	Hello interval in msec
                                	**type**\: int
                                
                                	**range:** 10..30000
                                
                                .. attribute:: misses
                                
                                	Number of missed Hello Acks which triggers neighbor down
                                	**type**\: int
                                
                                	**range:** 4..10
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Refresh, self).__init__()

                                    self.yang_name = "refresh"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.misses = None
                                    self._segment_path = lambda: "refresh"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Refresh, ['interval', 'misses'], name, value)


                            class Reroute(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Reroute
                                
                                .. attribute:: dscp
                                
                                	DSCP for RSVP Hello messages
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: refresh
                                
                                	Configure RSVP Reroute Hello refresh behavior
                                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Reroute.Refresh>`
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Reroute, self).__init__()

                                    self.yang_name = "reroute"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Reroute.Refresh))])
                                    self._leafs = OrderedDict([
                                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ])
                                    self.dscp = None

                                    self.refresh = Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Reroute.Refresh()
                                    self.refresh.parent = self
                                    self._children_name_map["refresh"] = "refresh"
                                    self._segment_path = lambda: "reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Reroute, ['dscp'], name, value)


                                class Refresh(Entity):
                                    """
                                    Configure RSVP Reroute Hello refresh behavior
                                    
                                    .. attribute:: interval
                                    
                                    	Hello Reroute interval in msec
                                    	**type**\: int
                                    
                                    	**range:** 1000..30000
                                    
                                    .. attribute:: misses
                                    
                                    	Number of missed Hello Acks which triggers neighbor down
                                    	**type**\: int
                                    
                                    	**range:** 4..10
                                    
                                    

                                    """

                                    _prefix = 'ios-rsvp'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, self).__init__()

                                        self.yang_name = "refresh"
                                        self.yang_parent_name = "reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.misses = None
                                        self._segment_path = lambda: "refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, ['interval', 'misses'], name, value)


                    class Tos(Entity):
                        """
                        RSVP TOS setting
                        
                        .. attribute:: conform
                        
                        	TOS for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: exceed
                        
                        	TOS for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Rsvp.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Rsvp.Tos, ['conform', 'exceed'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.Loopback.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.Loopback.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.Loopback.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.Loopback.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.Loopback.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.Loopback.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Loopback.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.Loopback.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Loopback.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.Loopback.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.Loopback.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.Loopback.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.Loopback.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.Loopback.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.Loopback.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Loopback.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.Loopback.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Loopback.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.Loopback.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.TrafficFilter>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Flow>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Crypto>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Pim>`
                
                .. attribute:: rip
                
                	Configure RIP routing protocol
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Rip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Loopback.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Loopback.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Loopback.Ipv6.Dhcp)), ("address", ("address", Native.Interface.Loopback.Ipv6.Address)), ("nd", ("nd", Native.Interface.Loopback.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.Loopback.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Loopback.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.Loopback.Ipv6.Flow)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.Loopback.Ipv6.Crypto)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.Loopback.Ipv6.Ospf)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.Loopback.Ipv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.Loopback.Ipv6.Pim)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Interface.Loopback.Ipv6.Rip))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Loopback.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Loopback.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Loopback.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Loopback.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.flow = Native.Interface.Loopback.Ipv6.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.crypto = Native.Interface.Loopback.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.ospf = Native.Interface.Loopback.Ipv6.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.no_pim = Native.Interface.Loopback.Ipv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.Loopback.Ipv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.Loopback.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.Loopback.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.Loopback.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.Loopback.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.Loopback.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.Loopback.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Loopback.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Loopback.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Loopback.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Loopback.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.Loopback.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.Loopback.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.Loopback.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.Loopback.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.Loopback.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.Loopback.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.Loopback.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.Loopback.Ipv6.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.Loopback.Ipv6.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ipv6.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ipv6.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ipv6.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Crypto, ['map'], name, value)


                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process
                    
                    	
                    	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Process>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: encryption
                    
                    	Enable encryption
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Network>`
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process", ("process", Native.Interface.Loopback.Ipv6.Ospf.Process)), ("authentication", ("authentication", Native.Interface.Loopback.Ipv6.Ospf.Authentication)), ("bfd", ("bfd", Native.Interface.Loopback.Ipv6.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.Loopback.Ipv6.Ospf.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.Loopback.Ipv6.Ospf.DemandCircuit)), ("encryption", ("encryption", Native.Interface.Loopback.Ipv6.Ospf.Encryption)), ("flood-reduction", ("flood_reduction", Native.Interface.Loopback.Ipv6.Ospf.FloodReduction)), ("mtu-ignore", ("mtu_ignore", Native.Interface.Loopback.Ipv6.Ospf.MtuIgnore)), ("neighbor", ("neighbor", Native.Interface.Loopback.Ipv6.Ospf.Neighbor)), ("network", ("network", Native.Interface.Loopback.Ipv6.Ospf.Network)), ("shutdown", ("shutdown", Native.Interface.Loopback.Ipv6.Ospf.Shutdown))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.cost = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.Loopback.Ipv6.Ospf.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.Loopback.Ipv6.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.encryption = Native.Interface.Loopback.Ipv6.Ospf.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.network = Native.Interface.Loopback.Ipv6.Ospf.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.process = YList(self)
                        self.neighbor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf, ['cost', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Process(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: instance
                        
                        	Set the OSPF instance
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..31
                        
                        		**type**\: int
                        
                        			**range:** 32..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Ospf.Process, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['int','int'])),
                            ])
                            self.id = None
                            self.area = None
                            self.instance = None
                            self._segment_path = lambda: "process" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Process, ['id', 'area', 'instance'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec authentication
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Authentication, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec authentication
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 256..4294967295
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5>`
                            
                            .. attribute:: sha1
                            
                            	Use SHA\-1 authentication
                            	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ])
                                self.spi = None

                                self.md5 = Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.sha1 = Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1()
                                self.sha1.parent = self
                                self._children_name_map["sha1"] = "sha1"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec, ['spi'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Sha1(Entity):
                                """
                                Use SHA\-1 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1, self).__init__()

                                    self.yang_name = "sha1"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "sha1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "sha1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ipv6.Ospf.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.DatabaseFilter, ['all', 'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.DemandCircuit, ['disable', 'ignore'], name, value)


                    class Encryption(Entity):
                        """
                        Enable encryption
                        
                        .. attribute:: null
                        
                        	No IPsec encryption on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec encryption
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Ospf.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Encryption, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec encryption
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: esp
                            
                            	Use ESP encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipsec_3des
                            
                            	Use 3DES encryption
                            	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des>`
                            
                            .. attribute:: aes_cbc
                            
                            	Use AES\-CBC encryption
                            	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                                ])
                                self.spi = None
                                self.esp = None

                                self.ipsec_3des = Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des()
                                self.ipsec_3des.parent = self
                                self._children_name_map["ipsec_3des"] = "ipsec_3des"

                                self.aes_cbc = Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc()
                                self.aes_cbc.parent = self
                                self._children_name_map["aes_cbc"] = "aes-cbc"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec, ['spi', 'esp'], name, value)


                            class Ipsec3des(Entity):
                                """
                                Use 3DES encryption
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, self).__init__()

                                    self.yang_name = "ipsec_3des"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "ipsec_3des"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "ipsec_3des"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class AesCbc(Entity):
                                """
                                Use AES\-CBC encryption
                                
                                .. attribute:: aes_cbc_128
                                
                                	Use 128 bit key
                                	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128>`
                                
                                .. attribute:: aes_192
                                
                                	Use 192 bit key
                                	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192>`
                                
                                .. attribute:: aes_256
                                
                                	Use 256 bit key
                                	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc, self).__init__()

                                    self.yang_name = "aes-cbc"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256))])
                                    self._leafs = OrderedDict()

                                    self.aes_cbc_128 = Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128()
                                    self.aes_cbc_128.parent = self
                                    self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                    self.aes_192 = Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192()
                                    self.aes_192.parent = self
                                    self._children_name_map["aes_192"] = "aes-192"

                                    self.aes_256 = Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256()
                                    self.aes_256.parent = self
                                    self._children_name_map["aes_256"] = "aes-256"
                                    self._segment_path = lambda: "aes-cbc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc, [], name, value)


                                class AesCbc128(Entity):
                                    """
                                    Use 128 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                        self.yang_name = "aes-cbc-128"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-cbc-128"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-cbc-128"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes192(Entity):
                                    """
                                    Use 192 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                        self.yang_name = "aes-192"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-192"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-192"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes256(Entity):
                                    """
                                    Use 256 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                        self.yang_name = "aes-256"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-256"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	Disable Flood Reduction on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Ospf.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.FloodReduction, ['disable'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Ospf.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.MtuIgnore, ['disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Ospf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.Loopback.Ipv6.Ospf.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.Loopback.Ipv6.Ospf.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ipv6.Ospf.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ipv6.Ospf.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Ospf.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Ospf.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.Loopback.Ipv6.Ospf.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ipv6.Ospf.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Ospf.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Ospf.Shutdown, ['disable'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.Loopback.Ipv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.Loopback.Ipv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Pim.Bsr, ['border'], name, value)


                class Rip(Entity):
                    """
                    Configure RIP routing protocol
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable/disable RIP routing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default_information
                    
                    	Configure handling of default route
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Rip.DefaultInformation>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ipv6.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("default-information", ("default_information", Native.Interface.Loopback.Ipv6.Rip.DefaultInformation))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.id = None
                        self.enable = None

                        self.default_information = Native.Interface.Loopback.Ipv6.Rip.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ipv6.Rip, ['id', 'enable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Configure handling of default route
                        
                        .. attribute:: route
                        
                        	
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ipv6.Rip.DefaultInformation.Route>`
                        
                        .. attribute:: metric
                        
                        	Default route metric
                        	**type**\: int
                        
                        	**range:** 1..15
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ipv6.Rip.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route', (YLeaf(YType.enumeration, 'route'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ipv6.Rip.DefaultInformation.Route')])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ])
                            self.route = None
                            self.metric = None
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ipv6.Rip.DefaultInformation, ['route', 'metric'], name, value)

                        class Route(Enum):
                            """
                            Route (Enum Class)

                            .. data:: only = 0

                            .. data:: originate = 1

                            """

                            only = Enum.YLeaf(0, "only")

                            originate = Enum.YLeaf(1, "originate")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Loopback.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Loopback.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Loopback.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Loopback.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Loopback.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Loopback.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Loopback.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Loopback.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Loopback.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Loopback.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.Loopback.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Loopback.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Loopback.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Loopback.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Loopback.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Loopback.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Loopback.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Loopback.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Loopback.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Loopback.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.Loopback.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Loopback.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Loopback.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Loopback.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Loopback.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Loopback.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Loopback.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Loopback.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Loopback.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Loopback.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Loopback.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Loopback.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Loopback.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Loopback.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Loopback.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Loopback.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Loopback.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Loopback.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Loopback.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Loopback.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Loopback.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Loopback.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Loopback.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Loopback.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Loopback.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Loopback.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Loopback.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Loopback.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Loopback.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Loopback.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Loopback.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Loopback.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Loopback.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Loopback.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Loopback.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Loopback.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Loopback.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Loopback.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Loopback.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Loopback.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Loopback.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Loopback.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Loopback.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Loopback.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Loopback.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Loopback.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Loopback.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Loopback.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Loopback.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Loopback.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Loopback.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Loopback.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Loopback.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Loopback.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Loopback.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Loopback.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Loopback.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Loopback.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Loopback.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Loopback.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Loopback.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Loopback.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Loopback.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Loopback.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Loopback.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Loopback.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Loopback.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Loopback.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.PmPath, [u'name', u'interface_id'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Loopback.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.Loopback.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.Loopback.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.Loopback.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.Loopback.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.Loopback.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.Loopback.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.Loopback.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.Loopback.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.Loopback.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.Loopback.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.Loopback.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.Loopback.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Loopback.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.Loopback.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.Loopback.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.Loopback.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.Loopback.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Loopback.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.Loopback.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.Loopback.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.Loopback.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.Loopback.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Loopback.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.Loopback.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Loopback.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Utd, ['enable'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.Loopback.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.Loopback.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.Loopback.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.Loopback.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.Loopback.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.Loopback.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.Loopback.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.Loopback.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.Loopback.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.Loopback.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.Loopback.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.Loopback.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.Loopback.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.Loopback.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Loopback.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.Loopback.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.Loopback.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.Loopback.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.Loopback.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class Performance(Entity):
                """
                Global performance monitor configuration
                
                .. attribute:: monitor
                
                	monitor
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Performance.Monitor>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.Loopback.Performance, self).__init__()

                    self.yang_name = "performance"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.Loopback.Performance.Monitor))])
                    self._leafs = OrderedDict()

                    self.monitor = Native.Interface.Loopback.Performance.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"
                    self._segment_path = lambda: "Cisco-IOS-XE-ezpm:performance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Performance, [], name, value)


                class Monitor(Entity):
                    """
                    monitor
                    
                    .. attribute:: context
                    
                    	Select ezPM context
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Loopback.Performance.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "performance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('context', (YLeafList(YType.str, 'context'), ['str'])),
                        ])
                        self.context = []
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Performance.Monitor, ['context'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.Loopback.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Umbrella, ['out', 'in_'], name, value)


            class Ospfv3(Entity):
                """
                OSPFv3 interface commands
                
                .. attribute:: process_id
                
                	
                	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId>`
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Authentication>`
                
                .. attribute:: bfd
                
                	Enable BFD on this interface
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: cost
                
                	Route cost of this interface
                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Cost>`
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: demand_circuit
                
                	OSPF Demand Circuit
                	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.DemandCircuit>`
                
                	**presence node**\: True
                
                .. attribute:: encryption
                
                	Enable encryption
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption>`
                
                .. attribute:: flood_reduction
                
                	OSPF Flood Reduction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: manet
                
                	Mobile Adhoc Networking options
                	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Manet>`
                
                .. attribute:: mtu_ignore
                
                	Ignores the MTU in DBD packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: multi_area
                
                	Set the OSPF multi\-area ID
                	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.MultiArea>`
                
                .. attribute:: neighbor
                
                	OSPF neighbor
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Neighbor>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Network>`
                
                .. attribute:: prefix_suppression
                
                	OSPF prefix suppression
                	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.PrefixSuppression>`
                
                	**presence node**\: True
                
                .. attribute:: priority
                
                	Router priority
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: retransmit_interval
                
                	Time between retransmitting lost link state advertisements
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Shut down the interface in OSPFv3
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transmit_delay
                
                	Link state transmit delay
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Loopback.Ospfv3, self).__init__()

                    self.yang_name = "ospfv3"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.Loopback.Ospfv3.ProcessId)), ("authentication", ("authentication", Native.Interface.Loopback.Ospfv3.Authentication)), ("bfd", ("bfd", Native.Interface.Loopback.Ospfv3.Bfd)), ("cost", ("cost", Native.Interface.Loopback.Ospfv3.Cost)), ("database-filter", ("database_filter", Native.Interface.Loopback.Ospfv3.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.Loopback.Ospfv3.DemandCircuit)), ("encryption", ("encryption", Native.Interface.Loopback.Ospfv3.Encryption)), ("manet", ("manet", Native.Interface.Loopback.Ospfv3.Manet)), ("multi-area", ("multi_area", Native.Interface.Loopback.Ospfv3.MultiArea)), ("neighbor", ("neighbor", Native.Interface.Loopback.Ospfv3.Neighbor)), ("network", ("network", Native.Interface.Loopback.Ospfv3.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.Loopback.Ospfv3.PrefixSuppression))])
                    self._leafs = OrderedDict([
                        ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                        ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                        ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                    ])
                    self.dead_interval = None
                    self.flood_reduction = None
                    self.hello_interval = None
                    self.mtu_ignore = None
                    self.priority = None
                    self.retransmit_interval = None
                    self.shutdown = None
                    self.transmit_delay = None

                    self.authentication = Native.Interface.Loopback.Ospfv3.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"

                    self.cost = Native.Interface.Loopback.Ospfv3.Cost()
                    self.cost.parent = self
                    self._children_name_map["cost"] = "cost"

                    self.database_filter = Native.Interface.Loopback.Ospfv3.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"

                    self.demand_circuit = None
                    self._children_name_map["demand_circuit"] = "demand-circuit"

                    self.encryption = Native.Interface.Loopback.Ospfv3.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.manet = Native.Interface.Loopback.Ospfv3.Manet()
                    self.manet.parent = self
                    self._children_name_map["manet"] = "manet"

                    self.multi_area = Native.Interface.Loopback.Ospfv3.MultiArea()
                    self.multi_area.parent = self
                    self._children_name_map["multi_area"] = "multi-area"

                    self.network = Native.Interface.Loopback.Ospfv3.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.prefix_suppression = None
                    self._children_name_map["prefix_suppression"] = "prefix-suppression"

                    self.process_id = YList(self)
                    self.neighbor = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Ospfv3, ['dead_interval', u'flood_reduction', 'hello_interval', u'mtu_ignore', 'priority', 'retransmit_interval', u'shutdown', 'transmit_delay'], name, value)


                class ProcessId(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Cost>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: manet
                    
                    	Mobile Adhoc Networking options
                    	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Manet>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.MultiArea>`
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Network>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipv4
                    
                    	Specify parameters for IPv4
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Specify parameters for IPv6
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.ProcessId, self).__init__()

                        self.yang_name = "process-id"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Loopback.Ospfv3.ProcessId.Authentication)), ("bfd", ("bfd", Native.Interface.Loopback.Ospfv3.ProcessId.Bfd)), ("cost", ("cost", Native.Interface.Loopback.Ospfv3.ProcessId.Cost)), ("database-filter", ("database_filter", Native.Interface.Loopback.Ospfv3.ProcessId.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.Loopback.Ospfv3.ProcessId.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.Loopback.Ospfv3.ProcessId.FloodReduction)), ("manet", ("manet", Native.Interface.Loopback.Ospfv3.ProcessId.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.Loopback.Ospfv3.ProcessId.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.Loopback.Ospfv3.ProcessId.MultiArea)), ("neighbor", ("neighbor", Native.Interface.Loopback.Ospfv3.ProcessId.Neighbor)), ("network", ("network", Native.Interface.Loopback.Ospfv3.ProcessId.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.Loopback.Ospfv3.ProcessId.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.Loopback.Ospfv3.ProcessId.Shutdown)), ("ipv4", ("ipv4", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4)), ("ipv6", ("ipv6", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.id = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.Loopback.Ospfv3.ProcessId.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.cost = Native.Interface.Loopback.Ospfv3.ProcessId.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.database_filter = Native.Interface.Loopback.Ospfv3.ProcessId.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.manet = Native.Interface.Loopback.Ospfv3.ProcessId.Manet()
                        self.manet.parent = self
                        self._children_name_map["manet"] = "manet"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.multi_area = Native.Interface.Loopback.Ospfv3.ProcessId.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.network = Native.Interface.Loopback.Ospfv3.ProcessId.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.ipv4 = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId, [u'id', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\: str
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.null = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Authentication, [u'key_chain', u'null'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Bfd, ['disable'], name, value)


                    class Cost(Entity):
                        """
                        Route cost of this interface
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dynamic
                        
                        	Specify dynamic cost options
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.dynamic = None
                            self._children_name_map["dynamic"] = "dynamic"
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Cost, [u'value'], name, value)


                        class Dynamic(Entity):
                            """
                            Specify dynamic cost options
                            
                            .. attribute:: default
                            
                            	Specify default link metric value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: hysteresis
                            
                            	Specify hysteresis value for LSA dampening
                            	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: weight
                            
                            	Specify weight to be placed on individual metrics
                            	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ])
                                self.default = None

                                self.hysteresis = None
                                self._children_name_map["hysteresis"] = "hysteresis"

                                self.weight = Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight()
                                self.weight.parent = self
                                self._children_name_map["weight"] = "weight"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic, [u'default'], name, value)


                            class Hysteresis(Entity):
                                """
                                Specify hysteresis value for LSA dampening
                                
                                .. attribute:: percent
                                
                                	Specify hysteresis percent changed
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold
                                
                                	Specify hysteresis threshold value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, self).__init__()

                                    self.yang_name = "hysteresis"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "hysteresis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                            class Weight(Entity):
                                """
                                Specify weight to be placed on individual metrics
                                
                                .. attribute:: l2_factor
                                
                                	Specify weight to be given to L2\-factor metric
                                	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: latency
                                
                                	Specify weight to be given to latency metric
                                	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: resources
                                
                                	Specify weight to be given to resources metric
                                	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: throughput
                                
                                	Specify weight to be given to throughput metric
                                	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight, self).__init__()

                                    self.yang_name = "weight"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput))])
                                    self._leafs = OrderedDict()

                                    self.l2_factor = None
                                    self._children_name_map["l2_factor"] = "L2-factor"

                                    self.latency = None
                                    self._children_name_map["latency"] = "latency"

                                    self.resources = None
                                    self._children_name_map["resources"] = "resources"

                                    self.throughput = None
                                    self._children_name_map["throughput"] = "throughput"
                                    self._segment_path = lambda: "weight"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight, [], name, value)


                                class L2Factor(Entity):
                                    """
                                    Specify weight to be given to L2\-factor metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                        self.yang_name = "L2-factor"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "L2-factor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                class Latency(Entity):
                                    """
                                    Specify weight to be given to latency metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, self).__init__()

                                        self.yang_name = "latency"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "latency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                class Resources(Entity):
                                    """
                                    Specify weight to be given to resources metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, self).__init__()

                                        self.yang_name = "resources"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "resources"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                class Throughput(Entity):
                                    """
                                    Specify weight to be given to throughput metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, self).__init__()

                                        self.yang_name = "throughput"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "throughput"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.ProcessId.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.DatabaseFilter, [u'all', u'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.DemandCircuit, [u'disable', u'ignore'], name, value)


                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.FloodReduction, [u'disable'], name, value)


                    class Manet(Entity):
                        """
                        Mobile Adhoc Networking options
                        
                        .. attribute:: peering
                        
                        	MANET Peering options
                        	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Manet.Peering>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Manet, self).__init__()

                            self.yang_name = "manet"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.Loopback.Ospfv3.ProcessId.Manet.Peering))])
                            self._leafs = OrderedDict()

                            self.peering = Native.Interface.Loopback.Ospfv3.ProcessId.Manet.Peering()
                            self.peering.parent = self
                            self._children_name_map["peering"] = "peering"
                            self._segment_path = lambda: "manet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Manet, [], name, value)


                        class Peering(Entity):
                            """
                            MANET Peering options
                            
                            .. attribute:: cost
                            
                            	Redundant path cost improvement required to peer
                            	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Manet.Peering.Cost>`
                            
                            .. attribute:: link_metrics
                            
                            	Require link metrics
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Manet.Peering, self).__init__()

                                self.yang_name = "peering"
                                self.yang_parent_name = "manet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.Loopback.Ospfv3.ProcessId.Manet.Peering.Cost))])
                                self._leafs = OrderedDict([
                                    ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                ])
                                self.link_metrics = None

                                self.cost = Native.Interface.Loopback.Ospfv3.ProcessId.Manet.Peering.Cost()
                                self.cost.parent = self
                                self._children_name_map["cost"] = "cost"
                                self._segment_path = lambda: "peering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Manet.Peering, [u'link_metrics'], name, value)


                            class Cost(Entity):
                                """
                                Redundant path cost improvement required to peer
                                
                                .. attribute:: percent
                                
                                	Relative incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                .. attribute:: threshold
                                
                                	Absolute incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.ProcessId.Manet.Peering.Cost, self).__init__()

                                    self.yang_name = "cost"
                                    self.yang_parent_name = "peering"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "cost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.MtuIgnore, [u'disable'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: disable
                        
                        	disable OSPF multi\-area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.disable = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.MultiArea, [u'id', u'cost', u'disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.Loopback.Ospfv3.ProcessId.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.Loopback.Ospfv3.ProcessId.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.Loopback.Ospfv3.ProcessId.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.PrefixSuppression, ['disable'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Shutdown, [u'disable'], name, value)


                    class Ipv4(Entity):
                        """
                        Specify parameters for IPv4
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Area)), ("authentication", ("authentication", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Authentication)), ("bfd", ("bfd", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Bfd)), ("cost", ("cost", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost)), ("database-filter", ("database_filter", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.FloodReduction)), ("manet", ("manet", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.MultiArea)), ("neighbor", ("neighbor", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Neighbor)), ("network", ("network", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 64..95
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv4.Shutdown, [u'disable'], name, value)


                    class Ipv6(Entity):
                        """
                        Specify parameters for IPv6
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Area)), ("authentication", ("authentication", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Authentication)), ("bfd", ("bfd", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Bfd)), ("cost", ("cost", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost)), ("database-filter", ("database_filter", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.FloodReduction)), ("manet", ("manet", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.MultiArea)), ("neighbor", ("neighbor", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Neighbor)), ("network", ("network", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 0..31
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.ProcessId.Ipv6.Shutdown, [u'disable'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: key_chain
                    
                    	Use a key\-chain for cryptographic authentication keys
                    	**type**\: str
                    
                    .. attribute:: null
                    
                    	Use no authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec authentication
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Authentication.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.Loopback.Ospfv3.Authentication.Ipsec))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.null = None

                        self.ipsec = Native.Interface.Loopback.Ospfv3.Authentication.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.Authentication, [u'key_chain', u'null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec authentication
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 256..4294967295
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5>`
                        
                        .. attribute:: sha1
                        
                        	Use SHA\-1 authentication
                        	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.Authentication.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                            ])
                            self.spi = None

                            self.md5 = Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"

                            self.sha1 = Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1()
                            self.sha1.parent = self
                            self._children_name_map["sha1"] = "sha1"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.Authentication.Ipsec, ['spi'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class Sha1(Entity):
                            """
                            Use SHA\-1 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1, self).__init__()

                                self.yang_name = "sha1"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "sha1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "sha1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                class Bfd(Entity):
                    """
                    Enable BFD on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BFD on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.Bfd, ['disable'], name, value)


                class Cost(Entity):
                    """
                    Route cost of this interface
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: dynamic
                    
                    	Specify dynamic cost options
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Cost.Dynamic>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.Cost, self).__init__()

                        self.yang_name = "cost"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.Loopback.Ospfv3.Cost.Dynamic))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.dynamic = None
                        self._children_name_map["dynamic"] = "dynamic"
                        self._segment_path = lambda: "cost"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.Cost, [u'value'], name, value)


                    class Dynamic(Entity):
                        """
                        Specify dynamic cost options
                        
                        .. attribute:: default
                        
                        	Specify default link metric value
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hysteresis
                        
                        	Specify hysteresis value for LSA dampening
                        	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Hysteresis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: weight
                        
                        	Specify weight to be placed on individual metrics
                        	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.Cost.Dynamic, self).__init__()

                            self.yang_name = "dynamic"
                            self.yang_parent_name = "cost"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                            ])
                            self.default = None

                            self.hysteresis = None
                            self._children_name_map["hysteresis"] = "hysteresis"

                            self.weight = Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight()
                            self.weight.parent = self
                            self._children_name_map["weight"] = "weight"
                            self._segment_path = lambda: "dynamic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.Cost.Dynamic, [u'default'], name, value)


                        class Hysteresis(Entity):
                            """
                            Specify hysteresis value for LSA dampening
                            
                            .. attribute:: percent
                            
                            	Specify hysteresis percent changed
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold
                            
                            	Specify hysteresis threshold value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Hysteresis, self).__init__()

                                self.yang_name = "hysteresis"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "hysteresis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                        class Weight(Entity):
                            """
                            Specify weight to be placed on individual metrics
                            
                            .. attribute:: l2_factor
                            
                            	Specify weight to be given to L2\-factor metric
                            	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.L2Factor>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: latency
                            
                            	Specify weight to be given to latency metric
                            	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Latency>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: resources
                            
                            	Specify weight to be given to resources metric
                            	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Resources>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: throughput
                            
                            	Specify weight to be given to throughput metric
                            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Throughput>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight, self).__init__()

                                self.yang_name = "weight"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Throughput))])
                                self._leafs = OrderedDict()

                                self.l2_factor = None
                                self._children_name_map["l2_factor"] = "L2-factor"

                                self.latency = None
                                self._children_name_map["latency"] = "latency"

                                self.resources = None
                                self._children_name_map["resources"] = "resources"

                                self.throughput = None
                                self._children_name_map["throughput"] = "throughput"
                                self._segment_path = lambda: "weight"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight, [], name, value)


                            class L2Factor(Entity):
                                """
                                Specify weight to be given to L2\-factor metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                    self.yang_name = "L2-factor"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "L2-factor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                            class Latency(Entity):
                                """
                                Specify weight to be given to latency metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Latency, self).__init__()

                                    self.yang_name = "latency"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "latency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                            class Resources(Entity):
                                """
                                Specify weight to be given to resources metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Resources, self).__init__()

                                    self.yang_name = "resources"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "resources"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                            class Throughput(Entity):
                                """
                                Specify weight to be given to throughput metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Throughput, self).__init__()

                                    self.yang_name = "throughput"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "throughput"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.DatabaseFilter.All')])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.DatabaseFilter, [u'all'], name, value)

                    class All(Enum):
                        """
                        All (Enum Class)

                        Filter all LSA

                        .. data:: out = 0

                        """

                        out = Enum.YLeaf(0, "out")



                class DemandCircuit(Entity):
                    """
                    OSPF Demand Circuit
                    
                    .. attribute:: ignore
                    
                    	Ignore demand circuit auto\-negotiation requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.DemandCircuit, self).__init__()

                        self.yang_name = "demand-circuit"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.ignore = None
                        self._segment_path = lambda: "demand-circuit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.DemandCircuit, [u'ignore'], name, value)


                class Encryption(Entity):
                    """
                    Enable encryption
                    
                    .. attribute:: null
                    
                    	No IPsec encryption on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec encryption
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.Loopback.Ospfv3.Encryption.Ipsec))])
                        self._leafs = OrderedDict([
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.null = None

                        self.ipsec = Native.Interface.Loopback.Ospfv3.Encryption.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.Encryption, ['null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec encryption
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: esp
                        
                        	Use ESP encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec_3des
                        
                        	Use 3DES encryption
                        	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des>`
                        
                        .. attribute:: aes_cbc
                        
                        	Use AES\-CBC encryption
                        	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                            ])
                            self.spi = None
                            self.esp = None

                            self.ipsec_3des = Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des()
                            self.ipsec_3des.parent = self
                            self._children_name_map["ipsec_3des"] = "ipsec_3des"

                            self.aes_cbc = Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc()
                            self.aes_cbc.parent = self
                            self._children_name_map["aes_cbc"] = "aes-cbc"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec, ['spi', 'esp'], name, value)


                        class Ipsec3des(Entity):
                            """
                            Use 3DES encryption
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des, self).__init__()

                                self.yang_name = "ipsec_3des"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "ipsec_3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "ipsec_3des"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class AesCbc(Entity):
                            """
                            Use AES\-CBC encryption
                            
                            .. attribute:: aes_cbc_128
                            
                            	Use 128 bit key
                            	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128>`
                            
                            .. attribute:: aes_192
                            
                            	Use 192 bit key
                            	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192>`
                            
                            .. attribute:: aes_256
                            
                            	Use 256 bit key
                            	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc, self).__init__()

                                self.yang_name = "aes-cbc"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256))])
                                self._leafs = OrderedDict()

                                self.aes_cbc_128 = Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128()
                                self.aes_cbc_128.parent = self
                                self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                self.aes_192 = Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192()
                                self.aes_192.parent = self
                                self._children_name_map["aes_192"] = "aes-192"

                                self.aes_256 = Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256()
                                self.aes_256.parent = self
                                self._children_name_map["aes_256"] = "aes-256"
                                self._segment_path = lambda: "aes-cbc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc, [], name, value)


                            class AesCbc128(Entity):
                                """
                                Use 128 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                    self.yang_name = "aes-cbc-128"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-cbc-128"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-cbc-128"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes192(Entity):
                                """
                                Use 192 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                    self.yang_name = "aes-192"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-192"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-192"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes256(Entity):
                                """
                                Use 256 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                    self.yang_name = "aes-256"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-256"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-256"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                class Manet(Entity):
                    """
                    Mobile Adhoc Networking options
                    
                    .. attribute:: peering
                    
                    	MANET Peering options
                    	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Manet.Peering>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.Manet, self).__init__()

                        self.yang_name = "manet"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.Loopback.Ospfv3.Manet.Peering))])
                        self._leafs = OrderedDict()

                        self.peering = Native.Interface.Loopback.Ospfv3.Manet.Peering()
                        self.peering.parent = self
                        self._children_name_map["peering"] = "peering"
                        self._segment_path = lambda: "manet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.Manet, [], name, value)


                    class Peering(Entity):
                        """
                        MANET Peering options
                        
                        .. attribute:: cost
                        
                        	Redundant path cost improvement required to peer
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Manet.Peering.Cost>`
                        
                        .. attribute:: link_metrics
                        
                        	Require link metrics
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.Manet.Peering, self).__init__()

                            self.yang_name = "peering"
                            self.yang_parent_name = "manet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.Loopback.Ospfv3.Manet.Peering.Cost))])
                            self._leafs = OrderedDict([
                                ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                            ])
                            self.link_metrics = None

                            self.cost = Native.Interface.Loopback.Ospfv3.Manet.Peering.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"
                            self._segment_path = lambda: "peering"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.Manet.Peering, [u'link_metrics'], name, value)


                        class Cost(Entity):
                            """
                            Redundant path cost improvement required to peer
                            
                            .. attribute:: percent
                            
                            	Relative incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: threshold
                            
                            	Absolute incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Loopback.Ospfv3.Manet.Peering.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "peering"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Ospfv3.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                class MultiArea(Entity):
                    """
                    Set the OSPF multi\-area ID
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.MultiArea, self).__init__()

                        self.yang_name = "multi-area"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self._segment_path = lambda: "multi-area"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.MultiArea, [u'id', u'cost'], name, value)


                class Neighbor(Entity):
                    """
                    OSPF neighbor
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	OSPF cost for point\-to\-multipoint neighbor
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Neighbor.DatabaseFilter>`
                    
                    .. attribute:: poll_interval
                    
                    	OSPF dead\-router polling interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: priority
                    
                    	OSPF priority of non\-broadcast neighbor
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.Loopback.Ospfv3.Neighbor.DatabaseFilter))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self.poll_interval = None
                        self.priority = None

                        self.database_filter = Native.Interface.Loopback.Ospfv3.Neighbor.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Neighbor.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.Neighbor.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Loopback.Ospfv3.Neighbor.DatabaseFilter.All')])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.Neighbor.DatabaseFilter, ['all'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                class Network(Entity):
                    """
                    Network type
                    
                    .. attribute:: broadcast
                    
                    	Specify OSPF broadcast multi\-access network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: manet
                    
                    	Specify MANET OSPF interface type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: non_broadcast
                    
                    	Specify OSPF NBMA network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: point_to_multipoint
                    
                    	Specify OSPF point\-to\-multipoint network
                    	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Ospfv3.Network.PointToMultipoint>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: point_to_point
                    
                    	Specify OSPF point\-to\-point network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.Loopback.Ospfv3.Network.PointToMultipoint))])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                            ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                        ])
                        self.broadcast = None
                        self.manet = None
                        self.non_broadcast = None
                        self.point_to_point = None

                        self.point_to_multipoint = None
                        self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                    class PointToMultipoint(Entity):
                        """
                        Specify OSPF point\-to\-multipoint network
                        
                        .. attribute:: non_broadcast
                        
                        	Specify non\-broadcast point\-to\-mpoint network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Loopback.Ospfv3.Network.PointToMultipoint, self).__init__()

                            self.yang_name = "point-to-multipoint"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ])
                            self.non_broadcast = None
                            self._segment_path = lambda: "point-to-multipoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Ospfv3.Network.PointToMultipoint, ['non_broadcast'], name, value)


                class PrefixSuppression(Entity):
                    """
                    OSPF prefix suppression
                    
                    .. attribute:: disable
                    
                    	Disable prefix suppression
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Loopback.Ospfv3.PrefixSuppression, self).__init__()

                        self.yang_name = "prefix-suppression"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "prefix-suppression"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Ospfv3.PrefixSuppression, ['disable'], name, value)


            class Udld(Entity):
                """
                Configure UDLD enabled or disabled and ignore global UDLD setting
                
                .. attribute:: port
                
                	Enable UDLD protocol on this interface despite global UDLD setting
                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Udld.Port>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-udld'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.Loopback.Udld, self).__init__()

                    self.yang_name = "udld"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.Loopback.Udld.Port))])
                    self._leafs = OrderedDict()

                    self.port = None
                    self._children_name_map["port"] = "port"
                    self._segment_path = lambda: "Cisco-IOS-XE-udld:udld"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Udld, [], name, value)


                class Port(Entity):
                    """
                    Enable UDLD protocol on this interface despite global UDLD setting
                    
                    .. attribute:: aggressive
                    
                    	Enable UDLD protocol in aggressive mode on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	Disable UDLD protocol on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-udld'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Loopback.Udld.Port, self).__init__()

                        self.yang_name = "port"
                        self.yang_parent_name = "udld"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aggressive', (YLeaf(YType.empty, 'aggressive'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.aggressive = None
                        self.disable = None
                        self._segment_path = lambda: "port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Udld.Port, ['aggressive', 'disable'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts.Manual>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.Loopback.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "Loopback"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.Loopback.Cts.Manual))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Loopback.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Loopback.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.Loopback.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.Loopback.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.Loopback.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.Loopback.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.Loopback.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.Loopback.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Loopback.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.Loopback.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.Loopback.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.Loopback.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Loopback.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Loopback.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Loopback.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Loopback.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Loopback.Cts.Manual.Propagate, ['sgt'], name, value)


        class LISP(Entity):
            """
            Locator/ID Separation Protocol Virtual Interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..65520
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.PmPath>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.ServicePolicy>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Utd>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Umbrella>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.LISP, self).__init__()

                self.yang_name = "LISP"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.LISP.SwitchportConf)), ("switchport", ("switchport", Native.Interface.LISP.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.LISP.StackwiseVirtual)), ("arp", ("arp", Native.Interface.LISP.Arp)), ("backup", ("backup", Native.Interface.LISP.Backup)), ("cemoudp", ("cemoudp", Native.Interface.LISP.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.LISP.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.LISP.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.LISP.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.LISP.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.LISP.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.LISP.Flowcontrol)), ("isis", ("isis", Native.Interface.LISP.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.LISP.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.LISP.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.LISP.Bandwidth)), ("dampening", ("dampening", Native.Interface.LISP.Dampening)), ("domain", ("domain", Native.Interface.LISP.Domain)), ("hold-queue", ("hold_queue", Native.Interface.LISP.HoldQueue)), ("mpls", ("mpls", Native.Interface.LISP.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.LISP.IpVrf)), ("vrf", ("vrf", Native.Interface.LISP.Vrf)), ("ip", ("ip", Native.Interface.LISP.Ip)), ("ipv6", ("ipv6", Native.Interface.LISP.Ipv6)), ("logging", ("logging", Native.Interface.LISP.Logging)), ("mdix", ("mdix", Native.Interface.LISP.Mdix)), ("mop", ("mop", Native.Interface.LISP.Mop)), ("interface_qos", ("interface_qos", Native.Interface.LISP.InterfaceQos)), ("source", ("source", Native.Interface.LISP.Source)), ("standby", ("standby", Native.Interface.LISP.Standby)), ("access-session", ("access_session", Native.Interface.LISP.AccessSession)), ("storm-control", ("storm_control", Native.Interface.LISP.StormControl)), ("trust", ("trust", Native.Interface.LISP.Trust)), ("priority-queue", ("priority_queue", Native.Interface.LISP.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.LISP.RcvQueue)), ("peer", ("peer", Native.Interface.LISP.Peer)), ("pm-path", ("pm_path", Native.Interface.LISP.PmPath)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.LISP.ServicePolicy)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.LISP.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.LISP.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.LISP.Utd)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.LISP.Umbrella))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.LISP.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.LISP.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.LISP.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.LISP.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.LISP.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.LISP.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.LISP.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.LISP.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.LISP.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.LISP.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.LISP.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.LISP.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.LISP.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.LISP.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.LISP.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.LISP.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.LISP.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.LISP.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.LISP.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.LISP.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.LISP.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.LISP.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.LISP.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.LISP.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.LISP.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.LISP.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.LISP.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.LISP.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.LISP.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.LISP.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.LISP.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.LISP.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.LISP.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.LISP.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.LISP.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.service_policy = Native.Interface.LISP.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.et_analytics = Native.Interface.LISP.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.LISP.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.LISP.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.umbrella = Native.Interface.LISP.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "LISP" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.LISP, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.LISP.Backup.Delay)), ("interface", ("interface", Native.Interface.LISP.Backup.Interface_)), ("load", ("load", Native.Interface.LISP.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.LISP.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.LISP.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.LISP.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.LISP.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.LISP.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.LISP.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.LISP.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.LISP.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.LISP.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.LISP.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.LISP.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.LISP.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.LISP.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.LISP.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.LISP.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.LISP.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.LISP.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.LISP.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.LISP.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.LISP.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.LISP.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.LISP.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.LISP.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.LISP.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.LISP.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.LISP.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.LISP.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.LISP.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.LISP.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.LISP.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.LISP.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.LISP.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.LISP.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.LISP.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.LISP.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.LISP.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.LISP.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.LISP.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.LISP.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.LISP.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.LISP.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.LISP.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.LISP.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.LISP.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.LISP.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.LISP.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.LISP.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.LISP.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.LISP.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.LISP.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.LISP.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.LISP.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.LISP.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.LISP.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.LISP.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.LISP.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.LISP.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.LISP.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.LISP.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.LISP.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.LISP.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.LISP.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.LISP.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.LISP.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.LISP.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.LISP.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.LISP.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.LISP.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.LISP.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.LISP.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.LISP.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.LISP.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.LISP.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.LISP.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.LISP.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.LISP.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.LISP.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.LISP.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.LISP.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.LISP.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.LISP.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.LISP.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.LISP.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.LISP.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.LISP.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.LISP.Ip.Arp)), ("vrf", ("vrf", Native.Interface.LISP.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.LISP.Ip.NoAddress)), ("address", ("address", Native.Interface.LISP.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.LISP.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.LISP.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.LISP.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.LISP.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.LISP.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.LISP.Ip.Pim)), ("policy", ("policy", Native.Interface.LISP.Ip.Policy)), ("rip", ("rip", Native.Interface.LISP.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.LISP.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.LISP.Ip.RouteCache)), ("router", ("router", Native.Interface.LISP.Ip.Router)), ("tcp", ("tcp", Native.Interface.LISP.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.LISP.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.LISP.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.LISP.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.LISP.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.LISP.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.LISP.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.LISP.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.LISP.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.LISP.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.LISP.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.LISP.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.LISP.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.LISP.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.LISP.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.LISP.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.LISP.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.LISP.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.LISP.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.LISP.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.LISP.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.LISP.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.LISP.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.LISP.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.LISP.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.LISP.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.LISP.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.LISP.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.LISP.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.LISP.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.LISP.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.LISP.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.LISP.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.LISP.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.LISP.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.LISP.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.LISP.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.LISP.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.LISP.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.LISP.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.LISP.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.LISP.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.LISP.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.LISP.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.LISP.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.LISP.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.LISP.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.LISP.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.LISP.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.LISP.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.LISP.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.LISP.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.LISP.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.LISP.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.LISP.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.LISP.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.LISP.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.LISP.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.LISP.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.LISP.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.LISP.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.LISP.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.LISP.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISP.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISP.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.LISP.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.LISP.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.LISP.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.LISP.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.LISP.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.LISP.Ipv6.Dhcp)), ("address", ("address", Native.Interface.LISP.Ipv6.Address)), ("nd", ("nd", Native.Interface.LISP.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.LISP.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.LISP.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.LISP.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.LISP.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.LISP.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.LISP.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.LISP.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.LISP.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.LISP.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.LISP.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.LISP.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.LISP.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.LISP.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.LISP.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.LISP.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.LISP.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.LISP.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.LISP.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.LISP.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.LISP.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.LISP.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.LISP.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.LISP.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.LISP.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.LISP.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.LISP.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.LISP.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.LISP.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.LISP.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.LISP.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.LISP.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.LISP.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.LISP.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.LISP.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.LISP.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.LISP.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.LISP.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.LISP.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISP.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.LISP.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.LISP.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.LISP.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.LISP.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.LISP.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.LISP.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.LISP.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.LISP.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.LISP.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.LISP.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.LISP.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.LISP.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.LISP.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.LISP.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.LISP.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.LISP.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.LISP.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.LISP.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.LISP.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.LISP.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.LISP.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.LISP.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.LISP.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.LISP.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.LISP.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.LISP.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.LISP.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.LISP.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.LISP.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.LISP.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.LISP.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.LISP.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.LISP.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.LISP.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.LISP.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.LISP.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.LISP.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.LISP.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.LISP.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.LISP.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.LISP.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.LISP.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.LISP.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.LISP.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.LISP.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.LISP.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.LISP.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.LISP.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.LISP.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.LISP.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.LISP.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISP.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.LISP.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.LISP.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISP.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.LISP.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.LISP.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISP.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.LISP.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.LISP.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISP.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISP.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISP.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISP.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISP.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.PmPath, [u'name', u'interface_id'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.LISP.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.LISP.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.LISP.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.LISP.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.LISP.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.LISP.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.LISP.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.LISP.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.LISP.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.LISP.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISP.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISP.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISP.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.LISP.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.LISP.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.LISP.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.LISP.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.LISP.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISP.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.LISP.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.LISP.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISP.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.LISP.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.LISP.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.LISP.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Utd, ['enable'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.LISP.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "LISP"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISP.Umbrella, ['out', 'in_'], name, value)


        class LISPSubinterface(Entity):
            """
            Locator/ID Separation Protocol Virtual Interface
            
            .. attribute:: lisp
            
            	
            	**type**\: list of  		 :py:class:`LISP <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.LISPSubinterface, self).__init__()

                self.yang_name = "LISP-subinterface"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("LISP", ("lisp", Native.Interface.LISPSubinterface.LISP))])
                self._leafs = OrderedDict()

                self.lisp = YList(self)
                self._segment_path = lambda: "LISP-subinterface"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.LISPSubinterface, [], name, value)


            class LISP(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                
                .. attribute:: description
                
                	Interface specific description
                	**type**\: str
                
                	**length:** 0..240
                
                .. attribute:: switchport_conf
                
                	
                	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.SwitchportConf>`
                
                .. attribute:: switchport
                
                	Set switching mode characteristics
                	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Switchport>`
                
                .. attribute:: stackwise_virtual
                
                	Configure stackwise\-virtual link values
                	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StackwiseVirtual>`
                
                .. attribute:: mac_address
                
                	Manually set interface MAC address
                	**type**\: str
                
                .. attribute:: shutdown
                
                	Shutdown the selected interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: arp
                
                	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Arp>`
                
                .. attribute:: backup
                
                	Modify backup parameters
                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Backup>`
                
                .. attribute:: cemoudp
                
                	cemoudp
                	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Cemoudp>`
                
                .. attribute:: cws_tunnel
                
                	Configure Cloud Web Security Tunnel
                	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.CwsTunnel>`
                
                .. attribute:: l2protocol_tunnel
                
                	Tunnel Layer2 protocols
                	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.L2protocolTunnel>`
                
                	**presence node**\: True
                
                .. attribute:: encapsulation
                
                	Set encapsulation type for an interface
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Encapsulation>`
                
                .. attribute:: fair_queue_conf
                
                	
                	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.FairQueueConf>`
                
                .. attribute:: fair_queue
                
                	Enable Fair Queuing on an Interface
                	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.FairQueue>`
                
                .. attribute:: flowcontrol
                
                	Configure flow operation
                	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Flowcontrol>`
                
                .. attribute:: isis
                
                	IS\-IS commands
                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Isis>`
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\: bool
                
                .. attribute:: keepalive_settings
                
                	
                	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.KeepaliveSettings>`
                
                .. attribute:: bfd
                
                	BFD interface configuration commands
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Bfd>`
                
                .. attribute:: bandwidth
                
                	Set bandwidth informational parameter
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Bandwidth>`
                
                .. attribute:: dampening
                
                	Enable event dampening
                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Dampening>`
                
                .. attribute:: if_state
                
                	
                	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.IfState>`
                
                .. attribute:: delay
                
                	Specify interface throughput delay
                	**type**\: int
                
                	**range:** 1..16777215
                
                .. attribute:: domain
                
                	Specify a domain
                	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Domain>`
                
                .. attribute:: hold_queue
                
                	Set hold queue depth
                	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.HoldQueue>`
                
                .. attribute:: mpls
                
                	
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Mpls>`
                
                .. attribute:: ip_vrf
                
                	
                	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.IpVrf>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Vrf>`
                
                .. attribute:: ip
                
                	Interface Internet Protocol config commands
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip>`
                
                .. attribute:: ipv6
                
                	IPv6 interface subcommands
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6>`
                
                .. attribute:: load_interval
                
                	Specify interval for load calculation for an interface
                	**type**\: int
                
                	**range:** 0..600
                
                .. attribute:: logging
                
                	Configure logging for interface
                	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Logging>`
                
                .. attribute:: mdix
                
                	Set Media Dependent Interface with Crossover
                	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Mdix>`
                
                .. attribute:: mop
                
                	
                	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Mop>`
                
                .. attribute:: max_reserved_bandwidth
                
                	Maximum Reservable Bandwidth on an Interface
                	**type**\: int
                
                	**range:** 1..100
                
                .. attribute:: mtu
                
                	Set the interface Maximum Transmission Unit (MTU)
                	**type**\: int
                
                	**range:** 64..18000
                
                .. attribute:: interface_qos
                
                	
                	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.InterfaceQos>`
                
                .. attribute:: service_insertion
                
                	Service\-insertion AppNav Controller
                	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.ServiceInsertion>`
                
                .. attribute:: source
                
                	Get config from another source
                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Source>`
                
                .. attribute:: standby
                
                	HSRP interface configuration commands
                	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby>`
                
                .. attribute:: access_session
                
                	Access Session specific Interface Configuration Commands
                	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.AccessSession>`
                
                .. attribute:: storm_control
                
                	storm configuration
                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl>`
                
                .. attribute:: trust
                
                	Set trust value for the interface
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Trust>`
                
                .. attribute:: priority_queue
                
                	Configure priority scheduling
                	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.PriorityQueue>`
                
                .. attribute:: rcv_queue
                
                	Configure receive queue(s)
                	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.RcvQueue>`
                
                .. attribute:: peer
                
                	Peer parameters for point to point interfaces
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Peer>`
                
                .. attribute:: pm_path
                
                	Global pm\-path configuration
                	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.PmPath>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.LISPSubinterface.LISP, self).__init__()

                    self.yang_name = "LISP"
                    self.yang_parent_name = "LISP-subinterface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.LISPSubinterface.LISP.SwitchportConf)), ("switchport", ("switchport", Native.Interface.LISPSubinterface.LISP.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.LISPSubinterface.LISP.StackwiseVirtual)), ("arp", ("arp", Native.Interface.LISPSubinterface.LISP.Arp)), ("backup", ("backup", Native.Interface.LISPSubinterface.LISP.Backup)), ("cemoudp", ("cemoudp", Native.Interface.LISPSubinterface.LISP.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.LISPSubinterface.LISP.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.LISPSubinterface.LISP.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.LISPSubinterface.LISP.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.LISPSubinterface.LISP.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.LISPSubinterface.LISP.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.LISPSubinterface.LISP.Flowcontrol)), ("isis", ("isis", Native.Interface.LISPSubinterface.LISP.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.LISPSubinterface.LISP.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.LISPSubinterface.LISP.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.LISPSubinterface.LISP.Bandwidth)), ("dampening", ("dampening", Native.Interface.LISPSubinterface.LISP.Dampening)), ("domain", ("domain", Native.Interface.LISPSubinterface.LISP.Domain)), ("hold-queue", ("hold_queue", Native.Interface.LISPSubinterface.LISP.HoldQueue)), ("mpls", ("mpls", Native.Interface.LISPSubinterface.LISP.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.LISPSubinterface.LISP.IpVrf)), ("vrf", ("vrf", Native.Interface.LISPSubinterface.LISP.Vrf)), ("ip", ("ip", Native.Interface.LISPSubinterface.LISP.Ip)), ("ipv6", ("ipv6", Native.Interface.LISPSubinterface.LISP.Ipv6)), ("logging", ("logging", Native.Interface.LISPSubinterface.LISP.Logging)), ("mdix", ("mdix", Native.Interface.LISPSubinterface.LISP.Mdix)), ("mop", ("mop", Native.Interface.LISPSubinterface.LISP.Mop)), ("interface_qos", ("interface_qos", Native.Interface.LISPSubinterface.LISP.InterfaceQos)), ("source", ("source", Native.Interface.LISPSubinterface.LISP.Source)), ("standby", ("standby", Native.Interface.LISPSubinterface.LISP.Standby)), ("access-session", ("access_session", Native.Interface.LISPSubinterface.LISP.AccessSession)), ("storm-control", ("storm_control", Native.Interface.LISPSubinterface.LISP.StormControl)), ("trust", ("trust", Native.Interface.LISPSubinterface.LISP.Trust)), ("priority-queue", ("priority_queue", Native.Interface.LISPSubinterface.LISP.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.LISPSubinterface.LISP.RcvQueue)), ("peer", ("peer", Native.Interface.LISPSubinterface.LISP.Peer)), ("pm-path", ("pm_path", Native.Interface.LISPSubinterface.LISP.PmPath))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                        ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.IfState')])),
                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                        ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                        ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.ServiceInsertion')])),
                    ])
                    self.name = None
                    self.description = None
                    self.mac_address = None
                    self.shutdown = None
                    self.keepalive = None
                    self.if_state = None
                    self.delay = None
                    self.load_interval = None
                    self.max_reserved_bandwidth = None
                    self.mtu = None
                    self.service_insertion = None

                    self.switchport_conf = Native.Interface.LISPSubinterface.LISP.SwitchportConf()
                    self.switchport_conf.parent = self
                    self._children_name_map["switchport_conf"] = "switchport-conf"

                    self.switchport = Native.Interface.LISPSubinterface.LISP.Switchport()
                    self.switchport.parent = self
                    self._children_name_map["switchport"] = "switchport"

                    self.stackwise_virtual = Native.Interface.LISPSubinterface.LISP.StackwiseVirtual()
                    self.stackwise_virtual.parent = self
                    self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                    self.arp = Native.Interface.LISPSubinterface.LISP.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.backup = Native.Interface.LISPSubinterface.LISP.Backup()
                    self.backup.parent = self
                    self._children_name_map["backup"] = "backup"

                    self.cemoudp = Native.Interface.LISPSubinterface.LISP.Cemoudp()
                    self.cemoudp.parent = self
                    self._children_name_map["cemoudp"] = "cemoudp"

                    self.cws_tunnel = Native.Interface.LISPSubinterface.LISP.CwsTunnel()
                    self.cws_tunnel.parent = self
                    self._children_name_map["cws_tunnel"] = "cws-tunnel"

                    self.l2protocol_tunnel = None
                    self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                    self.encapsulation = Native.Interface.LISPSubinterface.LISP.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"

                    self.fair_queue_conf = Native.Interface.LISPSubinterface.LISP.FairQueueConf()
                    self.fair_queue_conf.parent = self
                    self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                    self.fair_queue = Native.Interface.LISPSubinterface.LISP.FairQueue()
                    self.fair_queue.parent = self
                    self._children_name_map["fair_queue"] = "fair-queue"

                    self.flowcontrol = Native.Interface.LISPSubinterface.LISP.Flowcontrol()
                    self.flowcontrol.parent = self
                    self._children_name_map["flowcontrol"] = "flowcontrol"

                    self.isis = Native.Interface.LISPSubinterface.LISP.Isis()
                    self.isis.parent = self
                    self._children_name_map["isis"] = "isis"

                    self.keepalive_settings = Native.Interface.LISPSubinterface.LISP.KeepaliveSettings()
                    self.keepalive_settings.parent = self
                    self._children_name_map["keepalive_settings"] = "keepalive-settings"

                    self.bfd = Native.Interface.LISPSubinterface.LISP.Bfd()
                    self.bfd.parent = self
                    self._children_name_map["bfd"] = "bfd"

                    self.bandwidth = Native.Interface.LISPSubinterface.LISP.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"

                    self.dampening = Native.Interface.LISPSubinterface.LISP.Dampening()
                    self.dampening.parent = self
                    self._children_name_map["dampening"] = "dampening"

                    self.domain = Native.Interface.LISPSubinterface.LISP.Domain()
                    self.domain.parent = self
                    self._children_name_map["domain"] = "domain"

                    self.mpls = Native.Interface.LISPSubinterface.LISP.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"

                    self.ip_vrf = Native.Interface.LISPSubinterface.LISP.IpVrf()
                    self.ip_vrf.parent = self
                    self._children_name_map["ip_vrf"] = "ip-vrf"

                    self.vrf = Native.Interface.LISPSubinterface.LISP.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.ip = Native.Interface.LISPSubinterface.LISP.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.ipv6 = Native.Interface.LISPSubinterface.LISP.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.logging = Native.Interface.LISPSubinterface.LISP.Logging()
                    self.logging.parent = self
                    self._children_name_map["logging"] = "logging"

                    self.mdix = Native.Interface.LISPSubinterface.LISP.Mdix()
                    self.mdix.parent = self
                    self._children_name_map["mdix"] = "mdix"

                    self.mop = Native.Interface.LISPSubinterface.LISP.Mop()
                    self.mop.parent = self
                    self._children_name_map["mop"] = "mop"

                    self.interface_qos = Native.Interface.LISPSubinterface.LISP.InterfaceQos()
                    self.interface_qos.parent = self
                    self._children_name_map["interface_qos"] = "interface_qos"

                    self.source = Native.Interface.LISPSubinterface.LISP.Source()
                    self.source.parent = self
                    self._children_name_map["source"] = "source"

                    self.standby = Native.Interface.LISPSubinterface.LISP.Standby()
                    self.standby.parent = self
                    self._children_name_map["standby"] = "standby"

                    self.access_session = Native.Interface.LISPSubinterface.LISP.AccessSession()
                    self.access_session.parent = self
                    self._children_name_map["access_session"] = "access-session"

                    self.storm_control = Native.Interface.LISPSubinterface.LISP.StormControl()
                    self.storm_control.parent = self
                    self._children_name_map["storm_control"] = "storm-control"

                    self.trust = Native.Interface.LISPSubinterface.LISP.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"

                    self.priority_queue = Native.Interface.LISPSubinterface.LISP.PriorityQueue()
                    self.priority_queue.parent = self
                    self._children_name_map["priority_queue"] = "priority-queue"

                    self.rcv_queue = Native.Interface.LISPSubinterface.LISP.RcvQueue()
                    self.rcv_queue.parent = self
                    self._children_name_map["rcv_queue"] = "rcv-queue"

                    self.peer = Native.Interface.LISPSubinterface.LISP.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"

                    self.pm_path = Native.Interface.LISPSubinterface.LISP.PmPath()
                    self.pm_path.parent = self
                    self._children_name_map["pm_path"] = "pm-path"

                    self.hold_queue = YList(self)
                    self._segment_path = lambda: "LISP" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/LISP-subinterface/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

                class IfState(Enum):
                    """
                    IfState (Enum Class)

                    .. data:: nhrp = 0

                    """

                    nhrp = Enum.YLeaf(0, "nhrp")


                class ServiceInsertion(Enum):
                    """
                    ServiceInsertion (Enum Class)

                    Service\-insertion AppNav Controller

                    .. data:: waas = 0

                    """

                    waas = Enum.YLeaf(0, "waas")



                class SwitchportConf(Entity):
                    """
                    
                    
                    .. attribute:: switchport
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.SwitchportConf, self).__init__()

                        self.yang_name = "switchport-conf"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                        ])
                        self.switchport = None
                        self._segment_path = lambda: "switchport-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.SwitchportConf, [u'switchport'], name, value)


                class Switchport(Entity):
                    """
                    Set switching mode characteristics
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Switchport, self).__init__()

                        self.yang_name = "switchport"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "switchport"
                        self._is_frozen = True


                class StackwiseVirtual(Entity):
                    """
                    Configure stackwise\-virtual link values
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..2
                    
                    .. attribute:: dual_active_detection
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.StackwiseVirtual, self).__init__()

                        self.yang_name = "stackwise-virtual"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                            ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                        ])
                        self.link = None
                        self.dual_active_detection = None
                        self._segment_path = lambda: "stackwise-virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


                class Arp(Entity):
                    """
                    Set arp type (arpa, probe, snap), timeout, log options or 
                    packet priority
                    
                    .. attribute:: timeout
                    
                    	Set ARP cache timeout
                    	**type**\: int
                    
                    	**range:** 0..2147483
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Arp, [u'timeout'], name, value)


                class Backup(Entity):
                    """
                    Modify backup parameters
                    
                    .. attribute:: delay
                    
                    	Delays before backup line up or down transitions
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Backup.Delay>`
                    
                    .. attribute:: interface
                    
                    	Configure an interface as a backup
                    	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Backup.Interface_>`
                    
                    .. attribute:: load
                    
                    	Load thresholds for line up or down transitions
                    	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Backup.Load>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Backup, self).__init__()

                        self.yang_name = "backup"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.LISPSubinterface.LISP.Backup.Delay)), ("interface", ("interface", Native.Interface.LISPSubinterface.LISP.Backup.Interface_)), ("load", ("load", Native.Interface.LISPSubinterface.LISP.Backup.Load))])
                        self._leafs = OrderedDict()

                        self.delay = Native.Interface.LISPSubinterface.LISP.Backup.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"

                        self.interface = Native.Interface.LISPSubinterface.LISP.Backup.Interface_()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"

                        self.load = Native.Interface.LISPSubinterface.LISP.Backup.Load()
                        self.load.parent = self
                        self._children_name_map["load"] = "load"
                        self._segment_path = lambda: "backup"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Backup, [], name, value)


                    class Delay(Entity):
                        """
                        Delays before backup line up or down transitions
                        
                        .. attribute:: failure
                        
                        	Seconds
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967294
                        
                        		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                        
                        .. attribute:: secondary_disable
                        
                        	Seconds
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967294
                        
                        		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Backup.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                                ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                            ])
                            self.failure = None
                            self.secondary_disable = None
                            self._segment_path = lambda: "delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                        class Failure(Enum):
                            """
                            Failure (Enum Class)

                            Seconds

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")


                        class SecondaryDisable(Enum):
                            """
                            SecondaryDisable (Enum Class)

                            Seconds

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")



                    class Interface_(Entity):
                        """
                        Configure an interface as a backup
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Backup.Interface_.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Backup.Interface_.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Backup.Interface_.LISPSubinterface_>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Backup.Interface_.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Backup.Interface_, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.LISPSubinterface.LISP.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.LISPSubinterface.LISP.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.LISPSubinterface.LISP.Backup.Interface_.LISPSubinterface_)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.LISPSubinterface.LISP.Backup.Interface_.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Interface.LISPSubinterface.LISP.Backup.Interface_.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Interface.LISPSubinterface.LISP.Backup.Interface_.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Interface.LISPSubinterface.LISP.Backup.Interface_.LISPSubinterface_()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Interface.LISPSubinterface.LISP.Backup.Interface_.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Backup.Interface_.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Backup.Interface_.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface_(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Backup.Interface_.LISPSubinterface_, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Backup.Interface_.LISPSubinterface_, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Backup.Interface_.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                    class Load(Entity):
                        """
                        Load thresholds for line up or down transitions
                        
                        .. attribute:: kickin
                        
                        	Percentage
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..100
                        
                        		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                        
                        .. attribute:: kickout
                        
                        	Percentage
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..100
                        
                        		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Backup.Load, self).__init__()

                            self.yang_name = "load"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                                ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                            ])
                            self.kickin = None
                            self.kickout = None
                            self._segment_path = lambda: "load"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Backup.Load, [u'kickin', u'kickout'], name, value)

                        class Kickin(Enum):
                            """
                            Kickin (Enum Class)

                            Percentage

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")


                        class Kickout(Enum):
                            """
                            Kickout (Enum Class)

                            Percentage

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")



                class Cemoudp(Entity):
                    """
                    cemoudp
                    
                    .. attribute:: reserve
                    
                    	
                    	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Cemoudp.Reserve>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Cemoudp, self).__init__()

                        self.yang_name = "cemoudp"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.LISPSubinterface.LISP.Cemoudp.Reserve))])
                        self._leafs = OrderedDict()

                        self.reserve = Native.Interface.LISPSubinterface.LISP.Cemoudp.Reserve()
                        self.reserve.parent = self
                        self._children_name_map["reserve"] = "reserve"
                        self._segment_path = lambda: "cemoudp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Cemoudp, [], name, value)


                    class Reserve(Entity):
                        """
                        
                        
                        .. attribute:: acr
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Cemoudp.Reserve, self).__init__()

                            self.yang_name = "reserve"
                            self.yang_parent_name = "cemoudp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                            ])
                            self.acr = None
                            self._segment_path = lambda: "reserve"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Cemoudp.Reserve, [u'acr'], name, value)


                class CwsTunnel(Entity):
                    """
                    Configure Cloud Web Security Tunnel
                    
                    .. attribute:: in_
                    
                    	Inbound traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: out
                    
                    	Outbound traffic
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.CwsTunnel.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.CwsTunnel, self).__init__()

                        self.yang_name = "cws-tunnel"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("out", ("out", Native.Interface.LISPSubinterface.LISP.CwsTunnel.Out))])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None

                        self.out = Native.Interface.LISPSubinterface.LISP.CwsTunnel.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "cws-tunnel"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.CwsTunnel, [u'in_'], name, value)


                    class Out(Entity):
                        """
                        Outbound traffic
                        
                        .. attribute:: tunnel_number
                        
                        	Outboud traffic tunnel identifier
                        	**type**\: int
                        
                        	**range:** 0..65534
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.CwsTunnel.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "cws-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                            ])
                            self.tunnel_number = None
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.CwsTunnel.Out, [u'tunnel_number'], name, value)


                class L2protocolTunnel(Entity):
                    """
                    Tunnel Layer2 protocols
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: drop_threshold
                    
                    	Set drop threshold for protocol packets
                    	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.L2protocolTunnel.DropThreshold>`
                    
                    .. attribute:: shutdown_threshold
                    
                    	Set shutdown threshold for protocol packets
                    	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.L2protocolTunnel.ShutdownThreshold>`
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.L2protocolTunnel, self).__init__()

                        self.yang_name = "l2protocol-tunnel"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.LISPSubinterface.LISP.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.LISPSubinterface.LISP.L2protocolTunnel.ShutdownThreshold))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                            ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                            ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                        ])
                        self.cdp = None
                        self.stp = None
                        self.vtp = None

                        self.drop_threshold = Native.Interface.LISPSubinterface.LISP.L2protocolTunnel.DropThreshold()
                        self.drop_threshold.parent = self
                        self._children_name_map["drop_threshold"] = "drop-threshold"

                        self.shutdown_threshold = Native.Interface.LISPSubinterface.LISP.L2protocolTunnel.ShutdownThreshold()
                        self.shutdown_threshold.parent = self
                        self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                        self._segment_path = lambda: "l2protocol-tunnel"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                    class DropThreshold(Entity):
                        """
                        Set drop threshold for protocol packets
                        
                        .. attribute:: packet_rate
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: cdp
                        
                        	Cisco Discovery Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: stp
                        
                        	Spanning Tree Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: vtp
                        
                        	Vlan Trunking Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.L2protocolTunnel.DropThreshold, self).__init__()

                            self.yang_name = "drop-threshold"
                            self.yang_parent_name = "l2protocol-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                                ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                                ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                                ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                            ])
                            self.packet_rate = None
                            self.cdp = None
                            self.stp = None
                            self.vtp = None
                            self._segment_path = lambda: "drop-threshold"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                    class ShutdownThreshold(Entity):
                        """
                        Set shutdown threshold for protocol packets
                        
                        .. attribute:: packet_rate
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: cdp
                        
                        	Cisco Discovery Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: stp
                        
                        	Spanning Tree Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: vtp
                        
                        	Vlan Trunking Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.L2protocolTunnel.ShutdownThreshold, self).__init__()

                            self.yang_name = "shutdown-threshold"
                            self.yang_parent_name = "l2protocol-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                                ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                                ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                                ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                            ])
                            self.packet_rate = None
                            self.cdp = None
                            self.stp = None
                            self.vtp = None
                            self._segment_path = lambda: "shutdown-threshold"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class Encapsulation(Entity):
                    """
                    Set encapsulation type for an interface
                    
                    .. attribute:: dot1q
                    
                    	IEEE 802.1Q Virtual LAN
                    	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Encapsulation.Dot1Q>`
                    
                    .. attribute:: isl
                    
                    	Inter Switch Link \- Virtual LAN encapsulation
                    	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Encapsulation.Isl>`
                    
                    .. attribute:: ppp
                    
                    	Point\-to\-Point protocol
                    	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Encapsulation.Ppp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: slip
                    
                    	Serial Line IP
                    	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Encapsulation.Slip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: frame_relay
                    
                    	Frame Relay networks
                    	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Encapsulation.FrameRelay>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Encapsulation, self).__init__()

                        self.yang_name = "encapsulation"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.LISPSubinterface.LISP.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.LISPSubinterface.LISP.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.LISPSubinterface.LISP.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.LISPSubinterface.LISP.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.LISPSubinterface.LISP.Encapsulation.FrameRelay))])
                        self._leafs = OrderedDict()

                        self.dot1q = Native.Interface.LISPSubinterface.LISP.Encapsulation.Dot1Q()
                        self.dot1q.parent = self
                        self._children_name_map["dot1q"] = "dot1Q"

                        self.isl = Native.Interface.LISPSubinterface.LISP.Encapsulation.Isl()
                        self.isl.parent = self
                        self._children_name_map["isl"] = "isl"

                        self.ppp = None
                        self._children_name_map["ppp"] = "ppp"

                        self.slip = None
                        self._children_name_map["slip"] = "slip"

                        self.frame_relay = None
                        self._children_name_map["frame_relay"] = "frame-relay"
                        self._segment_path = lambda: "encapsulation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Encapsulation, [], name, value)


                    class Dot1Q(Entity):
                        """
                        IEEE 802.1Q Virtual LAN
                        
                        .. attribute:: vlan_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        .. attribute:: native
                        
                        	Make this as native vlan
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Encapsulation.Dot1Q, self).__init__()

                            self.yang_name = "dot1Q"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                            ])
                            self.vlan_id = None
                            self.native = None
                            self._segment_path = lambda: "dot1Q"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                    class Isl(Entity):
                        """
                        Inter Switch Link \- Virtual LAN encapsulation
                        
                        .. attribute:: vlan_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4095
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Encapsulation.Isl, self).__init__()

                            self.yang_name = "isl"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ])
                            self.vlan_id = None
                            self._segment_path = lambda: "isl"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Encapsulation.Isl, [u'vlan_id'], name, value)


                    class Ppp(Entity):
                        """
                        Point\-to\-Point protocol
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Encapsulation.Ppp, self).__init__()

                            self.yang_name = "ppp"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "ppp"
                            self._is_frozen = True


                    class Slip(Entity):
                        """
                        Serial Line IP
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Encapsulation.Slip, self).__init__()

                            self.yang_name = "slip"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "slip"
                            self._is_frozen = True


                    class FrameRelay(Entity):
                        """
                        Frame Relay networks
                        
                        .. attribute:: ietf
                        
                        	Use RFC1490/RFC2427 encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Encapsulation.FrameRelay, self).__init__()

                            self.yang_name = "frame-relay"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                            ])
                            self.ietf = None
                            self._segment_path = lambda: "frame-relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Encapsulation.FrameRelay, [u'ietf'], name, value)


                class FairQueueConf(Entity):
                    """
                    
                    
                    .. attribute:: fair_queue
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.FairQueueConf, self).__init__()

                        self.yang_name = "fair-queue-conf"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                        ])
                        self.fair_queue = None
                        self._segment_path = lambda: "fair-queue-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.FairQueueConf, [u'fair_queue'], name, value)


                class FairQueue(Entity):
                    """
                    Enable Fair Queuing on an Interface
                    
                    .. attribute:: incomplete
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.FairQueue, self).__init__()

                        self.yang_name = "fair-queue"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                        ])
                        self.incomplete = None
                        self._segment_path = lambda: "fair-queue"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.FairQueue, [u'incomplete'], name, value)


                class Flowcontrol(Entity):
                    """
                    Configure flow operation.
                    
                    .. attribute:: receive
                    
                    	Configure receiving flow operation
                    	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Flowcontrol.Receive>`
                    
                    .. attribute:: send
                    
                    	Configure sending flow operation
                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Flowcontrol.Send>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Flowcontrol, self).__init__()

                        self.yang_name = "flowcontrol"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.Flowcontrol.Receive')])),
                            ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.Flowcontrol.Send')])),
                        ])
                        self.receive = None
                        self.send = None
                        self._segment_path = lambda: "flowcontrol"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Flowcontrol, [u'receive', u'send'], name, value)

                    class Receive(Enum):
                        """
                        Receive (Enum Class)

                        Configure receiving flow operation

                        .. data:: desired = 0

                        .. data:: off = 1

                        .. data:: on = 2

                        """

                        desired = Enum.YLeaf(0, "desired")

                        off = Enum.YLeaf(1, "off")

                        on = Enum.YLeaf(2, "on")


                    class Send(Enum):
                        """
                        Send (Enum Class)

                        Configure sending flow operation

                        .. data:: desired = 0

                        .. data:: off = 1

                        .. data:: on = 2

                        """

                        desired = Enum.YLeaf(0, "desired")

                        off = Enum.YLeaf(1, "off")

                        on = Enum.YLeaf(2, "on")



                class Isis(Entity):
                    """
                    IS\-IS commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Isis, self).__init__()

                        self.yang_name = "isis"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "isis"
                        self._is_frozen = True


                class KeepaliveSettings(Entity):
                    """
                    
                    
                    .. attribute:: keepalive
                    
                    	Enable keepalive
                    	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.KeepaliveSettings.Keepalive>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.KeepaliveSettings, self).__init__()

                        self.yang_name = "keepalive-settings"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.LISPSubinterface.LISP.KeepaliveSettings.Keepalive))])
                        self._leafs = OrderedDict()

                        self.keepalive = None
                        self._children_name_map["keepalive"] = "keepalive"
                        self._segment_path = lambda: "keepalive-settings"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.KeepaliveSettings, [], name, value)


                    class Keepalive(Entity):
                        """
                        Enable keepalive
                        
                        .. attribute:: period
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..32767
                        
                        .. attribute:: retries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.KeepaliveSettings.Keepalive, self).__init__()

                            self.yang_name = "keepalive"
                            self.yang_parent_name = "keepalive-settings"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                            ])
                            self.period = None
                            self.retries = None
                            self._segment_path = lambda: "keepalive"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


                class Bfd(Entity):
                    """
                    BFD interface configuration commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True


                class Bandwidth(Entity):
                    """
                    Set bandwidth informational parameter
                    
                    .. attribute:: receive
                    
                    	Specify receive\-side bandwidth
                    	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Bandwidth.Receive>`
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Bandwidth.Inherit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: qos_reference
                    
                    	Reference bandwidth for QOS
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.LISPSubinterface.LISP.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.LISPSubinterface.LISP.Bandwidth.Inherit))])
                        self._leafs = OrderedDict([
                            ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.qos_reference = None
                        self.kilobits = None

                        self.receive = Native.Interface.LISPSubinterface.LISP.Bandwidth.Receive()
                        self.receive.parent = self
                        self._children_name_map["receive"] = "receive"

                        self.inherit = None
                        self._children_name_map["inherit"] = "inherit"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                    class Receive(Entity):
                        """
                        Specify receive\-side bandwidth
                        
                        .. attribute:: inherit
                        
                        	Specify how bandwidth is inherited
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: kilobits
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Bandwidth.Receive, self).__init__()

                            self.yang_name = "receive"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                                ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                            ])
                            self.inherit = None
                            self.kilobits = None
                            self._segment_path = lambda: "receive"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                    class Inherit(Entity):
                        """
                        Specify how bandwidth is inherited
                        
                        .. attribute:: kilobits
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Bandwidth.Inherit, self).__init__()

                            self.yang_name = "inherit"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                            ])
                            self.kilobits = None
                            self._segment_path = lambda: "inherit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Bandwidth.Inherit, [u'kilobits'], name, value)


                class Dampening(Entity):
                    """
                    Enable event dampening
                    
                    .. attribute:: dampening_time
                    
                    	<1\-30>;;Half\-life time for penalty
                    	**type**\: int
                    
                    	**range:** 1..30
                    
                    .. attribute:: start_reusing_time
                    
                    	<1\-20000>;;Value to start reusing an interface
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    .. attribute:: start_supressing_time
                    
                    	<1\-20000>;;Value to start supressing an interface
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    .. attribute:: maximum_supressing_time
                    
                    	<1\-255>;;Maximum duration to suppress an interface
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Dampening.Restart>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Dampening, self).__init__()

                        self.yang_name = "dampening"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.LISPSubinterface.LISP.Dampening.Restart))])
                        self._leafs = OrderedDict([
                            ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                            ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                            ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                            ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                        ])
                        self.dampening_time = None
                        self.start_reusing_time = None
                        self.start_supressing_time = None
                        self.maximum_supressing_time = None

                        self.restart = Native.Interface.LISPSubinterface.LISP.Dampening.Restart()
                        self.restart.parent = self
                        self._children_name_map["restart"] = "restart"
                        self._segment_path = lambda: "dampening"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                    class Restart(Entity):
                        """
                        Enable restart penalty
                        
                        .. attribute:: restart
                        
                        	Enable restart penalty
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restart_penalty
                        
                        	<1\-20000>;;Penalty applied at restart
                        	**type**\: int
                        
                        	**range:** 1..20000
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Dampening.Restart, self).__init__()

                            self.yang_name = "restart"
                            self.yang_parent_name = "dampening"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                                ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                            ])
                            self.restart = None
                            self.restart_penalty = None
                            self._segment_path = lambda: "restart"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


                class Domain(Entity):
                    """
                    Specify a domain
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: path
                    
                    	Specify a service provider for this interface
                    	**type**\: str
                    
                    .. attribute:: internet_bound
                    
                    	Specify Internet\-bound interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: path_id
                    
                    	Specify service provider path\-id for this interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: path_last_resort
                    
                    	Specify if you want this interface to be a path of last resort
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: zero_sla
                    
                    	Specify if you want this interface to be a 0\-sla interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Domain, self).__init__()

                        self.yang_name = "domain"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('path', (YLeaf(YType.str, 'path'), ['str'])),
                            ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                            ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                            ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                            ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                        ])
                        self.name = None
                        self.path = None
                        self.internet_bound = None
                        self.path_id = None
                        self.path_last_resort = None
                        self.zero_sla = None
                        self._segment_path = lambda: "domain"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


                class HoldQueue(Entity):
                    """
                    Set hold queue depth
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.HoldQueue.Direction>`
                    
                    .. attribute:: queue_length
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.HoldQueue, self).__init__()

                        self.yang_name = "hold-queue"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.HoldQueue.Direction')])),
                            ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                        ])
                        self.direction = None
                        self.queue_length = None
                        self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.HoldQueue, [u'direction', u'queue_length'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Mpls(Entity):
                    """
                    
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "mpls"
                        self._is_frozen = True


                class IpVrf(Entity):
                    """
                    
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.IpVrf.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.IpVrf, self).__init__()

                        self.yang_name = "ip-vrf"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.LISPSubinterface.LISP.IpVrf.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.LISPSubinterface.LISP.IpVrf.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "ip-vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.IpVrf, [], name, value)


                    class Ip(Entity):
                        """
                        
                        
                        .. attribute:: vrf
                        
                        	
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.IpVrf.Ip.Vrf>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.IpVrf.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "ip-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.LISPSubinterface.LISP.IpVrf.Ip.Vrf))])
                            self._leafs = OrderedDict()

                            self.vrf = Native.Interface.LISPSubinterface.LISP.IpVrf.Ip.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.IpVrf.Ip, [], name, value)


                        class Vrf(Entity):
                            """
                            
                            
                            .. attribute:: forwarding
                            
                            	Configure forwarding table
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.IpVrf.Ip.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                                ])
                                self.forwarding = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Vrf, [u'forwarding'], name, value)


                class Ip(Entity):
                    """
                    Interface Internet Protocol config commands
                    
                    .. attribute:: admission
                    
                    	Apply Network Admission Control
                    	**type**\: str
                    
                    .. attribute:: access_group
                    
                    	Specify access control for packets
                    	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup>`
                    
                    .. attribute:: arp
                    
                    	Configure ARP features
                    	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Arp>`
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding parameters on the interface
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Vrf>`
                    
                    .. attribute:: unnumbered
                    
                    	Enable IP processing without an explicit address
                    	**type**\: str
                    
                    .. attribute:: no_address
                    
                    	
                    	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.NoAddress>`
                    
                    .. attribute:: address
                    
                    	Set the IP address of an interface
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Address>`
                    
                    .. attribute:: directed_broadcast
                    
                    	Enable forwarding of directed broadcasts
                    	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.DirectedBroadcast>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Configures EIGRP\-IPv4 hello interval
                    	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.HelloInterval>`
                    
                    .. attribute:: authentication
                    
                    	authentication subcommands
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Authentication>`
                    
                    .. attribute:: hold_time
                    
                    	Configures EIGRP\-IPv4 hold time
                    	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.HoldTime>`
                    
                    .. attribute:: helper_address
                    
                    	Specify a destination address for UDP broadcasts
                    	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.HelperAddress>`
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Pim>`
                    
                    .. attribute:: policy
                    
                    	Enable policy routing
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Policy>`
                    
                    .. attribute:: local_proxy_arp
                    
                    	Enable local\-proxy ARP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: proxy_arp
                    
                    	Enable proxy ARP
                    	**type**\: bool
                    
                    .. attribute:: rip
                    
                    	Router Information Protocol
                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Rip>`
                    
                    .. attribute:: route_cache_conf
                    
                    	
                    	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.RouteCacheConf>`
                    
                    .. attribute:: route_cache
                    
                    	Enable fast\-switching cache for outgoing packets
                    	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.RouteCache>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: router
                    
                    	IP router interface commands
                    	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Router>`
                    
                    .. attribute:: redirects
                    
                    	Enable sending ICMP Redirect messages
                    	**type**\: bool
                    
                    .. attribute:: tcp
                    
                    	TCP header compression and other parameters
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Tcp>`
                    
                    .. attribute:: virtual_reassembly
                    
                    	
                    	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.VirtualReassembly>`
                    
                    .. attribute:: dhcp
                    
                    	Configure DHCP parameters for this interface
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Dhcp>`
                    
                    .. attribute:: mtu
                    
                    	Set IP Maximum Transmission Unit
                    	**type**\: int
                    
                    	**range:** 68..9216
                    
                    .. attribute:: mroute_cache
                    
                    	Enable switching cache for incoming multicast packets
                    	**type**\: bool
                    
                    .. attribute:: summary_address
                    
                    	
                    	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.SummaryAddress>`
                    
                    .. attribute:: verify
                    
                    	Enable per packet validation
                    	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Verify>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.LISPSubinterface.LISP.Ip.Arp)), ("vrf", ("vrf", Native.Interface.LISPSubinterface.LISP.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.LISPSubinterface.LISP.Ip.NoAddress)), ("address", ("address", Native.Interface.LISPSubinterface.LISP.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.LISPSubinterface.LISP.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.LISPSubinterface.LISP.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.LISPSubinterface.LISP.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.LISPSubinterface.LISP.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.LISPSubinterface.LISP.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.LISPSubinterface.LISP.Ip.Pim)), ("policy", ("policy", Native.Interface.LISPSubinterface.LISP.Ip.Policy)), ("rip", ("rip", Native.Interface.LISPSubinterface.LISP.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.LISPSubinterface.LISP.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.LISPSubinterface.LISP.Ip.RouteCache)), ("router", ("router", Native.Interface.LISPSubinterface.LISP.Ip.Router)), ("tcp", ("tcp", Native.Interface.LISPSubinterface.LISP.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.LISPSubinterface.LISP.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.LISPSubinterface.LISP.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.LISPSubinterface.LISP.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.LISPSubinterface.LISP.Ip.Verify))])
                        self._leafs = OrderedDict([
                            ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                            ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                            ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                            ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                            ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                            ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                            ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ])
                        self.admission = None
                        self.unnumbered = None
                        self.local_proxy_arp = None
                        self.proxy_arp = None
                        self.redirects = None
                        self.mtu = None
                        self.mroute_cache = None

                        self.access_group = Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup()
                        self.access_group.parent = self
                        self._children_name_map["access_group"] = "access-group"

                        self.arp = Native.Interface.LISPSubinterface.LISP.Ip.Arp()
                        self.arp.parent = self
                        self._children_name_map["arp"] = "arp"

                        self.vrf = Native.Interface.LISPSubinterface.LISP.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.no_address = Native.Interface.LISPSubinterface.LISP.Ip.NoAddress()
                        self.no_address.parent = self
                        self._children_name_map["no_address"] = "no-address"

                        self.address = Native.Interface.LISPSubinterface.LISP.Ip.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.directed_broadcast = None
                        self._children_name_map["directed_broadcast"] = "directed-broadcast"

                        self.hello_interval = Native.Interface.LISPSubinterface.LISP.Ip.HelloInterval()
                        self.hello_interval.parent = self
                        self._children_name_map["hello_interval"] = "hello-interval"

                        self.authentication = Native.Interface.LISPSubinterface.LISP.Ip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.hold_time = Native.Interface.LISPSubinterface.LISP.Ip.HoldTime()
                        self.hold_time.parent = self
                        self._children_name_map["hold_time"] = "hold-time"

                        self.pim = Native.Interface.LISPSubinterface.LISP.Ip.Pim()
                        self.pim.parent = self
                        self._children_name_map["pim"] = "pim"

                        self.policy = Native.Interface.LISPSubinterface.LISP.Ip.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.rip = Native.Interface.LISPSubinterface.LISP.Ip.Rip()
                        self.rip.parent = self
                        self._children_name_map["rip"] = "rip"

                        self.route_cache_conf = Native.Interface.LISPSubinterface.LISP.Ip.RouteCacheConf()
                        self.route_cache_conf.parent = self
                        self._children_name_map["route_cache_conf"] = "route-cache-conf"

                        self.route_cache = None
                        self._children_name_map["route_cache"] = "route-cache"

                        self.router = Native.Interface.LISPSubinterface.LISP.Ip.Router()
                        self.router.parent = self
                        self._children_name_map["router"] = "router"

                        self.tcp = Native.Interface.LISPSubinterface.LISP.Ip.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"

                        self.virtual_reassembly = Native.Interface.LISPSubinterface.LISP.Ip.VirtualReassembly()
                        self.virtual_reassembly.parent = self
                        self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                        self.dhcp = Native.Interface.LISPSubinterface.LISP.Ip.Dhcp()
                        self.dhcp.parent = self
                        self._children_name_map["dhcp"] = "dhcp"

                        self.summary_address = Native.Interface.LISPSubinterface.LISP.Ip.SummaryAddress()
                        self.summary_address.parent = self
                        self._children_name_map["summary_address"] = "summary-address"

                        self.verify = Native.Interface.LISPSubinterface.LISP.Ip.Verify()
                        self.verify.parent = self
                        self._children_name_map["verify"] = "verify"

                        self.helper_address = YList(self)
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                    class AccessGroup(Entity):
                        """
                        Specify access control for packets
                        
                        .. attribute:: in_
                        
                        	
                        	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In>`
                        
                        .. attribute:: out
                        
                        	
                        	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup, self).__init__()

                            self.yang_name = "access-group"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("in", ("in_", Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out))])
                            self._leafs = OrderedDict()

                            self.in_ = Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In()
                            self.in_.parent = self
                            self._children_name_map["in_"] = "in"

                            self.out = Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out()
                            self.out.parent = self
                            self._children_name_map["out"] = "out"
                            self._segment_path = lambda: "access-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup, [], name, value)


                        class In(Entity):
                            """
                            
                            
                            .. attribute:: common_acl
                            
                            	
                            	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In.CommonAcl>`
                            
                            .. attribute:: acl
                            
                            	
                            	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In.Acl>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In, self).__init__()

                                self.yang_name = "in"
                                self.yang_parent_name = "access-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In.Acl))])
                                self._leafs = OrderedDict()

                                self.common_acl = Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In.CommonAcl()
                                self.common_acl.parent = self
                                self._children_name_map["common_acl"] = "common-acl"

                                self.acl = Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In.Acl()
                                self.acl.parent = self
                                self._children_name_map["acl"] = "acl"
                                self._segment_path = lambda: "in"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In, [], name, value)


                            class CommonAcl(Entity):
                                """
                                
                                
                                .. attribute:: common
                                
                                	specify ipv4 common ACL for packet filtering
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: in_
                                
                                	inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                    self.yang_name = "common-acl"
                                    self.yang_parent_name = "in"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ])
                                    self.common = None
                                    self.in_ = None
                                    self._segment_path = lambda: "common-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                            class Acl(Entity):
                                """
                                
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: in_
                                
                                	inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In.Acl, self).__init__()

                                    self.yang_name = "acl"
                                    self.yang_parent_name = "in"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ])
                                    self.acl_name = None
                                    self.in_ = None
                                    self._segment_path = lambda: "acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                        class Out(Entity):
                            """
                            
                            
                            .. attribute:: common_acl
                            
                            	
                            	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out.CommonAcl>`
                            
                            .. attribute:: acl
                            
                            	
                            	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out.Acl>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out, self).__init__()

                                self.yang_name = "out"
                                self.yang_parent_name = "access-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out.Acl))])
                                self._leafs = OrderedDict()

                                self.common_acl = Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out.CommonAcl()
                                self.common_acl.parent = self
                                self._children_name_map["common_acl"] = "common-acl"

                                self.acl = Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out.Acl()
                                self.acl.parent = self
                                self._children_name_map["acl"] = "acl"
                                self._segment_path = lambda: "out"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out, [], name, value)


                            class CommonAcl(Entity):
                                """
                                
                                
                                .. attribute:: common
                                
                                	specify ipv4 common ACL for packet filtering
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: out
                                
                                	outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                    self.yang_name = "common-acl"
                                    self.yang_parent_name = "out"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.common = None
                                    self.out = None
                                    self._segment_path = lambda: "common-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                            class Acl(Entity):
                                """
                                
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: out
                                
                                	outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out.Acl, self).__init__()

                                    self.yang_name = "acl"
                                    self.yang_parent_name = "out"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.acl_name = None
                                    self.out = None
                                    self._segment_path = lambda: "acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                    class Arp(Entity):
                        """
                        Configure ARP features
                        
                        .. attribute:: inspection
                        
                        	Arp Inspection configuration
                        	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Arp.Inspection>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.Arp, self).__init__()

                            self.yang_name = "arp"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.LISPSubinterface.LISP.Ip.Arp.Inspection))])
                            self._leafs = OrderedDict()

                            self.inspection = Native.Interface.LISPSubinterface.LISP.Ip.Arp.Inspection()
                            self.inspection.parent = self
                            self._children_name_map["inspection"] = "inspection"
                            self._segment_path = lambda: "arp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Arp, [], name, value)


                        class Inspection(Entity):
                            """
                            Arp Inspection configuration
                            
                            .. attribute:: limit
                            
                            	Configure Rate limit of incoming ARP packets
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Arp.Inspection.Limit>`
                            
                            .. attribute:: trust
                            
                            	Configure Trust state
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.Arp.Inspection, self).__init__()

                                self.yang_name = "inspection"
                                self.yang_parent_name = "arp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.LISPSubinterface.LISP.Ip.Arp.Inspection.Limit))])
                                self._leafs = OrderedDict([
                                    ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ])
                                self.trust = None

                                self.limit = Native.Interface.LISPSubinterface.LISP.Ip.Arp.Inspection.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "inspection"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Arp.Inspection, [u'trust'], name, value)


                            class Limit(Entity):
                                """
                                Configure Rate limit of incoming ARP packets
                                
                                .. attribute:: none
                                
                                	No limit
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rate
                                
                                	Rate Limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Ip.Arp.Inspection.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "inspection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                    ])
                                    self.none = None
                                    self.rate = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                    class Vrf(Entity):
                        """
                        VPN Routing/Forwarding parameters on the interface
                        
                        .. attribute:: receive
                        
                        	Add Interface Address into VRF Table
                        	**type**\: str
                        
                        .. attribute:: sitemap
                        
                        	Configure route\-map for routesreceived from this site
                        	**type**\: str
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Vrf.Forwarding>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.LISPSubinterface.LISP.Ip.Vrf.Forwarding))])
                            self._leafs = OrderedDict([
                                ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                                ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                            ])
                            self.receive = None
                            self.sitemap = None

                            self.forwarding = Native.Interface.LISPSubinterface.LISP.Ip.Vrf.Forwarding()
                            self.forwarding.parent = self
                            self._children_name_map["forwarding"] = "forwarding"
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                        class Forwarding(Entity):
                            """
                            Configure forwarding table
                            
                            .. attribute:: liin_vrf
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mgmtvrf
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: word
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.Vrf.Forwarding, self).__init__()

                                self.yang_name = "forwarding"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                    ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.liin_vrf = None
                                self.mgmtvrf = None
                                self.word = None
                                self._segment_path = lambda: "forwarding"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                    class NoAddress(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.NoAddress, self).__init__()

                            self.yang_name = "no-address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                            ])
                            self.address = None
                            self._segment_path = lambda: "no-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.NoAddress, [u'address'], name, value)


                    class Address(Entity):
                        """
                        Set the IP address of an interface
                        
                        .. attribute:: secondary
                        
                        	
                        	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Address.Secondary>`
                        
                        .. attribute:: primary
                        
                        	
                        	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Address.Primary>`
                        
                        .. attribute:: dhcp
                        
                        	IP Address negotiated via DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Address.Dhcp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: negotiated
                        
                        	IP Address negotiated via IKEv2 Modeconfig
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.LISPSubinterface.LISP.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.LISPSubinterface.LISP.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.LISPSubinterface.LISP.Ip.Address.Dhcp))])
                            self._leafs = OrderedDict([
                                ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                            ])
                            self.negotiated = None

                            self.primary = Native.Interface.LISPSubinterface.LISP.Ip.Address.Primary()
                            self.primary.parent = self
                            self._children_name_map["primary"] = "primary"

                            self.dhcp = None
                            self._children_name_map["dhcp"] = "dhcp"

                            self.secondary = YList(self)
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Address, [u'negotiated'], name, value)


                        class Secondary(Entity):
                            """
                            
                            
                            .. attribute:: address  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**mandatory**\: True
                            
                            .. attribute:: secondary
                            
                            	Make this IP address a secondary address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.Address.Secondary, self).__init__()

                                self.yang_name = "secondary"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.address = None
                                self.mask = None
                                self.secondary = None
                                self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                        class Primary(Entity):
                            """
                            
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.Address.Primary, self).__init__()

                                self.yang_name = "primary"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.address = None
                                self.mask = None
                                self._segment_path = lambda: "primary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Address.Primary, [u'address', u'mask'], name, value)


                        class Dhcp(Entity):
                            """
                            IP Address negotiated via DHCP
                            
                            .. attribute:: client_id
                            
                            	Specify client\-id to use
                            	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Address.Dhcp.ClientId>`
                            
                            .. attribute:: hostname
                            
                            	Specify value for hostname option
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.Address.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.LISPSubinterface.LISP.Ip.Address.Dhcp.ClientId))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                                ])
                                self.hostname = None

                                self.client_id = Native.Interface.LISPSubinterface.LISP.Ip.Address.Dhcp.ClientId()
                                self.client_id.parent = self
                                self._children_name_map["client_id"] = "client-id"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Address.Dhcp, [u'hostname'], name, value)


                            class ClientId(Entity):
                                """
                                Specify client\-id to use
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five Gigabit Ethernet 
                                	**type**\: str
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five Gigabit Ethernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two Gigabit Ethernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: vlan
                                
                                	Catalyst Vlans
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Ip.Address.Dhcp.ClientId, self).__init__()

                                    self.yang_name = "client-id"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.port_channel = None
                                    self.tengigabitethernet = None
                                    self.twentyfivegige = None
                                    self.fortygigabitethernet = None
                                    self.twogigabitethernet = None
                                    self.hundredgige = None
                                    self.vlan = None
                                    self._segment_path = lambda: "client-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                    class DirectedBroadcast(Entity):
                        """
                        Enable forwarding of directed broadcasts
                        
                        .. attribute:: direct_broadcast
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.DirectedBroadcast, self).__init__()

                            self.yang_name = "directed-broadcast"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                            ])
                            self.direct_broadcast = None
                            self._segment_path = lambda: "directed-broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                    class HelloInterval(Entity):
                        """
                        Configures EIGRP\-IPv4 hello interval
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: seconds
                        
                        	Seconds between hello transmissions
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.HelloInterval, self).__init__()

                            self.yang_name = "hello-interval"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                            ])
                            self.eigrp = None
                            self.seconds = None
                            self._segment_path = lambda: "hello-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                    class Authentication(Entity):
                        """
                        authentication subcommands
                        
                        .. attribute:: key_chain
                        
                        	key\-chain
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Authentication.KeyChain>`
                        
                        .. attribute:: mode
                        
                        	mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.LISPSubinterface.LISP.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.LISPSubinterface.LISP.Ip.Authentication.Mode))])
                            self._leafs = OrderedDict()

                            self.key_chain = Native.Interface.LISPSubinterface.LISP.Ip.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"

                            self.mode = Native.Interface.LISPSubinterface.LISP.Ip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Authentication, [], name, value)


                        class KeyChain(Entity):
                            """
                            key\-chain
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: name
                            
                            	name of key\-chain
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.eigrp = None
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                        class Mode(Entity):
                            """
                            mode
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                ])
                                self.eigrp = None
                                self.md5 = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                    class HoldTime(Entity):
                        """
                        Configures EIGRP\-IPv4 hold time
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: seconds
                        
                        	Seconds before neighbor is considered down
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.HoldTime, self).__init__()

                            self.yang_name = "hold-time"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                            ])
                            self.eigrp = None
                            self.seconds = None
                            self._segment_path = lambda: "hold-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                    class HelperAddress(Entity):
                        """
                        Specify a destination address for UDP broadcasts
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: global_
                        
                        	Helper\-address is global
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vrf
                        
                        	VRF name for helper\-address (if different from interface VRF)
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.HelperAddress, self).__init__()

                            self.yang_name = "helper-address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.address = None
                            self.global_ = None
                            self.vrf = None
                            self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                    class Pim(Entity):
                        """
                        PIM interface commands
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.Pim, self).__init__()

                            self.yang_name = "pim"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "pim"
                            self._is_frozen = True


                    class Policy(Entity):
                        """
                        Enable policy routing
                        
                        .. attribute:: route_map
                        
                        	Policy route\-map
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Policy, [u'route_map'], name, value)


                    class Rip(Entity):
                        """
                        Router Information Protocol
                        
                        .. attribute:: authentication
                        
                        	Authentication control
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Rip.Authentication>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.Rip, self).__init__()

                            self.yang_name = "rip"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.LISPSubinterface.LISP.Ip.Rip.Authentication))])
                            self._leafs = OrderedDict()

                            self.authentication = Native.Interface.LISPSubinterface.LISP.Ip.Rip.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"
                            self._segment_path = lambda: "rip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Rip, [], name, value)


                        class Authentication(Entity):
                            """
                            Authentication control
                            
                            .. attribute:: key_chain
                            
                            	Authentication key\-chain
                            	**type**\: str
                            
                            .. attribute:: mode
                            
                            	Authentication mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Rip.Authentication.Mode>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.Rip.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "rip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.LISPSubinterface.LISP.Ip.Rip.Authentication.Mode))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.mode = Native.Interface.LISPSubinterface.LISP.Ip.Rip.Authentication.Mode()
                                self.mode.parent = self
                                self._children_name_map["mode"] = "mode"
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Rip.Authentication, [u'key_chain'], name, value)


                            class Mode(Entity):
                                """
                                Authentication mode
                                
                                .. attribute:: md5
                                
                                	Keyed message digest
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: text
                                
                                	Clear text authentication
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Ip.Rip.Authentication.Mode, self).__init__()

                                    self.yang_name = "mode"
                                    self.yang_parent_name = "authentication"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                        ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                    ])
                                    self.md5 = None
                                    self.text = None
                                    self._segment_path = lambda: "mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                    class RouteCacheConf(Entity):
                        """
                        
                        
                        .. attribute:: route_cache
                        
                        	
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.RouteCacheConf, self).__init__()

                            self.yang_name = "route-cache-conf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                            ])
                            self.route_cache = None
                            self._segment_path = lambda: "route-cache-conf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.RouteCacheConf, [u'route_cache'], name, value)


                    class RouteCache(Entity):
                        """
                        Enable fast\-switching cache for outgoing packets
                        
                        .. attribute:: cef
                        
                        	Enable Cisco Express Forwarding
                        	**type**\: bool
                        
                        .. attribute:: flow
                        
                        	Enable Flow fast\-switching cache
                        	**type**\: bool
                        
                        .. attribute:: policy
                        
                        	Enable fast\-switching policy cache for outgoing packets
                        	**type**\: bool
                        
                        .. attribute:: same_interface
                        
                        	Enable fast\-switching on the same interface
                        	**type**\: bool
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.RouteCache, self).__init__()

                            self.yang_name = "route-cache"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                                ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                                ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                                ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                            ])
                            self.cef = None
                            self.flow = None
                            self.policy = None
                            self.same_interface = None
                            self._segment_path = lambda: "route-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                    class Router(Entity):
                        """
                        IP router interface commands
                        
                        .. attribute:: isis
                        
                        	IS\-IS Routing for IP
                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Router.Isis>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.Router, self).__init__()

                            self.yang_name = "router"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.LISPSubinterface.LISP.Ip.Router.Isis))])
                            self._leafs = OrderedDict()

                            self.isis = None
                            self._children_name_map["isis"] = "isis"
                            self._segment_path = lambda: "router"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Router, [], name, value)


                        class Isis(Entity):
                            """
                            IS\-IS Routing for IP
                            
                            .. attribute:: tag
                            
                            	
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.Router.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "router"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                                ])
                                self.tag = None
                                self._segment_path = lambda: "isis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Router.Isis, [u'tag'], name, value)


                    class Tcp(Entity):
                        """
                        TCP header compression and other parameters
                        
                        .. attribute:: adjust_mss
                        
                        	Adjust the mss of transit packets
                        	**type**\: int
                        
                        	**range:** 500..1460
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                            ])
                            self.adjust_mss = None
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Tcp, [u'adjust_mss'], name, value)


                    class VirtualReassembly(Entity):
                        """
                        
                        
                        .. attribute:: max_reassemblies
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_fragments
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: timeout
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop_fragments
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: in_
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.VirtualReassembly, self).__init__()

                            self.yang_name = "virtual-reassembly"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                                ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                                ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                                ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                            ])
                            self.max_reassemblies = None
                            self.max_fragments = None
                            self.timeout = None
                            self.drop_fragments = None
                            self.in_ = None
                            self._segment_path = lambda: "virtual-reassembly"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                    class Dhcp(Entity):
                        """
                        Configure DHCP parameters for this interface
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True


                    class SummaryAddress(Entity):
                        """
                        
                        
                        .. attribute:: eigrp
                        
                        	
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.SummaryAddress.Eigrp>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.SummaryAddress, self).__init__()

                            self.yang_name = "summary-address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.LISPSubinterface.LISP.Ip.SummaryAddress.Eigrp))])
                            self._leafs = OrderedDict()

                            self.eigrp = YList(self)
                            self._segment_path = lambda: "summary-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.SummaryAddress, [], name, value)


                        class Eigrp(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: metric
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.SummaryAddress.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "summary-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ])
                                self.id = None
                                self.ip = None
                                self.mask = None
                                self.metric = None
                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                    class Verify(Entity):
                        """
                        Enable per packet validation
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: unicast
                        
                        	Enable per packet validation for unicast
                        	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ip.Verify, self).__init__()

                            self.yang_name = "verify"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source", ("source", Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast))])
                            self._leafs = OrderedDict()

                            self.source = None
                            self._children_name_map["source"] = "source"

                            self.unicast = Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast()
                            self.unicast.parent = self
                            self._children_name_map["unicast"] = "unicast"
                            self._segment_path = lambda: "verify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Verify, [], name, value)


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source.Vlan>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "verify"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source.Vlan))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.vlan = Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source, [], name, value)


                            class Vlan(Entity):
                                """
                                vlan specification
                                
                                .. attribute:: dhcp_snooping
                                
                                	snooping enable vlan
                                	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source.Vlan.DhcpSnooping>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                    self._leafs = OrderedDict()

                                    self.dhcp_snooping = None
                                    self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source.Vlan, [], name, value)


                                class DhcpSnooping(Entity):
                                    """
                                    snooping enable vlan
                                    
                                    .. attribute:: port_security
                                    
                                    	port security
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                        self.yang_name = "dhcp-snooping"
                                        self.yang_parent_name = "vlan"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                        ])
                                        self.port_security = None
                                        self._segment_path = lambda: "dhcp-snooping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                        class Unicast(Entity):
                            """
                            Enable per packet validation for unicast
                            
                            .. attribute:: reverse_path
                            
                            	Reverse path validation of source address (old command format)
                            	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast.ReversePath>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: source
                            
                            	Validation of source address
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast.Source>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast, self).__init__()

                                self.yang_name = "unicast"
                                self.yang_parent_name = "verify"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast.Source))])
                                self._leafs = OrderedDict()

                                self.reverse_path = None
                                self._children_name_map["reverse_path"] = "reverse-path"

                                self.source = Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "unicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast, [], name, value)


                            class ReversePath(Entity):
                                """
                                Reverse path validation of source address (old command format)
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast.ReversePath, self).__init__()

                                    self.yang_name = "reverse-path"
                                    self.yang_parent_name = "unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "reverse-path"
                                    self._is_frozen = True


                            class Source(Entity):
                                """
                                Validation of source address
                                
                                .. attribute:: reachable_via
                                
                                	Specify reachability check to apply to the source address
                                	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast.Source.ReachableVia>`
                                
                                .. attribute:: allow_self_ping
                                
                                	Allow router to ping itself (opens vulnerability in verification)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allow_default
                                
                                	Allow default route to match when checking source address
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.Ip.Verify.Unicast.Source.ReachableVia')])),
                                        ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                        ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                    ])
                                    self.reachable_via = None
                                    self.allow_self_ping = None
                                    self.allow_default = None
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                                class ReachableVia(Enum):
                                    """
                                    ReachableVia (Enum Class)

                                    Specify reachability check to apply to the source address

                                    .. data:: any = 0

                                    .. data:: rx = 1

                                    """

                                    any = Enum.YLeaf(0, "any")

                                    rx = Enum.YLeaf(1, "rx")



                class Ipv6(Entity):
                    """
                    IPv6 interface subcommands
                    
                    .. attribute:: destination_guard
                    
                    	Configure ipv6 destination guard on the interface
                    	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.DestinationGuard>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: source_guard
                    
                    	Configure ipv6 source guard on the interface
                    	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.SourceGuard>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dhcp
                    
                    	IPv6 DHCP interface subcommands
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.Dhcp>`
                    
                    .. attribute:: address
                    
                    	Configure IPv6 address on interface
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.Address>`
                    
                    .. attribute:: unnumbered
                    
                    	Preferred interface for source address selection
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable IPv6 on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mtu
                    
                    	Set IPv6 Maximum Transmission Unit
                    	**type**\: int
                    
                    	**range:** 1280..9216
                    
                    .. attribute:: nd
                    
                    	IPv6 interface Neighbor Discovery subcommands
                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.Nd>`
                    
                    .. attribute:: redirects
                    
                    	Enable sending ICMP Redirect messages
                    	**type**\: bool
                    
                    .. attribute:: tcp
                    
                    	TCP header compression and other parameters
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.Tcp>`
                    
                    .. attribute:: traffic_filter
                    
                    	Access control list for packets
                    	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.TrafficFilter>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.LISPSubinterface.LISP.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.LISPSubinterface.LISP.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.LISPSubinterface.LISP.Ipv6.Dhcp)), ("address", ("address", Native.Interface.LISPSubinterface.LISP.Ipv6.Address)), ("nd", ("nd", Native.Interface.LISPSubinterface.LISP.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.LISPSubinterface.LISP.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.LISPSubinterface.LISP.Ipv6.TrafficFilter))])
                        self._leafs = OrderedDict([
                            ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                            ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ])
                        self.unnumbered = None
                        self.enable = None
                        self.mtu = None
                        self.redirects = None

                        self.destination_guard = None
                        self._children_name_map["destination_guard"] = "destination-guard"

                        self.source_guard = None
                        self._children_name_map["source_guard"] = "source-guard"

                        self.dhcp = Native.Interface.LISPSubinterface.LISP.Ipv6.Dhcp()
                        self.dhcp.parent = self
                        self._children_name_map["dhcp"] = "dhcp"

                        self.address = Native.Interface.LISPSubinterface.LISP.Ipv6.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.nd = Native.Interface.LISPSubinterface.LISP.Ipv6.Nd()
                        self.nd.parent = self
                        self._children_name_map["nd"] = "nd"

                        self.tcp = Native.Interface.LISPSubinterface.LISP.Ipv6.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"

                        self.traffic_filter = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                    class DestinationGuard(Entity):
                        """
                        Configure ipv6 destination guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature ipv6 destguard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ipv6.DestinationGuard, self).__init__()

                            self.yang_name = "destination-guard"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "destination-guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                    class SourceGuard(Entity):
                        """
                        Configure ipv6 source guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature ipv6 sourceguard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ipv6.SourceGuard, self).__init__()

                            self.yang_name = "source-guard"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "source-guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                    class Dhcp(Entity):
                        """
                        IPv6 DHCP interface subcommands
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ipv6.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True


                    class Address(Entity):
                        """
                        Configure IPv6 address on interface
                        
                        .. attribute:: dhcp
                        
                        	Obtain IPv6 address from DHCP server
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.Address.Dhcp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: autoconfig
                        
                        	Obtain address using autoconfiguration
                        	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.Address.Autoconfig>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix_list
                        
                        	
                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.Address.PrefixList>`
                        
                        .. attribute:: link_local_address
                        
                        	
                        	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.Address.LinkLocalAddress>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ipv6.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.LISPSubinterface.LISP.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.LISPSubinterface.LISP.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.LISPSubinterface.LISP.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.LISPSubinterface.LISP.Ipv6.Address.LinkLocalAddress))])
                            self._leafs = OrderedDict()

                            self.dhcp = None
                            self._children_name_map["dhcp"] = "dhcp"

                            self.autoconfig = None
                            self._children_name_map["autoconfig"] = "autoconfig"

                            self.prefix_list = YList(self)
                            self.link_local_address = YList(self)
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ipv6.Address, [], name, value)


                        class Dhcp(Entity):
                            """
                            Obtain IPv6 address from DHCP server
                            
                            .. attribute:: rapid_commit
                            
                            	rapid\-commit for prefix delegation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ipv6.Address.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                                ])
                                self.rapid_commit = None
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                        class Autoconfig(Entity):
                            """
                            Obtain address using autoconfiguration
                            
                            .. attribute:: default
                            
                            	Insert default route
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ipv6.Address.Autoconfig, self).__init__()

                                self.yang_name = "autoconfig"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ])
                                self.default = None
                                self._segment_path = lambda: "autoconfig"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ipv6.Address.Autoconfig, [u'default'], name, value)


                        class PrefixList(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: anycast
                            
                            	Configure as an anycast
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: eui_64
                            
                            	Use eui\-64 interface identifier
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ipv6.Address.PrefixList, self).__init__()

                                self.yang_name = "prefix-list"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                    ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                                ])
                                self.prefix = None
                                self.anycast = None
                                self.eui_64 = None
                                self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                        class LinkLocalAddress(Entity):
                            """
                            
                            
                            .. attribute:: address  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: link_local
                            
                            	Use link\-local address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Ipv6.Address.LinkLocalAddress, self).__init__()

                                self.yang_name = "link-local-address"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                                ])
                                self.address = None
                                self.link_local = None
                                self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                    class Nd(Entity):
                        """
                        IPv6 interface Neighbor Discovery subcommands
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ipv6.Nd, self).__init__()

                            self.yang_name = "nd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "nd"
                            self._is_frozen = True


                    class Tcp(Entity):
                        """
                        TCP header compression and other parameters
                        
                        .. attribute:: adjust_mss
                        
                        	Adjust the mss of transit packets
                        	**type**\: int
                        
                        	**range:** 40..1454
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ipv6.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                            ])
                            self.adjust_mss = None
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ipv6.Tcp, [u'adjust_mss'], name, value)


                    class TrafficFilter(Entity):
                        """
                        Access control list for packets
                        
                        .. attribute:: direction  (key)
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Ipv6.TrafficFilter.Direction>`
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Ipv6.TrafficFilter, self).__init__()

                            self.yang_name = "traffic-filter"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['direction']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.Ipv6.TrafficFilter.Direction')])),
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                            ])
                            self.direction = None
                            self.access_list = None
                            self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: in_ = 0

                            .. data:: out = 1

                            """

                            in_ = Enum.YLeaf(0, "in")

                            out = Enum.YLeaf(1, "out")



                class Logging(Entity):
                    """
                    Configure logging for interface
                    
                    .. attribute:: event
                    
                    	Interface events
                    	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Logging.Event>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Logging, self).__init__()

                        self.yang_name = "logging"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("event", ("event", Native.Interface.LISPSubinterface.LISP.Logging.Event))])
                        self._leafs = OrderedDict()

                        self.event = Native.Interface.LISPSubinterface.LISP.Logging.Event()
                        self.event.parent = self
                        self._children_name_map["event"] = "event"
                        self._segment_path = lambda: "logging"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Logging, [], name, value)


                    class Event(Entity):
                        """
                        Interface events
                        
                        .. attribute:: bundle_status
                        
                        	BUNDLE/UNBUNDLE messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: link_status
                        
                        	UPDOWN and CHANGE messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trunk_status
                        
                        	TRUNK status messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: nfas_status
                        
                        	NFAS D\-channel status messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: power_inline_status
                        
                        	Inline power messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: spanning_tree
                        
                        	Spanning\-tree Interface events
                        	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Logging.Event.SpanningTree>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: subif_link_status
                        
                        	Sub\-interface UPDOWN and CHANGE messages
                        	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Logging.Event.SubifLinkStatus>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Logging.Event, self).__init__()

                            self.yang_name = "event"
                            self.yang_parent_name = "logging"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.LISPSubinterface.LISP.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.LISPSubinterface.LISP.Logging.Event.SubifLinkStatus))])
                            self._leafs = OrderedDict([
                                ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                                ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                                ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                                ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.bundle_status = None
                            self.link_status = None
                            self.trunk_status = None
                            self.nfas_status = None
                            self.power_inline_status = None
                            self.status = None

                            self.spanning_tree = None
                            self._children_name_map["spanning_tree"] = "spanning-tree"

                            self.subif_link_status = None
                            self._children_name_map["subif_link_status"] = "subif-link-status"
                            self._segment_path = lambda: "event"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                        class SpanningTree(Entity):
                            """
                            Spanning\-tree Interface events
                            
                            .. attribute:: status
                            
                            	Spanning\-tree state change messages
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Logging.Event.SpanningTree, self).__init__()

                                self.yang_name = "spanning-tree"
                                self.yang_parent_name = "event"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                                ])
                                self.status = None
                                self._segment_path = lambda: "spanning-tree"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Logging.Event.SpanningTree, [u'status'], name, value)


                        class SubifLinkStatus(Entity):
                            """
                            Sub\-interface UPDOWN and CHANGE messages
                            
                            .. attribute:: ignore_bulk
                            
                            	Do not log messages when the main interface is transitioning
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Logging.Event.SubifLinkStatus, self).__init__()

                                self.yang_name = "subif-link-status"
                                self.yang_parent_name = "event"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                                ])
                                self.ignore_bulk = None
                                self._segment_path = lambda: "subif-link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


                class Mdix(Entity):
                    """
                    Set Media Dependent Interface with Crossover
                    
                    .. attribute:: auto
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Mdix, self).__init__()

                        self.yang_name = "mdix"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "mdix"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Mdix, [u'auto'], name, value)


                class Mop(Entity):
                    """
                    
                    
                    .. attribute:: enabled
                    
                    	
                    	**type**\: bool
                    
                    .. attribute:: sysid
                    
                    	Send out MOP periodic system ID messages
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Mop, self).__init__()

                        self.yang_name = "mop"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                            ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                        ])
                        self.enabled = None
                        self.sysid = None
                        self._segment_path = lambda: "mop"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Mop, [u'enabled', u'sysid'], name, value)


                class InterfaceQos(Entity):
                    """
                    
                    
                    .. attribute:: trust
                    
                    	
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.InterfaceQos.Trust>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.InterfaceQos, self).__init__()

                        self.yang_name = "interface_qos"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.LISPSubinterface.LISP.InterfaceQos.Trust))])
                        self._leafs = OrderedDict()

                        self.trust = Native.Interface.LISPSubinterface.LISP.InterfaceQos.Trust()
                        self.trust.parent = self
                        self._children_name_map["trust"] = "trust"
                        self._segment_path = lambda: "interface_qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.InterfaceQos, [], name, value)


                    class Trust(Entity):
                        """
                        
                        
                        .. attribute:: device
                        
                        	
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.InterfaceQos.Trust.Device>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.InterfaceQos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "interface_qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.InterfaceQos.Trust.Device')])),
                            ])
                            self.device = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.InterfaceQos.Trust, [u'device'], name, value)

                        class Device(Enum):
                            """
                            Device (Enum Class)

                            .. data:: cisco_phone = 0

                            """

                            cisco_phone = Enum.YLeaf(0, "cisco-phone")



                class Source(Entity):
                    """
                    Get config from another source
                    
                    .. attribute:: template
                    
                    	Get config from a template
                    	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Source.Template>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Source, self).__init__()

                        self.yang_name = "source"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template", ("template", Native.Interface.LISPSubinterface.LISP.Source.Template))])
                        self._leafs = OrderedDict()

                        self.template = Native.Interface.LISPSubinterface.LISP.Source.Template()
                        self.template.parent = self
                        self._children_name_map["template"] = "template"
                        self._segment_path = lambda: "source"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Source, [], name, value)


                    class Template(Entity):
                        """
                        Get config from a template
                        
                        .. attribute:: template_name
                        
                        	
                        	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Source.Template.TemplateName>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Source.Template, self).__init__()

                            self.yang_name = "template"
                            self.yang_parent_name = "source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.LISPSubinterface.LISP.Source.Template.TemplateName))])
                            self._leafs = OrderedDict()

                            self.template_name = YList(self)
                            self._segment_path = lambda: "template"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Source.Template, [], name, value)


                        class TemplateName(Entity):
                            """
                            
                            
                            .. attribute:: template_name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: merge
                            
                            	merge option of binding
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Source.Template.TemplateName, self).__init__()

                                self.yang_name = "template-name"
                                self.yang_parent_name = "template"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['template_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                    ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                                ])
                                self.template_name = None
                                self.merge = None
                                self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


                class Standby(Entity):
                    """
                    HSRP interface configuration commands
                    
                    .. attribute:: version
                    
                    	HSRP version
                    	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.Version>`
                    
                    .. attribute:: bfd
                    
                    	Enable HSRP BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: delay
                    
                    	HSRP initialisation delay
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.Delay>`
                    
                    .. attribute:: mac_refresh
                    
                    	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: use_bia
                    
                    	HSRP uses interface's burned in address
                    	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.UseBia>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: standby_list
                    
                    	
                    	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Standby, self).__init__()

                        self.yang_name = "standby"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.LISPSubinterface.LISP.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.LISPSubinterface.LISP.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.Standby.Version')])),
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                        ])
                        self.version = None
                        self.bfd = None
                        self.mac_refresh = None

                        self.delay = Native.Interface.LISPSubinterface.LISP.Standby.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"

                        self.use_bia = None
                        self._children_name_map["use_bia"] = "use-bia"

                        self.standby_list = YList(self)
                        self._segment_path = lambda: "standby"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                    class Version(Enum):
                        """
                        Version (Enum Class)

                        HSRP version

                        .. data:: Y_1 = 0

                        .. data:: Y_2 = 1

                        """

                        Y_1 = Enum.YLeaf(0, "1")

                        Y_2 = Enum.YLeaf(1, "2")



                    class Delay(Entity):
                        """
                        HSRP initialisation delay
                        
                        .. attribute:: minimum
                        
                        	Minimum delay
                        	**type**\: int
                        
                        	**range:** 0..10000
                        
                        .. attribute:: reload
                        
                        	Delay after reload
                        	**type**\: int
                        
                        	**range:** 0..10000
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Standby.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "standby"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                            ])
                            self.minimum = None
                            self.reload = None
                            self._segment_path = lambda: "delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.Delay, [u'minimum', u'reload'], name, value)


                    class UseBia(Entity):
                        """
                        HSRP uses interface's burned in address
                        
                        .. attribute:: scope
                        
                        	Specify the scope of use\-bia
                        	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.UseBia.Scope>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Standby.UseBia, self).__init__()

                            self.yang_name = "use-bia"
                            self.yang_parent_name = "standby"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.LISPSubinterface.LISP.Standby.UseBia.Scope))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.scope = Native.Interface.LISPSubinterface.LISP.Standby.UseBia.Scope()
                            self.scope.parent = self
                            self._children_name_map["scope"] = "scope"
                            self._segment_path = lambda: "use-bia"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.UseBia, [], name, value)


                        class Scope(Entity):
                            """
                            Specify the scope of use\-bia
                            
                            .. attribute:: interface
                            
                            	Use\-bia applies to all groups on this interface or sub\-interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Standby.UseBia.Scope, self).__init__()

                                self.yang_name = "scope"
                                self.yang_parent_name = "use-bia"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                                ])
                                self.interface = None
                                self._segment_path = lambda: "scope"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.UseBia.Scope, [u'interface'], name, value)


                    class StandbyList(Entity):
                        """
                        
                        
                        .. attribute:: group_number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: authentication
                        
                        	Authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication>`
                        
                        .. attribute:: follow
                        
                        	Name of HSRP group to follow
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	Enable HSRP and set the virtual IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Ip>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	Enable HSRP IPv6
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                        
                        .. attribute:: mac_address
                        
                        	Virtual MAC address
                        	**type**\: str
                        
                        .. attribute:: name
                        
                        	Redundancy name string
                        	**type**\: str
                        
                        .. attribute:: preempt
                        
                        	Overthrow lower priority Active routers
                        	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Preempt>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Priority level
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: redirect
                        
                        	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect>`
                        
                        .. attribute:: timers
                        
                        	Hello and hold timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers>`
                        
                        .. attribute:: track
                        
                        	Priority tracking
                        	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Track>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList, self).__init__()

                            self.yang_name = "standby-list"
                            self.yang_parent_name = "standby"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['group_number']
                            self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Track))])
                            self._leafs = OrderedDict([
                                ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                                ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.group_number = None
                            self.follow = None
                            self.ipv6 = None
                            self.mac_address = None
                            self.name = None
                            self.priority = None

                            self.authentication = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.ip = None
                            self._children_name_map["ip"] = "ip"

                            self.preempt = None
                            self._children_name_map["preempt"] = "preempt"

                            self.redirect = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"

                            self.timers = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"

                            self.track = YList(self)
                            self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                        class Ipv6(Enum):
                            """
                            Ipv6 (Enum Class)

                            Enable HSRP IPv6

                            .. data:: autoconfig = 0

                            """

                            autoconfig = Enum.YLeaf(0, "autoconfig")



                        class Authentication(Entity):
                            """
                            Authentication
                            
                            .. attribute:: word
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5>`
                            
                            .. attribute:: text
                            
                            	Plain text authentication
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                ])
                                self.word = None
                                self.text = None

                                self.md5 = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_chain
                                
                                	Set key chain
                                	**type**\: str
                                
                                .. attribute:: key_string
                                
                                	Set key string
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "authentication"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5.KeyString))])
                                    self._leafs = OrderedDict([
                                        ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ])
                                    self.key_chain = None

                                    self.key_string = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                                class KeyString(Entity):
                                    """
                                    Set key string
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: timeout
                                    
                                    	Set timeout
                                    	**type**\: int
                                    
                                    	**range:** 0..32767
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self.timeout = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                        class Ip(Entity):
                            """
                            Enable HSRP and set the virtual IP address
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	Make this IP address a secondary virtual IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.address = None
                                self.secondary = None
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                        class Preempt(Entity):
                            """
                            Overthrow lower priority Active routers
                            
                            .. attribute:: delay
                            
                            	Wait before preempting
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Preempt.Delay>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Preempt, self).__init__()

                                self.yang_name = "preempt"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Preempt.Delay))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.delay = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Preempt.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "preempt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Preempt, [], name, value)


                            class Delay(Entity):
                                """
                                Wait before preempting
                                
                                .. attribute:: minimum
                                
                                	Delay at least this long
                                	**type**\: int
                                
                                	**range:** 0..3600
                                
                                .. attribute:: reload
                                
                                	Delay after reload
                                	**type**\: int
                                
                                	**range:** 0..3600
                                
                                .. attribute:: sync
                                
                                	Wait for IP redundancy client
                                	**type**\: int
                                
                                	**range:** 0..3600
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Preempt.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "preempt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                        ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                    ])
                                    self.minimum = None
                                    self.reload = None
                                    self.sync = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                        class Redirect(Entity):
                            """
                            Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                            
                            .. attribute:: advertisement
                            
                            	Redirect advertisement messages
                            	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement>`
                            
                            .. attribute:: timers
                            
                            	Adjust redirect timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Timers>`
                            
                            .. attribute:: unknown
                            
                            	Redirect to non\-HSRP routers
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Timers))])
                                self._leafs = OrderedDict([
                                    ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                                ])
                                self.unknown = None

                                self.advertisement = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement()
                                self.advertisement.parent = self
                                self._children_name_map["advertisement"] = "advertisement"

                                self.timers = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                            class Advertisement(Entity):
                                """
                                Redirect advertisement messages
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                    self.yang_name = "advertisement"
                                    self.yang_parent_name = "redirect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                    self._leafs = OrderedDict()

                                    self.authentication = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._segment_path = lambda: "advertisement"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: md5
                                    
                                    	Use MD5 authentication
                                    	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "advertisement"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                        self._leafs = OrderedDict()

                                        self.md5 = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                        self.md5.parent = self
                                        self._children_name_map["md5"] = "md5"
                                        self._segment_path = lambda: "authentication"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                    class Md5(Entity):
                                        """
                                        Use MD5 authentication
                                        
                                        .. attribute:: key_chain
                                        
                                        	Set key chain
                                        	**type**\: str
                                        
                                        .. attribute:: key_string
                                        
                                        	Set key string
                                        	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                            self.yang_name = "md5"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                            self._leafs = OrderedDict([
                                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                            ])
                                            self.key_chain = None

                                            self.key_string = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                            self.key_string.parent = self
                                            self._children_name_map["key_string"] = "key-string"
                                            self._segment_path = lambda: "md5"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                        class KeyString(Entity):
                                            """
                                            Set key string
                                            
                                            .. attribute:: encrypt
                                            
                                            	
                                            	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                            
                                            .. attribute:: string
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: timeout
                                            
                                            	Set timeout
                                            	**type**\: int
                                            
                                            	**range:** 0..32767
                                            
                                            

                                            """

                                            _prefix = 'ios'
                                            _revision = '2018-05-22'

                                            def __init__(self):
                                                super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                                self.yang_name = "key-string"
                                                self.yang_parent_name = "md5"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                    ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                                ])
                                                self.encrypt = None
                                                self.string = None
                                                self.timeout = None
                                                self._segment_path = lambda: "key-string"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                            class Encrypt(Enum):
                                                """
                                                Encrypt (Enum Class)

                                                .. data:: Y_0 = 0

                                                .. data:: Y_7 = 1

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")

                                                Y_7 = Enum.YLeaf(1, "7")



                            class Timers(Entity):
                                """
                                Adjust redirect timers
                                
                                .. attribute:: advertisement
                                
                                	
                                	**type**\: int
                                
                                	**range:** 10..180
                                
                                .. attribute:: holddown
                                
                                	
                                	**type**\: int
                                
                                	**range:** 30..3600
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "redirect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                        ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                    ])
                                    self.advertisement = None
                                    self.holddown = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                        class Timers(Entity):
                            """
                            Hello and hold timers
                            
                            .. attribute:: hello_interval
                            
                            	
                            	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers.HelloInterval>`
                            
                            .. attribute:: hold_time
                            
                            	
                            	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers.HoldTime>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers.HoldTime))])
                                self._leafs = OrderedDict()

                                self.hello_interval = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers.HelloInterval()
                                self.hello_interval.parent = self
                                self._children_name_map["hello_interval"] = "hello-interval"

                                self.hold_time = Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers.HoldTime()
                                self.hold_time.parent = self
                                self._children_name_map["hold_time"] = "hold-time"
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers, [], name, value)


                            class HelloInterval(Entity):
                                """
                                
                                
                                .. attribute:: seconds
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: msec
                                
                                	Specify hello interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 15..999
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                    self.yang_name = "hello-interval"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.msec = None
                                    self._segment_path = lambda: "hello-interval"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                            class HoldTime(Entity):
                                """
                                
                                
                                .. attribute:: seconds
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: msec
                                
                                	Specify hold time in milliseconds
                                	**type**\: int
                                
                                	**range:** 50..3000
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                    self.yang_name = "hold-time"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.msec = None
                                    self._segment_path = lambda: "hold-time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                        class Track(Entity):
                            """
                            Priority tracking
                            
                            .. attribute:: number  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: decrement
                            
                            	Priority decrement
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: shutdown
                            
                            	Shutdown group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Track, self).__init__()

                                self.yang_name = "track"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['number']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                    ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.number = None
                                self.decrement = None
                                self.shutdown = None
                                self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


                class AccessSession(Entity):
                    """
                    Access Session specific Interface Configuration Commands
                    
                    .. attribute:: closed
                    
                    	Enable closed access on port (disabled by default, i.e. open access)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: port_control
                    
                    	Set the port\-control value
                    	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.AccessSession.PortControl>`
                    
                    .. attribute:: control_direction
                    
                    	Set the control\-direction on the interface
                    	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.AccessSession.ControlDirection>`
                    
                    .. attribute:: host_mode
                    
                    	Set the Host mode for authentication on this interface
                    	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.AccessSession.HostMode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.AccessSession, self).__init__()

                        self.yang_name = "access-session"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.LISPSubinterface.LISP.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.LISPSubinterface.LISP.AccessSession.ControlDirection))])
                        self._leafs = OrderedDict([
                            ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                            ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.AccessSession.HostMode')])),
                        ])
                        self.closed = None
                        self.host_mode = None

                        self.port_control = Native.Interface.LISPSubinterface.LISP.AccessSession.PortControl()
                        self.port_control.parent = self
                        self._children_name_map["port_control"] = "port-control"

                        self.control_direction = Native.Interface.LISPSubinterface.LISP.AccessSession.ControlDirection()
                        self.control_direction.parent = self
                        self._children_name_map["control_direction"] = "control-direction"
                        self._segment_path = lambda: "access-session"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.AccessSession, [u'closed', u'host_mode'], name, value)

                    class HostMode(Enum):
                        """
                        HostMode (Enum Class)

                        Set the Host mode for authentication on this interface

                        .. data:: multi_auth = 0

                        .. data:: multi_domain = 1

                        .. data:: multi_host = 2

                        .. data:: single_host = 3

                        """

                        multi_auth = Enum.YLeaf(0, "multi-auth")

                        multi_domain = Enum.YLeaf(1, "multi-domain")

                        multi_host = Enum.YLeaf(2, "multi-host")

                        single_host = Enum.YLeaf(3, "single-host")



                    class PortControl(Entity):
                        """
                        Set the port\-control value
                        
                        .. attribute:: auto
                        
                        	PortState set to automatic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.AccessSession.PortControl, self).__init__()

                            self.yang_name = "port-control"
                            self.yang_parent_name = "access-session"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                            ])
                            self.auto = None
                            self._segment_path = lambda: "port-control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.AccessSession.PortControl, [u'auto'], name, value)


                    class ControlDirection(Entity):
                        """
                        Set the control\-direction on the interface
                        
                        .. attribute:: in_
                        
                        	Control inbound traffic only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.AccessSession.ControlDirection, self).__init__()

                            self.yang_name = "control-direction"
                            self.yang_parent_name = "access-session"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                            ])
                            self.in_ = None
                            self._segment_path = lambda: "control-direction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.AccessSession.ControlDirection, [u'in_'], name, value)


                class StormControl(Entity):
                    """
                    storm configuration
                    
                    .. attribute:: action
                    
                    	Action to take for storm..control;
                    	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Action>`
                    
                    .. attribute:: broadcast
                    
                    	Broadcast address storm control
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast>`
                    
                    .. attribute:: multicast
                    
                    	Multicast address storm control
                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Multicast>`
                    
                    .. attribute:: unicast
                    
                    	Unicast address storm control
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.StormControl, self).__init__()

                        self.yang_name = "storm-control"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("action", ("action", Native.Interface.LISPSubinterface.LISP.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.LISPSubinterface.LISP.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.LISPSubinterface.LISP.StormControl.Unicast))])
                        self._leafs = OrderedDict()

                        self.action = Native.Interface.LISPSubinterface.LISP.StormControl.Action()
                        self.action.parent = self
                        self._children_name_map["action"] = "action"

                        self.broadcast = Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"

                        self.multicast = Native.Interface.LISPSubinterface.LISP.StormControl.Multicast()
                        self.multicast.parent = self
                        self._children_name_map["multicast"] = "multicast"

                        self.unicast = Native.Interface.LISPSubinterface.LISP.StormControl.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "storm-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl, [], name, value)


                    class Action(Entity):
                        """
                        Action to take for storm..control;
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\: Decimal64
                        
                        	**range:** 0..100
                        
                        .. attribute:: shutdown
                        
                        	Shutdown this interface if a storm occurs
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trap
                        
                        	Send SNMP trap if a storm occurs
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.StormControl.Action, self).__init__()

                            self.yang_name = "action"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                            ])
                            self.level = None
                            self.shutdown = None
                            self.trap = None
                            self._segment_path = lambda: "action"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                    class Broadcast(Entity):
                        """
                        Broadcast address storm control
                        
                        .. attribute:: include
                        
                        	
                        	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Include>`
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("include", ("include", Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level))])
                            self._leafs = OrderedDict()

                            self.include = Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Include()
                            self.include.parent = self
                            self._children_name_map["include"] = "include"

                            self.level = Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level()
                            self.level.parent = self
                            self._children_name_map["level"] = "level"
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast, [], name, value)


                        class Include(Entity):
                            """
                            
                            
                            .. attribute:: multicast
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Include, self).__init__()

                                self.yang_name = "include"
                                self.yang_parent_name = "broadcast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ])
                                self.multicast = None
                                self._segment_path = lambda: "include"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Include, [u'multicast'], name, value)


                        class Level(Entity):
                            """
                            Set storm suppression level on this interface
                            
                            .. attribute:: threshold
                            
                            	Broadcast address storm control
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Threshold>`
                            
                            .. attribute:: bps
                            
                            	Enter suppression level in bits per second
                            	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Bps>`
                            
                            .. attribute:: pps
                            
                            	Enter suppression level in packets per second
                            	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Pps>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level, self).__init__()

                                self.yang_name = "level"
                                self.yang_parent_name = "broadcast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Pps))])
                                self._leafs = OrderedDict()

                                self.threshold = Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"

                                self.bps = Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Bps()
                                self.bps.parent = self
                                self._children_name_map["bps"] = "bps"

                                self.pps = Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Pps()
                                self.pps.parent = self
                                self._children_name_map["pps"] = "pps"
                                self._segment_path = lambda: "level"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level, [], name, value)


                            class Threshold(Entity):
                                """
                                Broadcast address storm control
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Bps(Entity):
                                """
                                Enter suppression level in bits per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Bps, self).__init__()

                                    self.yang_name = "bps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "bps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Pps(Entity):
                                """
                                Enter suppression level in packets per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Pps, self).__init__()

                                    self.yang_name = "pps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "pps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                    class Multicast(Entity):
                        """
                        Multicast address storm control
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.StormControl.Multicast, self).__init__()

                            self.yang_name = "multicast"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level", ("level", Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level))])
                            self._leafs = OrderedDict()

                            self.level = Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level()
                            self.level.parent = self
                            self._children_name_map["level"] = "level"
                            self._segment_path = lambda: "multicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Multicast, [], name, value)


                        class Level(Entity):
                            """
                            Set storm suppression level on this interface
                            
                            .. attribute:: threshold
                            
                            	Broadcast address storm control
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Threshold>`
                            
                            .. attribute:: bps
                            
                            	Enter suppression level in bits per second
                            	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Bps>`
                            
                            .. attribute:: pps
                            
                            	Enter suppression level in packets per second
                            	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Pps>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level, self).__init__()

                                self.yang_name = "level"
                                self.yang_parent_name = "multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Pps))])
                                self._leafs = OrderedDict()

                                self.threshold = Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"

                                self.bps = Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Bps()
                                self.bps.parent = self
                                self._children_name_map["bps"] = "bps"

                                self.pps = Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Pps()
                                self.pps.parent = self
                                self._children_name_map["pps"] = "pps"
                                self._segment_path = lambda: "level"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level, [], name, value)


                            class Threshold(Entity):
                                """
                                Broadcast address storm control
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Bps(Entity):
                                """
                                Enter suppression level in bits per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Bps, self).__init__()

                                    self.yang_name = "bps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "bps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Pps(Entity):
                                """
                                Enter suppression level in packets per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Pps, self).__init__()

                                    self.yang_name = "pps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "pps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                    class Unicast(Entity):
                        """
                        Unicast address storm control
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.StormControl.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level", ("level", Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level))])
                            self._leafs = OrderedDict()

                            self.level = Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level()
                            self.level.parent = self
                            self._children_name_map["level"] = "level"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Unicast, [], name, value)


                        class Level(Entity):
                            """
                            Set storm suppression level on this interface
                            
                            .. attribute:: threshold
                            
                            	Broadcast address storm control
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Threshold>`
                            
                            .. attribute:: bps
                            
                            	Enter suppression level in bits per second
                            	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Bps>`
                            
                            .. attribute:: pps
                            
                            	Enter suppression level in packets per second
                            	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Pps>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level, self).__init__()

                                self.yang_name = "level"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Pps))])
                                self._leafs = OrderedDict()

                                self.threshold = Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"

                                self.bps = Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Bps()
                                self.bps.parent = self
                                self._children_name_map["bps"] = "bps"

                                self.pps = Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Pps()
                                self.pps.parent = self
                                self._children_name_map["pps"] = "pps"
                                self._segment_path = lambda: "level"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level, [], name, value)


                            class Threshold(Entity):
                                """
                                Broadcast address storm control
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Bps(Entity):
                                """
                                Enter suppression level in bits per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Bps, self).__init__()

                                    self.yang_name = "bps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "bps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Pps(Entity):
                                """
                                Enter suppression level in packets per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Pps, self).__init__()

                                    self.yang_name = "pps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "pps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Trust(Entity):
                    """
                    Set trust value for the interface
                    
                    .. attribute:: device
                    
                    	trusted device class
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.LISPSubinterface.LISP.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        trusted device class

                        .. data:: cisco_phone = 0

                        .. data:: cts = 1

                        .. data:: ip_camera = 2

                        .. data:: media_player = 3

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")

                        cts = Enum.YLeaf(1, "cts")

                        ip_camera = Enum.YLeaf(2, "ip-camera")

                        media_player = Enum.YLeaf(3, "media-player")



                class PriorityQueue(Entity):
                    """
                    Configure priority scheduling
                    
                    .. attribute:: cos_map
                    
                    	Configure cos\-map for a queue
                    	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.PriorityQueue.CosMap>`
                    
                    .. attribute:: out
                    
                    	egress priority queue
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.PriorityQueue, self).__init__()

                        self.yang_name = "priority-queue"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.LISPSubinterface.LISP.PriorityQueue.CosMap))])
                        self._leafs = OrderedDict([
                            ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ])
                        self.out = None

                        self.cos_map = Native.Interface.LISPSubinterface.LISP.PriorityQueue.CosMap()
                        self.cos_map.parent = self
                        self._children_name_map["cos_map"] = "cos-map"
                        self._segment_path = lambda: "priority-queue"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.PriorityQueue, [u'out'], name, value)


                    class CosMap(Entity):
                        """
                        Configure cos\-map for a queue
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: cos_values
                        
                        	
                        	**type**\: list of int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.PriorityQueue.CosMap, self).__init__()

                            self.yang_name = "cos-map"
                            self.yang_parent_name = "priority-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                            ])
                            self.id = None
                            self.cos_values = []
                            self._segment_path = lambda: "cos-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


                class RcvQueue(Entity):
                    """
                    Configure receive queue(s)
                    
                    .. attribute:: cos_map
                    
                    	Configure cos\-map for a queue threshold
                    	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.RcvQueue.CosMap>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.RcvQueue, self).__init__()

                        self.yang_name = "rcv-queue"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.LISPSubinterface.LISP.RcvQueue.CosMap))])
                        self._leafs = OrderedDict()

                        self.cos_map = YList(self)
                        self._segment_path = lambda: "rcv-queue"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.RcvQueue, [], name, value)


                    class CosMap(Entity):
                        """
                        Configure cos\-map for a queue threshold
                        
                        .. attribute:: queue_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: threshold_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8
                        
                        .. attribute:: cos_values
                        
                        	
                        	**type**\: list of int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.RcvQueue.CosMap, self).__init__()

                            self.yang_name = "cos-map"
                            self.yang_parent_name = "rcv-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['queue_id','threshold_id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                                ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                                ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                            ])
                            self.queue_id = None
                            self.threshold_id = None
                            self.cos_values = []
                            self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


                class Peer(Entity):
                    """
                    Peer parameters for point to point interfaces
                    
                    .. attribute:: default
                    
                    	Specify default parameters
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Peer.Default>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default", ("default", Native.Interface.LISPSubinterface.LISP.Peer.Default))])
                        self._leafs = OrderedDict()

                        self.default = Native.Interface.LISPSubinterface.LISP.Peer.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"
                        self._segment_path = lambda: "peer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Peer, [], name, value)


                    class Default(Entity):
                        """
                        Specify default parameters
                        
                        .. attribute:: ip
                        
                        	Specify default IP parameters
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.LISPSubinterface.LISP.Peer.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Peer.Default, [], name, value)


                        class Ip(Entity):
                            """
                            Specify default IP parameters
                            
                            .. attribute:: address
                            
                            	Specify default IP address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address))])
                                self._leafs = OrderedDict()

                                self.address = Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip, [], name, value)


                            class Address(Entity):
                                """
                                Specify default IP address
                                
                                .. attribute:: dhcp
                                
                                	Use DHCP proxy client mechanism to allocate a peer IP address
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: dhcp_pool
                                
                                	Use local DHCP pools to allocate a peer IP address
                                	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address.DhcpPool>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: pool
                                
                                	Use IP pool mechanism to allocate a peer IP address
                                	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address.Pool>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address.Pool))])
                                    self._leafs = OrderedDict([
                                        ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                    ])
                                    self.dhcp = None

                                    self.dhcp_pool = None
                                    self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                    self.pool = None
                                    self._children_name_map["pool"] = "pool"
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                                class DhcpPool(Entity):
                                    """
                                    Use local DHCP pools to allocate a peer IP address
                                    
                                    .. attribute:: pools
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                        self.yang_name = "dhcp-pool"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                        ])
                                        self.pools = None
                                        self._segment_path = lambda: "dhcp-pool"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                                class Pool(Entity):
                                    """
                                    Use IP pool mechanism to allocate a peer IP address
                                    
                                    .. attribute:: pools
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address.Pool, self).__init__()

                                        self.yang_name = "pool"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                        ])
                                        self.pools = None
                                        self._segment_path = lambda: "pool"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


                class PmPath(Entity):
                    """
                    Global pm\-path configuration
                    
                    .. attribute:: name
                    
                    	WORD Path name
                    	**type**\: str
                    
                    .. attribute:: interface_id
                    
                    	<1\-255> Specify the interface\-id value
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.LISPSubinterface.LISP.PmPath, self).__init__()

                        self.yang_name = "pm-path"
                        self.yang_parent_name = "LISP"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                        ])
                        self.name = None
                        self.interface_id = None
                        self._segment_path = lambda: "pm-path"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.LISPSubinterface.LISP.PmPath, [u'name', u'interface_id'], name, value)


        class Nve(Entity):
            """
            Network virtualization endpoint interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..4096
            
            .. attribute:: group_based
            
            	group based policy mode
            	**type**\:  :py:class:`GroupBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.GroupBased>`
            
            .. attribute:: host_reachability
            
            	
            	**type**\:  :py:class:`HostReachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.HostReachability>`
            
            .. attribute:: vxlan
            
            	
            	**type**\:  :py:class:`Vxlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Vxlan>`
            
            .. attribute:: source_interface
            
            	Specify source interface for NVE
            	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.SourceInterface>`
            
            .. attribute:: member_in_one_line
            
            	
            	**type**\:  :py:class:`MemberInOneLine <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.MemberInOneLine>`
            
            .. attribute:: member
            
            	
            	**type**\:  :py:class:`Member <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Member>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.PmPath>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Nve, self).__init__()

                self.yang_name = "nve"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("group-based", ("group_based", Native.Interface.Nve.GroupBased)), ("host-reachability", ("host_reachability", Native.Interface.Nve.HostReachability)), ("vxlan", ("vxlan", Native.Interface.Nve.Vxlan)), ("source-interface", ("source_interface", Native.Interface.Nve.SourceInterface)), ("member-in-one-line", ("member_in_one_line", Native.Interface.Nve.MemberInOneLine)), ("member", ("member", Native.Interface.Nve.Member)), ("switchport-conf", ("switchport_conf", Native.Interface.Nve.SwitchportConf)), ("switchport", ("switchport", Native.Interface.Nve.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.Nve.StackwiseVirtual)), ("arp", ("arp", Native.Interface.Nve.Arp)), ("backup", ("backup", Native.Interface.Nve.Backup)), ("cemoudp", ("cemoudp", Native.Interface.Nve.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.Nve.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.Nve.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.Nve.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.Nve.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.Nve.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.Nve.Flowcontrol)), ("isis", ("isis", Native.Interface.Nve.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.Nve.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.Nve.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.Nve.Bandwidth)), ("dampening", ("dampening", Native.Interface.Nve.Dampening)), ("domain", ("domain", Native.Interface.Nve.Domain)), ("hold-queue", ("hold_queue", Native.Interface.Nve.HoldQueue)), ("mpls", ("mpls", Native.Interface.Nve.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.Nve.IpVrf)), ("vrf", ("vrf", Native.Interface.Nve.Vrf)), ("ip", ("ip", Native.Interface.Nve.Ip)), ("ipv6", ("ipv6", Native.Interface.Nve.Ipv6)), ("logging", ("logging", Native.Interface.Nve.Logging)), ("mdix", ("mdix", Native.Interface.Nve.Mdix)), ("mop", ("mop", Native.Interface.Nve.Mop)), ("interface_qos", ("interface_qos", Native.Interface.Nve.InterfaceQos)), ("source", ("source", Native.Interface.Nve.Source)), ("standby", ("standby", Native.Interface.Nve.Standby)), ("access-session", ("access_session", Native.Interface.Nve.AccessSession)), ("storm-control", ("storm_control", Native.Interface.Nve.StormControl)), ("trust", ("trust", Native.Interface.Nve.Trust)), ("priority-queue", ("priority_queue", Native.Interface.Nve.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.Nve.RcvQueue)), ("peer", ("peer", Native.Interface.Nve.Peer)), ("pm-path", ("pm_path", Native.Interface.Nve.PmPath))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.group_based = Native.Interface.Nve.GroupBased()
                self.group_based.parent = self
                self._children_name_map["group_based"] = "group-based"

                self.host_reachability = Native.Interface.Nve.HostReachability()
                self.host_reachability.parent = self
                self._children_name_map["host_reachability"] = "host-reachability"

                self.vxlan = Native.Interface.Nve.Vxlan()
                self.vxlan.parent = self
                self._children_name_map["vxlan"] = "vxlan"

                self.source_interface = Native.Interface.Nve.SourceInterface()
                self.source_interface.parent = self
                self._children_name_map["source_interface"] = "source-interface"

                self.member_in_one_line = Native.Interface.Nve.MemberInOneLine()
                self.member_in_one_line.parent = self
                self._children_name_map["member_in_one_line"] = "member-in-one-line"

                self.member = Native.Interface.Nve.Member()
                self.member.parent = self
                self._children_name_map["member"] = "member"

                self.switchport_conf = Native.Interface.Nve.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.Nve.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.Nve.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.Nve.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.Nve.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.Nve.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.Nve.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.Nve.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.Nve.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.Nve.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.Nve.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.Nve.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.Nve.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.Nve.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.Nve.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.Nve.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.Nve.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.Nve.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.Nve.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.Nve.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.Nve.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.Nve.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.Nve.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.Nve.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.Nve.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.Nve.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.Nve.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.Nve.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.Nve.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.Nve.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.Nve.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.Nve.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.Nve.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.Nve.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.Nve.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "nve" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Nve, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class GroupBased(Entity):
                """
                group based policy mode
                
                .. attribute:: policy
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.GroupBased, self).__init__()

                    self.yang_name = "group-based"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('policy', (YLeaf(YType.empty, 'policy'), ['Empty'])),
                    ])
                    self.policy = None
                    self._segment_path = lambda: "group-based"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.GroupBased, [u'policy'], name, value)


            class HostReachability(Entity):
                """
                
                
                .. attribute:: protocol
                
                	
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.HostReachability.Protocol>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.HostReachability, self).__init__()

                    self.yang_name = "host-reachability"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("protocol", ("protocol", Native.Interface.Nve.HostReachability.Protocol))])
                    self._leafs = OrderedDict()

                    self.protocol = Native.Interface.Nve.HostReachability.Protocol()
                    self.protocol.parent = self
                    self._children_name_map["protocol"] = "protocol"
                    self._segment_path = lambda: "host-reachability"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.HostReachability, [], name, value)


                class Protocol(Entity):
                    """
                    
                    
                    .. attribute:: bgp
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.HostReachability.Protocol, self).__init__()

                        self.yang_name = "protocol"
                        self.yang_parent_name = "host-reachability"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                        ])
                        self.bgp = None
                        self._segment_path = lambda: "protocol"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.HostReachability.Protocol, [u'bgp'], name, value)


            class Vxlan(Entity):
                """
                
                
                .. attribute:: udp
                
                	
                	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Vxlan.Udp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Vxlan, self).__init__()

                    self.yang_name = "vxlan"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.Nve.Vxlan.Udp))])
                    self._leafs = OrderedDict()

                    self.udp = Native.Interface.Nve.Vxlan.Udp()
                    self.udp.parent = self
                    self._children_name_map["udp"] = "udp"
                    self._segment_path = lambda: "vxlan"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Vxlan, [], name, value)


                class Udp(Entity):
                    """
                    
                    
                    .. attribute:: port
                    
                    	VxLAN dataplane UDP destination port for this NVE interface
                    	**type**\: int
                    
                    	**range:** 1024..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Vxlan.Udp, self).__init__()

                        self.yang_name = "udp"
                        self.yang_parent_name = "vxlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                        ])
                        self.port = None
                        self._segment_path = lambda: "udp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Vxlan.Udp, [u'port'], name, value)


            class SourceInterface(Entity):
                """
                Specify source interface for NVE
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.SourceInterface.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.SourceInterface.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.SourceInterface.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.SourceInterface.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.SourceInterface, self).__init__()

                    self.yang_name = "source-interface"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Nve.SourceInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Nve.SourceInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Nve.SourceInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Nve.SourceInterface.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.Interface.Nve.SourceInterface.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.Interface.Nve.SourceInterface.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.Interface.Nve.SourceInterface.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.Interface.Nve.SourceInterface.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "source-interface"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.SourceInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.SourceInterface.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.SourceInterface.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.SourceInterface.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.SourceInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.SourceInterface.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.SourceInterface.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.SourceInterface.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "source-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.SourceInterface.PortChannelSubinterface, [u'port_channel'], name, value)


            class MemberInOneLine(Entity):
                """
                
                
                .. attribute:: member
                
                	
                	**type**\:  :py:class:`Member <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.MemberInOneLine.Member>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.MemberInOneLine, self).__init__()

                    self.yang_name = "member-in-one-line"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("member", ("member", Native.Interface.Nve.MemberInOneLine.Member))])
                    self._leafs = OrderedDict()

                    self.member = Native.Interface.Nve.MemberInOneLine.Member()
                    self.member.parent = self
                    self._children_name_map["member"] = "member"
                    self._segment_path = lambda: "member-in-one-line"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.MemberInOneLine, [], name, value)


                class Member(Entity):
                    """
                    
                    
                    .. attribute:: vni
                    
                    	Configure VNI information
                    	**type**\: list of  		 :py:class:`Vni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.MemberInOneLine.Member.Vni>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.MemberInOneLine.Member, self).__init__()

                        self.yang_name = "member"
                        self.yang_parent_name = "member-in-one-line"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vni", ("vni", Native.Interface.Nve.MemberInOneLine.Member.Vni))])
                        self._leafs = OrderedDict()

                        self.vni = YList(self)
                        self._segment_path = lambda: "member"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.MemberInOneLine.Member, [], name, value)


                    class Vni(Entity):
                        """
                        Configure VNI information
                        
                        .. attribute:: vni_range  (key)
                        
                        	VNI range or instance between 4096\-16777215, example\: 6010\-6030 or 7115
                        	**type**\: str
                        
                        .. attribute:: vrf
                        
                        	Specify a particular VRF
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.MemberInOneLine.Member.Vni, self).__init__()

                            self.yang_name = "vni"
                            self.yang_parent_name = "member"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['vni_range']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vni_range', (YLeaf(YType.str, 'vni-range'), ['str'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.vni_range = None
                            self.vrf = None
                            self._segment_path = lambda: "vni" + "[vni-range='" + str(self.vni_range) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.MemberInOneLine.Member.Vni, [u'vni_range', u'vrf'], name, value)


            class Member(Entity):
                """
                
                
                .. attribute:: vni
                
                	Configure VNI information
                	**type**\: list of  		 :py:class:`Vni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Member.Vni>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Member, self).__init__()

                    self.yang_name = "member"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vni", ("vni", Native.Interface.Nve.Member.Vni))])
                    self._leafs = OrderedDict()

                    self.vni = YList(self)
                    self._segment_path = lambda: "member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Member, [], name, value)


                class Vni(Entity):
                    """
                    Configure VNI information
                    
                    .. attribute:: vni_range  (key)
                    
                    	VNI range or instance between 4096\-16777215, example\: 6010\-6030 or 7115
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Member.Vni.Default>`
                    
                    .. attribute:: ingress_replication
                    
                    	Ingress Replication or Unicast mode for vni(s)
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mcast_group
                    
                    	
                    	**type**\:  :py:class:`McastGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Member.Vni.McastGroup>`
                    
                    .. attribute:: no
                    
                    	
                    	**type**\:  :py:class:`No <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Member.Vni.No>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Member.Vni, self).__init__()

                        self.yang_name = "vni"
                        self.yang_parent_name = "member"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vni_range']
                        self._child_classes = OrderedDict([("default", ("default", Native.Interface.Nve.Member.Vni.Default)), ("mcast-group", ("mcast_group", Native.Interface.Nve.Member.Vni.McastGroup)), ("no", ("no", Native.Interface.Nve.Member.Vni.No))])
                        self._leafs = OrderedDict([
                            ('vni_range', (YLeaf(YType.str, 'vni-range'), ['str'])),
                            ('ingress_replication', (YLeaf(YType.str, 'ingress-replication'), ['str'])),
                        ])
                        self.vni_range = None
                        self.ingress_replication = None

                        self.default = Native.Interface.Nve.Member.Vni.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.mcast_group = Native.Interface.Nve.Member.Vni.McastGroup()
                        self.mcast_group.parent = self
                        self._children_name_map["mcast_group"] = "mcast-group"

                        self.no = Native.Interface.Nve.Member.Vni.No()
                        self.no.parent = self
                        self._children_name_map["no"] = "no"
                        self._segment_path = lambda: "vni" + "[vni-range='" + str(self.vni_range) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Member.Vni, [u'vni_range', u'ingress_replication'], name, value)


                    class Default(Entity):
                        """
                        
                        
                        .. attribute:: ingress_replication
                        
                        	Ingress Replication or Unicast mode for vni(s)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mcast_group
                        
                        	
                        	**type**\:  :py:class:`McastGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Member.Vni.Default.McastGroup>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Member.Vni.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "vni"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mcast-group", ("mcast_group", Native.Interface.Nve.Member.Vni.Default.McastGroup))])
                            self._leafs = OrderedDict([
                                ('ingress_replication', (YLeaf(YType.str, 'ingress-replication'), ['str'])),
                            ])
                            self.ingress_replication = None

                            self.mcast_group = Native.Interface.Nve.Member.Vni.Default.McastGroup()
                            self.mcast_group.parent = self
                            self._children_name_map["mcast_group"] = "mcast-group"
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Member.Vni.Default, [u'ingress_replication'], name, value)


                        class McastGroup(Entity):
                            """
                            
                            
                            .. attribute:: multicast_group_min
                            
                            	Starting Multicast Group IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: multicast_group_max
                            
                            	Ending Multicast Group IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Member.Vni.Default.McastGroup, self).__init__()

                                self.yang_name = "mcast-group"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('multicast_group_min', (YLeaf(YType.str, 'multicast-group-min'), ['str'])),
                                    ('multicast_group_max', (YLeaf(YType.str, 'multicast-group-max'), ['str'])),
                                ])
                                self.multicast_group_min = None
                                self.multicast_group_max = None
                                self._segment_path = lambda: "mcast-group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Member.Vni.Default.McastGroup, [u'multicast_group_min', u'multicast_group_max'], name, value)


                    class McastGroup(Entity):
                        """
                        
                        
                        .. attribute:: multicast_group_min
                        
                        	Starting Multicast Group IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: multicast_group_max
                        
                        	Ending Multicast Group IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Member.Vni.McastGroup, self).__init__()

                            self.yang_name = "mcast-group"
                            self.yang_parent_name = "vni"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast_group_min', (YLeaf(YType.str, 'multicast-group-min'), ['str'])),
                                ('multicast_group_max', (YLeaf(YType.str, 'multicast-group-max'), ['str'])),
                            ])
                            self.multicast_group_min = None
                            self.multicast_group_max = None
                            self._segment_path = lambda: "mcast-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Member.Vni.McastGroup, [u'multicast_group_min', u'multicast_group_max'], name, value)


                    class No(Entity):
                        """
                        
                        
                        .. attribute:: ingress_replication
                        
                        	Ingress Replication or Unicast mode for vni(s)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mcast_group
                        
                        	
                        	**type**\:  :py:class:`McastGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Member.Vni.No.McastGroup>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Member.Vni.No, self).__init__()

                            self.yang_name = "no"
                            self.yang_parent_name = "vni"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mcast-group", ("mcast_group", Native.Interface.Nve.Member.Vni.No.McastGroup))])
                            self._leafs = OrderedDict([
                                ('ingress_replication', (YLeaf(YType.str, 'ingress-replication'), ['str'])),
                            ])
                            self.ingress_replication = None

                            self.mcast_group = Native.Interface.Nve.Member.Vni.No.McastGroup()
                            self.mcast_group.parent = self
                            self._children_name_map["mcast_group"] = "mcast-group"
                            self._segment_path = lambda: "no"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Member.Vni.No, [u'ingress_replication'], name, value)


                        class McastGroup(Entity):
                            """
                            
                            
                            .. attribute:: multicast_group_min
                            
                            	Starting Multicast Group IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: multicast_group_max
                            
                            	Ending Multicast Group IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Member.Vni.No.McastGroup, self).__init__()

                                self.yang_name = "mcast-group"
                                self.yang_parent_name = "no"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('multicast_group_min', (YLeaf(YType.str, 'multicast-group-min'), ['str'])),
                                    ('multicast_group_max', (YLeaf(YType.str, 'multicast-group-max'), ['str'])),
                                ])
                                self.multicast_group_min = None
                                self.multicast_group_max = None
                                self._segment_path = lambda: "mcast-group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Member.Vni.No.McastGroup, [u'multicast_group_min', u'multicast_group_max'], name, value)


            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Nve.Backup.Delay)), ("interface", ("interface", Native.Interface.Nve.Backup.Interface_)), ("load", ("load", Native.Interface.Nve.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Nve.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Nve.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Nve.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Nve.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Nve.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Nve.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Nve.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Nve.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Nve.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Nve.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Nve.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Nve.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Nve.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Nve.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Nve.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Nve.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Nve.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Nve.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Nve.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Nve.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Nve.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Nve.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.Nve.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Nve.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Nve.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Nve.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Nve.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Nve.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Nve.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Nve.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Nve.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Nve.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Nve.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Nve.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Nve.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Nve.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Nve.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.Nve.Ip.Arp)), ("vrf", ("vrf", Native.Interface.Nve.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.Nve.Ip.NoAddress)), ("address", ("address", Native.Interface.Nve.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Nve.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Nve.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.Nve.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.Nve.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Nve.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.Nve.Ip.Pim)), ("policy", ("policy", Native.Interface.Nve.Ip.Policy)), ("rip", ("rip", Native.Interface.Nve.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Nve.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Nve.Ip.RouteCache)), ("router", ("router", Native.Interface.Nve.Ip.Router)), ("tcp", ("tcp", Native.Interface.Nve.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Nve.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Nve.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Nve.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.Nve.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.Nve.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Nve.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Nve.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Nve.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Nve.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Nve.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Nve.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Nve.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Nve.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Nve.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Nve.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Nve.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Nve.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Nve.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Nve.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Nve.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Nve.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Nve.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Nve.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.Nve.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Nve.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Nve.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Nve.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Nve.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Nve.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Nve.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Nve.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Nve.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Nve.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Nve.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Nve.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Nve.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Nve.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Nve.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Nve.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Nve.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Nve.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.Nve.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Nve.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Nve.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Nve.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Nve.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Nve.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Nve.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Nve.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Nve.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Nve.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Nve.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Nve.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Nve.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Nve.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Nve.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Nve.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.Nve.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Nve.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Nve.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Nve.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Nve.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Nve.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Nve.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Nve.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Nve.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Nve.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Nve.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Nve.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Nve.Ipv6.Dhcp)), ("address", ("address", Native.Interface.Nve.Ipv6.Address)), ("nd", ("nd", Native.Interface.Nve.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.Nve.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Nve.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Nve.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Nve.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Nve.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Nve.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Nve.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Nve.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Nve.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Nve.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Nve.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Nve.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Nve.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Nve.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Nve.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Nve.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Nve.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Nve.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Nve.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Nve.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.Nve.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Nve.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Nve.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Nve.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Nve.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Nve.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Nve.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Nve.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Nve.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Nve.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.Nve.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Nve.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Nve.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Nve.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Nve.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Nve.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Nve.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Nve.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Nve.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Nve.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Nve.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Nve.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Nve.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Nve.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Nve.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Nve.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Nve.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Nve.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Nve.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Nve.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Nve.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Nve.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Nve.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Nve.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Nve.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Nve.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Nve.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Nve.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Nve.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Nve.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Nve.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Nve.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Nve.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Nve.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Nve.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Nve.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Nve.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Nve.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Nve.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Nve.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Nve.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Nve.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Nve.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Nve.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Nve.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Nve.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Nve.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Nve.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Nve.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Nve.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Nve.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Nve.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Nve.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Nve.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Nve.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Nve.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Nve.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Nve.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Nve.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Nve.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Nve.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Nve.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Nve.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Nve.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Nve.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Nve.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Nve.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Nve.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Nve.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Nve.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Nve.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Nve.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Nve.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Nve.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Nve.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Nve.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Nve.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Nve.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Nve.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Nve.PmPath, [u'name', u'interface_id'], name, value)


        class Overlay(Entity):
            """
            Overlay interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..512
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service>`
            
            .. attribute:: otv
            
            	Configure OTV information
            	**type**\:  :py:class:`Otv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Overlay, self).__init__()

                self.yang_name = "overlay"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("Cisco-IOS-XE-otv:switchport-conf", ("switchport_conf", Native.Interface.Overlay.SwitchportConf)), ("Cisco-IOS-XE-otv:switchport", ("switchport", Native.Interface.Overlay.Switchport)), ("Cisco-IOS-XE-otv:stackwise-virtual", ("stackwise_virtual", Native.Interface.Overlay.StackwiseVirtual)), ("Cisco-IOS-XE-otv:arp", ("arp", Native.Interface.Overlay.Arp)), ("Cisco-IOS-XE-otv:backup", ("backup", Native.Interface.Overlay.Backup)), ("Cisco-IOS-XE-otv:cemoudp", ("cemoudp", Native.Interface.Overlay.Cemoudp)), ("Cisco-IOS-XE-otv:cws-tunnel", ("cws_tunnel", Native.Interface.Overlay.CwsTunnel)), ("Cisco-IOS-XE-otv:l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.Overlay.L2protocolTunnel)), ("Cisco-IOS-XE-otv:encapsulation", ("encapsulation", Native.Interface.Overlay.Encapsulation)), ("Cisco-IOS-XE-otv:fair-queue-conf", ("fair_queue_conf", Native.Interface.Overlay.FairQueueConf)), ("Cisco-IOS-XE-otv:fair-queue", ("fair_queue", Native.Interface.Overlay.FairQueue)), ("Cisco-IOS-XE-otv:flowcontrol", ("flowcontrol", Native.Interface.Overlay.Flowcontrol)), ("Cisco-IOS-XE-otv:isis", ("isis", Native.Interface.Overlay.Isis)), ("Cisco-IOS-XE-otv:keepalive-settings", ("keepalive_settings", Native.Interface.Overlay.KeepaliveSettings)), ("Cisco-IOS-XE-otv:bfd", ("bfd", Native.Interface.Overlay.Bfd)), ("Cisco-IOS-XE-otv:bandwidth", ("bandwidth", Native.Interface.Overlay.Bandwidth)), ("Cisco-IOS-XE-otv:dampening", ("dampening", Native.Interface.Overlay.Dampening)), ("Cisco-IOS-XE-otv:domain", ("domain", Native.Interface.Overlay.Domain)), ("Cisco-IOS-XE-otv:hold-queue", ("hold_queue", Native.Interface.Overlay.HoldQueue)), ("Cisco-IOS-XE-otv:mpls", ("mpls", Native.Interface.Overlay.Mpls)), ("Cisco-IOS-XE-otv:ip-vrf", ("ip_vrf", Native.Interface.Overlay.IpVrf)), ("Cisco-IOS-XE-otv:vrf", ("vrf", Native.Interface.Overlay.Vrf)), ("Cisco-IOS-XE-otv:ip", ("ip", Native.Interface.Overlay.Ip)), ("Cisco-IOS-XE-otv:ipv6", ("ipv6", Native.Interface.Overlay.Ipv6)), ("Cisco-IOS-XE-otv:logging", ("logging", Native.Interface.Overlay.Logging)), ("Cisco-IOS-XE-otv:mdix", ("mdix", Native.Interface.Overlay.Mdix)), ("Cisco-IOS-XE-otv:mop", ("mop", Native.Interface.Overlay.Mop)), ("Cisco-IOS-XE-otv:interface_qos", ("interface_qos", Native.Interface.Overlay.InterfaceQos)), ("Cisco-IOS-XE-otv:source", ("source", Native.Interface.Overlay.Source)), ("Cisco-IOS-XE-otv:standby", ("standby", Native.Interface.Overlay.Standby)), ("Cisco-IOS-XE-otv:access-session", ("access_session", Native.Interface.Overlay.AccessSession)), ("Cisco-IOS-XE-otv:storm-control", ("storm_control", Native.Interface.Overlay.StormControl)), ("Cisco-IOS-XE-otv:trust", ("trust", Native.Interface.Overlay.Trust)), ("Cisco-IOS-XE-otv:priority-queue", ("priority_queue", Native.Interface.Overlay.PriorityQueue)), ("Cisco-IOS-XE-otv:rcv-queue", ("rcv_queue", Native.Interface.Overlay.RcvQueue)), ("Cisco-IOS-XE-otv:peer", ("peer", Native.Interface.Overlay.Peer)), ("Cisco-IOS-XE-otv:pm-path", ("pm_path", Native.Interface.Overlay.PmPath)), ("Cisco-IOS-XE-otv:carrier-delay", ("carrier_delay", Native.Interface.Overlay.CarrierDelay)), ("Cisco-IOS-XE-otv:channel-group", ("channel_group", Native.Interface.Overlay.ChannelGroup)), ("Cisco-IOS-XE-otv:ethernet", ("ethernet", Native.Interface.Overlay.Ethernet)), ("Cisco-IOS-XE-otv:eapol", ("eapol", Native.Interface.Overlay.Eapol)), ("Cisco-IOS-XE-otv:synchronous", ("synchronous", Native.Interface.Overlay.Synchronous)), ("Cisco-IOS-XE-otv:speed", ("speed", Native.Interface.Overlay.Speed)), ("Cisco-IOS-XE-otv:negotiation", ("negotiation", Native.Interface.Overlay.Negotiation)), ("Cisco-IOS-XE-otv:plim", ("plim", Native.Interface.Overlay.Plim)), ("Cisco-IOS-XE-otv:pppoe", ("pppoe", Native.Interface.Overlay.Pppoe)), ("Cisco-IOS-XE-otv:service", ("service", Native.Interface.Overlay.Service)), ("Cisco-IOS-XE-otv:otv", ("otv", Native.Interface.Overlay.Otv))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Duplex')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None

                self.switchport_conf = Native.Interface.Overlay.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "Cisco-IOS-XE-otv:switchport-conf"

                self.switchport = Native.Interface.Overlay.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "Cisco-IOS-XE-otv:switchport"

                self.stackwise_virtual = Native.Interface.Overlay.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "Cisco-IOS-XE-otv:stackwise-virtual"

                self.arp = Native.Interface.Overlay.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "Cisco-IOS-XE-otv:arp"

                self.backup = Native.Interface.Overlay.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "Cisco-IOS-XE-otv:backup"

                self.cemoudp = Native.Interface.Overlay.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "Cisco-IOS-XE-otv:cemoudp"

                self.cws_tunnel = Native.Interface.Overlay.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "Cisco-IOS-XE-otv:cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "Cisco-IOS-XE-otv:l2protocol-tunnel"

                self.encapsulation = Native.Interface.Overlay.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "Cisco-IOS-XE-otv:encapsulation"

                self.fair_queue_conf = Native.Interface.Overlay.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "Cisco-IOS-XE-otv:fair-queue-conf"

                self.fair_queue = Native.Interface.Overlay.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "Cisco-IOS-XE-otv:fair-queue"

                self.flowcontrol = Native.Interface.Overlay.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "Cisco-IOS-XE-otv:flowcontrol"

                self.isis = Native.Interface.Overlay.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "Cisco-IOS-XE-otv:isis"

                self.keepalive_settings = Native.Interface.Overlay.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "Cisco-IOS-XE-otv:keepalive-settings"

                self.bfd = Native.Interface.Overlay.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "Cisco-IOS-XE-otv:bfd"

                self.bandwidth = Native.Interface.Overlay.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "Cisco-IOS-XE-otv:bandwidth"

                self.dampening = Native.Interface.Overlay.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "Cisco-IOS-XE-otv:dampening"

                self.domain = Native.Interface.Overlay.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "Cisco-IOS-XE-otv:domain"

                self.mpls = Native.Interface.Overlay.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "Cisco-IOS-XE-otv:mpls"

                self.ip_vrf = Native.Interface.Overlay.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "Cisco-IOS-XE-otv:ip-vrf"

                self.vrf = Native.Interface.Overlay.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "Cisco-IOS-XE-otv:vrf"

                self.ip = Native.Interface.Overlay.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "Cisco-IOS-XE-otv:ip"

                self.ipv6 = Native.Interface.Overlay.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "Cisco-IOS-XE-otv:ipv6"

                self.logging = Native.Interface.Overlay.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "Cisco-IOS-XE-otv:logging"

                self.mdix = Native.Interface.Overlay.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "Cisco-IOS-XE-otv:mdix"

                self.mop = Native.Interface.Overlay.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "Cisco-IOS-XE-otv:mop"

                self.interface_qos = Native.Interface.Overlay.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "Cisco-IOS-XE-otv:interface_qos"

                self.source = Native.Interface.Overlay.Source()
                self.source.parent = self
                self._children_name_map["source"] = "Cisco-IOS-XE-otv:source"

                self.standby = Native.Interface.Overlay.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "Cisco-IOS-XE-otv:standby"

                self.access_session = Native.Interface.Overlay.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "Cisco-IOS-XE-otv:access-session"

                self.storm_control = Native.Interface.Overlay.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "Cisco-IOS-XE-otv:storm-control"

                self.trust = Native.Interface.Overlay.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "Cisco-IOS-XE-otv:trust"

                self.priority_queue = Native.Interface.Overlay.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "Cisco-IOS-XE-otv:priority-queue"

                self.rcv_queue = Native.Interface.Overlay.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "Cisco-IOS-XE-otv:rcv-queue"

                self.peer = Native.Interface.Overlay.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "Cisco-IOS-XE-otv:peer"

                self.pm_path = Native.Interface.Overlay.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "Cisco-IOS-XE-otv:pm-path"

                self.carrier_delay = Native.Interface.Overlay.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-otv:carrier-delay"

                self.channel_group = Native.Interface.Overlay.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-otv:channel-group"

                self.ethernet = Native.Interface.Overlay.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-otv:ethernet"

                self.eapol = Native.Interface.Overlay.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-otv:eapol"

                self.synchronous = Native.Interface.Overlay.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-otv:synchronous"

                self.speed = Native.Interface.Overlay.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-otv:speed"

                self.negotiation = Native.Interface.Overlay.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-otv:negotiation"

                self.plim = Native.Interface.Overlay.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-otv:plim"

                self.pppoe = Native.Interface.Overlay.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-otv:pppoe"

                self.service = Native.Interface.Overlay.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-otv:service"

                self.otv = Native.Interface.Overlay.Otv()
                self.otv.parent = self
                self._children_name_map["otv"] = "Cisco-IOS-XE-otv:otv"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "overlay" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Overlay, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Backup.Load>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Overlay.Backup.Delay)), ("interface", ("interface", Native.Interface.Overlay.Backup.Interface_)), ("load", ("load", Native.Interface.Overlay.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Overlay.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Overlay.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Overlay.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Overlay.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Overlay.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Overlay.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Overlay.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Overlay.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Overlay.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Overlay.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Overlay.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Overlay.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Overlay.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Overlay.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Overlay.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Overlay.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Overlay.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Overlay.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Overlay.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Overlay.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Overlay.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Overlay.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.Overlay.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Overlay.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Overlay.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Overlay.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Overlay.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Overlay.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Overlay.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Overlay.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Dampening.Restart>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Overlay.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Overlay.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Overlay.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Overlay.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Overlay.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Overlay.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Verify>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Overlay.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.Overlay.Ip.Arp)), ("vrf", ("vrf", Native.Interface.Overlay.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.Overlay.Ip.NoAddress)), ("address", ("address", Native.Interface.Overlay.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Overlay.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Overlay.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.Overlay.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.Overlay.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Overlay.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.Overlay.Ip.Pim)), ("policy", ("policy", Native.Interface.Overlay.Ip.Policy)), ("rip", ("rip", Native.Interface.Overlay.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Overlay.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Overlay.Ip.RouteCache)), ("router", ("router", Native.Interface.Overlay.Ip.Router)), ("tcp", ("tcp", Native.Interface.Overlay.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Overlay.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Overlay.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Overlay.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.Overlay.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.Overlay.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Overlay.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Overlay.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Overlay.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Overlay.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Overlay.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Overlay.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Overlay.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Overlay.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Overlay.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Overlay.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Overlay.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Overlay.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Overlay.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Overlay.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Overlay.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Overlay.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Overlay.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Overlay.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.Overlay.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Overlay.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Overlay.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Overlay.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Overlay.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Overlay.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Overlay.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Overlay.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Overlay.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Overlay.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Overlay.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Overlay.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Overlay.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Overlay.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Overlay.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Overlay.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Overlay.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Overlay.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.Overlay.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Overlay.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Overlay.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Overlay.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Overlay.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Overlay.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Overlay.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Overlay.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Overlay.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Overlay.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Overlay.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Overlay.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Overlay.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Overlay.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Overlay.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Overlay.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.Overlay.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Overlay.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Overlay.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Overlay.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Overlay.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Overlay.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Overlay.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Overlay.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Overlay.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Overlay.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Overlay.Ipv6.Dhcp)), ("address", ("address", Native.Interface.Overlay.Ipv6.Address)), ("nd", ("nd", Native.Interface.Overlay.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.Overlay.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Overlay.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Overlay.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Overlay.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Overlay.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Overlay.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Overlay.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Overlay.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Overlay.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Overlay.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Logging.Event>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Overlay.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Overlay.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Overlay.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Overlay.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Overlay.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Overlay.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Source.Template>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Overlay.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Overlay.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Overlay.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Overlay.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.Overlay.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Overlay.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Overlay.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Overlay.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Overlay.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Overlay.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Overlay.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Overlay.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Overlay.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Overlay.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.Overlay.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Overlay.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Overlay.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Overlay.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Overlay.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Overlay.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Overlay.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Overlay.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Overlay.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Overlay.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Overlay.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Overlay.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios-otv'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Overlay.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Overlay.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Overlay.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Overlay.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Overlay.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Overlay.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Overlay.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Overlay.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Overlay.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Overlay.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Overlay.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Overlay.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Overlay.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Overlay.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Overlay.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Overlay.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Overlay.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Overlay.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Overlay.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Overlay.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Overlay.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Overlay.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Overlay.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Overlay.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Overlay.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Overlay.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Overlay.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Overlay.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Overlay.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Overlay.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Overlay.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Overlay.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Overlay.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Overlay.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Overlay.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Overlay.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Overlay.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Overlay.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Overlay.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Overlay.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Overlay.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Overlay.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Trust.Device>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Overlay.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Overlay.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Overlay.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Peer.Default>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Overlay.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Overlay.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Overlay.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Overlay.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Overlay.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Overlay.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Overlay.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Overlay.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.Overlay.CarrierDelay.Down)), ("up", ("up", Native.Interface.Overlay.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.Overlay.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.Overlay.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.Overlay.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.Overlay.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.Overlay.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.Overlay.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.Overlay.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.Overlay.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.Overlay.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.Overlay.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.Overlay.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.Overlay.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.Overlay.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Plim.Qos>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.Overlay.Plim.Ethernet)), ("qos", ("qos", Native.Interface.Overlay.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.Overlay.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.Overlay.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Overlay.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.Overlay.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.Overlay.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.Overlay.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.Overlay.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.Overlay.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.Overlay.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.Overlay.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.Overlay.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.Overlay.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.Overlay.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.Overlay.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.Overlay.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.Overlay.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.Overlay.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.Overlay.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.Overlay.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.Overlay.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.L2protocol>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.Overlay.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.Overlay.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.Overlay.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.Overlay.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.Overlay.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.Overlay.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.Overlay.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.Overlay.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.Overlay.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.Overlay.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.Overlay.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.Overlay.Service.Instance.L2protocol))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.Overlay.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.Overlay.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.Overlay.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.Overlay.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.Overlay.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.Overlay.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.Overlay.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.Overlay.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.Overlay.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.Overlay.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.Overlay.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.Overlay.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.Overlay.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.Overlay.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.Overlay.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.Overlay.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.Overlay.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.Overlay.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.Overlay.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.Overlay.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.Overlay.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.Overlay.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-otv'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.Overlay.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.Overlay.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-otv'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-otv'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-otv'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-otv'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.Overlay.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.Overlay.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.Overlay.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.Overlay.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-otv'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-otv'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Overlay.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.Overlay.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.Overlay.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.Overlay.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.Overlay.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.Overlay.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.Overlay.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.Overlay.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.Overlay.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.Overlay.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.Overlay.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.Overlay.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.Overlay.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.Overlay.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.Overlay.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.Overlay.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.Overlay.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Overlay.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.Overlay.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.Overlay.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.Overlay.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.Overlay.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



            class Otv(Entity):
                """
                Configure OTV information
                
                .. attribute:: adjacency_server
                
                	Indicate if the box is an Adjacency Server
                	**type**\:  :py:class:`AdjacencyServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.AdjacencyServer>`
                
                .. attribute:: control_group
                
                	OTV VPN control multicast group
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: data_group
                
                	Multicast group range for data
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                
                .. attribute:: encapsulation_format
                
                	Encapsulation format
                	**type**\:  :py:class:`EncapsulationFormat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.EncapsulationFormat>`
                
                .. attribute:: filter_fhrp
                
                	Configure to not forward HSRP, GLBP, and VRRP packets on overlay
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: isis
                
                	ISIS interface subcommands
                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.Isis>`
                
                .. attribute:: join_interface
                
                	OTV VPN join\-interface
                	**type**\:  :py:class:`JoinInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.JoinInterface>`
                
                .. attribute:: suppress
                
                	Enable overlay packet suppression
                	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.Suppress>`
                
                .. attribute:: use_adjacency_server
                
                	Point to remote Adjacency Server address
                	**type**\:  :py:class:`UseAdjacencyServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.UseAdjacencyServer>`
                
                .. attribute:: vpn_name
                
                	OTV VPN name
                	**type**\: str
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Interface.Overlay.Otv, self).__init__()

                    self.yang_name = "otv"
                    self.yang_parent_name = "overlay"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("adjacency-server", ("adjacency_server", Native.Interface.Overlay.Otv.AdjacencyServer)), ("encapsulation-format", ("encapsulation_format", Native.Interface.Overlay.Otv.EncapsulationFormat)), ("isis", ("isis", Native.Interface.Overlay.Otv.Isis)), ("join-interface", ("join_interface", Native.Interface.Overlay.Otv.JoinInterface)), ("suppress", ("suppress", Native.Interface.Overlay.Otv.Suppress)), ("use-adjacency-server", ("use_adjacency_server", Native.Interface.Overlay.Otv.UseAdjacencyServer))])
                    self._leafs = OrderedDict([
                        ('control_group', (YLeaf(YType.str, 'control-group'), ['str'])),
                        ('data_group', (YLeaf(YType.str, 'data-group'), ['str'])),
                        ('filter_fhrp', (YLeaf(YType.empty, 'filter-fhrp'), ['Empty'])),
                        ('vpn_name', (YLeaf(YType.str, 'vpn-name'), ['str'])),
                    ])
                    self.control_group = None
                    self.data_group = None
                    self.filter_fhrp = None
                    self.vpn_name = None

                    self.adjacency_server = Native.Interface.Overlay.Otv.AdjacencyServer()
                    self.adjacency_server.parent = self
                    self._children_name_map["adjacency_server"] = "adjacency-server"

                    self.encapsulation_format = Native.Interface.Overlay.Otv.EncapsulationFormat()
                    self.encapsulation_format.parent = self
                    self._children_name_map["encapsulation_format"] = "encapsulation-format"

                    self.isis = Native.Interface.Overlay.Otv.Isis()
                    self.isis.parent = self
                    self._children_name_map["isis"] = "isis"

                    self.join_interface = Native.Interface.Overlay.Otv.JoinInterface()
                    self.join_interface.parent = self
                    self._children_name_map["join_interface"] = "join-interface"

                    self.suppress = Native.Interface.Overlay.Otv.Suppress()
                    self.suppress.parent = self
                    self._children_name_map["suppress"] = "suppress"

                    self.use_adjacency_server = Native.Interface.Overlay.Otv.UseAdjacencyServer()
                    self.use_adjacency_server.parent = self
                    self._children_name_map["use_adjacency_server"] = "use-adjacency-server"
                    self._segment_path = lambda: "Cisco-IOS-XE-otv:otv"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Overlay.Otv, ['control_group', 'data_group', 'filter_fhrp', 'vpn_name'], name, value)


                class AdjacencyServer(Entity):
                    """
                    Indicate if the box is an Adjacency Server
                    
                    .. attribute:: unicast_only
                    
                    	Unicast Only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Otv.AdjacencyServer, self).__init__()

                        self.yang_name = "adjacency-server"
                        self.yang_parent_name = "otv"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast_only', (YLeaf(YType.empty, 'unicast-only'), ['Empty'])),
                        ])
                        self.unicast_only = None
                        self._segment_path = lambda: "adjacency-server"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Otv.AdjacencyServer, ['unicast_only'], name, value)


                class EncapsulationFormat(Entity):
                    """
                    Encapsulation format
                    
                    .. attribute:: ip
                    
                    	Use IP for outer header encapsulation
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.EncapsulationFormat.Ip>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Otv.EncapsulationFormat, self).__init__()

                        self.yang_name = "encapsulation-format"
                        self.yang_parent_name = "otv"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Overlay.Otv.EncapsulationFormat.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Overlay.Otv.EncapsulationFormat.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "encapsulation-format"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Otv.EncapsulationFormat, [], name, value)


                    class Ip(Entity):
                        """
                        Use IP for outer header encapsulation
                        
                        .. attribute:: gre
                        
                        	Use GRE middle header encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Otv.EncapsulationFormat.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "encapsulation-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('gre', (YLeaf(YType.empty, 'gre'), ['Empty'])),
                            ])
                            self.gre = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Otv.EncapsulationFormat.Ip, ['gre'], name, value)


                class Isis(Entity):
                    """
                    ISIS interface subcommands
                    
                    .. attribute:: authentication
                    
                    	ISIS authentication for interface related PDUs
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.Isis.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: csnp_interval
                    
                    	Set CSNP interval in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello
                    
                    	Add padding to IS\-IS hello packets
                    	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.Isis.Hello>`
                    
                    .. attribute:: hello_interval
                    
                    	Set Hello interval in seconds
                    	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.Isis.HelloInterval>`
                    
                    .. attribute:: hello_multiplier
                    
                    	Set multiplier for Hello holding time
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    .. attribute:: lsp_interval
                    
                    	Set LSP transmission interval
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.Isis.Metric>`
                    
                    .. attribute:: priority
                    
                    	Set priority for Designated Router election
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    .. attribute:: retransmit_interval
                    
                    	Set per\-LSP retransmission interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: retransmit_throttle_interval
                    
                    	Set interface LSP retransmission interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Otv.Isis, self).__init__()

                        self.yang_name = "isis"
                        self.yang_parent_name = "otv"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Overlay.Otv.Isis.Authentication)), ("hello", ("hello", Native.Interface.Overlay.Otv.Isis.Hello)), ("hello-interval", ("hello_interval", Native.Interface.Overlay.Otv.Isis.HelloInterval)), ("metric", ("metric", Native.Interface.Overlay.Otv.Isis.Metric))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('csnp_interval', (YLeaf(YType.uint16, 'csnp-interval'), ['int'])),
                            ('hello_multiplier', (YLeaf(YType.uint16, 'hello-multiplier'), ['int'])),
                            ('lsp_interval', (YLeaf(YType.uint64, 'lsp-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint16, 'retransmit-interval'), ['int'])),
                            ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'retransmit-throttle-interval'), ['int'])),
                        ])
                        self.bfd = None
                        self.csnp_interval = None
                        self.hello_multiplier = None
                        self.lsp_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.retransmit_throttle_interval = None

                        self.authentication = Native.Interface.Overlay.Otv.Isis.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.hello = Native.Interface.Overlay.Otv.Isis.Hello()
                        self.hello.parent = self
                        self._children_name_map["hello"] = "hello"

                        self.hello_interval = Native.Interface.Overlay.Otv.Isis.HelloInterval()
                        self.hello_interval.parent = self
                        self._children_name_map["hello_interval"] = "hello-interval"

                        self.metric = Native.Interface.Overlay.Otv.Isis.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"
                        self._segment_path = lambda: "isis"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Otv.Isis, ['bfd', 'csnp_interval', 'hello_multiplier', 'lsp_interval', 'priority', 'retransmit_interval', 'retransmit_throttle_interval'], name, value)


                    class Authentication(Entity):
                        """
                        ISIS authentication for interface related PDUs
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode for PDUs
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.Isis.Authentication.Mode>`
                        
                        .. attribute:: send_only
                        
                        	Authentication send only, receive ignore
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Otv.Isis.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Overlay.Otv.Isis.Authentication.Mode')])),
                                ('send_only', (YLeaf(YType.empty, 'send-only'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.mode = None
                            self.send_only = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Otv.Isis.Authentication, ['key_chain', 'mode', 'send_only'], name, value)

                        class Mode(Enum):
                            """
                            Mode (Enum Class)

                            Authentication mode for PDUs

                            .. data:: md5 = 0

                            .. data:: text = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            text = Enum.YLeaf(1, "text")



                    class Hello(Entity):
                        """
                        Add padding to IS\-IS hello packets
                        
                        .. attribute:: padding
                        
                        	Pad hello packets
                        	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.Isis.Hello.Padding>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Otv.Isis.Hello, self).__init__()

                            self.yang_name = "hello"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.Overlay.Otv.Isis.Hello.Padding))])
                            self._leafs = OrderedDict()

                            self.padding = None
                            self._children_name_map["padding"] = "padding"
                            self._segment_path = lambda: "hello"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Otv.Isis.Hello, [], name, value)


                        class Padding(Entity):
                            """
                            Pad hello packets
                            
                            .. attribute:: always
                            
                            	Never pad hello packets if no prefix present
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Overlay.Otv.Isis.Hello.Padding, self).__init__()

                                self.yang_name = "padding"
                                self.yang_parent_name = "hello"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                ])
                                self.always = None
                                self._segment_path = lambda: "padding"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Overlay.Otv.Isis.Hello.Padding, ['always'], name, value)


                    class HelloInterval(Entity):
                        """
                        Set Hello interval in seconds
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Holdtime 1 second, interval depends on multiplier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Otv.Isis.HelloInterval, self).__init__()

                            self.yang_name = "hello-interval"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                ('minimal', (YLeaf(YType.empty, 'minimal'), ['Empty'])),
                            ])
                            self.value = None
                            self.minimal = None
                            self._segment_path = lambda: "hello-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Otv.Isis.HelloInterval, ['value', 'minimal'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: default
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: maximum
                        
                        	Maximum metric. All routers will exclude this link from their SPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: delay
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: expense
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: error
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Otv.Isis.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ('maximum', (YLeaf(YType.empty, 'maximum'), ['Empty'])),
                                ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                ('expense', (YLeaf(YType.uint32, 'expense'), ['int'])),
                                ('error', (YLeaf(YType.uint32, 'error'), ['int'])),
                            ])
                            self.default = None
                            self.maximum = None
                            self.delay = None
                            self.expense = None
                            self.error = None
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Otv.Isis.Metric, ['default', 'maximum', 'delay', 'expense', 'error'], name, value)


                class JoinInterface(Entity):
                    """
                    OTV VPN join\-interface
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.JoinInterface.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.JoinInterface.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.JoinInterface.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Overlay.Otv.JoinInterface.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Otv.JoinInterface, self).__init__()

                        self.yang_name = "join-interface"
                        self.yang_parent_name = "otv"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Overlay.Otv.JoinInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Overlay.Otv.JoinInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Overlay.Otv.JoinInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Overlay.Otv.JoinInterface.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Overlay.Otv.JoinInterface.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Overlay.Otv.JoinInterface.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Overlay.Otv.JoinInterface.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Overlay.Otv.JoinInterface.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "join-interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Otv.JoinInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Otv.JoinInterface.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "join-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Otv.JoinInterface.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Otv.JoinInterface.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "join-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Otv.JoinInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Otv.JoinInterface.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "join-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Otv.JoinInterface.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Overlay.Otv.JoinInterface.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "join-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Overlay.Otv.JoinInterface.PortChannelSubinterface, [u'port_channel'], name, value)


                class Suppress(Entity):
                    """
                    Enable overlay packet suppression
                    
                    .. attribute:: arp_nd
                    
                    	Suppress sending ARP and neighbor discovery packets on overlay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Otv.Suppress, self).__init__()

                        self.yang_name = "suppress"
                        self.yang_parent_name = "otv"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                        ])
                        self.arp_nd = None
                        self._segment_path = lambda: "suppress"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Otv.Suppress, ['arp_nd'], name, value)


                class UseAdjacencyServer(Entity):
                    """
                    Point to remote Adjacency Server address
                    
                    .. attribute:: remote_pri_ip
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: remote_sec_ip
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: unicast_only
                    
                    	Unicast Only Capability
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Overlay.Otv.UseAdjacencyServer, self).__init__()

                        self.yang_name = "use-adjacency-server"
                        self.yang_parent_name = "otv"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('remote_pri_ip', (YLeaf(YType.str, 'remote-pri-ip'), ['str'])),
                            ('remote_sec_ip', (YLeaf(YType.str, 'remote-sec-ip'), ['str'])),
                            ('unicast_only', (YLeaf(YType.empty, 'unicast-only'), ['Empty'])),
                        ])
                        self.remote_pri_ip = None
                        self.remote_sec_ip = None
                        self.unicast_only = None
                        self._segment_path = lambda: "use-adjacency-server"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Overlay.Otv.UseAdjacencyServer, ['remote_pri_ip', 'remote_sec_ip', 'unicast_only'], name, value)


        class PortChannel(Entity):
            """
            Ethernet Channel of interfaces
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..512
            
            .. attribute:: pc_speed
            
            	Configure speed operation
            	**type**\:  :py:class:`PcSpeed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.PcSpeed>`
            
            .. attribute:: port_channel
            
            	Port Channel interface subcommands
            	**type**\:  :py:class:`PortChannel_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.PortChannel_>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service>`
            
            .. attribute:: lacp
            
            	LACP Port Channel interface subcommands
            	**type**\:  :py:class:`Lacp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Lacp>`
            
            .. attribute:: mlacp
            
            	mLACP Port Channel interface subcommands
            	**type**\:  :py:class:`Mlacp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mlacp>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ServicePolicy>`
            
            .. attribute:: auto
            
            	Configure Automation
            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Auto>`
            
            .. attribute:: datalink
            
            	Interface Datalink commands
            	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Datalink>`
            
            .. attribute:: energywise
            
            	EnergyWise interface configurations
            	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Energywise>`
            
            	**presence node**\: True
            
            .. attribute:: location
            
            	Interface location information
            	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Location>`
            
            .. attribute:: mac
            
            	MAC interface commands
            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mac>`
            
            .. attribute:: macro
            
            	Command macro
            	**type**\:  :py:class:`Macro <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Macro>`
            
            .. attribute:: dual_active
            
            	
            	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.DualActive>`
            
            .. attribute:: load_balancing
            
            	Etherchannel Load\-Balancing
            	**type**\:  :py:class:`LoadBalancing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.LoadBalancing>`
            
            .. attribute:: vlan_range
            
            	
            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.VlanRange>`
            
            .. attribute:: switch
            
            	
            	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switch>`
            
            .. attribute:: srr_queue
            
            	
            	**type**\:  :py:class:`SrrQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SrrQueue>`
            
            .. attribute:: macsec
            
            	Enable macsec on the interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: macsec_option
            
            	Enable macsec on the interface
            	**type**\:  :py:class:`MacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.MacsecOption>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Snmp>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Crypto>`
            
            .. attribute:: xconnect
            
            	Xconnect commands
            	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Xconnect>`
            
            .. attribute:: evpn
            
            	
            	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Evpn>`
            
            .. attribute:: mvrp
            
            	
            	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mvrp>`
            
            	**presence node**\: True
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Lisp>`
            
            .. attribute:: authentication
            
            	Auth Manager Interface Configuration Commands
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication>`
            
            .. attribute:: mab
            
            	
            	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mab>`
            
            	**presence node**\: True
            
            .. attribute:: dot1x
            
            	Interface Config Commands for IEEE 802.1X
            	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Dot1x>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SpanningTree>`
            
            .. attribute:: nat66
            
            	NAT66 interface commands
            	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Nat66>`
            
            .. attribute:: ospfv3
            
            	OSPFv3 interface commands
            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts>`
            
            .. attribute:: analysis_module
            
            	Configure NAM on the interface
            	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.AnalysisModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.PortChannel, self).__init__()

                self.yang_name = "Port-channel"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("port-channel", ("port_channel", Native.Interface.PortChannel.PortChannel_)), ("switchport-conf", ("switchport_conf", Native.Interface.PortChannel.SwitchportConf)), ("switchport", ("switchport", Native.Interface.PortChannel.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.PortChannel.StackwiseVirtual)), ("arp", ("arp", Native.Interface.PortChannel.Arp)), ("backup", ("backup", Native.Interface.PortChannel.Backup)), ("cemoudp", ("cemoudp", Native.Interface.PortChannel.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.PortChannel.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.PortChannel.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.PortChannel.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.PortChannel.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.PortChannel.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.PortChannel.Flowcontrol)), ("isis", ("isis", Native.Interface.PortChannel.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.PortChannel.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.PortChannel.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.PortChannel.Bandwidth)), ("dampening", ("dampening", Native.Interface.PortChannel.Dampening)), ("domain", ("domain", Native.Interface.PortChannel.Domain)), ("hold-queue", ("hold_queue", Native.Interface.PortChannel.HoldQueue)), ("mpls", ("mpls", Native.Interface.PortChannel.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.PortChannel.IpVrf)), ("vrf", ("vrf", Native.Interface.PortChannel.Vrf)), ("ip", ("ip", Native.Interface.PortChannel.Ip)), ("ipv6", ("ipv6", Native.Interface.PortChannel.Ipv6)), ("logging", ("logging", Native.Interface.PortChannel.Logging)), ("mdix", ("mdix", Native.Interface.PortChannel.Mdix)), ("mop", ("mop", Native.Interface.PortChannel.Mop)), ("interface_qos", ("interface_qos", Native.Interface.PortChannel.InterfaceQos)), ("source", ("source", Native.Interface.PortChannel.Source)), ("standby", ("standby", Native.Interface.PortChannel.Standby)), ("access-session", ("access_session", Native.Interface.PortChannel.AccessSession)), ("storm-control", ("storm_control", Native.Interface.PortChannel.StormControl)), ("trust", ("trust", Native.Interface.PortChannel.Trust)), ("priority-queue", ("priority_queue", Native.Interface.PortChannel.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.PortChannel.RcvQueue)), ("peer", ("peer", Native.Interface.PortChannel.Peer)), ("pm-path", ("pm_path", Native.Interface.PortChannel.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.PortChannel.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.PortChannel.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.PortChannel.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.PortChannel.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.PortChannel.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.PortChannel.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.PortChannel.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.PortChannel.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.PortChannel.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.PortChannel.Service)), ("Cisco-IOS-XE-ethernet:lacp", ("lacp", Native.Interface.PortChannel.Lacp)), ("Cisco-IOS-XE-ethernet:mlacp", ("mlacp", Native.Interface.PortChannel.Mlacp)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.PortChannel.ServicePolicy)), ("Cisco-IOS-XE-switch:auto", ("auto", Native.Interface.PortChannel.Auto)), ("Cisco-IOS-XE-switch:datalink", ("datalink", Native.Interface.PortChannel.Datalink)), ("Cisco-IOS-XE-switch:energywise", ("energywise", Native.Interface.PortChannel.Energywise)), ("Cisco-IOS-XE-switch:location", ("location", Native.Interface.PortChannel.Location)), ("Cisco-IOS-XE-switch:mac", ("mac", Native.Interface.PortChannel.Mac)), ("Cisco-IOS-XE-switch:macro", ("macro", Native.Interface.PortChannel.Macro)), ("Cisco-IOS-XE-switch:dual-active", ("dual_active", Native.Interface.PortChannel.DualActive)), ("Cisco-IOS-XE-switch:load-balancing", ("load_balancing", Native.Interface.PortChannel.LoadBalancing)), ("Cisco-IOS-XE-switch:vlan-range", ("vlan_range", Native.Interface.PortChannel.VlanRange)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Interface.PortChannel.Switch)), ("Cisco-IOS-XE-switch:srr-queue", ("srr_queue", Native.Interface.PortChannel.SrrQueue)), ("Cisco-IOS-XE-switch:macsec-option", ("macsec_option", Native.Interface.PortChannel.MacsecOption)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.PortChannel.Snmp)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.PortChannel.Crypto)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.PortChannel.Xconnect)), ("Cisco-IOS-XE-l2vpn:evpn", ("evpn", Native.Interface.PortChannel.Evpn)), ("Cisco-IOS-XE-mvrp:mvrp", ("mvrp", Native.Interface.PortChannel.Mvrp)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.PortChannel.Lisp)), ("Cisco-IOS-XE-sanet:authentication", ("authentication", Native.Interface.PortChannel.Authentication)), ("Cisco-IOS-XE-sanet:mab", ("mab", Native.Interface.PortChannel.Mab)), ("Cisco-IOS-XE-dot1x:dot1x", ("dot1x", Native.Interface.PortChannel.Dot1x)), ("Cisco-IOS-XE-spanning-tree:spanning-tree", ("spanning_tree", Native.Interface.PortChannel.SpanningTree)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Interface.PortChannel.Ospfv3)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.PortChannel.Cts)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Interface.PortChannel.AnalysisModule))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint32, 'name'), ['int'])),
                    ('pc_speed', (YLeaf(YType.enumeration, 'pc-speed'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.PcSpeed')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Duplex')])),
                    ('macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:macsec'), ['Empty'])),
                    ('nat66', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-nat:nat66'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Nat66')])),
                ])
                self.name = None
                self.pc_speed = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None
                self.macsec = None
                self.nat66 = None

                self.port_channel = Native.Interface.PortChannel.PortChannel_()
                self.port_channel.parent = self
                self._children_name_map["port_channel"] = "port-channel"

                self.switchport_conf = Native.Interface.PortChannel.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.PortChannel.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.PortChannel.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.PortChannel.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.PortChannel.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.PortChannel.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.PortChannel.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.PortChannel.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.PortChannel.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.PortChannel.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.PortChannel.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.PortChannel.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.PortChannel.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.PortChannel.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.PortChannel.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.PortChannel.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.PortChannel.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.PortChannel.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.PortChannel.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.PortChannel.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.PortChannel.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.PortChannel.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.PortChannel.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.PortChannel.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.PortChannel.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.PortChannel.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.PortChannel.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.PortChannel.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.PortChannel.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.PortChannel.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.PortChannel.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.PortChannel.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.PortChannel.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.PortChannel.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.PortChannel.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.PortChannel.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.PortChannel.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.PortChannel.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.PortChannel.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.PortChannel.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.PortChannel.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.PortChannel.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.PortChannel.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.PortChannel.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.PortChannel.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.lacp = Native.Interface.PortChannel.Lacp()
                self.lacp.parent = self
                self._children_name_map["lacp"] = "Cisco-IOS-XE-ethernet:lacp"

                self.mlacp = Native.Interface.PortChannel.Mlacp()
                self.mlacp.parent = self
                self._children_name_map["mlacp"] = "Cisco-IOS-XE-ethernet:mlacp"

                self.service_policy = Native.Interface.PortChannel.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.auto = Native.Interface.PortChannel.Auto()
                self.auto.parent = self
                self._children_name_map["auto"] = "Cisco-IOS-XE-switch:auto"

                self.datalink = Native.Interface.PortChannel.Datalink()
                self.datalink.parent = self
                self._children_name_map["datalink"] = "Cisco-IOS-XE-switch:datalink"

                self.energywise = None
                self._children_name_map["energywise"] = "Cisco-IOS-XE-switch:energywise"

                self.location = Native.Interface.PortChannel.Location()
                self.location.parent = self
                self._children_name_map["location"] = "Cisco-IOS-XE-switch:location"

                self.mac = Native.Interface.PortChannel.Mac()
                self.mac.parent = self
                self._children_name_map["mac"] = "Cisco-IOS-XE-switch:mac"

                self.macro = Native.Interface.PortChannel.Macro()
                self.macro.parent = self
                self._children_name_map["macro"] = "Cisco-IOS-XE-switch:macro"

                self.dual_active = Native.Interface.PortChannel.DualActive()
                self.dual_active.parent = self
                self._children_name_map["dual_active"] = "Cisco-IOS-XE-switch:dual-active"

                self.load_balancing = Native.Interface.PortChannel.LoadBalancing()
                self.load_balancing.parent = self
                self._children_name_map["load_balancing"] = "Cisco-IOS-XE-switch:load-balancing"

                self.switch = Native.Interface.PortChannel.Switch()
                self.switch.parent = self
                self._children_name_map["switch"] = "Cisco-IOS-XE-switch:switch"

                self.srr_queue = Native.Interface.PortChannel.SrrQueue()
                self.srr_queue.parent = self
                self._children_name_map["srr_queue"] = "Cisco-IOS-XE-switch:srr-queue"

                self.macsec_option = Native.Interface.PortChannel.MacsecOption()
                self.macsec_option.parent = self
                self._children_name_map["macsec_option"] = "Cisco-IOS-XE-switch:macsec-option"

                self.snmp = Native.Interface.PortChannel.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.crypto = Native.Interface.PortChannel.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.xconnect = Native.Interface.PortChannel.Xconnect()
                self.xconnect.parent = self
                self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                self.evpn = Native.Interface.PortChannel.Evpn()
                self.evpn.parent = self
                self._children_name_map["evpn"] = "Cisco-IOS-XE-l2vpn:evpn"

                self.mvrp = None
                self._children_name_map["mvrp"] = "Cisco-IOS-XE-mvrp:mvrp"

                self.lisp = Native.Interface.PortChannel.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.authentication = Native.Interface.PortChannel.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "Cisco-IOS-XE-sanet:authentication"

                self.mab = None
                self._children_name_map["mab"] = "Cisco-IOS-XE-sanet:mab"

                self.dot1x = Native.Interface.PortChannel.Dot1x()
                self.dot1x.parent = self
                self._children_name_map["dot1x"] = "Cisco-IOS-XE-dot1x:dot1x"

                self.spanning_tree = Native.Interface.PortChannel.SpanningTree()
                self.spanning_tree.parent = self
                self._children_name_map["spanning_tree"] = "Cisco-IOS-XE-spanning-tree:spanning-tree"

                self.ospfv3 = Native.Interface.PortChannel.Ospfv3()
                self.ospfv3.parent = self
                self._children_name_map["ospfv3"] = "Cisco-IOS-XE-ospfv3:ospfv3"

                self.cts = Native.Interface.PortChannel.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.analysis_module = Native.Interface.PortChannel.AnalysisModule()
                self.analysis_module.parent = self
                self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"

                self.hold_queue = YList(self)
                self.vlan_range = YList(self)
                self._segment_path = lambda: "Port-channel" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.PortChannel, [u'name', u'pc_speed', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex', u'macsec', 'nat66'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class Nat66(Enum):
                """
                Nat66 (Enum Class)

                NAT66 interface commands

                .. data:: inside = 0

                .. data:: outside = 1

                """

                inside = Enum.YLeaf(0, "inside")

                outside = Enum.YLeaf(1, "outside")


            class PcSpeed(Enum):
                """
                PcSpeed (Enum Class)

                Configure speed operation.

                .. data:: Y_10 = 0

                .. data:: Y_100 = 1

                .. data:: Y_1000 = 2

                .. data:: nonegotiate = 3

                .. data:: auto = 4

                """

                Y_10 = Enum.YLeaf(0, "10")

                Y_100 = Enum.YLeaf(1, "100")

                Y_1000 = Enum.YLeaf(2, "1000")

                nonegotiate = Enum.YLeaf(3, "nonegotiate")

                auto = Enum.YLeaf(4, "auto")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class PortChannel_(Entity):
                """
                Port Channel interface subcommands
                
                .. attribute:: min_links
                
                	Minimum number of bundled ports needed to bring up      this port channel
                	**type**\: int
                
                	**range:** 2..8
                
                .. attribute:: standalone_disable
                
                	Ports will go to suspended mode if peer does not respond. Use with [no] prefix for independent mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.PortChannel_, self).__init__()

                    self.yang_name = "port-channel"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('min_links', (YLeaf(YType.uint8, 'min-links'), ['int'])),
                        ('standalone_disable', (YLeaf(YType.empty, 'standalone-disable'), ['Empty'])),
                    ])
                    self.min_links = None
                    self.standalone_disable = None
                    self._segment_path = lambda: "port-channel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.PortChannel_, [u'min_links', u'standalone_disable'], name, value)


            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Access>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Block>`
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: trunk
                
                	Set trunking characteristics of the interface
                	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Trunk>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Voice>`
                
                .. attribute:: priority
                
                	Set appliance 802.1p priority
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Priority>`
                
                .. attribute:: autostate
                
                	Include or exclude this port from vlan link up calculation
                	**type**\:  :py:class:`Autostate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Autostate>`
                
                .. attribute:: protected
                
                	Configure an interface to be a protected port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Set port host
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: private_vlan
                
                	Set the private VLAN configuration
                	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PrivateVlan>`
                
                .. attribute:: vepa
                
                	Reflective relay configuration
                	**type**\:  :py:class:`Vepa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Vepa>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:access", ("access", Native.Interface.PortChannel.Switchport.Access)), ("Cisco-IOS-XE-switch:block", ("block", Native.Interface.PortChannel.Switchport.Block)), ("Cisco-IOS-XE-switch:mode", ("mode", Native.Interface.PortChannel.Switchport.Mode)), ("Cisco-IOS-XE-switch:port-security", ("port_security", Native.Interface.PortChannel.Switchport.PortSecurity)), ("Cisco-IOS-XE-switch:trunk", ("trunk", Native.Interface.PortChannel.Switchport.Trunk)), ("Cisco-IOS-XE-switch:voice", ("voice", Native.Interface.PortChannel.Switchport.Voice)), ("Cisco-IOS-XE-switch:priority", ("priority", Native.Interface.PortChannel.Switchport.Priority)), ("Cisco-IOS-XE-switch:autostate", ("autostate", Native.Interface.PortChannel.Switchport.Autostate)), ("Cisco-IOS-XE-switch:private-vlan", ("private_vlan", Native.Interface.PortChannel.Switchport.PrivateVlan)), ("Cisco-IOS-XE-switch:vepa", ("vepa", Native.Interface.PortChannel.Switchport.Vepa))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:nonegotiate'), ['Empty'])),
                        ('protected', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:protected'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:host'), ['Empty'])),
                    ])
                    self.nonegotiate = None
                    self.protected = None
                    self.host = None

                    self.access = Native.Interface.PortChannel.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "Cisco-IOS-XE-switch:access"

                    self.block = Native.Interface.PortChannel.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "Cisco-IOS-XE-switch:block"

                    self.mode = Native.Interface.PortChannel.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "Cisco-IOS-XE-switch:mode"

                    self.port_security = None
                    self._children_name_map["port_security"] = "Cisco-IOS-XE-switch:port-security"

                    self.trunk = Native.Interface.PortChannel.Switchport.Trunk()
                    self.trunk.parent = self
                    self._children_name_map["trunk"] = "Cisco-IOS-XE-switch:trunk"

                    self.voice = Native.Interface.PortChannel.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "Cisco-IOS-XE-switch:voice"

                    self.priority = Native.Interface.PortChannel.Switchport.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-switch:priority"

                    self.autostate = Native.Interface.PortChannel.Switchport.Autostate()
                    self.autostate.parent = self
                    self._children_name_map["autostate"] = "Cisco-IOS-XE-switch:autostate"

                    self.private_vlan = Native.Interface.PortChannel.Switchport.PrivateVlan()
                    self.private_vlan.parent = self
                    self._children_name_map["private_vlan"] = "Cisco-IOS-XE-switch:private-vlan"

                    self.vepa = Native.Interface.PortChannel.Switchport.Vepa()
                    self.vepa.parent = self
                    self._children_name_map["vepa"] = "Cisco-IOS-XE-switch:vepa"
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Switchport, [u'nonegotiate', u'protected', u'host'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	Set VLAN when interface is in access mode
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Access.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannel.Switchport.Access.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.PortChannel.Switchport.Access.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:access"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Switchport.Access, [], name, value)


                    class Vlan(Entity):
                        """
                        Set VLAN when interface is in access mode
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_>`
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.Access.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "access"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.Access.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dynamic = 0

                            """

                            dynamic = Enum.YLeaf(0, "dynamic")



                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: multicast
                    
                    	Block unknown multicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.multicast = None
                        self.unicast = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:block"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Switchport.Block, [u'multicast', u'unicast'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Mode.Access>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dot1q_tunnel
                    
                    	set trunking mode to TUNNEL unconditionally
                    	**type**\:  :py:class:`Dot1qTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Mode.Dot1qTunnel>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dynamic
                    
                    	Set trunking mode to dynamically negotiate access or trunk mode
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Mode.Dynamic>`
                    
                    .. attribute:: private_vlan
                    
                    	Set private\-vlan mode
                    	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Mode.PrivateVlan>`
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Mode.Trunk>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access", ("access", Native.Interface.PortChannel.Switchport.Mode.Access)), ("dot1q-tunnel", ("dot1q_tunnel", Native.Interface.PortChannel.Switchport.Mode.Dot1qTunnel)), ("private-vlan", ("private_vlan", Native.Interface.PortChannel.Switchport.Mode.PrivateVlan)), ("trunk", ("trunk", Native.Interface.PortChannel.Switchport.Mode.Trunk))])
                        self._leafs = OrderedDict([
                            ('dynamic', (YLeaf(YType.enumeration, 'dynamic'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Switchport.Mode.Dynamic')])),
                        ])
                        self.dynamic = None

                        self.access = None
                        self._children_name_map["access"] = "access"

                        self.dot1q_tunnel = None
                        self._children_name_map["dot1q_tunnel"] = "dot1q-tunnel"

                        self.private_vlan = Native.Interface.PortChannel.Switchport.Mode.PrivateVlan()
                        self.private_vlan.parent = self
                        self._children_name_map["private_vlan"] = "private-vlan"

                        self.trunk = None
                        self._children_name_map["trunk"] = "trunk"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Switchport.Mode, [u'dynamic'], name, value)

                    class Dynamic(Enum):
                        """
                        Dynamic (Enum Class)

                        Set trunking mode to dynamically negotiate access or trunk mode

                        .. data:: auto = 0

                        .. data:: desirable = 1

                        """

                        auto = Enum.YLeaf(0, "auto")

                        desirable = Enum.YLeaf(1, "desirable")



                    class Access(Entity):
                        """
                        Set trunking mode to ACCESS unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.Mode.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "access"
                            self._is_frozen = True


                    class Dot1qTunnel(Entity):
                        """
                        set trunking mode to TUNNEL unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.Mode.Dot1qTunnel, self).__init__()

                            self.yang_name = "dot1q-tunnel"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dot1q-tunnel"
                            self._is_frozen = True


                    class PrivateVlan(Entity):
                        """
                        Set private\-vlan mode
                        
                        .. attribute:: host
                        
                        	Set the mode to private\-vlan host
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: promiscuous
                        
                        	Set the mode to private\-vlan promiscuous
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.Mode.PrivateVlan, self).__init__()

                            self.yang_name = "private-vlan"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                ('promiscuous', (YLeaf(YType.empty, 'promiscuous'), ['Empty'])),
                            ])
                            self.host = None
                            self.promiscuous = None
                            self._segment_path = lambda: "private-vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.Mode.PrivateVlan, [u'host', u'promiscuous'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking mode to TRUNK unconditionally
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.Mode.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "trunk"
                            self._is_frozen = True


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: mac_address
                    
                    	Secure mac address
                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PortSecurity.MacAddress>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Interface.PortChannel.Switchport.PortSecurity.Aging)), ("mac-address", ("mac_address", Native.Interface.PortChannel.Switchport.PortSecurity.MacAddress)), ("maximum", ("maximum", Native.Interface.PortChannel.Switchport.PortSecurity.Maximum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Switchport.PortSecurity.Violation')])),
                        ])
                        self.violation = None

                        self.aging = Native.Interface.PortChannel.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.mac_address = Native.Interface.PortChannel.Switchport.PortSecurity.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"

                        self.maximum = Native.Interface.PortChannel.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:port-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Switchport.PortSecurity, [u'violation'], name, value)

                    class Violation(Enum):
                        """
                        Violation (Enum Class)

                        Security violation mode

                        .. data:: protect = 0

                        .. data:: restrict = 1

                        .. data:: shutdown = 2

                        """

                        protect = Enum.YLeaf(0, "protect")

                        restrict = Enum.YLeaf(1, "restrict")

                        shutdown = Enum.YLeaf(2, "shutdown")



                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PortSecurity.Aging.Type>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Switchport.PortSecurity.Aging.Type')])),
                            ])
                            self.static = None
                            self.time = None
                            self.type = None
                            self._segment_path = lambda: "aging"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.PortSecurity.Aging, [u'static', u'time', u'type'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Port\-security aging type

                            .. data:: absolute = 0

                            .. data:: inactivity = 1

                            """

                            absolute = Enum.YLeaf(0, "absolute")

                            inactivity = Enum.YLeaf(1, "inactivity")



                    class MacAddress(Entity):
                        """
                        Secure mac address
                        
                        .. attribute:: sticky
                        
                        	Configure dynamic secure addresses as sticky
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hw_address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: vlan
                        
                        	set VLAN ID of the VLAN on which this address can be learned
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.PortSecurity.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                ('hw_address', (YLeaf(YType.str, 'hw-address'), ['str'])),
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.sticky = None
                            self.hw_address = None
                            self.vlan = None
                            self._segment_path = lambda: "mac-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.PortSecurity.MacAddress, [u'sticky', u'hw_address', u'vlan'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: max_addresses
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4097
                        
                        .. attribute:: vlan
                        
                        	Max secure addresses per vlan
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_addresses', (YLeaf(YType.uint16, 'max-addresses'), ['int'])),
                                ('vlan', (YLeaf(YType.str, 'vlan'), ['str'])),
                            ])
                            self.max_addresses = None
                            self.vlan = None
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.PortSecurity.Maximum, [u'max_addresses', u'vlan'], name, value)


                class Trunk(Entity):
                    """
                    Set trunking characteristics of the interface
                    
                    .. attribute:: allowed
                    
                    	Set allowed VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Trunk.Allowed>`
                    
                    .. attribute:: encapsulation
                    
                    	Set encapsulation format on trunk port
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Trunk.Encapsulation>`
                    
                    .. attribute:: native
                    
                    	Set trunking native characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Trunk.Native_>`
                    
                    .. attribute:: pruning
                    
                    	Set pruning VLAN characteristics when interface is in trunking mode
                    	**type**\:  :py:class:`Pruning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Trunk.Pruning>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Switchport.Trunk, self).__init__()

                        self.yang_name = "trunk"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.PortChannel.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.PortChannel.Switchport.Trunk.Native_)), ("pruning", ("pruning", Native.Interface.PortChannel.Switchport.Trunk.Pruning))])
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Switchport.Trunk.Encapsulation')])),
                        ])
                        self.encapsulation = None

                        self.allowed = Native.Interface.PortChannel.Switchport.Trunk.Allowed()
                        self.allowed.parent = self
                        self._children_name_map["allowed"] = "allowed"

                        self.native = Native.Interface.PortChannel.Switchport.Trunk.Native_()
                        self.native.parent = self
                        self._children_name_map["native"] = "native"

                        self.pruning = Native.Interface.PortChannel.Switchport.Trunk.Pruning()
                        self.pruning.parent = self
                        self._children_name_map["pruning"] = "pruning"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:trunk"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Switchport.Trunk, [u'encapsulation'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Set encapsulation format on trunk port

                        .. data:: dot1q = 0

                        .. data:: isl = 1

                        .. data:: negotiate = 2

                        """

                        dot1q = Enum.YLeaf(0, "dot1q")

                        isl = Enum.YLeaf(1, "isl")

                        negotiate = Enum.YLeaf(2, "negotiate")



                    class Allowed(Entity):
                        """
                        Set allowed VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set allowed VLANs when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Trunk.Allowed.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.Trunk.Allowed, self).__init__()

                            self.yang_name = "allowed"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannel.Switchport.Trunk.Allowed.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.PortChannel.Switchport.Trunk.Allowed.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "allowed"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.Trunk.Allowed, [], name, value)


                        class Vlan(Entity):
                            """
                            Set allowed VLANs when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: all
                            
                            	all VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "allowed"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = None
                                self.add = None
                                self.all = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                    class Native_(Entity):
                        """
                        Set trunking native characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set native VLAN when interface is in trunking mode
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.Trunk.Native_, self).__init__()

                            self.yang_name = "native"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan'),'int'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "native"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.Trunk.Native_, [u'vlan'], name, value)

                        class Vlan(Enum):
                            """
                            Vlan (Enum Class)

                            Set native VLAN when interface is in trunking mode

                            .. data:: tag = 0

                            """

                            tag = Enum.YLeaf(0, "tag")



                    class Pruning(Entity):
                        """
                        Set pruning VLAN characteristics when interface is in trunking mode
                        
                        .. attribute:: vlan
                        
                        	Set VLANs enabled for pruning when interface is in trunking mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Trunk.Pruning.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.Trunk.Pruning, self).__init__()

                            self.yang_name = "pruning"
                            self.yang_parent_name = "trunk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannel.Switchport.Trunk.Pruning.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.PortChannel.Switchport.Trunk.Pruning.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "pruning"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.Trunk.Pruning, [], name, value)


                        class Vlan(Entity):
                            """
                            Set VLANs enabled for pruning when interface is in trunking mode
                            
                            .. attribute:: vlans
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: add
                            
                            	VLAN IDs of the allowed VLANs when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            .. attribute:: except_
                            
                            	all VLANs except the following
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 0..65535
                            
                            		**type**\: list of str
                            
                            .. attribute:: none
                            
                            	no VLANs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove
                            
                            	VLAN IDs of disallowed VLANS when this port is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..65535
                            
                            		**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Switchport.Trunk.Pruning.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "pruning"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlans', (YLeafList(YType.str, 'vlans'), ['int','str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                    ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                ])
                                self.vlans = []
                                self.add = None
                                self.except_ = []
                                self.none = None
                                self.remove = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Switchport.Trunk.Pruning.Vlan, [u'vlans', u'add', u'except_', u'none', u'remove'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Voice.Vlan>`
                    
                    .. attribute:: detect
                    
                    	detection enhancement keyword
                    	**type**\:  :py:class:`Detect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Voice.Detect>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannel.Switchport.Voice.Vlan)), ("detect", ("detect", Native.Interface.PortChannel.Switchport.Voice.Detect))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.PortChannel.Switchport.Voice.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"

                        self.detect = Native.Interface.PortChannel.Switchport.Voice.Detect()
                        self.detect.parent = self
                        self._children_name_map["detect"] = "detect"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:voice"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Switchport.Voice, [], name, value)


                    class Vlan(Entity):
                        """
                        Vlan for voice traffic
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_>`
                        
                        		**type**\: int
                        
                        			**range:** 1..4094
                        
                        		**type**\: str
                        
                        .. attribute:: name
                        
                        	Vlan name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.Voice.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_'),'int','str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.vlan = None
                            self.name = None
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.Voice.Vlan, [u'vlan', u'name'], name, value)

                        class Vlan_(Enum):
                            """
                            Vlan\_ (Enum Class)

                            .. data:: dot1p = 0

                            .. data:: none = 1

                            .. data:: untagged = 2

                            """

                            dot1p = Enum.YLeaf(0, "dot1p")

                            none = Enum.YLeaf(1, "none")

                            untagged = Enum.YLeaf(2, "untagged")



                    class Detect(Entity):
                        """
                        detection enhancement keyword
                        
                        .. attribute:: cisco_phone
                        
                        	Cisco IP phone
                        	**type**\:  :py:class:`CiscoPhone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Voice.Detect.CiscoPhone>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.Voice.Detect, self).__init__()

                            self.yang_name = "detect"
                            self.yang_parent_name = "voice"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cisco-phone", ("cisco_phone", Native.Interface.PortChannel.Switchport.Voice.Detect.CiscoPhone))])
                            self._leafs = OrderedDict()

                            self.cisco_phone = None
                            self._children_name_map["cisco_phone"] = "cisco-phone"
                            self._segment_path = lambda: "detect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.Voice.Detect, [], name, value)


                        class CiscoPhone(Entity):
                            """
                            Cisco IP phone
                            
                            .. attribute:: full_duplex
                            
                            	full duplex keyword
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Switchport.Voice.Detect.CiscoPhone, self).__init__()

                                self.yang_name = "cisco-phone"
                                self.yang_parent_name = "detect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('full_duplex', (YLeaf(YType.empty, 'full-duplex'), ['Empty'])),
                                ])
                                self.full_duplex = None
                                self._segment_path = lambda: "cisco-phone"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Switchport.Voice.Detect.CiscoPhone, [u'full_duplex'], name, value)


                class Priority(Entity):
                    """
                    Set appliance 802.1p priority
                    
                    .. attribute:: extend
                    
                    	Set appliance 802.1p priority
                    	**type**\:  :py:class:`Extend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.Priority.Extend>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Switchport.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("extend", ("extend", Native.Interface.PortChannel.Switchport.Priority.Extend))])
                        self._leafs = OrderedDict()

                        self.extend = Native.Interface.PortChannel.Switchport.Priority.Extend()
                        self.extend.parent = self
                        self._children_name_map["extend"] = "extend"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Switchport.Priority, [], name, value)


                    class Extend(Entity):
                        """
                        Set appliance 802.1p priority
                        
                        .. attribute:: trust
                        
                        	Trust 802.1p priorities of devices on appliance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cos
                        
                        	Override 802.1p priority of devices on appliance
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.Priority.Extend, self).__init__()

                            self.yang_name = "extend"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                            ])
                            self.trust = None
                            self.cos = None
                            self._segment_path = lambda: "extend"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.Priority.Extend, [u'trust', u'cos'], name, value)


                class Autostate(Entity):
                    """
                    Include or exclude this port from vlan link up calculation
                    
                    .. attribute:: exclude
                    
                    	Exclude this port from vlan link up calculation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Switchport.Autostate, self).__init__()

                        self.yang_name = "autostate"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('exclude', (YLeaf(YType.empty, 'exclude'), ['Empty'])),
                        ])
                        self.exclude = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:autostate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Switchport.Autostate, [u'exclude'], name, value)


                class PrivateVlan(Entity):
                    """
                    Set the private VLAN configuration
                    
                    .. attribute:: association
                    
                    	Set the private VLAN association
                    	**type**\:  :py:class:`Association <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PrivateVlan.Association>`
                    
                    .. attribute:: host_association
                    
                    	Set the private VLAN host association
                    	**type**\:  :py:class:`HostAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PrivateVlan.HostAssociation>`
                    
                    .. attribute:: mapping
                    
                    	Set the private VLAN promiscuous mapping
                    	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PrivateVlan.Mapping>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Switchport.PrivateVlan, self).__init__()

                        self.yang_name = "private-vlan"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("association", ("association", Native.Interface.PortChannel.Switchport.PrivateVlan.Association)), ("host-association", ("host_association", Native.Interface.PortChannel.Switchport.PrivateVlan.HostAssociation)), ("mapping", ("mapping", Native.Interface.PortChannel.Switchport.PrivateVlan.Mapping))])
                        self._leafs = OrderedDict()

                        self.association = Native.Interface.PortChannel.Switchport.PrivateVlan.Association()
                        self.association.parent = self
                        self._children_name_map["association"] = "association"

                        self.host_association = Native.Interface.PortChannel.Switchport.PrivateVlan.HostAssociation()
                        self.host_association.parent = self
                        self._children_name_map["host_association"] = "host-association"

                        self.mapping = Native.Interface.PortChannel.Switchport.PrivateVlan.Mapping()
                        self.mapping.parent = self
                        self._children_name_map["mapping"] = "mapping"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:private-vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Switchport.PrivateVlan, [], name, value)


                    class Association(Entity):
                        """
                        Set the private VLAN association
                        
                        .. attribute:: host
                        
                        	Set the private VLAN host association
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PrivateVlan.Association.Host>`
                        
                        .. attribute:: mapping
                        
                        	Set the private VLAN promiscuous mapping
                        	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switchport.PrivateVlan.Association.Mapping>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.PrivateVlan.Association, self).__init__()

                            self.yang_name = "association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.Interface.PortChannel.Switchport.PrivateVlan.Association.Host)), ("mapping", ("mapping", Native.Interface.PortChannel.Switchport.PrivateVlan.Association.Mapping))])
                            self._leafs = OrderedDict()

                            self.host = Native.Interface.PortChannel.Switchport.PrivateVlan.Association.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.mapping = Native.Interface.PortChannel.Switchport.PrivateVlan.Association.Mapping()
                            self.mapping.parent = self
                            self._children_name_map["mapping"] = "mapping"
                            self._segment_path = lambda: "association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.PrivateVlan.Association, [], name, value)


                        class Host(Entity):
                            """
                            Set the private VLAN host association
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary normal range VLAN ID of the private VLAN host port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Switchport.PrivateVlan.Association.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Switchport.PrivateVlan.Association.Host, [u'primary_range', u'secondary_range'], name, value)


                        class Mapping(Entity):
                            """
                            Set the private VLAN promiscuous mapping
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: remove
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Switchport.PrivateVlan.Association.Mapping, self).__init__()

                                self.yang_name = "mapping"
                                self.yang_parent_name = "association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self.add = None
                                self.remove = None
                                self._segment_path = lambda: "mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Switchport.PrivateVlan.Association.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                    class HostAssociation(Entity):
                        """
                        Set the private VLAN host association
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary normal range VLAN ID of the private VLAN host port association
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.PrivateVlan.HostAssociation, self).__init__()

                            self.yang_name = "host-association"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self._segment_path = lambda: "host-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.PrivateVlan.HostAssociation, [u'primary_range', u'secondary_range'], name, value)


                    class Mapping(Entity):
                        """
                        Set the private VLAN promiscuous mapping
                        
                        .. attribute:: primary_range
                        
                        	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                        	**type**\: int
                        
                        	**range:** 2..1001 \| 1006..4094
                        
                        .. attribute:: secondary_range
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: add
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        .. attribute:: remove
                        
                        	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Switchport.PrivateVlan.Mapping, self).__init__()

                            self.yang_name = "mapping"
                            self.yang_parent_name = "private-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                            ])
                            self.primary_range = None
                            self.secondary_range = None
                            self.add = None
                            self.remove = None
                            self._segment_path = lambda: "mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Switchport.PrivateVlan.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                class Vepa(Entity):
                    """
                    Reflective relay configuration
                    
                    .. attribute:: enabled
                    
                    	Enable reflective relay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Switchport.Vepa, self).__init__()

                        self.yang_name = "vepa"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                        ])
                        self.enabled = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:vepa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Switchport.Vepa, [u'enabled'], name, value)


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.PortChannel.Backup.Delay)), ("interface", ("interface", Native.Interface.PortChannel.Backup.Interface_)), ("load", ("load", Native.Interface.PortChannel.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.PortChannel.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.PortChannel.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.PortChannel.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.PortChannel.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.PortChannel.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.PortChannel.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.PortChannel.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.PortChannel.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.PortChannel.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.PortChannel.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.PortChannel.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.PortChannel.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.PortChannel.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.PortChannel.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.PortChannel.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.PortChannel.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.PortChannel.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.PortChannel.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.PortChannel.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.PortChannel.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.PortChannel.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.PortChannel.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.PortChannel.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.PortChannel.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.PortChannel.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.PortChannel.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.PortChannel.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.PortChannel.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.PortChannel.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.PortChannel.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.PortChannel.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.PortChannel.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.PortChannel.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.PortChannel.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.PortChannel.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.PortChannel.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.PortChannel.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.PortChannel.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.PortChannel.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.PortChannel.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.PortChannel.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.PortChannel.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.PortChannel.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.PortChannel.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.PortChannel.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.PortChannel.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.PortChannel.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.PortChannel.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.PortChannel.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.PortChannel.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.PortChannel.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.PortChannel.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.PortChannel.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.PortChannel.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.PortChannel.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.PortChannel.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.PortChannel.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.PortChannel.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.PortChannel.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.PortChannel.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.PortChannel.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.PortChannel.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.PortChannel.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.PortChannel.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.PortChannel.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Igmp>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Flow>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Nbar>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf>`
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Lisp>`
                
                .. attribute:: rsvp
                
                	RSVP Interface Commands
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Nat>`
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.PortChannel.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.PortChannel.Ip.Arp)), ("vrf", ("vrf", Native.Interface.PortChannel.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.PortChannel.Ip.NoAddress)), ("address", ("address", Native.Interface.PortChannel.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.PortChannel.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.PortChannel.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.PortChannel.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.PortChannel.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.PortChannel.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.PortChannel.Ip.Pim)), ("policy", ("policy", Native.Interface.PortChannel.Ip.Policy)), ("rip", ("rip", Native.Interface.PortChannel.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.PortChannel.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.PortChannel.Ip.RouteCache)), ("router", ("router", Native.Interface.PortChannel.Ip.Router)), ("tcp", ("tcp", Native.Interface.PortChannel.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.PortChannel.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.PortChannel.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.PortChannel.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.PortChannel.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.PortChannel.Ip.Igmp)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.PortChannel.Ip.Flow)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.PortChannel.Ip.Nbar)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.PortChannel.Ip.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.PortChannel.Ip.Lisp)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Interface.PortChannel.Ip.Rsvp)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.PortChannel.Ip.Nat)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.PortChannel.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.PortChannel.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.PortChannel.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.PortChannel.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.PortChannel.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.PortChannel.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.PortChannel.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.PortChannel.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.PortChannel.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.PortChannel.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.PortChannel.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.PortChannel.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.PortChannel.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.PortChannel.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.PortChannel.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.PortChannel.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.PortChannel.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.PortChannel.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.PortChannel.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.PortChannel.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.flow = Native.Interface.PortChannel.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.nbar = Native.Interface.PortChannel.Ip.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.ospf = Native.Interface.PortChannel.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.lisp = Native.Interface.PortChannel.Ip.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                    self.rsvp = Native.Interface.PortChannel.Ip.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

                    self.nat = Native.Interface.PortChannel.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.wccp = Native.Interface.PortChannel.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.PortChannel.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.PortChannel.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.PortChannel.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.PortChannel.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.PortChannel.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.PortChannel.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.PortChannel.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.PortChannel.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.PortChannel.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.PortChannel.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.PortChannel.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.PortChannel.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.PortChannel.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.PortChannel.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.PortChannel.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.PortChannel.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.PortChannel.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.PortChannel.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.PortChannel.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.PortChannel.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.PortChannel.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.PortChannel.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.PortChannel.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.PortChannel.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.PortChannel.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.PortChannel.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.PortChannel.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.PortChannel.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.PortChannel.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.PortChannel.Ip.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ip.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ip.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.PortChannel.Ip.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.PortChannel.Ip.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.PortChannel.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.PortChannel.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.PortChannel.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.PortChannel.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.PortChannel.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.PortChannel.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.PortChannel.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.PortChannel.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.PortChannel.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.PortChannel.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.PortChannel.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.PortChannel.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.PortChannel.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.PortChannel.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.PortChannel.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.PortChannel.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.PortChannel.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.PortChannel.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.PortChannel.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.PortChannel.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.PortChannel.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.PortChannel.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.PortChannel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.PortChannel.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.PortChannel.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.PortChannel.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.PortChannel.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannel.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.PortChannel.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.PortChannel.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.PortChannel.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.PortChannel.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.PortChannel.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.PortChannel.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.PortChannel.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.PortChannel.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.PortChannel.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.PortChannel.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.PortChannel.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.PortChannel.Ip.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ip.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.PortChannel.Ip.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.PortChannel.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.PortChannel.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.PortChannel.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.PortChannel.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.PortChannel.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.PortChannel.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.PortChannel.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.PortChannel.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.PortChannel.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.PortChannel.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.PortChannel.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.PortChannel.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.PortChannel.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.PortChannel.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.PortChannel.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.PortChannel.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.PortChannel.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.PortChannel.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.PortChannel.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.PortChannel.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.PortChannel.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.PortChannel.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.PortChannel.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.PortChannel.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Lisp(Entity):
                    """
                    Locator/ID Separation Protocol
                    
                    .. attribute:: source_locator
                    
                    	Choose IP source address for LISP packets egressing this interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_locator', (YLeaf(YType.str, 'source-locator'), ['str'])),
                        ])
                        self.source_locator = None
                        self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Lisp, ['source_locator'], name, value)


                class Rsvp(Entity):
                    """
                    RSVP Interface Commands
                    
                    .. attribute:: authentication
                    
                    	Enables RSVP neighbor authentication (RFC 2747)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bandwidth
                    
                    	RSVP Reservable Bandwidth (kbps)
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Bandwidth>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	Select permissible RSVP neighbors
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Neighbor>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: precedence
                    
                    	RSVP precedence setting
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Precedence>`
                    
                    .. attribute:: signalling
                    
                    	RSVP signalling
                    	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Signalling>`
                    
                    .. attribute:: tos
                    
                    	RSVP TOS setting
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Tos>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.PortChannel.Ip.Rsvp.Authentication)), ("bandwidth", ("bandwidth", Native.Interface.PortChannel.Ip.Rsvp.Bandwidth)), ("neighbor", ("neighbor", Native.Interface.PortChannel.Ip.Rsvp.Neighbor)), ("precedence", ("precedence", Native.Interface.PortChannel.Ip.Rsvp.Precedence)), ("signalling", ("signalling", Native.Interface.PortChannel.Ip.Rsvp.Signalling)), ("tos", ("tos", Native.Interface.PortChannel.Ip.Rsvp.Tos))])
                        self._leafs = OrderedDict()

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.bandwidth = None
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.neighbor = None
                        self._children_name_map["neighbor"] = "neighbor"

                        self.precedence = Native.Interface.PortChannel.Ip.Rsvp.Precedence()
                        self.precedence.parent = self
                        self._children_name_map["precedence"] = "precedence"

                        self.signalling = Native.Interface.PortChannel.Ip.Rsvp.Signalling()
                        self.signalling.parent = self
                        self._children_name_map["signalling"] = "signalling"

                        self.tos = Native.Interface.PortChannel.Ip.Rsvp.Tos()
                        self.tos.parent = self
                        self._children_name_map["tos"] = "tos"
                        self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp, [], name, value)


                    class Authentication(Entity):
                        """
                        Enables RSVP neighbor authentication (RFC 2747)
                        
                        .. attribute:: key
                        
                        	Password (8 to 40 characters, spaces allowed)
                        	**type**\: str
                        
                        .. attribute:: challenge
                        
                        	Perform challenge/response handshake with new neighbor(s)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key_chain
                        
                        	Name of key chain to use (as created by global 'key chain' command)
                        	**type**\: str
                        
                        .. attribute:: lifetime
                        
                        	Maximum lifetime of neighbor authentication state
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Authentication.Lifetime>`
                        
                        .. attribute:: type
                        
                        	Type of authentication algorithm (default = md5)
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Authentication.Type>`
                        
                        .. attribute:: window_size
                        
                        	Maximum number of messages allowed in receive window (default = 1)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Rsvp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Interface.PortChannel.Ip.Rsvp.Authentication.Lifetime))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ip.Rsvp.Authentication.Type')])),
                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                            ])
                            self.key = None
                            self.challenge = None
                            self.key_chain = None
                            self.type = None
                            self.window_size = None

                            self.lifetime = Native.Interface.PortChannel.Ip.Rsvp.Authentication.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Authentication, ['key', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Type of authentication algorithm (default = md5)

                            .. data:: md5 = 0

                            .. data:: sha_1 = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            sha_1 = Enum.YLeaf(1, "sha-1")



                        class Lifetime(Entity):
                            """
                            Maximum lifetime of neighbor authentication state
                            
                            .. attribute:: hh_mm_ss
                            
                            	Lifetime (default = 30 mins) in hh\:mm\:ss format
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ])
                                self.hh_mm_ss = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


                    class Bandwidth(Entity):
                        """
                        RSVP Reservable Bandwidth (kbps)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Value>`
                        
                        .. attribute:: percent
                        
                        	Percentage of interface bandwidth. Values higher than 100 represent overbooking
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: mam
                        
                        	Use bandwidth with MAM model of DSTE
                        	**type**\:  :py:class:`Mam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Mam>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Rsvp.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Value)), ("mam", ("mam", Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Mam))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                            ])
                            self.percent = None

                            self.value = Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.mam = Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Mam()
                            self.mam.parent = self
                            self._children_name_map["mam"] = "mam"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Bandwidth, ['percent'], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	Reservable Bandwidth (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            .. attribute:: sub_pool
                            
                            	Reservable Bandwidth for Tunnel using sub (BC1) pool (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.value = None
                                self.sub_pool = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Value, ['value', 'sub_pool'], name, value)


                        class Mam(Entity):
                            """
                            Use bandwidth with MAM model of DSTE
                            
                            .. attribute:: max_reservable_bw
                            
                            	Maximum Reservable bandwidth for MAM
                            	**type**\:  :py:class:`MaxReservableBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Mam, self).__init__()

                                self.yang_name = "mam"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("max-reservable-bw", ("max_reservable_bw", Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw))])
                                self._leafs = OrderedDict()

                                self.max_reservable_bw = None
                                self._children_name_map["max_reservable_bw"] = "max-reservable-bw"
                                self._segment_path = lambda: "mam"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Mam, [], name, value)


                            class MaxReservableBw(Entity):
                                """
                                Maximum Reservable bandwidth for MAM
                                
                                .. attribute:: value
                                
                                	Reservable Bandwidth (kbps)
                                	**type**\: int
                                
                                	**range:** 1..10000000
                                
                                .. attribute:: bc0
                                
                                	Reservable Bandwidth from global (BC0) pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                .. attribute:: bc1
                                
                                	Reservable Bandwidth from sub pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, self).__init__()

                                    self.yang_name = "max-reservable-bw"
                                    self.yang_parent_name = "mam"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                        ('bc0', (YLeaf(YType.uint32, 'bc0'), ['int'])),
                                        ('bc1', (YLeaf(YType.uint32, 'bc1'), ['int'])),
                                    ])
                                    self.value = None
                                    self.bc0 = None
                                    self.bc1 = None
                                    self._segment_path = lambda: "max-reservable-bw"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, ['value', 'bc0', 'bc1'], name, value)


                    class Neighbor(Entity):
                        """
                        Select permissible RSVP neighbors
                        
                        .. attribute:: acl_number
                        
                        	Access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Rsvp.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                            ])
                            self.acl_number = None
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Neighbor, ['acl_number'], name, value)


                    class Precedence(Entity):
                        """
                        RSVP precedence setting
                        
                        .. attribute:: conform
                        
                        	Precedence for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: exceed
                        
                        	Precedence for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Rsvp.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Precedence, ['conform', 'exceed'], name, value)


                    class Signalling(Entity):
                        """
                        RSVP signalling
                        
                        .. attribute:: dscp
                        
                        	DSCP for RSVP signalling messages
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: fast_local_repair
                        
                        	Fast Local Repair parameters
                        	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Signalling.FastLocalRepair>`
                        
                        .. attribute:: hello
                        
                        	Enable neighbor\-down detection
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Rsvp.Signalling, self).__init__()

                            self.yang_name = "signalling"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Interface.PortChannel.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.fast_local_repair = Native.Interface.PortChannel.Ip.Rsvp.Signalling.FastLocalRepair()
                            self.fast_local_repair.parent = self
                            self._children_name_map["fast_local_repair"] = "fast-local-repair"

                            self.hello = None
                            self._children_name_map["hello"] = "hello"
                            self._segment_path = lambda: "signalling"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Signalling, ['dscp'], name, value)


                        class FastLocalRepair(Entity):
                            """
                            Fast Local Repair parameters
                            
                            .. attribute:: wait_time
                            
                            	Wait Time for start of Fast Local Repair in msec
                            	**type**\: int
                            
                            	**range:** 0..5000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                                self.yang_name = "fast-local-repair"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint16, 'wait-time'), ['int'])),
                                ])
                                self.wait_time = None
                                self._segment_path = lambda: "fast-local-repair"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Signalling.FastLocalRepair, ['wait_time'], name, value)


                        class Hello(Entity):
                            """
                            Enable neighbor\-down detection
                            
                            .. attribute:: bfd
                            
                            	Configure BFD trigger for MPLS/TE FRR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	DSCP for RSVP Hello messages
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: graceful_restart
                            
                            	Configure RSVP Graceful Restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: refresh
                            
                            	Configure RSVP Hello refresh behavior for Fast\-Reroute
                            	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Refresh>`
                            
                            .. attribute:: reroute
                            
                            	Configure RSVP Hello refresh behavior for Reroute
                            	**type**\:  :py:class:`Reroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Reroute>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Refresh)), ("reroute", ("reroute", Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Reroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ('graceful_restart', (YLeaf(YType.empty, 'graceful-restart'), ['Empty'])),
                                ])
                                self.bfd = None
                                self.dscp = None
                                self.graceful_restart = None

                                self.refresh = Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Refresh()
                                self.refresh.parent = self
                                self._children_name_map["refresh"] = "refresh"

                                self.reroute = Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Reroute()
                                self.reroute.parent = self
                                self._children_name_map["reroute"] = "reroute"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello, ['bfd', 'dscp', 'graceful_restart'], name, value)


                            class Refresh(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Fast\-Reroute
                                
                                .. attribute:: interval
                                
                                	Hello interval in msec
                                	**type**\: int
                                
                                	**range:** 10..30000
                                
                                .. attribute:: misses
                                
                                	Number of missed Hello Acks which triggers neighbor down
                                	**type**\: int
                                
                                	**range:** 4..10
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Refresh, self).__init__()

                                    self.yang_name = "refresh"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.misses = None
                                    self._segment_path = lambda: "refresh"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Refresh, ['interval', 'misses'], name, value)


                            class Reroute(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Reroute
                                
                                .. attribute:: dscp
                                
                                	DSCP for RSVP Hello messages
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: refresh
                                
                                	Configure RSVP Reroute Hello refresh behavior
                                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Reroute.Refresh>`
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Reroute, self).__init__()

                                    self.yang_name = "reroute"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Reroute.Refresh))])
                                    self._leafs = OrderedDict([
                                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ])
                                    self.dscp = None

                                    self.refresh = Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Reroute.Refresh()
                                    self.refresh.parent = self
                                    self._children_name_map["refresh"] = "refresh"
                                    self._segment_path = lambda: "reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Reroute, ['dscp'], name, value)


                                class Refresh(Entity):
                                    """
                                    Configure RSVP Reroute Hello refresh behavior
                                    
                                    .. attribute:: interval
                                    
                                    	Hello Reroute interval in msec
                                    	**type**\: int
                                    
                                    	**range:** 1000..30000
                                    
                                    .. attribute:: misses
                                    
                                    	Number of missed Hello Acks which triggers neighbor down
                                    	**type**\: int
                                    
                                    	**range:** 4..10
                                    
                                    

                                    """

                                    _prefix = 'ios-rsvp'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, self).__init__()

                                        self.yang_name = "refresh"
                                        self.yang_parent_name = "reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.misses = None
                                        self._segment_path = lambda: "refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, ['interval', 'misses'], name, value)


                    class Tos(Entity):
                        """
                        RSVP TOS setting
                        
                        .. attribute:: conform
                        
                        	TOS for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: exceed
                        
                        	TOS for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Rsvp.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Rsvp.Tos, ['conform', 'exceed'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.PortChannel.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.PortChannel.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.PortChannel.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.PortChannel.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.PortChannel.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.PortChannel.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.PortChannel.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.PortChannel.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.PortChannel.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.PortChannel.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.PortChannel.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.PortChannel.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.PortChannel.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.PortChannel.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.PortChannel.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.PortChannel.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.PortChannel.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.PortChannel.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.PortChannel.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.TrafficFilter>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Flow>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Crypto>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Pim>`
                
                .. attribute:: rip
                
                	Configure RIP routing protocol
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Rip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.PortChannel.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.PortChannel.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.PortChannel.Ipv6.Dhcp)), ("address", ("address", Native.Interface.PortChannel.Ipv6.Address)), ("nd", ("nd", Native.Interface.PortChannel.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.PortChannel.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.PortChannel.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.PortChannel.Ipv6.Flow)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.PortChannel.Ipv6.Crypto)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.PortChannel.Ipv6.Ospf)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.PortChannel.Ipv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.PortChannel.Ipv6.Pim)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Interface.PortChannel.Ipv6.Rip))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.PortChannel.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.PortChannel.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.PortChannel.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.PortChannel.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.flow = Native.Interface.PortChannel.Ipv6.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.crypto = Native.Interface.PortChannel.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.ospf = Native.Interface.PortChannel.Ipv6.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.no_pim = Native.Interface.PortChannel.Ipv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.PortChannel.Ipv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.PortChannel.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.PortChannel.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.PortChannel.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.PortChannel.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.PortChannel.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.PortChannel.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.PortChannel.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.PortChannel.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.PortChannel.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.PortChannel.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.PortChannel.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.PortChannel.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.PortChannel.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.PortChannel.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.PortChannel.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.PortChannel.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.PortChannel.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.PortChannel.Ipv6.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.PortChannel.Ipv6.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ipv6.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ipv6.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ipv6.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Crypto, ['map'], name, value)


                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process
                    
                    	
                    	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Process>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: encryption
                    
                    	Enable encryption
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Network>`
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process", ("process", Native.Interface.PortChannel.Ipv6.Ospf.Process)), ("authentication", ("authentication", Native.Interface.PortChannel.Ipv6.Ospf.Authentication)), ("bfd", ("bfd", Native.Interface.PortChannel.Ipv6.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.PortChannel.Ipv6.Ospf.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.PortChannel.Ipv6.Ospf.DemandCircuit)), ("encryption", ("encryption", Native.Interface.PortChannel.Ipv6.Ospf.Encryption)), ("flood-reduction", ("flood_reduction", Native.Interface.PortChannel.Ipv6.Ospf.FloodReduction)), ("mtu-ignore", ("mtu_ignore", Native.Interface.PortChannel.Ipv6.Ospf.MtuIgnore)), ("neighbor", ("neighbor", Native.Interface.PortChannel.Ipv6.Ospf.Neighbor)), ("network", ("network", Native.Interface.PortChannel.Ipv6.Ospf.Network)), ("shutdown", ("shutdown", Native.Interface.PortChannel.Ipv6.Ospf.Shutdown))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.cost = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.PortChannel.Ipv6.Ospf.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.PortChannel.Ipv6.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.encryption = Native.Interface.PortChannel.Ipv6.Ospf.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.network = Native.Interface.PortChannel.Ipv6.Ospf.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.process = YList(self)
                        self.neighbor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf, ['cost', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Process(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: instance
                        
                        	Set the OSPF instance
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..31
                        
                        		**type**\: int
                        
                        			**range:** 32..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Ospf.Process, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['int','int'])),
                            ])
                            self.id = None
                            self.area = None
                            self.instance = None
                            self._segment_path = lambda: "process" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Process, ['id', 'area', 'instance'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec authentication
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Authentication, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec authentication
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 256..4294967295
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5>`
                            
                            .. attribute:: sha1
                            
                            	Use SHA\-1 authentication
                            	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ])
                                self.spi = None

                                self.md5 = Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.sha1 = Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1()
                                self.sha1.parent = self
                                self._children_name_map["sha1"] = "sha1"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec, ['spi'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Sha1(Entity):
                                """
                                Use SHA\-1 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1, self).__init__()

                                    self.yang_name = "sha1"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "sha1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "sha1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ipv6.Ospf.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.DatabaseFilter, ['all', 'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.DemandCircuit, ['disable', 'ignore'], name, value)


                    class Encryption(Entity):
                        """
                        Enable encryption
                        
                        .. attribute:: null
                        
                        	No IPsec encryption on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec encryption
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Ospf.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Encryption, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec encryption
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: esp
                            
                            	Use ESP encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipsec_3des
                            
                            	Use 3DES encryption
                            	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des>`
                            
                            .. attribute:: aes_cbc
                            
                            	Use AES\-CBC encryption
                            	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                                ])
                                self.spi = None
                                self.esp = None

                                self.ipsec_3des = Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des()
                                self.ipsec_3des.parent = self
                                self._children_name_map["ipsec_3des"] = "ipsec_3des"

                                self.aes_cbc = Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc()
                                self.aes_cbc.parent = self
                                self._children_name_map["aes_cbc"] = "aes-cbc"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec, ['spi', 'esp'], name, value)


                            class Ipsec3des(Entity):
                                """
                                Use 3DES encryption
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, self).__init__()

                                    self.yang_name = "ipsec_3des"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "ipsec_3des"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "ipsec_3des"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class AesCbc(Entity):
                                """
                                Use AES\-CBC encryption
                                
                                .. attribute:: aes_cbc_128
                                
                                	Use 128 bit key
                                	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128>`
                                
                                .. attribute:: aes_192
                                
                                	Use 192 bit key
                                	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192>`
                                
                                .. attribute:: aes_256
                                
                                	Use 256 bit key
                                	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc, self).__init__()

                                    self.yang_name = "aes-cbc"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256))])
                                    self._leafs = OrderedDict()

                                    self.aes_cbc_128 = Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128()
                                    self.aes_cbc_128.parent = self
                                    self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                    self.aes_192 = Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192()
                                    self.aes_192.parent = self
                                    self._children_name_map["aes_192"] = "aes-192"

                                    self.aes_256 = Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256()
                                    self.aes_256.parent = self
                                    self._children_name_map["aes_256"] = "aes-256"
                                    self._segment_path = lambda: "aes-cbc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc, [], name, value)


                                class AesCbc128(Entity):
                                    """
                                    Use 128 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                        self.yang_name = "aes-cbc-128"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-cbc-128"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-cbc-128"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes192(Entity):
                                    """
                                    Use 192 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                        self.yang_name = "aes-192"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-192"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-192"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes256(Entity):
                                    """
                                    Use 256 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                        self.yang_name = "aes-256"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-256"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	Disable Flood Reduction on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Ospf.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.FloodReduction, ['disable'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Ospf.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.MtuIgnore, ['disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Ospf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.PortChannel.Ipv6.Ospf.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.PortChannel.Ipv6.Ospf.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ipv6.Ospf.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ipv6.Ospf.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Ospf.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Ospf.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.PortChannel.Ipv6.Ospf.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ipv6.Ospf.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Ospf.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Ospf.Shutdown, ['disable'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.PortChannel.Ipv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.PortChannel.Ipv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Pim.Bsr, ['border'], name, value)


                class Rip(Entity):
                    """
                    Configure RIP routing protocol
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable/disable RIP routing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default_information
                    
                    	Configure handling of default route
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Rip.DefaultInformation>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ipv6.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("default-information", ("default_information", Native.Interface.PortChannel.Ipv6.Rip.DefaultInformation))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.id = None
                        self.enable = None

                        self.default_information = Native.Interface.PortChannel.Ipv6.Rip.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ipv6.Rip, ['id', 'enable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Configure handling of default route
                        
                        .. attribute:: route
                        
                        	
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ipv6.Rip.DefaultInformation.Route>`
                        
                        .. attribute:: metric
                        
                        	Default route metric
                        	**type**\: int
                        
                        	**range:** 1..15
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ipv6.Rip.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route', (YLeaf(YType.enumeration, 'route'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ipv6.Rip.DefaultInformation.Route')])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ])
                            self.route = None
                            self.metric = None
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ipv6.Rip.DefaultInformation, ['route', 'metric'], name, value)

                        class Route(Enum):
                            """
                            Route (Enum Class)

                            .. data:: only = 0

                            .. data:: originate = 1

                            """

                            only = Enum.YLeaf(0, "only")

                            originate = Enum.YLeaf(1, "originate")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.PortChannel.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.PortChannel.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.PortChannel.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.PortChannel.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.PortChannel.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.PortChannel.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.PortChannel.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.PortChannel.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.PortChannel.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.PortChannel.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.PortChannel.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.PortChannel.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.PortChannel.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.PortChannel.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.PortChannel.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.PortChannel.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.PortChannel.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.PortChannel.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.PortChannel.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.PortChannel.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.PortChannel.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.PortChannel.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.PortChannel.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.PortChannel.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.PortChannel.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.PortChannel.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.PortChannel.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.PortChannel.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.PortChannel.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.PortChannel.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.PortChannel.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.PortChannel.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.PortChannel.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.PortChannel.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.PortChannel.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.PortChannel.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.PortChannel.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.PortChannel.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannel.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.PortChannel.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.PortChannel.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.PortChannel.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.PortChannel.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.PortChannel.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.PortChannel.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.PortChannel.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.PortChannel.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.PortChannel.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.PortChannel.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.PortChannel.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannel.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.PortChannel.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.PortChannel.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.PortChannel.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.PortChannel.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.PortChannel.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.PortChannel.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.PortChannel.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannel.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.PortChannel.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.PortChannel.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.PortChannel.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.PortChannel.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.PortChannel.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.PortChannel.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.PortChannel.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannel.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.PortChannel.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.PortChannel.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.PortChannel.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.PortChannel.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.PortChannel.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.PortChannel.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.PortChannel.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.PortChannel.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.PortChannel.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.PortChannel.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.PortChannel.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.PortChannel.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.PortChannel.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.PortChannel.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.PortChannel.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.PortChannel.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannel.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.PortChannel.CarrierDelay.Down)), ("up", ("up", Native.Interface.PortChannel.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.PortChannel.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.PortChannel.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannel.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannel.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.PortChannel.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.PortChannel.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.PortChannel.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.PortChannel.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.PortChannel.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.PortChannel.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.PortChannel.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.PortChannel.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.PortChannel.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.PortChannel.Plim.Ethernet)), ("qos", ("qos", Native.Interface.PortChannel.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.PortChannel.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.PortChannel.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannel.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.PortChannel.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.PortChannel.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.PortChannel.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.PortChannel.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.PortChannel.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.PortChannel.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.PortChannel.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.PortChannel.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.PortChannel.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.PortChannel.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.PortChannel.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.PortChannel.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.PortChannel.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.PortChannel.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.PortChannel.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.PortChannel.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.PortChannel.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.L2protocol>`
                    
                    .. attribute:: xconnect
                    
                    	
                    	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Xconnect>`
                    
                    .. attribute:: xconnect_pw_class
                    
                    	
                    	**type**\:  :py:class:`XconnectPwClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.XconnectPwClass>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.PortChannel.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.PortChannel.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.PortChannel.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.PortChannel.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.PortChannel.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.PortChannel.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.PortChannel.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.PortChannel.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.PortChannel.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.PortChannel.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.PortChannel.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.PortChannel.Service.Instance.L2protocol)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.Interface.PortChannel.Service.Instance.Xconnect)), ("Cisco-IOS-XE-l2vpn:xconnect-pw-class", ("xconnect_pw_class", Native.Interface.PortChannel.Service.Instance.XconnectPwClass))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.PortChannel.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.PortChannel.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.PortChannel.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.PortChannel.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.PortChannel.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.PortChannel.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.PortChannel.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.PortChannel.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.PortChannel.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.PortChannel.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.PortChannel.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.PortChannel.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"

                        self.xconnect = Native.Interface.PortChannel.Service.Instance.Xconnect()
                        self.xconnect.parent = self
                        self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

                        self.xconnect_pw_class = Native.Interface.PortChannel.Service.Instance.XconnectPwClass()
                        self.xconnect_pw_class.parent = self
                        self._children_name_map["xconnect_pw_class"] = "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.PortChannel.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.PortChannel.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.PortChannel.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.PortChannel.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.PortChannel.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.PortChannel.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.PortChannel.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.PortChannel.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.PortChannel.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.PortChannel.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.PortChannel.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.PortChannel.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.PortChannel.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.PortChannel.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.PortChannel.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.PortChannel.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.PortChannel.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.PortChannel.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.PortChannel.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.PortChannel.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.PortChannel.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.PortChannel.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.PortChannel.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.PortChannel.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.PortChannel.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.PortChannel.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.PortChannel.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.PortChannel.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.PortChannel.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.PortChannel.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.PortChannel.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.PortChannel.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                    class Xconnect(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vcid
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Xconnect.Encapsulation>`
                        
                        .. attribute:: manual
                        
                        	Manually configure L2TP session parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pw_class
                        
                        	Optional pseudowire\-class to use for advanced configuration
                        	**type**\: str
                        
                        .. attribute:: sequencing
                        
                        	Configure sequencing options for xconnect
                        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Xconnect.Sequencing>`
                        
                        .. attribute:: backup
                        
                        	Xconnect backup configuration commands
                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Xconnect.Backup>`
                        
                        .. attribute:: mtu
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.Xconnect, self).__init__()

                            self.yang_name = "xconnect"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backup", ("backup", Native.Interface.PortChannel.Service.Instance.Xconnect.Backup))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Xconnect.Encapsulation')])),
                                ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                                ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ('sequencing', (YLeaf(YType.enumeration, 'sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Service.Instance.Xconnect.Sequencing')])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.address = None
                            self.vcid = None
                            self.encapsulation = None
                            self.manual = None
                            self.pw_class = None
                            self.sequencing = None
                            self.mtu = None

                            self.backup = Native.Interface.PortChannel.Service.Instance.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'pw_class', 'sequencing', 'mtu'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Data encapsulation method

                            .. data:: mpls = 0

                            .. data:: l2tpv3 = 1

                            """

                            mpls = Enum.YLeaf(0, "mpls")

                            l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                        class Sequencing(Enum):
                            """
                            Sequencing (Enum Class)

                            Configure sequencing options for xconnect

                            .. data:: both = 0

                            .. data:: receive = 1

                            .. data:: transmit = 2

                            """

                            both = Enum.YLeaf(0, "both")

                            receive = Enum.YLeaf(1, "receive")

                            transmit = Enum.YLeaf(2, "transmit")



                        class Backup(Entity):
                            """
                            Xconnect backup configuration commands
                            
                            .. attribute:: peer
                            
                            	Backup pseudowire
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Xconnect.Backup.Peer>`
                            
                            .. attribute:: delay
                            
                            	backup delay time
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.Xconnect.Backup.Delay>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.Xconnect.Backup, self).__init__()

                                self.yang_name = "backup"
                                self.yang_parent_name = "xconnect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.PortChannel.Service.Instance.Xconnect.Backup.Peer)), ("delay", ("delay", Native.Interface.PortChannel.Service.Instance.Xconnect.Backup.Delay))])
                                self._leafs = OrderedDict()

                                self.peer = Native.Interface.PortChannel.Service.Instance.Xconnect.Backup.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.delay = Native.Interface.PortChannel.Service.Instance.Xconnect.Backup.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Xconnect.Backup, [], name, value)


                            class Peer(Entity):
                                """
                                Backup pseudowire
                                
                                .. attribute:: peer_router_ip_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vcid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_class
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: priority
                                
                                	Optional priority to use for backup pseudowire
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.Xconnect.Backup.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_router_ip_addr', (YLeaf(YType.str, 'peer-router-ip-addr'), ['str'])),
                                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.peer_router_ip_addr = None
                                    self.vcid = None
                                    self.pw_class = None
                                    self.priority = None
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Xconnect.Backup.Peer, ['peer_router_ip_addr', 'vcid', 'pw_class', 'priority'], name, value)


                            class Delay(Entity):
                                """
                                backup delay time
                                
                                .. attribute:: min
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.Xconnect.Backup.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                                    ])
                                    self.min = None
                                    self.max = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.Xconnect.Backup.Delay, ['min', 'max'], name, value)


                    class XconnectPwClass(Entity):
                        """
                        
                        
                        .. attribute:: xconnect
                        
                        	Xconnect commands
                        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Service.Instance.XconnectPwClass, self).__init__()

                            self.yang_name = "xconnect-pw-class"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xconnect", ("xconnect", Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect))])
                            self._leafs = OrderedDict()

                            self.xconnect = Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect()
                            self.xconnect.parent = self
                            self._children_name_map["xconnect"] = "xconnect"
                            self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect-pw-class"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Service.Instance.XconnectPwClass, [], name, value)


                        class Xconnect(Entity):
                            """
                            Xconnect commands
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vcid
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_class
                            
                            	Pseudowire\-class to use for encapsulation and protocol configuration
                            	**type**\: str
                            
                            .. attribute:: udp
                            
                            	UDP
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect.Udp>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect, self).__init__()

                                self.yang_name = "xconnect"
                                self.yang_parent_name = "xconnect-pw-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect.Udp))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                                    ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                                ])
                                self.address = None
                                self.vcid = None
                                self.pw_class = None

                                self.udp = Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "xconnect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect, ['address', 'vcid', 'pw_class'], name, value)


                            class Udp(Entity):
                                """
                                UDP
                                
                                .. attribute:: port
                                
                                	UDP ports
                                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect.Udp.Port>`
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "xconnect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect.Udp.Port))])
                                    self._leafs = OrderedDict()

                                    self.port = Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect.Udp.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect.Udp, [], name, value)


                                class Port(Entity):
                                    """
                                    UDP ports
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                            ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                        ])
                                        self.local = None
                                        self.remote = None
                                        self._segment_path = lambda: "port"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Service.Instance.XconnectPwClass.Xconnect.Udp.Port, ['local', 'remote'], name, value)


            class Lacp(Entity):
                """
                LACP Port Channel interface subcommands
                
                .. attribute:: failover
                
                	Link failover options
                	**type**\:  :py:class:`Failover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Lacp.Failover>`
                
                .. attribute:: fast_switchover
                
                	Enable LACP fast switchover on this port channel
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: max_bundle
                
                	LACP maximum number of ports to bundle in this port channel
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: min_bundle
                
                	LACP minimum number of ports to bundle in this port channel
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.Lacp, self).__init__()

                    self.yang_name = "lacp"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('failover', (YLeaf(YType.enumeration, 'failover'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Lacp.Failover')])),
                        ('fast_switchover', (YLeaf(YType.empty, 'fast-switchover'), ['Empty'])),
                        ('max_bundle', (YLeaf(YType.uint8, 'max-bundle'), ['int'])),
                        ('min_bundle', (YLeaf(YType.uint8, 'min-bundle'), ['int'])),
                    ])
                    self.failover = None
                    self.fast_switchover = None
                    self.max_bundle = None
                    self.min_bundle = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:lacp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Lacp, ['failover', 'fast_switchover', 'max_bundle', 'min_bundle'], name, value)

                class Failover(Enum):
                    """
                    Failover (Enum Class)

                    Link failover options

                    .. data:: brute_force = 0

                    .. data:: non_revertive = 1

                    """

                    brute_force = Enum.YLeaf(0, "brute-force")

                    non_revertive = Enum.YLeaf(1, "non-revertive")



            class Mlacp(Entity):
                """
                mLACP Port Channel interface subcommands
                
                .. attribute:: interchassis
                
                	mLACP Interchassis commands
                	**type**\:  :py:class:`Interchassis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mlacp.Interchassis>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.PortChannel.Mlacp, self).__init__()

                    self.yang_name = "mlacp"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interchassis", ("interchassis", Native.Interface.PortChannel.Mlacp.Interchassis))])
                    self._leafs = OrderedDict()

                    self.interchassis = Native.Interface.PortChannel.Mlacp.Interchassis()
                    self.interchassis.parent = self
                    self._children_name_map["interchassis"] = "interchassis"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:mlacp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Mlacp, [], name, value)


                class Interchassis(Entity):
                    """
                    mLACP Interchassis commands
                    
                    .. attribute:: group
                    
                    	Interchassis Group
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Mlacp.Interchassis, self).__init__()

                        self.yang_name = "interchassis"
                        self.yang_parent_name = "mlacp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "interchassis"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Mlacp.Interchassis, ['group'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.PortChannel.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.PortChannel.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.PortChannel.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.PortChannel.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.PortChannel.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.PortChannel.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.PortChannel.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Auto(Entity):
                """
                Configure Automation
                
                .. attribute:: qos
                
                	Configure AutoQoS
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Auto.Qos>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.Auto, self).__init__()

                    self.yang_name = "auto"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("qos", ("qos", Native.Interface.PortChannel.Auto.Qos))])
                    self._leafs = OrderedDict()

                    self.qos = Native.Interface.PortChannel.Auto.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:auto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Auto, [], name, value)


                class Qos(Entity):
                    """
                    Configure AutoQoS
                    
                    .. attribute:: classify
                    
                    	Configure classification for untrusted devices
                    	**type**\:  :py:class:`Classify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Auto.Qos.Classify>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trust
                    
                    	Trust the DSCP/CoS marking
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Auto.Qos.Trust>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: video
                    
                    	Configure AutoQoS for video devices
                    	**type**\:  :py:class:`Video <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Auto.Qos.Video>`
                    
                    .. attribute:: voip
                    
                    	Configure AutoQoS for VoIP
                    	**type**\:  :py:class:`Voip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Auto.Qos.Voip>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Auto.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "auto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("classify", ("classify", Native.Interface.PortChannel.Auto.Qos.Classify)), ("trust", ("trust", Native.Interface.PortChannel.Auto.Qos.Trust)), ("video", ("video", Native.Interface.PortChannel.Auto.Qos.Video)), ("voip", ("voip", Native.Interface.PortChannel.Auto.Qos.Voip))])
                        self._leafs = OrderedDict()

                        self.classify = None
                        self._children_name_map["classify"] = "classify"

                        self.trust = None
                        self._children_name_map["trust"] = "trust"

                        self.video = Native.Interface.PortChannel.Auto.Qos.Video()
                        self.video.parent = self
                        self._children_name_map["video"] = "video"

                        self.voip = None
                        self._children_name_map["voip"] = "voip"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Auto.Qos, [], name, value)


                    class Classify(Entity):
                        """
                        Configure classification for untrusted devices
                        
                        .. attribute:: police
                        
                        	Configure QoS policing for untrusted devices
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Auto.Qos.Classify, self).__init__()

                            self.yang_name = "classify"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('police', (YLeaf(YType.empty, 'police'), ['Empty'])),
                            ])
                            self.police = None
                            self._segment_path = lambda: "classify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Auto.Qos.Classify, [u'police'], name, value)


                    class Trust(Entity):
                        """
                        Trust the DSCP/CoS marking
                        
                        .. attribute:: cos
                        
                        	Trust the CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dscp
                        
                        	Trust the DSCP marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Auto.Qos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cos', (YLeaf(YType.empty, 'cos'), ['Empty'])),
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ])
                            self.cos = None
                            self.dscp = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Auto.Qos.Trust, [u'cos', u'dscp'], name, value)


                    class Video(Entity):
                        """
                        Configure AutoQoS for video devices
                        
                        .. attribute:: cts
                        
                        	Trust the QoS marking of the Cisco Telepresence System
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ip_camera
                        
                        	Trust the QoS marking of the Ip Video Surveillance camera
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: media_player
                        
                        	Trust the Qos marking of the Cisco Media Player
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Auto.Qos.Video, self).__init__()

                            self.yang_name = "video"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('cts', (YLeaf(YType.empty, 'cts'), ['Empty'])),
                                ('ip_camera', (YLeaf(YType.empty, 'ip-camera'), ['Empty'])),
                                ('media_player', (YLeaf(YType.empty, 'media-player'), ['Empty'])),
                            ])
                            self.cts = None
                            self.ip_camera = None
                            self.media_player = None
                            self._segment_path = lambda: "video"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Auto.Qos.Video, [u'cts', u'ip_camera', u'media_player'], name, value)


                    class Voip(Entity):
                        """
                        Configure AutoQoS for VoIP
                        
                        .. attribute:: cisco_phone
                        
                        	Trust the QoS marking of Cisco IP Phone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cisco_softphone
                        
                        	Trust the QoS marking of Cisco IP SoftPhone
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trust
                        
                        	Trust the DSCP/CoS marking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Auto.Qos.Voip, self).__init__()

                            self.yang_name = "voip"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cisco_phone', (YLeaf(YType.empty, 'cisco-phone'), ['Empty'])),
                                ('cisco_softphone', (YLeaf(YType.empty, 'cisco-softphone'), ['Empty'])),
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.cisco_phone = None
                            self.cisco_softphone = None
                            self.trust = None
                            self._segment_path = lambda: "voip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Auto.Qos.Voip, [u'cisco_phone', u'cisco_softphone', u'trust'], name, value)


            class Datalink(Entity):
                """
                Interface Datalink commands
                
                .. attribute:: flow
                
                	Interface Flow configuration subcommands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Datalink.Flow>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.Datalink, self).__init__()

                    self.yang_name = "datalink"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flow", ("flow", Native.Interface.PortChannel.Datalink.Flow))])
                    self._leafs = OrderedDict()

                    self.flow = Native.Interface.PortChannel.Datalink.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:datalink"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Datalink, [], name, value)


                class Flow(Entity):
                    """
                    Interface Flow configuration subcommands
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Datalink.Flow.Monitor>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Datalink.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "datalink"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.PortChannel.Datalink.Flow.Monitor))])
                        self._leafs = OrderedDict()

                        self.monitor = None
                        self._children_name_map["monitor"] = "monitor"
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Datalink.Flow, [], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: user_defined_flow
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: input_output
                        
                        	Apply Flow Monitor on input/output traffic
                        	**type**\:  :py:class:`InputOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Datalink.Flow.Monitor.InputOutput>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Datalink.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('user_defined_flow', (YLeaf(YType.str, 'User-defined-flow'), ['str'])),
                                ('input_output', (YLeaf(YType.enumeration, 'input-output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Datalink.Flow.Monitor.InputOutput')])),
                            ])
                            self.user_defined_flow = None
                            self.input_output = None
                            self._segment_path = lambda: "monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Datalink.Flow.Monitor, [u'user_defined_flow', u'input_output'], name, value)

                        class InputOutput(Enum):
                            """
                            InputOutput (Enum Class)

                            Apply Flow Monitor on input/output traffic

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



            class Energywise(Entity):
                """
                EnergyWise interface configurations
                
                .. attribute:: activitycheck
                
                	Apply an activity check before turning off power    to this PoE port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: level
                
                	Set the EnergyWise level of this interface  or attached entity
                	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Energywise.Level>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.Energywise, self).__init__()

                    self.yang_name = "energywise"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Interface.PortChannel.Energywise.Level))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('activitycheck', (YLeaf(YType.empty, 'activitycheck'), ['Empty'])),
                    ])
                    self.activitycheck = None

                    self.level = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:energywise"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Energywise, [u'activitycheck'], name, value)


                class Level(Entity):
                    """
                    Set the EnergyWise level of this interface 
                    or attached entity
                    
                    .. attribute:: range  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..10
                    
                    .. attribute:: recurrence
                    
                    	Specify that this level setting should  recur at the specified time
                    	**type**\:  :py:class:`Recurrence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Energywise.Level.Recurrence>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Energywise.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "energywise"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("recurrence", ("recurrence", Native.Interface.PortChannel.Energywise.Level.Recurrence))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                        ])
                        self.range = None

                        self.recurrence = Native.Interface.PortChannel.Energywise.Level.Recurrence()
                        self.recurrence.parent = self
                        self._children_name_map["recurrence"] = "recurrence"
                        self._segment_path = lambda: "level" + "[range='" + str(self.range) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Energywise.Level, [u'range'], name, value)


                    class Recurrence(Entity):
                        """
                        Specify that this level setting should 
                        recur at the specified time
                        
                        .. attribute:: importance
                        
                        	Specify the importance at which the event  should be sent when it recurs
                        	**type**\: list of  		 :py:class:`Importance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Energywise.Level.Recurrence.Importance>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Energywise.Level.Recurrence, self).__init__()

                            self.yang_name = "recurrence"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("importance", ("importance", Native.Interface.PortChannel.Energywise.Level.Recurrence.Importance))])
                            self._leafs = OrderedDict()

                            self.importance = YList(self)
                            self._segment_path = lambda: "recurrence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Energywise.Level.Recurrence, [], name, value)


                        class Importance(Entity):
                            """
                            Specify the importance at which the event 
                            should be sent when it recurs
                            
                            .. attribute:: range  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: at
                            
                            	Specify the time(s) this level setting should occur
                            	**type**\:  :py:class:`At <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Energywise.Level.Recurrence.Importance.At>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Energywise.Level.Recurrence.Importance, self).__init__()

                                self.yang_name = "importance"
                                self.yang_parent_name = "recurrence"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("at", ("at", Native.Interface.PortChannel.Energywise.Level.Recurrence.Importance.At))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.at = Native.Interface.PortChannel.Energywise.Level.Recurrence.Importance.At()
                                self.at.parent = self
                                self._children_name_map["at"] = "at"
                                self._segment_path = lambda: "importance" + "[range='" + str(self.range) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Energywise.Level.Recurrence.Importance, [u'range'], name, value)


                            class At(Entity):
                                """
                                Specify the time(s) this level setting should occur
                                
                                .. attribute:: minute
                                
                                	cron format of minute(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..59
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: hour
                                
                                	cron format of hour(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..23
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: day
                                
                                	cron format of day(s) of month
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..31
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: month
                                
                                	cron format of month(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..12
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                .. attribute:: weekday
                                
                                	cron format of weekday(s)
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..7
                                
                                		**type**\: str
                                
                                			**pattern:** [\*].\*
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Energywise.Level.Recurrence.Importance.At, self).__init__()

                                    self.yang_name = "at"
                                    self.yang_parent_name = "importance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minute', (YLeaf(YType.str, 'minute'), ['int','str'])),
                                        ('hour', (YLeaf(YType.str, 'hour'), ['int','str'])),
                                        ('day', (YLeaf(YType.str, 'day'), ['int','str'])),
                                        ('month', (YLeaf(YType.str, 'month'), ['int','str'])),
                                        ('weekday', (YLeaf(YType.str, 'weekday'), ['int','str'])),
                                    ])
                                    self.minute = None
                                    self.hour = None
                                    self.day = None
                                    self.month = None
                                    self.weekday = None
                                    self._segment_path = lambda: "at"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Energywise.Level.Recurrence.Importance.At, [u'minute', u'hour', u'day', u'month', u'weekday'], name, value)


            class Location(Entity):
                """
                Interface location information
                
                .. attribute:: civic_location_id
                
                	Civic location information
                	**type**\:  :py:class:`CivicLocationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Location.CivicLocationId>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.Location, self).__init__()

                    self.yang_name = "location"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("civic-location-id", ("civic_location_id", Native.Interface.PortChannel.Location.CivicLocationId))])
                    self._leafs = OrderedDict()

                    self.civic_location_id = Native.Interface.PortChannel.Location.CivicLocationId()
                    self.civic_location_id.parent = self
                    self._children_name_map["civic_location_id"] = "civic-location-id"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:location"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Location, [], name, value)


                class CivicLocationId(Entity):
                    """
                    Civic location information
                    
                    .. attribute:: location_identifier
                    
                    	civic location identifier string
                    	**type**\: str
                    
                    .. attribute:: host
                    
                    	Globally defined host location identifer
                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Location.CivicLocationId.Host>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: none
                    
                    	No globally defined location identifer
                    	**type**\:  :py:class:`Y_None <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Location.CivicLocationId.Y_None>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Location.CivicLocationId, self).__init__()

                        self.yang_name = "civic-location-id"
                        self.yang_parent_name = "location"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("host", ("host", Native.Interface.PortChannel.Location.CivicLocationId.Host)), ("none", ("none", Native.Interface.PortChannel.Location.CivicLocationId.Y_None))])
                        self._leafs = OrderedDict([
                            ('location_identifier', (YLeaf(YType.str, 'location-identifier'), ['str'])),
                        ])
                        self.location_identifier = None

                        self.host = None
                        self._children_name_map["host"] = "host"

                        self.none = None
                        self._children_name_map["none"] = "none"
                        self._segment_path = lambda: "civic-location-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Location.CivicLocationId, [u'location_identifier'], name, value)


                    class Host(Entity):
                        """
                        Globally defined host location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Location.CivicLocationId.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "host"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Location.CivicLocationId.Host, [u'port_location'], name, value)


                    class Y_None(Entity):
                        """
                        No globally defined location identifer
                        
                        .. attribute:: port_location
                        
                        	Port specific attributes
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Location.CivicLocationId.Y_None, self).__init__()

                            self.yang_name = "none"
                            self.yang_parent_name = "civic-location-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                            ])
                            self.port_location = None
                            self._segment_path = lambda: "none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Location.CivicLocationId.Y_None, [u'port_location'], name, value)


            class Mac(Entity):
                """
                MAC interface commands
                
                .. attribute:: access_group
                
                	MAC access\-group configuration commands
                	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mac.AccessGroup>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.Mac, self).__init__()

                    self.yang_name = "mac"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.PortChannel.Mac.AccessGroup))])
                    self._leafs = OrderedDict()

                    self.access_group = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:mac"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Mac, [], name, value)


                class AccessGroup(Entity):
                    """
                    MAC access\-group configuration commands
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mac.AccessGroup.Direction>`
                    
                    .. attribute:: acl_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Mac.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "mac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Mac.AccessGroup.Direction')])),
                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                        ])
                        self.direction = None
                        self.acl_name = None
                        self._segment_path = lambda: "access-group" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Mac.AccessGroup, [u'direction', u'acl_name'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Macro(Entity):
                """
                Command macro
                
                .. attribute:: description
                
                	Macro description for this interface
                	**type**\: str
                
                .. attribute:: auto
                
                	Smartport interface macro configurations
                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Macro.Auto>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.Macro, self).__init__()

                    self.yang_name = "macro"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.PortChannel.Macro.Auto))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.auto = Native.Interface.PortChannel.Macro.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "auto"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macro"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Macro, [u'description'], name, value)


                class Auto(Entity):
                    """
                    Smartport interface macro configurations
                    
                    .. attribute:: processing
                    
                    	Enable smartport macro auto execution on this interface
                    	**type**\: bool
                    
                    .. attribute:: port
                    
                    	Provide interface specific configuration for macro processing
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Macro.Auto.Port>`
                    
                    .. attribute:: control
                    
                    	Control macro auto execution
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Macro.Auto.Control>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Macro.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "macro"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port", ("port", Native.Interface.PortChannel.Macro.Auto.Port)), ("control", ("control", Native.Interface.PortChannel.Macro.Auto.Control))])
                        self._leafs = OrderedDict([
                            ('processing', (YLeaf(YType.boolean, 'processing'), ['bool'])),
                        ])
                        self.processing = None

                        self.port = Native.Interface.PortChannel.Macro.Auto.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"

                        self.control = Native.Interface.PortChannel.Macro.Auto.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"
                        self._segment_path = lambda: "auto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Macro.Auto, [u'processing'], name, value)


                    class Port(Entity):
                        """
                        Provide interface specific configuration for macro processing
                        
                        .. attribute:: sticky
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Macro.Auto.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                            ])
                            self.sticky = None
                            self._segment_path = lambda: "port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Macro.Auto.Port, [u'sticky'], name, value)


                    class Control(Entity):
                        """
                        Control macro auto execution
                        
                        .. attribute:: device
                        
                        	Enable macro auto execution for devices
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Macro.Auto.Control.Device>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Macro.Auto.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("device", ("device", Native.Interface.PortChannel.Macro.Auto.Control.Device))])
                            self._leafs = OrderedDict()

                            self.device = Native.Interface.PortChannel.Macro.Auto.Control.Device()
                            self.device.parent = self
                            self._children_name_map["device"] = "device"
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Macro.Auto.Control, [], name, value)


                        class Device(Entity):
                            """
                            Enable macro auto execution for devices
                            
                            .. attribute:: phone
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Macro.Auto.Control.Device, self).__init__()

                                self.yang_name = "device"
                                self.yang_parent_name = "control"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('phone', (YLeaf(YType.empty, 'phone'), ['Empty'])),
                                ])
                                self.phone = None
                                self._segment_path = lambda: "device"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Macro.Auto.Control.Device, [u'phone'], name, value)


            class DualActive(Entity):
                """
                
                
                .. attribute:: fast_hello
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.DualActive, self).__init__()

                    self.yang_name = "dual-active"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fast_hello', (YLeaf(YType.empty, 'fast-hello'), ['Empty'])),
                    ])
                    self.fast_hello = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:dual-active"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.DualActive, [u'fast_hello'], name, value)


            class LoadBalancing(Entity):
                """
                Etherchannel Load\-Balancing
                
                .. attribute:: flow
                
                	Based on the traffic flows identified by the packet headers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Based on the VLAN to member links manual configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.LoadBalancing, self).__init__()

                    self.yang_name = "load-balancing"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('flow', (YLeaf(YType.empty, 'flow'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.flow = None
                    self.vlan = None
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:load-balancing"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.LoadBalancing, [u'flow', u'vlan'], name, value)


            class VlanRange(Entity):
                """
                
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4096
                
                		**type**\: str
                
                .. attribute:: service_policy
                
                	Configure QoS Service Policy
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.VlanRange.ServicePolicy>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.VlanRange, self).__init__()

                    self.yang_name = "vlan-range"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.PortChannel.VlanRange.ServicePolicy))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                    ])
                    self.id = None

                    self.service_policy = Native.Interface.PortChannel.VlanRange.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:vlan-range" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.VlanRange, [u'id'], name, value)


                class ServicePolicy(Entity):
                    """
                    Configure QoS Service Policy
                    
                    .. attribute:: input
                    
                    	Assign policy\-map to the input of an interface
                    	**type**\: str
                    
                    .. attribute:: output
                    
                    	Assign policy\-map to the output of an interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.VlanRange.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "vlan-range"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeaf(YType.str, 'input'), ['str'])),
                            ('output', (YLeaf(YType.str, 'output'), ['str'])),
                        ])
                        self.input = None
                        self.output = None
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.VlanRange.ServicePolicy, [u'input', u'output'], name, value)


            class Switch(Entity):
                """
                
                
                .. attribute:: virtual
                
                	
                	**type**\:  :py:class:`Virtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Switch.Virtual>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("virtual", ("virtual", Native.Interface.PortChannel.Switch.Virtual))])
                    self._leafs = OrderedDict()

                    self.virtual = Native.Interface.PortChannel.Switch.Virtual()
                    self.virtual.parent = self
                    self._children_name_map["virtual"] = "virtual"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:switch"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Switch, [], name, value)


                class Virtual(Entity):
                    """
                    
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Switch.Virtual, self).__init__()

                        self.yang_name = "virtual"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ])
                        self.link = None
                        self._segment_path = lambda: "virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Switch.Virtual, [u'link'], name, value)


            class SrrQueue(Entity):
                """
                
                
                .. attribute:: bandwidth
                
                	
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SrrQueue.Bandwidth>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.SrrQueue, self).__init__()

                    self.yang_name = "srr-queue"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.PortChannel.SrrQueue.Bandwidth))])
                    self._leafs = OrderedDict()

                    self.bandwidth = Native.Interface.PortChannel.SrrQueue.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:srr-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.SrrQueue, [], name, value)


                class Bandwidth(Entity):
                    """
                    
                    
                    .. attribute:: shape
                    
                    	
                    	**type**\:  :py:class:`Shape <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SrrQueue.Bandwidth.Shape>`
                    
                    .. attribute:: share
                    
                    	
                    	**type**\:  :py:class:`Share <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SrrQueue.Bandwidth.Share>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.SrrQueue.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "srr-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("shape", ("shape", Native.Interface.PortChannel.SrrQueue.Bandwidth.Shape)), ("share", ("share", Native.Interface.PortChannel.SrrQueue.Bandwidth.Share))])
                        self._leafs = OrderedDict()

                        self.shape = Native.Interface.PortChannel.SrrQueue.Bandwidth.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"

                        self.share = Native.Interface.PortChannel.SrrQueue.Bandwidth.Share()
                        self.share.parent = self
                        self._children_name_map["share"] = "share"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.SrrQueue.Bandwidth, [], name, value)


                    class Shape(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.SrrQueue.Bandwidth.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint16, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint16, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint16, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint16, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "shape"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.SrrQueue.Bandwidth.Shape, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


                    class Share(Entity):
                        """
                        
                        
                        .. attribute:: weight1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weight4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.SrrQueue.Bandwidth.Share, self).__init__()

                            self.yang_name = "share"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('weight1', (YLeaf(YType.uint8, 'weight1'), ['int'])),
                                ('weight2', (YLeaf(YType.uint8, 'weight2'), ['int'])),
                                ('weight3', (YLeaf(YType.uint8, 'weight3'), ['int'])),
                                ('weight4', (YLeaf(YType.uint8, 'weight4'), ['int'])),
                            ])
                            self.weight1 = None
                            self.weight2 = None
                            self.weight3 = None
                            self.weight4 = None
                            self._segment_path = lambda: "share"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.SrrQueue.Bandwidth.Share, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


            class MacsecOption(Entity):
                """
                Enable macsec on the interface
                
                .. attribute:: macsec
                
                	
                	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.MacsecOption.Macsec>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Interface.PortChannel.MacsecOption, self).__init__()

                    self.yang_name = "macsec-option"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.PortChannel.MacsecOption.Macsec))])
                    self._leafs = OrderedDict()

                    self.macsec = Native.Interface.PortChannel.MacsecOption.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-switch:macsec-option"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.MacsecOption, [], name, value)


                class Macsec(Entity):
                    """
                    
                    
                    .. attribute:: replay_protection
                    
                    	Set replay\-protection
                    	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.MacsecOption.Macsec.ReplayProtection>`
                    
                    .. attribute:: network_link
                    
                    	Enable macsec on switch connected interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannel.MacsecOption.Macsec, self).__init__()

                        self.yang_name = "macsec"
                        self.yang_parent_name = "macsec-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.PortChannel.MacsecOption.Macsec.ReplayProtection))])
                        self._leafs = OrderedDict([
                            ('network_link', (YLeaf(YType.empty, 'network-link'), ['Empty'])),
                        ])
                        self.network_link = None

                        self.replay_protection = Native.Interface.PortChannel.MacsecOption.Macsec.ReplayProtection()
                        self.replay_protection.parent = self
                        self._children_name_map["replay_protection"] = "replay-protection"
                        self._segment_path = lambda: "macsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.MacsecOption.Macsec, [u'network_link'], name, value)


                    class ReplayProtection(Entity):
                        """
                        Set replay\-protection
                        
                        .. attribute:: window_size
                        
                        	Set replay window\-size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannel.MacsecOption.Macsec.ReplayProtection, self).__init__()

                            self.yang_name = "replay-protection"
                            self.yang_parent_name = "macsec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                            ])
                            self.window_size = None
                            self._segment_path = lambda: "replay-protection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.MacsecOption.Macsec.ReplayProtection, [u'window_size'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.PortChannel.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.PortChannel.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.PortChannel.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.PortChannel.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.PortChannel.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.PortChannel.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.PortChannel.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.PortChannel.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.PortChannel.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.PortChannel.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class Xconnect(Entity):
                """
                Xconnect commands
                
                .. attribute:: address
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: vcid
                
                	
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: encapsulation
                
                	Data encapsulation method
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Xconnect.Encapsulation>`
                
                .. attribute:: manual
                
                	Manually configure L2TP session parameters
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sequence
                
                	Configure sequencing options for xconnect
                	**type**\:  :py:class:`Sequence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Xconnect.Sequence>`
                
                .. attribute:: pw_class
                
                	Pseudowire\-class to use for encapsulation and protocol configuration
                	**type**\: str
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.PortChannel.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('vcid', (YLeaf(YType.uint32, 'vcid'), ['int'])),
                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Xconnect.Encapsulation')])),
                        ('manual', (YLeaf(YType.empty, 'manual'), ['Empty'])),
                        ('sequence', (YLeaf(YType.enumeration, 'sequence'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Xconnect.Sequence')])),
                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                    ])
                    self.address = None
                    self.vcid = None
                    self.encapsulation = None
                    self.manual = None
                    self.sequence = None
                    self.pw_class = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Xconnect, ['address', 'vcid', 'encapsulation', 'manual', 'sequence', 'pw_class'], name, value)

                class Encapsulation(Enum):
                    """
                    Encapsulation (Enum Class)

                    Data encapsulation method

                    .. data:: mpls = 0

                    .. data:: l2tpv3 = 1

                    """

                    mpls = Enum.YLeaf(0, "mpls")

                    l2tpv3 = Enum.YLeaf(1, "l2tpv3")


                class Sequence(Enum):
                    """
                    Sequence (Enum Class)

                    Configure sequencing options for xconnect

                    .. data:: both = 0

                    .. data:: receive = 1

                    .. data:: transmit = 2

                    """

                    both = Enum.YLeaf(0, "both")

                    receive = Enum.YLeaf(1, "receive")

                    transmit = Enum.YLeaf(2, "transmit")



            class Evpn(Entity):
                """
                
                
                .. attribute:: ethernet_segment
                
                	Ethernet segment local discriminator value
                	**type**\: list of  		 :py:class:`EthernetSegment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Evpn.EthernetSegment>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.PortChannel.Evpn, self).__init__()

                    self.yang_name = "evpn"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet-segment", ("ethernet_segment", Native.Interface.PortChannel.Evpn.EthernetSegment))])
                    self._leafs = OrderedDict()

                    self.ethernet_segment = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:evpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Evpn, [], name, value)


                class EthernetSegment(Entity):
                    """
                    Ethernet segment local discriminator value
                    
                    .. attribute:: es_value  (key)
                    
                    	Ethernet segment local discriminator value
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: df_election
                    
                    	Designated forwarder election parameters
                    	**type**\:  :py:class:`DfElection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Evpn.EthernetSegment.DfElection>`
                    
                    .. attribute:: redundancy
                    
                    	Multi\-homing redundancy parameters
                    	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Evpn.EthernetSegment.Redundancy>`
                    
                    .. attribute:: sytem_mac
                    
                    	System MAC address for generating the Ethernet Segment ID
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Evpn.EthernetSegment, self).__init__()

                        self.yang_name = "ethernet-segment"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['es_value']
                        self._child_classes = OrderedDict([("df-election", ("df_election", Native.Interface.PortChannel.Evpn.EthernetSegment.DfElection)), ("redundancy", ("redundancy", Native.Interface.PortChannel.Evpn.EthernetSegment.Redundancy))])
                        self._leafs = OrderedDict([
                            ('es_value', (YLeaf(YType.uint16, 'es-value'), ['int'])),
                            ('sytem_mac', (YLeaf(YType.str, 'sytem-mac'), ['str'])),
                        ])
                        self.es_value = None
                        self.sytem_mac = None

                        self.df_election = Native.Interface.PortChannel.Evpn.EthernetSegment.DfElection()
                        self.df_election.parent = self
                        self._children_name_map["df_election"] = "df-election"

                        self.redundancy = Native.Interface.PortChannel.Evpn.EthernetSegment.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                        self._segment_path = lambda: "ethernet-segment" + "[es-value='" + str(self.es_value) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Evpn.EthernetSegment, ['es_value', 'sytem_mac'], name, value)


                    class DfElection(Entity):
                        """
                        Designated forwarder election parameters
                        
                        .. attribute:: wait_time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Evpn.EthernetSegment.DfElection, self).__init__()

                            self.yang_name = "df-election"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wait_time', (YLeaf(YType.uint8, 'wait-time'), ['int'])),
                            ])
                            self.wait_time = None
                            self._segment_path = lambda: "df-election"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Evpn.EthernetSegment.DfElection, ['wait_time'], name, value)


                    class Redundancy(Entity):
                        """
                        Multi\-homing redundancy parameters
                        
                        .. attribute:: all_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: single_active
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Evpn.EthernetSegment.Redundancy, self).__init__()

                            self.yang_name = "redundancy"
                            self.yang_parent_name = "ethernet-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all_active', (YLeaf(YType.empty, 'all-active'), ['Empty'])),
                                ('single_active', (YLeaf(YType.empty, 'single-active'), ['Empty'])),
                            ])
                            self.all_active = None
                            self.single_active = None
                            self._segment_path = lambda: "redundancy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Evpn.EthernetSegment.Redundancy, ['all_active', 'single_active'], name, value)


            class Mvrp(Entity):
                """
                
                
                .. attribute:: mvrp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: registration
                
                	
                	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mvrp.Registration>`
                
                .. attribute:: timer
                
                	
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mvrp.Timer>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mvrp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.PortChannel.Mvrp, self).__init__()

                    self.yang_name = "mvrp"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("registration", ("registration", Native.Interface.PortChannel.Mvrp.Registration)), ("timer", ("timer", Native.Interface.PortChannel.Mvrp.Timer))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mvrp', (YLeaf(YType.empty, 'mvrp'), ['Empty'])),
                    ])
                    self.mvrp = None

                    self.registration = Native.Interface.PortChannel.Mvrp.Registration()
                    self.registration.parent = self
                    self._children_name_map["registration"] = "registration"

                    self.timer = Native.Interface.PortChannel.Mvrp.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-mvrp:mvrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Mvrp, ['mvrp'], name, value)


                class Registration(Entity):
                    """
                    
                    
                    .. attribute:: fixed
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: forbidden
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: normal
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Mvrp.Registration, self).__init__()

                        self.yang_name = "registration"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fixed', (YLeaf(YType.empty, 'fixed'), ['Empty'])),
                            ('forbidden', (YLeaf(YType.empty, 'forbidden'), ['Empty'])),
                            ('normal', (YLeaf(YType.empty, 'normal'), ['Empty'])),
                        ])
                        self.fixed = None
                        self.forbidden = None
                        self.normal = None
                        self._segment_path = lambda: "registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Mvrp.Registration, ['fixed', 'forbidden', 'normal'], name, value)


                class Timer(Entity):
                    """
                    
                    
                    .. attribute:: join
                    
                    	
                    	**type**\:  :py:class:`Join <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mvrp.Timer.Join>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave
                    
                    	
                    	**type**\:  :py:class:`Leave <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mvrp.Timer.Leave>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: leave_all
                    
                    	
                    	**type**\:  :py:class:`LeaveAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Mvrp.Timer.LeaveAll>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: periodic
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mvrp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Mvrp.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("join", ("join", Native.Interface.PortChannel.Mvrp.Timer.Join)), ("leave", ("leave", Native.Interface.PortChannel.Mvrp.Timer.Leave)), ("leave-all", ("leave_all", Native.Interface.PortChannel.Mvrp.Timer.LeaveAll))])
                        self._leafs = OrderedDict([
                            ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ])
                        self.periodic = None

                        self.join = None
                        self._children_name_map["join"] = "join"

                        self.leave = None
                        self._children_name_map["leave"] = "leave"

                        self.leave_all = None
                        self._children_name_map["leave_all"] = "leave-all"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Mvrp.Timer, ['periodic'], name, value)


                    class Join(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 20..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Mvrp.Timer.Join, self).__init__()

                            self.yang_name = "join"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "join"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Mvrp.Timer.Join, ['y_range'], name, value)


                    class Leave(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Mvrp.Timer.Leave, self).__init__()

                            self.yang_name = "leave"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Mvrp.Timer.Leave, ['y_range'], name, value)


                    class LeaveAll(Entity):
                        """
                        
                        
                        .. attribute:: y_range
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1000..214748364
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mvrp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Mvrp.Timer.LeaveAll, self).__init__()

                            self.yang_name = "leave-all"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('y_range', (YLeaf(YType.uint32, '_range'), ['int'])),
                            ])
                            self.y_range = None
                            self._segment_path = lambda: "leave-all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Mvrp.Timer.LeaveAll, ['y_range'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.PortChannel.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.PortChannel.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.PortChannel.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.PortChannel.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.PortChannel.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.PortChannel.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.PortChannel.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.PortChannel.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.PortChannel.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Authentication(Entity):
                """
                Auth Manager Interface Configuration Commands
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.ControlDirection>`
                
                .. attribute:: event
                
                	Set action for authentication events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event>`
                
                .. attribute:: fallback
                
                	Enable the Webauth fallback mechanism
                	**type**\: str
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.HostMode>`
                
                .. attribute:: open
                
                	Enable or Disable open access on this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: order
                
                	Add an authentication method to the order list
                	**type**\:  :py:class:`Order <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Order>`
                
                .. attribute:: priority
                
                	Add an authentication method to the priority list
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Priority>`
                
                .. attribute:: port_control
                
                	set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.PortControl>`
                
                .. attribute:: periodic
                
                	Enable or Disable Reauthentication for this port
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timer
                
                	Set authentication timer values
                	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Timer>`
                
                .. attribute:: violation
                
                	Configure action to take on security violations
                	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Violation>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.PortChannel.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.PortChannel.Authentication.Event)), ("order", ("order", Native.Interface.PortChannel.Authentication.Order)), ("priority", ("priority", Native.Interface.PortChannel.Authentication.Priority)), ("timer", ("timer", Native.Interface.PortChannel.Authentication.Timer))])
                    self._leafs = OrderedDict([
                        ('control_direction', (YLeaf(YType.enumeration, 'control-direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Authentication.ControlDirection')])),
                        ('fallback', (YLeaf(YType.str, 'fallback'), ['str'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Authentication.HostMode')])),
                        ('open', (YLeaf(YType.empty, 'open'), ['Empty'])),
                        ('port_control', (YLeaf(YType.enumeration, 'port-control'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Authentication.PortControl')])),
                        ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                        ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Authentication.Violation')])),
                    ])
                    self.control_direction = None
                    self.fallback = None
                    self.host_mode = None
                    self.open = None
                    self.port_control = None
                    self.periodic = None
                    self.violation = None

                    self.event = Native.Interface.PortChannel.Authentication.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.order = Native.Interface.PortChannel.Authentication.Order()
                    self.order.parent = self
                    self._children_name_map["order"] = "order"

                    self.priority = Native.Interface.PortChannel.Authentication.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "priority"

                    self.timer = Native.Interface.PortChannel.Authentication.Timer()
                    self.timer.parent = self
                    self._children_name_map["timer"] = "timer"
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:authentication"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Authentication, ['control_direction', 'fallback', 'host_mode', 'open', 'port_control', 'periodic', 'violation'], name, value)

                class ControlDirection(Enum):
                    """
                    ControlDirection (Enum Class)

                    Set the control\-direction on the interface

                    .. data:: both = 0

                    .. data:: in_ = 1

                    """

                    both = Enum.YLeaf(0, "both")

                    in_ = Enum.YLeaf(1, "in")


                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")


                class PortControl(Enum):
                    """
                    PortControl (Enum Class)

                    set the port\-control value

                    .. data:: auto = 0

                    .. data:: force_authorized = 1

                    .. data:: force_unauthorized = 2

                    """

                    auto = Enum.YLeaf(0, "auto")

                    force_authorized = Enum.YLeaf(1, "force-authorized")

                    force_unauthorized = Enum.YLeaf(2, "force-unauthorized")


                class Violation(Enum):
                    """
                    Violation (Enum Class)

                    Configure action to take on security violations

                    .. data:: protect = 0

                    .. data:: replace = 1

                    .. data:: restrict = 2

                    .. data:: shutdown = 3

                    """

                    protect = Enum.YLeaf(0, "protect")

                    replace = Enum.YLeaf(1, "replace")

                    restrict = Enum.YLeaf(2, "restrict")

                    shutdown = Enum.YLeaf(3, "shutdown")



                class Event(Entity):
                    """
                    Set action for authentication events
                    
                    .. attribute:: server
                    
                    	Configure actions for AAA server events
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.Server>`
                    
                    .. attribute:: fail
                    
                    	Configure actions for AAA fail events
                    	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.Fail>`
                    
                    .. attribute:: no_response
                    
                    	Configure actions for AAA no\-response events
                    	**type**\:  :py:class:`NoResponse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.NoResponse>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Authentication.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("server", ("server", Native.Interface.PortChannel.Authentication.Event.Server)), ("fail", ("fail", Native.Interface.PortChannel.Authentication.Event.Fail)), ("no-response", ("no_response", Native.Interface.PortChannel.Authentication.Event.NoResponse))])
                        self._leafs = OrderedDict()

                        self.server = Native.Interface.PortChannel.Authentication.Event.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.fail = Native.Interface.PortChannel.Authentication.Event.Fail()
                        self.fail.parent = self
                        self._children_name_map["fail"] = "fail"

                        self.no_response = Native.Interface.PortChannel.Authentication.Event.NoResponse()
                        self.no_response.parent = self
                        self._children_name_map["no_response"] = "no-response"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Authentication.Event, [], name, value)


                    class Server(Entity):
                        """
                        Configure actions for AAA server events
                        
                        .. attribute:: alive
                        
                        	Configure AAA server alive action
                        	**type**\:  :py:class:`Alive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.Server.Alive>`
                        
                        .. attribute:: dead
                        
                        	Configure AAA server dead action
                        	**type**\:  :py:class:`Dead <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.Server.Dead>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Authentication.Event.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("alive", ("alive", Native.Interface.PortChannel.Authentication.Event.Server.Alive)), ("dead", ("dead", Native.Interface.PortChannel.Authentication.Event.Server.Dead))])
                            self._leafs = OrderedDict()

                            self.alive = Native.Interface.PortChannel.Authentication.Event.Server.Alive()
                            self.alive.parent = self
                            self._children_name_map["alive"] = "alive"

                            self.dead = Native.Interface.PortChannel.Authentication.Event.Server.Dead()
                            self.dead.parent = self
                            self._children_name_map["dead"] = "dead"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.Server, [], name, value)


                        class Alive(Entity):
                            """
                            Configure AAA server alive action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.Server.Alive.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Authentication.Event.Server.Alive, self).__init__()

                                self.yang_name = "alive"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannel.Authentication.Event.Server.Alive.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.PortChannel.Authentication.Event.Server.Alive.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "alive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.Server.Alive, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all authorized clients
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Authentication.Event.Server.Alive.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "alive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reinitialize', (YLeaf(YType.empty, 'reinitialize'), ['Empty'])),
                                    ])
                                    self.reinitialize = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.Server.Alive.Action, ['reinitialize'], name, value)


                        class Dead(Entity):
                            """
                            Configure AAA server dead action
                            
                            .. attribute:: action
                            
                            	Required action for authentication event
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Authentication.Event.Server.Dead, self).__init__()

                                self.yang_name = "dead"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dead"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.Server.Dead, [], name, value)


                            class Action(Entity):
                                """
                                Required action for authentication event
                                
                                .. attribute:: authorize
                                
                                	Authorize the port
                                	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action.Authorize>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: reinitialize
                                
                                	Reinitialize all client on the port
                                	**type**\:  :py:class:`Reinitialize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action.Reinitialize>`
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dead"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action.Authorize)), ("reinitialize", ("reinitialize", Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action.Reinitialize))])
                                    self._leafs = OrderedDict()

                                    self.authorize = None
                                    self._children_name_map["authorize"] = "authorize"

                                    self.reinitialize = Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action.Reinitialize()
                                    self.reinitialize.parent = self
                                    self._children_name_map["reinitialize"] = "reinitialize"
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action, [], name, value)


                                class Authorize(Entity):
                                    """
                                    Authorize the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: voice
                                    
                                    	Authorize the port for VOICE traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action.Authorize, self).__init__()

                                        self.yang_name = "authorize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ('voice', (YLeaf(YType.empty, 'voice'), ['Empty'])),
                                        ])
                                        self.vlan = None
                                        self.voice = None
                                        self._segment_path = lambda: "authorize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action.Authorize, ['vlan', 'voice'], name, value)


                                class Reinitialize(Entity):
                                    """
                                    Reinitialize all client on the port
                                    
                                    .. attribute:: vlan
                                    
                                    	Configure Critical Authorization VLAN
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-sanet'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action.Reinitialize, self).__init__()

                                        self.yang_name = "reinitialize"
                                        self.yang_parent_name = "action"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "reinitialize"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.Server.Dead.Action.Reinitialize, ['vlan'], name, value)


                    class Fail(Entity):
                        """
                        Configure actions for AAA fail events
                        
                        .. attribute:: action
                        
                        	Required action for fail event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.Fail.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Authentication.Event.Fail, self).__init__()

                            self.yang_name = "fail"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannel.Authentication.Event.Fail.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.PortChannel.Authentication.Event.Fail.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "fail"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.Fail, [], name, value)


                        class Action(Entity):
                            """
                            Required action for fail event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.Fail.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Authentication.Event.Fail.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "fail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.PortChannel.Authentication.Event.Fail.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.PortChannel.Authentication.Event.Fail.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.Fail.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Authentication.Event.Fail.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.Fail.Action.Authorize, ['vlan'], name, value)


                    class NoResponse(Entity):
                        """
                        Configure actions for AAA no\-response events
                        
                        .. attribute:: action
                        
                        	Required action for no\-response event
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.NoResponse.Action>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Authentication.Event.NoResponse, self).__init__()

                            self.yang_name = "no-response"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannel.Authentication.Event.NoResponse.Action))])
                            self._leafs = OrderedDict()

                            self.action = Native.Interface.PortChannel.Authentication.Event.NoResponse.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                            self._segment_path = lambda: "no-response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.NoResponse, [], name, value)


                        class Action(Entity):
                            """
                            Required action for no\-response event
                            
                            .. attribute:: authorize
                            
                            	Reinitialize all authorized clients
                            	**type**\:  :py:class:`Authorize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Event.NoResponse.Action.Authorize>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Authentication.Event.NoResponse.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "no-response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorize", ("authorize", Native.Interface.PortChannel.Authentication.Event.NoResponse.Action.Authorize))])
                                self._leafs = OrderedDict()

                                self.authorize = Native.Interface.PortChannel.Authentication.Event.NoResponse.Action.Authorize()
                                self.authorize.parent = self
                                self._children_name_map["authorize"] = "authorize"
                                self._segment_path = lambda: "action"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.NoResponse.Action, [], name, value)


                            class Authorize(Entity):
                                """
                                Reinitialize all authorized clients
                                
                                .. attribute:: vlan
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-sanet'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Authentication.Event.NoResponse.Action.Authorize, self).__init__()

                                    self.yang_name = "authorize"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "authorize"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Authentication.Event.NoResponse.Action.Authorize, ['vlan'], name, value)


                class Order(Entity):
                    """
                    Add an authentication method to the order list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Authentication.Order, self).__init__()

                        self.yang_name = "order"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "order"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Authentication.Order, ['dot1x', 'mab', 'webauth'], name, value)


                class Priority(Entity):
                    """
                    Add an authentication method to the priority list
                    
                    .. attribute:: dot1x
                    
                    	Authentication method dot1x allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mab
                    
                    	Authentication method mab allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: webauth
                    
                    	Authentication method webauth allowed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Authentication.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                            ('mab', (YLeaf(YType.empty, 'mab'), ['Empty'])),
                            ('webauth', (YLeaf(YType.empty, 'webauth'), ['Empty'])),
                        ])
                        self.dot1x = None
                        self.mab = None
                        self.webauth = None
                        self._segment_path = lambda: "priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Authentication.Priority, ['dot1x', 'mab', 'webauth'], name, value)


                class Timer(Entity):
                    """
                    Set authentication timer values
                    
                    .. attribute:: reauthenticate
                    
                    	Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                    	**type**\:  :py:class:`Reauthenticate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Timer.Reauthenticate>`
                    
                    .. attribute:: inactivity
                    
                    	Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                    	**type**\:  :py:class:`Inactivity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Timer.Inactivity>`
                    
                    .. attribute:: restart
                    
                    	Interval in seconds after which an attempt should be made toauthenticate an unauthorized port (default 60 sec)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Authentication.Timer, self).__init__()

                        self.yang_name = "timer"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reauthenticate", ("reauthenticate", Native.Interface.PortChannel.Authentication.Timer.Reauthenticate)), ("inactivity", ("inactivity", Native.Interface.PortChannel.Authentication.Timer.Inactivity))])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                        ])
                        self.restart = None

                        self.reauthenticate = Native.Interface.PortChannel.Authentication.Timer.Reauthenticate()
                        self.reauthenticate.parent = self
                        self._children_name_map["reauthenticate"] = "reauthenticate"

                        self.inactivity = Native.Interface.PortChannel.Authentication.Timer.Inactivity()
                        self.inactivity.parent = self
                        self._children_name_map["inactivity"] = "inactivity"
                        self._segment_path = lambda: "timer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Authentication.Timer, ['restart'], name, value)


                    class Reauthenticate(Entity):
                        """
                        Time in seconds after which an automatic re\-authenticationshould be initiated (default 1 hour)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: server
                        
                        	Obtain re\-authentication timeout value from the server
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Authentication.Timer.Reauthenticate, self).__init__()

                            self.yang_name = "reauthenticate"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                ('server', (YLeaf(YType.empty, 'server'), ['Empty'])),
                            ])
                            self.value = None
                            self.server = None
                            self._segment_path = lambda: "reauthenticate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Authentication.Timer.Reauthenticate, ['value', 'server'], name, value)


                    class Inactivity(Entity):
                        """
                        Interval in seconds after which if there is no activity fromthe client then it will be unauthorized (default OFF)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Timer.Inactivity.Value>`
                        
                        .. attribute:: server
                        
                        	Obtain inactivity timeout value from the server
                        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Authentication.Timer.Inactivity.Server>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sanet'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Authentication.Timer.Inactivity, self).__init__()

                            self.yang_name = "inactivity"
                            self.yang_parent_name = "timer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.PortChannel.Authentication.Timer.Inactivity.Value)), ("server", ("server", Native.Interface.PortChannel.Authentication.Timer.Inactivity.Server))])
                            self._leafs = OrderedDict()

                            self.value = Native.Interface.PortChannel.Authentication.Timer.Inactivity.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.server = None
                            self._children_name_map["server"] = "server"
                            self._segment_path = lambda: "inactivity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Authentication.Timer.Inactivity, [], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Authentication.Timer.Inactivity.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.value = None
                                self.dynamic = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Authentication.Timer.Inactivity.Value, ['value', 'dynamic'], name, value)


                        class Server(Entity):
                            """
                            Obtain inactivity timeout value from the server
                            
                            .. attribute:: dynamic
                            
                            	Initiate a dynamic probe on inactivity timeout
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sanet'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Authentication.Timer.Inactivity.Server, self).__init__()

                                self.yang_name = "server"
                                self.yang_parent_name = "inactivity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.dynamic = None
                                self._segment_path = lambda: "server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Authentication.Timer.Inactivity.Server, ['dynamic'], name, value)


            class Mab(Entity):
                """
                
                
                .. attribute:: eap
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.PortChannel.Mab, self).__init__()

                    self.yang_name = "mab"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                    ])
                    self.eap = None
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:mab"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Mab, ['eap'], name, value)


            class Dot1x(Entity):
                """
                Interface Config Commands for IEEE 802.1X
                
                .. attribute:: authenticator
                
                	Configure authenticator parameters
                	**type**\:  :py:class:`Authenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Dot1x.Authenticator>`
                
                .. attribute:: credentials
                
                	Credentials profile configuration
                	**type**\: str
                
                .. attribute:: max_reauth_req
                
                	Max No. of Reauthentication Attempts
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_req
                
                	Max No. of Retries
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: max_start
                
                	Max No. of EAPOL\-Start requests
                	**type**\: int
                
                	**range:** 1..10
                
                .. attribute:: pae
                
                	Set 802.1x interface pae type
                	**type**\:  :py:class:`Pae <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Dot1x.Pae>`
                
                .. attribute:: supplicant
                
                	Configure supplicant parameters
                	**type**\:  :py:class:`Supplicant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Dot1x.Supplicant>`
                
                .. attribute:: timeout
                
                	Various Timeouts
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Dot1x.Timeout>`
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.PortChannel.Dot1x, self).__init__()

                    self.yang_name = "dot1x"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authenticator", ("authenticator", Native.Interface.PortChannel.Dot1x.Authenticator)), ("supplicant", ("supplicant", Native.Interface.PortChannel.Dot1x.Supplicant)), ("timeout", ("timeout", Native.Interface.PortChannel.Dot1x.Timeout))])
                    self._leafs = OrderedDict([
                        ('credentials', (YLeaf(YType.str, 'credentials'), ['str'])),
                        ('max_reauth_req', (YLeaf(YType.uint8, 'max-reauth-req'), ['int'])),
                        ('max_req', (YLeaf(YType.uint8, 'max-req'), ['int'])),
                        ('max_start', (YLeaf(YType.uint8, 'max-start'), ['int'])),
                        ('pae', (YLeaf(YType.enumeration, 'pae'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Dot1x.Pae')])),
                    ])
                    self.credentials = None
                    self.max_reauth_req = None
                    self.max_req = None
                    self.max_start = None
                    self.pae = None

                    self.authenticator = Native.Interface.PortChannel.Dot1x.Authenticator()
                    self.authenticator.parent = self
                    self._children_name_map["authenticator"] = "authenticator"

                    self.supplicant = Native.Interface.PortChannel.Dot1x.Supplicant()
                    self.supplicant.parent = self
                    self._children_name_map["supplicant"] = "supplicant"

                    self.timeout = Native.Interface.PortChannel.Dot1x.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"
                    self._segment_path = lambda: "Cisco-IOS-XE-dot1x:dot1x"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Dot1x, ['credentials', 'max_reauth_req', 'max_req', 'max_start', 'pae'], name, value)

                class Pae(Enum):
                    """
                    Pae (Enum Class)

                    Set 802.1x interface pae type

                    .. data:: authenticator = 0

                    .. data:: supplicant = 1

                    .. data:: both = 2

                    """

                    authenticator = Enum.YLeaf(0, "authenticator")

                    supplicant = Enum.YLeaf(1, "supplicant")

                    both = Enum.YLeaf(2, "both")



                class Authenticator(Entity):
                    """
                    Configure authenticator parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP authenticator parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Dot1x.Authenticator.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Dot1x.Authenticator, self).__init__()

                        self.yang_name = "authenticator"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.PortChannel.Dot1x.Authenticator.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.PortChannel.Dot1x.Authenticator.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "authenticator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Dot1x.Authenticator, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP authenticator parameters
                        
                        .. attribute:: profile
                        
                        	EAP authenticator profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Dot1x.Authenticator.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "authenticator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Dot1x.Authenticator.Eap, ['profile'], name, value)


                class Supplicant(Entity):
                    """
                    Configure supplicant parameters
                    
                    .. attribute:: eap
                    
                    	Configure EAP supplicant parameters
                    	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Dot1x.Supplicant.Eap>`
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Dot1x.Supplicant, self).__init__()

                        self.yang_name = "supplicant"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eap", ("eap", Native.Interface.PortChannel.Dot1x.Supplicant.Eap))])
                        self._leafs = OrderedDict()

                        self.eap = Native.Interface.PortChannel.Dot1x.Supplicant.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                        self._segment_path = lambda: "supplicant"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Dot1x.Supplicant, [], name, value)


                    class Eap(Entity):
                        """
                        Configure EAP supplicant parameters
                        
                        .. attribute:: profile
                        
                        	EAP supplicant profile configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Dot1x.Supplicant.Eap, self).__init__()

                            self.yang_name = "eap"
                            self.yang_parent_name = "supplicant"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ])
                            self.profile = None
                            self._segment_path = lambda: "eap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Dot1x.Supplicant.Eap, ['profile'], name, value)


                class Timeout(Entity):
                    """
                    Various Timeouts
                    
                    .. attribute:: auth_period
                    
                    	Timeout for authenticator reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: held_period
                    
                    	Timeout for authentication retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: quiet_period
                    
                    	QuietPeriod in Seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ratelimit_period
                    
                    	Ratelimit Period in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: server_timeout
                    
                    	Timeout for Radius Retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: start_period
                    
                    	Timeout for EAPOL\-start retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: supp_timeout
                    
                    	Timeout for supplicant reply
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: tx_period
                    
                    	Timeout for supplicant retries
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Dot1x.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auth_period', (YLeaf(YType.uint16, 'auth-period'), ['int'])),
                            ('held_period', (YLeaf(YType.uint16, 'held-period'), ['int'])),
                            ('quiet_period', (YLeaf(YType.uint16, 'quiet-period'), ['int'])),
                            ('ratelimit_period', (YLeaf(YType.uint16, 'ratelimit-period'), ['int'])),
                            ('server_timeout', (YLeaf(YType.uint16, 'server-timeout'), ['int'])),
                            ('start_period', (YLeaf(YType.uint16, 'start-period'), ['int'])),
                            ('supp_timeout', (YLeaf(YType.uint16, 'supp-timeout'), ['int'])),
                            ('tx_period', (YLeaf(YType.uint16, 'tx-period'), ['int'])),
                        ])
                        self.auth_period = None
                        self.held_period = None
                        self.quiet_period = None
                        self.ratelimit_period = None
                        self.server_timeout = None
                        self.start_period = None
                        self.supp_timeout = None
                        self.tx_period = None
                        self._segment_path = lambda: "timeout"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Dot1x.Timeout, ['auth_period', 'held_period', 'quiet_period', 'ratelimit_period', 'server_timeout', 'start_period', 'supp_timeout', 'tx_period'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpdufilter
                
                	Don't send or receive BPDUs on this interface
                	**type**\:  :py:class:`Bpdufilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SpanningTree.Bpdufilter>`
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SpanningTree.Bpduguard>`
                
                .. attribute:: cost
                
                	To set the path cost of the interface
                	**type**\: int
                
                	**range:** 1..200000000
                
                .. attribute:: guard
                
                	Change an interface's spanning tree guard mode
                	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SpanningTree.Guard>`
                
                .. attribute:: link_type
                
                	Specify a link type for spanning tree tree protocol use
                	**type**\:  :py:class:`LinkType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SpanningTree.LinkType>`
                
                .. attribute:: portfast
                
                	Spanning tree portfast options
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                .. attribute:: port_priority
                
                	Spanning tree port\-priority options
                	**type**\: int
                
                	**range:** 0..240
                
                .. attribute:: vlan
                
                	VLAN Switch Spanning Tree
                	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SpanningTree.Vlan>`
                
                .. attribute:: loopguard
                
                	Spanning tree loopguard options
                	**type**\:  :py:class:`Loopguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SpanningTree.Loopguard>`
                
                .. attribute:: mst
                
                	Per interface MST configurations
                	**type**\:  :py:class:`Mst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SpanningTree.Mst>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.PortChannel.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Interface.PortChannel.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Interface.PortChannel.SpanningTree.Portfast)), ("vlan", ("vlan", Native.Interface.PortChannel.SpanningTree.Vlan)), ("loopguard", ("loopguard", Native.Interface.PortChannel.SpanningTree.Loopguard)), ("mst", ("mst", Native.Interface.PortChannel.SpanningTree.Mst))])
                    self._leafs = OrderedDict([
                        ('bpdufilter', (YLeaf(YType.enumeration, 'bpdufilter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.SpanningTree.Bpdufilter')])),
                        ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ('guard', (YLeaf(YType.enumeration, 'guard'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.SpanningTree.Guard')])),
                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.SpanningTree.LinkType')])),
                        ('port_priority', (YLeaf(YType.uint8, 'port-priority'), ['int'])),
                    ])
                    self.bpdufilter = None
                    self.cost = None
                    self.guard = None
                    self.link_type = None
                    self.port_priority = None

                    self.bpduguard = Native.Interface.PortChannel.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"

                    self.loopguard = Native.Interface.PortChannel.SpanningTree.Loopguard()
                    self.loopguard.parent = self
                    self._children_name_map["loopguard"] = "loopguard"

                    self.mst = Native.Interface.PortChannel.SpanningTree.Mst()
                    self.mst.parent = self
                    self._children_name_map["mst"] = "mst"

                    self.vlan = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:spanning-tree"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.SpanningTree, ['bpdufilter', 'cost', 'guard', 'link_type', 'port_priority'], name, value)

                class Bpdufilter(Enum):
                    """
                    Bpdufilter (Enum Class)

                    Don't send or receive BPDUs on this interface

                    .. data:: disable = 0

                    .. data:: enable = 1

                    """

                    disable = Enum.YLeaf(0, "disable")

                    enable = Enum.YLeaf(1, "enable")


                class Guard(Enum):
                    """
                    Guard (Enum Class)

                    Change an interface's spanning tree guard mode

                    .. data:: loop = 0

                    .. data:: none = 1

                    .. data:: root = 2

                    """

                    loop = Enum.YLeaf(0, "loop")

                    none = Enum.YLeaf(1, "none")

                    root = Enum.YLeaf(2, "root")


                class LinkType(Enum):
                    """
                    LinkType (Enum Class)

                    Specify a link type for spanning tree tree protocol use

                    .. data:: point_to_point = 0

                    .. data:: shared = 1

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")

                    shared = Enum.YLeaf(1, "shared")



                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.disable = None
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.SpanningTree.Bpduguard, ['disable', 'enable'], name, value)


                class Portfast(Entity):
                    """
                    Spanning tree portfast options
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk
                    
                    	Enable portfast on the interface even in trunk mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                        ])
                        self.disable = None
                        self.trunk = None
                        self.edge = None
                        self._segment_path = lambda: "portfast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.SpanningTree.Portfast, ['disable', 'trunk', 'edge'], name, value)


                class Vlan(Entity):
                    """
                    VLAN Switch Spanning Tree
                    
                    .. attribute:: vlan_ids  (key)
                    
                    	vlan range, example\: 1,3\-5,7,9\-11
                    	**type**\: str
                    
                    .. attribute:: cost
                    
                    	<1\-200000000> Spanning\-tree cost
                    	**type**\: int
                    
                    	**range:** 1..200000000
                    
                    .. attribute:: port_priority
                    
                    	<0\-240> port priority in increments of 16
                    	**type**\: int
                    
                    	**range:** 0..240
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.SpanningTree.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vlan_ids']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_ids', (YLeaf(YType.str, 'vlan-ids'), ['str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                        ])
                        self.vlan_ids = None
                        self.cost = None
                        self.port_priority = None
                        self._segment_path = lambda: "vlan" + "[vlan-ids='" + str(self.vlan_ids) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.SpanningTree.Vlan, ['vlan_ids', 'cost', 'port_priority'], name, value)


                class Loopguard(Entity):
                    """
                    Spanning tree loopguard options
                    
                    .. attribute:: default
                    
                    	Enable loopguard by default on all ports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.SpanningTree.Loopguard, self).__init__()

                        self.yang_name = "loopguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.default = None
                        self._segment_path = lambda: "loopguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.SpanningTree.Loopguard, ['default'], name, value)


                class Mst(Entity):
                    """
                    Per interface MST configurations
                    
                    .. attribute:: mst_instance
                    
                    	
                    	**type**\: list of  		 :py:class:`MstInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.SpanningTree.Mst.MstInstance>`
                    
                    .. attribute:: pre_standard
                    
                    	Force pre\-standard MST BPDU transmission on port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.SpanningTree.Mst, self).__init__()

                        self.yang_name = "mst"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mst-instance", ("mst_instance", Native.Interface.PortChannel.SpanningTree.Mst.MstInstance))])
                        self._leafs = OrderedDict([
                            ('pre_standard', (YLeaf(YType.empty, 'pre-standard'), ['Empty'])),
                        ])
                        self.pre_standard = None

                        self.mst_instance = YList(self)
                        self._segment_path = lambda: "mst"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.SpanningTree.Mst, ['pre_standard'], name, value)


                    class MstInstance(Entity):
                        """
                        
                        
                        .. attribute:: instance  (key)
                        
                        	MST instance list, example 0,2\-4,6,8\-12
                        	**type**\: str
                        
                        .. attribute:: cost
                        
                        	<1\-200000000> Spanning\-tree cost
                        	**type**\: int
                        
                        	**range:** 1..200000000
                        
                        .. attribute:: port_priority
                        
                        	<0\-240> port priority in increments of 16
                        	**type**\: int
                        
                        	**range:** 0..240
                        
                        

                        """

                        _prefix = 'ios-stp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.SpanningTree.Mst.MstInstance, self).__init__()

                            self.yang_name = "mst-instance"
                            self.yang_parent_name = "mst"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                            ])
                            self.instance = None
                            self.cost = None
                            self.port_priority = None
                            self._segment_path = lambda: "mst-instance" + "[instance='" + str(self.instance) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.SpanningTree.Mst.MstInstance, ['instance', 'cost', 'port_priority'], name, value)


            class Ospfv3(Entity):
                """
                OSPFv3 interface commands
                
                .. attribute:: process_id
                
                	
                	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId>`
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Authentication>`
                
                .. attribute:: bfd
                
                	Enable BFD on this interface
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: cost
                
                	Route cost of this interface
                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Cost>`
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: demand_circuit
                
                	OSPF Demand Circuit
                	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.DemandCircuit>`
                
                	**presence node**\: True
                
                .. attribute:: encryption
                
                	Enable encryption
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption>`
                
                .. attribute:: flood_reduction
                
                	OSPF Flood Reduction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: manet
                
                	Mobile Adhoc Networking options
                	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Manet>`
                
                .. attribute:: mtu_ignore
                
                	Ignores the MTU in DBD packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: multi_area
                
                	Set the OSPF multi\-area ID
                	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.MultiArea>`
                
                .. attribute:: neighbor
                
                	OSPF neighbor
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Neighbor>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Network>`
                
                .. attribute:: prefix_suppression
                
                	OSPF prefix suppression
                	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.PrefixSuppression>`
                
                	**presence node**\: True
                
                .. attribute:: priority
                
                	Router priority
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: retransmit_interval
                
                	Time between retransmitting lost link state advertisements
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Shut down the interface in OSPFv3
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transmit_delay
                
                	Link state transmit delay
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.PortChannel.Ospfv3, self).__init__()

                    self.yang_name = "ospfv3"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.PortChannel.Ospfv3.ProcessId)), ("authentication", ("authentication", Native.Interface.PortChannel.Ospfv3.Authentication)), ("bfd", ("bfd", Native.Interface.PortChannel.Ospfv3.Bfd)), ("cost", ("cost", Native.Interface.PortChannel.Ospfv3.Cost)), ("database-filter", ("database_filter", Native.Interface.PortChannel.Ospfv3.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.PortChannel.Ospfv3.DemandCircuit)), ("encryption", ("encryption", Native.Interface.PortChannel.Ospfv3.Encryption)), ("manet", ("manet", Native.Interface.PortChannel.Ospfv3.Manet)), ("multi-area", ("multi_area", Native.Interface.PortChannel.Ospfv3.MultiArea)), ("neighbor", ("neighbor", Native.Interface.PortChannel.Ospfv3.Neighbor)), ("network", ("network", Native.Interface.PortChannel.Ospfv3.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.PortChannel.Ospfv3.PrefixSuppression))])
                    self._leafs = OrderedDict([
                        ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                        ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                        ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                    ])
                    self.dead_interval = None
                    self.flood_reduction = None
                    self.hello_interval = None
                    self.mtu_ignore = None
                    self.priority = None
                    self.retransmit_interval = None
                    self.shutdown = None
                    self.transmit_delay = None

                    self.authentication = Native.Interface.PortChannel.Ospfv3.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"

                    self.cost = Native.Interface.PortChannel.Ospfv3.Cost()
                    self.cost.parent = self
                    self._children_name_map["cost"] = "cost"

                    self.database_filter = Native.Interface.PortChannel.Ospfv3.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"

                    self.demand_circuit = None
                    self._children_name_map["demand_circuit"] = "demand-circuit"

                    self.encryption = Native.Interface.PortChannel.Ospfv3.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.manet = Native.Interface.PortChannel.Ospfv3.Manet()
                    self.manet.parent = self
                    self._children_name_map["manet"] = "manet"

                    self.multi_area = Native.Interface.PortChannel.Ospfv3.MultiArea()
                    self.multi_area.parent = self
                    self._children_name_map["multi_area"] = "multi-area"

                    self.network = Native.Interface.PortChannel.Ospfv3.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.prefix_suppression = None
                    self._children_name_map["prefix_suppression"] = "prefix-suppression"

                    self.process_id = YList(self)
                    self.neighbor = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3, ['dead_interval', u'flood_reduction', 'hello_interval', u'mtu_ignore', 'priority', 'retransmit_interval', u'shutdown', 'transmit_delay'], name, value)


                class ProcessId(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Cost>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: manet
                    
                    	Mobile Adhoc Networking options
                    	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Manet>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.MultiArea>`
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Network>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipv4
                    
                    	Specify parameters for IPv4
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Specify parameters for IPv6
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.ProcessId, self).__init__()

                        self.yang_name = "process-id"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.PortChannel.Ospfv3.ProcessId.Authentication)), ("bfd", ("bfd", Native.Interface.PortChannel.Ospfv3.ProcessId.Bfd)), ("cost", ("cost", Native.Interface.PortChannel.Ospfv3.ProcessId.Cost)), ("database-filter", ("database_filter", Native.Interface.PortChannel.Ospfv3.ProcessId.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.PortChannel.Ospfv3.ProcessId.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.PortChannel.Ospfv3.ProcessId.FloodReduction)), ("manet", ("manet", Native.Interface.PortChannel.Ospfv3.ProcessId.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.PortChannel.Ospfv3.ProcessId.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.PortChannel.Ospfv3.ProcessId.MultiArea)), ("neighbor", ("neighbor", Native.Interface.PortChannel.Ospfv3.ProcessId.Neighbor)), ("network", ("network", Native.Interface.PortChannel.Ospfv3.ProcessId.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.PortChannel.Ospfv3.ProcessId.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.PortChannel.Ospfv3.ProcessId.Shutdown)), ("ipv4", ("ipv4", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4)), ("ipv6", ("ipv6", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.id = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.PortChannel.Ospfv3.ProcessId.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.cost = Native.Interface.PortChannel.Ospfv3.ProcessId.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.database_filter = Native.Interface.PortChannel.Ospfv3.ProcessId.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.manet = Native.Interface.PortChannel.Ospfv3.ProcessId.Manet()
                        self.manet.parent = self
                        self._children_name_map["manet"] = "manet"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.multi_area = Native.Interface.PortChannel.Ospfv3.ProcessId.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.network = Native.Interface.PortChannel.Ospfv3.ProcessId.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.ipv4 = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId, [u'id', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\: str
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.null = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Authentication, [u'key_chain', u'null'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Bfd, ['disable'], name, value)


                    class Cost(Entity):
                        """
                        Route cost of this interface
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dynamic
                        
                        	Specify dynamic cost options
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.dynamic = None
                            self._children_name_map["dynamic"] = "dynamic"
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost, [u'value'], name, value)


                        class Dynamic(Entity):
                            """
                            Specify dynamic cost options
                            
                            .. attribute:: default
                            
                            	Specify default link metric value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: hysteresis
                            
                            	Specify hysteresis value for LSA dampening
                            	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: weight
                            
                            	Specify weight to be placed on individual metrics
                            	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ])
                                self.default = None

                                self.hysteresis = None
                                self._children_name_map["hysteresis"] = "hysteresis"

                                self.weight = Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight()
                                self.weight.parent = self
                                self._children_name_map["weight"] = "weight"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic, [u'default'], name, value)


                            class Hysteresis(Entity):
                                """
                                Specify hysteresis value for LSA dampening
                                
                                .. attribute:: percent
                                
                                	Specify hysteresis percent changed
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold
                                
                                	Specify hysteresis threshold value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, self).__init__()

                                    self.yang_name = "hysteresis"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "hysteresis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                            class Weight(Entity):
                                """
                                Specify weight to be placed on individual metrics
                                
                                .. attribute:: l2_factor
                                
                                	Specify weight to be given to L2\-factor metric
                                	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: latency
                                
                                	Specify weight to be given to latency metric
                                	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: resources
                                
                                	Specify weight to be given to resources metric
                                	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: throughput
                                
                                	Specify weight to be given to throughput metric
                                	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight, self).__init__()

                                    self.yang_name = "weight"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput))])
                                    self._leafs = OrderedDict()

                                    self.l2_factor = None
                                    self._children_name_map["l2_factor"] = "L2-factor"

                                    self.latency = None
                                    self._children_name_map["latency"] = "latency"

                                    self.resources = None
                                    self._children_name_map["resources"] = "resources"

                                    self.throughput = None
                                    self._children_name_map["throughput"] = "throughput"
                                    self._segment_path = lambda: "weight"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight, [], name, value)


                                class L2Factor(Entity):
                                    """
                                    Specify weight to be given to L2\-factor metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                        self.yang_name = "L2-factor"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "L2-factor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                class Latency(Entity):
                                    """
                                    Specify weight to be given to latency metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, self).__init__()

                                        self.yang_name = "latency"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "latency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                class Resources(Entity):
                                    """
                                    Specify weight to be given to resources metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, self).__init__()

                                        self.yang_name = "resources"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "resources"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                class Throughput(Entity):
                                    """
                                    Specify weight to be given to throughput metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, self).__init__()

                                        self.yang_name = "throughput"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "throughput"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.ProcessId.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.DatabaseFilter, [u'all', u'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.DemandCircuit, [u'disable', u'ignore'], name, value)


                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.FloodReduction, [u'disable'], name, value)


                    class Manet(Entity):
                        """
                        Mobile Adhoc Networking options
                        
                        .. attribute:: peering
                        
                        	MANET Peering options
                        	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Manet.Peering>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Manet, self).__init__()

                            self.yang_name = "manet"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.PortChannel.Ospfv3.ProcessId.Manet.Peering))])
                            self._leafs = OrderedDict()

                            self.peering = Native.Interface.PortChannel.Ospfv3.ProcessId.Manet.Peering()
                            self.peering.parent = self
                            self._children_name_map["peering"] = "peering"
                            self._segment_path = lambda: "manet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Manet, [], name, value)


                        class Peering(Entity):
                            """
                            MANET Peering options
                            
                            .. attribute:: cost
                            
                            	Redundant path cost improvement required to peer
                            	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Manet.Peering.Cost>`
                            
                            .. attribute:: link_metrics
                            
                            	Require link metrics
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Manet.Peering, self).__init__()

                                self.yang_name = "peering"
                                self.yang_parent_name = "manet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.PortChannel.Ospfv3.ProcessId.Manet.Peering.Cost))])
                                self._leafs = OrderedDict([
                                    ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                ])
                                self.link_metrics = None

                                self.cost = Native.Interface.PortChannel.Ospfv3.ProcessId.Manet.Peering.Cost()
                                self.cost.parent = self
                                self._children_name_map["cost"] = "cost"
                                self._segment_path = lambda: "peering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Manet.Peering, [u'link_metrics'], name, value)


                            class Cost(Entity):
                                """
                                Redundant path cost improvement required to peer
                                
                                .. attribute:: percent
                                
                                	Relative incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                .. attribute:: threshold
                                
                                	Absolute incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.ProcessId.Manet.Peering.Cost, self).__init__()

                                    self.yang_name = "cost"
                                    self.yang_parent_name = "peering"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "cost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.MtuIgnore, [u'disable'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: disable
                        
                        	disable OSPF multi\-area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.disable = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.MultiArea, [u'id', u'cost', u'disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.PortChannel.Ospfv3.ProcessId.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.PortChannel.Ospfv3.ProcessId.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.PortChannel.Ospfv3.ProcessId.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.PrefixSuppression, ['disable'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Shutdown, [u'disable'], name, value)


                    class Ipv4(Entity):
                        """
                        Specify parameters for IPv4
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Area)), ("authentication", ("authentication", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Authentication)), ("bfd", ("bfd", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Bfd)), ("cost", ("cost", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost)), ("database-filter", ("database_filter", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.FloodReduction)), ("manet", ("manet", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.MultiArea)), ("neighbor", ("neighbor", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Neighbor)), ("network", ("network", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 64..95
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv4.Shutdown, [u'disable'], name, value)


                    class Ipv6(Entity):
                        """
                        Specify parameters for IPv6
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Area)), ("authentication", ("authentication", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Authentication)), ("bfd", ("bfd", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Bfd)), ("cost", ("cost", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost)), ("database-filter", ("database_filter", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.FloodReduction)), ("manet", ("manet", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.MultiArea)), ("neighbor", ("neighbor", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Neighbor)), ("network", ("network", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 0..31
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.ProcessId.Ipv6.Shutdown, [u'disable'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: key_chain
                    
                    	Use a key\-chain for cryptographic authentication keys
                    	**type**\: str
                    
                    .. attribute:: null
                    
                    	Use no authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec authentication
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.null = None

                        self.ipsec = Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Authentication, [u'key_chain', u'null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec authentication
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 256..4294967295
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5>`
                        
                        .. attribute:: sha1
                        
                        	Use SHA\-1 authentication
                        	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                            ])
                            self.spi = None

                            self.md5 = Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"

                            self.sha1 = Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1()
                            self.sha1.parent = self
                            self._children_name_map["sha1"] = "sha1"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec, ['spi'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class Sha1(Entity):
                            """
                            Use SHA\-1 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1, self).__init__()

                                self.yang_name = "sha1"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "sha1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "sha1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                class Bfd(Entity):
                    """
                    Enable BFD on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BFD on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Bfd, ['disable'], name, value)


                class Cost(Entity):
                    """
                    Route cost of this interface
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: dynamic
                    
                    	Specify dynamic cost options
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Cost.Dynamic>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.Cost, self).__init__()

                        self.yang_name = "cost"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.PortChannel.Ospfv3.Cost.Dynamic))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.dynamic = None
                        self._children_name_map["dynamic"] = "dynamic"
                        self._segment_path = lambda: "cost"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Cost, [u'value'], name, value)


                    class Dynamic(Entity):
                        """
                        Specify dynamic cost options
                        
                        .. attribute:: default
                        
                        	Specify default link metric value
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hysteresis
                        
                        	Specify hysteresis value for LSA dampening
                        	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Hysteresis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: weight
                        
                        	Specify weight to be placed on individual metrics
                        	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic, self).__init__()

                            self.yang_name = "dynamic"
                            self.yang_parent_name = "cost"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                            ])
                            self.default = None

                            self.hysteresis = None
                            self._children_name_map["hysteresis"] = "hysteresis"

                            self.weight = Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight()
                            self.weight.parent = self
                            self._children_name_map["weight"] = "weight"
                            self._segment_path = lambda: "dynamic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic, [u'default'], name, value)


                        class Hysteresis(Entity):
                            """
                            Specify hysteresis value for LSA dampening
                            
                            .. attribute:: percent
                            
                            	Specify hysteresis percent changed
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold
                            
                            	Specify hysteresis threshold value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Hysteresis, self).__init__()

                                self.yang_name = "hysteresis"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "hysteresis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                        class Weight(Entity):
                            """
                            Specify weight to be placed on individual metrics
                            
                            .. attribute:: l2_factor
                            
                            	Specify weight to be given to L2\-factor metric
                            	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.L2Factor>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: latency
                            
                            	Specify weight to be given to latency metric
                            	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Latency>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: resources
                            
                            	Specify weight to be given to resources metric
                            	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Resources>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: throughput
                            
                            	Specify weight to be given to throughput metric
                            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Throughput>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight, self).__init__()

                                self.yang_name = "weight"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Throughput))])
                                self._leafs = OrderedDict()

                                self.l2_factor = None
                                self._children_name_map["l2_factor"] = "L2-factor"

                                self.latency = None
                                self._children_name_map["latency"] = "latency"

                                self.resources = None
                                self._children_name_map["resources"] = "resources"

                                self.throughput = None
                                self._children_name_map["throughput"] = "throughput"
                                self._segment_path = lambda: "weight"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight, [], name, value)


                            class L2Factor(Entity):
                                """
                                Specify weight to be given to L2\-factor metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                    self.yang_name = "L2-factor"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "L2-factor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                            class Latency(Entity):
                                """
                                Specify weight to be given to latency metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Latency, self).__init__()

                                    self.yang_name = "latency"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "latency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                            class Resources(Entity):
                                """
                                Specify weight to be given to resources metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Resources, self).__init__()

                                    self.yang_name = "resources"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "resources"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                            class Throughput(Entity):
                                """
                                Specify weight to be given to throughput metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Throughput, self).__init__()

                                    self.yang_name = "throughput"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "throughput"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.DatabaseFilter.All')])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.DatabaseFilter, [u'all'], name, value)

                    class All(Enum):
                        """
                        All (Enum Class)

                        Filter all LSA

                        .. data:: out = 0

                        """

                        out = Enum.YLeaf(0, "out")



                class DemandCircuit(Entity):
                    """
                    OSPF Demand Circuit
                    
                    .. attribute:: ignore
                    
                    	Ignore demand circuit auto\-negotiation requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.DemandCircuit, self).__init__()

                        self.yang_name = "demand-circuit"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.ignore = None
                        self._segment_path = lambda: "demand-circuit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.DemandCircuit, [u'ignore'], name, value)


                class Encryption(Entity):
                    """
                    Enable encryption
                    
                    .. attribute:: null
                    
                    	No IPsec encryption on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec encryption
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec))])
                        self._leafs = OrderedDict([
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.null = None

                        self.ipsec = Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Encryption, ['null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec encryption
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: esp
                        
                        	Use ESP encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec_3des
                        
                        	Use 3DES encryption
                        	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des>`
                        
                        .. attribute:: aes_cbc
                        
                        	Use AES\-CBC encryption
                        	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                            ])
                            self.spi = None
                            self.esp = None

                            self.ipsec_3des = Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des()
                            self.ipsec_3des.parent = self
                            self._children_name_map["ipsec_3des"] = "ipsec_3des"

                            self.aes_cbc = Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc()
                            self.aes_cbc.parent = self
                            self._children_name_map["aes_cbc"] = "aes-cbc"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec, ['spi', 'esp'], name, value)


                        class Ipsec3des(Entity):
                            """
                            Use 3DES encryption
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des, self).__init__()

                                self.yang_name = "ipsec_3des"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "ipsec_3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "ipsec_3des"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class AesCbc(Entity):
                            """
                            Use AES\-CBC encryption
                            
                            .. attribute:: aes_cbc_128
                            
                            	Use 128 bit key
                            	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128>`
                            
                            .. attribute:: aes_192
                            
                            	Use 192 bit key
                            	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192>`
                            
                            .. attribute:: aes_256
                            
                            	Use 256 bit key
                            	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc, self).__init__()

                                self.yang_name = "aes-cbc"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256))])
                                self._leafs = OrderedDict()

                                self.aes_cbc_128 = Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128()
                                self.aes_cbc_128.parent = self
                                self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                self.aes_192 = Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192()
                                self.aes_192.parent = self
                                self._children_name_map["aes_192"] = "aes-192"

                                self.aes_256 = Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256()
                                self.aes_256.parent = self
                                self._children_name_map["aes_256"] = "aes-256"
                                self._segment_path = lambda: "aes-cbc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc, [], name, value)


                            class AesCbc128(Entity):
                                """
                                Use 128 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                    self.yang_name = "aes-cbc-128"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-cbc-128"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-cbc-128"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes192(Entity):
                                """
                                Use 192 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                    self.yang_name = "aes-192"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-192"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-192"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes256(Entity):
                                """
                                Use 256 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                    self.yang_name = "aes-256"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-256"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-256"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                class Manet(Entity):
                    """
                    Mobile Adhoc Networking options
                    
                    .. attribute:: peering
                    
                    	MANET Peering options
                    	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Manet.Peering>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.Manet, self).__init__()

                        self.yang_name = "manet"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.PortChannel.Ospfv3.Manet.Peering))])
                        self._leafs = OrderedDict()

                        self.peering = Native.Interface.PortChannel.Ospfv3.Manet.Peering()
                        self.peering.parent = self
                        self._children_name_map["peering"] = "peering"
                        self._segment_path = lambda: "manet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Manet, [], name, value)


                    class Peering(Entity):
                        """
                        MANET Peering options
                        
                        .. attribute:: cost
                        
                        	Redundant path cost improvement required to peer
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Manet.Peering.Cost>`
                        
                        .. attribute:: link_metrics
                        
                        	Require link metrics
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.Manet.Peering, self).__init__()

                            self.yang_name = "peering"
                            self.yang_parent_name = "manet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.PortChannel.Ospfv3.Manet.Peering.Cost))])
                            self._leafs = OrderedDict([
                                ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                            ])
                            self.link_metrics = None

                            self.cost = Native.Interface.PortChannel.Ospfv3.Manet.Peering.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"
                            self._segment_path = lambda: "peering"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Manet.Peering, [u'link_metrics'], name, value)


                        class Cost(Entity):
                            """
                            Redundant path cost improvement required to peer
                            
                            .. attribute:: percent
                            
                            	Relative incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: threshold
                            
                            	Absolute incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Ospfv3.Manet.Peering.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "peering"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                class MultiArea(Entity):
                    """
                    Set the OSPF multi\-area ID
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.MultiArea, self).__init__()

                        self.yang_name = "multi-area"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self._segment_path = lambda: "multi-area"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.MultiArea, [u'id', u'cost'], name, value)


                class Neighbor(Entity):
                    """
                    OSPF neighbor
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	OSPF cost for point\-to\-multipoint neighbor
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Neighbor.DatabaseFilter>`
                    
                    .. attribute:: poll_interval
                    
                    	OSPF dead\-router polling interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: priority
                    
                    	OSPF priority of non\-broadcast neighbor
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.PortChannel.Ospfv3.Neighbor.DatabaseFilter))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self.poll_interval = None
                        self.priority = None

                        self.database_filter = Native.Interface.PortChannel.Ospfv3.Neighbor.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Neighbor.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.Neighbor.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannel.Ospfv3.Neighbor.DatabaseFilter.All')])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Neighbor.DatabaseFilter, ['all'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                class Network(Entity):
                    """
                    Network type
                    
                    .. attribute:: broadcast
                    
                    	Specify OSPF broadcast multi\-access network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: manet
                    
                    	Specify MANET OSPF interface type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: non_broadcast
                    
                    	Specify OSPF NBMA network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: point_to_multipoint
                    
                    	Specify OSPF point\-to\-multipoint network
                    	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Ospfv3.Network.PointToMultipoint>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: point_to_point
                    
                    	Specify OSPF point\-to\-point network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.PortChannel.Ospfv3.Network.PointToMultipoint))])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                            ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                        ])
                        self.broadcast = None
                        self.manet = None
                        self.non_broadcast = None
                        self.point_to_point = None

                        self.point_to_multipoint = None
                        self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                    class PointToMultipoint(Entity):
                        """
                        Specify OSPF point\-to\-multipoint network
                        
                        .. attribute:: non_broadcast
                        
                        	Specify non\-broadcast point\-to\-mpoint network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Ospfv3.Network.PointToMultipoint, self).__init__()

                            self.yang_name = "point-to-multipoint"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ])
                            self.non_broadcast = None
                            self._segment_path = lambda: "point-to-multipoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Ospfv3.Network.PointToMultipoint, ['non_broadcast'], name, value)


                class PrefixSuppression(Entity):
                    """
                    OSPF prefix suppression
                    
                    .. attribute:: disable
                    
                    	Disable prefix suppression
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Ospfv3.PrefixSuppression, self).__init__()

                        self.yang_name = "prefix-suppression"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "prefix-suppression"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Ospfv3.PrefixSuppression, ['disable'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts.Manual>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.PortChannel.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.PortChannel.Cts.Manual))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.PortChannel.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.PortChannel.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.PortChannel.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.PortChannel.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.PortChannel.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.PortChannel.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.PortChannel.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.PortChannel.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.PortChannel.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.PortChannel.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannel.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.PortChannel.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannel.Cts.Manual.Propagate, ['sgt'], name, value)


            class AnalysisModule(Entity):
                """
                Configure NAM on the interface
                
                .. attribute:: monitoring
                
                	Configure NAM monitoring on the interface
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannel.AnalysisModule.Monitoring>`
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Interface.PortChannel.AnalysisModule, self).__init__()

                    self.yang_name = "analysis-module"
                    self.yang_parent_name = "Port-channel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Interface.PortChannel.AnalysisModule.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = Native.Interface.PortChannel.AnalysisModule.Monitoring()
                    self.monitoring.parent = self
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannel.AnalysisModule, [], name, value)


                class Monitoring(Entity):
                    """
                    Configure NAM monitoring on the interface
                    
                    .. attribute:: interface_name
                    
                    	The name of the output interface.  E.g., 'ucse 1/0/0'
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nam'
                    _revision = '2017-12-28'

                    def __init__(self):
                        super(Native.Interface.PortChannel.AnalysisModule.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "analysis-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "monitoring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannel.AnalysisModule.Monitoring, ['interface_name'], name, value)


        class PortChannelSubinterface(Entity):
            """
            
            
            .. attribute:: port_channel
            
            	
            	**type**\: list of  		 :py:class:`PortChannel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.PortChannelSubinterface, self).__init__()

                self.yang_name = "Port-channel-subinterface"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Port-channel", ("port_channel", Native.Interface.PortChannelSubinterface.PortChannel))])
                self._leafs = OrderedDict()

                self.port_channel = YList(self)
                self._segment_path = lambda: "Port-channel-subinterface"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.PortChannelSubinterface, [], name, value)


            class PortChannel(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: description
                
                	Interface specific description
                	**type**\: str
                
                	**length:** 0..240
                
                .. attribute:: switchport_conf
                
                	
                	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.SwitchportConf>`
                
                .. attribute:: switchport
                
                	Set switching mode characteristics
                	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport>`
                
                .. attribute:: stackwise_virtual
                
                	Configure stackwise\-virtual link values
                	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StackwiseVirtual>`
                
                .. attribute:: mac_address
                
                	Manually set interface MAC address
                	**type**\: str
                
                .. attribute:: shutdown
                
                	Shutdown the selected interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: arp
                
                	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Arp>`
                
                .. attribute:: backup
                
                	Modify backup parameters
                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Backup>`
                
                .. attribute:: cemoudp
                
                	cemoudp
                	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Cemoudp>`
                
                .. attribute:: cws_tunnel
                
                	Configure Cloud Web Security Tunnel
                	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.CwsTunnel>`
                
                .. attribute:: l2protocol_tunnel
                
                	Tunnel Layer2 protocols
                	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel>`
                
                	**presence node**\: True
                
                .. attribute:: encapsulation
                
                	Set encapsulation type for an interface
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation>`
                
                .. attribute:: fair_queue_conf
                
                	
                	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.FairQueueConf>`
                
                .. attribute:: fair_queue
                
                	Enable Fair Queuing on an Interface
                	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.FairQueue>`
                
                .. attribute:: flowcontrol
                
                	Configure flow operation
                	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Flowcontrol>`
                
                .. attribute:: isis
                
                	IS\-IS commands
                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Isis>`
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\: bool
                
                .. attribute:: keepalive_settings
                
                	
                	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.KeepaliveSettings>`
                
                .. attribute:: bfd
                
                	BFD interface configuration commands
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Bfd>`
                
                .. attribute:: bandwidth
                
                	Set bandwidth informational parameter
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth>`
                
                .. attribute:: dampening
                
                	Enable event dampening
                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Dampening>`
                
                .. attribute:: if_state
                
                	
                	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.IfState>`
                
                .. attribute:: delay
                
                	Specify interface throughput delay
                	**type**\: int
                
                	**range:** 1..16777215
                
                .. attribute:: domain
                
                	Specify a domain
                	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Domain>`
                
                .. attribute:: hold_queue
                
                	Set hold queue depth
                	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.HoldQueue>`
                
                .. attribute:: mpls
                
                	
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Mpls>`
                
                .. attribute:: ip_vrf
                
                	
                	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.IpVrf>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Vrf>`
                
                .. attribute:: ip
                
                	Interface Internet Protocol config commands
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip>`
                
                .. attribute:: ipv6
                
                	IPv6 interface subcommands
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6>`
                
                .. attribute:: load_interval
                
                	Specify interval for load calculation for an interface
                	**type**\: int
                
                	**range:** 0..600
                
                .. attribute:: logging
                
                	Configure logging for interface
                	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Logging>`
                
                .. attribute:: mdix
                
                	Set Media Dependent Interface with Crossover
                	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Mdix>`
                
                .. attribute:: mop
                
                	
                	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Mop>`
                
                .. attribute:: max_reserved_bandwidth
                
                	Maximum Reservable Bandwidth on an Interface
                	**type**\: int
                
                	**range:** 1..100
                
                .. attribute:: mtu
                
                	Set the interface Maximum Transmission Unit (MTU)
                	**type**\: int
                
                	**range:** 64..18000
                
                .. attribute:: interface_qos
                
                	
                	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.InterfaceQos>`
                
                .. attribute:: service_insertion
                
                	Service\-insertion AppNav Controller
                	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.ServiceInsertion>`
                
                .. attribute:: source
                
                	Get config from another source
                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Source>`
                
                .. attribute:: standby
                
                	HSRP interface configuration commands
                	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby>`
                
                .. attribute:: access_session
                
                	Access Session specific Interface Configuration Commands
                	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.AccessSession>`
                
                .. attribute:: storm_control
                
                	storm configuration
                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl>`
                
                .. attribute:: trust
                
                	Set trust value for the interface
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Trust>`
                
                .. attribute:: priority_queue
                
                	Configure priority scheduling
                	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.PriorityQueue>`
                
                .. attribute:: rcv_queue
                
                	Configure receive queue(s)
                	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.RcvQueue>`
                
                .. attribute:: peer
                
                	Peer parameters for point to point interfaces
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Peer>`
                
                .. attribute:: pm_path
                
                	Global pm\-path configuration
                	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.PmPath>`
                
                .. attribute:: carrier_delay
                
                	Specify delay for interface transitions
                	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay>`
                
                .. attribute:: channel_group
                
                	Add this interface to an Etherchannel group
                	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.ChannelGroup>`
                
                .. attribute:: channel_protocol
                
                	Select the channel protocol (LACP, PAgP)
                	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.ChannelProtocol>`
                
                .. attribute:: ethernet
                
                	Ethernet interface parameters
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet>`
                
                .. attribute:: eapol
                
                	eapol
                	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Eapol>`
                
                .. attribute:: synchronous
                
                	Synchronous
                	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Synchronous>`
                
                .. attribute:: speed
                
                	Configure speed operation
                	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Speed>`
                
                .. attribute:: duplex
                
                	Configure duplex operation
                	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Duplex>`
                
                .. attribute:: negotiation
                
                	Select autonegotiation mode
                	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Negotiation>`
                
                .. attribute:: plim
                
                	Configure features on the PLIM
                	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Plim>`
                
                .. attribute:: pppoe
                
                	pppoe interface subcommands
                	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Pppoe>`
                
                .. attribute:: service
                
                	Configure Ether Service
                	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service>`
                
                .. attribute:: auto
                
                	Configure Automation
                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Auto>`
                
                .. attribute:: datalink
                
                	Interface Datalink commands
                	**type**\:  :py:class:`Datalink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Datalink>`
                
                .. attribute:: energywise
                
                	EnergyWise interface configurations
                	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Energywise>`
                
                	**presence node**\: True
                
                .. attribute:: location
                
                	Interface location information
                	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Location>`
                
                .. attribute:: mac
                
                	MAC interface commands
                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Mac>`
                
                .. attribute:: macro
                
                	Command macro
                	**type**\:  :py:class:`Macro <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Macro>`
                
                .. attribute:: dual_active
                
                	
                	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.DualActive>`
                
                .. attribute:: load_balancing
                
                	Etherchannel Load\-Balancing
                	**type**\:  :py:class:`LoadBalancing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.LoadBalancing>`
                
                .. attribute:: vlan_range
                
                	
                	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.VlanRange>`
                
                .. attribute:: switch
                
                	
                	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switch>`
                
                .. attribute:: srr_queue
                
                	
                	**type**\:  :py:class:`SrrQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue>`
                
                .. attribute:: macsec
                
                	Enable macsec on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: macsec_option
                
                	Enable macsec on the interface
                	**type**\:  :py:class:`MacsecOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.PortChannelSubinterface.PortChannel, self).__init__()

                    self.yang_name = "Port-channel"
                    self.yang_parent_name = "Port-channel-subinterface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.PortChannelSubinterface.PortChannel.SwitchportConf)), ("switchport", ("switchport", Native.Interface.PortChannelSubinterface.PortChannel.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.PortChannelSubinterface.PortChannel.StackwiseVirtual)), ("arp", ("arp", Native.Interface.PortChannelSubinterface.PortChannel.Arp)), ("backup", ("backup", Native.Interface.PortChannelSubinterface.PortChannel.Backup)), ("cemoudp", ("cemoudp", Native.Interface.PortChannelSubinterface.PortChannel.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.PortChannelSubinterface.PortChannel.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.PortChannelSubinterface.PortChannel.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.PortChannelSubinterface.PortChannel.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.PortChannelSubinterface.PortChannel.Flowcontrol)), ("isis", ("isis", Native.Interface.PortChannelSubinterface.PortChannel.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.PortChannelSubinterface.PortChannel.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.PortChannelSubinterface.PortChannel.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth)), ("dampening", ("dampening", Native.Interface.PortChannelSubinterface.PortChannel.Dampening)), ("domain", ("domain", Native.Interface.PortChannelSubinterface.PortChannel.Domain)), ("hold-queue", ("hold_queue", Native.Interface.PortChannelSubinterface.PortChannel.HoldQueue)), ("mpls", ("mpls", Native.Interface.PortChannelSubinterface.PortChannel.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.PortChannelSubinterface.PortChannel.IpVrf)), ("vrf", ("vrf", Native.Interface.PortChannelSubinterface.PortChannel.Vrf)), ("ip", ("ip", Native.Interface.PortChannelSubinterface.PortChannel.Ip)), ("ipv6", ("ipv6", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6)), ("logging", ("logging", Native.Interface.PortChannelSubinterface.PortChannel.Logging)), ("mdix", ("mdix", Native.Interface.PortChannelSubinterface.PortChannel.Mdix)), ("mop", ("mop", Native.Interface.PortChannelSubinterface.PortChannel.Mop)), ("interface_qos", ("interface_qos", Native.Interface.PortChannelSubinterface.PortChannel.InterfaceQos)), ("source", ("source", Native.Interface.PortChannelSubinterface.PortChannel.Source)), ("standby", ("standby", Native.Interface.PortChannelSubinterface.PortChannel.Standby)), ("access-session", ("access_session", Native.Interface.PortChannelSubinterface.PortChannel.AccessSession)), ("storm-control", ("storm_control", Native.Interface.PortChannelSubinterface.PortChannel.StormControl)), ("trust", ("trust", Native.Interface.PortChannelSubinterface.PortChannel.Trust)), ("priority-queue", ("priority_queue", Native.Interface.PortChannelSubinterface.PortChannel.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.PortChannelSubinterface.PortChannel.RcvQueue)), ("peer", ("peer", Native.Interface.PortChannelSubinterface.PortChannel.Peer)), ("pm-path", ("pm_path", Native.Interface.PortChannelSubinterface.PortChannel.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.PortChannelSubinterface.PortChannel.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.PortChannelSubinterface.PortChannel.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.PortChannelSubinterface.PortChannel.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.PortChannelSubinterface.PortChannel.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.PortChannelSubinterface.PortChannel.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.PortChannelSubinterface.PortChannel.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.PortChannelSubinterface.PortChannel.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.PortChannelSubinterface.PortChannel.Service)), ("Cisco-IOS-XE-switch:auto", ("auto", Native.Interface.PortChannelSubinterface.PortChannel.Auto)), ("Cisco-IOS-XE-switch:datalink", ("datalink", Native.Interface.PortChannelSubinterface.PortChannel.Datalink)), ("Cisco-IOS-XE-switch:energywise", ("energywise", Native.Interface.PortChannelSubinterface.PortChannel.Energywise)), ("Cisco-IOS-XE-switch:location", ("location", Native.Interface.PortChannelSubinterface.PortChannel.Location)), ("Cisco-IOS-XE-switch:mac", ("mac", Native.Interface.PortChannelSubinterface.PortChannel.Mac)), ("Cisco-IOS-XE-switch:macro", ("macro", Native.Interface.PortChannelSubinterface.PortChannel.Macro)), ("Cisco-IOS-XE-switch:dual-active", ("dual_active", Native.Interface.PortChannelSubinterface.PortChannel.DualActive)), ("Cisco-IOS-XE-switch:load-balancing", ("load_balancing", Native.Interface.PortChannelSubinterface.PortChannel.LoadBalancing)), ("Cisco-IOS-XE-switch:vlan-range", ("vlan_range", Native.Interface.PortChannelSubinterface.PortChannel.VlanRange)), ("Cisco-IOS-XE-switch:switch", ("switch", Native.Interface.PortChannelSubinterface.PortChannel.Switch)), ("Cisco-IOS-XE-switch:srr-queue", ("srr_queue", Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue)), ("Cisco-IOS-XE-switch:macsec-option", ("macsec_option", Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                        ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.IfState')])),
                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                        ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                        ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.ServiceInsertion')])),
                        ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.ChannelProtocol')])),
                        ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Duplex')])),
                        ('macsec', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:macsec'), ['Empty'])),
                    ])
                    self.name = None
                    self.description = None
                    self.mac_address = None
                    self.shutdown = None
                    self.keepalive = None
                    self.if_state = None
                    self.delay = None
                    self.load_interval = None
                    self.max_reserved_bandwidth = None
                    self.mtu = None
                    self.service_insertion = None
                    self.channel_protocol = None
                    self.duplex = None
                    self.macsec = None

                    self.switchport_conf = Native.Interface.PortChannelSubinterface.PortChannel.SwitchportConf()
                    self.switchport_conf.parent = self
                    self._children_name_map["switchport_conf"] = "switchport-conf"

                    self.switchport = Native.Interface.PortChannelSubinterface.PortChannel.Switchport()
                    self.switchport.parent = self
                    self._children_name_map["switchport"] = "switchport"

                    self.stackwise_virtual = Native.Interface.PortChannelSubinterface.PortChannel.StackwiseVirtual()
                    self.stackwise_virtual.parent = self
                    self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                    self.arp = Native.Interface.PortChannelSubinterface.PortChannel.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.backup = Native.Interface.PortChannelSubinterface.PortChannel.Backup()
                    self.backup.parent = self
                    self._children_name_map["backup"] = "backup"

                    self.cemoudp = Native.Interface.PortChannelSubinterface.PortChannel.Cemoudp()
                    self.cemoudp.parent = self
                    self._children_name_map["cemoudp"] = "cemoudp"

                    self.cws_tunnel = Native.Interface.PortChannelSubinterface.PortChannel.CwsTunnel()
                    self.cws_tunnel.parent = self
                    self._children_name_map["cws_tunnel"] = "cws-tunnel"

                    self.l2protocol_tunnel = None
                    self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                    self.encapsulation = Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"

                    self.fair_queue_conf = Native.Interface.PortChannelSubinterface.PortChannel.FairQueueConf()
                    self.fair_queue_conf.parent = self
                    self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                    self.fair_queue = Native.Interface.PortChannelSubinterface.PortChannel.FairQueue()
                    self.fair_queue.parent = self
                    self._children_name_map["fair_queue"] = "fair-queue"

                    self.flowcontrol = Native.Interface.PortChannelSubinterface.PortChannel.Flowcontrol()
                    self.flowcontrol.parent = self
                    self._children_name_map["flowcontrol"] = "flowcontrol"

                    self.isis = Native.Interface.PortChannelSubinterface.PortChannel.Isis()
                    self.isis.parent = self
                    self._children_name_map["isis"] = "isis"

                    self.keepalive_settings = Native.Interface.PortChannelSubinterface.PortChannel.KeepaliveSettings()
                    self.keepalive_settings.parent = self
                    self._children_name_map["keepalive_settings"] = "keepalive-settings"

                    self.bfd = Native.Interface.PortChannelSubinterface.PortChannel.Bfd()
                    self.bfd.parent = self
                    self._children_name_map["bfd"] = "bfd"

                    self.bandwidth = Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"

                    self.dampening = Native.Interface.PortChannelSubinterface.PortChannel.Dampening()
                    self.dampening.parent = self
                    self._children_name_map["dampening"] = "dampening"

                    self.domain = Native.Interface.PortChannelSubinterface.PortChannel.Domain()
                    self.domain.parent = self
                    self._children_name_map["domain"] = "domain"

                    self.mpls = Native.Interface.PortChannelSubinterface.PortChannel.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"

                    self.ip_vrf = Native.Interface.PortChannelSubinterface.PortChannel.IpVrf()
                    self.ip_vrf.parent = self
                    self._children_name_map["ip_vrf"] = "ip-vrf"

                    self.vrf = Native.Interface.PortChannelSubinterface.PortChannel.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.ip = Native.Interface.PortChannelSubinterface.PortChannel.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.ipv6 = Native.Interface.PortChannelSubinterface.PortChannel.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.logging = Native.Interface.PortChannelSubinterface.PortChannel.Logging()
                    self.logging.parent = self
                    self._children_name_map["logging"] = "logging"

                    self.mdix = Native.Interface.PortChannelSubinterface.PortChannel.Mdix()
                    self.mdix.parent = self
                    self._children_name_map["mdix"] = "mdix"

                    self.mop = Native.Interface.PortChannelSubinterface.PortChannel.Mop()
                    self.mop.parent = self
                    self._children_name_map["mop"] = "mop"

                    self.interface_qos = Native.Interface.PortChannelSubinterface.PortChannel.InterfaceQos()
                    self.interface_qos.parent = self
                    self._children_name_map["interface_qos"] = "interface_qos"

                    self.source = Native.Interface.PortChannelSubinterface.PortChannel.Source()
                    self.source.parent = self
                    self._children_name_map["source"] = "source"

                    self.standby = Native.Interface.PortChannelSubinterface.PortChannel.Standby()
                    self.standby.parent = self
                    self._children_name_map["standby"] = "standby"

                    self.access_session = Native.Interface.PortChannelSubinterface.PortChannel.AccessSession()
                    self.access_session.parent = self
                    self._children_name_map["access_session"] = "access-session"

                    self.storm_control = Native.Interface.PortChannelSubinterface.PortChannel.StormControl()
                    self.storm_control.parent = self
                    self._children_name_map["storm_control"] = "storm-control"

                    self.trust = Native.Interface.PortChannelSubinterface.PortChannel.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"

                    self.priority_queue = Native.Interface.PortChannelSubinterface.PortChannel.PriorityQueue()
                    self.priority_queue.parent = self
                    self._children_name_map["priority_queue"] = "priority-queue"

                    self.rcv_queue = Native.Interface.PortChannelSubinterface.PortChannel.RcvQueue()
                    self.rcv_queue.parent = self
                    self._children_name_map["rcv_queue"] = "rcv-queue"

                    self.peer = Native.Interface.PortChannelSubinterface.PortChannel.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"

                    self.pm_path = Native.Interface.PortChannelSubinterface.PortChannel.PmPath()
                    self.pm_path.parent = self
                    self._children_name_map["pm_path"] = "pm-path"

                    self.carrier_delay = Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay()
                    self.carrier_delay.parent = self
                    self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                    self.channel_group = Native.Interface.PortChannelSubinterface.PortChannel.ChannelGroup()
                    self.channel_group.parent = self
                    self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                    self.ethernet = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                    self.eapol = Native.Interface.PortChannelSubinterface.PortChannel.Eapol()
                    self.eapol.parent = self
                    self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                    self.synchronous = Native.Interface.PortChannelSubinterface.PortChannel.Synchronous()
                    self.synchronous.parent = self
                    self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                    self.speed = Native.Interface.PortChannelSubinterface.PortChannel.Speed()
                    self.speed.parent = self
                    self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                    self.negotiation = Native.Interface.PortChannelSubinterface.PortChannel.Negotiation()
                    self.negotiation.parent = self
                    self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                    self.plim = Native.Interface.PortChannelSubinterface.PortChannel.Plim()
                    self.plim.parent = self
                    self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                    self.pppoe = Native.Interface.PortChannelSubinterface.PortChannel.Pppoe()
                    self.pppoe.parent = self
                    self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                    self.service = Native.Interface.PortChannelSubinterface.PortChannel.Service()
                    self.service.parent = self
                    self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                    self.auto = Native.Interface.PortChannelSubinterface.PortChannel.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "Cisco-IOS-XE-switch:auto"

                    self.datalink = Native.Interface.PortChannelSubinterface.PortChannel.Datalink()
                    self.datalink.parent = self
                    self._children_name_map["datalink"] = "Cisco-IOS-XE-switch:datalink"

                    self.energywise = None
                    self._children_name_map["energywise"] = "Cisco-IOS-XE-switch:energywise"

                    self.location = Native.Interface.PortChannelSubinterface.PortChannel.Location()
                    self.location.parent = self
                    self._children_name_map["location"] = "Cisco-IOS-XE-switch:location"

                    self.mac = Native.Interface.PortChannelSubinterface.PortChannel.Mac()
                    self.mac.parent = self
                    self._children_name_map["mac"] = "Cisco-IOS-XE-switch:mac"

                    self.macro = Native.Interface.PortChannelSubinterface.PortChannel.Macro()
                    self.macro.parent = self
                    self._children_name_map["macro"] = "Cisco-IOS-XE-switch:macro"

                    self.dual_active = Native.Interface.PortChannelSubinterface.PortChannel.DualActive()
                    self.dual_active.parent = self
                    self._children_name_map["dual_active"] = "Cisco-IOS-XE-switch:dual-active"

                    self.load_balancing = Native.Interface.PortChannelSubinterface.PortChannel.LoadBalancing()
                    self.load_balancing.parent = self
                    self._children_name_map["load_balancing"] = "Cisco-IOS-XE-switch:load-balancing"

                    self.switch = Native.Interface.PortChannelSubinterface.PortChannel.Switch()
                    self.switch.parent = self
                    self._children_name_map["switch"] = "Cisco-IOS-XE-switch:switch"

                    self.srr_queue = Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue()
                    self.srr_queue.parent = self
                    self._children_name_map["srr_queue"] = "Cisco-IOS-XE-switch:srr-queue"

                    self.macsec_option = Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption()
                    self.macsec_option.parent = self
                    self._children_name_map["macsec_option"] = "Cisco-IOS-XE-switch:macsec-option"

                    self.hold_queue = YList(self)
                    self.vlan_range = YList(self)
                    self._segment_path = lambda: "Port-channel" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/Port-channel-subinterface/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex', u'macsec'], name, value)

                class ChannelProtocol(Enum):
                    """
                    ChannelProtocol (Enum Class)

                    Select the channel protocol (LACP, PAgP)

                    .. data:: lacp = 0

                    .. data:: pagp = 1

                    """

                    lacp = Enum.YLeaf(0, "lacp")

                    pagp = Enum.YLeaf(1, "pagp")


                class Duplex(Enum):
                    """
                    Duplex (Enum Class)

                    Configure duplex operation.

                    .. data:: auto = 0

                    .. data:: full = 1

                    .. data:: half = 2

                    """

                    auto = Enum.YLeaf(0, "auto")

                    full = Enum.YLeaf(1, "full")

                    half = Enum.YLeaf(2, "half")


                class IfState(Enum):
                    """
                    IfState (Enum Class)

                    .. data:: nhrp = 0

                    """

                    nhrp = Enum.YLeaf(0, "nhrp")


                class ServiceInsertion(Enum):
                    """
                    ServiceInsertion (Enum Class)

                    Service\-insertion AppNav Controller

                    .. data:: waas = 0

                    """

                    waas = Enum.YLeaf(0, "waas")



                class SwitchportConf(Entity):
                    """
                    
                    
                    .. attribute:: switchport
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.SwitchportConf, self).__init__()

                        self.yang_name = "switchport-conf"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                        ])
                        self.switchport = None
                        self._segment_path = lambda: "switchport-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.SwitchportConf, [u'switchport'], name, value)


                class Switchport(Entity):
                    """
                    Set switching mode characteristics
                    
                    .. attribute:: access
                    
                    	Set access mode characteristics of the interface
                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access>`
                    
                    .. attribute:: block
                    
                    	Disable forwarding of unknown uni/multi cast addresses
                    	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Block>`
                    
                    .. attribute:: mode
                    
                    	Set trunking mode of the interface
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode>`
                    
                    .. attribute:: nonegotiate
                    
                    	Device will not engage in negotiation protocol on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: port_security
                    
                    	Security related command
                    	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trunk
                    
                    	Set trunking characteristics of the interface
                    	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk>`
                    
                    .. attribute:: voice
                    
                    	Voice appliance attributes
                    	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice>`
                    
                    .. attribute:: priority
                    
                    	Set appliance 802.1p priority
                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Priority>`
                    
                    .. attribute:: autostate
                    
                    	Include or exclude this port from vlan link up calculation
                    	**type**\:  :py:class:`Autostate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Autostate>`
                    
                    .. attribute:: protected
                    
                    	Configure an interface to be a protected port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: host
                    
                    	Set port host
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: private_vlan
                    
                    	Set the private VLAN configuration
                    	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan>`
                    
                    .. attribute:: vepa
                    
                    	Reflective relay configuration
                    	**type**\:  :py:class:`Vepa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Vepa>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport, self).__init__()

                        self.yang_name = "switchport"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:access", ("access", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access)), ("Cisco-IOS-XE-switch:block", ("block", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Block)), ("Cisco-IOS-XE-switch:mode", ("mode", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode)), ("Cisco-IOS-XE-switch:port-security", ("port_security", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity)), ("Cisco-IOS-XE-switch:trunk", ("trunk", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk)), ("Cisco-IOS-XE-switch:voice", ("voice", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice)), ("Cisco-IOS-XE-switch:priority", ("priority", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Priority)), ("Cisco-IOS-XE-switch:autostate", ("autostate", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Autostate)), ("Cisco-IOS-XE-switch:private-vlan", ("private_vlan", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan)), ("Cisco-IOS-XE-switch:vepa", ("vepa", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Vepa))])
                        self._leafs = OrderedDict([
                            ('nonegotiate', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:nonegotiate'), ['Empty'])),
                            ('protected', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:protected'), ['Empty'])),
                            ('host', (YLeaf(YType.empty, 'Cisco-IOS-XE-switch:host'), ['Empty'])),
                        ])
                        self.nonegotiate = None
                        self.protected = None
                        self.host = None

                        self.access = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access()
                        self.access.parent = self
                        self._children_name_map["access"] = "Cisco-IOS-XE-switch:access"

                        self.block = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Block()
                        self.block.parent = self
                        self._children_name_map["block"] = "Cisco-IOS-XE-switch:block"

                        self.mode = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "Cisco-IOS-XE-switch:mode"

                        self.port_security = None
                        self._children_name_map["port_security"] = "Cisco-IOS-XE-switch:port-security"

                        self.trunk = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk()
                        self.trunk.parent = self
                        self._children_name_map["trunk"] = "Cisco-IOS-XE-switch:trunk"

                        self.voice = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice()
                        self.voice.parent = self
                        self._children_name_map["voice"] = "Cisco-IOS-XE-switch:voice"

                        self.priority = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Priority()
                        self.priority.parent = self
                        self._children_name_map["priority"] = "Cisco-IOS-XE-switch:priority"

                        self.autostate = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Autostate()
                        self.autostate.parent = self
                        self._children_name_map["autostate"] = "Cisco-IOS-XE-switch:autostate"

                        self.private_vlan = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan()
                        self.private_vlan.parent = self
                        self._children_name_map["private_vlan"] = "Cisco-IOS-XE-switch:private-vlan"

                        self.vepa = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Vepa()
                        self.vepa.parent = self
                        self._children_name_map["vepa"] = "Cisco-IOS-XE-switch:vepa"
                        self._segment_path = lambda: "switchport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport, [u'nonegotiate', u'protected', u'host'], name, value)


                    class Access(Entity):
                        """
                        Set access mode characteristics of the interface
                        
                        .. attribute:: vlan
                        
                        	Set VLAN when interface is in access mode
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access, self).__init__()

                            self.yang_name = "access"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "Cisco-IOS-XE-switch:access"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access, [], name, value)


                        class Vlan(Entity):
                            """
                            Set VLAN when interface is in access mode
                            
                            .. attribute:: vlan
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4094
                            
                            		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_>`
                            
                            .. attribute:: name
                            
                            	Vlan name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "access"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlan', (YLeaf(YType.str, 'vlan'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan.Vlan_')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.vlan = None
                                self.name = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Access.Vlan, [u'vlan', u'name'], name, value)

                            class Vlan_(Enum):
                                """
                                Vlan\_ (Enum Class)

                                .. data:: dynamic = 0

                                """

                                dynamic = Enum.YLeaf(0, "dynamic")



                    class Block(Entity):
                        """
                        Disable forwarding of unknown uni/multi cast addresses
                        
                        .. attribute:: multicast
                        
                        	Block unknown multicast addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	Block unknown unicast addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Block, self).__init__()

                            self.yang_name = "block"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self.unicast = None
                            self._segment_path = lambda: "Cisco-IOS-XE-switch:block"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Block, [u'multicast', u'unicast'], name, value)


                    class Mode(Entity):
                        """
                        Set trunking mode of the interface
                        
                        .. attribute:: access
                        
                        	Set trunking mode to ACCESS unconditionally
                        	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.Access>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: dot1q_tunnel
                        
                        	set trunking mode to TUNNEL unconditionally
                        	**type**\:  :py:class:`Dot1qTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.Dot1qTunnel>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: dynamic
                        
                        	Set trunking mode to dynamically negotiate access or trunk mode
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.Dynamic>`
                        
                        .. attribute:: private_vlan
                        
                        	Set private\-vlan mode
                        	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.PrivateVlan>`
                        
                        .. attribute:: trunk
                        
                        	Set trunking mode to TRUNK unconditionally
                        	**type**\:  :py:class:`Trunk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.Trunk>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("access", ("access", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.Access)), ("dot1q-tunnel", ("dot1q_tunnel", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.Dot1qTunnel)), ("private-vlan", ("private_vlan", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.PrivateVlan)), ("trunk", ("trunk", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.Trunk))])
                            self._leafs = OrderedDict([
                                ('dynamic', (YLeaf(YType.enumeration, 'dynamic'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.Dynamic')])),
                            ])
                            self.dynamic = None

                            self.access = None
                            self._children_name_map["access"] = "access"

                            self.dot1q_tunnel = None
                            self._children_name_map["dot1q_tunnel"] = "dot1q-tunnel"

                            self.private_vlan = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.PrivateVlan()
                            self.private_vlan.parent = self
                            self._children_name_map["private_vlan"] = "private-vlan"

                            self.trunk = None
                            self._children_name_map["trunk"] = "trunk"
                            self._segment_path = lambda: "Cisco-IOS-XE-switch:mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode, [u'dynamic'], name, value)

                        class Dynamic(Enum):
                            """
                            Dynamic (Enum Class)

                            Set trunking mode to dynamically negotiate access or trunk mode

                            .. data:: auto = 0

                            .. data:: desirable = 1

                            """

                            auto = Enum.YLeaf(0, "auto")

                            desirable = Enum.YLeaf(1, "desirable")



                        class Access(Entity):
                            """
                            Set trunking mode to ACCESS unconditionally
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "access"
                                self._is_frozen = True


                        class Dot1qTunnel(Entity):
                            """
                            set trunking mode to TUNNEL unconditionally
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.Dot1qTunnel, self).__init__()

                                self.yang_name = "dot1q-tunnel"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "dot1q-tunnel"
                                self._is_frozen = True


                        class PrivateVlan(Entity):
                            """
                            Set private\-vlan mode
                            
                            .. attribute:: host
                            
                            	Set the mode to private\-vlan host
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: promiscuous
                            
                            	Set the mode to private\-vlan promiscuous
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.PrivateVlan, self).__init__()

                                self.yang_name = "private-vlan"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                    ('promiscuous', (YLeaf(YType.empty, 'promiscuous'), ['Empty'])),
                                ])
                                self.host = None
                                self.promiscuous = None
                                self._segment_path = lambda: "private-vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.PrivateVlan, [u'host', u'promiscuous'], name, value)


                        class Trunk(Entity):
                            """
                            Set trunking mode to TRUNK unconditionally
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Mode.Trunk, self).__init__()

                                self.yang_name = "trunk"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "trunk"
                                self._is_frozen = True


                    class PortSecurity(Entity):
                        """
                        Security related command
                        
                        .. attribute:: aging
                        
                        	Port\-security aging commands
                        	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Aging>`
                        
                        .. attribute:: mac_address
                        
                        	Secure mac address
                        	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.MacAddress>`
                        
                        .. attribute:: maximum
                        
                        	Max secure addresses
                        	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Maximum>`
                        
                        .. attribute:: violation
                        
                        	Security violation mode
                        	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Violation>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity, self).__init__()

                            self.yang_name = "port-security"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("aging", ("aging", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Aging)), ("mac-address", ("mac_address", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.MacAddress)), ("maximum", ("maximum", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Maximum))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Violation')])),
                            ])
                            self.violation = None

                            self.aging = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Aging()
                            self.aging.parent = self
                            self._children_name_map["aging"] = "aging"

                            self.mac_address = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.MacAddress()
                            self.mac_address.parent = self
                            self._children_name_map["mac_address"] = "mac-address"

                            self.maximum = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Maximum()
                            self.maximum.parent = self
                            self._children_name_map["maximum"] = "maximum"
                            self._segment_path = lambda: "Cisco-IOS-XE-switch:port-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity, [u'violation'], name, value)

                        class Violation(Enum):
                            """
                            Violation (Enum Class)

                            Security violation mode

                            .. data:: protect = 0

                            .. data:: restrict = 1

                            .. data:: shutdown = 2

                            """

                            protect = Enum.YLeaf(0, "protect")

                            restrict = Enum.YLeaf(1, "restrict")

                            shutdown = Enum.YLeaf(2, "shutdown")



                        class Aging(Entity):
                            """
                            Port\-security aging commands
                            
                            .. attribute:: static
                            
                            	Enable aging for configured secure addresses
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: time
                            
                            	Port\-security aging time
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            .. attribute:: type
                            
                            	Port\-security aging type
                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Aging.Type>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Aging, self).__init__()

                                self.yang_name = "aging"
                                self.yang_parent_name = "port-security"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                    ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Aging.Type')])),
                                ])
                                self.static = None
                                self.time = None
                                self.type = None
                                self._segment_path = lambda: "aging"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Aging, [u'static', u'time', u'type'], name, value)

                            class Type(Enum):
                                """
                                Type (Enum Class)

                                Port\-security aging type

                                .. data:: absolute = 0

                                .. data:: inactivity = 1

                                """

                                absolute = Enum.YLeaf(0, "absolute")

                                inactivity = Enum.YLeaf(1, "inactivity")



                        class MacAddress(Entity):
                            """
                            Secure mac address
                            
                            .. attribute:: sticky
                            
                            	Configure dynamic secure addresses as sticky
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: hw_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: vlan
                            
                            	set VLAN ID of the VLAN on which this address can be learned
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.MacAddress, self).__init__()

                                self.yang_name = "mac-address"
                                self.yang_parent_name = "port-security"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                    ('hw_address', (YLeaf(YType.str, 'hw-address'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.sticky = None
                                self.hw_address = None
                                self.vlan = None
                                self._segment_path = lambda: "mac-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.MacAddress, [u'sticky', u'hw_address', u'vlan'], name, value)


                        class Maximum(Entity):
                            """
                            Max secure addresses
                            
                            .. attribute:: max_addresses
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4097
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Maximum, self).__init__()

                                self.yang_name = "maximum"
                                self.yang_parent_name = "port-security"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_addresses', (YLeaf(YType.uint16, 'max-addresses'), ['int'])),
                                    ('vlan', (YLeaf(YType.str, 'vlan'), ['str'])),
                                ])
                                self.max_addresses = None
                                self.vlan = None
                                self._segment_path = lambda: "maximum"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PortSecurity.Maximum, [u'max_addresses', u'vlan'], name, value)


                    class Trunk(Entity):
                        """
                        Set trunking characteristics of the interface
                        
                        .. attribute:: allowed
                        
                        	Set allowed VLAN characteristics when interface is in trunking mode
                        	**type**\:  :py:class:`Allowed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Allowed>`
                        
                        .. attribute:: encapsulation
                        
                        	Set encapsulation format on trunk port
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Encapsulation>`
                        
                        .. attribute:: native
                        
                        	Set trunking native characteristics when interface is in trunking mode
                        	**type**\:  :py:class:`Native_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_>`
                        
                        .. attribute:: pruning
                        
                        	Set pruning VLAN characteristics when interface is in trunking mode
                        	**type**\:  :py:class:`Pruning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Pruning>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk, self).__init__()

                            self.yang_name = "trunk"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("allowed", ("allowed", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Allowed)), ("native", ("native", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_)), ("pruning", ("pruning", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Pruning))])
                            self._leafs = OrderedDict([
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Encapsulation')])),
                            ])
                            self.encapsulation = None

                            self.allowed = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Allowed()
                            self.allowed.parent = self
                            self._children_name_map["allowed"] = "allowed"

                            self.native = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_()
                            self.native.parent = self
                            self._children_name_map["native"] = "native"

                            self.pruning = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Pruning()
                            self.pruning.parent = self
                            self._children_name_map["pruning"] = "pruning"
                            self._segment_path = lambda: "Cisco-IOS-XE-switch:trunk"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk, [u'encapsulation'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Set encapsulation format on trunk port

                            .. data:: dot1q = 0

                            .. data:: isl = 1

                            .. data:: negotiate = 2

                            """

                            dot1q = Enum.YLeaf(0, "dot1q")

                            isl = Enum.YLeaf(1, "isl")

                            negotiate = Enum.YLeaf(2, "negotiate")



                        class Allowed(Entity):
                            """
                            Set allowed VLAN characteristics when interface is in trunking mode
                            
                            .. attribute:: vlan
                            
                            	Set allowed VLANs when interface is in trunking mode
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Allowed.Vlan>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Allowed, self).__init__()

                                self.yang_name = "allowed"
                                self.yang_parent_name = "trunk"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Allowed.Vlan))])
                                self._leafs = OrderedDict()

                                self.vlan = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Allowed.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "allowed"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Allowed, [], name, value)


                            class Vlan(Entity):
                                """
                                Set allowed VLANs when interface is in trunking mode
                                
                                .. attribute:: vlans
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: add
                                
                                	VLAN IDs of the allowed VLANs when this port is in trunking mode
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\: str
                                
                                .. attribute:: all
                                
                                	all VLANs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: except_
                                
                                	all VLANs except the following
                                	**type**\: union of the below types:
                                
                                		**type**\: list of int
                                
                                			**range:** 0..65535
                                
                                		**type**\: list of str
                                
                                .. attribute:: none
                                
                                	no VLANs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: remove
                                
                                	VLAN IDs of disallowed VLANS when this port is in trunking mode
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Allowed.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "allowed"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlans', (YLeaf(YType.str, 'vlans'), ['str'])),
                                        ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                    ])
                                    self.vlans = None
                                    self.add = None
                                    self.all = None
                                    self.except_ = []
                                    self.none = None
                                    self.remove = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Allowed.Vlan, [u'vlans', u'add', u'all', u'except_', u'none', u'remove'], name, value)


                        class Native_(Entity):
                            """
                            Set trunking native characteristics when interface is in trunking mode
                            
                            .. attribute:: vlan
                            
                            	Set native VLAN when interface is in trunking mode
                            	**type**\: union of the below types:
                            
                            		**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan>`
                            
                            		**type**\: int
                            
                            			**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_, self).__init__()

                                self.yang_name = "native"
                                self.yang_parent_name = "trunk"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_.Vlan'),'int'])),
                                ])
                                self.vlan = None
                                self._segment_path = lambda: "native"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Native_, [u'vlan'], name, value)

                            class Vlan(Enum):
                                """
                                Vlan (Enum Class)

                                Set native VLAN when interface is in trunking mode

                                .. data:: tag = 0

                                """

                                tag = Enum.YLeaf(0, "tag")



                        class Pruning(Entity):
                            """
                            Set pruning VLAN characteristics when interface is in trunking mode
                            
                            .. attribute:: vlan
                            
                            	Set VLANs enabled for pruning when interface is in trunking mode
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Pruning.Vlan>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Pruning, self).__init__()

                                self.yang_name = "pruning"
                                self.yang_parent_name = "trunk"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Pruning.Vlan))])
                                self._leafs = OrderedDict()

                                self.vlan = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Pruning.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "pruning"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Pruning, [], name, value)


                            class Vlan(Entity):
                                """
                                Set VLANs enabled for pruning when interface is in trunking mode
                                
                                .. attribute:: vlans
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: list of int
                                
                                			**range:** 0..65535
                                
                                		**type**\: list of str
                                
                                .. attribute:: add
                                
                                	VLAN IDs of the allowed VLANs when this port is in trunking mode
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\: str
                                
                                .. attribute:: except_
                                
                                	all VLANs except the following
                                	**type**\: union of the below types:
                                
                                		**type**\: list of int
                                
                                			**range:** 0..65535
                                
                                		**type**\: list of str
                                
                                .. attribute:: none
                                
                                	no VLANs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: remove
                                
                                	VLAN IDs of disallowed VLANS when this port is in trunking mode
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..65535
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Pruning.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "pruning"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlans', (YLeafList(YType.str, 'vlans'), ['int','str'])),
                                        ('add', (YLeaf(YType.str, 'add'), ['int','str'])),
                                        ('except_', (YLeafList(YType.str, 'except'), ['int','str'])),
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ('remove', (YLeaf(YType.str, 'remove'), ['int','str'])),
                                    ])
                                    self.vlans = []
                                    self.add = None
                                    self.except_ = []
                                    self.none = None
                                    self.remove = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Trunk.Pruning.Vlan, [u'vlans', u'add', u'except_', u'none', u'remove'], name, value)


                    class Voice(Entity):
                        """
                        Voice appliance attributes
                        
                        .. attribute:: vlan
                        
                        	Vlan for voice traffic
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan>`
                        
                        .. attribute:: detect
                        
                        	detection enhancement keyword
                        	**type**\:  :py:class:`Detect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Detect>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice, self).__init__()

                            self.yang_name = "voice"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan)), ("detect", ("detect", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Detect))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"

                            self.detect = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Detect()
                            self.detect.parent = self
                            self._children_name_map["detect"] = "detect"
                            self._segment_path = lambda: "Cisco-IOS-XE-switch:voice"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice, [], name, value)


                        class Vlan(Entity):
                            """
                            Vlan for voice traffic
                            
                            .. attribute:: vlan
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_>`
                            
                            		**type**\: int
                            
                            			**range:** 1..4094
                            
                            		**type**\: str
                            
                            .. attribute:: name
                            
                            	Vlan name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "voice"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlan', (YLeaf(YType.str, 'vlan'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan.Vlan_'),'int','str'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.vlan = None
                                self.name = None
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Vlan, [u'vlan', u'name'], name, value)

                            class Vlan_(Enum):
                                """
                                Vlan\_ (Enum Class)

                                .. data:: dot1p = 0

                                .. data:: none = 1

                                .. data:: untagged = 2

                                """

                                dot1p = Enum.YLeaf(0, "dot1p")

                                none = Enum.YLeaf(1, "none")

                                untagged = Enum.YLeaf(2, "untagged")



                        class Detect(Entity):
                            """
                            detection enhancement keyword
                            
                            .. attribute:: cisco_phone
                            
                            	Cisco IP phone
                            	**type**\:  :py:class:`CiscoPhone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Detect.CiscoPhone>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Detect, self).__init__()

                                self.yang_name = "detect"
                                self.yang_parent_name = "voice"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cisco-phone", ("cisco_phone", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Detect.CiscoPhone))])
                                self._leafs = OrderedDict()

                                self.cisco_phone = None
                                self._children_name_map["cisco_phone"] = "cisco-phone"
                                self._segment_path = lambda: "detect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Detect, [], name, value)


                            class CiscoPhone(Entity):
                                """
                                Cisco IP phone
                                
                                .. attribute:: full_duplex
                                
                                	full duplex keyword
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Detect.CiscoPhone, self).__init__()

                                    self.yang_name = "cisco-phone"
                                    self.yang_parent_name = "detect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('full_duplex', (YLeaf(YType.empty, 'full-duplex'), ['Empty'])),
                                    ])
                                    self.full_duplex = None
                                    self._segment_path = lambda: "cisco-phone"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Voice.Detect.CiscoPhone, [u'full_duplex'], name, value)


                    class Priority(Entity):
                        """
                        Set appliance 802.1p priority
                        
                        .. attribute:: extend
                        
                        	Set appliance 802.1p priority
                        	**type**\:  :py:class:`Extend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Priority.Extend>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Priority, self).__init__()

                            self.yang_name = "priority"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("extend", ("extend", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Priority.Extend))])
                            self._leafs = OrderedDict()

                            self.extend = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Priority.Extend()
                            self.extend.parent = self
                            self._children_name_map["extend"] = "extend"
                            self._segment_path = lambda: "Cisco-IOS-XE-switch:priority"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Priority, [], name, value)


                        class Extend(Entity):
                            """
                            Set appliance 802.1p priority
                            
                            .. attribute:: trust
                            
                            	Trust 802.1p priorities of devices on appliance
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cos
                            
                            	Override 802.1p priority of devices on appliance
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Priority.Extend, self).__init__()

                                self.yang_name = "extend"
                                self.yang_parent_name = "priority"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                    ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                ])
                                self.trust = None
                                self.cos = None
                                self._segment_path = lambda: "extend"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Priority.Extend, [u'trust', u'cos'], name, value)


                    class Autostate(Entity):
                        """
                        Include or exclude this port from vlan link up calculation
                        
                        .. attribute:: exclude
                        
                        	Exclude this port from vlan link up calculation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Autostate, self).__init__()

                            self.yang_name = "autostate"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('exclude', (YLeaf(YType.empty, 'exclude'), ['Empty'])),
                            ])
                            self.exclude = None
                            self._segment_path = lambda: "Cisco-IOS-XE-switch:autostate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Autostate, [u'exclude'], name, value)


                    class PrivateVlan(Entity):
                        """
                        Set the private VLAN configuration
                        
                        .. attribute:: association
                        
                        	Set the private VLAN association
                        	**type**\:  :py:class:`Association <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association>`
                        
                        .. attribute:: host_association
                        
                        	Set the private VLAN host association
                        	**type**\:  :py:class:`HostAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.HostAssociation>`
                        
                        .. attribute:: mapping
                        
                        	Set the private VLAN promiscuous mapping
                        	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Mapping>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan, self).__init__()

                            self.yang_name = "private-vlan"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("association", ("association", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association)), ("host-association", ("host_association", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.HostAssociation)), ("mapping", ("mapping", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Mapping))])
                            self._leafs = OrderedDict()

                            self.association = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association()
                            self.association.parent = self
                            self._children_name_map["association"] = "association"

                            self.host_association = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.HostAssociation()
                            self.host_association.parent = self
                            self._children_name_map["host_association"] = "host-association"

                            self.mapping = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Mapping()
                            self.mapping.parent = self
                            self._children_name_map["mapping"] = "mapping"
                            self._segment_path = lambda: "Cisco-IOS-XE-switch:private-vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan, [], name, value)


                        class Association(Entity):
                            """
                            Set the private VLAN association
                            
                            .. attribute:: host
                            
                            	Set the private VLAN host association
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association.Host>`
                            
                            .. attribute:: mapping
                            
                            	Set the private VLAN promiscuous mapping
                            	**type**\:  :py:class:`Mapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association.Mapping>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association, self).__init__()

                                self.yang_name = "association"
                                self.yang_parent_name = "private-vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("host", ("host", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association.Host)), ("mapping", ("mapping", Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association.Mapping))])
                                self._leafs = OrderedDict()

                                self.host = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.mapping = Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association.Mapping()
                                self.mapping.parent = self
                                self._children_name_map["mapping"] = "mapping"
                                self._segment_path = lambda: "association"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association, [], name, value)


                            class Host(Entity):
                                """
                                Set the private VLAN host association
                                
                                .. attribute:: primary_range
                                
                                	Primary normal range VLAN ID of the private VLAN port association
                                	**type**\: int
                                
                                	**range:** 2..1001 \| 1006..4094
                                
                                .. attribute:: secondary_range
                                
                                	Secondary normal range VLAN ID of the private VLAN host port association
                                	**type**\: int
                                
                                	**range:** 2..1001 \| 1006..4094
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "association"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                        ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                                    ])
                                    self.primary_range = None
                                    self.secondary_range = None
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association.Host, [u'primary_range', u'secondary_range'], name, value)


                            class Mapping(Entity):
                                """
                                Set the private VLAN promiscuous mapping
                                
                                .. attribute:: primary_range
                                
                                	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                                	**type**\: int
                                
                                	**range:** 2..1001 \| 1006..4094
                                
                                .. attribute:: secondary_range
                                
                                	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                                	**type**\: str
                                
                                .. attribute:: add
                                
                                	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                                	**type**\: str
                                
                                .. attribute:: remove
                                
                                	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association.Mapping, self).__init__()

                                    self.yang_name = "mapping"
                                    self.yang_parent_name = "association"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                        ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                        ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                        ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                                    ])
                                    self.primary_range = None
                                    self.secondary_range = None
                                    self.add = None
                                    self.remove = None
                                    self._segment_path = lambda: "mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Association.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                        class HostAssociation(Entity):
                            """
                            Set the private VLAN host association
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary normal range VLAN ID of the private VLAN host port association
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.HostAssociation, self).__init__()

                                self.yang_name = "host-association"
                                self.yang_parent_name = "private-vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.uint16, 'secondary-range'), ['int'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self._segment_path = lambda: "host-association"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.HostAssociation, [u'primary_range', u'secondary_range'], name, value)


                        class Mapping(Entity):
                            """
                            Set the private VLAN promiscuous mapping
                            
                            .. attribute:: primary_range
                            
                            	Primary normal range VLAN ID of the private VLAN promiscuous port mapping
                            	**type**\: int
                            
                            	**range:** 2..1001 \| 1006..4094
                            
                            .. attribute:: secondary_range
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: add
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            .. attribute:: remove
                            
                            	Secondary VLAN IDs of the private VLAN promiscuous port mapping
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Mapping, self).__init__()

                                self.yang_name = "mapping"
                                self.yang_parent_name = "private-vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary_range', (YLeaf(YType.uint16, 'primary-range'), ['int'])),
                                    ('secondary_range', (YLeaf(YType.str, 'secondary-range'), ['str'])),
                                    ('add', (YLeaf(YType.str, 'add'), ['str'])),
                                    ('remove', (YLeaf(YType.str, 'remove'), ['str'])),
                                ])
                                self.primary_range = None
                                self.secondary_range = None
                                self.add = None
                                self.remove = None
                                self._segment_path = lambda: "mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.PrivateVlan.Mapping, [u'primary_range', u'secondary_range', u'add', u'remove'], name, value)


                    class Vepa(Entity):
                        """
                        Reflective relay configuration
                        
                        .. attribute:: enabled
                        
                        	Enable reflective relay
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Vepa, self).__init__()

                            self.yang_name = "vepa"
                            self.yang_parent_name = "switchport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                            ])
                            self.enabled = None
                            self._segment_path = lambda: "Cisco-IOS-XE-switch:vepa"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switchport.Vepa, [u'enabled'], name, value)


                class StackwiseVirtual(Entity):
                    """
                    Configure stackwise\-virtual link values
                    
                    .. attribute:: link
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..2
                    
                    .. attribute:: dual_active_detection
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.StackwiseVirtual, self).__init__()

                        self.yang_name = "stackwise-virtual"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                            ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                        ])
                        self.link = None
                        self.dual_active_detection = None
                        self._segment_path = lambda: "stackwise-virtual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


                class Arp(Entity):
                    """
                    Set arp type (arpa, probe, snap), timeout, log options or 
                    packet priority
                    
                    .. attribute:: timeout
                    
                    	Set ARP cache timeout
                    	**type**\: int
                    
                    	**range:** 0..2147483
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Arp, [u'timeout'], name, value)


                class Backup(Entity):
                    """
                    Modify backup parameters
                    
                    .. attribute:: delay
                    
                    	Delays before backup line up or down transitions
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Backup.Delay>`
                    
                    .. attribute:: interface
                    
                    	Configure an interface as a backup
                    	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_>`
                    
                    .. attribute:: load
                    
                    	Load thresholds for line up or down transitions
                    	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Backup.Load>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Backup, self).__init__()

                        self.yang_name = "backup"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.PortChannelSubinterface.PortChannel.Backup.Delay)), ("interface", ("interface", Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_)), ("load", ("load", Native.Interface.PortChannelSubinterface.PortChannel.Backup.Load))])
                        self._leafs = OrderedDict()

                        self.delay = Native.Interface.PortChannelSubinterface.PortChannel.Backup.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"

                        self.interface = Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"

                        self.load = Native.Interface.PortChannelSubinterface.PortChannel.Backup.Load()
                        self.load.parent = self
                        self._children_name_map["load"] = "load"
                        self._segment_path = lambda: "backup"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Backup, [], name, value)


                    class Delay(Entity):
                        """
                        Delays before backup line up or down transitions
                        
                        .. attribute:: failure
                        
                        	Seconds
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967294
                        
                        		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                        
                        .. attribute:: secondary_disable
                        
                        	Seconds
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967294
                        
                        		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                                ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                            ])
                            self.failure = None
                            self.secondary_disable = None
                            self._segment_path = lambda: "delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                        class Failure(Enum):
                            """
                            Failure (Enum Class)

                            Seconds

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")


                        class SecondaryDisable(Enum):
                            """
                            SecondaryDisable (Enum Class)

                            Seconds

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")



                    class Interface_(Entity):
                        """
                        Configure an interface as a backup
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.PortChannelSubinterface_>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.PortChannelSubinterface_))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.PortChannelSubinterface_()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface_(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.PortChannelSubinterface_, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Interface_.PortChannelSubinterface_, [u'port_channel'], name, value)


                    class Load(Entity):
                        """
                        Load thresholds for line up or down transitions
                        
                        .. attribute:: kickin
                        
                        	Percentage
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..100
                        
                        		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                        
                        .. attribute:: kickout
                        
                        	Percentage
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..100
                        
                        		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Load, self).__init__()

                            self.yang_name = "load"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                                ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                            ])
                            self.kickin = None
                            self.kickout = None
                            self._segment_path = lambda: "load"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Backup.Load, [u'kickin', u'kickout'], name, value)

                        class Kickin(Enum):
                            """
                            Kickin (Enum Class)

                            Percentage

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")


                        class Kickout(Enum):
                            """
                            Kickout (Enum Class)

                            Percentage

                            .. data:: never = 0

                            """

                            never = Enum.YLeaf(0, "never")



                class Cemoudp(Entity):
                    """
                    cemoudp
                    
                    .. attribute:: reserve
                    
                    	
                    	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Cemoudp.Reserve>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Cemoudp, self).__init__()

                        self.yang_name = "cemoudp"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.PortChannelSubinterface.PortChannel.Cemoudp.Reserve))])
                        self._leafs = OrderedDict()

                        self.reserve = Native.Interface.PortChannelSubinterface.PortChannel.Cemoudp.Reserve()
                        self.reserve.parent = self
                        self._children_name_map["reserve"] = "reserve"
                        self._segment_path = lambda: "cemoudp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Cemoudp, [], name, value)


                    class Reserve(Entity):
                        """
                        
                        
                        .. attribute:: acr
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Cemoudp.Reserve, self).__init__()

                            self.yang_name = "reserve"
                            self.yang_parent_name = "cemoudp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                            ])
                            self.acr = None
                            self._segment_path = lambda: "reserve"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Cemoudp.Reserve, [u'acr'], name, value)


                class CwsTunnel(Entity):
                    """
                    Configure Cloud Web Security Tunnel
                    
                    .. attribute:: in_
                    
                    	Inbound traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: out
                    
                    	Outbound traffic
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.CwsTunnel.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.CwsTunnel, self).__init__()

                        self.yang_name = "cws-tunnel"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("out", ("out", Native.Interface.PortChannelSubinterface.PortChannel.CwsTunnel.Out))])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None

                        self.out = Native.Interface.PortChannelSubinterface.PortChannel.CwsTunnel.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "cws-tunnel"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.CwsTunnel, [u'in_'], name, value)


                    class Out(Entity):
                        """
                        Outbound traffic
                        
                        .. attribute:: tunnel_number
                        
                        	Outboud traffic tunnel identifier
                        	**type**\: int
                        
                        	**range:** 0..65534
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.CwsTunnel.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "cws-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                            ])
                            self.tunnel_number = None
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.CwsTunnel.Out, [u'tunnel_number'], name, value)


                class L2protocolTunnel(Entity):
                    """
                    Tunnel Layer2 protocols
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: drop_threshold
                    
                    	Set drop threshold for protocol packets
                    	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel.DropThreshold>`
                    
                    .. attribute:: shutdown_threshold
                    
                    	Set shutdown threshold for protocol packets
                    	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel.ShutdownThreshold>`
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel, self).__init__()

                        self.yang_name = "l2protocol-tunnel"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel.ShutdownThreshold))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                            ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                            ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                        ])
                        self.cdp = None
                        self.stp = None
                        self.vtp = None

                        self.drop_threshold = Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel.DropThreshold()
                        self.drop_threshold.parent = self
                        self._children_name_map["drop_threshold"] = "drop-threshold"

                        self.shutdown_threshold = Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel.ShutdownThreshold()
                        self.shutdown_threshold.parent = self
                        self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                        self._segment_path = lambda: "l2protocol-tunnel"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                    class DropThreshold(Entity):
                        """
                        Set drop threshold for protocol packets
                        
                        .. attribute:: packet_rate
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: cdp
                        
                        	Cisco Discovery Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: stp
                        
                        	Spanning Tree Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: vtp
                        
                        	Vlan Trunking Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel.DropThreshold, self).__init__()

                            self.yang_name = "drop-threshold"
                            self.yang_parent_name = "l2protocol-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                                ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                                ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                                ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                            ])
                            self.packet_rate = None
                            self.cdp = None
                            self.stp = None
                            self.vtp = None
                            self._segment_path = lambda: "drop-threshold"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                    class ShutdownThreshold(Entity):
                        """
                        Set shutdown threshold for protocol packets
                        
                        .. attribute:: packet_rate
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: cdp
                        
                        	Cisco Discovery Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: stp
                        
                        	Spanning Tree Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        .. attribute:: vtp
                        
                        	Vlan Trunking Protocol
                        	**type**\: int
                        
                        	**range:** 1..4096
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel.ShutdownThreshold, self).__init__()

                            self.yang_name = "shutdown-threshold"
                            self.yang_parent_name = "l2protocol-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                                ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                                ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                                ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                            ])
                            self.packet_rate = None
                            self.cdp = None
                            self.stp = None
                            self.vtp = None
                            self._segment_path = lambda: "shutdown-threshold"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class Encapsulation(Entity):
                    """
                    Set encapsulation type for an interface
                    
                    .. attribute:: dot1q
                    
                    	IEEE 802.1Q Virtual LAN
                    	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Dot1Q>`
                    
                    .. attribute:: isl
                    
                    	Inter Switch Link \- Virtual LAN encapsulation
                    	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Isl>`
                    
                    .. attribute:: ppp
                    
                    	Point\-to\-Point protocol
                    	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Ppp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: slip
                    
                    	Serial Line IP
                    	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Slip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: frame_relay
                    
                    	Frame Relay networks
                    	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.FrameRelay>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation, self).__init__()

                        self.yang_name = "encapsulation"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.FrameRelay))])
                        self._leafs = OrderedDict()

                        self.dot1q = Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Dot1Q()
                        self.dot1q.parent = self
                        self._children_name_map["dot1q"] = "dot1Q"

                        self.isl = Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Isl()
                        self.isl.parent = self
                        self._children_name_map["isl"] = "isl"

                        self.ppp = None
                        self._children_name_map["ppp"] = "ppp"

                        self.slip = None
                        self._children_name_map["slip"] = "slip"

                        self.frame_relay = None
                        self._children_name_map["frame_relay"] = "frame-relay"
                        self._segment_path = lambda: "encapsulation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation, [], name, value)


                    class Dot1Q(Entity):
                        """
                        IEEE 802.1Q Virtual LAN
                        
                        .. attribute:: vlan_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        .. attribute:: native
                        
                        	Make this as native vlan
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Dot1Q, self).__init__()

                            self.yang_name = "dot1Q"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                            ])
                            self.vlan_id = None
                            self.native = None
                            self._segment_path = lambda: "dot1Q"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                    class Isl(Entity):
                        """
                        Inter Switch Link \- Virtual LAN encapsulation
                        
                        .. attribute:: vlan_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4095
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Isl, self).__init__()

                            self.yang_name = "isl"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ])
                            self.vlan_id = None
                            self._segment_path = lambda: "isl"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Isl, [u'vlan_id'], name, value)


                    class Ppp(Entity):
                        """
                        Point\-to\-Point protocol
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Ppp, self).__init__()

                            self.yang_name = "ppp"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "ppp"
                            self._is_frozen = True


                    class Slip(Entity):
                        """
                        Serial Line IP
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.Slip, self).__init__()

                            self.yang_name = "slip"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "slip"
                            self._is_frozen = True


                    class FrameRelay(Entity):
                        """
                        Frame Relay networks
                        
                        .. attribute:: ietf
                        
                        	Use RFC1490/RFC2427 encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.FrameRelay, self).__init__()

                            self.yang_name = "frame-relay"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                            ])
                            self.ietf = None
                            self._segment_path = lambda: "frame-relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Encapsulation.FrameRelay, [u'ietf'], name, value)


                class FairQueueConf(Entity):
                    """
                    
                    
                    .. attribute:: fair_queue
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.FairQueueConf, self).__init__()

                        self.yang_name = "fair-queue-conf"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                        ])
                        self.fair_queue = None
                        self._segment_path = lambda: "fair-queue-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.FairQueueConf, [u'fair_queue'], name, value)


                class FairQueue(Entity):
                    """
                    Enable Fair Queuing on an Interface
                    
                    .. attribute:: incomplete
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.FairQueue, self).__init__()

                        self.yang_name = "fair-queue"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                        ])
                        self.incomplete = None
                        self._segment_path = lambda: "fair-queue"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.FairQueue, [u'incomplete'], name, value)


                class Flowcontrol(Entity):
                    """
                    Configure flow operation.
                    
                    .. attribute:: receive
                    
                    	Configure receiving flow operation
                    	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Flowcontrol.Receive>`
                    
                    .. attribute:: send
                    
                    	Configure sending flow operation
                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Flowcontrol.Send>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Flowcontrol, self).__init__()

                        self.yang_name = "flowcontrol"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Flowcontrol.Receive')])),
                            ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Flowcontrol.Send')])),
                        ])
                        self.receive = None
                        self.send = None
                        self._segment_path = lambda: "flowcontrol"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Flowcontrol, [u'receive', u'send'], name, value)

                    class Receive(Enum):
                        """
                        Receive (Enum Class)

                        Configure receiving flow operation

                        .. data:: desired = 0

                        .. data:: off = 1

                        .. data:: on = 2

                        """

                        desired = Enum.YLeaf(0, "desired")

                        off = Enum.YLeaf(1, "off")

                        on = Enum.YLeaf(2, "on")


                    class Send(Enum):
                        """
                        Send (Enum Class)

                        Configure sending flow operation

                        .. data:: desired = 0

                        .. data:: off = 1

                        .. data:: on = 2

                        """

                        desired = Enum.YLeaf(0, "desired")

                        off = Enum.YLeaf(1, "off")

                        on = Enum.YLeaf(2, "on")



                class Isis(Entity):
                    """
                    IS\-IS commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Isis, self).__init__()

                        self.yang_name = "isis"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "isis"
                        self._is_frozen = True


                class KeepaliveSettings(Entity):
                    """
                    
                    
                    .. attribute:: keepalive
                    
                    	Enable keepalive
                    	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.KeepaliveSettings.Keepalive>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.KeepaliveSettings, self).__init__()

                        self.yang_name = "keepalive-settings"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.PortChannelSubinterface.PortChannel.KeepaliveSettings.Keepalive))])
                        self._leafs = OrderedDict()

                        self.keepalive = None
                        self._children_name_map["keepalive"] = "keepalive"
                        self._segment_path = lambda: "keepalive-settings"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.KeepaliveSettings, [], name, value)


                    class Keepalive(Entity):
                        """
                        Enable keepalive
                        
                        .. attribute:: period
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..32767
                        
                        .. attribute:: retries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.KeepaliveSettings.Keepalive, self).__init__()

                            self.yang_name = "keepalive"
                            self.yang_parent_name = "keepalive-settings"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                            ])
                            self.period = None
                            self.retries = None
                            self._segment_path = lambda: "keepalive"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


                class Bfd(Entity):
                    """
                    BFD interface configuration commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True


                class Bandwidth(Entity):
                    """
                    Set bandwidth informational parameter
                    
                    .. attribute:: receive
                    
                    	Specify receive\-side bandwidth
                    	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth.Receive>`
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth.Inherit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: qos_reference
                    
                    	Reference bandwidth for QOS
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth.Inherit))])
                        self._leafs = OrderedDict([
                            ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.qos_reference = None
                        self.kilobits = None

                        self.receive = Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth.Receive()
                        self.receive.parent = self
                        self._children_name_map["receive"] = "receive"

                        self.inherit = None
                        self._children_name_map["inherit"] = "inherit"
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                    class Receive(Entity):
                        """
                        Specify receive\-side bandwidth
                        
                        .. attribute:: inherit
                        
                        	Specify how bandwidth is inherited
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: kilobits
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth.Receive, self).__init__()

                            self.yang_name = "receive"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                                ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                            ])
                            self.inherit = None
                            self.kilobits = None
                            self._segment_path = lambda: "receive"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                    class Inherit(Entity):
                        """
                        Specify how bandwidth is inherited
                        
                        .. attribute:: kilobits
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth.Inherit, self).__init__()

                            self.yang_name = "inherit"
                            self.yang_parent_name = "bandwidth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                            ])
                            self.kilobits = None
                            self._segment_path = lambda: "inherit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Bandwidth.Inherit, [u'kilobits'], name, value)


                class Dampening(Entity):
                    """
                    Enable event dampening
                    
                    .. attribute:: dampening_time
                    
                    	<1\-30>;;Half\-life time for penalty
                    	**type**\: int
                    
                    	**range:** 1..30
                    
                    .. attribute:: start_reusing_time
                    
                    	<1\-20000>;;Value to start reusing an interface
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    .. attribute:: start_supressing_time
                    
                    	<1\-20000>;;Value to start supressing an interface
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    .. attribute:: maximum_supressing_time
                    
                    	<1\-255>;;Maximum duration to suppress an interface
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Dampening.Restart>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Dampening, self).__init__()

                        self.yang_name = "dampening"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.PortChannelSubinterface.PortChannel.Dampening.Restart))])
                        self._leafs = OrderedDict([
                            ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                            ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                            ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                            ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                        ])
                        self.dampening_time = None
                        self.start_reusing_time = None
                        self.start_supressing_time = None
                        self.maximum_supressing_time = None

                        self.restart = Native.Interface.PortChannelSubinterface.PortChannel.Dampening.Restart()
                        self.restart.parent = self
                        self._children_name_map["restart"] = "restart"
                        self._segment_path = lambda: "dampening"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                    class Restart(Entity):
                        """
                        Enable restart penalty
                        
                        .. attribute:: restart
                        
                        	Enable restart penalty
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restart_penalty
                        
                        	<1\-20000>;;Penalty applied at restart
                        	**type**\: int
                        
                        	**range:** 1..20000
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Dampening.Restart, self).__init__()

                            self.yang_name = "restart"
                            self.yang_parent_name = "dampening"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                                ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                            ])
                            self.restart = None
                            self.restart_penalty = None
                            self._segment_path = lambda: "restart"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


                class Domain(Entity):
                    """
                    Specify a domain
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: path
                    
                    	Specify a service provider for this interface
                    	**type**\: str
                    
                    .. attribute:: internet_bound
                    
                    	Specify Internet\-bound interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: path_id
                    
                    	Specify service provider path\-id for this interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: path_last_resort
                    
                    	Specify if you want this interface to be a path of last resort
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: zero_sla
                    
                    	Specify if you want this interface to be a 0\-sla interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Domain, self).__init__()

                        self.yang_name = "domain"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('path', (YLeaf(YType.str, 'path'), ['str'])),
                            ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                            ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                            ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                            ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                        ])
                        self.name = None
                        self.path = None
                        self.internet_bound = None
                        self.path_id = None
                        self.path_last_resort = None
                        self.zero_sla = None
                        self._segment_path = lambda: "domain"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


                class HoldQueue(Entity):
                    """
                    Set hold queue depth
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.HoldQueue.Direction>`
                    
                    .. attribute:: queue_length
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.HoldQueue, self).__init__()

                        self.yang_name = "hold-queue"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.HoldQueue.Direction')])),
                            ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                        ])
                        self.direction = None
                        self.queue_length = None
                        self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.HoldQueue, [u'direction', u'queue_length'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Mpls(Entity):
                    """
                    
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "mpls"
                        self._is_frozen = True


                class IpVrf(Entity):
                    """
                    
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.IpVrf.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.IpVrf, self).__init__()

                        self.yang_name = "ip-vrf"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.PortChannelSubinterface.PortChannel.IpVrf.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.PortChannelSubinterface.PortChannel.IpVrf.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "ip-vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.IpVrf, [], name, value)


                    class Ip(Entity):
                        """
                        
                        
                        .. attribute:: vrf
                        
                        	
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.IpVrf.Ip.Vrf>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.IpVrf.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "ip-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.PortChannelSubinterface.PortChannel.IpVrf.Ip.Vrf))])
                            self._leafs = OrderedDict()

                            self.vrf = Native.Interface.PortChannelSubinterface.PortChannel.IpVrf.Ip.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.IpVrf.Ip, [], name, value)


                        class Vrf(Entity):
                            """
                            
                            
                            .. attribute:: forwarding
                            
                            	Configure forwarding table
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.IpVrf.Ip.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                                ])
                                self.forwarding = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Vrf, [u'forwarding'], name, value)


                class Ip(Entity):
                    """
                    Interface Internet Protocol config commands
                    
                    .. attribute:: admission
                    
                    	Apply Network Admission Control
                    	**type**\: str
                    
                    .. attribute:: access_group
                    
                    	Specify access control for packets
                    	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup>`
                    
                    .. attribute:: arp
                    
                    	Configure ARP features
                    	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp>`
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding parameters on the interface
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Vrf>`
                    
                    .. attribute:: unnumbered
                    
                    	Enable IP processing without an explicit address
                    	**type**\: str
                    
                    .. attribute:: no_address
                    
                    	
                    	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.NoAddress>`
                    
                    .. attribute:: address
                    
                    	Set the IP address of an interface
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address>`
                    
                    .. attribute:: directed_broadcast
                    
                    	Enable forwarding of directed broadcasts
                    	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.DirectedBroadcast>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Configures EIGRP\-IPv4 hello interval
                    	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.HelloInterval>`
                    
                    .. attribute:: authentication
                    
                    	authentication subcommands
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication>`
                    
                    .. attribute:: hold_time
                    
                    	Configures EIGRP\-IPv4 hold time
                    	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.HoldTime>`
                    
                    .. attribute:: helper_address
                    
                    	Specify a destination address for UDP broadcasts
                    	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.HelperAddress>`
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim>`
                    
                    .. attribute:: policy
                    
                    	Enable policy routing
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Policy>`
                    
                    .. attribute:: local_proxy_arp
                    
                    	Enable local\-proxy ARP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: proxy_arp
                    
                    	Enable proxy ARP
                    	**type**\: bool
                    
                    .. attribute:: rip
                    
                    	Router Information Protocol
                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip>`
                    
                    .. attribute:: route_cache_conf
                    
                    	
                    	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.RouteCacheConf>`
                    
                    .. attribute:: route_cache
                    
                    	Enable fast\-switching cache for outgoing packets
                    	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.RouteCache>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: router
                    
                    	IP router interface commands
                    	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Router>`
                    
                    .. attribute:: redirects
                    
                    	Enable sending ICMP Redirect messages
                    	**type**\: bool
                    
                    .. attribute:: tcp
                    
                    	TCP header compression and other parameters
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Tcp>`
                    
                    .. attribute:: virtual_reassembly
                    
                    	
                    	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.VirtualReassembly>`
                    
                    .. attribute:: dhcp
                    
                    	Configure DHCP parameters for this interface
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Dhcp>`
                    
                    .. attribute:: mtu
                    
                    	Set IP Maximum Transmission Unit
                    	**type**\: int
                    
                    	**range:** 68..9216
                    
                    .. attribute:: mroute_cache
                    
                    	Enable switching cache for incoming multicast packets
                    	**type**\: bool
                    
                    .. attribute:: summary_address
                    
                    	
                    	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.SummaryAddress>`
                    
                    .. attribute:: verify
                    
                    	Enable per packet validation
                    	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp)), ("vrf", ("vrf", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.PortChannelSubinterface.PortChannel.Ip.NoAddress)), ("address", ("address", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.PortChannelSubinterface.PortChannel.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.PortChannelSubinterface.PortChannel.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.PortChannelSubinterface.PortChannel.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.PortChannelSubinterface.PortChannel.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim)), ("policy", ("policy", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Policy)), ("rip", ("rip", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.PortChannelSubinterface.PortChannel.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.PortChannelSubinterface.PortChannel.Ip.RouteCache)), ("router", ("router", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Router)), ("tcp", ("tcp", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.PortChannelSubinterface.PortChannel.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.PortChannelSubinterface.PortChannel.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify))])
                        self._leafs = OrderedDict([
                            ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                            ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                            ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                            ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                            ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                            ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                            ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ])
                        self.admission = None
                        self.unnumbered = None
                        self.local_proxy_arp = None
                        self.proxy_arp = None
                        self.redirects = None
                        self.mtu = None
                        self.mroute_cache = None

                        self.access_group = Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup()
                        self.access_group.parent = self
                        self._children_name_map["access_group"] = "access-group"

                        self.arp = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp()
                        self.arp.parent = self
                        self._children_name_map["arp"] = "arp"

                        self.vrf = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.no_address = Native.Interface.PortChannelSubinterface.PortChannel.Ip.NoAddress()
                        self.no_address.parent = self
                        self._children_name_map["no_address"] = "no-address"

                        self.address = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.directed_broadcast = None
                        self._children_name_map["directed_broadcast"] = "directed-broadcast"

                        self.hello_interval = Native.Interface.PortChannelSubinterface.PortChannel.Ip.HelloInterval()
                        self.hello_interval.parent = self
                        self._children_name_map["hello_interval"] = "hello-interval"

                        self.authentication = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.hold_time = Native.Interface.PortChannelSubinterface.PortChannel.Ip.HoldTime()
                        self.hold_time.parent = self
                        self._children_name_map["hold_time"] = "hold-time"

                        self.pim = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim()
                        self.pim.parent = self
                        self._children_name_map["pim"] = "pim"

                        self.policy = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.rip = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip()
                        self.rip.parent = self
                        self._children_name_map["rip"] = "rip"

                        self.route_cache_conf = Native.Interface.PortChannelSubinterface.PortChannel.Ip.RouteCacheConf()
                        self.route_cache_conf.parent = self
                        self._children_name_map["route_cache_conf"] = "route-cache-conf"

                        self.route_cache = None
                        self._children_name_map["route_cache"] = "route-cache"

                        self.router = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Router()
                        self.router.parent = self
                        self._children_name_map["router"] = "router"

                        self.tcp = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"

                        self.virtual_reassembly = Native.Interface.PortChannelSubinterface.PortChannel.Ip.VirtualReassembly()
                        self.virtual_reassembly.parent = self
                        self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                        self.dhcp = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Dhcp()
                        self.dhcp.parent = self
                        self._children_name_map["dhcp"] = "dhcp"

                        self.summary_address = Native.Interface.PortChannelSubinterface.PortChannel.Ip.SummaryAddress()
                        self.summary_address.parent = self
                        self._children_name_map["summary_address"] = "summary-address"

                        self.verify = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify()
                        self.verify.parent = self
                        self._children_name_map["verify"] = "verify"

                        self.helper_address = YList(self)
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                    class AccessGroup(Entity):
                        """
                        Specify access control for packets
                        
                        .. attribute:: in_
                        
                        	
                        	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In>`
                        
                        .. attribute:: out
                        
                        	
                        	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup, self).__init__()

                            self.yang_name = "access-group"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("in", ("in_", Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out))])
                            self._leafs = OrderedDict()

                            self.in_ = Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In()
                            self.in_.parent = self
                            self._children_name_map["in_"] = "in"

                            self.out = Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out()
                            self.out.parent = self
                            self._children_name_map["out"] = "out"
                            self._segment_path = lambda: "access-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup, [], name, value)


                        class In(Entity):
                            """
                            
                            
                            .. attribute:: common_acl
                            
                            	
                            	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In.CommonAcl>`
                            
                            .. attribute:: acl
                            
                            	
                            	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In.Acl>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In, self).__init__()

                                self.yang_name = "in"
                                self.yang_parent_name = "access-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In.Acl))])
                                self._leafs = OrderedDict()

                                self.common_acl = Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In.CommonAcl()
                                self.common_acl.parent = self
                                self._children_name_map["common_acl"] = "common-acl"

                                self.acl = Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In.Acl()
                                self.acl.parent = self
                                self._children_name_map["acl"] = "acl"
                                self._segment_path = lambda: "in"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In, [], name, value)


                            class CommonAcl(Entity):
                                """
                                
                                
                                .. attribute:: common
                                
                                	specify ipv4 common ACL for packet filtering
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: in_
                                
                                	inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                    self.yang_name = "common-acl"
                                    self.yang_parent_name = "in"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ])
                                    self.common = None
                                    self.in_ = None
                                    self._segment_path = lambda: "common-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                            class Acl(Entity):
                                """
                                
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: in_
                                
                                	inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In.Acl, self).__init__()

                                    self.yang_name = "acl"
                                    self.yang_parent_name = "in"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ])
                                    self.acl_name = None
                                    self.in_ = None
                                    self._segment_path = lambda: "acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                        class Out(Entity):
                            """
                            
                            
                            .. attribute:: common_acl
                            
                            	
                            	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out.CommonAcl>`
                            
                            .. attribute:: acl
                            
                            	
                            	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out.Acl>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out, self).__init__()

                                self.yang_name = "out"
                                self.yang_parent_name = "access-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out.Acl))])
                                self._leafs = OrderedDict()

                                self.common_acl = Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out.CommonAcl()
                                self.common_acl.parent = self
                                self._children_name_map["common_acl"] = "common-acl"

                                self.acl = Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out.Acl()
                                self.acl.parent = self
                                self._children_name_map["acl"] = "acl"
                                self._segment_path = lambda: "out"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out, [], name, value)


                            class CommonAcl(Entity):
                                """
                                
                                
                                .. attribute:: common
                                
                                	specify ipv4 common ACL for packet filtering
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: out
                                
                                	outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                    self.yang_name = "common-acl"
                                    self.yang_parent_name = "out"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.common = None
                                    self.out = None
                                    self._segment_path = lambda: "common-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                            class Acl(Entity):
                                """
                                
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                	**mandatory**\: True
                                
                                .. attribute:: out
                                
                                	outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out.Acl, self).__init__()

                                    self.yang_name = "acl"
                                    self.yang_parent_name = "out"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.acl_name = None
                                    self.out = None
                                    self._segment_path = lambda: "acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                    class Arp(Entity):
                        """
                        Configure ARP features
                        
                        .. attribute:: inspection
                        
                        	Arp Inspection configuration
                        	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp.Inspection>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp, self).__init__()

                            self.yang_name = "arp"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp.Inspection))])
                            self._leafs = OrderedDict()

                            self.inspection = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp.Inspection()
                            self.inspection.parent = self
                            self._children_name_map["inspection"] = "inspection"
                            self._segment_path = lambda: "arp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp, [], name, value)


                        class Inspection(Entity):
                            """
                            Arp Inspection configuration
                            
                            .. attribute:: limit
                            
                            	Configure Rate limit of incoming ARP packets
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp.Inspection.Limit>`
                            
                            .. attribute:: trust
                            
                            	Configure Trust state
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp.Inspection, self).__init__()

                                self.yang_name = "inspection"
                                self.yang_parent_name = "arp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp.Inspection.Limit))])
                                self._leafs = OrderedDict([
                                    ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ])
                                self.trust = None

                                self.limit = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp.Inspection.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "inspection"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp.Inspection, [u'trust'], name, value)


                            class Limit(Entity):
                                """
                                Configure Rate limit of incoming ARP packets
                                
                                .. attribute:: none
                                
                                	No limit
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rate
                                
                                	Rate Limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp.Inspection.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "inspection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                    ])
                                    self.none = None
                                    self.rate = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                    class Vrf(Entity):
                        """
                        VPN Routing/Forwarding parameters on the interface
                        
                        .. attribute:: receive
                        
                        	Add Interface Address into VRF Table
                        	**type**\: str
                        
                        .. attribute:: sitemap
                        
                        	Configure route\-map for routesreceived from this site
                        	**type**\: str
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Vrf.Forwarding>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Vrf.Forwarding))])
                            self._leafs = OrderedDict([
                                ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                                ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                            ])
                            self.receive = None
                            self.sitemap = None

                            self.forwarding = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Vrf.Forwarding()
                            self.forwarding.parent = self
                            self._children_name_map["forwarding"] = "forwarding"
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                        class Forwarding(Entity):
                            """
                            Configure forwarding table
                            
                            .. attribute:: liin_vrf
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: mgmtvrf
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: word
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Vrf.Forwarding, self).__init__()

                                self.yang_name = "forwarding"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                    ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.liin_vrf = None
                                self.mgmtvrf = None
                                self.word = None
                                self._segment_path = lambda: "forwarding"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                    class NoAddress(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.NoAddress, self).__init__()

                            self.yang_name = "no-address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                            ])
                            self.address = None
                            self._segment_path = lambda: "no-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.NoAddress, [u'address'], name, value)


                    class Address(Entity):
                        """
                        Set the IP address of an interface
                        
                        .. attribute:: secondary
                        
                        	
                        	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Secondary>`
                        
                        .. attribute:: primary
                        
                        	
                        	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Primary>`
                        
                        .. attribute:: dhcp
                        
                        	IP Address negotiated via DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Dhcp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: negotiated
                        
                        	IP Address negotiated via IKEv2 Modeconfig
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Dhcp))])
                            self._leafs = OrderedDict([
                                ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                            ])
                            self.negotiated = None

                            self.primary = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Primary()
                            self.primary.parent = self
                            self._children_name_map["primary"] = "primary"

                            self.dhcp = None
                            self._children_name_map["dhcp"] = "dhcp"

                            self.secondary = YList(self)
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address, [u'negotiated'], name, value)


                        class Secondary(Entity):
                            """
                            
                            
                            .. attribute:: address  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**mandatory**\: True
                            
                            .. attribute:: secondary
                            
                            	Make this IP address a secondary address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Secondary, self).__init__()

                                self.yang_name = "secondary"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.address = None
                                self.mask = None
                                self.secondary = None
                                self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                        class Primary(Entity):
                            """
                            
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Primary, self).__init__()

                                self.yang_name = "primary"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.address = None
                                self.mask = None
                                self._segment_path = lambda: "primary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Primary, [u'address', u'mask'], name, value)


                        class Dhcp(Entity):
                            """
                            IP Address negotiated via DHCP
                            
                            .. attribute:: client_id
                            
                            	Specify client\-id to use
                            	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Dhcp.ClientId>`
                            
                            .. attribute:: hostname
                            
                            	Specify value for hostname option
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Dhcp.ClientId))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                                ])
                                self.hostname = None

                                self.client_id = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Dhcp.ClientId()
                                self.client_id.parent = self
                                self._children_name_map["client_id"] = "client-id"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Dhcp, [u'hostname'], name, value)


                            class ClientId(Entity):
                                """
                                Specify client\-id to use
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five Gigabit Ethernet 
                                	**type**\: str
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five Gigabit Ethernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two Gigabit Ethernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: vlan
                                
                                	Catalyst Vlans
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Dhcp.ClientId, self).__init__()

                                    self.yang_name = "client-id"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.port_channel = None
                                    self.tengigabitethernet = None
                                    self.twentyfivegige = None
                                    self.fortygigabitethernet = None
                                    self.twogigabitethernet = None
                                    self.hundredgige = None
                                    self.vlan = None
                                    self._segment_path = lambda: "client-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                    class DirectedBroadcast(Entity):
                        """
                        Enable forwarding of directed broadcasts
                        
                        .. attribute:: direct_broadcast
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.DirectedBroadcast, self).__init__()

                            self.yang_name = "directed-broadcast"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                            ])
                            self.direct_broadcast = None
                            self._segment_path = lambda: "directed-broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                    class HelloInterval(Entity):
                        """
                        Configures EIGRP\-IPv4 hello interval
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: seconds
                        
                        	Seconds between hello transmissions
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.HelloInterval, self).__init__()

                            self.yang_name = "hello-interval"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                            ])
                            self.eigrp = None
                            self.seconds = None
                            self._segment_path = lambda: "hello-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                    class Authentication(Entity):
                        """
                        authentication subcommands
                        
                        .. attribute:: key_chain
                        
                        	key\-chain
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication.KeyChain>`
                        
                        .. attribute:: mode
                        
                        	mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication.Mode))])
                            self._leafs = OrderedDict()

                            self.key_chain = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"

                            self.mode = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication, [], name, value)


                        class KeyChain(Entity):
                            """
                            key\-chain
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: name
                            
                            	name of key\-chain
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.eigrp = None
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                        class Mode(Entity):
                            """
                            mode
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                ])
                                self.eigrp = None
                                self.md5 = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                    class HoldTime(Entity):
                        """
                        Configures EIGRP\-IPv4 hold time
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: seconds
                        
                        	Seconds before neighbor is considered down
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.HoldTime, self).__init__()

                            self.yang_name = "hold-time"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                            ])
                            self.eigrp = None
                            self.seconds = None
                            self._segment_path = lambda: "hold-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                    class HelperAddress(Entity):
                        """
                        Specify a destination address for UDP broadcasts
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: global_
                        
                        	Helper\-address is global
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vrf
                        
                        	VRF name for helper\-address (if different from interface VRF)
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.HelperAddress, self).__init__()

                            self.yang_name = "helper-address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.address = None
                            self.global_ = None
                            self.vrf = None
                            self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                    class Pim(Entity):
                        """
                        PIM interface commands
                        
                        .. attribute:: accept_register
                        
                        	
                        	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.AcceptRegister>`
                        
                        .. attribute:: pim_mode
                        
                        	
                        	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.PimMode>`
                        
                        .. attribute:: nbma_mode
                        
                        	Enable PIM nbma\-mode operation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dr_priority
                        
                        	PIM router DR priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: query_interval
                        
                        	PIM router query interval
                        	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.QueryInterval>`
                        
                        .. attribute:: spt_threshold
                        
                        	
                        	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.SptThreshold>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim, self).__init__()

                            self.yang_name = "pim"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.QueryInterval))])
                            self._leafs = OrderedDict([
                                ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Ip.Pim.PimMode')])),
                                ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                                ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Ip.Pim.SptThreshold')])),
                            ])
                            self.pim_mode = None
                            self.nbma_mode = None
                            self.dr_priority = None
                            self.spt_threshold = None

                            self.accept_register = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.AcceptRegister()
                            self.accept_register.parent = self
                            self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                            self.query_interval = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.QueryInterval()
                            self.query_interval.parent = self
                            self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                            self._segment_path = lambda: "pim"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                        class PimMode(Enum):
                            """
                            PimMode (Enum Class)

                            .. data:: passive = 0

                            .. data:: dense_mode = 1

                            .. data:: sparse_mode = 2

                            .. data:: sparse_dense_mode = 3

                            """

                            passive = Enum.YLeaf(0, "passive")

                            dense_mode = Enum.YLeaf(1, "dense-mode")

                            sparse_mode = Enum.YLeaf(2, "sparse-mode")

                            sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                        class SptThreshold(Enum):
                            """
                            SptThreshold (Enum Class)

                            .. data:: infinity = 0

                            """

                            infinity = Enum.YLeaf(0, "infinity")



                        class AcceptRegister(Entity):
                            """
                            
                            
                            .. attribute:: list
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-mc'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.AcceptRegister, self).__init__()

                                self.yang_name = "accept-register"
                                self.yang_parent_name = "pim"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('list', (YLeaf(YType.str, 'list'), ['str'])),
                                ])
                                self.list = None
                                self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.AcceptRegister, ['list'], name, value)


                        class QueryInterval(Entity):
                            """
                            PIM router query interval
                            
                            .. attribute:: seconds_interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..18725
                            
                            .. attribute:: milliseconds_interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 100..65535
                            
                            .. attribute:: msec
                            
                            	Query interval in milliseconds
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'ios-mc'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.QueryInterval, self).__init__()

                                self.yang_name = "query-interval"
                                self.yang_parent_name = "pim"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                    ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                    ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                                ])
                                self.seconds_interval = None
                                self.milliseconds_interval = None
                                self.msec = None
                                self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                    class Policy(Entity):
                        """
                        Enable policy routing
                        
                        .. attribute:: route_map
                        
                        	Policy route\-map
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Policy, [u'route_map'], name, value)


                    class Rip(Entity):
                        """
                        Router Information Protocol
                        
                        .. attribute:: authentication
                        
                        	Authentication control
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip.Authentication>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip, self).__init__()

                            self.yang_name = "rip"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip.Authentication))])
                            self._leafs = OrderedDict()

                            self.authentication = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"
                            self._segment_path = lambda: "rip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip, [], name, value)


                        class Authentication(Entity):
                            """
                            Authentication control
                            
                            .. attribute:: key_chain
                            
                            	Authentication key\-chain
                            	**type**\: str
                            
                            .. attribute:: mode
                            
                            	Authentication mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip.Authentication.Mode>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "rip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip.Authentication.Mode))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.mode = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip.Authentication.Mode()
                                self.mode.parent = self
                                self._children_name_map["mode"] = "mode"
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip.Authentication, [u'key_chain'], name, value)


                            class Mode(Entity):
                                """
                                Authentication mode
                                
                                .. attribute:: md5
                                
                                	Keyed message digest
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: text
                                
                                	Clear text authentication
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip.Authentication.Mode, self).__init__()

                                    self.yang_name = "mode"
                                    self.yang_parent_name = "authentication"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                        ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                    ])
                                    self.md5 = None
                                    self.text = None
                                    self._segment_path = lambda: "mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                    class RouteCacheConf(Entity):
                        """
                        
                        
                        .. attribute:: route_cache
                        
                        	
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.RouteCacheConf, self).__init__()

                            self.yang_name = "route-cache-conf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                            ])
                            self.route_cache = None
                            self._segment_path = lambda: "route-cache-conf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.RouteCacheConf, [u'route_cache'], name, value)


                    class RouteCache(Entity):
                        """
                        Enable fast\-switching cache for outgoing packets
                        
                        .. attribute:: cef
                        
                        	Enable Cisco Express Forwarding
                        	**type**\: bool
                        
                        .. attribute:: flow
                        
                        	Enable Flow fast\-switching cache
                        	**type**\: bool
                        
                        .. attribute:: policy
                        
                        	Enable fast\-switching policy cache for outgoing packets
                        	**type**\: bool
                        
                        .. attribute:: same_interface
                        
                        	Enable fast\-switching on the same interface
                        	**type**\: bool
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.RouteCache, self).__init__()

                            self.yang_name = "route-cache"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                                ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                                ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                                ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                            ])
                            self.cef = None
                            self.flow = None
                            self.policy = None
                            self.same_interface = None
                            self._segment_path = lambda: "route-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                    class Router(Entity):
                        """
                        IP router interface commands
                        
                        .. attribute:: isis
                        
                        	IS\-IS Routing for IP
                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Router.Isis>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Router, self).__init__()

                            self.yang_name = "router"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Router.Isis))])
                            self._leafs = OrderedDict()

                            self.isis = None
                            self._children_name_map["isis"] = "isis"
                            self._segment_path = lambda: "router"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Router, [], name, value)


                        class Isis(Entity):
                            """
                            IS\-IS Routing for IP
                            
                            .. attribute:: tag
                            
                            	
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Router.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "router"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                                ])
                                self.tag = None
                                self._segment_path = lambda: "isis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Router.Isis, [u'tag'], name, value)


                    class Tcp(Entity):
                        """
                        TCP header compression and other parameters
                        
                        .. attribute:: adjust_mss
                        
                        	Adjust the mss of transit packets
                        	**type**\: int
                        
                        	**range:** 500..1460
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                            ])
                            self.adjust_mss = None
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Tcp, [u'adjust_mss'], name, value)


                    class VirtualReassembly(Entity):
                        """
                        
                        
                        .. attribute:: max_reassemblies
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_fragments
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: timeout
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop_fragments
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: in_
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.VirtualReassembly, self).__init__()

                            self.yang_name = "virtual-reassembly"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                                ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                                ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                                ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                            ])
                            self.max_reassemblies = None
                            self.max_fragments = None
                            self.timeout = None
                            self.drop_fragments = None
                            self.in_ = None
                            self._segment_path = lambda: "virtual-reassembly"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                    class Dhcp(Entity):
                        """
                        Configure DHCP parameters for this interface
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True


                    class SummaryAddress(Entity):
                        """
                        
                        
                        .. attribute:: eigrp
                        
                        	
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.SummaryAddress.Eigrp>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.SummaryAddress, self).__init__()

                            self.yang_name = "summary-address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.PortChannelSubinterface.PortChannel.Ip.SummaryAddress.Eigrp))])
                            self._leafs = OrderedDict()

                            self.eigrp = YList(self)
                            self._segment_path = lambda: "summary-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.SummaryAddress, [], name, value)


                        class Eigrp(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: metric
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.SummaryAddress.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "summary-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ])
                                self.id = None
                                self.ip = None
                                self.mask = None
                                self.metric = None
                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                    class Verify(Entity):
                        """
                        Enable per packet validation
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: unicast
                        
                        	Enable per packet validation for unicast
                        	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify, self).__init__()

                            self.yang_name = "verify"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source", ("source", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast))])
                            self._leafs = OrderedDict()

                            self.source = None
                            self._children_name_map["source"] = "source"

                            self.unicast = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast()
                            self.unicast.parent = self
                            self._children_name_map["unicast"] = "unicast"
                            self._segment_path = lambda: "verify"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify, [], name, value)


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source.Vlan>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "verify"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source.Vlan))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.vlan = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source, [], name, value)


                            class Vlan(Entity):
                                """
                                vlan specification
                                
                                .. attribute:: dhcp_snooping
                                
                                	snooping enable vlan
                                	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source.Vlan.DhcpSnooping>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                    self._leafs = OrderedDict()

                                    self.dhcp_snooping = None
                                    self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source.Vlan, [], name, value)


                                class DhcpSnooping(Entity):
                                    """
                                    snooping enable vlan
                                    
                                    .. attribute:: port_security
                                    
                                    	port security
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                        self.yang_name = "dhcp-snooping"
                                        self.yang_parent_name = "vlan"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                        ])
                                        self.port_security = None
                                        self._segment_path = lambda: "dhcp-snooping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                        class Unicast(Entity):
                            """
                            Enable per packet validation for unicast
                            
                            .. attribute:: reverse_path
                            
                            	Reverse path validation of source address (old command format)
                            	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast.ReversePath>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: source
                            
                            	Validation of source address
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast.Source>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast, self).__init__()

                                self.yang_name = "unicast"
                                self.yang_parent_name = "verify"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast.Source))])
                                self._leafs = OrderedDict()

                                self.reverse_path = None
                                self._children_name_map["reverse_path"] = "reverse-path"

                                self.source = Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "unicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast, [], name, value)


                            class ReversePath(Entity):
                                """
                                Reverse path validation of source address (old command format)
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast.ReversePath, self).__init__()

                                    self.yang_name = "reverse-path"
                                    self.yang_parent_name = "unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "reverse-path"
                                    self._is_frozen = True


                            class Source(Entity):
                                """
                                Validation of source address
                                
                                .. attribute:: reachable_via
                                
                                	Specify reachability check to apply to the source address
                                	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast.Source.ReachableVia>`
                                
                                .. attribute:: allow_self_ping
                                
                                	Allow router to ping itself (opens vulnerability in verification)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allow_default
                                
                                	Allow default route to match when checking source address
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast.Source.ReachableVia')])),
                                        ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                        ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                    ])
                                    self.reachable_via = None
                                    self.allow_self_ping = None
                                    self.allow_default = None
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                                class ReachableVia(Enum):
                                    """
                                    ReachableVia (Enum Class)

                                    Specify reachability check to apply to the source address

                                    .. data:: any = 0

                                    .. data:: rx = 1

                                    """

                                    any = Enum.YLeaf(0, "any")

                                    rx = Enum.YLeaf(1, "rx")



                class Ipv6(Entity):
                    """
                    IPv6 interface subcommands
                    
                    .. attribute:: destination_guard
                    
                    	Configure ipv6 destination guard on the interface
                    	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.DestinationGuard>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: source_guard
                    
                    	Configure ipv6 source guard on the interface
                    	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.SourceGuard>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dhcp
                    
                    	IPv6 DHCP interface subcommands
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Dhcp>`
                    
                    .. attribute:: address
                    
                    	Configure IPv6 address on interface
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address>`
                    
                    .. attribute:: unnumbered
                    
                    	Preferred interface for source address selection
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable IPv6 on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mtu
                    
                    	Set IPv6 Maximum Transmission Unit
                    	**type**\: int
                    
                    	**range:** 1280..9216
                    
                    .. attribute:: nd
                    
                    	IPv6 interface Neighbor Discovery subcommands
                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Nd>`
                    
                    .. attribute:: redirects
                    
                    	Enable sending ICMP Redirect messages
                    	**type**\: bool
                    
                    .. attribute:: tcp
                    
                    	TCP header compression and other parameters
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Tcp>`
                    
                    .. attribute:: traffic_filter
                    
                    	Access control list for packets
                    	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.TrafficFilter>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Dhcp)), ("address", ("address", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address)), ("nd", ("nd", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.TrafficFilter))])
                        self._leafs = OrderedDict([
                            ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                            ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ])
                        self.unnumbered = None
                        self.enable = None
                        self.mtu = None
                        self.redirects = None

                        self.destination_guard = None
                        self._children_name_map["destination_guard"] = "destination-guard"

                        self.source_guard = None
                        self._children_name_map["source_guard"] = "source-guard"

                        self.dhcp = Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Dhcp()
                        self.dhcp.parent = self
                        self._children_name_map["dhcp"] = "dhcp"

                        self.address = Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.nd = Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Nd()
                        self.nd.parent = self
                        self._children_name_map["nd"] = "nd"

                        self.tcp = Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"

                        self.traffic_filter = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                    class DestinationGuard(Entity):
                        """
                        Configure ipv6 destination guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature ipv6 destguard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.DestinationGuard, self).__init__()

                            self.yang_name = "destination-guard"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "destination-guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                    class SourceGuard(Entity):
                        """
                        Configure ipv6 source guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature ipv6 sourceguard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.SourceGuard, self).__init__()

                            self.yang_name = "source-guard"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "source-guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                    class Dhcp(Entity):
                        """
                        IPv6 DHCP interface subcommands
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True


                    class Address(Entity):
                        """
                        Configure IPv6 address on interface
                        
                        .. attribute:: dhcp
                        
                        	Obtain IPv6 address from DHCP server
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.Dhcp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: autoconfig
                        
                        	Obtain address using autoconfiguration
                        	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.Autoconfig>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: prefix_list
                        
                        	
                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.PrefixList>`
                        
                        .. attribute:: link_local_address
                        
                        	
                        	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.LinkLocalAddress>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.LinkLocalAddress))])
                            self._leafs = OrderedDict()

                            self.dhcp = None
                            self._children_name_map["dhcp"] = "dhcp"

                            self.autoconfig = None
                            self._children_name_map["autoconfig"] = "autoconfig"

                            self.prefix_list = YList(self)
                            self.link_local_address = YList(self)
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address, [], name, value)


                        class Dhcp(Entity):
                            """
                            Obtain IPv6 address from DHCP server
                            
                            .. attribute:: rapid_commit
                            
                            	rapid\-commit for prefix delegation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                                ])
                                self.rapid_commit = None
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                        class Autoconfig(Entity):
                            """
                            Obtain address using autoconfiguration
                            
                            .. attribute:: default
                            
                            	Insert default route
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.Autoconfig, self).__init__()

                                self.yang_name = "autoconfig"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ])
                                self.default = None
                                self._segment_path = lambda: "autoconfig"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.Autoconfig, [u'default'], name, value)


                        class PrefixList(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: anycast
                            
                            	Configure as an anycast
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: eui_64
                            
                            	Use eui\-64 interface identifier
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.PrefixList, self).__init__()

                                self.yang_name = "prefix-list"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                    ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                                ])
                                self.prefix = None
                                self.anycast = None
                                self.eui_64 = None
                                self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                        class LinkLocalAddress(Entity):
                            """
                            
                            
                            .. attribute:: address  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: link_local
                            
                            	Use link\-local address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.LinkLocalAddress, self).__init__()

                                self.yang_name = "link-local-address"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                                ])
                                self.address = None
                                self.link_local = None
                                self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                    class Nd(Entity):
                        """
                        IPv6 interface Neighbor Discovery subcommands
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Nd, self).__init__()

                            self.yang_name = "nd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "nd"
                            self._is_frozen = True


                    class Tcp(Entity):
                        """
                        TCP header compression and other parameters
                        
                        .. attribute:: adjust_mss
                        
                        	Adjust the mss of transit packets
                        	**type**\: int
                        
                        	**range:** 40..1454
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                            ])
                            self.adjust_mss = None
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.Tcp, [u'adjust_mss'], name, value)


                    class TrafficFilter(Entity):
                        """
                        Access control list for packets
                        
                        .. attribute:: direction  (key)
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.TrafficFilter.Direction>`
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.TrafficFilter, self).__init__()

                            self.yang_name = "traffic-filter"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['direction']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Ipv6.TrafficFilter.Direction')])),
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                            ])
                            self.direction = None
                            self.access_list = None
                            self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: in_ = 0

                            .. data:: out = 1

                            """

                            in_ = Enum.YLeaf(0, "in")

                            out = Enum.YLeaf(1, "out")



                class Logging(Entity):
                    """
                    Configure logging for interface
                    
                    .. attribute:: event
                    
                    	Interface events
                    	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Logging, self).__init__()

                        self.yang_name = "logging"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("event", ("event", Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event))])
                        self._leafs = OrderedDict()

                        self.event = Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event()
                        self.event.parent = self
                        self._children_name_map["event"] = "event"
                        self._segment_path = lambda: "logging"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Logging, [], name, value)


                    class Event(Entity):
                        """
                        Interface events
                        
                        .. attribute:: bundle_status
                        
                        	BUNDLE/UNBUNDLE messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: link_status
                        
                        	UPDOWN and CHANGE messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trunk_status
                        
                        	TRUNK status messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: nfas_status
                        
                        	NFAS D\-channel status messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: power_inline_status
                        
                        	Inline power messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: spanning_tree
                        
                        	Spanning\-tree Interface events
                        	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event.SpanningTree>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: subif_link_status
                        
                        	Sub\-interface UPDOWN and CHANGE messages
                        	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event.SubifLinkStatus>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event, self).__init__()

                            self.yang_name = "event"
                            self.yang_parent_name = "logging"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event.SubifLinkStatus))])
                            self._leafs = OrderedDict([
                                ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                                ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                                ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                                ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.bundle_status = None
                            self.link_status = None
                            self.trunk_status = None
                            self.nfas_status = None
                            self.power_inline_status = None
                            self.status = None

                            self.spanning_tree = None
                            self._children_name_map["spanning_tree"] = "spanning-tree"

                            self.subif_link_status = None
                            self._children_name_map["subif_link_status"] = "subif-link-status"
                            self._segment_path = lambda: "event"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                        class SpanningTree(Entity):
                            """
                            Spanning\-tree Interface events
                            
                            .. attribute:: status
                            
                            	Spanning\-tree state change messages
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event.SpanningTree, self).__init__()

                                self.yang_name = "spanning-tree"
                                self.yang_parent_name = "event"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                                ])
                                self.status = None
                                self._segment_path = lambda: "spanning-tree"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event.SpanningTree, [u'status'], name, value)


                        class SubifLinkStatus(Entity):
                            """
                            Sub\-interface UPDOWN and CHANGE messages
                            
                            .. attribute:: ignore_bulk
                            
                            	Do not log messages when the main interface is transitioning
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event.SubifLinkStatus, self).__init__()

                                self.yang_name = "subif-link-status"
                                self.yang_parent_name = "event"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                                ])
                                self.ignore_bulk = None
                                self._segment_path = lambda: "subif-link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


                class Mdix(Entity):
                    """
                    Set Media Dependent Interface with Crossover
                    
                    .. attribute:: auto
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Mdix, self).__init__()

                        self.yang_name = "mdix"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "mdix"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Mdix, [u'auto'], name, value)


                class Mop(Entity):
                    """
                    
                    
                    .. attribute:: enabled
                    
                    	
                    	**type**\: bool
                    
                    .. attribute:: sysid
                    
                    	Send out MOP periodic system ID messages
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Mop, self).__init__()

                        self.yang_name = "mop"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                            ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                        ])
                        self.enabled = None
                        self.sysid = None
                        self._segment_path = lambda: "mop"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Mop, [u'enabled', u'sysid'], name, value)


                class InterfaceQos(Entity):
                    """
                    
                    
                    .. attribute:: trust
                    
                    	
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.InterfaceQos.Trust>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.InterfaceQos, self).__init__()

                        self.yang_name = "interface_qos"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.PortChannelSubinterface.PortChannel.InterfaceQos.Trust))])
                        self._leafs = OrderedDict()

                        self.trust = Native.Interface.PortChannelSubinterface.PortChannel.InterfaceQos.Trust()
                        self.trust.parent = self
                        self._children_name_map["trust"] = "trust"
                        self._segment_path = lambda: "interface_qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.InterfaceQos, [], name, value)


                    class Trust(Entity):
                        """
                        
                        
                        .. attribute:: device
                        
                        	
                        	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.InterfaceQos.Trust.Device>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.InterfaceQos.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "interface_qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.InterfaceQos.Trust.Device')])),
                            ])
                            self.device = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.InterfaceQos.Trust, [u'device'], name, value)

                        class Device(Enum):
                            """
                            Device (Enum Class)

                            .. data:: cisco_phone = 0

                            """

                            cisco_phone = Enum.YLeaf(0, "cisco-phone")



                class Source(Entity):
                    """
                    Get config from another source
                    
                    .. attribute:: template
                    
                    	Get config from a template
                    	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Source.Template>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Source, self).__init__()

                        self.yang_name = "source"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template", ("template", Native.Interface.PortChannelSubinterface.PortChannel.Source.Template))])
                        self._leafs = OrderedDict()

                        self.template = Native.Interface.PortChannelSubinterface.PortChannel.Source.Template()
                        self.template.parent = self
                        self._children_name_map["template"] = "template"
                        self._segment_path = lambda: "source"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Source, [], name, value)


                    class Template(Entity):
                        """
                        Get config from a template
                        
                        .. attribute:: template_name
                        
                        	
                        	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Source.Template.TemplateName>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Source.Template, self).__init__()

                            self.yang_name = "template"
                            self.yang_parent_name = "source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.PortChannelSubinterface.PortChannel.Source.Template.TemplateName))])
                            self._leafs = OrderedDict()

                            self.template_name = YList(self)
                            self._segment_path = lambda: "template"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Source.Template, [], name, value)


                        class TemplateName(Entity):
                            """
                            
                            
                            .. attribute:: template_name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: merge
                            
                            	merge option of binding
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Source.Template.TemplateName, self).__init__()

                                self.yang_name = "template-name"
                                self.yang_parent_name = "template"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['template_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                    ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                                ])
                                self.template_name = None
                                self.merge = None
                                self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


                class Standby(Entity):
                    """
                    HSRP interface configuration commands
                    
                    .. attribute:: version
                    
                    	HSRP version
                    	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.Version>`
                    
                    .. attribute:: bfd
                    
                    	Enable HSRP BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: delay
                    
                    	HSRP initialisation delay
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.Delay>`
                    
                    .. attribute:: mac_refresh
                    
                    	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: use_bia
                    
                    	HSRP uses interface's burned in address
                    	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.UseBia>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: standby_list
                    
                    	
                    	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Standby, self).__init__()

                        self.yang_name = "standby"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.PortChannelSubinterface.PortChannel.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.PortChannelSubinterface.PortChannel.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Standby.Version')])),
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                        ])
                        self.version = None
                        self.bfd = None
                        self.mac_refresh = None

                        self.delay = Native.Interface.PortChannelSubinterface.PortChannel.Standby.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"

                        self.use_bia = None
                        self._children_name_map["use_bia"] = "use-bia"

                        self.standby_list = YList(self)
                        self._segment_path = lambda: "standby"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                    class Version(Enum):
                        """
                        Version (Enum Class)

                        HSRP version

                        .. data:: Y_1 = 0

                        .. data:: Y_2 = 1

                        """

                        Y_1 = Enum.YLeaf(0, "1")

                        Y_2 = Enum.YLeaf(1, "2")



                    class Delay(Entity):
                        """
                        HSRP initialisation delay
                        
                        .. attribute:: minimum
                        
                        	Minimum delay
                        	**type**\: int
                        
                        	**range:** 0..10000
                        
                        .. attribute:: reload
                        
                        	Delay after reload
                        	**type**\: int
                        
                        	**range:** 0..10000
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "standby"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                            ])
                            self.minimum = None
                            self.reload = None
                            self._segment_path = lambda: "delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.Delay, [u'minimum', u'reload'], name, value)


                    class UseBia(Entity):
                        """
                        HSRP uses interface's burned in address
                        
                        .. attribute:: scope
                        
                        	Specify the scope of use\-bia
                        	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.UseBia.Scope>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.UseBia, self).__init__()

                            self.yang_name = "use-bia"
                            self.yang_parent_name = "standby"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.PortChannelSubinterface.PortChannel.Standby.UseBia.Scope))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.scope = Native.Interface.PortChannelSubinterface.PortChannel.Standby.UseBia.Scope()
                            self.scope.parent = self
                            self._children_name_map["scope"] = "scope"
                            self._segment_path = lambda: "use-bia"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.UseBia, [], name, value)


                        class Scope(Entity):
                            """
                            Specify the scope of use\-bia
                            
                            .. attribute:: interface
                            
                            	Use\-bia applies to all groups on this interface or sub\-interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.UseBia.Scope, self).__init__()

                                self.yang_name = "scope"
                                self.yang_parent_name = "use-bia"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                                ])
                                self.interface = None
                                self._segment_path = lambda: "scope"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.UseBia.Scope, [u'interface'], name, value)


                    class StandbyList(Entity):
                        """
                        
                        
                        .. attribute:: group_number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: authentication
                        
                        	Authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication>`
                        
                        .. attribute:: follow
                        
                        	Name of HSRP group to follow
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	Enable HSRP and set the virtual IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Ip>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	Enable HSRP IPv6
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                        
                        .. attribute:: mac_address
                        
                        	Virtual MAC address
                        	**type**\: str
                        
                        .. attribute:: name
                        
                        	Redundancy name string
                        	**type**\: str
                        
                        .. attribute:: preempt
                        
                        	Overthrow lower priority Active routers
                        	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Preempt>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Priority level
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: redirect
                        
                        	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect>`
                        
                        .. attribute:: timers
                        
                        	Hello and hold timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers>`
                        
                        .. attribute:: track
                        
                        	Priority tracking
                        	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Track>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList, self).__init__()

                            self.yang_name = "standby-list"
                            self.yang_parent_name = "standby"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['group_number']
                            self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Track))])
                            self._leafs = OrderedDict([
                                ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                                ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.group_number = None
                            self.follow = None
                            self.ipv6 = None
                            self.mac_address = None
                            self.name = None
                            self.priority = None

                            self.authentication = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.ip = None
                            self._children_name_map["ip"] = "ip"

                            self.preempt = None
                            self._children_name_map["preempt"] = "preempt"

                            self.redirect = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"

                            self.timers = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"

                            self.track = YList(self)
                            self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                        class Ipv6(Enum):
                            """
                            Ipv6 (Enum Class)

                            Enable HSRP IPv6

                            .. data:: autoconfig = 0

                            """

                            autoconfig = Enum.YLeaf(0, "autoconfig")



                        class Authentication(Entity):
                            """
                            Authentication
                            
                            .. attribute:: word
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5>`
                            
                            .. attribute:: text
                            
                            	Plain text authentication
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                ])
                                self.word = None
                                self.text = None

                                self.md5 = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_chain
                                
                                	Set key chain
                                	**type**\: str
                                
                                .. attribute:: key_string
                                
                                	Set key string
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "authentication"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString))])
                                    self._leafs = OrderedDict([
                                        ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ])
                                    self.key_chain = None

                                    self.key_string = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                                class KeyString(Entity):
                                    """
                                    Set key string
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: timeout
                                    
                                    	Set timeout
                                    	**type**\: int
                                    
                                    	**range:** 0..32767
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self.timeout = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                        class Ip(Entity):
                            """
                            Enable HSRP and set the virtual IP address
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	Make this IP address a secondary virtual IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.address = None
                                self.secondary = None
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                        class Preempt(Entity):
                            """
                            Overthrow lower priority Active routers
                            
                            .. attribute:: delay
                            
                            	Wait before preempting
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Preempt.Delay>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Preempt, self).__init__()

                                self.yang_name = "preempt"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Preempt.Delay))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.delay = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Preempt.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "preempt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Preempt, [], name, value)


                            class Delay(Entity):
                                """
                                Wait before preempting
                                
                                .. attribute:: minimum
                                
                                	Delay at least this long
                                	**type**\: int
                                
                                	**range:** 0..3600
                                
                                .. attribute:: reload
                                
                                	Delay after reload
                                	**type**\: int
                                
                                	**range:** 0..3600
                                
                                .. attribute:: sync
                                
                                	Wait for IP redundancy client
                                	**type**\: int
                                
                                	**range:** 0..3600
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Preempt.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "preempt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                        ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                    ])
                                    self.minimum = None
                                    self.reload = None
                                    self.sync = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                        class Redirect(Entity):
                            """
                            Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                            
                            .. attribute:: advertisement
                            
                            	Redirect advertisement messages
                            	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement>`
                            
                            .. attribute:: timers
                            
                            	Adjust redirect timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Timers>`
                            
                            .. attribute:: unknown
                            
                            	Redirect to non\-HSRP routers
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Timers))])
                                self._leafs = OrderedDict([
                                    ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                                ])
                                self.unknown = None

                                self.advertisement = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement()
                                self.advertisement.parent = self
                                self._children_name_map["advertisement"] = "advertisement"

                                self.timers = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                            class Advertisement(Entity):
                                """
                                Redirect advertisement messages
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                    self.yang_name = "advertisement"
                                    self.yang_parent_name = "redirect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                    self._leafs = OrderedDict()

                                    self.authentication = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._segment_path = lambda: "advertisement"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: md5
                                    
                                    	Use MD5 authentication
                                    	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "advertisement"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                        self._leafs = OrderedDict()

                                        self.md5 = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                        self.md5.parent = self
                                        self._children_name_map["md5"] = "md5"
                                        self._segment_path = lambda: "authentication"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                    class Md5(Entity):
                                        """
                                        Use MD5 authentication
                                        
                                        .. attribute:: key_chain
                                        
                                        	Set key chain
                                        	**type**\: str
                                        
                                        .. attribute:: key_string
                                        
                                        	Set key string
                                        	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                            self.yang_name = "md5"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                            self._leafs = OrderedDict([
                                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                            ])
                                            self.key_chain = None

                                            self.key_string = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                            self.key_string.parent = self
                                            self._children_name_map["key_string"] = "key-string"
                                            self._segment_path = lambda: "md5"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                        class KeyString(Entity):
                                            """
                                            Set key string
                                            
                                            .. attribute:: encrypt
                                            
                                            	
                                            	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                            
                                            .. attribute:: string
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: timeout
                                            
                                            	Set timeout
                                            	**type**\: int
                                            
                                            	**range:** 0..32767
                                            
                                            

                                            """

                                            _prefix = 'ios'
                                            _revision = '2018-05-22'

                                            def __init__(self):
                                                super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                                self.yang_name = "key-string"
                                                self.yang_parent_name = "md5"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                    ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                                ])
                                                self.encrypt = None
                                                self.string = None
                                                self.timeout = None
                                                self._segment_path = lambda: "key-string"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                            class Encrypt(Enum):
                                                """
                                                Encrypt (Enum Class)

                                                .. data:: Y_0 = 0

                                                .. data:: Y_7 = 1

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")

                                                Y_7 = Enum.YLeaf(1, "7")



                            class Timers(Entity):
                                """
                                Adjust redirect timers
                                
                                .. attribute:: advertisement
                                
                                	
                                	**type**\: int
                                
                                	**range:** 10..180
                                
                                .. attribute:: holddown
                                
                                	
                                	**type**\: int
                                
                                	**range:** 30..3600
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "redirect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                        ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                    ])
                                    self.advertisement = None
                                    self.holddown = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                        class Timers(Entity):
                            """
                            Hello and hold timers
                            
                            .. attribute:: hello_interval
                            
                            	
                            	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers.HelloInterval>`
                            
                            .. attribute:: hold_time
                            
                            	
                            	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers.HoldTime>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers.HoldTime))])
                                self._leafs = OrderedDict()

                                self.hello_interval = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers.HelloInterval()
                                self.hello_interval.parent = self
                                self._children_name_map["hello_interval"] = "hello-interval"

                                self.hold_time = Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers.HoldTime()
                                self.hold_time.parent = self
                                self._children_name_map["hold_time"] = "hold-time"
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers, [], name, value)


                            class HelloInterval(Entity):
                                """
                                
                                
                                .. attribute:: seconds
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: msec
                                
                                	Specify hello interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 15..999
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                    self.yang_name = "hello-interval"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.msec = None
                                    self._segment_path = lambda: "hello-interval"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                            class HoldTime(Entity):
                                """
                                
                                
                                .. attribute:: seconds
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: msec
                                
                                	Specify hold time in milliseconds
                                	**type**\: int
                                
                                	**range:** 50..3000
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                    self.yang_name = "hold-time"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.msec = None
                                    self._segment_path = lambda: "hold-time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                        class Track(Entity):
                            """
                            Priority tracking
                            
                            .. attribute:: number  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: decrement
                            
                            	Priority decrement
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: shutdown
                            
                            	Shutdown group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Track, self).__init__()

                                self.yang_name = "track"
                                self.yang_parent_name = "standby-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['number']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                    ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.number = None
                                self.decrement = None
                                self.shutdown = None
                                self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


                class AccessSession(Entity):
                    """
                    Access Session specific Interface Configuration Commands
                    
                    .. attribute:: closed
                    
                    	Enable closed access on port (disabled by default, i.e. open access)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: port_control
                    
                    	Set the port\-control value
                    	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.AccessSession.PortControl>`
                    
                    .. attribute:: control_direction
                    
                    	Set the control\-direction on the interface
                    	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.AccessSession.ControlDirection>`
                    
                    .. attribute:: host_mode
                    
                    	Set the Host mode for authentication on this interface
                    	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.AccessSession.HostMode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.AccessSession, self).__init__()

                        self.yang_name = "access-session"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.PortChannelSubinterface.PortChannel.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.PortChannelSubinterface.PortChannel.AccessSession.ControlDirection))])
                        self._leafs = OrderedDict([
                            ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                            ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.AccessSession.HostMode')])),
                        ])
                        self.closed = None
                        self.host_mode = None

                        self.port_control = Native.Interface.PortChannelSubinterface.PortChannel.AccessSession.PortControl()
                        self.port_control.parent = self
                        self._children_name_map["port_control"] = "port-control"

                        self.control_direction = Native.Interface.PortChannelSubinterface.PortChannel.AccessSession.ControlDirection()
                        self.control_direction.parent = self
                        self._children_name_map["control_direction"] = "control-direction"
                        self._segment_path = lambda: "access-session"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.AccessSession, [u'closed', u'host_mode'], name, value)

                    class HostMode(Enum):
                        """
                        HostMode (Enum Class)

                        Set the Host mode for authentication on this interface

                        .. data:: multi_auth = 0

                        .. data:: multi_domain = 1

                        .. data:: multi_host = 2

                        .. data:: single_host = 3

                        """

                        multi_auth = Enum.YLeaf(0, "multi-auth")

                        multi_domain = Enum.YLeaf(1, "multi-domain")

                        multi_host = Enum.YLeaf(2, "multi-host")

                        single_host = Enum.YLeaf(3, "single-host")



                    class PortControl(Entity):
                        """
                        Set the port\-control value
                        
                        .. attribute:: auto
                        
                        	PortState set to automatic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.AccessSession.PortControl, self).__init__()

                            self.yang_name = "port-control"
                            self.yang_parent_name = "access-session"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                            ])
                            self.auto = None
                            self._segment_path = lambda: "port-control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.AccessSession.PortControl, [u'auto'], name, value)


                    class ControlDirection(Entity):
                        """
                        Set the control\-direction on the interface
                        
                        .. attribute:: in_
                        
                        	Control inbound traffic only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.AccessSession.ControlDirection, self).__init__()

                            self.yang_name = "control-direction"
                            self.yang_parent_name = "access-session"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                            ])
                            self.in_ = None
                            self._segment_path = lambda: "control-direction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.AccessSession.ControlDirection, [u'in_'], name, value)


                class StormControl(Entity):
                    """
                    storm configuration
                    
                    .. attribute:: action
                    
                    	Action to take for storm..control;
                    	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Action>`
                    
                    .. attribute:: broadcast
                    
                    	Broadcast address storm control
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast>`
                    
                    .. attribute:: multicast
                    
                    	Multicast address storm control
                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast>`
                    
                    .. attribute:: unicast
                    
                    	Unicast address storm control
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl, self).__init__()

                        self.yang_name = "storm-control"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast))])
                        self._leafs = OrderedDict()

                        self.action = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Action()
                        self.action.parent = self
                        self._children_name_map["action"] = "action"

                        self.broadcast = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"

                        self.multicast = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast()
                        self.multicast.parent = self
                        self._children_name_map["multicast"] = "multicast"

                        self.unicast = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "storm-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl, [], name, value)


                    class Action(Entity):
                        """
                        Action to take for storm..control;
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\: Decimal64
                        
                        	**range:** 0..100
                        
                        .. attribute:: shutdown
                        
                        	Shutdown this interface if a storm occurs
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: trap
                        
                        	Send SNMP trap if a storm occurs
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Action, self).__init__()

                            self.yang_name = "action"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                            ])
                            self.level = None
                            self.shutdown = None
                            self.trap = None
                            self._segment_path = lambda: "action"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                    class Broadcast(Entity):
                        """
                        Broadcast address storm control
                        
                        .. attribute:: include
                        
                        	
                        	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Include>`
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("include", ("include", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level))])
                            self._leafs = OrderedDict()

                            self.include = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Include()
                            self.include.parent = self
                            self._children_name_map["include"] = "include"

                            self.level = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level()
                            self.level.parent = self
                            self._children_name_map["level"] = "level"
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast, [], name, value)


                        class Include(Entity):
                            """
                            
                            
                            .. attribute:: multicast
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Include, self).__init__()

                                self.yang_name = "include"
                                self.yang_parent_name = "broadcast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ])
                                self.multicast = None
                                self._segment_path = lambda: "include"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Include, [u'multicast'], name, value)


                        class Level(Entity):
                            """
                            Set storm suppression level on this interface
                            
                            .. attribute:: threshold
                            
                            	Broadcast address storm control
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Threshold>`
                            
                            .. attribute:: bps
                            
                            	Enter suppression level in bits per second
                            	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Bps>`
                            
                            .. attribute:: pps
                            
                            	Enter suppression level in packets per second
                            	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Pps>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level, self).__init__()

                                self.yang_name = "level"
                                self.yang_parent_name = "broadcast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Pps))])
                                self._leafs = OrderedDict()

                                self.threshold = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"

                                self.bps = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Bps()
                                self.bps.parent = self
                                self._children_name_map["bps"] = "bps"

                                self.pps = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Pps()
                                self.pps.parent = self
                                self._children_name_map["pps"] = "pps"
                                self._segment_path = lambda: "level"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level, [], name, value)


                            class Threshold(Entity):
                                """
                                Broadcast address storm control
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Bps(Entity):
                                """
                                Enter suppression level in bits per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Bps, self).__init__()

                                    self.yang_name = "bps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "bps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Pps(Entity):
                                """
                                Enter suppression level in packets per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Pps, self).__init__()

                                    self.yang_name = "pps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "pps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                    class Multicast(Entity):
                        """
                        Multicast address storm control
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast, self).__init__()

                            self.yang_name = "multicast"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level", ("level", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level))])
                            self._leafs = OrderedDict()

                            self.level = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level()
                            self.level.parent = self
                            self._children_name_map["level"] = "level"
                            self._segment_path = lambda: "multicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast, [], name, value)


                        class Level(Entity):
                            """
                            Set storm suppression level on this interface
                            
                            .. attribute:: threshold
                            
                            	Broadcast address storm control
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Threshold>`
                            
                            .. attribute:: bps
                            
                            	Enter suppression level in bits per second
                            	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Bps>`
                            
                            .. attribute:: pps
                            
                            	Enter suppression level in packets per second
                            	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Pps>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level, self).__init__()

                                self.yang_name = "level"
                                self.yang_parent_name = "multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Pps))])
                                self._leafs = OrderedDict()

                                self.threshold = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"

                                self.bps = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Bps()
                                self.bps.parent = self
                                self._children_name_map["bps"] = "bps"

                                self.pps = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Pps()
                                self.pps.parent = self
                                self._children_name_map["pps"] = "pps"
                                self._segment_path = lambda: "level"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level, [], name, value)


                            class Threshold(Entity):
                                """
                                Broadcast address storm control
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Bps(Entity):
                                """
                                Enter suppression level in bits per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Bps, self).__init__()

                                    self.yang_name = "bps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "bps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Pps(Entity):
                                """
                                Enter suppression level in packets per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Pps, self).__init__()

                                    self.yang_name = "pps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "pps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                    class Unicast(Entity):
                        """
                        Unicast address storm control
                        
                        .. attribute:: level
                        
                        	Set storm suppression level on this interface
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "storm-control"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level", ("level", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level))])
                            self._leafs = OrderedDict()

                            self.level = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level()
                            self.level.parent = self
                            self._children_name_map["level"] = "level"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast, [], name, value)


                        class Level(Entity):
                            """
                            Set storm suppression level on this interface
                            
                            .. attribute:: threshold
                            
                            	Broadcast address storm control
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Threshold>`
                            
                            .. attribute:: bps
                            
                            	Enter suppression level in bits per second
                            	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Bps>`
                            
                            .. attribute:: pps
                            
                            	Enter suppression level in packets per second
                            	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Pps>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level, self).__init__()

                                self.yang_name = "level"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Pps))])
                                self._leafs = OrderedDict()

                                self.threshold = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"

                                self.bps = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Bps()
                                self.bps.parent = self
                                self._children_name_map["bps"] = "bps"

                                self.pps = Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Pps()
                                self.pps.parent = self
                                self._children_name_map["pps"] = "pps"
                                self._segment_path = lambda: "level"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level, [], name, value)


                            class Threshold(Entity):
                                """
                                Broadcast address storm control
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold
                                	**type**\: Decimal64
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Bps(Entity):
                                """
                                Enter suppression level in bits per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Bps, self).__init__()

                                    self.yang_name = "bps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "bps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                            class Pps(Entity):
                                """
                                Enter suppression level in packets per second
                                
                                .. attribute:: rising_threshold
                                
                                	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                .. attribute:: falling_threshold
                                
                                	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                                	**type**\: str
                                
                                	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Pps, self).__init__()

                                    self.yang_name = "pps"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                        ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                    ])
                                    self.rising_threshold = None
                                    self.falling_threshold = None
                                    self._segment_path = lambda: "pps"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Trust(Entity):
                    """
                    Set trust value for the interface
                    
                    .. attribute:: device
                    
                    	trusted device class
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        trusted device class

                        .. data:: cisco_phone = 0

                        .. data:: cts = 1

                        .. data:: ip_camera = 2

                        .. data:: media_player = 3

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")

                        cts = Enum.YLeaf(1, "cts")

                        ip_camera = Enum.YLeaf(2, "ip-camera")

                        media_player = Enum.YLeaf(3, "media-player")



                class PriorityQueue(Entity):
                    """
                    Configure priority scheduling
                    
                    .. attribute:: cos_map
                    
                    	Configure cos\-map for a queue
                    	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.PriorityQueue.CosMap>`
                    
                    .. attribute:: out
                    
                    	egress priority queue
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.PriorityQueue, self).__init__()

                        self.yang_name = "priority-queue"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.PortChannelSubinterface.PortChannel.PriorityQueue.CosMap))])
                        self._leafs = OrderedDict([
                            ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ])
                        self.out = None

                        self.cos_map = Native.Interface.PortChannelSubinterface.PortChannel.PriorityQueue.CosMap()
                        self.cos_map.parent = self
                        self._children_name_map["cos_map"] = "cos-map"
                        self._segment_path = lambda: "priority-queue"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.PriorityQueue, [u'out'], name, value)


                    class CosMap(Entity):
                        """
                        Configure cos\-map for a queue
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: cos_values
                        
                        	
                        	**type**\: list of int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.PriorityQueue.CosMap, self).__init__()

                            self.yang_name = "cos-map"
                            self.yang_parent_name = "priority-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                            ])
                            self.id = None
                            self.cos_values = []
                            self._segment_path = lambda: "cos-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


                class RcvQueue(Entity):
                    """
                    Configure receive queue(s)
                    
                    .. attribute:: cos_map
                    
                    	Configure cos\-map for a queue threshold
                    	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.RcvQueue.CosMap>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.RcvQueue, self).__init__()

                        self.yang_name = "rcv-queue"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.PortChannelSubinterface.PortChannel.RcvQueue.CosMap))])
                        self._leafs = OrderedDict()

                        self.cos_map = YList(self)
                        self._segment_path = lambda: "rcv-queue"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.RcvQueue, [], name, value)


                    class CosMap(Entity):
                        """
                        Configure cos\-map for a queue threshold
                        
                        .. attribute:: queue_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: threshold_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8
                        
                        .. attribute:: cos_values
                        
                        	
                        	**type**\: list of int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.RcvQueue.CosMap, self).__init__()

                            self.yang_name = "cos-map"
                            self.yang_parent_name = "rcv-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['queue_id','threshold_id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                                ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                                ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                            ])
                            self.queue_id = None
                            self.threshold_id = None
                            self.cos_values = []
                            self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


                class Peer(Entity):
                    """
                    Peer parameters for point to point interfaces
                    
                    .. attribute:: default
                    
                    	Specify default parameters
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default", ("default", Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default))])
                        self._leafs = OrderedDict()

                        self.default = Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"
                        self._segment_path = lambda: "peer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Peer, [], name, value)


                    class Default(Entity):
                        """
                        Specify default parameters
                        
                        .. attribute:: ip
                        
                        	Specify default IP parameters
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default, [], name, value)


                        class Ip(Entity):
                            """
                            Specify default IP parameters
                            
                            .. attribute:: address
                            
                            	Specify default IP address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address))])
                                self._leafs = OrderedDict()

                                self.address = Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip, [], name, value)


                            class Address(Entity):
                                """
                                Specify default IP address
                                
                                .. attribute:: dhcp
                                
                                	Use DHCP proxy client mechanism to allocate a peer IP address
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: dhcp_pool
                                
                                	Use local DHCP pools to allocate a peer IP address
                                	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address.DhcpPool>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: pool
                                
                                	Use IP pool mechanism to allocate a peer IP address
                                	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address.Pool>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address.Pool))])
                                    self._leafs = OrderedDict([
                                        ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                    ])
                                    self.dhcp = None

                                    self.dhcp_pool = None
                                    self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                    self.pool = None
                                    self._children_name_map["pool"] = "pool"
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                                class DhcpPool(Entity):
                                    """
                                    Use local DHCP pools to allocate a peer IP address
                                    
                                    .. attribute:: pools
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                        self.yang_name = "dhcp-pool"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                        ])
                                        self.pools = None
                                        self._segment_path = lambda: "dhcp-pool"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                                class Pool(Entity):
                                    """
                                    Use IP pool mechanism to allocate a peer IP address
                                    
                                    .. attribute:: pools
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address.Pool, self).__init__()

                                        self.yang_name = "pool"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                        ])
                                        self.pools = None
                                        self._segment_path = lambda: "pool"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


                class PmPath(Entity):
                    """
                    Global pm\-path configuration
                    
                    .. attribute:: name
                    
                    	WORD Path name
                    	**type**\: str
                    
                    .. attribute:: interface_id
                    
                    	<1\-255> Specify the interface\-id value
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.PmPath, self).__init__()

                        self.yang_name = "pm-path"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                        ])
                        self.name = None
                        self.interface_id = None
                        self._segment_path = lambda: "pm-path"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.PmPath, [u'name', u'interface_id'], name, value)


                class CarrierDelay(Entity):
                    """
                    Specify delay for interface transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    .. attribute:: down
                    
                    	Carrier Down Transitions
                    	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay.Down>`
                    
                    .. attribute:: up
                    
                    	Carrier Up Transitions
                    	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay.Up>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay, self).__init__()

                        self.yang_name = "carrier-delay"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("down", ("down", Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay.Down)), ("up", ("up", Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay.Up))])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None

                        self.down = Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay.Down()
                        self.down.parent = self
                        self._children_name_map["down"] = "down"

                        self.up = Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay.Up()
                        self.up.parent = self
                        self._children_name_map["up"] = "up"
                        self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay, ['seconds', 'msec'], name, value)


                    class Down(Entity):
                        """
                        Carrier Down Transitions
                        
                        .. attribute:: seconds
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..60
                        
                        .. attribute:: msec
                        
                        	delay specified in milliseconds
                        	**type**\: int
                        
                        	**range:** 0..1000
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay.Down, self).__init__()

                            self.yang_name = "down"
                            self.yang_parent_name = "carrier-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                            ])
                            self.seconds = None
                            self.msec = None
                            self._segment_path = lambda: "down"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                    class Up(Entity):
                        """
                        Carrier Up Transitions
                        
                        .. attribute:: seconds
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..60
                        
                        .. attribute:: msec
                        
                        	delay specified in milliseconds
                        	**type**\: int
                        
                        	**range:** 0..1000
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay.Up, self).__init__()

                            self.yang_name = "up"
                            self.yang_parent_name = "carrier-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                            ])
                            self.seconds = None
                            self.msec = None
                            self._segment_path = lambda: "up"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.CarrierDelay.Up, ['seconds', 'msec'], name, value)


                class ChannelGroup(Entity):
                    """
                    Add this interface to an Etherchannel group
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..512
                    
                    .. attribute:: mode
                    
                    	Etherchannel Mode of the interface
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.ChannelGroup.Mode>`
                    
                    .. attribute:: non_silent
                    
                    	Start negotiation only after data packets received
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link
                    
                    	Assign a link identifier used for load\-balancing
                    	**type**\: int
                    
                    	**range:** 1..4
                    
                    .. attribute:: auto
                    
                    	LACP auto
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.ChannelGroup, self).__init__()

                        self.yang_name = "channel-group"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.ChannelGroup.Mode')])),
                            ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                            ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.number = None
                        self.mode = None
                        self.non_silent = None
                        self.link = None
                        self.auto = None
                        self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        Etherchannel Mode of the interface

                        .. data:: active = 0

                        .. data:: auto = 1

                        .. data:: desirable = 2

                        .. data:: on = 3

                        .. data:: passive = 4

                        """

                        active = Enum.YLeaf(0, "active")

                        auto = Enum.YLeaf(1, "auto")

                        desirable = Enum.YLeaf(2, "desirable")

                        on = Enum.YLeaf(3, "on")

                        passive = Enum.YLeaf(4, "passive")



                class Ethernet(Entity):
                    """
                    Ethernet interface parameters
                    
                    .. attribute:: oam
                    
                    	To enable Ethernet Link OAM
                    	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dot1ad
                    
                    	ethernet dot1ad port
                    	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Dot1ad>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Dot1ad))])
                        self._leafs = OrderedDict()

                        self.oam = None
                        self._children_name_map["oam"] = "oam"

                        self.dot1ad = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Dot1ad()
                        self.dot1ad.parent = self
                        self._children_name_map["dot1ad"] = "dot1ad"
                        self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet, [], name, value)


                    class Oam(Entity):
                        """
                        To enable Ethernet Link OAM
                        
                        .. attribute:: link_monitor
                        
                        	Ethernet OAM Link Monitor
                        	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor>`
                        
                        .. attribute:: max_rate
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        .. attribute:: min_rate
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        .. attribute:: mode
                        
                        	
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.Mode>`
                        
                        .. attribute:: remote_failure
                        
                        	Ethernet OAM remote failure indication
                        	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure>`
                        
                        .. attribute:: remote_loopback
                        
                        	Ethernet OAM Remote Loopback
                        	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteLoopback>`
                        
                        .. attribute:: timeout
                        
                        	
                        	**type**\: int
                        
                        	**range:** 2..30
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam, self).__init__()

                            self.yang_name = "oam"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteLoopback))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                                ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.Mode')])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.max_rate = None
                            self.min_rate = None
                            self.mode = None
                            self.timeout = None

                            self.link_monitor = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor()
                            self.link_monitor.parent = self
                            self._children_name_map["link_monitor"] = "link-monitor"

                            self.remote_failure = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure()
                            self.remote_failure.parent = self
                            self._children_name_map["remote_failure"] = "remote-failure"

                            self.remote_loopback = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteLoopback()
                            self.remote_loopback.parent = self
                            self._children_name_map["remote_loopback"] = "remote-loopback"
                            self._segment_path = lambda: "oam"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                        class Mode(Enum):
                            """
                            Mode (Enum Class)

                            .. data:: active = 0

                            .. data:: passive = 1

                            """

                            active = Enum.YLeaf(0, "active")

                            passive = Enum.YLeaf(1, "passive")



                        class LinkMonitor(Entity):
                            """
                            Ethernet OAM Link Monitor
                            
                            .. attribute:: frame
                            
                            	Errored frames in a period measured by time
                            	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame>`
                            
                            .. attribute:: frame_period
                            
                            	Errored frames in a period measured by number of frames
                            	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod>`
                            
                            .. attribute:: frame_seconds
                            
                            	Errored frame seconds in a period
                            	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                            
                            .. attribute:: high_threshold
                            
                            	Additional high threshold configuration
                            	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold>`
                            
                            .. attribute:: on
                            
                            	Enable link monitoring on the interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: receive_crc
                            
                            	Received frames with CRC errors in a period
                            	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                            
                            .. attribute:: supported
                            
                            	Support link monitoring on the interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: symbol_period
                            
                            	Errored symbols in a period
                            	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor, self).__init__()

                                self.yang_name = "link-monitor"
                                self.yang_parent_name = "oam"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                                self._leafs = OrderedDict([
                                    ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                    ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ])
                                self.on = None
                                self.supported = None

                                self.frame = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame()
                                self.frame.parent = self
                                self._children_name_map["frame"] = "frame"

                                self.frame_period = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod()
                                self.frame_period.parent = self
                                self._children_name_map["frame_period"] = "frame-period"

                                self.frame_seconds = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds()
                                self.frame_seconds.parent = self
                                self._children_name_map["frame_seconds"] = "frame-seconds"

                                self.high_threshold = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold()
                                self.high_threshold.parent = self
                                self._children_name_map["high_threshold"] = "high-threshold"

                                self.receive_crc = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                                self.receive_crc.parent = self
                                self._children_name_map["receive_crc"] = "receive-crc"

                                self.symbol_period = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                                self.symbol_period.parent = self
                                self._children_name_map["symbol_period"] = "symbol-period"
                                self._segment_path = lambda: "link-monitor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                            class Frame(Entity):
                                """
                                Errored frames in a period measured by time
                                
                                .. attribute:: threshold
                                
                                	Errored frame threshold
                                	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                                
                                .. attribute:: window
                                
                                	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                                	**type**\: int
                                
                                	**range:** 10..600
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                    self.yang_name = "frame"
                                    self.yang_parent_name = "link-monitor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                    self._leafs = OrderedDict([
                                        ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                    ])
                                    self.window = None

                                    self.threshold = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                    self.threshold.parent = self
                                    self._children_name_map["threshold"] = "threshold"
                                    self._segment_path = lambda: "frame"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                                class Threshold(Entity):
                                    """
                                    Errored frame threshold
                                    
                                    .. attribute:: high
                                    
                                    	High Threshold
                                    	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                    
                                    .. attribute:: low
                                    
                                    	Set the low errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                        self.yang_name = "threshold"
                                        self.yang_parent_name = "frame"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("high", ("high", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                        self._leafs = OrderedDict([
                                            ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                        ])
                                        self.low = None

                                        self.high = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                        self.high.parent = self
                                        self._children_name_map["high"] = "high"
                                        self._segment_path = lambda: "threshold"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                    class High(Entity):
                                        """
                                        High Threshold
                                        
                                        .. attribute:: thresh
                                        
                                        	Set the high errored frame threshold in number of frames
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: none
                                        
                                        	Disable high threshold
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                            self.yang_name = "high"
                                            self.yang_parent_name = "threshold"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                            ])
                                            self.thresh = None
                                            self.none = None
                                            self._segment_path = lambda: "high"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                            class FramePeriod(Entity):
                                """
                                Errored frames in a period measured by number of frames
                                
                                .. attribute:: threshold
                                
                                	Errored frame\-period threshold
                                	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                                
                                .. attribute:: window
                                
                                	Set window size in number of 10000 frames
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                    self.yang_name = "frame-period"
                                    self.yang_parent_name = "link-monitor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                    self._leafs = OrderedDict([
                                        ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                    ])
                                    self.window = None

                                    self.threshold = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                    self.threshold.parent = self
                                    self._children_name_map["threshold"] = "threshold"
                                    self._segment_path = lambda: "frame-period"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                                class Threshold(Entity):
                                    """
                                    Errored frame\-period threshold
                                    
                                    .. attribute:: high
                                    
                                    	High Threshold
                                    	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                    
                                    .. attribute:: low
                                    
                                    	Set the low errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                        self.yang_name = "threshold"
                                        self.yang_parent_name = "frame-period"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("high", ("high", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                        self._leafs = OrderedDict([
                                            ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                        ])
                                        self.low = None

                                        self.high = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                        self.high.parent = self
                                        self._children_name_map["high"] = "high"
                                        self._segment_path = lambda: "threshold"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                    class High(Entity):
                                        """
                                        High Threshold
                                        
                                        .. attribute:: f_thresh
                                        
                                        	Set the high errored frame\-period threshold in number of frames
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: none
                                        
                                        	Disable high threshold
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                            self.yang_name = "high"
                                            self.yang_parent_name = "threshold"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                            ])
                                            self.f_thresh = None
                                            self.none = None
                                            self._segment_path = lambda: "high"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                            class FrameSeconds(Entity):
                                """
                                Errored frame seconds in a period
                                
                                .. attribute:: threshold
                                
                                	Errored frame\-seconds threshold
                                	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                                
                                .. attribute:: window
                                
                                	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                                	**type**\: int
                                
                                	**range:** 100..9000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                    self.yang_name = "frame-seconds"
                                    self.yang_parent_name = "link-monitor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                    self._leafs = OrderedDict([
                                        ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                    ])
                                    self.window = None

                                    self.threshold = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                    self.threshold.parent = self
                                    self._children_name_map["threshold"] = "threshold"
                                    self._segment_path = lambda: "frame-seconds"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                                class Threshold(Entity):
                                    """
                                    Errored frame\-seconds threshold
                                    
                                    .. attribute:: high
                                    
                                    	High Threshold
                                    	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                    
                                    .. attribute:: low
                                    
                                    	Set the low errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                        self.yang_name = "threshold"
                                        self.yang_parent_name = "frame-seconds"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("high", ("high", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                        self._leafs = OrderedDict([
                                            ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                        ])
                                        self.low = None

                                        self.high = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                        self.high.parent = self
                                        self._children_name_map["high"] = "high"
                                        self._segment_path = lambda: "threshold"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                    class High(Entity):
                                        """
                                        High Threshold
                                        
                                        .. attribute:: e_thresh
                                        
                                        	Set the high errored frame\-seconds threshold in number of seconds
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        .. attribute:: none
                                        
                                        	Disable high threshold
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                            self.yang_name = "high"
                                            self.yang_parent_name = "threshold"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                            ])
                                            self.e_thresh = None
                                            self.none = None
                                            self._segment_path = lambda: "high"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                            class HighThreshold(Entity):
                                """
                                Additional high threshold configuration
                                
                                .. attribute:: action
                                
                                	Specifiy an action when the high threshold is crossed
                                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                    self.yang_name = "high-threshold"
                                    self.yang_parent_name = "link-monitor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                    self._leafs = OrderedDict()

                                    self.action = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                    self.action.parent = self
                                    self._children_name_map["action"] = "action"
                                    self._segment_path = lambda: "high-threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                                class Action(Entity):
                                    """
                                    Specifiy an action when the high threshold is crossed
                                    
                                    .. attribute:: error_disable_interface
                                    
                                    	Error\-disable the interface
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                        self.yang_name = "action"
                                        self.yang_parent_name = "high-threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                        ])
                                        self.error_disable_interface = None
                                        self._segment_path = lambda: "action"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                            class ReceiveCrc(Entity):
                                """
                                Received frames with CRC errors in a period
                                
                                .. attribute:: threshold
                                
                                	Errored frame\-seconds threshold
                                	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                                
                                .. attribute:: window
                                
                                	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                                	**type**\: int
                                
                                	**range:** 10..1800
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                    self.yang_name = "receive-crc"
                                    self.yang_parent_name = "link-monitor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                    self._leafs = OrderedDict([
                                        ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                    ])
                                    self.window = None

                                    self.threshold = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                    self.threshold.parent = self
                                    self._children_name_map["threshold"] = "threshold"
                                    self._segment_path = lambda: "receive-crc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                                class Threshold(Entity):
                                    """
                                    Errored frame\-seconds threshold
                                    
                                    .. attribute:: high
                                    
                                    	High Threshold
                                    	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                    
                                    .. attribute:: low
                                    
                                    	Set the low received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                        self.yang_name = "threshold"
                                        self.yang_parent_name = "receive-crc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("high", ("high", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                        self._leafs = OrderedDict([
                                            ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                        ])
                                        self.low = None

                                        self.high = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                        self.high.parent = self
                                        self._children_name_map["high"] = "high"
                                        self._segment_path = lambda: "threshold"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                    class High(Entity):
                                        """
                                        High Threshold
                                        
                                        .. attribute:: crc_thresh
                                        
                                        	Set the high received crc error threshold in number of frames
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: none
                                        
                                        	Disable high threshold
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                            self.yang_name = "high"
                                            self.yang_parent_name = "threshold"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                            ])
                                            self.crc_thresh = None
                                            self.none = None
                                            self._segment_path = lambda: "high"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                            class SymbolPeriod(Entity):
                                """
                                Errored symbols in a period
                                
                                .. attribute:: threshold
                                
                                	Error symbol\-period threshold
                                	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                                
                                .. attribute:: window
                                
                                	Set window size in number of 1048576 symbols
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                    self.yang_name = "symbol-period"
                                    self.yang_parent_name = "link-monitor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                    self._leafs = OrderedDict([
                                        ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                    ])
                                    self.window = None

                                    self.threshold = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                    self.threshold.parent = self
                                    self._children_name_map["threshold"] = "threshold"
                                    self._segment_path = lambda: "symbol-period"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                                class Threshold(Entity):
                                    """
                                    Error symbol\-period threshold
                                    
                                    .. attribute:: high
                                    
                                    	High Threshold
                                    	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                    
                                    .. attribute:: low
                                    
                                    	Set the low error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                        self.yang_name = "threshold"
                                        self.yang_parent_name = "symbol-period"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("high", ("high", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                        self._leafs = OrderedDict([
                                            ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                        ])
                                        self.low = None

                                        self.high = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                        self.high.parent = self
                                        self._children_name_map["high"] = "high"
                                        self._segment_path = lambda: "threshold"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                    class High(Entity):
                                        """
                                        High Threshold
                                        
                                        .. attribute:: err_thresh
                                        
                                        	Set the high error symbol\-period threshold in number of symbols
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: none
                                        
                                        	Disable high threshold
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                            self.yang_name = "high"
                                            self.yang_parent_name = "threshold"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                            ])
                                            self.err_thresh = None
                                            self.none = None
                                            self._segment_path = lambda: "high"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                        class RemoteFailure(Entity):
                            """
                            Ethernet OAM remote failure indication
                            
                            .. attribute:: critical_event
                            
                            	Critical event
                            	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                            
                            .. attribute:: dying_gasp
                            
                            	Dying gasp
                            	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp>`
                            
                            .. attribute:: link_fault
                            
                            	Link fault
                            	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure, self).__init__()

                                self.yang_name = "remote-failure"
                                self.yang_parent_name = "oam"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault))])
                                self._leafs = OrderedDict()

                                self.critical_event = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent()
                                self.critical_event.parent = self
                                self._children_name_map["critical_event"] = "critical-event"

                                self.dying_gasp = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp()
                                self.dying_gasp.parent = self
                                self._children_name_map["dying_gasp"] = "dying-gasp"

                                self.link_fault = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault()
                                self.link_fault.parent = self
                                self._children_name_map["link_fault"] = "link-fault"
                                self._segment_path = lambda: "remote-failure"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure, [], name, value)


                            class CriticalEvent(Entity):
                                """
                                Critical event
                                
                                .. attribute:: action
                                
                                	Specifiy an action when a remote failure is detected
                                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                    self.yang_name = "critical-event"
                                    self.yang_parent_name = "remote-failure"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                    self._leafs = OrderedDict()

                                    self.action = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                    self.action.parent = self
                                    self._children_name_map["action"] = "action"
                                    self._segment_path = lambda: "critical-event"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                                class Action(Entity):
                                    """
                                    Specifiy an action when a remote failure is detected
                                    
                                    .. attribute:: error_disable_interface
                                    
                                    	Error\-disable the interface
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                        self.yang_name = "action"
                                        self.yang_parent_name = "critical-event"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                        ])
                                        self.error_disable_interface = None
                                        self._segment_path = lambda: "action"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                            class DyingGasp(Entity):
                                """
                                Dying gasp
                                
                                .. attribute:: action
                                
                                	Specifiy an action when a remote failure is detected
                                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                    self.yang_name = "dying-gasp"
                                    self.yang_parent_name = "remote-failure"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                    self._leafs = OrderedDict()

                                    self.action = None
                                    self._children_name_map["action"] = "action"
                                    self._segment_path = lambda: "dying-gasp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                                class Action(Entity):
                                    """
                                    Specifiy an action when a remote failure is detected
                                    
                                    .. attribute:: error_disable_interface
                                    
                                    	Error\-disable the interface
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                        self.yang_name = "action"
                                        self.yang_parent_name = "dying-gasp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                        ])
                                        self.error_disable_interface = None
                                        self._segment_path = lambda: "action"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                            class LinkFault(Entity):
                                """
                                Link fault
                                
                                .. attribute:: action
                                
                                	Specifiy an action when a remote failure is detected
                                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                    self.yang_name = "link-fault"
                                    self.yang_parent_name = "remote-failure"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                    self._leafs = OrderedDict()

                                    self.action = None
                                    self._children_name_map["action"] = "action"
                                    self._segment_path = lambda: "link-fault"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                                class Action(Entity):
                                    """
                                    Specifiy an action when a remote failure is detected
                                    
                                    .. attribute:: error_disable_interface
                                    
                                    	Error\-disable the interface
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                        self.yang_name = "action"
                                        self.yang_parent_name = "link-fault"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                        ])
                                        self.error_disable_interface = None
                                        self._segment_path = lambda: "action"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                        class RemoteLoopback(Entity):
                            """
                            Ethernet OAM Remote Loopback
                            
                            .. attribute:: supported
                            
                            	Support remote loopback functionality
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timeout
                            
                            	Set timeout value in number of seconds
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteLoopback, self).__init__()

                                self.yang_name = "remote-loopback"
                                self.yang_parent_name = "oam"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                    ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                                ])
                                self.supported = None
                                self.timeout = None
                                self._segment_path = lambda: "remote-loopback"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                    class Dot1ad(Entity):
                        """
                        ethernet dot1ad port
                        
                        .. attribute:: nni
                        
                        	dot1ad nni port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: uni
                        
                        	dot1ad uni
                        	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Dot1ad.Uni>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Dot1ad, self).__init__()

                            self.yang_name = "dot1ad"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Dot1ad.Uni))])
                            self._leafs = OrderedDict([
                                ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                            ])
                            self.nni = None

                            self.uni = Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Dot1ad.Uni()
                            self.uni.parent = self
                            self._children_name_map["uni"] = "uni"
                            self._segment_path = lambda: "dot1ad"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Dot1ad, ['nni'], name, value)


                        class Uni(Entity):
                            """
                            dot1ad uni
                            
                            .. attribute:: c_port
                            
                            	dot1ad uni customer bridge port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: s_port
                            
                            	dot1ad uni s bridge port
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Dot1ad.Uni, self).__init__()

                                self.yang_name = "uni"
                                self.yang_parent_name = "dot1ad"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                    ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                                ])
                                self.c_port = None
                                self.s_port = None
                                self._segment_path = lambda: "uni"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


                class Eapol(Entity):
                    """
                    eapol
                    
                    .. attribute:: destination_address
                    
                    	Configure destination MAC address
                    	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Eapol.DestinationAddress>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Eapol, self).__init__()

                        self.yang_name = "eapol"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.PortChannelSubinterface.PortChannel.Eapol.DestinationAddress))])
                        self._leafs = OrderedDict()

                        self.destination_address = Native.Interface.PortChannelSubinterface.PortChannel.Eapol.DestinationAddress()
                        self.destination_address.parent = self
                        self._children_name_map["destination_address"] = "destination-address"
                        self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Eapol, [], name, value)


                    class DestinationAddress(Entity):
                        """
                        Configure destination MAC address
                        
                        .. attribute:: broadcast_address
                        
                        	Configure broadcast MAC address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Eapol.DestinationAddress, self).__init__()

                            self.yang_name = "destination-address"
                            self.yang_parent_name = "eapol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                            ])
                            self.broadcast_address = None
                            self._segment_path = lambda: "destination-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Eapol.DestinationAddress, ['broadcast_address'], name, value)


                class Synchronous(Entity):
                    """
                    Synchronous
                    
                    .. attribute:: mode
                    
                    	Mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Synchronous, self).__init__()

                        self.yang_name = "synchronous"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                        ])
                        self.mode = None
                        self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Synchronous, ['mode'], name, value)


                class Speed(Entity):
                    """
                    Configure speed operation
                    
                    .. attribute:: auto
                    
                    	Enable AUTO speed configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: value_10
                    
                    	10 Mbps operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: value_100
                    
                    	100 Mbps operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: value_1000
                    
                    	1000 Mbps operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: value_10000
                    
                    	10000 Mbps operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nonegotiate
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Speed, self).__init__()

                        self.yang_name = "speed"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                            ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                            ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                            ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                            ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                            ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                        ])
                        self.auto = None
                        self.value_10 = None
                        self.value_100 = None
                        self.value_1000 = None
                        self.value_10000 = None
                        self.nonegotiate = None
                        self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


                class Negotiation(Entity):
                    """
                    Select autonegotiation mode
                    
                    .. attribute:: auto
                    
                    	Enable link autonegotiation
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Negotiation, self).__init__()

                        self.yang_name = "negotiation"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Negotiation, ['auto'], name, value)


                class Plim(Entity):
                    """
                    Configure features on the PLIM
                    
                    .. attribute:: ethernet
                    
                    	Configure features on the ethernet interface
                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet>`
                    
                    .. attribute:: qos
                    
                    	QoS on the PLIM
                    	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Plim, self).__init__()

                        self.yang_name = "plim"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet)), ("qos", ("qos", Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos))])
                        self._leafs = OrderedDict()

                        self.ethernet = Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet()
                        self.ethernet.parent = self
                        self._children_name_map["ethernet"] = "ethernet"

                        self.qos = Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos()
                        self.qos.parent = self
                        self._children_name_map["qos"] = "qos"
                        self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Plim, [], name, value)


                    class Ethernet(Entity):
                        """
                        Configure features on the ethernet interface
                        
                        .. attribute:: vlan
                        
                        	vlan specific features
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet, self).__init__()

                            self.yang_name = "ethernet"
                            self.yang_parent_name = "plim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "ethernet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specific features
                            
                            .. attribute:: filter
                            
                            	Configure VLAN filtering
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet.Vlan.Filter>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet.Vlan.Filter))])
                                self._leafs = OrderedDict()

                                self.filter = Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet.Vlan.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet.Vlan, [], name, value)


                            class Filter(Entity):
                                """
                                Configure VLAN filtering
                                
                                .. attribute:: disable
                                
                                	Configure the interface to accept all VLAN traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet.Vlan.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                    class Qos(Entity):
                        """
                        QoS on the PLIM
                        
                        .. attribute:: input
                        
                        	Configure PLIM QoS at the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos, self).__init__()

                            self.yang_name = "qos"
                            self.yang_parent_name = "plim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"
                            self._segment_path = lambda: "qos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos, [], name, value)


                        class Input(Entity):
                            """
                            Configure PLIM QoS at the input of an interface
                            
                            .. attribute:: queue
                            
                            	Queue number
                            	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "qos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue))])
                                self._leafs = OrderedDict()

                                self.queue = Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue()
                                self.queue.parent = self
                                self._children_name_map["queue"] = "queue"
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input, [], name, value)


                            class Queue(Entity):
                                """
                                Queue number
                                
                                .. attribute:: zero
                                
                                	Low priority queue
                                	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.Zero>`
                                
                                .. attribute:: strict_priority
                                
                                	High priority queue
                                	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.StrictPriority>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue, self).__init__()

                                    self.yang_name = "queue"
                                    self.yang_parent_name = "input"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.StrictPriority))])
                                    self._leafs = OrderedDict()

                                    self.zero = Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.Zero()
                                    self.zero.parent = self
                                    self._children_name_map["zero"] = "zero"

                                    self.strict_priority = Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.StrictPriority()
                                    self.strict_priority.parent = self
                                    self._children_name_map["strict_priority"] = "strict-priority"
                                    self._segment_path = lambda: "queue"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue, [], name, value)


                                class Zero(Entity):
                                    """
                                    Low priority queue
                                    
                                    .. attribute:: pause
                                    
                                    	Pause Frame generation and threshold
                                    	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.Zero.Pause>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.Zero, self).__init__()

                                        self.yang_name = "zero"
                                        self.yang_parent_name = "queue"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.Zero.Pause))])
                                        self._leafs = OrderedDict()

                                        self.pause = Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.Zero.Pause()
                                        self.pause.parent = self
                                        self._children_name_map["pause"] = "pause"
                                        self._segment_path = lambda: "zero"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.Zero, [], name, value)


                                    class Pause(Entity):
                                        """
                                        Pause Frame generation and threshold
                                        
                                        .. attribute:: enable
                                        
                                        	Enable pause\-frame generation
                                        	**type**\: bool
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold as a percent of queue limit for pause frame generation
                                        	**type**\: int
                                        
                                        	**range:** 0..99
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                            self.yang_name = "pause"
                                            self.yang_parent_name = "zero"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ])
                                            self.enable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "pause"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                                class StrictPriority(Entity):
                                    """
                                    High priority queue
                                    
                                    .. attribute:: pause
                                    
                                    	Pause Frame generation and threshold
                                    	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                        self.yang_name = "strict-priority"
                                        self.yang_parent_name = "queue"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                        self._leafs = OrderedDict()

                                        self.pause = Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                        self.pause.parent = self
                                        self._children_name_map["pause"] = "pause"
                                        self._segment_path = lambda: "strict-priority"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                    class Pause(Entity):
                                        """
                                        Pause Frame generation and threshold
                                        
                                        .. attribute:: enable
                                        
                                        	Enable pause\-frame generation
                                        	**type**\: bool
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold as a percent of queue limit for pause frame generation
                                        	**type**\: int
                                        
                                        	**range:** 0..99
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                            self.yang_name = "pause"
                                            self.yang_parent_name = "strict-priority"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ])
                                            self.enable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "pause"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


                class Pppoe(Entity):
                    """
                    pppoe interface subcommands
                    
                    .. attribute:: enable
                    
                    	Enable pppoe
                    	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Pppoe.Enable>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: max_sessions
                    
                    	Maximum PPPOE sessions
                    	**type**\: int
                    
                    	**range:** 1..4085
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Pppoe, self).__init__()

                        self.yang_name = "pppoe"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.PortChannelSubinterface.PortChannel.Pppoe.Enable))])
                        self._leafs = OrderedDict([
                            ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                        ])
                        self.max_sessions = None

                        self.enable = None
                        self._children_name_map["enable"] = "enable"
                        self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Pppoe, ['max_sessions'], name, value)


                    class Enable(Entity):
                        """
                        Enable pppoe
                        
                        .. attribute:: group
                        
                        	attach a BBA group
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Pppoe.Enable, self).__init__()

                            self.yang_name = "enable"
                            self.yang_parent_name = "pppoe"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                            ])
                            self.group = None
                            self._segment_path = lambda: "enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Pppoe.Enable, ['group'], name, value)

                        class Group(Enum):
                            """
                            Group (Enum Class)

                            attach a BBA group

                            .. data:: global_ = 0

                            """

                            global_ = Enum.YLeaf(0, "global")



                class Service(Entity):
                    """
                    Configure Ether Service
                    
                    .. attribute:: instance
                    
                    	Configure Ether Service Instance
                    	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service, self).__init__()

                        self.yang_name = "service"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance))])
                        self._leafs = OrderedDict()

                        self.instance = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service, [], name, value)


                    class Instance(Entity):
                        """
                        Configure Ether Service Instance
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: trunk
                        
                        	Trunk Service Instance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: gigabitethernet
                        
                        	Configure an GigabitEthernet Instance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ethernet
                        
                        	Configure an Ethernet Instance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ethernet_evc_name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: description
                        
                        	Service instance specific description
                        	**type**\: str
                        
                        	**length:** 0..240
                        
                        .. attribute:: evc_name
                        
                        	
                        	**type**\: str
                        
                        	**length:** 1..100
                        
                        .. attribute:: encapsulation
                        
                        	Configure ethernet frame match criteria
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation>`
                        
                        .. attribute:: ip
                        
                        	Interface Internet Protocol config commands
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip>`
                        
                        .. attribute:: ipv6
                        
                        	IPv6 interface subcommands
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ipv6>`
                        
                        .. attribute:: rewrite
                        
                        	Configure ethernet rewrite criteria
                        	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite>`
                        
                        .. attribute:: group
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: errdisable
                        
                        	Configure error disable
                        	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable>`
                        
                        .. attribute:: ethernet_container
                        
                        	
                        	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer>`
                        
                        .. attribute:: snmp
                        
                        	Modify SNMP service instance parameters
                        	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp>`
                        
                        .. attribute:: bridge_domain
                        
                        	Bridge\-domain
                        	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.BridgeDomain>`
                        
                        .. attribute:: mac
                        
                        	Commands for MAC Address\-based features
                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac>`
                        
                        .. attribute:: service_policy
                        
                        	Attach a policy\-map to an EFP
                        	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy>`
                        
                        .. attribute:: shutdown
                        
                        	Take the Service Instance out of Service
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cfm
                        
                        	Ethernet CFM EFP subcommands
                        	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm>`
                        
                        .. attribute:: l2protocol
                        
                        	Configure l2 control protocol processing
                        	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance, self).__init__()

                            self.yang_name = "instance"
                            self.yang_parent_name = "service"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                                ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                                ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                                ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                                ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.id = None
                            self.trunk = None
                            self.gigabitethernet = None
                            self.ethernet = None
                            self.ethernet_evc_name = None
                            self.description = None
                            self.evc_name = None
                            self.group = None
                            self.shutdown = None

                            self.encapsulation = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.ip = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"

                            self.ipv6 = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.rewrite = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite()
                            self.rewrite.parent = self
                            self._children_name_map["rewrite"] = "rewrite"

                            self.errdisable = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable()
                            self.errdisable.parent = self
                            self._children_name_map["errdisable"] = "errdisable"

                            self.ethernet_container = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer()
                            self.ethernet_container.parent = self
                            self._children_name_map["ethernet_container"] = "ethernet-container"

                            self.snmp = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp()
                            self.snmp.parent = self
                            self._children_name_map["snmp"] = "snmp"

                            self.bridge_domain = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.BridgeDomain()
                            self.bridge_domain.parent = self
                            self._children_name_map["bridge_domain"] = "bridge-domain"

                            self.mac = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac()
                            self.mac.parent = self
                            self._children_name_map["mac"] = "mac"

                            self.service_policy = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy()
                            self.service_policy.parent = self
                            self._children_name_map["service_policy"] = "service-policy"

                            self.cfm = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm()
                            self.cfm.parent = self
                            self._children_name_map["cfm"] = "cfm"

                            self.l2protocol = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol()
                            self.l2protocol.parent = self
                            self._children_name_map["l2protocol"] = "l2protocol"
                            self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure ethernet frame match criteria
                            
                            .. attribute:: default
                            
                            	catch\-all unconfigured encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q>`
                            
                            .. attribute:: priority_tagged
                            
                            	Priority tagged EFP
                            	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.PriorityTagged>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: untagged
                            
                            	Untagged encapsulation
                            	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Untagged>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Untagged))])
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ])
                                self.default = None

                                self.dot1ad = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"

                                self.priority_tagged = None
                                self._children_name_map["priority_tagged"] = "priority-tagged"

                                self.untagged = None
                                self._children_name_map["untagged"] = "untagged"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation, ['default'], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: id
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: list of int
                                
                                			**range:** 1..4094
                                
                                		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                                
                                		**type**\: list of str
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: union of the below types:
                                
                                		**type**\: list of int
                                
                                			**range:** 1..4094
                                
                                		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                                
                                		**type**\: list of str
                                
                                .. attribute:: cos2
                                
                                	
                                	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                                
                                .. attribute:: etype
                                
                                	payload ethertype after Vlan Field
                                	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Etype>`
                                
                                .. attribute:: exact
                                
                                	payload Ethertype does not include 802.1q/802.1ad Tags
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                        ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                        ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ])
                                    self.id = []
                                    self.cos = []
                                    self.dot1q = []
                                    self.etype = []
                                    self.exact = None

                                    self.cos2 = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                    self.cos2.parent = self
                                    self._children_name_map["cos2"] = "cos2"
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                                class Dot1q(Enum):
                                    """
                                    Dot1q (Enum Class)

                                    Second tag (dot1q)

                                    .. data:: any = 0

                                    """

                                    any = Enum.YLeaf(0, "any")


                                class Etype(Enum):
                                    """
                                    Etype (Enum Class)

                                    payload ethertype after Vlan Field

                                    .. data:: ipv4 = 0

                                    .. data:: ipv6 = 1

                                    .. data:: pppoe_all = 2

                                    .. data:: pppoe_discovery = 3

                                    .. data:: pppoe_session = 4

                                    """

                                    ipv4 = Enum.YLeaf(0, "ipv4")

                                    ipv6 = Enum.YLeaf(1, "ipv6")

                                    pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                    pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                    pppoe_session = Enum.YLeaf(4, "pppoe-session")


                                class Id(Enum):
                                    """
                                    Id (Enum Class)

                                    .. data:: any = 0

                                    """

                                    any = Enum.YLeaf(0, "any")



                                class Cos2(Entity):
                                    """
                                    
                                    
                                    .. attribute:: cos
                                    
                                    	CoS value to use for CFM packets
                                    	**type**\: list of int
                                    
                                    	**range:** 0..7
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                        self.yang_name = "cos2"
                                        self.yang_parent_name = "dot1ad"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                        ])
                                        self.cos = []
                                        self._segment_path = lambda: "cos2"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: id
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: list of int
                                
                                			**range:** 1..4094
                                
                                		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                                
                                		**type**\: list of str
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: union of the below types:
                                
                                		**type**\: list of int
                                
                                			**range:** 1..4094
                                
                                		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                                
                                		**type**\: list of str
                                
                                .. attribute:: cos2
                                
                                	
                                	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q.Cos2>`
                                
                                .. attribute:: etype
                                
                                	payload ethertype after Vlan Field
                                	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q.Etype>`
                                
                                .. attribute:: exact
                                
                                	payload Ethertype does not include 802.1q/802.1ad Tags
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: vlan_type
                                
                                	Vlan Protocol Type
                                	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q.VlanType>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                        ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                        ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                        ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                    ])
                                    self.id = []
                                    self.cos = []
                                    self.second_dot1q = []
                                    self.etype = []
                                    self.exact = None
                                    self.vlan_type = None

                                    self.cos2 = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q.Cos2()
                                    self.cos2.parent = self
                                    self._children_name_map["cos2"] = "cos2"
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                                class Etype(Enum):
                                    """
                                    Etype (Enum Class)

                                    payload ethertype after Vlan Field

                                    .. data:: ipv4 = 0

                                    .. data:: ipv6 = 1

                                    .. data:: pppoe_all = 2

                                    .. data:: pppoe_discovery = 3

                                    .. data:: pppoe_session = 4

                                    """

                                    ipv4 = Enum.YLeaf(0, "ipv4")

                                    ipv6 = Enum.YLeaf(1, "ipv6")

                                    pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                    pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                    pppoe_session = Enum.YLeaf(4, "pppoe-session")


                                class Id(Enum):
                                    """
                                    Id (Enum Class)

                                    .. data:: any = 0

                                    """

                                    any = Enum.YLeaf(0, "any")


                                class SecondDot1q(Enum):
                                    """
                                    SecondDot1q (Enum Class)

                                    inner 802.1Q Virtual LAN or C\-VLAN

                                    .. data:: any = 0

                                    """

                                    any = Enum.YLeaf(0, "any")


                                class VlanType(Enum):
                                    """
                                    VlanType (Enum Class)

                                    Vlan Protocol Type

                                    .. data:: Y_0x88A8 = 0

                                    .. data:: Y_0x9100 = 1

                                    .. data:: Y_0x9200 = 2

                                    """

                                    Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                    Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                    Y_0x9200 = Enum.YLeaf(2, "0x9200")



                                class Cos2(Entity):
                                    """
                                    
                                    
                                    .. attribute:: cos
                                    
                                    	cos Vlan
                                    	**type**\: list of int
                                    
                                    	**range:** 0..7
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                        self.yang_name = "cos2"
                                        self.yang_parent_name = "dot1q"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                        ])
                                        self.cos = []
                                        self._segment_path = lambda: "cos2"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                            class PriorityTagged(Entity):
                                """
                                Priority tagged EFP
                                
                                .. attribute:: cos_container
                                
                                	
                                	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                                
                                .. attribute:: etype
                                
                                	payload ethertype after Vlan Field
                                	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                    self.yang_name = "priority-tagged"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                    ])
                                    self.etype = []

                                    self.cos_container = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                    self.cos_container.parent = self
                                    self._children_name_map["cos_container"] = "cos-container"
                                    self._segment_path = lambda: "priority-tagged"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                                class Etype(Enum):
                                    """
                                    Etype (Enum Class)

                                    payload ethertype after Vlan Field

                                    .. data:: ipv4 = 0

                                    .. data:: ipv6 = 1

                                    .. data:: pppoe_all = 2

                                    .. data:: pppoe_discovery = 3

                                    .. data:: pppoe_session = 4

                                    """

                                    ipv4 = Enum.YLeaf(0, "ipv4")

                                    ipv6 = Enum.YLeaf(1, "ipv6")

                                    pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                    pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                    pppoe_session = Enum.YLeaf(4, "pppoe-session")



                                class CosContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: cos
                                    
                                    	cos Vlan
                                    	**type**\: list of int
                                    
                                    	**range:** 0..7
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                        self.yang_name = "cos-container"
                                        self.yang_parent_name = "priority-tagged"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                        ])
                                        self.cos = []
                                        self._segment_path = lambda: "cos-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                            class Untagged(Entity):
                                """
                                Untagged encapsulation
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Encapsulation.Untagged, self).__init__()

                                    self.yang_name = "untagged"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "untagged"
                                    self._is_frozen = True


                        class Ip(Entity):
                            """
                            Interface Internet Protocol config commands
                            
                            .. attribute:: acl
                            
                            	
                            	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Acl>`
                            
                            .. attribute:: dhcp
                            
                            	DHCP
                            	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp>`
                            
                            .. attribute:: verify
                            
                            	verify
                            	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Verify>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Verify))])
                                self._leafs = OrderedDict()

                                self.acl = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Acl()
                                self.acl.parent = self
                                self._children_name_map["acl"] = "acl"

                                self.dhcp = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp()
                                self.dhcp.parent = self
                                self._children_name_map["dhcp"] = "dhcp"

                                self.verify = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Verify()
                                self.verify.parent = self
                                self._children_name_map["verify"] = "verify"
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip, [], name, value)


                            class Acl(Entity):
                                """
                                
                                
                                .. attribute:: access_group
                                
                                	Specify access control for packets
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..199 \| 1300..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                .. attribute:: in_
                                
                                	inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Acl, self).__init__()

                                    self.yang_name = "acl"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.access_group = None
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                            class Dhcp(Entity):
                                """
                                DHCP
                                
                                .. attribute:: relay
                                
                                	DHCP relay
                                	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp, self).__init__()

                                    self.yang_name = "dhcp"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay))])
                                    self._leafs = OrderedDict()

                                    self.relay = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay()
                                    self.relay.parent = self
                                    self._children_name_map["relay"] = "relay"
                                    self._segment_path = lambda: "dhcp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp, [], name, value)


                                class Relay(Entity):
                                    """
                                    DHCP relay
                                    
                                    .. attribute:: information
                                    
                                    	DHCP relay information
                                    	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                        self.yang_name = "relay"
                                        self.yang_parent_name = "dhcp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("information", ("information", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information))])
                                        self._leafs = OrderedDict()

                                        self.information = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information()
                                        self.information.parent = self
                                        self._children_name_map["information"] = "information"
                                        self._segment_path = lambda: "relay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                    class Information(Entity):
                                        """
                                        DHCP relay information
                                        
                                        .. attribute:: option
                                        
                                        	DHCP relay information option
                                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                            self.yang_name = "information"
                                            self.yang_parent_name = "relay"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                            self._leafs = OrderedDict()

                                            self.option = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                            self.option.parent = self
                                            self._children_name_map["option"] = "option"
                                            self._segment_path = lambda: "information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                        class Option(Entity):
                                            """
                                            DHCP relay information option
                                            
                                            .. attribute:: subscriber_id
                                            
                                            	DHCP relay information option subscriber\-id
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-eth'
                                            _revision = '2018-04-09'

                                            def __init__(self):
                                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                                self.yang_name = "option"
                                                self.yang_parent_name = "information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                                ])
                                                self.subscriber_id = None
                                                self._segment_path = lambda: "option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class Verify(Entity):
                                """
                                verify
                                
                                .. attribute:: source
                                
                                	source address
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: vlan
                                
                                	vlan specification
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: dhcp_snooping
                                
                                	snooping enable vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Verify, self).__init__()

                                    self.yang_name = "verify"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                        ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.source = None
                                    self.vlan = None
                                    self.dhcp_snooping = None
                                    self.port_security = None
                                    self._segment_path = lambda: "verify"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 interface subcommands
                            
                            .. attribute:: traffic_filter
                            
                            	Access control list for packets
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.traffic_filter = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                        class Rewrite(Entity):
                            """
                            Configure ethernet rewrite criteria
                            
                            .. attribute:: ingress
                            
                            	Ingress Rewrite
                            	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite, self).__init__()

                                self.yang_name = "rewrite"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress))])
                                self._leafs = OrderedDict()

                                self.ingress = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress()
                                self.ingress.parent = self
                                self._children_name_map["ingress"] = "ingress"
                                self._segment_path = lambda: "rewrite"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite, [], name, value)


                            class Ingress(Entity):
                                """
                                Ingress Rewrite
                                
                                .. attribute:: tag
                                
                                	Configure Rewrite Tag
                                	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress, self).__init__()

                                    self.yang_name = "ingress"
                                    self.yang_parent_name = "rewrite"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag))])
                                    self._leafs = OrderedDict()

                                    self.tag = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag()
                                    self.tag.parent = self
                                    self._children_name_map["tag"] = "tag"
                                    self._segment_path = lambda: "ingress"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress, [], name, value)


                                class Tag(Entity):
                                    """
                                    Configure Rewrite Tag
                                    
                                    .. attribute:: pop
                                    
                                    	Pop the tag
                                    	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                    
                                    .. attribute:: push
                                    
                                    	Rewrite Operation of push
                                    	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                    
                                    .. attribute:: translate
                                    
                                    	Translate Tag
                                    	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                        self.yang_name = "tag"
                                        self.yang_parent_name = "ingress"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                        self._leafs = OrderedDict()

                                        self.pop = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                        self.pop.parent = self
                                        self._children_name_map["pop"] = "pop"

                                        self.push = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push()
                                        self.push.parent = self
                                        self._children_name_map["push"] = "push"

                                        self.translate = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                        self.translate.parent = self
                                        self._children_name_map["translate"] = "translate"
                                        self._segment_path = lambda: "tag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                    class Pop(Entity):
                                        """
                                        Pop the tag
                                        
                                        .. attribute:: way
                                        
                                        	
                                        	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                            self.yang_name = "pop"
                                            self.yang_parent_name = "tag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                            ])
                                            self.way = None
                                            self.mode = None
                                            self._segment_path = lambda: "pop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")


                                        class Way(Enum):
                                            """
                                            Way (Enum Class)

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class Push(Entity):
                                        """
                                        Rewrite Operation of push
                                        
                                        .. attribute:: dot1q
                                        
                                        	Push dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                            self.yang_name = "push"
                                            self.yang_parent_name = "tag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "push"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class Translate(Entity):
                                        """
                                        Translate Tag
                                        
                                        .. attribute:: t1_to_1
                                        
                                        	Translate 1\-to\-1
                                        	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                        
                                        .. attribute:: t1_to_2
                                        
                                        	Translate 1\-to\-2
                                        	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                        
                                        .. attribute:: t2_to_1
                                        
                                        	Translate 2\-to\-1
                                        	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                        
                                        .. attribute:: t2_to_2
                                        
                                        	Translate 2\-to\-2
                                        	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                            self.yang_name = "translate"
                                            self.yang_parent_name = "tag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                            self._leafs = OrderedDict()

                                            self.t1_to_1 = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                            self.t1_to_1.parent = self
                                            self._children_name_map["t1_to_1"] = "t1-to-1"

                                            self.t1_to_2 = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                            self.t1_to_2.parent = self
                                            self._children_name_map["t1_to_2"] = "t1-to-2"

                                            self.t2_to_1 = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                            self.t2_to_1.parent = self
                                            self._children_name_map["t2_to_1"] = "t2-to-1"

                                            self.t2_to_2 = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                            self.t2_to_2.parent = self
                                            self._children_name_map["t2_to_2"] = "t2-to-2"
                                            self._segment_path = lambda: "translate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                        class T1To1(Entity):
                                            """
                                            Translate 1\-to\-1
                                            
                                            .. attribute:: dot1q
                                            
                                            	Ethertype dot1q of the translation
                                            	**type**\: int
                                            
                                            	**range:** 1..4094
                                            
                                            .. attribute:: mode
                                            
                                            	
                                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                            
                                            

                                            """

                                            _prefix = 'ios-eth'
                                            _revision = '2018-04-09'

                                            def __init__(self):
                                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                                self.yang_name = "t1-to-1"
                                                self.yang_parent_name = "translate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                                ])
                                                self.dot1q = None
                                                self.mode = None
                                                self._segment_path = lambda: "t1-to-1"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                            class Mode(Enum):
                                                """
                                                Mode (Enum Class)

                                                .. data:: symmetric = 0

                                                """

                                                symmetric = Enum.YLeaf(0, "symmetric")



                                        class T1To2(Entity):
                                            """
                                            Translate 1\-to\-2
                                            
                                            .. attribute:: dot1q
                                            
                                            	Translate ethertype of dot1q
                                            	**type**\: int
                                            
                                            	**range:** 1..4094
                                            
                                            .. attribute:: second_dot1q
                                            
                                            	Second dot1q tag
                                            	**type**\: int
                                            
                                            	**range:** 1..4094
                                            
                                            .. attribute:: mode
                                            
                                            	
                                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                            
                                            

                                            """

                                            _prefix = 'ios-eth'
                                            _revision = '2018-04-09'

                                            def __init__(self):
                                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                                self.yang_name = "t1-to-2"
                                                self.yang_parent_name = "translate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                    ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                                ])
                                                self.dot1q = None
                                                self.second_dot1q = None
                                                self.mode = None
                                                self._segment_path = lambda: "t1-to-2"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                            class Mode(Enum):
                                                """
                                                Mode (Enum Class)

                                                .. data:: symmetric = 0

                                                """

                                                symmetric = Enum.YLeaf(0, "symmetric")



                                        class T2To1(Entity):
                                            """
                                            Translate 2\-to\-1
                                            
                                            .. attribute:: dot1q
                                            
                                            	Ethertype dot1q of the translation
                                            	**type**\: int
                                            
                                            	**range:** 1..4094
                                            
                                            .. attribute:: mode
                                            
                                            	
                                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                            
                                            

                                            """

                                            _prefix = 'ios-eth'
                                            _revision = '2018-04-09'

                                            def __init__(self):
                                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                                self.yang_name = "t2-to-1"
                                                self.yang_parent_name = "translate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                                ])
                                                self.dot1q = None
                                                self.mode = None
                                                self._segment_path = lambda: "t2-to-1"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                            class Mode(Enum):
                                                """
                                                Mode (Enum Class)

                                                .. data:: symmetric = 0

                                                """

                                                symmetric = Enum.YLeaf(0, "symmetric")



                                        class T2To2(Entity):
                                            """
                                            Translate 2\-to\-2
                                            
                                            .. attribute:: dot1q
                                            
                                            	Translate ethertype of dot1q
                                            	**type**\: int
                                            
                                            	**range:** 1..4094
                                            
                                            .. attribute:: second_dot1q
                                            
                                            	Second dot1q tag
                                            	**type**\: int
                                            
                                            	**range:** 1..4094
                                            
                                            .. attribute:: mode
                                            
                                            	
                                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                            
                                            

                                            """

                                            _prefix = 'ios-eth'
                                            _revision = '2018-04-09'

                                            def __init__(self):
                                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                                self.yang_name = "t2-to-2"
                                                self.yang_parent_name = "translate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                    ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                                ])
                                                self.dot1q = None
                                                self.second_dot1q = None
                                                self.mode = None
                                                self._segment_path = lambda: "t2-to-2"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                            class Mode(Enum):
                                                """
                                                Mode (Enum Class)

                                                .. data:: symmetric = 0

                                                """

                                                symmetric = Enum.YLeaf(0, "symmetric")



                        class Errdisable(Entity):
                            """
                            Configure error disable
                            
                            .. attribute:: recovery
                            
                            	enable auto recovery
                            	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable.Recovery>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable, self).__init__()

                                self.yang_name = "errdisable"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable.Recovery))])
                                self._leafs = OrderedDict()

                                self.recovery = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable.Recovery()
                                self.recovery.parent = self
                                self._children_name_map["recovery"] = "recovery"
                                self._segment_path = lambda: "errdisable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable, [], name, value)


                            class Recovery(Entity):
                                """
                                enable auto recovery
                                
                                .. attribute:: cause
                                
                                	error disable cause
                                	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable.Recovery.Cause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable.Recovery, self).__init__()

                                    self.yang_name = "recovery"
                                    self.yang_parent_name = "errdisable"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable.Recovery.Cause))])
                                    self._leafs = OrderedDict()

                                    self.cause = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable.Recovery.Cause()
                                    self.cause.parent = self
                                    self._children_name_map["cause"] = "cause"
                                    self._segment_path = lambda: "recovery"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable.Recovery, [], name, value)


                                class Cause(Entity):
                                    """
                                    error disable cause
                                    
                                    .. attribute:: mac_security
                                    
                                    	mac\-security violation
                                    	**type**\: int
                                    
                                    	**range:** 30..86400
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                        self.yang_name = "cause"
                                        self.yang_parent_name = "recovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                        ])
                                        self.mac_security = None
                                        self._segment_path = lambda: "cause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                        class EthernetContainer(Entity):
                            """
                            
                            
                            .. attribute:: ethernet
                            
                            	ethernet
                            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer, self).__init__()

                                self.yang_name = "ethernet-container"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet))])
                                self._leafs = OrderedDict()

                                self.ethernet = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._segment_path = lambda: "ethernet-container"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer, [], name, value)


                            class Ethernet(Entity):
                                """
                                ethernet
                                
                                .. attribute:: lmi
                                
                                	Configure ether lmi parameters
                                	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                                
                                .. attribute:: loopback
                                
                                	Ethernet Dataplane Loopback
                                	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "ethernet-container"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                    self._leafs = OrderedDict()

                                    self.lmi = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                    self.lmi.parent = self
                                    self._children_name_map["lmi"] = "lmi"

                                    self.loopback = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                    self.loopback.parent = self
                                    self._children_name_map["loopback"] = "loopback"
                                    self._segment_path = lambda: "ethernet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                                class Lmi(Entity):
                                    """
                                    Configure ether lmi parameters
                                    
                                    .. attribute:: ce_vlan
                                    
                                    	Configure ether lmi customer vlans
                                    	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                        self.yang_name = "lmi"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                        self._leafs = OrderedDict()

                                        self.ce_vlan = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                        self.ce_vlan.parent = self
                                        self._children_name_map["ce_vlan"] = "ce-vlan"
                                        self._segment_path = lambda: "lmi"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                    class CeVlan(Entity):
                                        """
                                        Configure ether lmi customer vlans
                                        
                                        .. attribute:: map
                                        
                                        	Configure ether lmi ce\-vlan/evc map
                                        	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                            self.yang_name = "ce-vlan"
                                            self.yang_parent_name = "lmi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map", ("map", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                            self._leafs = OrderedDict()

                                            self.map = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                            self.map.parent = self
                                            self._children_name_map["map"] = "map"
                                            self._segment_path = lambda: "ce-vlan"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                        class Map(Entity):
                                            """
                                            Configure ether lmi ce\-vlan/evc map
                                            
                                            .. attribute:: any
                                            
                                            	For all VLANS [1\-4094,untagged]
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: default
                                            
                                            	Default EFP
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: untagged
                                            
                                            	Untagged frames
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                            
                                            

                                            """

                                            _prefix = 'ios-eth'
                                            _revision = '2018-04-09'

                                            def __init__(self):
                                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                                self.yang_name = "map"
                                                self.yang_parent_name = "ce-vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                    ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                    ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                                ])
                                                self.any = None
                                                self.default = None
                                                self.untagged = None
                                                self.vlan_range = None
                                                self._segment_path = lambda: "map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                                class Loopback(Entity):
                                    """
                                    Ethernet Dataplane Loopback
                                    
                                    .. attribute:: permit
                                    
                                    	Allow data plane loopback to be activated
                                    	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                        self.yang_name = "loopback"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                        self._leafs = OrderedDict()

                                        self.permit = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                        self.permit.parent = self
                                        self._children_name_map["permit"] = "permit"
                                        self._segment_path = lambda: "loopback"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                    class Permit(Entity):
                                        """
                                        Allow data plane loopback to be activated
                                        
                                        .. attribute:: external
                                        
                                        	Allow to loopback the traffic from the wire
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: internal
                                        
                                        	Allow to loopback the traffic from the relay
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                            self.yang_name = "permit"
                                            self.yang_parent_name = "loopback"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                                ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                            ])
                                            self.external = None
                                            self.internal = None
                                            self._segment_path = lambda: "permit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                        class Snmp(Entity):
                            """
                            Modify SNMP service instance parameters
                            
                            .. attribute:: trap
                            
                            	Allow a specific SNMP trap
                            	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp.Trap>`
                            
                            .. attribute:: ifindex
                            
                            	Persist ifindex for the service instance
                            	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp.Ifindex>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp, self).__init__()

                                self.yang_name = "snmp"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp.Ifindex))])
                                self._leafs = OrderedDict()

                                self.trap = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp.Trap()
                                self.trap.parent = self
                                self._children_name_map["trap"] = "trap"

                                self.ifindex = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp.Ifindex()
                                self.ifindex.parent = self
                                self._children_name_map["ifindex"] = "ifindex"
                                self._segment_path = lambda: "snmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp, [], name, value)


                            class Trap(Entity):
                                """
                                Allow a specific SNMP trap
                                
                                .. attribute:: link_status
                                
                                	Allow SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp.Trap, self).__init__()

                                    self.yang_name = "trap"
                                    self.yang_parent_name = "snmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                    ])
                                    self.link_status = None
                                    self._segment_path = lambda: "trap"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                            class Ifindex(Entity):
                                """
                                Persist ifindex for the service instance
                                
                                .. attribute:: persist
                                
                                	Enable/Disable ifIndex persistence
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp.Ifindex, self).__init__()

                                    self.yang_name = "ifindex"
                                    self.yang_parent_name = "snmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                    ])
                                    self.persist = None
                                    self._segment_path = lambda: "ifindex"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                        class BridgeDomain(Entity):
                            """
                            Bridge\-domain
                            
                            .. attribute:: bridge_id
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: split_horizon
                            
                            	Configure this port as a member of a split horizon group
                            	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.BridgeDomain.SplitHorizon>`
                            
                            .. attribute:: from_encapsulation
                            
                            	from\-encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.BridgeDomain, self).__init__()

                                self.yang_name = "bridge-domain"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.BridgeDomain.SplitHorizon))])
                                self._leafs = OrderedDict([
                                    ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                    ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                                ])
                                self.bridge_id = None
                                self.from_encapsulation = None

                                self.split_horizon = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.BridgeDomain.SplitHorizon()
                                self.split_horizon.parent = self
                                self._children_name_map["split_horizon"] = "split-horizon"
                                self._segment_path = lambda: "bridge-domain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                            class SplitHorizon(Entity):
                                """
                                Configure this port as a member of a split horizon group
                                
                                .. attribute:: group
                                
                                	Split\-horizon group
                                	**type**\: int
                                
                                	**range:** 0..13
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                    self.yang_name = "split-horizon"
                                    self.yang_parent_name = "bridge-domain"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                    ])
                                    self.group = None
                                    self._segment_path = lambda: "split-horizon"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                        class Mac(Entity):
                            """
                            Commands for MAC Address\-based features
                            
                            .. attribute:: security
                            
                            	MAC Security commands
                            	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.Security>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.AccessGroup>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac, self).__init__()

                                self.yang_name = "mac"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("security", ("security", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.AccessGroup))])
                                self._leafs = OrderedDict()

                                self.security = None
                                self._children_name_map["security"] = "security"

                                self.access_group = YList(self)
                                self._segment_path = lambda: "mac"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac, [], name, value)


                            class Security(Entity):
                                """
                                MAC Security commands
                                
                                .. attribute:: maximum
                                
                                	Configure an upper bound
                                	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.Security.Maximum>`
                                
                                .. attribute:: violation
                                
                                	Configure the response when a MAC security policy is violated
                                	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.Security.Violation>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.Security, self).__init__()

                                    self.yang_name = "security"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.Security.Maximum))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.Security.Violation')])),
                                    ])
                                    self.violation = None

                                    self.maximum = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.Security.Maximum()
                                    self.maximum.parent = self
                                    self._children_name_map["maximum"] = "maximum"
                                    self._segment_path = lambda: "security"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.Security, ['violation'], name, value)

                                class Violation(Enum):
                                    """
                                    Violation (Enum Class)

                                    Configure the response when a MAC security policy is violated

                                    .. data:: protect = 0

                                    .. data:: restrict = 1

                                    """

                                    protect = Enum.YLeaf(0, "protect")

                                    restrict = Enum.YLeaf(1, "restrict")



                                class Maximum(Entity):
                                    """
                                    Configure an upper bound
                                    
                                    .. attribute:: addresses
                                    
                                    	Maximum addresses that can be learnt on this service instance
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.Security.Maximum, self).__init__()

                                        self.yang_name = "maximum"
                                        self.yang_parent_name = "security"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                        ])
                                        self.addresses = None
                                        self._segment_path = lambda: "maximum"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                            class AccessGroup(Entity):
                                """
                                Specify access control for packets
                                
                                .. attribute:: acl_name  (key)
                                
                                	ACL name
                                	**type**\: str
                                
                                .. attribute:: in_
                                
                                	Apply to ingress
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Apply to Egress
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.AccessGroup, self).__init__()

                                    self.yang_name = "access-group"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['acl_name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.acl_name = None
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                        class ServicePolicy(Entity):
                            """
                            Attach a policy\-map to an EFP
                            
                            .. attribute:: input
                            
                            	service policy input
                            	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy.Input>`
                            
                            .. attribute:: output
                            
                            	service policy output
                            	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy.Output>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("input", ("input", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy.Output))])
                                self._leafs = OrderedDict()

                                self.input = YList(self)
                                self.output = YList(self)
                                self._segment_path = lambda: "service-policy"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy, [], name, value)


                            class Input(Entity):
                                """
                                service policy input
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy.Input, self).__init__()

                                    self.yang_name = "input"
                                    self.yang_parent_name = "service-policy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                            class Output(Entity):
                                """
                                service policy output
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy.Output, self).__init__()

                                    self.yang_name = "output"
                                    self.yang_parent_name = "service-policy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                        class Cfm(Entity):
                            """
                            Ethernet CFM EFP subcommands
                            
                            .. attribute:: encapsulation
                            
                            	Configure CFM ethernet frame encapsulation
                            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation>`
                            
                            .. attribute:: mep
                            
                            	Maintenance End Point
                            	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Mep>`
                            
                            .. attribute:: mip
                            
                            	Maintenance Intermediate Point
                            	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Mip>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm, self).__init__()

                                self.yang_name = "cfm"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Mip))])
                                self._leafs = OrderedDict()

                                self.encapsulation = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation()
                                self.encapsulation.parent = self
                                self._children_name_map["encapsulation"] = "encapsulation"

                                self.mep = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Mep()
                                self.mep.parent = self
                                self._children_name_map["mep"] = "mep"

                                self.mip = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Mip()
                                self.mip.parent = self
                                self._children_name_map["mip"] = "mip"
                                self._segment_path = lambda: "cfm"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm, [], name, value)


                            class Encapsulation(Entity):
                                """
                                Configure CFM ethernet frame encapsulation
                                
                                .. attribute:: dot1ad
                                
                                	802.1ad \- Provider Bridges
                                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                                
                                .. attribute:: dot1q
                                
                                	IEEE 802.1Q Virtual LAN or S\-VLAN
                                	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1q>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation, self).__init__()

                                    self.yang_name = "encapsulation"
                                    self.yang_parent_name = "cfm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                    self._leafs = OrderedDict()

                                    self.dot1ad = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                    self.dot1ad.parent = self
                                    self._children_name_map["dot1ad"] = "dot1ad"

                                    self.dot1q = Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1q()
                                    self.dot1q.parent = self
                                    self._children_name_map["dot1q"] = "dot1q"
                                    self._segment_path = lambda: "encapsulation"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation, [], name, value)


                                class Dot1ad(Entity):
                                    """
                                    802.1ad \- Provider Bridges
                                    
                                    .. attribute:: vlan_id
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: cos
                                    
                                    	CoS value to use for CFM packets
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: dot1q
                                    
                                    	Second tag (dot1q)
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                        self.yang_name = "dot1ad"
                                        self.yang_parent_name = "encapsulation"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                            ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                        ])
                                        self.vlan_id = None
                                        self.cos = None
                                        self.dot1q = None
                                        self._segment_path = lambda: "dot1ad"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                                class Dot1q(Entity):
                                    """
                                    IEEE 802.1Q Virtual LAN or S\-VLAN
                                    
                                    .. attribute:: vlan_id
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: cos
                                    
                                    	CoS value to use for CFM packets
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: second_dot1q
                                    
                                    	inner 802.1Q Virtual LAN or C\-VLAN
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                        self.yang_name = "dot1q"
                                        self.yang_parent_name = "encapsulation"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                            ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                            ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                        ])
                                        self.vlan_id = None
                                        self.cos = None
                                        self.second_dot1q = None
                                        self._segment_path = lambda: "dot1q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                            class Mep(Entity):
                                """
                                Maintenance End Point
                                
                                .. attribute:: domain
                                
                                	Configure a domain for this mep
                                	**type**\: str
                                
                                .. attribute:: mpid
                                
                                	Maintenance End Point Identifier
                                	**type**\: int
                                
                                	**range:** 1..8191
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Mep, self).__init__()

                                    self.yang_name = "mep"
                                    self.yang_parent_name = "cfm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                        ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                    ])
                                    self.domain = None
                                    self.mpid = None
                                    self._segment_path = lambda: "mep"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                            class Mip(Entity):
                                """
                                Maintenance Intermediate Point
                                
                                .. attribute:: level
                                
                                	Maintenance Level
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Mip, self).__init__()

                                    self.yang_name = "mip"
                                    self.yang_parent_name = "cfm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                    ])
                                    self.level = None
                                    self._segment_path = lambda: "mip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.Cfm.Mip, ['level'], name, value)


                        class L2protocol(Entity):
                            """
                            Configure l2 control protocol processing
                            
                            .. attribute:: discard
                            
                            	discard L2 control protocol packets as data
                            	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Discard>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: peer
                            
                            	peer L2 control protocol packets as data
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Peer>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: forward
                            
                            	forward L2 control protocol packets as data
                            	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Forward>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: tunnel
                            
                            	tunnel L2 control protocol packets as data
                            	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Tunnel>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol, self).__init__()

                                self.yang_name = "l2protocol"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Tunnel))])
                                self._leafs = OrderedDict()

                                self.discard = None
                                self._children_name_map["discard"] = "discard"

                                self.peer = None
                                self._children_name_map["peer"] = "peer"

                                self.forward = None
                                self._children_name_map["forward"] = "forward"

                                self.tunnel = None
                                self._children_name_map["tunnel"] = "tunnel"
                                self._segment_path = lambda: "l2protocol"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol, [], name, value)


                            class Discard(Entity):
                                """
                                discard L2 control protocol packets as data
                                
                                .. attribute:: protocol
                                
                                	
                                	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Discard.Protocol>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Discard, self).__init__()

                                    self.yang_name = "discard"
                                    self.yang_parent_name = "l2protocol"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Discard.Protocol')])),
                                    ])
                                    self.protocol = []
                                    self._segment_path = lambda: "discard"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                                class Protocol(Enum):
                                    """
                                    Protocol (Enum Class)

                                    .. data:: R4 = 0

                                    .. data:: R5 = 1

                                    .. data:: R6 = 2

                                    .. data:: R8 = 3

                                    .. data:: R9 = 4

                                    .. data:: RA = 5

                                    .. data:: RB = 6

                                    .. data:: RC = 7

                                    .. data:: RD = 8

                                    .. data:: RF = 9

                                    .. data:: cdp = 10

                                    .. data:: dtp = 11

                                    .. data:: elmi = 12

                                    .. data:: esmc = 13

                                    .. data:: lacp = 14

                                    .. data:: lldp = 15

                                    .. data:: loam = 16

                                    .. data:: pagp = 17

                                    .. data:: ptppd = 18

                                    .. data:: stp = 19

                                    .. data:: udld = 20

                                    .. data:: vtp = 21

                                    """

                                    R4 = Enum.YLeaf(0, "R4")

                                    R5 = Enum.YLeaf(1, "R5")

                                    R6 = Enum.YLeaf(2, "R6")

                                    R8 = Enum.YLeaf(3, "R8")

                                    R9 = Enum.YLeaf(4, "R9")

                                    RA = Enum.YLeaf(5, "RA")

                                    RB = Enum.YLeaf(6, "RB")

                                    RC = Enum.YLeaf(7, "RC")

                                    RD = Enum.YLeaf(8, "RD")

                                    RF = Enum.YLeaf(9, "RF")

                                    cdp = Enum.YLeaf(10, "cdp")

                                    dtp = Enum.YLeaf(11, "dtp")

                                    elmi = Enum.YLeaf(12, "elmi")

                                    esmc = Enum.YLeaf(13, "esmc")

                                    lacp = Enum.YLeaf(14, "lacp")

                                    lldp = Enum.YLeaf(15, "lldp")

                                    loam = Enum.YLeaf(16, "loam")

                                    pagp = Enum.YLeaf(17, "pagp")

                                    ptppd = Enum.YLeaf(18, "ptppd")

                                    stp = Enum.YLeaf(19, "stp")

                                    udld = Enum.YLeaf(20, "udld")

                                    vtp = Enum.YLeaf(21, "vtp")



                            class Peer(Entity):
                                """
                                peer L2 control protocol packets as data
                                
                                .. attribute:: protocol
                                
                                	
                                	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Peer.Protocol>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "l2protocol"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Peer.Protocol')])),
                                    ])
                                    self.protocol = []
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                                class Protocol(Enum):
                                    """
                                    Protocol (Enum Class)

                                    .. data:: R4 = 0

                                    .. data:: R5 = 1

                                    .. data:: R6 = 2

                                    .. data:: R8 = 3

                                    .. data:: R9 = 4

                                    .. data:: RA = 5

                                    .. data:: RB = 6

                                    .. data:: RC = 7

                                    .. data:: RD = 8

                                    .. data:: RF = 9

                                    .. data:: cdp = 10

                                    .. data:: dtp = 11

                                    .. data:: elmi = 12

                                    .. data:: esmc = 13

                                    .. data:: lacp = 14

                                    .. data:: lldp = 15

                                    .. data:: loam = 16

                                    .. data:: pagp = 17

                                    .. data:: ptppd = 18

                                    .. data:: stp = 19

                                    .. data:: udld = 20

                                    .. data:: vtp = 21

                                    """

                                    R4 = Enum.YLeaf(0, "R4")

                                    R5 = Enum.YLeaf(1, "R5")

                                    R6 = Enum.YLeaf(2, "R6")

                                    R8 = Enum.YLeaf(3, "R8")

                                    R9 = Enum.YLeaf(4, "R9")

                                    RA = Enum.YLeaf(5, "RA")

                                    RB = Enum.YLeaf(6, "RB")

                                    RC = Enum.YLeaf(7, "RC")

                                    RD = Enum.YLeaf(8, "RD")

                                    RF = Enum.YLeaf(9, "RF")

                                    cdp = Enum.YLeaf(10, "cdp")

                                    dtp = Enum.YLeaf(11, "dtp")

                                    elmi = Enum.YLeaf(12, "elmi")

                                    esmc = Enum.YLeaf(13, "esmc")

                                    lacp = Enum.YLeaf(14, "lacp")

                                    lldp = Enum.YLeaf(15, "lldp")

                                    loam = Enum.YLeaf(16, "loam")

                                    pagp = Enum.YLeaf(17, "pagp")

                                    ptppd = Enum.YLeaf(18, "ptppd")

                                    stp = Enum.YLeaf(19, "stp")

                                    udld = Enum.YLeaf(20, "udld")

                                    vtp = Enum.YLeaf(21, "vtp")



                            class Forward(Entity):
                                """
                                forward L2 control protocol packets as data
                                
                                .. attribute:: protocol
                                
                                	
                                	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Forward.Protocol>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Forward, self).__init__()

                                    self.yang_name = "forward"
                                    self.yang_parent_name = "l2protocol"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Forward.Protocol')])),
                                    ])
                                    self.protocol = []
                                    self._segment_path = lambda: "forward"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                                class Protocol(Enum):
                                    """
                                    Protocol (Enum Class)

                                    .. data:: R4 = 0

                                    .. data:: R5 = 1

                                    .. data:: R6 = 2

                                    .. data:: R8 = 3

                                    .. data:: R9 = 4

                                    .. data:: RA = 5

                                    .. data:: RB = 6

                                    .. data:: RC = 7

                                    .. data:: RD = 8

                                    .. data:: RF = 9

                                    .. data:: cdp = 10

                                    .. data:: dtp = 11

                                    .. data:: elmi = 12

                                    .. data:: esmc = 13

                                    .. data:: lacp = 14

                                    .. data:: lldp = 15

                                    .. data:: loam = 16

                                    .. data:: pagp = 17

                                    .. data:: ptppd = 18

                                    .. data:: stp = 19

                                    .. data:: udld = 20

                                    .. data:: vtp = 21

                                    """

                                    R4 = Enum.YLeaf(0, "R4")

                                    R5 = Enum.YLeaf(1, "R5")

                                    R6 = Enum.YLeaf(2, "R6")

                                    R8 = Enum.YLeaf(3, "R8")

                                    R9 = Enum.YLeaf(4, "R9")

                                    RA = Enum.YLeaf(5, "RA")

                                    RB = Enum.YLeaf(6, "RB")

                                    RC = Enum.YLeaf(7, "RC")

                                    RD = Enum.YLeaf(8, "RD")

                                    RF = Enum.YLeaf(9, "RF")

                                    cdp = Enum.YLeaf(10, "cdp")

                                    dtp = Enum.YLeaf(11, "dtp")

                                    elmi = Enum.YLeaf(12, "elmi")

                                    esmc = Enum.YLeaf(13, "esmc")

                                    lacp = Enum.YLeaf(14, "lacp")

                                    lldp = Enum.YLeaf(15, "lldp")

                                    loam = Enum.YLeaf(16, "loam")

                                    pagp = Enum.YLeaf(17, "pagp")

                                    ptppd = Enum.YLeaf(18, "ptppd")

                                    stp = Enum.YLeaf(19, "stp")

                                    udld = Enum.YLeaf(20, "udld")

                                    vtp = Enum.YLeaf(21, "vtp")



                            class Tunnel(Entity):
                                """
                                tunnel L2 control protocol packets as data
                                
                                .. attribute:: protocol
                                
                                	
                                	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Tunnel.Protocol>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Tunnel, self).__init__()

                                    self.yang_name = "tunnel"
                                    self.yang_parent_name = "l2protocol"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                    ])
                                    self.protocol = []
                                    self._segment_path = lambda: "tunnel"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                                class Protocol(Enum):
                                    """
                                    Protocol (Enum Class)

                                    .. data:: R4 = 0

                                    .. data:: R5 = 1

                                    .. data:: R6 = 2

                                    .. data:: R8 = 3

                                    .. data:: R9 = 4

                                    .. data:: RA = 5

                                    .. data:: RB = 6

                                    .. data:: RC = 7

                                    .. data:: RD = 8

                                    .. data:: RF = 9

                                    .. data:: cdp = 10

                                    .. data:: dtp = 11

                                    .. data:: elmi = 12

                                    .. data:: esmc = 13

                                    .. data:: lacp = 14

                                    .. data:: lldp = 15

                                    .. data:: loam = 16

                                    .. data:: pagp = 17

                                    .. data:: ptppd = 18

                                    .. data:: stp = 19

                                    .. data:: udld = 20

                                    .. data:: vtp = 21

                                    """

                                    R4 = Enum.YLeaf(0, "R4")

                                    R5 = Enum.YLeaf(1, "R5")

                                    R6 = Enum.YLeaf(2, "R6")

                                    R8 = Enum.YLeaf(3, "R8")

                                    R9 = Enum.YLeaf(4, "R9")

                                    RA = Enum.YLeaf(5, "RA")

                                    RB = Enum.YLeaf(6, "RB")

                                    RC = Enum.YLeaf(7, "RC")

                                    RD = Enum.YLeaf(8, "RD")

                                    RF = Enum.YLeaf(9, "RF")

                                    cdp = Enum.YLeaf(10, "cdp")

                                    dtp = Enum.YLeaf(11, "dtp")

                                    elmi = Enum.YLeaf(12, "elmi")

                                    esmc = Enum.YLeaf(13, "esmc")

                                    lacp = Enum.YLeaf(14, "lacp")

                                    lldp = Enum.YLeaf(15, "lldp")

                                    loam = Enum.YLeaf(16, "loam")

                                    pagp = Enum.YLeaf(17, "pagp")

                                    ptppd = Enum.YLeaf(18, "ptppd")

                                    stp = Enum.YLeaf(19, "stp")

                                    udld = Enum.YLeaf(20, "udld")

                                    vtp = Enum.YLeaf(21, "vtp")



                class Auto(Entity):
                    """
                    Configure Automation
                    
                    .. attribute:: qos
                    
                    	Configure AutoQoS
                    	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("qos", ("qos", Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos))])
                        self._leafs = OrderedDict()

                        self.qos = Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos()
                        self.qos.parent = self
                        self._children_name_map["qos"] = "qos"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:auto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Auto, [], name, value)


                    class Qos(Entity):
                        """
                        Configure AutoQoS
                        
                        .. attribute:: classify
                        
                        	Configure classification for untrusted devices
                        	**type**\:  :py:class:`Classify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Classify>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: trust
                        
                        	Trust the DSCP/CoS marking
                        	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Trust>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: video
                        
                        	Configure AutoQoS for video devices
                        	**type**\:  :py:class:`Video <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Video>`
                        
                        .. attribute:: voip
                        
                        	Configure AutoQoS for VoIP
                        	**type**\:  :py:class:`Voip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Voip>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos, self).__init__()

                            self.yang_name = "qos"
                            self.yang_parent_name = "auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("classify", ("classify", Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Classify)), ("trust", ("trust", Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Trust)), ("video", ("video", Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Video)), ("voip", ("voip", Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Voip))])
                            self._leafs = OrderedDict()

                            self.classify = None
                            self._children_name_map["classify"] = "classify"

                            self.trust = None
                            self._children_name_map["trust"] = "trust"

                            self.video = Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Video()
                            self.video.parent = self
                            self._children_name_map["video"] = "video"

                            self.voip = None
                            self._children_name_map["voip"] = "voip"
                            self._segment_path = lambda: "qos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos, [], name, value)


                        class Classify(Entity):
                            """
                            Configure classification for untrusted devices
                            
                            .. attribute:: police
                            
                            	Configure QoS policing for untrusted devices
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Classify, self).__init__()

                                self.yang_name = "classify"
                                self.yang_parent_name = "qos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('police', (YLeaf(YType.empty, 'police'), ['Empty'])),
                                ])
                                self.police = None
                                self._segment_path = lambda: "classify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Classify, [u'police'], name, value)


                        class Trust(Entity):
                            """
                            Trust the DSCP/CoS marking
                            
                            .. attribute:: cos
                            
                            	Trust the CoS marking
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	Trust the DSCP marking
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Trust, self).__init__()

                                self.yang_name = "trust"
                                self.yang_parent_name = "qos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('cos', (YLeaf(YType.empty, 'cos'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                                ])
                                self.cos = None
                                self.dscp = None
                                self._segment_path = lambda: "trust"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Trust, [u'cos', u'dscp'], name, value)


                        class Video(Entity):
                            """
                            Configure AutoQoS for video devices
                            
                            .. attribute:: cts
                            
                            	Trust the QoS marking of the Cisco Telepresence System
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ip_camera
                            
                            	Trust the QoS marking of the Ip Video Surveillance camera
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: media_player
                            
                            	Trust the Qos marking of the Cisco Media Player
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Video, self).__init__()

                                self.yang_name = "video"
                                self.yang_parent_name = "qos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('cts', (YLeaf(YType.empty, 'cts'), ['Empty'])),
                                    ('ip_camera', (YLeaf(YType.empty, 'ip-camera'), ['Empty'])),
                                    ('media_player', (YLeaf(YType.empty, 'media-player'), ['Empty'])),
                                ])
                                self.cts = None
                                self.ip_camera = None
                                self.media_player = None
                                self._segment_path = lambda: "video"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Video, [u'cts', u'ip_camera', u'media_player'], name, value)


                        class Voip(Entity):
                            """
                            Configure AutoQoS for VoIP
                            
                            .. attribute:: cisco_phone
                            
                            	Trust the QoS marking of Cisco IP Phone
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cisco_softphone
                            
                            	Trust the QoS marking of Cisco IP SoftPhone
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: trust
                            
                            	Trust the DSCP/CoS marking
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Voip, self).__init__()

                                self.yang_name = "voip"
                                self.yang_parent_name = "qos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('cisco_phone', (YLeaf(YType.empty, 'cisco-phone'), ['Empty'])),
                                    ('cisco_softphone', (YLeaf(YType.empty, 'cisco-softphone'), ['Empty'])),
                                    ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                                ])
                                self.cisco_phone = None
                                self.cisco_softphone = None
                                self.trust = None
                                self._segment_path = lambda: "voip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Auto.Qos.Voip, [u'cisco_phone', u'cisco_softphone', u'trust'], name, value)


                class Datalink(Entity):
                    """
                    Interface Datalink commands
                    
                    .. attribute:: flow
                    
                    	Interface Flow configuration subcommands
                    	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Datalink.Flow>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Datalink, self).__init__()

                        self.yang_name = "datalink"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("flow", ("flow", Native.Interface.PortChannelSubinterface.PortChannel.Datalink.Flow))])
                        self._leafs = OrderedDict()

                        self.flow = Native.Interface.PortChannelSubinterface.PortChannel.Datalink.Flow()
                        self.flow.parent = self
                        self._children_name_map["flow"] = "flow"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:datalink"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Datalink, [], name, value)


                    class Flow(Entity):
                        """
                        Interface Flow configuration subcommands
                        
                        .. attribute:: monitor
                        
                        	Apply a Flow Monitor
                        	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Datalink.Flow.Monitor>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Datalink.Flow, self).__init__()

                            self.yang_name = "flow"
                            self.yang_parent_name = "datalink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.PortChannelSubinterface.PortChannel.Datalink.Flow.Monitor))])
                            self._leafs = OrderedDict()

                            self.monitor = None
                            self._children_name_map["monitor"] = "monitor"
                            self._segment_path = lambda: "flow"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Datalink.Flow, [], name, value)


                        class Monitor(Entity):
                            """
                            Apply a Flow Monitor
                            
                            .. attribute:: user_defined_flow
                            
                            	User defined
                            	**type**\: str
                            
                            .. attribute:: input_output
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`InputOutput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Datalink.Flow.Monitor.InputOutput>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Datalink.Flow.Monitor, self).__init__()

                                self.yang_name = "monitor"
                                self.yang_parent_name = "flow"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('user_defined_flow', (YLeaf(YType.str, 'User-defined-flow'), ['str'])),
                                    ('input_output', (YLeaf(YType.enumeration, 'input-output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Datalink.Flow.Monitor.InputOutput')])),
                                ])
                                self.user_defined_flow = None
                                self.input_output = None
                                self._segment_path = lambda: "monitor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Datalink.Flow.Monitor, [u'user_defined_flow', u'input_output'], name, value)

                            class InputOutput(Enum):
                                """
                                InputOutput (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Energywise(Entity):
                    """
                    EnergyWise interface configurations
                    
                    .. attribute:: activitycheck
                    
                    	Apply an activity check before turning off power    to this PoE port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level
                    
                    	Set the EnergyWise level of this interface  or attached entity
                    	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Energywise, self).__init__()

                        self.yang_name = "energywise"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('activitycheck', (YLeaf(YType.empty, 'activitycheck'), ['Empty'])),
                        ])
                        self.activitycheck = None

                        self.level = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:energywise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Energywise, [u'activitycheck'], name, value)


                    class Level(Entity):
                        """
                        Set the EnergyWise level of this interface 
                        or attached entity
                        
                        .. attribute:: range  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..10
                        
                        .. attribute:: recurrence
                        
                        	Specify that this level setting should  recur at the specified time
                        	**type**\:  :py:class:`Recurrence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "energywise"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['range']
                            self._child_classes = OrderedDict([("recurrence", ("recurrence", Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence))])
                            self._leafs = OrderedDict([
                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                            ])
                            self.range = None

                            self.recurrence = Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence()
                            self.recurrence.parent = self
                            self._children_name_map["recurrence"] = "recurrence"
                            self._segment_path = lambda: "level" + "[range='" + str(self.range) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level, [u'range'], name, value)


                        class Recurrence(Entity):
                            """
                            Specify that this level setting should 
                            recur at the specified time
                            
                            .. attribute:: importance
                            
                            	Specify the importance at which the event  should be sent when it recurs
                            	**type**\: list of  		 :py:class:`Importance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence.Importance>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence, self).__init__()

                                self.yang_name = "recurrence"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("importance", ("importance", Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence.Importance))])
                                self._leafs = OrderedDict()

                                self.importance = YList(self)
                                self._segment_path = lambda: "recurrence"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence, [], name, value)


                            class Importance(Entity):
                                """
                                Specify the importance at which the event 
                                should be sent when it recurs
                                
                                .. attribute:: range  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: at
                                
                                	Specify the time(s) this level setting should occur
                                	**type**\:  :py:class:`At <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence.Importance.At>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence.Importance, self).__init__()

                                    self.yang_name = "importance"
                                    self.yang_parent_name = "recurrence"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['range']
                                    self._child_classes = OrderedDict([("at", ("at", Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence.Importance.At))])
                                    self._leafs = OrderedDict([
                                        ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                    ])
                                    self.range = None

                                    self.at = Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence.Importance.At()
                                    self.at.parent = self
                                    self._children_name_map["at"] = "at"
                                    self._segment_path = lambda: "importance" + "[range='" + str(self.range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence.Importance, [u'range'], name, value)


                                class At(Entity):
                                    """
                                    Specify the time(s) this level setting should occur
                                    
                                    .. attribute:: minute
                                    
                                    	cron format of minute(s)
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..59
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [\*].\*
                                    
                                    .. attribute:: hour
                                    
                                    	cron format of hour(s)
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..23
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [\*].\*
                                    
                                    .. attribute:: day
                                    
                                    	cron format of day(s) of month
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..31
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [\*].\*
                                    
                                    .. attribute:: month
                                    
                                    	cron format of month(s)
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..12
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [\*].\*
                                    
                                    .. attribute:: weekday
                                    
                                    	cron format of weekday(s)
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..7
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [\*].\*
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence.Importance.At, self).__init__()

                                        self.yang_name = "at"
                                        self.yang_parent_name = "importance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minute', (YLeaf(YType.str, 'minute'), ['int','str'])),
                                            ('hour', (YLeaf(YType.str, 'hour'), ['int','str'])),
                                            ('day', (YLeaf(YType.str, 'day'), ['int','str'])),
                                            ('month', (YLeaf(YType.str, 'month'), ['int','str'])),
                                            ('weekday', (YLeaf(YType.str, 'weekday'), ['int','str'])),
                                        ])
                                        self.minute = None
                                        self.hour = None
                                        self.day = None
                                        self.month = None
                                        self.weekday = None
                                        self._segment_path = lambda: "at"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Energywise.Level.Recurrence.Importance.At, [u'minute', u'hour', u'day', u'month', u'weekday'], name, value)


                class Location(Entity):
                    """
                    Interface location information
                    
                    .. attribute:: civic_location_id
                    
                    	Civic location information
                    	**type**\:  :py:class:`CivicLocationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Location, self).__init__()

                        self.yang_name = "location"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("civic-location-id", ("civic_location_id", Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId))])
                        self._leafs = OrderedDict()

                        self.civic_location_id = Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId()
                        self.civic_location_id.parent = self
                        self._children_name_map["civic_location_id"] = "civic-location-id"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:location"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Location, [], name, value)


                    class CivicLocationId(Entity):
                        """
                        Civic location information
                        
                        .. attribute:: location_identifier
                        
                        	civic location identifier string
                        	**type**\: str
                        
                        .. attribute:: host
                        
                        	Globally defined host location identifer
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId.Host>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: none
                        
                        	No globally defined location identifer
                        	**type**\:  :py:class:`Y_None <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId.Y_None>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId, self).__init__()

                            self.yang_name = "civic-location-id"
                            self.yang_parent_name = "location"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId.Host)), ("none", ("none", Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId.Y_None))])
                            self._leafs = OrderedDict([
                                ('location_identifier', (YLeaf(YType.str, 'location-identifier'), ['str'])),
                            ])
                            self.location_identifier = None

                            self.host = None
                            self._children_name_map["host"] = "host"

                            self.none = None
                            self._children_name_map["none"] = "none"
                            self._segment_path = lambda: "civic-location-id"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId, [u'location_identifier'], name, value)


                        class Host(Entity):
                            """
                            Globally defined host location identifer
                            
                            .. attribute:: port_location
                            
                            	Port specific attributes
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "civic-location-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                                ])
                                self.port_location = None
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId.Host, [u'port_location'], name, value)


                        class Y_None(Entity):
                            """
                            No globally defined location identifer
                            
                            .. attribute:: port_location
                            
                            	Port specific attributes
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId.Y_None, self).__init__()

                                self.yang_name = "none"
                                self.yang_parent_name = "civic-location-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('port_location', (YLeaf(YType.str, 'port-location'), ['str'])),
                                ])
                                self.port_location = None
                                self._segment_path = lambda: "none"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Location.CivicLocationId.Y_None, [u'port_location'], name, value)


                class Mac(Entity):
                    """
                    MAC interface commands
                    
                    .. attribute:: access_group
                    
                    	MAC access\-group configuration commands
                    	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Mac.AccessGroup>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Mac, self).__init__()

                        self.yang_name = "mac"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.PortChannelSubinterface.PortChannel.Mac.AccessGroup))])
                        self._leafs = OrderedDict()

                        self.access_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:mac"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Mac, [], name, value)


                    class AccessGroup(Entity):
                        """
                        MAC access\-group configuration commands
                        
                        .. attribute:: direction  (key)
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Mac.AccessGroup.Direction>`
                        
                        .. attribute:: acl_name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Mac.AccessGroup, self).__init__()

                            self.yang_name = "access-group"
                            self.yang_parent_name = "mac"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['direction']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.PortChannelSubinterface.PortChannel.Mac.AccessGroup.Direction')])),
                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                            ])
                            self.direction = None
                            self.acl_name = None
                            self._segment_path = lambda: "access-group" + "[direction='" + str(self.direction) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Mac.AccessGroup, [u'direction', u'acl_name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: in_ = 0

                            .. data:: out = 1

                            """

                            in_ = Enum.YLeaf(0, "in")

                            out = Enum.YLeaf(1, "out")



                class Macro(Entity):
                    """
                    Command macro
                    
                    .. attribute:: description
                    
                    	Macro description for this interface
                    	**type**\: str
                    
                    .. attribute:: auto
                    
                    	Smartport interface macro configurations
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Macro, self).__init__()

                        self.yang_name = "macro"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto))])
                        self._leafs = OrderedDict([
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ])
                        self.description = None

                        self.auto = Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto()
                        self.auto.parent = self
                        self._children_name_map["auto"] = "auto"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:macro"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Macro, [u'description'], name, value)


                    class Auto(Entity):
                        """
                        Smartport interface macro configurations
                        
                        .. attribute:: processing
                        
                        	Enable smartport macro auto execution on this interface
                        	**type**\: bool
                        
                        .. attribute:: port
                        
                        	Provide interface specific configuration for macro processing
                        	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Port>`
                        
                        .. attribute:: control
                        
                        	Control macro auto execution
                        	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Control>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "macro"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("port", ("port", Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Port)), ("control", ("control", Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Control))])
                            self._leafs = OrderedDict([
                                ('processing', (YLeaf(YType.boolean, 'processing'), ['bool'])),
                            ])
                            self.processing = None

                            self.port = Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Port()
                            self.port.parent = self
                            self._children_name_map["port"] = "port"

                            self.control = Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Control()
                            self.control.parent = self
                            self._children_name_map["control"] = "control"
                            self._segment_path = lambda: "auto"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto, [u'processing'], name, value)


                        class Port(Entity):
                            """
                            Provide interface specific configuration for macro processing
                            
                            .. attribute:: sticky
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Port, self).__init__()

                                self.yang_name = "port"
                                self.yang_parent_name = "auto"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                ])
                                self.sticky = None
                                self._segment_path = lambda: "port"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Port, [u'sticky'], name, value)


                        class Control(Entity):
                            """
                            Control macro auto execution
                            
                            .. attribute:: device
                            
                            	Enable macro auto execution for devices
                            	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Control.Device>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Control, self).__init__()

                                self.yang_name = "control"
                                self.yang_parent_name = "auto"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("device", ("device", Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Control.Device))])
                                self._leafs = OrderedDict()

                                self.device = Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Control.Device()
                                self.device.parent = self
                                self._children_name_map["device"] = "device"
                                self._segment_path = lambda: "control"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Control, [], name, value)


                            class Device(Entity):
                                """
                                Enable macro auto execution for devices
                                
                                .. attribute:: phone
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Control.Device, self).__init__()

                                    self.yang_name = "device"
                                    self.yang_parent_name = "control"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('phone', (YLeaf(YType.empty, 'phone'), ['Empty'])),
                                    ])
                                    self.phone = None
                                    self._segment_path = lambda: "device"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Macro.Auto.Control.Device, [u'phone'], name, value)


                class DualActive(Entity):
                    """
                    
                    
                    .. attribute:: fast_hello
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.DualActive, self).__init__()

                        self.yang_name = "dual-active"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fast_hello', (YLeaf(YType.empty, 'fast-hello'), ['Empty'])),
                        ])
                        self.fast_hello = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:dual-active"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.DualActive, [u'fast_hello'], name, value)


                class LoadBalancing(Entity):
                    """
                    Etherchannel Load\-Balancing
                    
                    .. attribute:: flow
                    
                    	Based on the traffic flows identified by the packet headers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vlan
                    
                    	Based on the VLAN to member links manual configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.LoadBalancing, self).__init__()

                        self.yang_name = "load-balancing"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('flow', (YLeaf(YType.empty, 'flow'), ['Empty'])),
                            ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                        ])
                        self.flow = None
                        self.vlan = None
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:load-balancing"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.LoadBalancing, [u'flow', u'vlan'], name, value)


                class VlanRange(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..4096
                    
                    		**type**\: str
                    
                    .. attribute:: service_policy
                    
                    	Configure QoS Service Policy
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.VlanRange.ServicePolicy>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.VlanRange, self).__init__()

                        self.yang_name = "vlan-range"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.PortChannelSubinterface.PortChannel.VlanRange.ServicePolicy))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                        ])
                        self.id = None

                        self.service_policy = Native.Interface.PortChannelSubinterface.PortChannel.VlanRange.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:vlan-range" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.VlanRange, [u'id'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Configure QoS Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\: str
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.VlanRange.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "vlan-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.str, 'input'), ['str'])),
                                ('output', (YLeaf(YType.str, 'output'), ['str'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.VlanRange.ServicePolicy, [u'input', u'output'], name, value)


                class Switch(Entity):
                    """
                    
                    
                    .. attribute:: virtual
                    
                    	
                    	**type**\:  :py:class:`Virtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.Switch.Virtual>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.Switch, self).__init__()

                        self.yang_name = "switch"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("virtual", ("virtual", Native.Interface.PortChannelSubinterface.PortChannel.Switch.Virtual))])
                        self._leafs = OrderedDict()

                        self.virtual = Native.Interface.PortChannelSubinterface.PortChannel.Switch.Virtual()
                        self.virtual.parent = self
                        self._children_name_map["virtual"] = "virtual"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:switch"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switch, [], name, value)


                    class Virtual(Entity):
                        """
                        
                        
                        .. attribute:: link
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.Switch.Virtual, self).__init__()

                            self.yang_name = "virtual"
                            self.yang_parent_name = "switch"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                            ])
                            self.link = None
                            self._segment_path = lambda: "virtual"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.Switch.Virtual, [u'link'], name, value)


                class SrrQueue(Entity):
                    """
                    
                    
                    .. attribute:: bandwidth
                    
                    	
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue, self).__init__()

                        self.yang_name = "srr-queue"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth))])
                        self._leafs = OrderedDict()

                        self.bandwidth = Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth()
                        self.bandwidth.parent = self
                        self._children_name_map["bandwidth"] = "bandwidth"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:srr-queue"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue, [], name, value)


                    class Bandwidth(Entity):
                        """
                        
                        
                        .. attribute:: shape
                        
                        	
                        	**type**\:  :py:class:`Shape <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth.Shape>`
                        
                        .. attribute:: share
                        
                        	
                        	**type**\:  :py:class:`Share <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth.Share>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "srr-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("shape", ("shape", Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth.Shape)), ("share", ("share", Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth.Share))])
                            self._leafs = OrderedDict()

                            self.shape = Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth.Shape()
                            self.shape.parent = self
                            self._children_name_map["shape"] = "shape"

                            self.share = Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth.Share()
                            self.share.parent = self
                            self._children_name_map["share"] = "share"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth, [], name, value)


                        class Shape(Entity):
                            """
                            
                            
                            .. attribute:: weight1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: weight2
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: weight3
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: weight4
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth.Shape, self).__init__()

                                self.yang_name = "shape"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('weight1', (YLeaf(YType.uint16, 'weight1'), ['int'])),
                                    ('weight2', (YLeaf(YType.uint16, 'weight2'), ['int'])),
                                    ('weight3', (YLeaf(YType.uint16, 'weight3'), ['int'])),
                                    ('weight4', (YLeaf(YType.uint16, 'weight4'), ['int'])),
                                ])
                                self.weight1 = None
                                self.weight2 = None
                                self.weight3 = None
                                self.weight4 = None
                                self._segment_path = lambda: "shape"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth.Shape, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


                        class Share(Entity):
                            """
                            
                            
                            .. attribute:: weight1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: weight2
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: weight3
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: weight4
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth.Share, self).__init__()

                                self.yang_name = "share"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('weight1', (YLeaf(YType.uint8, 'weight1'), ['int'])),
                                    ('weight2', (YLeaf(YType.uint8, 'weight2'), ['int'])),
                                    ('weight3', (YLeaf(YType.uint8, 'weight3'), ['int'])),
                                    ('weight4', (YLeaf(YType.uint8, 'weight4'), ['int'])),
                                ])
                                self.weight1 = None
                                self.weight2 = None
                                self.weight3 = None
                                self.weight4 = None
                                self._segment_path = lambda: "share"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.SrrQueue.Bandwidth.Share, [u'weight1', u'weight2', u'weight3', u'weight4'], name, value)


                class MacsecOption(Entity):
                    """
                    Enable macsec on the interface
                    
                    .. attribute:: macsec
                    
                    	
                    	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption.Macsec>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption, self).__init__()

                        self.yang_name = "macsec-option"
                        self.yang_parent_name = "Port-channel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("macsec", ("macsec", Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption.Macsec))])
                        self._leafs = OrderedDict()

                        self.macsec = Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption.Macsec()
                        self.macsec.parent = self
                        self._children_name_map["macsec"] = "macsec"
                        self._segment_path = lambda: "Cisco-IOS-XE-switch:macsec-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption, [], name, value)


                    class Macsec(Entity):
                        """
                        
                        
                        .. attribute:: replay_protection
                        
                        	Set replay\-protection
                        	**type**\:  :py:class:`ReplayProtection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption.Macsec.ReplayProtection>`
                        
                        .. attribute:: network_link
                        
                        	Enable macsec on switch connected interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption.Macsec, self).__init__()

                            self.yang_name = "macsec"
                            self.yang_parent_name = "macsec-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("replay-protection", ("replay_protection", Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption.Macsec.ReplayProtection))])
                            self._leafs = OrderedDict([
                                ('network_link', (YLeaf(YType.empty, 'network-link'), ['Empty'])),
                            ])
                            self.network_link = None

                            self.replay_protection = Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption.Macsec.ReplayProtection()
                            self.replay_protection.parent = self
                            self._children_name_map["replay_protection"] = "replay-protection"
                            self._segment_path = lambda: "macsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption.Macsec, [u'network_link'], name, value)


                        class ReplayProtection(Entity):
                            """
                            Set replay\-protection
                            
                            .. attribute:: window_size
                            
                            	Set replay window\-size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption.Macsec.ReplayProtection, self).__init__()

                                self.yang_name = "replay-protection"
                                self.yang_parent_name = "macsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('window_size', (YLeaf(YType.uint32, 'window-size'), ['int'])),
                                ])
                                self.window_size = None
                                self._segment_path = lambda: "replay-protection"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.PortChannelSubinterface.PortChannel.MacsecOption.Macsec.ReplayProtection, [u'window_size'], name, value)


        class Pseudowire(Entity):
            """
            Pseudowire Interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..231072
            
            .. attribute:: encapsulation
            
            	Data encapsulation method
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Encapsulation>`
            
            .. attribute:: ip
            
            	Specify IP parameters
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Ip>`
            
            .. attribute:: control_word
            
            	Include control\-word in pseudowire packets
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: interworking
            
            	Interworking options for pseudowire
            	**type**\:  :py:class:`Interworking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Interworking>`
            
            .. attribute:: load_balance
            
            	Loadbalancing for pseudowire
            	**type**\:  :py:class:`LoadBalance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.LoadBalance>`
            
            .. attribute:: monitor
            
            	Active monitoring of xconnect peer
            	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Monitor>`
            
            .. attribute:: preferred_path
            
            	Preferred path
            	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.PreferredPath>`
            
            .. attribute:: protocol_mpls
            
            	
            	**type**\:  :py:class:`ProtocolMpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.ProtocolMpls>`
            
            .. attribute:: protocol_l2tpv2
            
            	
            	**type**\:  :py:class:`ProtocolL2tpv2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.ProtocolL2tpv2>`
            
            .. attribute:: protocol_l2tpv3
            
            	
            	**type**\:  :py:class:`ProtocolL2tpv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.ProtocolL2tpv3>`
            
            .. attribute:: sequencing
            
            	Sequencing options for pseudowire
            	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Sequencing>`
            
            .. attribute:: status
            
            	Pseudowire status capabilities
            	**type**\:  :py:class:`Status <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Status>`
            
            	**presence node**\: True
            
            .. attribute:: switching
            
            	Switching TLV on/off for pseudowire
            	**type**\:  :py:class:`Switching <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Switching>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Pseudowire, self).__init__()

                self.yang_name = "pseudowire"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("Cisco-IOS-XE-l2vpn:ip", ("ip", Native.Interface.Pseudowire.Ip)), ("Cisco-IOS-XE-l2vpn:load-balance", ("load_balance", Native.Interface.Pseudowire.LoadBalance)), ("Cisco-IOS-XE-l2vpn:monitor", ("monitor", Native.Interface.Pseudowire.Monitor)), ("Cisco-IOS-XE-l2vpn:preferred-path", ("preferred_path", Native.Interface.Pseudowire.PreferredPath)), ("Cisco-IOS-XE-l2vpn:protocol-mpls", ("protocol_mpls", Native.Interface.Pseudowire.ProtocolMpls)), ("Cisco-IOS-XE-l2vpn:protocol-l2tpv2", ("protocol_l2tpv2", Native.Interface.Pseudowire.ProtocolL2tpv2)), ("Cisco-IOS-XE-l2vpn:protocol-l2tpv3", ("protocol_l2tpv3", Native.Interface.Pseudowire.ProtocolL2tpv3)), ("Cisco-IOS-XE-l2vpn:status", ("status", Native.Interface.Pseudowire.Status)), ("Cisco-IOS-XE-l2vpn:switching", ("switching", Native.Interface.Pseudowire.Switching))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint32, 'name'), ['int'])),
                    ('encapsulation', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-l2vpn:encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Pseudowire.Encapsulation')])),
                    ('control_word', (YLeaf(YType.empty, 'Cisco-IOS-XE-l2vpn:control-word'), ['Empty'])),
                    ('interworking', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-l2vpn:interworking'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Pseudowire.Interworking')])),
                    ('sequencing', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-l2vpn:sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Pseudowire.Sequencing')])),
                ])
                self.name = None
                self.encapsulation = None
                self.control_word = None
                self.interworking = None
                self.sequencing = None

                self.ip = Native.Interface.Pseudowire.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "Cisco-IOS-XE-l2vpn:ip"

                self.load_balance = Native.Interface.Pseudowire.LoadBalance()
                self.load_balance.parent = self
                self._children_name_map["load_balance"] = "Cisco-IOS-XE-l2vpn:load-balance"

                self.monitor = Native.Interface.Pseudowire.Monitor()
                self.monitor.parent = self
                self._children_name_map["monitor"] = "Cisco-IOS-XE-l2vpn:monitor"

                self.preferred_path = Native.Interface.Pseudowire.PreferredPath()
                self.preferred_path.parent = self
                self._children_name_map["preferred_path"] = "Cisco-IOS-XE-l2vpn:preferred-path"

                self.protocol_mpls = Native.Interface.Pseudowire.ProtocolMpls()
                self.protocol_mpls.parent = self
                self._children_name_map["protocol_mpls"] = "Cisco-IOS-XE-l2vpn:protocol-mpls"

                self.protocol_l2tpv2 = Native.Interface.Pseudowire.ProtocolL2tpv2()
                self.protocol_l2tpv2.parent = self
                self._children_name_map["protocol_l2tpv2"] = "Cisco-IOS-XE-l2vpn:protocol-l2tpv2"

                self.protocol_l2tpv3 = Native.Interface.Pseudowire.ProtocolL2tpv3()
                self.protocol_l2tpv3.parent = self
                self._children_name_map["protocol_l2tpv3"] = "Cisco-IOS-XE-l2vpn:protocol-l2tpv3"

                self.status = None
                self._children_name_map["status"] = "Cisco-IOS-XE-l2vpn:status"

                self.switching = Native.Interface.Pseudowire.Switching()
                self.switching.parent = self
                self._children_name_map["switching"] = "Cisco-IOS-XE-l2vpn:switching"
                self._segment_path = lambda: "pseudowire" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Pseudowire, [u'name', 'encapsulation', 'control_word', 'interworking', 'sequencing'], name, value)

            class Encapsulation(Enum):
                """
                Encapsulation (Enum Class)

                Data encapsulation method

                .. data:: l2tpv2 = 0

                .. data:: l2tpv3 = 1

                .. data:: mpls = 2

                .. data:: udp = 3

                """

                l2tpv2 = Enum.YLeaf(0, "l2tpv2")

                l2tpv3 = Enum.YLeaf(1, "l2tpv3")

                mpls = Enum.YLeaf(2, "mpls")

                udp = Enum.YLeaf(3, "udp")


            class Interworking(Enum):
                """
                Interworking (Enum Class)

                Interworking options for pseudowire

                .. data:: ethernet = 0

                .. data:: ip = 1

                .. data:: vlan = 2

                """

                ethernet = Enum.YLeaf(0, "ethernet")

                ip = Enum.YLeaf(1, "ip")

                vlan = Enum.YLeaf(2, "vlan")


            class Sequencing(Enum):
                """
                Sequencing (Enum Class)

                Sequencing options for pseudowire

                .. data:: both = 0

                .. data:: receive = 1

                .. data:: resync = 2

                .. data:: transmit = 3

                """

                both = Enum.YLeaf(0, "both")

                receive = Enum.YLeaf(1, "receive")

                resync = Enum.YLeaf(2, "resync")

                transmit = Enum.YLeaf(3, "transmit")



            class Ip(Entity):
                """
                Specify IP parameters
                
                .. attribute:: dfbit
                
                	DF bit options for tunnel
                	**type**\:  :py:class:`Dfbit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Ip.Dfbit>`
                
                .. attribute:: local
                
                	Specify local information
                	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Ip.Local>`
                
                .. attribute:: pmtu
                
                	Enable Path MTU for tunnel
                	**type**\:  :py:class:`Pmtu <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Ip.Pmtu>`
                
                	**presence node**\: True
                
                .. attribute:: protocol
                
                	Specific IP protocol number to use
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Ip.Protocol>`
                
                .. attribute:: tos
                
                	Specify ToS options for IP tunnel header
                	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Ip.Tos>`
                
                .. attribute:: ttl
                
                	Specify TTL value for IP tunnel header
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.Pseudowire.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dfbit", ("dfbit", Native.Interface.Pseudowire.Ip.Dfbit)), ("local", ("local", Native.Interface.Pseudowire.Ip.Local)), ("pmtu", ("pmtu", Native.Interface.Pseudowire.Ip.Pmtu)), ("tos", ("tos", Native.Interface.Pseudowire.Ip.Tos))])
                    self._leafs = OrderedDict([
                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Pseudowire.Ip.Protocol')])),
                        ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                    ])
                    self.protocol = None
                    self.ttl = None

                    self.dfbit = Native.Interface.Pseudowire.Ip.Dfbit()
                    self.dfbit.parent = self
                    self._children_name_map["dfbit"] = "dfbit"

                    self.local = Native.Interface.Pseudowire.Ip.Local()
                    self.local.parent = self
                    self._children_name_map["local"] = "local"

                    self.pmtu = None
                    self._children_name_map["pmtu"] = "pmtu"

                    self.tos = Native.Interface.Pseudowire.Ip.Tos()
                    self.tos.parent = self
                    self._children_name_map["tos"] = "tos"
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Pseudowire.Ip, ['protocol', 'ttl'], name, value)

                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Specific IP protocol number to use

                    .. data:: l2tp = 0

                    .. data:: uti = 1

                    """

                    l2tp = Enum.YLeaf(0, "l2tp")

                    uti = Enum.YLeaf(1, "uti")



                class Dfbit(Entity):
                    """
                    DF bit options for tunnel
                    
                    .. attribute:: set
                    
                    	Set the DF bit in the tunnel header
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.Ip.Dfbit, self).__init__()

                        self.yang_name = "dfbit"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('set', (YLeaf(YType.empty, 'set'), ['Empty'])),
                        ])
                        self.set = None
                        self._segment_path = lambda: "dfbit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.Ip.Dfbit, ['set'], name, value)


                class Local(Entity):
                    """
                    Specify local information
                    
                    .. attribute:: interface
                    
                    	Source interface for pseudowire
                    	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Ip.Local.Interface_>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.Ip.Local, self).__init__()

                        self.yang_name = "local"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Native.Interface.Pseudowire.Ip.Local.Interface_))])
                        self._leafs = OrderedDict()

                        self.interface = Native.Interface.Pseudowire.Ip.Local.Interface_()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._segment_path = lambda: "local"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.Ip.Local, [], name, value)


                    class Interface_(Entity):
                        """
                        Source interface for pseudowire
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Ip.Local.Interface_.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Ip.Local.Interface_.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Ip.Local.Interface_.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Ip.Local.Interface_.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.Pseudowire.Ip.Local.Interface_, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "local"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Pseudowire.Ip.Local.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Pseudowire.Ip.Local.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Pseudowire.Ip.Local.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Pseudowire.Ip.Local.Interface_.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Interface.Pseudowire.Ip.Local.Interface_.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Interface.Pseudowire.Ip.Local.Interface_.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Interface.Pseudowire.Ip.Local.Interface_.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Interface.Pseudowire.Ip.Local.Interface_.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Pseudowire.Ip.Local.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.Pseudowire.Ip.Local.Interface_.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Pseudowire.Ip.Local.Interface_.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.Pseudowire.Ip.Local.Interface_.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Pseudowire.Ip.Local.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.Pseudowire.Ip.Local.Interface_.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Pseudowire.Ip.Local.Interface_.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.Pseudowire.Ip.Local.Interface_.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Pseudowire.Ip.Local.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Pmtu(Entity):
                    """
                    Enable Path MTU for tunnel
                    
                    .. attribute:: max
                    
                    	Maximum Path MTU for session
                    	**type**\: int
                    
                    	**range:** 68..65535
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.Ip.Pmtu, self).__init__()

                        self.yang_name = "pmtu"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                        ])
                        self.max = None
                        self._segment_path = lambda: "pmtu"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.Ip.Pmtu, ['max'], name, value)


                class Tos(Entity):
                    """
                    Specify ToS options for IP tunnel header
                    
                    .. attribute:: reflect
                    
                    	Reflect IP payload ToS on tunnel
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: value
                    
                    	IP ToS value
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.Ip.Tos, self).__init__()

                        self.yang_name = "tos"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('reflect', (YLeaf(YType.empty, 'reflect'), ['Empty'])),
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.reflect = None
                        self.value = None
                        self._segment_path = lambda: "tos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.Ip.Tos, ['reflect', 'value'], name, value)


            class LoadBalance(Entity):
                """
                Loadbalancing for pseudowire
                
                .. attribute:: flow
                
                	Enable flow based load balancing for pseudowire
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.LoadBalance.Flow>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.Pseudowire.LoadBalance, self).__init__()

                    self.yang_name = "load-balance"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flow", ("flow", Native.Interface.Pseudowire.LoadBalance.Flow))])
                    self._leafs = OrderedDict()

                    self.flow = None
                    self._children_name_map["flow"] = "flow"
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:load-balance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Pseudowire.LoadBalance, [], name, value)


                class Flow(Entity):
                    """
                    Enable flow based load balancing for pseudowire
                    
                    .. attribute:: ethernet
                    
                    	Ethernet pseudowire flow classification
                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.LoadBalance.Flow.Ethernet>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.LoadBalance.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "load-balance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ethernet', (YLeaf(YType.enumeration, 'ethernet'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Pseudowire.LoadBalance.Flow.Ethernet')])),
                        ])
                        self.ethernet = None
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.LoadBalance.Flow, ['ethernet'], name, value)

                    class Ethernet(Enum):
                        """
                        Ethernet (Enum Class)

                        Ethernet pseudowire flow classification

                        .. data:: dst_mac = 0

                        .. data:: src_dst_mac = 1

                        .. data:: src_mac = 2

                        """

                        dst_mac = Enum.YLeaf(0, "dst-mac")

                        src_dst_mac = Enum.YLeaf(1, "src-dst-mac")

                        src_mac = Enum.YLeaf(2, "src-mac")



            class Monitor(Entity):
                """
                Active monitoring of xconnect peer
                
                .. attribute:: peer
                
                	Active monitoring of xconnect peer
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Monitor.Peer>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.Pseudowire.Monitor, self).__init__()

                    self.yang_name = "monitor"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("peer", ("peer", Native.Interface.Pseudowire.Monitor.Peer))])
                    self._leafs = OrderedDict()

                    self.peer = Native.Interface.Pseudowire.Monitor.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:monitor"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Pseudowire.Monitor, [], name, value)


                class Peer(Entity):
                    """
                    Active monitoring of xconnect peer
                    
                    .. attribute:: bfd
                    
                    	BFD active monitoring for the xconnect peer
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Monitor.Peer.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.Monitor.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "monitor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bfd", ("bfd", Native.Interface.Pseudowire.Monitor.Peer.Bfd))])
                        self._leafs = OrderedDict()

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "peer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.Monitor.Peer, [], name, value)


                    class Bfd(Entity):
                        """
                        BFD active monitoring for the xconnect peer
                        
                        .. attribute:: local
                        
                        	Specify local endpoint information to map to a BFD session
                        	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.Pseudowire.Monitor.Peer.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("local", ("local", Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.local = Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local()
                            self.local.parent = self
                            self._children_name_map["local"] = "local"
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Pseudowire.Monitor.Peer.Bfd, [], name, value)


                        class Local(Entity):
                            """
                            Specify local endpoint information to map to a BFD session
                            
                            .. attribute:: interface
                            
                            	Source interface for pseudowire
                            	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local, self).__init__()

                                self.yang_name = "local"
                                self.yang_parent_name = "bfd"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_))])
                                self._leafs = OrderedDict()

                                self.interface = Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._segment_path = lambda: "local"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local, [], name, value)


                            class Interface_(Entity):
                                """
                                Source interface for pseudowire
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "local"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Pseudowire.Monitor.Peer.Bfd.Local.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


            class PreferredPath(Entity):
                """
                Preferred path
                
                .. attribute:: interface
                
                	Output Interface
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.PreferredPath.Interface_>`
                
                .. attribute:: peer_container
                
                	
                	**type**\:  :py:class:`PeerContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.PreferredPath.PeerContainer>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.Pseudowire.PreferredPath, self).__init__()

                    self.yang_name = "preferred-path"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Native.Interface.Pseudowire.PreferredPath.Interface_)), ("peer-container", ("peer_container", Native.Interface.Pseudowire.PreferredPath.PeerContainer))])
                    self._leafs = OrderedDict()

                    self.interface = Native.Interface.Pseudowire.PreferredPath.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.peer_container = Native.Interface.Pseudowire.PreferredPath.PeerContainer()
                    self.peer_container.parent = self
                    self._children_name_map["peer_container"] = "peer-container"
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:preferred-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Pseudowire.PreferredPath, [], name, value)


                class Interface_(Entity):
                    """
                    Output Interface
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..2147483647
                    
                    .. attribute:: tunnel_tp
                    
                    	MPLS Transport Profile interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: disable_fallback
                    
                    	disable fall back to alternative route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.PreferredPath.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "preferred-path"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel', (YLeaf(YType.uint64, 'Tunnel'), ['int'])),
                            ('tunnel_tp', (YLeaf(YType.uint16, 'Tunnel-tp'), ['int'])),
                            ('disable_fallback', (YLeaf(YType.empty, 'disable-fallback'), ['Empty'])),
                        ])
                        self.tunnel = None
                        self.tunnel_tp = None
                        self.disable_fallback = None
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.PreferredPath.Interface_, ['tunnel', 'tunnel_tp', 'disable_fallback'], name, value)


                class PeerContainer(Entity):
                    """
                    
                    
                    .. attribute:: peer
                    
                    	Peer Address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: disable_fallback
                    
                    	disable fall back to alternative route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.PreferredPath.PeerContainer, self).__init__()

                        self.yang_name = "peer-container"
                        self.yang_parent_name = "preferred-path"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('peer', (YLeaf(YType.str, 'peer'), ['str','str'])),
                            ('disable_fallback', (YLeaf(YType.empty, 'disable-fallback'), ['Empty'])),
                        ])
                        self.peer = None
                        self.disable_fallback = None
                        self._segment_path = lambda: "peer-container"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.PreferredPath.PeerContainer, ['peer', 'disable_fallback'], name, value)


            class ProtocolMpls(Entity):
                """
                
                
                .. attribute:: protocol
                
                	Signaling protocol to use
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.ProtocolMpls.Protocol>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.Pseudowire.ProtocolMpls, self).__init__()

                    self.yang_name = "protocol-mpls"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Pseudowire.ProtocolMpls.Protocol')])),
                    ])
                    self.protocol = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:protocol-mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Pseudowire.ProtocolMpls, ['protocol'], name, value)

                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Signaling protocol to use

                    .. data:: ldp = 0

                    .. data:: none = 1

                    """

                    ldp = Enum.YLeaf(0, "ldp")

                    none = Enum.YLeaf(1, "none")



            class ProtocolL2tpv2(Entity):
                """
                
                
                .. attribute:: protocol
                
                	Signaling protocol to use
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.ProtocolL2tpv2.Protocol>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.Pseudowire.ProtocolL2tpv2, self).__init__()

                    self.yang_name = "protocol-l2tpv2"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Pseudowire.ProtocolL2tpv2.Protocol')])),
                    ])
                    self.protocol = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:protocol-l2tpv2"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Pseudowire.ProtocolL2tpv2, ['protocol'], name, value)

                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Signaling protocol to use

                    .. data:: l2tpv2 = 0

                    .. data:: none = 1

                    """

                    l2tpv2 = Enum.YLeaf(0, "l2tpv2")

                    none = Enum.YLeaf(1, "none")



            class ProtocolL2tpv3(Entity):
                """
                
                
                .. attribute:: protocol
                
                	Signaling protocol to use
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.ProtocolL2tpv3.Protocol>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.Pseudowire.ProtocolL2tpv3, self).__init__()

                    self.yang_name = "protocol-l2tpv3"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Pseudowire.ProtocolL2tpv3.Protocol')])),
                    ])
                    self.protocol = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:protocol-l2tpv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Pseudowire.ProtocolL2tpv3, ['protocol'], name, value)

                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Signaling protocol to use

                    .. data:: l2tpv3 = 0

                    .. data:: l2tpv3ietf = 1

                    .. data:: none = 2

                    """

                    l2tpv3 = Enum.YLeaf(0, "l2tpv3")

                    l2tpv3ietf = Enum.YLeaf(1, "l2tpv3ietf")

                    none = Enum.YLeaf(2, "none")



            class Status(Entity):
                """
                Pseudowire status capabilities
                
                .. attribute:: admin_down
                
                	Admin down of Attachment Circuit
                	**type**\:  :py:class:`AdminDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Status.AdminDown>`
                
                .. attribute:: control_plane
                
                	control plane status events
                	**type**\:  :py:class:`ControlPlane <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Status.ControlPlane>`
                
                .. attribute:: decoupled
                
                	Reflect standby status of the attachment circuit as up on the pseudowire
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: peer
                
                	peer status configuration
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Status.Peer>`
                
                .. attribute:: redundancy
                
                	Xconnect redundancy configuration
                	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Status.Redundancy>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.Pseudowire.Status, self).__init__()

                    self.yang_name = "status"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("admin-down", ("admin_down", Native.Interface.Pseudowire.Status.AdminDown)), ("control-plane", ("control_plane", Native.Interface.Pseudowire.Status.ControlPlane)), ("peer", ("peer", Native.Interface.Pseudowire.Status.Peer)), ("redundancy", ("redundancy", Native.Interface.Pseudowire.Status.Redundancy))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('decoupled', (YLeaf(YType.empty, 'decoupled'), ['Empty'])),
                    ])
                    self.decoupled = None

                    self.admin_down = Native.Interface.Pseudowire.Status.AdminDown()
                    self.admin_down.parent = self
                    self._children_name_map["admin_down"] = "admin-down"

                    self.control_plane = Native.Interface.Pseudowire.Status.ControlPlane()
                    self.control_plane.parent = self
                    self._children_name_map["control_plane"] = "control-plane"

                    self.peer = Native.Interface.Pseudowire.Status.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"

                    self.redundancy = Native.Interface.Pseudowire.Status.Redundancy()
                    self.redundancy.parent = self
                    self._children_name_map["redundancy"] = "redundancy"
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:status"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Pseudowire.Status, ['decoupled'], name, value)


                class AdminDown(Entity):
                    """
                    Admin down of Attachment Circuit
                    
                    .. attribute:: disconnect
                    
                    	Disconnect the session
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.Status.AdminDown, self).__init__()

                        self.yang_name = "admin-down"
                        self.yang_parent_name = "status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disconnect', (YLeaf(YType.empty, 'disconnect'), ['Empty'])),
                        ])
                        self.disconnect = None
                        self._segment_path = lambda: "admin-down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.Status.AdminDown, ['disconnect'], name, value)


                class ControlPlane(Entity):
                    """
                    control plane status events
                    
                    .. attribute:: route_watch
                    
                    	listen on the control plane to route\-watch events
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.Status.ControlPlane, self).__init__()

                        self.yang_name = "control-plane"
                        self.yang_parent_name = "status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_watch', (YLeaf(YType.empty, 'route-watch'), ['Empty'])),
                        ])
                        self.route_watch = None
                        self._segment_path = lambda: "control-plane"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.Status.ControlPlane, ['route_watch'], name, value)


                class Peer(Entity):
                    """
                    peer status configuration
                    
                    .. attribute:: topology
                    
                    	change status behaviour based on peer topology
                    	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Pseudowire.Status.Peer.Topology>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.Status.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology", ("topology", Native.Interface.Pseudowire.Status.Peer.Topology))])
                        self._leafs = OrderedDict()

                        self.topology = Native.Interface.Pseudowire.Status.Peer.Topology()
                        self.topology.parent = self
                        self._children_name_map["topology"] = "topology"
                        self._segment_path = lambda: "peer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.Status.Peer, [], name, value)


                    class Topology(Entity):
                        """
                        change status behaviour based on peer topology
                        
                        .. attribute:: dual_homed
                        
                        	Our peer(s) are participating in a redundant solution with some form of redundancyprotocol running between the peer routers, Only one of the remote peers will advertise astatus of UP at a time. The other will advertise standby. Change our configuration so wecan send a status of UP on both active and redundant pseudowires
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.Interface.Pseudowire.Status.Peer.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dual_homed', (YLeaf(YType.empty, 'dual-homed'), ['Empty'])),
                            ])
                            self.dual_homed = None
                            self._segment_path = lambda: "topology"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Pseudowire.Status.Peer.Topology, ['dual_homed'], name, value)


                class Redundancy(Entity):
                    """
                    Xconnect redundancy configuration
                    
                    .. attribute:: master
                    
                    	Put the xconnect redundancy group on this node in master mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.Interface.Pseudowire.Status.Redundancy, self).__init__()

                        self.yang_name = "redundancy"
                        self.yang_parent_name = "status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('master', (YLeaf(YType.empty, 'master'), ['Empty'])),
                        ])
                        self.master = None
                        self._segment_path = lambda: "redundancy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Pseudowire.Status.Redundancy, ['master'], name, value)


            class Switching(Entity):
                """
                Switching TLV on/off for pseudowire
                
                .. attribute:: tlv
                
                	Switching TLV on/off for pseudowire
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Interface.Pseudowire.Switching, self).__init__()

                    self.yang_name = "switching"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('tlv', (YLeaf(YType.empty, 'tlv'), ['Empty'])),
                    ])
                    self.tlv = None
                    self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:switching"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Pseudowire.Switching, ['tlv'], name, value)


        class SM(Entity):
            """
            SM Interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            	**pattern:** ([0\-9])+(/([0\-9])+)?
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.PmPath>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.SM, self).__init__()

                self.yang_name = "SM"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.SM.SwitchportConf)), ("switchport", ("switchport", Native.Interface.SM.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.SM.StackwiseVirtual)), ("arp", ("arp", Native.Interface.SM.Arp)), ("backup", ("backup", Native.Interface.SM.Backup)), ("cemoudp", ("cemoudp", Native.Interface.SM.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.SM.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.SM.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.SM.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.SM.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.SM.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.SM.Flowcontrol)), ("isis", ("isis", Native.Interface.SM.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.SM.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.SM.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.SM.Bandwidth)), ("dampening", ("dampening", Native.Interface.SM.Dampening)), ("domain", ("domain", Native.Interface.SM.Domain)), ("hold-queue", ("hold_queue", Native.Interface.SM.HoldQueue)), ("mpls", ("mpls", Native.Interface.SM.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.SM.IpVrf)), ("vrf", ("vrf", Native.Interface.SM.Vrf)), ("ip", ("ip", Native.Interface.SM.Ip)), ("ipv6", ("ipv6", Native.Interface.SM.Ipv6)), ("logging", ("logging", Native.Interface.SM.Logging)), ("mdix", ("mdix", Native.Interface.SM.Mdix)), ("mop", ("mop", Native.Interface.SM.Mop)), ("interface_qos", ("interface_qos", Native.Interface.SM.InterfaceQos)), ("source", ("source", Native.Interface.SM.Source)), ("standby", ("standby", Native.Interface.SM.Standby)), ("access-session", ("access_session", Native.Interface.SM.AccessSession)), ("storm-control", ("storm_control", Native.Interface.SM.StormControl)), ("trust", ("trust", Native.Interface.SM.Trust)), ("priority-queue", ("priority_queue", Native.Interface.SM.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.SM.RcvQueue)), ("peer", ("peer", Native.Interface.SM.Peer)), ("pm-path", ("pm_path", Native.Interface.SM.PmPath))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.SM.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.SM.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.SM.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.SM.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.SM.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.SM.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.SM.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.SM.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.SM.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.SM.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.SM.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.SM.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.SM.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.SM.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.SM.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.SM.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.SM.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.SM.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.SM.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.SM.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.SM.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.SM.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.SM.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.SM.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.SM.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.SM.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.SM.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.SM.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.SM.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.SM.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.SM.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.SM.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.SM.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.SM.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.SM.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "SM" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.SM, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.SM.Backup.Delay)), ("interface", ("interface", Native.Interface.SM.Backup.Interface_)), ("load", ("load", Native.Interface.SM.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.SM.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.SM.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.SM.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.SM.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.SM.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.SM.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.SM.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.SM.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.SM.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.SM.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.SM.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.SM.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.SM.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.SM.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.SM.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.SM.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.SM.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.SM.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.SM.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.SM.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.SM.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.SM.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.SM.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.SM.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.SM.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.SM.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.SM.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.SM.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.SM.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.SM.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.SM.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.SM.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.SM.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.SM.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.SM.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.SM.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.SM.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.SM.Ip.Arp)), ("vrf", ("vrf", Native.Interface.SM.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.SM.Ip.NoAddress)), ("address", ("address", Native.Interface.SM.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.SM.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.SM.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.SM.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.SM.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.SM.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.SM.Ip.Pim)), ("policy", ("policy", Native.Interface.SM.Ip.Policy)), ("rip", ("rip", Native.Interface.SM.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.SM.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.SM.Ip.RouteCache)), ("router", ("router", Native.Interface.SM.Ip.Router)), ("tcp", ("tcp", Native.Interface.SM.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.SM.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.SM.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.SM.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.SM.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.SM.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.SM.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.SM.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.SM.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.SM.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.SM.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.SM.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.SM.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.SM.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.SM.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.SM.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.SM.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.SM.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.SM.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.SM.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.SM.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.SM.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.SM.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.SM.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.SM.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.SM.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.SM.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.SM.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.SM.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.SM.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.SM.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.SM.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.SM.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.SM.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.SM.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.SM.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.SM.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.SM.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.SM.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.SM.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.SM.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.SM.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.SM.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.SM.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.SM.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.SM.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.SM.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.SM.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.SM.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.SM.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.SM.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.SM.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.SM.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.SM.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.SM.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.SM.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.SM.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.SM.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.SM.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.SM.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.SM.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.SM.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.SM.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.SM.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.SM.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.SM.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.SM.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.SM.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.SM.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.SM.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.SM.Ipv6.Dhcp)), ("address", ("address", Native.Interface.SM.Ipv6.Address)), ("nd", ("nd", Native.Interface.SM.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.SM.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.SM.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.SM.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.SM.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.SM.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.SM.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.SM.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.SM.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.SM.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.SM.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.SM.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.SM.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.SM.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.SM.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.SM.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.SM.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.SM.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.SM.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.SM.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.SM.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.SM.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.SM.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.SM.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.SM.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.SM.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.SM.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.SM.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.SM.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.SM.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.SM.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.SM.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.SM.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.SM.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.SM.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.SM.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.SM.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.SM.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.SM.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.SM.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.SM.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.SM.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.SM.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.SM.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.SM.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.SM.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.SM.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.SM.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.SM.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.SM.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.SM.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.SM.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.SM.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.SM.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.SM.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.SM.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.SM.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.SM.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.SM.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.SM.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.SM.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.SM.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.SM.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.SM.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.SM.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.SM.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.SM.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.SM.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.SM.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.SM.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.SM.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.SM.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.SM.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.SM.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.SM.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.SM.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.SM.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.SM.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.SM.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.SM.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.SM.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.SM.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.SM.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.SM.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.SM.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.SM.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.SM.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.SM.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.SM.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.SM.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.SM.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.SM.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.SM.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.SM.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.SM.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.SM.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.SM.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.SM.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.SM.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.SM.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.SM.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.SM.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.SM.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.SM.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.SM.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.SM.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.SM.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.SM.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.SM.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.SM.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "SM"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.SM.PmPath, [u'name', u'interface_id'], name, value)


        class Cellular(Entity):
            """
            Cellular Interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            	**pattern:** ([0\-9])+(/([0\-9])+)\*
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.PmPath>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.ServicePolicy>`
            
            .. attribute:: dialer
            
            	
            	**type**\:  :py:class:`Dialer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Dialer>`
            
            .. attribute:: dialer_group
            
            	Assign interface to dialer\-list
            	**type**\: int
            
            	**range:** 1..128
            
            .. attribute:: pulse_time
            
            	Assign interface to dialer\-list
            	**type**\: int
            
            	**range:** 0..60
            
            .. attribute:: async
            
            	
            	**type**\:  :py:class:`Async <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Async>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Cellular, self).__init__()

                self.yang_name = "Cellular"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.Cellular.SwitchportConf)), ("switchport", ("switchport", Native.Interface.Cellular.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.Cellular.StackwiseVirtual)), ("arp", ("arp", Native.Interface.Cellular.Arp)), ("backup", ("backup", Native.Interface.Cellular.Backup)), ("cemoudp", ("cemoudp", Native.Interface.Cellular.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.Cellular.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.Cellular.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.Cellular.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.Cellular.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.Cellular.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.Cellular.Flowcontrol)), ("isis", ("isis", Native.Interface.Cellular.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.Cellular.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.Cellular.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.Cellular.Bandwidth)), ("dampening", ("dampening", Native.Interface.Cellular.Dampening)), ("domain", ("domain", Native.Interface.Cellular.Domain)), ("hold-queue", ("hold_queue", Native.Interface.Cellular.HoldQueue)), ("mpls", ("mpls", Native.Interface.Cellular.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.Cellular.IpVrf)), ("vrf", ("vrf", Native.Interface.Cellular.Vrf)), ("ip", ("ip", Native.Interface.Cellular.Ip)), ("ipv6", ("ipv6", Native.Interface.Cellular.Ipv6)), ("logging", ("logging", Native.Interface.Cellular.Logging)), ("mdix", ("mdix", Native.Interface.Cellular.Mdix)), ("mop", ("mop", Native.Interface.Cellular.Mop)), ("interface_qos", ("interface_qos", Native.Interface.Cellular.InterfaceQos)), ("source", ("source", Native.Interface.Cellular.Source)), ("standby", ("standby", Native.Interface.Cellular.Standby)), ("access-session", ("access_session", Native.Interface.Cellular.AccessSession)), ("storm-control", ("storm_control", Native.Interface.Cellular.StormControl)), ("trust", ("trust", Native.Interface.Cellular.Trust)), ("priority-queue", ("priority_queue", Native.Interface.Cellular.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.Cellular.RcvQueue)), ("peer", ("peer", Native.Interface.Cellular.Peer)), ("pm-path", ("pm_path", Native.Interface.Cellular.PmPath)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.Cellular.ServicePolicy)), ("Cisco-IOS-XE-cellular:dialer", ("dialer", Native.Interface.Cellular.Dialer)), ("Cisco-IOS-XE-cellular:async", ("async", Native.Interface.Cellular.Async))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.ServiceInsertion')])),
                    ('dialer_group', (YLeaf(YType.uint8, 'Cisco-IOS-XE-cellular:dialer-group'), ['int'])),
                    ('pulse_time', (YLeaf(YType.uint8, 'Cisco-IOS-XE-cellular:pulse-time'), ['int'])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.dialer_group = None
                self.pulse_time = None

                self.switchport_conf = Native.Interface.Cellular.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.Cellular.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.Cellular.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.Cellular.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.Cellular.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.Cellular.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.Cellular.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.Cellular.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.Cellular.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.Cellular.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.Cellular.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.Cellular.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.Cellular.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.Cellular.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.Cellular.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.Cellular.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.Cellular.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.Cellular.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.Cellular.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.Cellular.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.Cellular.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.Cellular.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.Cellular.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.Cellular.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.Cellular.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.Cellular.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.Cellular.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.Cellular.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.Cellular.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.Cellular.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.Cellular.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.Cellular.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.Cellular.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.Cellular.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.Cellular.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.service_policy = Native.Interface.Cellular.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.dialer = Native.Interface.Cellular.Dialer()
                self.dialer.parent = self
                self._children_name_map["dialer"] = "Cisco-IOS-XE-cellular:dialer"

                self.async = Native.Interface.Cellular.Async()
                self.async.parent = self
                self._children_name_map["async"] = "Cisco-IOS-XE-cellular:async"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "Cellular" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Cellular, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'dialer_group', 'pulse_time'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Cellular.Backup.Delay)), ("interface", ("interface", Native.Interface.Cellular.Backup.Interface_)), ("load", ("load", Native.Interface.Cellular.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Cellular.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Cellular.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Cellular.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Cellular.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Cellular.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Cellular.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Cellular.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Cellular.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Cellular.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Cellular.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Cellular.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Cellular.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Cellular.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Cellular.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Cellular.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Cellular.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Cellular.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Cellular.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Cellular.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Cellular.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Cellular.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Cellular.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.Cellular.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Cellular.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Cellular.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Cellular.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Cellular.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Cellular.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Cellular.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Cellular.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Cellular.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Cellular.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Cellular.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Cellular.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Cellular.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Cellular.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Verify>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Nat>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Cellular.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.Cellular.Ip.Arp)), ("vrf", ("vrf", Native.Interface.Cellular.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.Cellular.Ip.NoAddress)), ("address", ("address", Native.Interface.Cellular.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Cellular.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Cellular.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.Cellular.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.Cellular.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Cellular.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.Cellular.Ip.Pim)), ("policy", ("policy", Native.Interface.Cellular.Ip.Policy)), ("rip", ("rip", Native.Interface.Cellular.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Cellular.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Cellular.Ip.RouteCache)), ("router", ("router", Native.Interface.Cellular.Ip.Router)), ("tcp", ("tcp", Native.Interface.Cellular.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Cellular.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Cellular.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Cellular.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.Cellular.Ip.Verify)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.Cellular.Ip.Nat))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.Cellular.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Cellular.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Cellular.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Cellular.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Cellular.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Cellular.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Cellular.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Cellular.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Cellular.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Cellular.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Cellular.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Cellular.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Cellular.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Cellular.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Cellular.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Cellular.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Cellular.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Cellular.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.nat = Native.Interface.Cellular.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Cellular.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.Cellular.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Cellular.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Cellular.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Cellular.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Cellular.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Cellular.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Cellular.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Cellular.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Cellular.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Cellular.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Cellular.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Cellular.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Cellular.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Cellular.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Cellular.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Cellular.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Cellular.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Cellular.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.Cellular.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Cellular.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Cellular.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Cellular.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Cellular.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Cellular.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Cellular.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Cellular.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Cellular.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Cellular.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Cellular.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Cellular.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Cellular.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Cellular.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Cellular.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Cellular.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.Cellular.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Cellular.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Cellular.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Cellular.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Cellular.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Cellular.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Cellular.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Cellular.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Cellular.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Cellular.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Cellular.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Cellular.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Cellular.Ipv6.Dhcp)), ("address", ("address", Native.Interface.Cellular.Ipv6.Address)), ("nd", ("nd", Native.Interface.Cellular.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.Cellular.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Cellular.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Cellular.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Cellular.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Cellular.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Cellular.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Cellular.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Cellular.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Cellular.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Cellular.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Cellular.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Cellular.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Cellular.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Cellular.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Cellular.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Cellular.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Cellular.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Cellular.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Cellular.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Cellular.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.Cellular.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Cellular.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Cellular.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Cellular.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Cellular.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Cellular.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Cellular.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Cellular.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Cellular.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Cellular.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.Cellular.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Cellular.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Cellular.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Cellular.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Cellular.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Cellular.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Cellular.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Cellular.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Cellular.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Cellular.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Cellular.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Cellular.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Cellular.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Cellular.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Cellular.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Cellular.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Cellular.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Cellular.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Cellular.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Cellular.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Cellular.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Cellular.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Cellular.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Cellular.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Cellular.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Cellular.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Cellular.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Cellular.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Cellular.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Cellular.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Cellular.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Cellular.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Cellular.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Cellular.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Cellular.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Cellular.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Cellular.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Cellular.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Cellular.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Cellular.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Cellular.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Cellular.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Cellular.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Cellular.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Cellular.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Cellular.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Cellular.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Cellular.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Cellular.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Cellular.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Cellular.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Cellular.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Cellular.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Cellular.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Cellular.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Cellular.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Cellular.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Cellular.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Cellular.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Cellular.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Cellular.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Cellular.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Cellular.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Cellular.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Cellular.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Cellular.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Cellular.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Cellular.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Cellular.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Cellular.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Cellular.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Cellular.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Cellular.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Cellular.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.PmPath, [u'name', u'interface_id'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Cellular.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.Cellular.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.Cellular.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Cellular.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.Cellular.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.Cellular.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.Cellular.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.Cellular.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.Cellular.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.Cellular.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Cellular.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Cellular.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Cellular.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Cellular.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.Cellular.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.Cellular.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.Cellular.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.Cellular.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Cellular.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Cellular.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Cellular.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Cellular.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Dialer(Entity):
                """
                
                
                .. attribute:: in_band
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: idle_timeout
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: string
                
                	
                	**type**\: str
                
                .. attribute:: watch_group
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios-cell'
                _revision = '2017-12-20'

                def __init__(self):
                    super(Native.Interface.Cellular.Dialer, self).__init__()

                    self.yang_name = "dialer"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('in_band', (YLeaf(YType.empty, 'in-band'), ['Empty'])),
                        ('idle_timeout', (YLeaf(YType.uint32, 'idle-timeout'), ['int'])),
                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                        ('watch_group', (YLeaf(YType.uint32, 'watch-group'), ['int'])),
                    ])
                    self.in_band = None
                    self.idle_timeout = None
                    self.string = None
                    self.watch_group = None
                    self._segment_path = lambda: "Cisco-IOS-XE-cellular:dialer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Dialer, ['in_band', 'idle_timeout', 'string', 'watch_group'], name, value)


            class Async(Entity):
                """
                
                
                .. attribute:: mode
                
                	
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Cellular.Async.Mode>`
                
                

                """

                _prefix = 'ios-cell'
                _revision = '2017-12-20'

                def __init__(self):
                    super(Native.Interface.Cellular.Async, self).__init__()

                    self.yang_name = "async"
                    self.yang_parent_name = "Cellular"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Cellular.Async.Mode')])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-cellular:async"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Cellular.Async, ['mode'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    .. data:: interactive = 0

                    """

                    interactive = Enum.YLeaf(0, "interactive")



        class Vlan(Entity):
            """
            Catalyst Vlans
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..4094
            
            .. attribute:: cisco_ios_xe_interfaces_description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: cisco_ios_xe_interfaces_switchport_conf
            
            	
            	**type**\:  :py:class:`CiscoIOSXEInterfacesSwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchportConf>`
            
            .. attribute:: cisco_ios_xe_interfaces_switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`CiscoIOSXEInterfacesSwitchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchport>`
            
            .. attribute:: cisco_ios_xe_interfaces_stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`CiscoIOSXEInterfacesStackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStackwiseVirtual>`
            
            .. attribute:: cisco_ios_xe_interfaces_mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: cisco_ios_xe_interfaces_shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_interfaces_arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`CiscoIOSXEInterfacesArp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesArp>`
            
            .. attribute:: cisco_ios_xe_interfaces_backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`CiscoIOSXEInterfacesBackup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup>`
            
            .. attribute:: cisco_ios_xe_interfaces_cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`CiscoIOSXEInterfacesCemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp>`
            
            .. attribute:: cisco_ios_xe_interfaces_cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CiscoIOSXEInterfacesCwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel>`
            
            .. attribute:: cisco_ios_xe_interfaces_l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`CiscoIOSXEInterfacesL2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: cisco_ios_xe_interfaces_encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`CiscoIOSXEInterfacesEncapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation>`
            
            .. attribute:: cisco_ios_xe_interfaces_fair_queue_conf
            
            	
            	**type**\:  :py:class:`CiscoIOSXEInterfacesFairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueueConf>`
            
            .. attribute:: cisco_ios_xe_interfaces_fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`CiscoIOSXEInterfacesFairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueue>`
            
            .. attribute:: cisco_ios_xe_interfaces_flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`CiscoIOSXEInterfacesFlowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol>`
            
            .. attribute:: cisco_ios_xe_interfaces_isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesIsis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.KeepaliveSettings>`
            
            .. attribute:: cisco_ios_xe_interfaces_bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesBfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBfd>`
            
            .. attribute:: cisco_ios_xe_interfaces_bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`CiscoIOSXEInterfacesBandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth>`
            
            .. attribute:: cisco_ios_xe_interfaces_dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`CiscoIOSXEInterfacesDampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesDampening>`
            
            .. attribute:: cisco_ios_xe_interfaces_if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.IfState>`
            
            .. attribute:: cisco_ios_xe_interfaces_delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: cisco_ios_xe_interfaces_domain
            
            	Specify a domain
            	**type**\:  :py:class:`CiscoIOSXEInterfacesDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesDomain>`
            
            .. attribute:: cisco_ios_xe_interfaces_hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`CiscoIOSXEInterfacesHoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesHoldQueue>`
            
            .. attribute:: cisco_ios_xe_interfaces_mpls
            
            	
            	**type**\:  :py:class:`CiscoIOSXEInterfacesMpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrf>`
            
            .. attribute:: cisco_ios_xe_interfaces_ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp>`
            
            .. attribute:: cisco_ios_xe_interfaces_ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesIpv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6>`
            
            .. attribute:: cisco_ios_xe_interfaces_load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: cisco_ios_xe_interfaces_logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`CiscoIOSXEInterfacesLogging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesLogging>`
            
            .. attribute:: cisco_ios_xe_interfaces_mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`CiscoIOSXEInterfacesMdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMdix>`
            
            .. attribute:: cisco_ios_xe_interfaces_mop
            
            	
            	**type**\:  :py:class:`CiscoIOSXEInterfacesMop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMop>`
            
            .. attribute:: cisco_ios_xe_interfaces_max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: cisco_ios_xe_interfaces_mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: cisco_ios_xe_interfaces_interface_qos
            
            	
            	**type**\:  :py:class:`CiscoIOSXEInterfacesInterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos>`
            
            .. attribute:: cisco_ios_xe_interfaces_service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServiceInsertion>`
            
            .. attribute:: cisco_ios_xe_interfaces_source
            
            	Get config from another source
            	**type**\:  :py:class:`CiscoIOSXEInterfacesSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesSource>`
            
            .. attribute:: cisco_ios_xe_interfaces_standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesStandby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby>`
            
            .. attribute:: cisco_ios_xe_interfaces_access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesAccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession>`
            
            .. attribute:: cisco_ios_xe_interfaces_storm_control
            
            	storm configuration
            	**type**\:  :py:class:`CiscoIOSXEInterfacesStormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl>`
            
            .. attribute:: cisco_ios_xe_interfaces_trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`CiscoIOSXEInterfacesTrust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesTrust>`
            
            .. attribute:: cisco_ios_xe_interfaces_priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`CiscoIOSXEInterfacesPriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue>`
            
            .. attribute:: cisco_ios_xe_interfaces_rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`CiscoIOSXEInterfacesRcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue>`
            
            .. attribute:: cisco_ios_xe_interfaces_peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`CiscoIOSXEInterfacesPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer>`
            
            .. attribute:: cisco_ios_xe_interfaces_pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`CiscoIOSXEInterfacesPmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServicePolicy>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Crypto>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Utd>`
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Lisp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ntp>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.SpanningTree>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Umbrella>`
            
            .. attribute:: private_vlan
            
            	Configure private VLAN SVI interface settings
            	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.PrivateVlan>`
            
            .. attribute:: service_routing
            
            	Service Routing in Interface Mode
            	**type**\:  :py:class:`ServiceRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServiceRouting>`
            
            .. attribute:: glbp
            
            	Gateway Load Balancing Protocol interface commands
            	**type**\:  :py:class:`Glbp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp>`
            
            .. attribute:: cisco_ios_xe_interfaces_description_
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: cisco_ios_xe_interfaces_switchport_conf_
            
            	
            	**type**\:  :py:class:`CiscoIOSXEInterfacesSwitchportConf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchportConf_>`
            
            .. attribute:: cisco_ios_xe_interfaces_switchport_
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`CiscoIOSXEInterfacesSwitchport_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchport_>`
            
            .. attribute:: cisco_ios_xe_interfaces_stackwise_virtual_
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`CiscoIOSXEInterfacesStackwiseVirtual_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStackwiseVirtual_>`
            
            .. attribute:: cisco_ios_xe_interfaces_mac_address_
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: cisco_ios_xe_interfaces_shutdown_
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cisco_ios_xe_interfaces_arp_
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`CiscoIOSXEInterfacesArp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesArp_>`
            
            .. attribute:: cisco_ios_xe_interfaces_backup_
            
            	Modify backup parameters
            	**type**\:  :py:class:`CiscoIOSXEInterfacesBackup_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_>`
            
            .. attribute:: cisco_ios_xe_interfaces_cemoudp_
            
            	cemoudp
            	**type**\:  :py:class:`CiscoIOSXEInterfacesCemoudp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp_>`
            
            .. attribute:: cisco_ios_xe_interfaces_cws_tunnel_
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CiscoIOSXEInterfacesCwsTunnel_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel_>`
            
            .. attribute:: cisco_ios_xe_interfaces_l2protocol_tunnel_
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`CiscoIOSXEInterfacesL2protocolTunnel_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_>`
            
            	**presence node**\: True
            
            .. attribute:: cisco_ios_xe_interfaces_encapsulation_
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`CiscoIOSXEInterfacesEncapsulation_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_>`
            
            .. attribute:: cisco_ios_xe_interfaces_fair_queue_conf_
            
            	
            	**type**\:  :py:class:`CiscoIOSXEInterfacesFairQueueConf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueueConf_>`
            
            .. attribute:: cisco_ios_xe_interfaces_fair_queue_
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`CiscoIOSXEInterfacesFairQueue_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueue_>`
            
            .. attribute:: cisco_ios_xe_interfaces_flowcontrol_
            
            	Configure flow operation
            	**type**\:  :py:class:`CiscoIOSXEInterfacesFlowcontrol_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol_>`
            
            .. attribute:: cisco_ios_xe_interfaces_isis_
            
            	IS\-IS commands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesIsis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis_>`
            
            .. attribute:: keepalive_
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings_
            
            	
            	**type**\:  :py:class:`KeepaliveSettings_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.KeepaliveSettings_>`
            
            .. attribute:: cisco_ios_xe_interfaces_bfd_
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesBfd_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBfd_>`
            
            .. attribute:: cisco_ios_xe_interfaces_bandwidth_
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`CiscoIOSXEInterfacesBandwidth_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_>`
            
            .. attribute:: cisco_ios_xe_interfaces_dampening_
            
            	Enable event dampening
            	**type**\:  :py:class:`CiscoIOSXEInterfacesDampening_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesDampening_>`
            
            .. attribute:: cisco_ios_xe_interfaces_if_state_
            
            	
            	**type**\:  :py:class:`IfState_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.IfState_>`
            
            .. attribute:: cisco_ios_xe_interfaces_delay_
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: cisco_ios_xe_interfaces_domain_
            
            	Specify a domain
            	**type**\:  :py:class:`CiscoIOSXEInterfacesDomain_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesDomain_>`
            
            .. attribute:: cisco_ios_xe_interfaces_hold_queue_
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`CiscoIOSXEInterfacesHoldQueue_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesHoldQueue_>`
            
            .. attribute:: cisco_ios_xe_interfaces_mpls_
            
            	
            	**type**\:  :py:class:`CiscoIOSXEInterfacesMpls_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls_>`
            
            .. attribute:: ip_vrf_
            
            	
            	**type**\:  :py:class:`IpVrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.IpVrf_>`
            
            .. attribute:: vrf_
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrf_>`
            
            .. attribute:: cisco_ios_xe_interfaces_ip_
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesIp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_>`
            
            .. attribute:: cisco_ios_xe_interfaces_ipv6_
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesIpv6_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_>`
            
            .. attribute:: cisco_ios_xe_interfaces_load_interval_
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: cisco_ios_xe_interfaces_logging_
            
            	Configure logging for interface
            	**type**\:  :py:class:`CiscoIOSXEInterfacesLogging_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_>`
            
            .. attribute:: cisco_ios_xe_interfaces_mdix_
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`CiscoIOSXEInterfacesMdix_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMdix_>`
            
            .. attribute:: cisco_ios_xe_interfaces_mop_
            
            	
            	**type**\:  :py:class:`CiscoIOSXEInterfacesMop_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMop_>`
            
            .. attribute:: cisco_ios_xe_interfaces_max_reserved_bandwidth_
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: cisco_ios_xe_interfaces_mtu_
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: cisco_ios_xe_interfaces_interface_qos_
            
            	
            	**type**\:  :py:class:`CiscoIOSXEInterfacesInterfaceQos_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_>`
            
            .. attribute:: cisco_ios_xe_interfaces_service_insertion_
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServiceInsertion_>`
            
            .. attribute:: cisco_ios_xe_interfaces_source_
            
            	Get config from another source
            	**type**\:  :py:class:`CiscoIOSXEInterfacesSource_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesSource_>`
            
            .. attribute:: cisco_ios_xe_interfaces_standby_
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesStandby_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_>`
            
            .. attribute:: cisco_ios_xe_interfaces_access_session_
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`CiscoIOSXEInterfacesAccessSession_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_>`
            
            .. attribute:: cisco_ios_xe_interfaces_storm_control_
            
            	storm configuration
            	**type**\:  :py:class:`CiscoIOSXEInterfacesStormControl_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_>`
            
            .. attribute:: cisco_ios_xe_interfaces_trust_
            
            	Set trust value for the interface
            	**type**\:  :py:class:`CiscoIOSXEInterfacesTrust_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesTrust_>`
            
            .. attribute:: cisco_ios_xe_interfaces_priority_queue_
            
            	Configure priority scheduling
            	**type**\:  :py:class:`CiscoIOSXEInterfacesPriorityQueue_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue_>`
            
            .. attribute:: cisco_ios_xe_interfaces_rcv_queue_
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`CiscoIOSXEInterfacesRcvQueue_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue_>`
            
            .. attribute:: cisco_ios_xe_interfaces_peer_
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`CiscoIOSXEInterfacesPeer_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_>`
            
            .. attribute:: cisco_ios_xe_interfaces_pm_path_
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`CiscoIOSXEInterfacesPmPath_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPmPath_>`
            
            .. attribute:: vrrp
            
            	Configure VRRP
            	**type**\:  :py:class:`Vrrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Vlan, self).__init__()

                self.yang_name = "Vlan"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("cisco_ios_xe_interfaces_switchport_conf", Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchportConf)), ("switchport", ("cisco_ios_xe_interfaces_switchport", Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchport)), ("stackwise-virtual", ("cisco_ios_xe_interfaces_stackwise_virtual", Native.Interface.Vlan.CiscoIOSXEInterfacesStackwiseVirtual)), ("arp", ("cisco_ios_xe_interfaces_arp", Native.Interface.Vlan.CiscoIOSXEInterfacesArp)), ("backup", ("cisco_ios_xe_interfaces_backup", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup)), ("cemoudp", ("cisco_ios_xe_interfaces_cemoudp", Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp)), ("cws-tunnel", ("cisco_ios_xe_interfaces_cws_tunnel", Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel)), ("l2protocol-tunnel", ("cisco_ios_xe_interfaces_l2protocol_tunnel", Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel)), ("encapsulation", ("cisco_ios_xe_interfaces_encapsulation", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation)), ("fair-queue-conf", ("cisco_ios_xe_interfaces_fair_queue_conf", Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueueConf)), ("fair-queue", ("cisco_ios_xe_interfaces_fair_queue", Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueue)), ("flowcontrol", ("cisco_ios_xe_interfaces_flowcontrol", Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol)), ("isis", ("cisco_ios_xe_interfaces_isis", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.Vlan.KeepaliveSettings)), ("bfd", ("cisco_ios_xe_interfaces_bfd", Native.Interface.Vlan.CiscoIOSXEInterfacesBfd)), ("bandwidth", ("cisco_ios_xe_interfaces_bandwidth", Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth)), ("dampening", ("cisco_ios_xe_interfaces_dampening", Native.Interface.Vlan.CiscoIOSXEInterfacesDampening)), ("domain", ("cisco_ios_xe_interfaces_domain", Native.Interface.Vlan.CiscoIOSXEInterfacesDomain)), ("hold-queue", ("cisco_ios_xe_interfaces_hold_queue", Native.Interface.Vlan.CiscoIOSXEInterfacesHoldQueue)), ("mpls", ("cisco_ios_xe_interfaces_mpls", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls)), ("ip-vrf", ("ip_vrf", Native.Interface.Vlan.IpVrf)), ("vrf", ("vrf", Native.Interface.Vlan.Vrf)), ("ip", ("cisco_ios_xe_interfaces_ip", Native.Interface.Vlan.CiscoIOSXEInterfacesIp)), ("ipv6", ("cisco_ios_xe_interfaces_ipv6", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6)), ("logging", ("cisco_ios_xe_interfaces_logging", Native.Interface.Vlan.CiscoIOSXEInterfacesLogging)), ("mdix", ("cisco_ios_xe_interfaces_mdix", Native.Interface.Vlan.CiscoIOSXEInterfacesMdix)), ("mop", ("cisco_ios_xe_interfaces_mop", Native.Interface.Vlan.CiscoIOSXEInterfacesMop)), ("interface_qos", ("cisco_ios_xe_interfaces_interface_qos", Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos)), ("source", ("cisco_ios_xe_interfaces_source", Native.Interface.Vlan.CiscoIOSXEInterfacesSource)), ("standby", ("cisco_ios_xe_interfaces_standby", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby)), ("access-session", ("cisco_ios_xe_interfaces_access_session", Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession)), ("storm-control", ("cisco_ios_xe_interfaces_storm_control", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl)), ("trust", ("cisco_ios_xe_interfaces_trust", Native.Interface.Vlan.CiscoIOSXEInterfacesTrust)), ("priority-queue", ("cisco_ios_xe_interfaces_priority_queue", Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue)), ("rcv-queue", ("cisco_ios_xe_interfaces_rcv_queue", Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue)), ("peer", ("cisco_ios_xe_interfaces_peer", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer)), ("pm-path", ("cisco_ios_xe_interfaces_pm_path", Native.Interface.Vlan.CiscoIOSXEInterfacesPmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.Vlan.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.Vlan.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.Vlan.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.Vlan.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.Vlan.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.Vlan.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.Vlan.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.Vlan.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.Vlan.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.Vlan.Service)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.Vlan.ServicePolicy)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.Vlan.Crypto)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.Vlan.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.Vlan.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.Vlan.Utd)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.Vlan.Lisp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.Vlan.Ntp)), ("Cisco-IOS-XE-spanning-tree:spanning-tree", ("spanning_tree", Native.Interface.Vlan.SpanningTree)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.Vlan.Umbrella)), ("Cisco-IOS-XE-vlan:private-vlan", ("private_vlan", Native.Interface.Vlan.PrivateVlan)), ("Cisco-IOS-XE-vlan:service-routing", ("service_routing", Native.Interface.Vlan.ServiceRouting)), ("Cisco-IOS-XE-vlan:glbp", ("glbp", Native.Interface.Vlan.Glbp)), ("Cisco-IOS-XE-vlan:switchport-conf", ("cisco_ios_xe_interfaces_switchport_conf_", Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchportConf_)), ("Cisco-IOS-XE-vlan:switchport", ("cisco_ios_xe_interfaces_switchport_", Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchport_)), ("Cisco-IOS-XE-vlan:stackwise-virtual", ("cisco_ios_xe_interfaces_stackwise_virtual_", Native.Interface.Vlan.CiscoIOSXEInterfacesStackwiseVirtual_)), ("Cisco-IOS-XE-vlan:arp", ("cisco_ios_xe_interfaces_arp_", Native.Interface.Vlan.CiscoIOSXEInterfacesArp_)), ("Cisco-IOS-XE-vlan:backup", ("cisco_ios_xe_interfaces_backup_", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_)), ("Cisco-IOS-XE-vlan:cemoudp", ("cisco_ios_xe_interfaces_cemoudp_", Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp_)), ("Cisco-IOS-XE-vlan:cws-tunnel", ("cisco_ios_xe_interfaces_cws_tunnel_", Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel_)), ("Cisco-IOS-XE-vlan:l2protocol-tunnel", ("cisco_ios_xe_interfaces_l2protocol_tunnel_", Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_)), ("Cisco-IOS-XE-vlan:encapsulation", ("cisco_ios_xe_interfaces_encapsulation_", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_)), ("Cisco-IOS-XE-vlan:fair-queue-conf", ("cisco_ios_xe_interfaces_fair_queue_conf_", Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueueConf_)), ("Cisco-IOS-XE-vlan:fair-queue", ("cisco_ios_xe_interfaces_fair_queue_", Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueue_)), ("Cisco-IOS-XE-vlan:flowcontrol", ("cisco_ios_xe_interfaces_flowcontrol_", Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol_)), ("Cisco-IOS-XE-vlan:isis", ("cisco_ios_xe_interfaces_isis_", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis_)), ("Cisco-IOS-XE-vlan:keepalive-settings", ("keepalive_settings_", Native.Interface.Vlan.KeepaliveSettings_)), ("Cisco-IOS-XE-vlan:bfd", ("cisco_ios_xe_interfaces_bfd_", Native.Interface.Vlan.CiscoIOSXEInterfacesBfd_)), ("Cisco-IOS-XE-vlan:bandwidth", ("cisco_ios_xe_interfaces_bandwidth_", Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_)), ("Cisco-IOS-XE-vlan:dampening", ("cisco_ios_xe_interfaces_dampening_", Native.Interface.Vlan.CiscoIOSXEInterfacesDampening_)), ("Cisco-IOS-XE-vlan:domain", ("cisco_ios_xe_interfaces_domain_", Native.Interface.Vlan.CiscoIOSXEInterfacesDomain_)), ("Cisco-IOS-XE-vlan:hold-queue", ("cisco_ios_xe_interfaces_hold_queue_", Native.Interface.Vlan.CiscoIOSXEInterfacesHoldQueue_)), ("Cisco-IOS-XE-vlan:mpls", ("cisco_ios_xe_interfaces_mpls_", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls_)), ("Cisco-IOS-XE-vlan:ip-vrf", ("ip_vrf_", Native.Interface.Vlan.IpVrf_)), ("Cisco-IOS-XE-vlan:vrf", ("vrf_", Native.Interface.Vlan.Vrf_)), ("Cisco-IOS-XE-vlan:ip", ("cisco_ios_xe_interfaces_ip_", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_)), ("Cisco-IOS-XE-vlan:ipv6", ("cisco_ios_xe_interfaces_ipv6_", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_)), ("Cisco-IOS-XE-vlan:logging", ("cisco_ios_xe_interfaces_logging_", Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_)), ("Cisco-IOS-XE-vlan:mdix", ("cisco_ios_xe_interfaces_mdix_", Native.Interface.Vlan.CiscoIOSXEInterfacesMdix_)), ("Cisco-IOS-XE-vlan:mop", ("cisco_ios_xe_interfaces_mop_", Native.Interface.Vlan.CiscoIOSXEInterfacesMop_)), ("Cisco-IOS-XE-vlan:interface_qos", ("cisco_ios_xe_interfaces_interface_qos_", Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_)), ("Cisco-IOS-XE-vlan:source", ("cisco_ios_xe_interfaces_source_", Native.Interface.Vlan.CiscoIOSXEInterfacesSource_)), ("Cisco-IOS-XE-vlan:standby", ("cisco_ios_xe_interfaces_standby_", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_)), ("Cisco-IOS-XE-vlan:access-session", ("cisco_ios_xe_interfaces_access_session_", Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_)), ("Cisco-IOS-XE-vlan:storm-control", ("cisco_ios_xe_interfaces_storm_control_", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_)), ("Cisco-IOS-XE-vlan:trust", ("cisco_ios_xe_interfaces_trust_", Native.Interface.Vlan.CiscoIOSXEInterfacesTrust_)), ("Cisco-IOS-XE-vlan:priority-queue", ("cisco_ios_xe_interfaces_priority_queue_", Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue_)), ("Cisco-IOS-XE-vlan:rcv-queue", ("cisco_ios_xe_interfaces_rcv_queue_", Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue_)), ("Cisco-IOS-XE-vlan:peer", ("cisco_ios_xe_interfaces_peer_", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_)), ("Cisco-IOS-XE-vlan:pm-path", ("cisco_ios_xe_interfaces_pm_path_", Native.Interface.Vlan.CiscoIOSXEInterfacesPmPath_)), ("Cisco-IOS-XE-vrrp:vrrp", ("vrrp", Native.Interface.Vlan.Vrrp)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.Vlan.Cts))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('cisco_ios_xe_interfaces_description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('cisco_ios_xe_interfaces_mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('cisco_ios_xe_interfaces_shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('cisco_ios_xe_interfaces_if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.IfState')])),
                    ('cisco_ios_xe_interfaces_delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('cisco_ios_xe_interfaces_load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('cisco_ios_xe_interfaces_max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('cisco_ios_xe_interfaces_mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('cisco_ios_xe_interfaces_service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Duplex')])),
                    ('cisco_ios_xe_interfaces_description_', (YLeaf(YType.str, 'description'), ['str'])),
                    ('cisco_ios_xe_interfaces_mac_address_', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('cisco_ios_xe_interfaces_shutdown_', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive_', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('cisco_ios_xe_interfaces_if_state_', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.IfState_')])),
                    ('cisco_ios_xe_interfaces_delay_', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('cisco_ios_xe_interfaces_load_interval_', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('cisco_ios_xe_interfaces_max_reserved_bandwidth_', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('cisco_ios_xe_interfaces_mtu_', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('cisco_ios_xe_interfaces_service_insertion_', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.ServiceInsertion_')])),
                ])
                self.name = None
                self.cisco_ios_xe_interfaces_description = None
                self.cisco_ios_xe_interfaces_mac_address = None
                self.cisco_ios_xe_interfaces_shutdown = None
                self.keepalive = None
                self.cisco_ios_xe_interfaces_if_state = None
                self.cisco_ios_xe_interfaces_delay = None
                self.cisco_ios_xe_interfaces_load_interval = None
                self.cisco_ios_xe_interfaces_max_reserved_bandwidth = None
                self.cisco_ios_xe_interfaces_mtu = None
                self.cisco_ios_xe_interfaces_service_insertion = None
                self.channel_protocol = None
                self.duplex = None
                self.cisco_ios_xe_interfaces_description_ = None
                self.cisco_ios_xe_interfaces_mac_address_ = None
                self.cisco_ios_xe_interfaces_shutdown_ = None
                self.keepalive_ = None
                self.cisco_ios_xe_interfaces_if_state_ = None
                self.cisco_ios_xe_interfaces_delay_ = None
                self.cisco_ios_xe_interfaces_load_interval_ = None
                self.cisco_ios_xe_interfaces_max_reserved_bandwidth_ = None
                self.cisco_ios_xe_interfaces_mtu_ = None
                self.cisco_ios_xe_interfaces_service_insertion_ = None

                self.cisco_ios_xe_interfaces_switchport_conf = Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchportConf()
                self.cisco_ios_xe_interfaces_switchport_conf.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_switchport_conf"] = "switchport-conf"

                self.cisco_ios_xe_interfaces_switchport = Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchport()
                self.cisco_ios_xe_interfaces_switchport.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_switchport"] = "switchport"

                self.cisco_ios_xe_interfaces_stackwise_virtual = Native.Interface.Vlan.CiscoIOSXEInterfacesStackwiseVirtual()
                self.cisco_ios_xe_interfaces_stackwise_virtual.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_stackwise_virtual"] = "stackwise-virtual"

                self.cisco_ios_xe_interfaces_arp = Native.Interface.Vlan.CiscoIOSXEInterfacesArp()
                self.cisco_ios_xe_interfaces_arp.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_arp"] = "arp"

                self.cisco_ios_xe_interfaces_backup = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup()
                self.cisco_ios_xe_interfaces_backup.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_backup"] = "backup"

                self.cisco_ios_xe_interfaces_cemoudp = Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp()
                self.cisco_ios_xe_interfaces_cemoudp.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_cemoudp"] = "cemoudp"

                self.cisco_ios_xe_interfaces_cws_tunnel = Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel()
                self.cisco_ios_xe_interfaces_cws_tunnel.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_cws_tunnel"] = "cws-tunnel"

                self.cisco_ios_xe_interfaces_l2protocol_tunnel = None
                self._children_name_map["cisco_ios_xe_interfaces_l2protocol_tunnel"] = "l2protocol-tunnel"

                self.cisco_ios_xe_interfaces_encapsulation = Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation()
                self.cisco_ios_xe_interfaces_encapsulation.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_encapsulation"] = "encapsulation"

                self.cisco_ios_xe_interfaces_fair_queue_conf = Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueueConf()
                self.cisco_ios_xe_interfaces_fair_queue_conf.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_fair_queue_conf"] = "fair-queue-conf"

                self.cisco_ios_xe_interfaces_fair_queue = Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueue()
                self.cisco_ios_xe_interfaces_fair_queue.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_fair_queue"] = "fair-queue"

                self.cisco_ios_xe_interfaces_flowcontrol = Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol()
                self.cisco_ios_xe_interfaces_flowcontrol.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_flowcontrol"] = "flowcontrol"

                self.cisco_ios_xe_interfaces_isis = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis()
                self.cisco_ios_xe_interfaces_isis.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_isis"] = "isis"

                self.keepalive_settings = Native.Interface.Vlan.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.cisco_ios_xe_interfaces_bfd = Native.Interface.Vlan.CiscoIOSXEInterfacesBfd()
                self.cisco_ios_xe_interfaces_bfd.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_bfd"] = "bfd"

                self.cisco_ios_xe_interfaces_bandwidth = Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth()
                self.cisco_ios_xe_interfaces_bandwidth.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_bandwidth"] = "bandwidth"

                self.cisco_ios_xe_interfaces_dampening = Native.Interface.Vlan.CiscoIOSXEInterfacesDampening()
                self.cisco_ios_xe_interfaces_dampening.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_dampening"] = "dampening"

                self.cisco_ios_xe_interfaces_domain = Native.Interface.Vlan.CiscoIOSXEInterfacesDomain()
                self.cisco_ios_xe_interfaces_domain.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_domain"] = "domain"

                self.cisco_ios_xe_interfaces_mpls = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls()
                self.cisco_ios_xe_interfaces_mpls.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_mpls"] = "mpls"

                self.ip_vrf = Native.Interface.Vlan.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.Vlan.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.cisco_ios_xe_interfaces_ip = Native.Interface.Vlan.CiscoIOSXEInterfacesIp()
                self.cisco_ios_xe_interfaces_ip.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_ip"] = "ip"

                self.cisco_ios_xe_interfaces_ipv6 = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6()
                self.cisco_ios_xe_interfaces_ipv6.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_ipv6"] = "ipv6"

                self.cisco_ios_xe_interfaces_logging = Native.Interface.Vlan.CiscoIOSXEInterfacesLogging()
                self.cisco_ios_xe_interfaces_logging.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_logging"] = "logging"

                self.cisco_ios_xe_interfaces_mdix = Native.Interface.Vlan.CiscoIOSXEInterfacesMdix()
                self.cisco_ios_xe_interfaces_mdix.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_mdix"] = "mdix"

                self.cisco_ios_xe_interfaces_mop = Native.Interface.Vlan.CiscoIOSXEInterfacesMop()
                self.cisco_ios_xe_interfaces_mop.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_mop"] = "mop"

                self.cisco_ios_xe_interfaces_interface_qos = Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos()
                self.cisco_ios_xe_interfaces_interface_qos.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_interface_qos"] = "interface_qos"

                self.cisco_ios_xe_interfaces_source = Native.Interface.Vlan.CiscoIOSXEInterfacesSource()
                self.cisco_ios_xe_interfaces_source.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_source"] = "source"

                self.cisco_ios_xe_interfaces_standby = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby()
                self.cisco_ios_xe_interfaces_standby.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_standby"] = "standby"

                self.cisco_ios_xe_interfaces_access_session = Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession()
                self.cisco_ios_xe_interfaces_access_session.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_access_session"] = "access-session"

                self.cisco_ios_xe_interfaces_storm_control = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl()
                self.cisco_ios_xe_interfaces_storm_control.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_storm_control"] = "storm-control"

                self.cisco_ios_xe_interfaces_trust = Native.Interface.Vlan.CiscoIOSXEInterfacesTrust()
                self.cisco_ios_xe_interfaces_trust.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_trust"] = "trust"

                self.cisco_ios_xe_interfaces_priority_queue = Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue()
                self.cisco_ios_xe_interfaces_priority_queue.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_priority_queue"] = "priority-queue"

                self.cisco_ios_xe_interfaces_rcv_queue = Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue()
                self.cisco_ios_xe_interfaces_rcv_queue.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_rcv_queue"] = "rcv-queue"

                self.cisco_ios_xe_interfaces_peer = Native.Interface.Vlan.CiscoIOSXEInterfacesPeer()
                self.cisco_ios_xe_interfaces_peer.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_peer"] = "peer"

                self.cisco_ios_xe_interfaces_pm_path = Native.Interface.Vlan.CiscoIOSXEInterfacesPmPath()
                self.cisco_ios_xe_interfaces_pm_path.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.Vlan.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.Vlan.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.Vlan.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.Vlan.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.Vlan.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.Vlan.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.Vlan.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.Vlan.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.Vlan.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.Vlan.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.service_policy = Native.Interface.Vlan.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.crypto = Native.Interface.Vlan.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.et_analytics = Native.Interface.Vlan.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.Vlan.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.Vlan.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.lisp = Native.Interface.Vlan.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.ntp = Native.Interface.Vlan.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.spanning_tree = Native.Interface.Vlan.SpanningTree()
                self.spanning_tree.parent = self
                self._children_name_map["spanning_tree"] = "Cisco-IOS-XE-spanning-tree:spanning-tree"

                self.umbrella = Native.Interface.Vlan.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.private_vlan = Native.Interface.Vlan.PrivateVlan()
                self.private_vlan.parent = self
                self._children_name_map["private_vlan"] = "Cisco-IOS-XE-vlan:private-vlan"

                self.service_routing = Native.Interface.Vlan.ServiceRouting()
                self.service_routing.parent = self
                self._children_name_map["service_routing"] = "Cisco-IOS-XE-vlan:service-routing"

                self.glbp = Native.Interface.Vlan.Glbp()
                self.glbp.parent = self
                self._children_name_map["glbp"] = "Cisco-IOS-XE-vlan:glbp"

                self.cisco_ios_xe_interfaces_switchport_conf_ = Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchportConf_()
                self.cisco_ios_xe_interfaces_switchport_conf_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_switchport_conf_"] = "Cisco-IOS-XE-vlan:switchport-conf"

                self.cisco_ios_xe_interfaces_switchport_ = Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchport_()
                self.cisco_ios_xe_interfaces_switchport_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_switchport_"] = "Cisco-IOS-XE-vlan:switchport"

                self.cisco_ios_xe_interfaces_stackwise_virtual_ = Native.Interface.Vlan.CiscoIOSXEInterfacesStackwiseVirtual_()
                self.cisco_ios_xe_interfaces_stackwise_virtual_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_stackwise_virtual_"] = "Cisco-IOS-XE-vlan:stackwise-virtual"

                self.cisco_ios_xe_interfaces_arp_ = Native.Interface.Vlan.CiscoIOSXEInterfacesArp_()
                self.cisco_ios_xe_interfaces_arp_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_arp_"] = "Cisco-IOS-XE-vlan:arp"

                self.cisco_ios_xe_interfaces_backup_ = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_()
                self.cisco_ios_xe_interfaces_backup_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_backup_"] = "Cisco-IOS-XE-vlan:backup"

                self.cisco_ios_xe_interfaces_cemoudp_ = Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp_()
                self.cisco_ios_xe_interfaces_cemoudp_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_cemoudp_"] = "Cisco-IOS-XE-vlan:cemoudp"

                self.cisco_ios_xe_interfaces_cws_tunnel_ = Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel_()
                self.cisco_ios_xe_interfaces_cws_tunnel_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_cws_tunnel_"] = "Cisco-IOS-XE-vlan:cws-tunnel"

                self.cisco_ios_xe_interfaces_l2protocol_tunnel_ = None
                self._children_name_map["cisco_ios_xe_interfaces_l2protocol_tunnel_"] = "Cisco-IOS-XE-vlan:l2protocol-tunnel"

                self.cisco_ios_xe_interfaces_encapsulation_ = Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_()
                self.cisco_ios_xe_interfaces_encapsulation_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_encapsulation_"] = "Cisco-IOS-XE-vlan:encapsulation"

                self.cisco_ios_xe_interfaces_fair_queue_conf_ = Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueueConf_()
                self.cisco_ios_xe_interfaces_fair_queue_conf_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_fair_queue_conf_"] = "Cisco-IOS-XE-vlan:fair-queue-conf"

                self.cisco_ios_xe_interfaces_fair_queue_ = Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueue_()
                self.cisco_ios_xe_interfaces_fair_queue_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_fair_queue_"] = "Cisco-IOS-XE-vlan:fair-queue"

                self.cisco_ios_xe_interfaces_flowcontrol_ = Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol_()
                self.cisco_ios_xe_interfaces_flowcontrol_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_flowcontrol_"] = "Cisco-IOS-XE-vlan:flowcontrol"

                self.cisco_ios_xe_interfaces_isis_ = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis_()
                self.cisco_ios_xe_interfaces_isis_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_isis_"] = "Cisco-IOS-XE-vlan:isis"

                self.keepalive_settings_ = Native.Interface.Vlan.KeepaliveSettings_()
                self.keepalive_settings_.parent = self
                self._children_name_map["keepalive_settings_"] = "Cisco-IOS-XE-vlan:keepalive-settings"

                self.cisco_ios_xe_interfaces_bfd_ = Native.Interface.Vlan.CiscoIOSXEInterfacesBfd_()
                self.cisco_ios_xe_interfaces_bfd_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_bfd_"] = "Cisco-IOS-XE-vlan:bfd"

                self.cisco_ios_xe_interfaces_bandwidth_ = Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_()
                self.cisco_ios_xe_interfaces_bandwidth_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_bandwidth_"] = "Cisco-IOS-XE-vlan:bandwidth"

                self.cisco_ios_xe_interfaces_dampening_ = Native.Interface.Vlan.CiscoIOSXEInterfacesDampening_()
                self.cisco_ios_xe_interfaces_dampening_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_dampening_"] = "Cisco-IOS-XE-vlan:dampening"

                self.cisco_ios_xe_interfaces_domain_ = Native.Interface.Vlan.CiscoIOSXEInterfacesDomain_()
                self.cisco_ios_xe_interfaces_domain_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_domain_"] = "Cisco-IOS-XE-vlan:domain"

                self.cisco_ios_xe_interfaces_mpls_ = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls_()
                self.cisco_ios_xe_interfaces_mpls_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_mpls_"] = "Cisco-IOS-XE-vlan:mpls"

                self.ip_vrf_ = Native.Interface.Vlan.IpVrf_()
                self.ip_vrf_.parent = self
                self._children_name_map["ip_vrf_"] = "Cisco-IOS-XE-vlan:ip-vrf"

                self.vrf_ = Native.Interface.Vlan.Vrf_()
                self.vrf_.parent = self
                self._children_name_map["vrf_"] = "Cisco-IOS-XE-vlan:vrf"

                self.cisco_ios_xe_interfaces_ip_ = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_()
                self.cisco_ios_xe_interfaces_ip_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_ip_"] = "Cisco-IOS-XE-vlan:ip"

                self.cisco_ios_xe_interfaces_ipv6_ = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_()
                self.cisco_ios_xe_interfaces_ipv6_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_ipv6_"] = "Cisco-IOS-XE-vlan:ipv6"

                self.cisco_ios_xe_interfaces_logging_ = Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_()
                self.cisco_ios_xe_interfaces_logging_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_logging_"] = "Cisco-IOS-XE-vlan:logging"

                self.cisco_ios_xe_interfaces_mdix_ = Native.Interface.Vlan.CiscoIOSXEInterfacesMdix_()
                self.cisco_ios_xe_interfaces_mdix_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_mdix_"] = "Cisco-IOS-XE-vlan:mdix"

                self.cisco_ios_xe_interfaces_mop_ = Native.Interface.Vlan.CiscoIOSXEInterfacesMop_()
                self.cisco_ios_xe_interfaces_mop_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_mop_"] = "Cisco-IOS-XE-vlan:mop"

                self.cisco_ios_xe_interfaces_interface_qos_ = Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_()
                self.cisco_ios_xe_interfaces_interface_qos_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_interface_qos_"] = "Cisco-IOS-XE-vlan:interface_qos"

                self.cisco_ios_xe_interfaces_source_ = Native.Interface.Vlan.CiscoIOSXEInterfacesSource_()
                self.cisco_ios_xe_interfaces_source_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_source_"] = "Cisco-IOS-XE-vlan:source"

                self.cisco_ios_xe_interfaces_standby_ = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_()
                self.cisco_ios_xe_interfaces_standby_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_standby_"] = "Cisco-IOS-XE-vlan:standby"

                self.cisco_ios_xe_interfaces_access_session_ = Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_()
                self.cisco_ios_xe_interfaces_access_session_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_access_session_"] = "Cisco-IOS-XE-vlan:access-session"

                self.cisco_ios_xe_interfaces_storm_control_ = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_()
                self.cisco_ios_xe_interfaces_storm_control_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_storm_control_"] = "Cisco-IOS-XE-vlan:storm-control"

                self.cisco_ios_xe_interfaces_trust_ = Native.Interface.Vlan.CiscoIOSXEInterfacesTrust_()
                self.cisco_ios_xe_interfaces_trust_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_trust_"] = "Cisco-IOS-XE-vlan:trust"

                self.cisco_ios_xe_interfaces_priority_queue_ = Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue_()
                self.cisco_ios_xe_interfaces_priority_queue_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_priority_queue_"] = "Cisco-IOS-XE-vlan:priority-queue"

                self.cisco_ios_xe_interfaces_rcv_queue_ = Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue_()
                self.cisco_ios_xe_interfaces_rcv_queue_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_rcv_queue_"] = "Cisco-IOS-XE-vlan:rcv-queue"

                self.cisco_ios_xe_interfaces_peer_ = Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_()
                self.cisco_ios_xe_interfaces_peer_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_peer_"] = "Cisco-IOS-XE-vlan:peer"

                self.cisco_ios_xe_interfaces_pm_path_ = Native.Interface.Vlan.CiscoIOSXEInterfacesPmPath_()
                self.cisco_ios_xe_interfaces_pm_path_.parent = self
                self._children_name_map["cisco_ios_xe_interfaces_pm_path_"] = "Cisco-IOS-XE-vlan:pm-path"

                self.vrrp = Native.Interface.Vlan.Vrrp()
                self.vrrp.parent = self
                self._children_name_map["vrrp"] = "Cisco-IOS-XE-vrrp:vrrp"

                self.cts = Native.Interface.Vlan.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.cisco_ios_xe_interfaces_hold_queue = YList(self)
                self.cisco_ios_xe_interfaces_hold_queue_ = YList(self)
                self._segment_path = lambda: "Vlan" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Vlan, [u'name', u'cisco_ios_xe_interfaces_description', u'cisco_ios_xe_interfaces_mac_address', u'cisco_ios_xe_interfaces_shutdown', u'keepalive', u'cisco_ios_xe_interfaces_if_state', u'cisco_ios_xe_interfaces_delay', u'cisco_ios_xe_interfaces_load_interval', u'cisco_ios_xe_interfaces_max_reserved_bandwidth', u'cisco_ios_xe_interfaces_mtu', u'cisco_ios_xe_interfaces_service_insertion', 'channel_protocol', 'duplex', u'cisco_ios_xe_interfaces_description_', u'cisco_ios_xe_interfaces_mac_address_', u'cisco_ios_xe_interfaces_shutdown_', u'keepalive_', u'cisco_ios_xe_interfaces_if_state_', u'cisco_ios_xe_interfaces_delay_', u'cisco_ios_xe_interfaces_load_interval_', u'cisco_ios_xe_interfaces_max_reserved_bandwidth_', u'cisco_ios_xe_interfaces_mtu_', u'cisco_ios_xe_interfaces_service_insertion_'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class IfState_(Enum):
                """
                IfState\_ (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")


            class ServiceInsertion_(Enum):
                """
                ServiceInsertion\_ (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class CiscoIOSXEInterfacesSwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchportConf, [u'switchport'], name, value)


            class CiscoIOSXEInterfacesSwitchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class CiscoIOSXEInterfacesStackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesStackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class CiscoIOSXEInterfacesArp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesArp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesArp, [u'timeout'], name, value)


            class CiscoIOSXEInterfacesBackup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Delay)), ("interface", ("interface", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_)), ("load", ("load", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class CiscoIOSXEInterfacesCemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp.Reserve, [u'acr'], name, value)


            class CiscoIOSXEInterfacesCwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel.Out, [u'tunnel_number'], name, value)


            class CiscoIOSXEInterfacesL2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class CiscoIOSXEInterfacesEncapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Ppp)), ("slip", ("slip", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation.FrameRelay, [u'ietf'], name, value)


            class CiscoIOSXEInterfacesFairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueueConf, [u'fair_queue'], name, value)


            class CiscoIOSXEInterfacesFairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueue, [u'incomplete'], name, value)


            class CiscoIOSXEInterfacesFlowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class CiscoIOSXEInterfacesIsis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIsis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIsis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIsis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIsis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIsis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIsis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIsis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIsis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Vlan.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class CiscoIOSXEInterfacesBfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesBfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.Vlan.CiscoIOSXEInterfacesBfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.Vlan.CiscoIOSXEInterfacesBfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesBfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class CiscoIOSXEInterfacesBandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth.Inherit, [u'kilobits'], name, value)


            class CiscoIOSXEInterfacesDampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesDampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesDampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Vlan.CiscoIOSXEInterfacesDampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Vlan.CiscoIOSXEInterfacesDampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesDampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesDampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesDampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class CiscoIOSXEInterfacesDomain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesDomain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesDomain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class CiscoIOSXEInterfacesHoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesHoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesHoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesHoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesHoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class CiscoIOSXEInterfacesMpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesMpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Vlan.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Vlan.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Vlan.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Vlan.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Vrf, [u'forwarding'], name, value)


            class CiscoIOSXEInterfacesIp(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Nbar>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup)), ("arp", ("arp", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp)), ("vrf", ("vrf", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Vrf)), ("no-address", ("no_address", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.NoAddress)), ("address", ("address", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HelloInterval)), ("authentication", ("authentication", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication)), ("hold-time", ("hold_time", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HelperAddress)), ("pim", ("pim", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim)), ("policy", ("policy", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Policy)), ("rip", ("rip", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.RouteCache)), ("router", ("router", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Router)), ("tcp", ("tcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.SummaryAddress)), ("verify", ("verify", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Nbar))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None
                    self.unreachables = None

                    self.access_group = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.nbar = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache', 'unreachables'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In)), ("out", ("out", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Secondary)), ("primary", ("primary", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Option)), ("request", ("request", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Request)), ("route", ("route", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan_(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Dhcp.Snooping.Vlan_.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source)), ("unicast", ("unicast", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source.Vlan_>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source.Vlan_))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source.Vlan_()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source, [], name, value)


                        class Vlan_(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source.Vlan_.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source.Vlan_, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source.Vlan_.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source.Vlan_, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source.Vlan_.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Source.Vlan_.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIp.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



            class CiscoIOSXEInterfacesIpv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.TrafficFilter>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Crypto>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Pim>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp)), ("address", ("address", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address)), ("nd", ("nd", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Nd)), ("tcp", ("tcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.TrafficFilter)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Crypto)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Pim))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.crypto = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.no_pim = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIpv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Crypto, ['map'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6.Pim.Bsr, ['border'], name, value)


            class CiscoIOSXEInterfacesLogging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class CiscoIOSXEInterfacesMdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesMdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMdix, [u'auto'], name, value)


            class CiscoIOSXEInterfacesMop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesMop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMop, [u'enabled', u'sysid'], name, value)


            class CiscoIOSXEInterfacesInterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class CiscoIOSXEInterfacesSource(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesSource.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesSource, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Vlan.CiscoIOSXEInterfacesSource.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Vlan.CiscoIOSXEInterfacesSource.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesSource, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesSource.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesSource.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Vlan.CiscoIOSXEInterfacesSource.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesSource.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesSource.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesSource.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class CiscoIOSXEInterfacesStandby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.Delay)), ("use-bia", ("use_bia", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesStandby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers)), ("track", ("track", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class CiscoIOSXEInterfacesAccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesAccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession.ControlDirection, [u'in_'], name, value)


            class CiscoIOSXEInterfacesStormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class CiscoIOSXEInterfacesTrust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesTrust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesTrust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesTrust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesTrust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class CiscoIOSXEInterfacesPriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class CiscoIOSXEInterfacesRcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class CiscoIOSXEInterfacesPeer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class CiscoIOSXEInterfacesPmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesPmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.Vlan.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.Vlan.CarrierDelay.Down)), ("up", ("up", Native.Interface.Vlan.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.Vlan.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.Vlan.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.Vlan.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.Vlan.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.Vlan.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.Vlan.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.Vlan.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.Vlan.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.Vlan.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.Vlan.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.Vlan.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.Vlan.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.Vlan.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.Vlan.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.Vlan.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.Vlan.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.Vlan.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.Vlan.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.Vlan.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.Vlan.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.Vlan.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.Vlan.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.Vlan.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.Vlan.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.Vlan.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.Vlan.Plim.Ethernet)), ("qos", ("qos", Native.Interface.Vlan.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.Vlan.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.Vlan.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Plim.Ethernet.Vlan_>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.Vlan.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Vlan.Plim.Ethernet.Vlan_))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.Vlan.Plim.Ethernet.Vlan_()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Plim.Ethernet, [], name, value)


                    class Vlan_(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Plim.Ethernet.Vlan_.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Plim.Ethernet.Vlan_, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.Vlan.Plim.Ethernet.Vlan_.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.Vlan.Plim.Ethernet.Vlan_.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Plim.Ethernet.Vlan_, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Plim.Ethernet.Vlan_.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Plim.Ethernet.Vlan_.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.Vlan.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.Vlan.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.Vlan.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.Vlan.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.Vlan.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.Vlan.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.Vlan.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.Vlan.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.Vlan.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.Vlan.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.Vlan.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.Vlan.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.Vlan.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.Vlan.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.Vlan.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.Vlan.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.Vlan.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.Vlan.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.L2protocol>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.Vlan.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.Vlan.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.Vlan.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.Vlan.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.Vlan.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.Vlan.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.Vlan.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.Vlan.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.Vlan.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.Vlan.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.Vlan.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.Vlan.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.Vlan.Service.Instance.L2protocol))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.Vlan.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.Vlan.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.Vlan.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.Vlan.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.Vlan.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.Vlan.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.Vlan.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.Vlan.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.Vlan.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.Vlan.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.Vlan.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.Vlan.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.Vlan.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.Vlan.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.Vlan.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.Vlan.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.Vlan.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.Vlan.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.Vlan.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.Vlan.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.Vlan.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.Vlan.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.Vlan.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.Vlan.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.Vlan.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.Vlan.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.Vlan.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.Vlan.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.Vlan.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.Vlan.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.Vlan.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.Vlan.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.Vlan.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.Vlan.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.Vlan.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.Vlan.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.Vlan.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.Vlan.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.Vlan.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.Vlan.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.Vlan.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.Vlan.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.Vlan.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.Vlan.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.Vlan.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.Vlan.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.Vlan.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.Vlan.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.Vlan.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.Vlan.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vlan.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.Vlan.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.Vlan.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.Vlan.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.Vlan.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.Vlan.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.Vlan.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.Vlan.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.Vlan.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.Vlan.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.Vlan.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.Vlan.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.Vlan.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vlan.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.Vlan.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.Vlan.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.Vlan.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.Vlan.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vlan.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.Vlan.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vlan.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Utd, ['enable'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.Vlan.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.Vlan.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.Vlan.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.Vlan.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.Vlan.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.Vlan.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.Vlan.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.Vlan.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.Vlan.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.Vlan.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.Vlan.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.Vlan.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.Vlan.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.Vlan.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vlan.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.Vlan.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.Vlan.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.Vlan.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.Vlan.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpdufilter
                
                	Don't send or receive BPDUs on this interface
                	**type**\:  :py:class:`Bpdufilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.SpanningTree.Bpdufilter>`
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.SpanningTree.Bpduguard>`
                
                .. attribute:: cost
                
                	To set the path cost of the interface
                	**type**\: int
                
                	**range:** 1..200000000
                
                .. attribute:: guard
                
                	Change an interface's spanning tree guard mode
                	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.SpanningTree.Guard>`
                
                .. attribute:: link_type
                
                	Specify a link type for spanning tree tree protocol use
                	**type**\:  :py:class:`LinkType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.SpanningTree.LinkType>`
                
                .. attribute:: portfast
                
                	Spanning tree portfast options
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                .. attribute:: port_priority
                
                	Spanning tree port\-priority options
                	**type**\: int
                
                	**range:** 0..240
                
                .. attribute:: vlan
                
                	VLAN Switch Spanning Tree
                	**type**\: list of  		 :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.SpanningTree.Vlan_>`
                
                .. attribute:: loopguard
                
                	Spanning tree loopguard options
                	**type**\:  :py:class:`Loopguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.SpanningTree.Loopguard>`
                
                .. attribute:: mst
                
                	Per interface MST configurations
                	**type**\:  :py:class:`Mst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.SpanningTree.Mst>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.Vlan.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Interface.Vlan.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Interface.Vlan.SpanningTree.Portfast)), ("vlan", ("vlan", Native.Interface.Vlan.SpanningTree.Vlan_)), ("loopguard", ("loopguard", Native.Interface.Vlan.SpanningTree.Loopguard)), ("mst", ("mst", Native.Interface.Vlan.SpanningTree.Mst))])
                    self._leafs = OrderedDict([
                        ('bpdufilter', (YLeaf(YType.enumeration, 'bpdufilter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.SpanningTree.Bpdufilter')])),
                        ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ('guard', (YLeaf(YType.enumeration, 'guard'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.SpanningTree.Guard')])),
                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.SpanningTree.LinkType')])),
                        ('port_priority', (YLeaf(YType.uint8, 'port-priority'), ['int'])),
                    ])
                    self.bpdufilter = None
                    self.cost = None
                    self.guard = None
                    self.link_type = None
                    self.port_priority = None

                    self.bpduguard = Native.Interface.Vlan.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"

                    self.loopguard = Native.Interface.Vlan.SpanningTree.Loopguard()
                    self.loopguard.parent = self
                    self._children_name_map["loopguard"] = "loopguard"

                    self.mst = Native.Interface.Vlan.SpanningTree.Mst()
                    self.mst.parent = self
                    self._children_name_map["mst"] = "mst"

                    self.vlan = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:spanning-tree"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.SpanningTree, ['bpdufilter', 'cost', 'guard', 'link_type', 'port_priority'], name, value)

                class Bpdufilter(Enum):
                    """
                    Bpdufilter (Enum Class)

                    Don't send or receive BPDUs on this interface

                    .. data:: disable = 0

                    .. data:: enable = 1

                    """

                    disable = Enum.YLeaf(0, "disable")

                    enable = Enum.YLeaf(1, "enable")


                class Guard(Enum):
                    """
                    Guard (Enum Class)

                    Change an interface's spanning tree guard mode

                    .. data:: loop = 0

                    .. data:: none = 1

                    .. data:: root = 2

                    """

                    loop = Enum.YLeaf(0, "loop")

                    none = Enum.YLeaf(1, "none")

                    root = Enum.YLeaf(2, "root")


                class LinkType(Enum):
                    """
                    LinkType (Enum Class)

                    Specify a link type for spanning tree tree protocol use

                    .. data:: point_to_point = 0

                    .. data:: shared = 1

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")

                    shared = Enum.YLeaf(1, "shared")



                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Vlan.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.disable = None
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.SpanningTree.Bpduguard, ['disable', 'enable'], name, value)


                class Portfast(Entity):
                    """
                    Spanning tree portfast options
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk
                    
                    	Enable portfast on the interface even in trunk mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Vlan.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                        ])
                        self.disable = None
                        self.trunk = None
                        self.edge = None
                        self._segment_path = lambda: "portfast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.SpanningTree.Portfast, ['disable', 'trunk', 'edge'], name, value)


                class Vlan_(Entity):
                    """
                    VLAN Switch Spanning Tree
                    
                    .. attribute:: vlan_ids  (key)
                    
                    	vlan range, example\: 1,3\-5,7,9\-11
                    	**type**\: str
                    
                    .. attribute:: cost
                    
                    	<1\-200000000> Spanning\-tree cost
                    	**type**\: int
                    
                    	**range:** 1..200000000
                    
                    .. attribute:: port_priority
                    
                    	<0\-240> port priority in increments of 16
                    	**type**\: int
                    
                    	**range:** 0..240
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Vlan.SpanningTree.Vlan_, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vlan_ids']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_ids', (YLeaf(YType.str, 'vlan-ids'), ['str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                        ])
                        self.vlan_ids = None
                        self.cost = None
                        self.port_priority = None
                        self._segment_path = lambda: "vlan" + "[vlan-ids='" + str(self.vlan_ids) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.SpanningTree.Vlan_, ['vlan_ids', 'cost', 'port_priority'], name, value)


                class Loopguard(Entity):
                    """
                    Spanning tree loopguard options
                    
                    .. attribute:: default
                    
                    	Enable loopguard by default on all ports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Vlan.SpanningTree.Loopguard, self).__init__()

                        self.yang_name = "loopguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.default = None
                        self._segment_path = lambda: "loopguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.SpanningTree.Loopguard, ['default'], name, value)


                class Mst(Entity):
                    """
                    Per interface MST configurations
                    
                    .. attribute:: mst_instance
                    
                    	
                    	**type**\: list of  		 :py:class:`MstInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.SpanningTree.Mst.MstInstance>`
                    
                    .. attribute:: pre_standard
                    
                    	Force pre\-standard MST BPDU transmission on port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Vlan.SpanningTree.Mst, self).__init__()

                        self.yang_name = "mst"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mst-instance", ("mst_instance", Native.Interface.Vlan.SpanningTree.Mst.MstInstance))])
                        self._leafs = OrderedDict([
                            ('pre_standard', (YLeaf(YType.empty, 'pre-standard'), ['Empty'])),
                        ])
                        self.pre_standard = None

                        self.mst_instance = YList(self)
                        self._segment_path = lambda: "mst"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.SpanningTree.Mst, ['pre_standard'], name, value)


                    class MstInstance(Entity):
                        """
                        
                        
                        .. attribute:: instance  (key)
                        
                        	MST instance list, example 0,2\-4,6,8\-12
                        	**type**\: str
                        
                        .. attribute:: cost
                        
                        	<1\-200000000> Spanning\-tree cost
                        	**type**\: int
                        
                        	**range:** 1..200000000
                        
                        .. attribute:: port_priority
                        
                        	<0\-240> port priority in increments of 16
                        	**type**\: int
                        
                        	**range:** 0..240
                        
                        

                        """

                        _prefix = 'ios-stp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vlan.SpanningTree.Mst.MstInstance, self).__init__()

                            self.yang_name = "mst-instance"
                            self.yang_parent_name = "mst"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('port_priority', (YLeaf(YType.uint16, 'port-priority'), ['int'])),
                            ])
                            self.instance = None
                            self.cost = None
                            self.port_priority = None
                            self._segment_path = lambda: "mst-instance" + "[instance='" + str(self.instance) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.SpanningTree.Mst.MstInstance, ['instance', 'cost', 'port_priority'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.Vlan.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Umbrella, ['out', 'in_'], name, value)


            class PrivateVlan(Entity):
                """
                Configure private VLAN SVI interface settings
                
                .. attribute:: mapping
                
                	Set the private VLAN SVI interface mapping
                	**type**\: str
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.PrivateVlan, self).__init__()

                    self.yang_name = "private-vlan"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mapping', (YLeaf(YType.str, 'mapping'), ['str'])),
                    ])
                    self.mapping = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:private-vlan"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.PrivateVlan, ['mapping'], name, value)


            class ServiceRouting(Entity):
                """
                Service Routing in Interface Mode
                
                .. attribute:: mdns_sd
                
                	Service\-Routing mdns\-sd configuration in interface mode
                	**type**\:  :py:class:`MdnsSd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServiceRouting.MdnsSd>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.ServiceRouting, self).__init__()

                    self.yang_name = "service-routing"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mdns-sd", ("mdns_sd", Native.Interface.Vlan.ServiceRouting.MdnsSd))])
                    self._leafs = OrderedDict()

                    self.mdns_sd = None
                    self._children_name_map["mdns_sd"] = "mdns-sd"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:service-routing"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.ServiceRouting, [], name, value)


                class MdnsSd(Entity):
                    """
                    Service\-Routing mdns\-sd configuration in interface mode
                    
                    .. attribute:: redistribute
                    
                    	Redistribution of services
                    	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.ServiceRouting.MdnsSd.Redistribute>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.ServiceRouting.MdnsSd, self).__init__()

                        self.yang_name = "mdns-sd"
                        self.yang_parent_name = "service-routing"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redistribute", ("redistribute", Native.Interface.Vlan.ServiceRouting.MdnsSd.Redistribute))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.redistribute = Native.Interface.Vlan.ServiceRouting.MdnsSd.Redistribute()
                        self.redistribute.parent = self
                        self._children_name_map["redistribute"] = "redistribute"
                        self._segment_path = lambda: "mdns-sd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.ServiceRouting.MdnsSd, [], name, value)


                    class Redistribute(Entity):
                        """
                        Redistribution of services
                        
                        .. attribute:: mdns_sd
                        
                        	Redistribution of services
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: withdraw_only
                        
                        	Enable redistribution only for service withdraw
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.ServiceRouting.MdnsSd.Redistribute, self).__init__()

                            self.yang_name = "redistribute"
                            self.yang_parent_name = "mdns-sd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mdns_sd', (YLeaf(YType.empty, 'mdns-sd'), ['Empty'])),
                                ('withdraw_only', (YLeaf(YType.empty, 'withdraw-only'), ['Empty'])),
                            ])
                            self.mdns_sd = None
                            self.withdraw_only = None
                            self._segment_path = lambda: "redistribute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.ServiceRouting.MdnsSd.Redistribute, ['mdns_sd', 'withdraw_only'], name, value)


            class Glbp(Entity):
                """
                Gateway Load Balancing Protocol interface commands
                
                .. attribute:: range
                
                	
                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.Glbp, self).__init__()

                    self.yang_name = "glbp"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("range", ("range", Native.Interface.Vlan.Glbp.Range))])
                    self._leafs = OrderedDict()

                    self.range = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:glbp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Glbp, [], name, value)


                class Range(Entity):
                    """
                    
                    
                    .. attribute:: range  (key)
                    
                    	Group number
                    	**type**\: int
                    
                    	**range:** 0..1023
                    
                    .. attribute:: forwarder
                    
                    	Forwarder configuration
                    	**type**\:  :py:class:`Forwarder <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Forwarder>`
                    
                    .. attribute:: ip
                    
                    	Enable group and set virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority designated routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority value
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: weighting
                    
                    	Gateway weighting and tracking
                    	**type**\:  :py:class:`Weighting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Weighting>`
                    
                    .. attribute:: timers
                    
                    	Adjust GLBP timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Timers>`
                    
                    .. attribute:: name
                    
                    	Redundancy name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.Glbp.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "glbp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("forwarder", ("forwarder", Native.Interface.Vlan.Glbp.Range.Forwarder)), ("ip", ("ip", Native.Interface.Vlan.Glbp.Range.Ip)), ("preempt", ("preempt", Native.Interface.Vlan.Glbp.Range.Preempt)), ("weighting", ("weighting", Native.Interface.Vlan.Glbp.Range.Weighting)), ("timers", ("timers", Native.Interface.Vlan.Glbp.Range.Timers))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.range = None
                        self.priority = None
                        self.name = None

                        self.forwarder = Native.Interface.Vlan.Glbp.Range.Forwarder()
                        self.forwarder.parent = self
                        self._children_name_map["forwarder"] = "forwarder"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.weighting = Native.Interface.Vlan.Glbp.Range.Weighting()
                        self.weighting.parent = self
                        self._children_name_map["weighting"] = "weighting"

                        self.timers = Native.Interface.Vlan.Glbp.Range.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"
                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Glbp.Range, ['range', 'priority', 'name'], name, value)


                    class Forwarder(Entity):
                        """
                        Forwarder configuration
                        
                        .. attribute:: preempt
                        
                        	Overthrow lower priority active forwarders
                        	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Forwarder.Preempt>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.Glbp.Range.Forwarder, self).__init__()

                            self.yang_name = "forwarder"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("preempt", ("preempt", Native.Interface.Vlan.Glbp.Range.Forwarder.Preempt))])
                            self._leafs = OrderedDict()

                            self.preempt = None
                            self._children_name_map["preempt"] = "preempt"
                            self._segment_path = lambda: "forwarder"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Forwarder, [], name, value)


                        class Preempt(Entity):
                            """
                            Overthrow lower priority active forwarders
                            
                            .. attribute:: delay
                            
                            	Wait before preempting
                            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Forwarder.Preempt.Delay>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.Glbp.Range.Forwarder.Preempt, self).__init__()

                                self.yang_name = "preempt"
                                self.yang_parent_name = "forwarder"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vlan.Glbp.Range.Forwarder.Preempt.Delay))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.delay = Native.Interface.Vlan.Glbp.Range.Forwarder.Preempt.Delay()
                                self.delay.parent = self
                                self._children_name_map["delay"] = "delay"
                                self._segment_path = lambda: "preempt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Forwarder.Preempt, [], name, value)


                            class Delay(Entity):
                                """
                                Wait before preempting
                                
                                .. attribute:: minimum
                                
                                	Number of seconds for minimum delay
                                	**type**\: int
                                
                                	**range:** 0..3600
                                
                                

                                """

                                _prefix = 'ios-vlan'
                                _revision = '2018-03-13'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Glbp.Range.Forwarder.Preempt.Delay, self).__init__()

                                    self.yang_name = "delay"
                                    self.yang_parent_name = "preempt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ])
                                    self.minimum = None
                                    self._segment_path = lambda: "delay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Forwarder.Preempt.Delay, ['minimum'], name, value)


                    class Ip(Entity):
                        """
                        Enable group and set virtual IP address
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Ip.Ipv4>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.Glbp.Range.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.Vlan.Glbp.Range.Ip.Ipv4))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.ipv4 = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Ip, [], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	Virtual IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.Glbp.Range.Ip.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ])
                                self.ipv4 = None
                                self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Ip.Ipv4, ['ipv4'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority designated routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.Glbp.Range.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vlan.Glbp.Range.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Vlan.Glbp.Range.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Number of seconds for minimum delay
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.Glbp.Range.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                ])
                                self.minimum = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Preempt.Delay, ['minimum'], name, value)


                    class Weighting(Entity):
                        """
                        Gateway weighting and tracking
                        
                        .. attribute:: value
                        
                        	Weighting maximum value
                        	**type**\: list of  		 :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Weighting.Value>`
                        
                        .. attribute:: track
                        
                        	Interface tracking
                        	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Weighting.Track>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.Glbp.Range.Weighting, self).__init__()

                            self.yang_name = "weighting"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.Vlan.Glbp.Range.Weighting.Value)), ("track", ("track", Native.Interface.Vlan.Glbp.Range.Weighting.Track))])
                            self._leafs = OrderedDict()

                            self.track = Native.Interface.Vlan.Glbp.Range.Weighting.Track()
                            self.track.parent = self
                            self._children_name_map["track"] = "track"

                            self.value = YList(self)
                            self._segment_path = lambda: "weighting"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Weighting, [], name, value)


                        class Value(Entity):
                            """
                            Weighting maximum value
                            
                            .. attribute:: value  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-128..127
                            
                            .. attribute:: upper
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-128..127
                            
                            .. attribute:: lower
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-128..127
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.Glbp.Range.Weighting.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "weighting"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['value']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.int8, 'value'), ['int'])),
                                    ('upper', (YLeaf(YType.int8, 'upper'), ['int'])),
                                    ('lower', (YLeaf(YType.int8, 'lower'), ['int'])),
                                ])
                                self.value = None
                                self.upper = None
                                self.lower = None
                                self._segment_path = lambda: "value" + "[value='" + str(self.value) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Weighting.Value, ['value', 'upper', 'lower'], name, value)


                        class Track(Entity):
                            """
                            Interface tracking
                            
                            .. attribute:: range
                            
                            	
                            	**type**\: list of  		 :py:class:`Range_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Weighting.Track.Range_>`
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.Glbp.Range.Weighting.Track, self).__init__()

                                self.yang_name = "track"
                                self.yang_parent_name = "weighting"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("range", ("range", Native.Interface.Vlan.Glbp.Range.Weighting.Track.Range_))])
                                self._leafs = OrderedDict()

                                self.range = YList(self)
                                self._segment_path = lambda: "track"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Weighting.Track, [], name, value)


                            class Range_(Entity):
                                """
                                
                                
                                .. attribute:: range  (key)
                                
                                	Tracked object
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                .. attribute:: decrement
                                
                                	Decrement value
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-vlan'
                                _revision = '2018-03-13'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Glbp.Range.Weighting.Track.Range_, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "track"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                        ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                    ])
                                    self.range = None
                                    self.decrement = None
                                    self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Weighting.Track.Range_, ['range', 'decrement'], name, value)


                    class Timers(Entity):
                        """
                        Adjust GLBP timers
                        
                        .. attribute:: msec
                        
                        	Specify hello interval in milliseconds
                        	**type**\:  :py:class:`Msec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Timers.Msec>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.Glbp.Range.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("msec", ("msec", Native.Interface.Vlan.Glbp.Range.Timers.Msec))])
                            self._leafs = OrderedDict()

                            self.msec = Native.Interface.Vlan.Glbp.Range.Timers.Msec()
                            self.msec.parent = self
                            self._children_name_map["msec"] = "msec"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Timers, [], name, value)


                        class Msec(Entity):
                            """
                            Specify hello interval in milliseconds
                            
                            .. attribute:: range
                            
                            	
                            	**type**\: list of  		 :py:class:`Range_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Glbp.Range.Timers.Msec.Range_>`
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.Glbp.Range.Timers.Msec, self).__init__()

                                self.yang_name = "msec"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("range", ("range", Native.Interface.Vlan.Glbp.Range.Timers.Msec.Range_))])
                                self._leafs = OrderedDict()

                                self.range = YList(self)
                                self._segment_path = lambda: "msec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Timers.Msec, [], name, value)


                            class Range_(Entity):
                                """
                                
                                
                                .. attribute:: range  (key)
                                
                                	Hello interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 50..60000
                                
                                .. attribute:: range0
                                
                                	Hold time in seconds
                                	**type**\: int
                                
                                	**range:** 1..180
                                
                                

                                """

                                _prefix = 'ios-vlan'
                                _revision = '2018-03-13'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Glbp.Range.Timers.Msec.Range_, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "msec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                        ('range0', (YLeaf(YType.uint8, 'range0'), ['int'])),
                                    ])
                                    self.range = None
                                    self.range0 = None
                                    self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Glbp.Range.Timers.Msec.Range_, ['range', 'range0'], name, value)


            class CiscoIOSXEInterfacesSwitchportConf_(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchportConf_, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchportConf_, [u'switchport'], name, value)


            class CiscoIOSXEInterfacesSwitchport_(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesSwitchport_, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:switchport"
                    self._is_frozen = True


            class CiscoIOSXEInterfacesStackwiseVirtual_(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesStackwiseVirtual_, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStackwiseVirtual_, [u'link', u'dual_active_detection'], name, value)


            class CiscoIOSXEInterfacesArp_(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesArp_, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesArp_, [u'timeout'], name, value)


            class CiscoIOSXEInterfacesBackup_(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Load>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Delay)), ("interface", ("interface", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_)), ("load", ("load", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBackup_.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class CiscoIOSXEInterfacesCemoudp_(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp_.Reserve>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp_, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp_.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp_.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp_, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp_.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesCemoudp_.Reserve, [u'acr'], name, value)


            class CiscoIOSXEInterfacesCwsTunnel_(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel_.Out>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel_, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel_.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel_.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel_, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel_.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesCwsTunnel_.Out, [u'tunnel_number'], name, value)


            class CiscoIOSXEInterfacesL2protocolTunnel_(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesL2protocolTunnel_.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class CiscoIOSXEInterfacesEncapsulation_(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Dot1Q)), ("isl", ("isl", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Isl)), ("ppp", ("ppp", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Ppp)), ("slip", ("slip", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesEncapsulation_.FrameRelay, [u'ietf'], name, value)


            class CiscoIOSXEInterfacesFairQueueConf_(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueueConf_, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueueConf_, [u'fair_queue'], name, value)


            class CiscoIOSXEInterfacesFairQueue_(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueue_, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesFairQueue_, [u'incomplete'], name, value)


            class CiscoIOSXEInterfacesFlowcontrol_(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol_.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol_.Send>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol_, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol_.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol_.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesFlowcontrol_, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class CiscoIOSXEInterfacesIsis_(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIsis_, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:isis"
                    self._is_frozen = True


            class KeepaliveSettings_(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.KeepaliveSettings_.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.KeepaliveSettings_, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Vlan.KeepaliveSettings_.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.KeepaliveSettings_, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.KeepaliveSettings_.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.KeepaliveSettings_.Keepalive, [u'period', u'retries'], name, value)


            class CiscoIOSXEInterfacesBfd_(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesBfd_, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:bfd"
                    self._is_frozen = True


            class CiscoIOSXEInterfacesBandwidth_(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_.Receive)), ("inherit", ("inherit", Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesBandwidth_.Inherit, [u'kilobits'], name, value)


            class CiscoIOSXEInterfacesDampening_(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesDampening_.Restart>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesDampening_, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Vlan.CiscoIOSXEInterfacesDampening_.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Vlan.CiscoIOSXEInterfacesDampening_.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesDampening_, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesDampening_.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesDampening_.Restart, [u'restart', u'restart_penalty'], name, value)


            class CiscoIOSXEInterfacesDomain_(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesDomain_, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesDomain_, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class CiscoIOSXEInterfacesHoldQueue_(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesHoldQueue_.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesHoldQueue_, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesHoldQueue_.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesHoldQueue_, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class CiscoIOSXEInterfacesMpls_(Entity):
                """
                
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesMpls_, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:mpls"
                    self._is_frozen = True


            class IpVrf_(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.IpVrf_.Ip>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.IpVrf_, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Vlan.IpVrf_.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Vlan.IpVrf_.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.IpVrf_, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.IpVrf_.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.IpVrf_.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Vlan.IpVrf_.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Vlan.IpVrf_.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.IpVrf_.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.IpVrf_.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.IpVrf_.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf_(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.Vrf_, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Vrf_, [u'forwarding'], name, value)


            class CiscoIOSXEInterfacesIp_(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup)), ("arp", ("arp", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp)), ("vrf", ("vrf", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Vrf)), ("no-address", ("no_address", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.NoAddress)), ("address", ("address", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HelloInterval)), ("authentication", ("authentication", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication)), ("hold-time", ("hold_time", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HelperAddress)), ("pim", ("pim", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Pim)), ("policy", ("policy", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Policy)), ("rip", ("rip", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.RouteCache)), ("router", ("router", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Router)), ("tcp", ("tcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.SummaryAddress)), ("verify", ("verify", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In)), ("out", ("out", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Secondary)), ("primary", ("primary", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source)), ("unicast", ("unicast", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source.Vlan_>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source.Vlan_))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source.Vlan_()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source, [], name, value)


                        class Vlan_(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source.Vlan_.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source.Vlan_, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source.Vlan_.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source.Vlan_, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vlan'
                                _revision = '2018-03-13'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source.Vlan_.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Source.Vlan_.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIp_.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class CiscoIOSXEInterfacesIpv6_(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.TrafficFilter>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Dhcp)), ("address", ("address", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address)), ("nd", ("nd", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Nd)), ("tcp", ("tcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesIpv6_.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesIpv6_.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class CiscoIOSXEInterfacesLogging_(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesLogging_.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class CiscoIOSXEInterfacesMdix_(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesMdix_, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMdix_, [u'auto'], name, value)


            class CiscoIOSXEInterfacesMop_(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesMop_, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesMop_, [u'enabled', u'sysid'], name, value)


            class CiscoIOSXEInterfacesInterfaceQos_(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_.Trust>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesInterfaceQos_.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class CiscoIOSXEInterfacesSource_(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesSource_.Template>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesSource_, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Vlan.CiscoIOSXEInterfacesSource_.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Vlan.CiscoIOSXEInterfacesSource_.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesSource_, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesSource_.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesSource_.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Vlan.CiscoIOSXEInterfacesSource_.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesSource_.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesSource_.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesSource_.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class CiscoIOSXEInterfacesStandby_(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.Delay)), ("use-bia", ("use_bia", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.UseBia)), ("standby-list", ("standby_list", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesStandby_.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers)), ("track", ("track", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios-vlan'
                                _revision = '2018-03-13'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios-vlan'
                                _revision = '2018-03-13'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vlan'
                                    _revision = '2018-03-13'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios-vlan'
                                        _revision = '2018-03-13'

                                        def __init__(self):
                                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStandby_.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class CiscoIOSXEInterfacesAccessSession_(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.HostMode>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.PortControl)), ("control-direction", ("control_direction", Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesAccessSession_.ControlDirection, [u'in_'], name, value)


            class CiscoIOSXEInterfacesStormControl_(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Action)), ("broadcast", ("broadcast", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast)), ("multicast", ("multicast", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast)), ("unicast", ("unicast", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Include)), ("level", ("level", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesStormControl_.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class CiscoIOSXEInterfacesTrust_(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesTrust_.Device>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesTrust_, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vlan.CiscoIOSXEInterfacesTrust_.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesTrust_, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class CiscoIOSXEInterfacesPriorityQueue_(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue_.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue_, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue_.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue_.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue_, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue_.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPriorityQueue_.CosMap, [u'id', u'cos_values'], name, value)


            class CiscoIOSXEInterfacesRcvQueue_(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue_.CosMap>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue_, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue_.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue_, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue_.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesRcvQueue_.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class CiscoIOSXEInterfacesPeer_(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default>`
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios-vlan'
                    _revision = '2018-03-13'

                    def __init__(self):
                        super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios-vlan'
                        _revision = '2018-03-13'

                        def __init__(self):
                            super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-vlan'
                            _revision = '2018-03-13'

                            def __init__(self):
                                super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vlan'
                                _revision = '2018-03-13'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vlan'
                                _revision = '2018-03-13'

                                def __init__(self):
                                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPeer_.Default.Ip.Address.Pool, [u'pools'], name, value)


            class CiscoIOSXEInterfacesPmPath_(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios-vlan'
                _revision = '2018-03-13'

                def __init__(self):
                    super(Native.Interface.Vlan.CiscoIOSXEInterfacesPmPath_, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "Cisco-IOS-XE-vlan:pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.CiscoIOSXEInterfacesPmPath_, [u'name', u'interface_id'], name, value)


            class Vrrp(Entity):
                """
                Configure VRRP
                
                .. attribute:: vrrp_group
                
                	
                	**type**\: list of  		 :py:class:`VrrpGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup>`
                
                .. attribute:: vrrp_group_v2
                
                	vrrp version 2
                	**type**\: list of  		 :py:class:`VrrpGroupV2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroupV2>`
                
                .. attribute:: delay
                
                	
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.Delay>`
                
                

                """

                _prefix = 'ios-vrrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vlan.Vrrp, self).__init__()

                    self.yang_name = "vrrp"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrrp-group", ("vrrp_group", Native.Interface.Vlan.Vrrp.VrrpGroup)), ("vrrp-group-v2", ("vrrp_group_v2", Native.Interface.Vlan.Vrrp.VrrpGroupV2)), ("delay", ("delay", Native.Interface.Vlan.Vrrp.Delay))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Vlan.Vrrp.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.vrrp_group = YList(self)
                    self.vrrp_group_v2 = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-vrrp:vrrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Vrrp, [], name, value)


                class VrrpGroup(Entity):
                    """
                    
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: address_family
                    
                    	Address family of the group
                    	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.Vrrp.VrrpGroup, self).__init__()

                        self.yang_name = "vrrp-group"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("address-family", ("address_family", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                        ])
                        self.group_id = None

                        self.address_family = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"
                        self._segment_path = lambda: "vrrp-group" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup, ['group_id'], name, value)


                    class AddressFamily(Entity):
                        """
                        Address family of the group
                        
                        .. attribute:: ipv4
                        
                        	IPv4 Address family
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	IPv6 Address family
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily, self).__init__()

                            self.yang_name = "address-family"
                            self.yang_parent_name = "vrrp-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4)), ("ipv6", ("ipv6", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = None
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "address-family"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily, [], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 Address family
                            
                            .. attribute:: vrrpv2
                            
                            	Set VRRPv2 compatibility mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: address
                            
                            	Set the IPv4 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address)), ("preempt", ("preempt", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt)), ("timers", ("timers", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers)), ("track", ("track", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track)), ("vrrs", ("vrrs", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('vrrpv2', (YLeaf(YType.empty, 'vrrpv2'), ['Empty'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.vrrpv2 = None
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4, ['vrrpv2', 'description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv4 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary>`
                                
                                .. attribute:: secondary
                                
                                	
                                	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary)), ("secondary", ("secondary", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.secondary = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv4 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Primary, ['address', 'primary'], name, value)


                                class Secondary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: secondary
                                    
                                    	Make this IPv4 address a secondary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, self).__init__()

                                        self.yang_name = "secondary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                        ])
                                        self.address = None
                                        self.secondary = None
                                        self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Address.Secondary, ['address', 'secondary'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv4.Vrrs, ['leader'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 Address family
                            
                            .. attribute:: address
                            
                            	Set the IPv6 address of VRRP group
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address>`
                            
                            .. attribute:: description
                            
                            	Group description
                            	**type**\: str
                            
                            	**length:** 1..80
                            
                            .. attribute:: match_address
                            
                            	Match addresses in advertisement packet
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: preempt
                            
                            	Enable preemption of lower priority Master
                            	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: priority
                            
                            	Priority level
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: shutdown
                            
                            	Shutdown the group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timers
                            
                            	Set the VRRP timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers>`
                            
                            .. attribute:: track
                            
                            	
                            	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track>`
                            
                            .. attribute:: vrrs
                            
                            	VRRS related commands
                            	**type**\:  :py:class:`Vrrs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address)), ("preempt", ("preempt", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt)), ("timers", ("timers", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers)), ("track", ("track", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track)), ("vrrs", ("vrrs", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('match_address', (YLeaf(YType.empty, 'match-address'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ])
                                self.description = None
                                self.match_address = None
                                self.priority = None
                                self.shutdown = None

                                self.address = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.preempt = None
                                self._children_name_map["preempt"] = "preempt"

                                self.timers = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.track = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track()
                                self.track.parent = self
                                self._children_name_map["track"] = "track"

                                self.vrrs = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs()
                                self.vrrs.parent = self
                                self._children_name_map["vrrs"] = "vrrs"
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6, ['description', 'match_address', 'priority', 'shutdown'], name, value)


                            class Address(Entity):
                                """
                                Set the IPv6 address of VRRP group
                                
                                .. attribute:: primary
                                
                                	
                                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary>`
                                
                                .. attribute:: ipv6_prefix
                                
                                	
                                	**type**\: list of  		 :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary", ("primary", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary)), ("ipv6-prefix", ("ipv6_prefix", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix))])
                                    self._leafs = OrderedDict()

                                    self.primary = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary()
                                    self.primary.parent = self
                                    self._children_name_map["primary"] = "primary"

                                    self.ipv6_prefix = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address, [], name, value)


                                class Primary(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipv6_link_local
                                    
                                    	IPv6 link\-local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary
                                    
                                    	IPv6 primary address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, self).__init__()

                                        self.yang_name = "primary"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_link_local', (YLeaf(YType.str, 'ipv6-link-local'), ['str'])),
                                            ('primary', (YLeaf(YType.empty, 'primary'), ['Empty'])),
                                        ])
                                        self.ipv6_link_local = None
                                        self.primary = None
                                        self._segment_path = lambda: "primary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Primary, ['ipv6_link_local', 'primary'], name, value)


                                class Ipv6Prefix(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, self).__init__()

                                        self.yang_name = "ipv6-prefix"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                        ])
                                        self.prefix = None
                                        self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Address.Ipv6Prefix, ['prefix'], name, value)


                            class Preempt(Entity):
                                """
                                Enable preemption of lower priority Master
                                
                                .. attribute:: delay
                                
                                	Set time delay before preempting
                                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, self).__init__()

                                    self.yang_name = "preempt"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.delay = Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay()
                                    self.delay.parent = self
                                    self._children_name_map["delay"] = "delay"
                                    self._segment_path = lambda: "preempt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt, [], name, value)


                                class Delay(Entity):
                                    """
                                    Set time delay before preempting
                                    
                                    .. attribute:: minimum
                                    
                                    	Seconds to delay
                                    	**type**\: int
                                    
                                    	**range:** 0..3600
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, self).__init__()

                                        self.yang_name = "delay"
                                        self.yang_parent_name = "preempt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                        ])
                                        self.minimum = None
                                        self._segment_path = lambda: "delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Preempt.Delay, ['minimum'], name, value)


                            class Timers(Entity):
                                """
                                Set the VRRP timers
                                
                                .. attribute:: advertise
                                
                                	Advertisement interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 100..40950
                                
                                	**units**\: milliseconds
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('advertise', (YLeaf(YType.uint16, 'advertise'), ['int'])),
                                    ])
                                    self.advertise = None
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Timers, ['advertise'], name, value)


                            class Track(Entity):
                                """
                                
                                
                                .. attribute:: event
                                
                                	
                                	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event>`
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, self).__init__()

                                    self.yang_name = "track"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event))])
                                    self._leafs = OrderedDict()

                                    self.event = YList(self)
                                    self._segment_path = lambda: "track"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track, [], name, value)


                                class Event(Entity):
                                    """
                                    
                                    
                                    .. attribute:: object_id  (key)
                                    
                                    	Specify the tracked object\-id
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: decrement
                                    
                                    	Specify the decrement value from current priority
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown the group
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-vrrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, self).__init__()

                                        self.yang_name = "event"
                                        self.yang_parent_name = "track"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['object_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                            ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                        ])
                                        self.object_id = None
                                        self.decrement = None
                                        self.shutdown = None
                                        self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Track.Event, ['object_id', 'decrement', 'shutdown'], name, value)


                            class Vrrs(Entity):
                                """
                                VRRS related commands
                                
                                .. attribute:: leader
                                
                                	Name of VRRS Tag for which this group is the leader
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-vrrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, self).__init__()

                                    self.yang_name = "vrrs"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('leader', (YLeaf(YType.str, 'leader'), ['str'])),
                                    ])
                                    self.leader = None
                                    self._segment_path = lambda: "vrrs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroup.AddressFamily.Ipv6.Vrrs, ['leader'], name, value)


                class VrrpGroupV2(Entity):
                    """
                    vrrp version 2
                    
                    .. attribute:: group_id  (key)
                    
                    	VRRP group number
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: authentication
                    
                    	
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroupV2.Authentication>`
                    
                    .. attribute:: description
                    
                    	Up to 80 characters describing this group
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroupV2.Ip>`
                    
                    .. attribute:: name
                    
                    	Unique VRRS identifier (max 48 characters)
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroupV2.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: shutdown
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: timers
                    
                    	
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroupV2.Timers>`
                    
                    .. attribute:: track
                    
                    	
                    	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroupV2.Track>`
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.Vrrp.VrrpGroupV2, self).__init__()

                        self.yang_name = "vrrp-group-v2"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vlan.Vrrp.VrrpGroupV2.Authentication)), ("ip", ("ip", Native.Interface.Vlan.Vrrp.VrrpGroupV2.Ip)), ("preempt", ("preempt", Native.Interface.Vlan.Vrrp.VrrpGroupV2.Preempt)), ("timers", ("timers", Native.Interface.Vlan.Vrrp.VrrpGroupV2.Timers)), ("track", ("track", Native.Interface.Vlan.Vrrp.VrrpGroupV2.Track))])
                        self._leafs = OrderedDict([
                            ('group_id', (YLeaf(YType.uint8, 'group-id'), ['int'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.group_id = None
                        self.description = None
                        self.name = None
                        self.priority = None
                        self.shutdown = None

                        self.authentication = Native.Interface.Vlan.Vrrp.VrrpGroupV2.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = Native.Interface.Vlan.Vrrp.VrrpGroupV2.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.timers = Native.Interface.Vlan.Vrrp.VrrpGroupV2.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = Native.Interface.Vlan.Vrrp.VrrpGroupV2.Track()
                        self.track.parent = self
                        self._children_name_map["track"] = "track"
                        self._segment_path = lambda: "vrrp-group-v2" + "[group-id='" + str(self.group_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroupV2, ['group_id', 'description', 'name', 'priority', 'shutdown'], name, value)


                    class Authentication(Entity):
                        """
                        
                        
                        .. attribute:: text
                        
                        	authentication string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.text = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Authentication, ['text'], name, value)


                    class Ip(Entity):
                        """
                        
                        
                        .. attribute:: vrrp_ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`VrrpIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroupV2.Ip.VrrpIpv4>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrrp-ipv4", ("vrrp_ipv4", Native.Interface.Vlan.Vrrp.VrrpGroupV2.Ip.VrrpIpv4))])
                            self._leafs = OrderedDict()

                            self.vrrp_ipv4 = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Ip, [], name, value)


                        class VrrpIpv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, self).__init__()

                                self.yang_name = "vrrp-ipv4"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                                ])
                                self.ipv4 = None
                                self.secondary = None
                                self._segment_path = lambda: "vrrp-ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Ip.VrrpIpv4, ['ipv4', 'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        
                        
                        .. attribute:: delay
                        
                        	
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroupV2.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vlan.Vrrp.VrrpGroupV2.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Vlan.Vrrp.VrrpGroupV2.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            
                            
                            .. attribute:: minimum
                            
                            	Seconds to delay
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                ])
                                self.minimum = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Preempt.Delay, ['minimum'], name, value)


                    class Timers(Entity):
                        """
                        
                        
                        .. attribute:: advertise
                        
                        	
                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroupV2.Timers.Advertise>`
                        
                        .. attribute:: learn
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Interface.Vlan.Vrrp.VrrpGroupV2.Timers.Advertise))])
                            self._leafs = OrderedDict([
                                ('learn', (YLeaf(YType.empty, 'learn'), ['Empty'])),
                            ])
                            self.learn = None

                            self.advertise = Native.Interface.Vlan.Vrrp.VrrpGroupV2.Timers.Advertise()
                            self.advertise.parent = self
                            self._children_name_map["advertise"] = "advertise"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Timers, ['learn'], name, value)


                        class Advertise(Entity):
                            """
                            
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Advertisement interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..999
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Timers.Advertise, self).__init__()

                                self.yang_name = "advertise"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint8, 'interval'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.interval = None
                                self.msec = None
                                self._segment_path = lambda: "advertise"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Timers.Advertise, ['interval', 'msec'], name, value)


                    class Track(Entity):
                        """
                        
                        
                        .. attribute:: event
                        
                        	
                        	**type**\: list of  		 :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Vrrp.VrrpGroupV2.Track.Event>`
                        
                        

                        """

                        _prefix = 'ios-vrrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "vrrp-group-v2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("event", ("event", Native.Interface.Vlan.Vrrp.VrrpGroupV2.Track.Event))])
                            self._leafs = OrderedDict()

                            self.event = YList(self)
                            self._segment_path = lambda: "track"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Track, [], name, value)


                        class Event(Entity):
                            """
                            
                            
                            .. attribute:: object_id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: decrement
                            
                            	Decrement value
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-vrrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Track.Event, self).__init__()

                                self.yang_name = "event"
                                self.yang_parent_name = "track"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['object_id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('object_id', (YLeaf(YType.uint16, 'object-id'), ['int'])),
                                    ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ])
                                self.object_id = None
                                self.decrement = None
                                self._segment_path = lambda: "event" + "[object-id='" + str(self.object_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Vrrp.VrrpGroupV2.Track.Event, ['object_id', 'decrement'], name, value)


                class Delay(Entity):
                    """
                    
                    
                    .. attribute:: reload
                    
                    	Seconds to delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: minimum
                    
                    	Seconds to delay after interface up
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios-vrrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vlan.Vrrp.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "vrrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                        ])
                        self.reload = None
                        self.minimum = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Vrrp.Delay, ['reload', 'minimum'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts.Manual>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.Vlan.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "Vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.Vlan.Cts.Manual))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vlan.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Vlan.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.Vlan.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.Vlan.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.Vlan.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.Vlan.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.Vlan.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.Vlan.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vlan.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vlan.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.Vlan.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.Vlan.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vlan.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vlan.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.Vlan.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vlan.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vlan.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vlan.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vlan.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vlan.Cts.Manual.Propagate, ['sgt'], name, value)


        class GroupAsync(Entity):
            """
            Async Group interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..64
            
            .. attribute:: physical_layer
            
            	Configure sync or async physical layer on serial interface
            	**type**\:  :py:class:`PhysicalLayer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.PhysicalLayer>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.PmPath>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.GroupAsync, self).__init__()

                self.yang_name = "Group-Async"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.GroupAsync.SwitchportConf)), ("switchport", ("switchport", Native.Interface.GroupAsync.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.GroupAsync.StackwiseVirtual)), ("arp", ("arp", Native.Interface.GroupAsync.Arp)), ("backup", ("backup", Native.Interface.GroupAsync.Backup)), ("cemoudp", ("cemoudp", Native.Interface.GroupAsync.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.GroupAsync.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.GroupAsync.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.GroupAsync.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.GroupAsync.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.GroupAsync.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.GroupAsync.Flowcontrol)), ("isis", ("isis", Native.Interface.GroupAsync.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.GroupAsync.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.GroupAsync.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.GroupAsync.Bandwidth)), ("dampening", ("dampening", Native.Interface.GroupAsync.Dampening)), ("domain", ("domain", Native.Interface.GroupAsync.Domain)), ("hold-queue", ("hold_queue", Native.Interface.GroupAsync.HoldQueue)), ("mpls", ("mpls", Native.Interface.GroupAsync.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.GroupAsync.IpVrf)), ("vrf", ("vrf", Native.Interface.GroupAsync.Vrf)), ("ip", ("ip", Native.Interface.GroupAsync.Ip)), ("ipv6", ("ipv6", Native.Interface.GroupAsync.Ipv6)), ("logging", ("logging", Native.Interface.GroupAsync.Logging)), ("mdix", ("mdix", Native.Interface.GroupAsync.Mdix)), ("mop", ("mop", Native.Interface.GroupAsync.Mop)), ("interface_qos", ("interface_qos", Native.Interface.GroupAsync.InterfaceQos)), ("source", ("source", Native.Interface.GroupAsync.Source)), ("standby", ("standby", Native.Interface.GroupAsync.Standby)), ("access-session", ("access_session", Native.Interface.GroupAsync.AccessSession)), ("storm-control", ("storm_control", Native.Interface.GroupAsync.StormControl)), ("trust", ("trust", Native.Interface.GroupAsync.Trust)), ("priority-queue", ("priority_queue", Native.Interface.GroupAsync.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.GroupAsync.RcvQueue)), ("peer", ("peer", Native.Interface.GroupAsync.Peer)), ("pm-path", ("pm_path", Native.Interface.GroupAsync.PmPath))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('physical_layer', (YLeaf(YType.enumeration, 'physical-layer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.PhysicalLayer')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.ServiceInsertion')])),
                ])
                self.name = None
                self.physical_layer = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.GroupAsync.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.GroupAsync.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.GroupAsync.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.GroupAsync.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.GroupAsync.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.GroupAsync.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.GroupAsync.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.GroupAsync.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.GroupAsync.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.GroupAsync.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.GroupAsync.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.GroupAsync.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.GroupAsync.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.GroupAsync.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.GroupAsync.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.GroupAsync.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.GroupAsync.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.GroupAsync.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.GroupAsync.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.GroupAsync.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.GroupAsync.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.GroupAsync.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.GroupAsync.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.GroupAsync.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.GroupAsync.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.GroupAsync.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.GroupAsync.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.GroupAsync.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.GroupAsync.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.GroupAsync.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.GroupAsync.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.GroupAsync.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.GroupAsync.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.GroupAsync.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.GroupAsync.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "Group-Async" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.GroupAsync, [u'name', u'physical_layer', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class PhysicalLayer(Enum):
                """
                PhysicalLayer (Enum Class)

                Configure sync or async physical layer on serial interface

                .. data:: async = 0

                .. data:: sync = 1

                """

                async = Enum.YLeaf(0, "async")

                sync = Enum.YLeaf(1, "sync")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.GroupAsync.Backup.Delay)), ("interface", ("interface", Native.Interface.GroupAsync.Backup.Interface_)), ("load", ("load", Native.Interface.GroupAsync.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.GroupAsync.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.GroupAsync.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.GroupAsync.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.GroupAsync.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.GroupAsync.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.GroupAsync.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.GroupAsync.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.GroupAsync.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.GroupAsync.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.GroupAsync.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.GroupAsync.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.GroupAsync.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.GroupAsync.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.GroupAsync.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.GroupAsync.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.GroupAsync.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.GroupAsync.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.GroupAsync.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.GroupAsync.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.GroupAsync.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.GroupAsync.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.GroupAsync.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.GroupAsync.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.GroupAsync.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.GroupAsync.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.GroupAsync.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.GroupAsync.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.GroupAsync.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.GroupAsync.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.GroupAsync.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.GroupAsync.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.GroupAsync.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.GroupAsync.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.GroupAsync.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.GroupAsync.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.GroupAsync.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.GroupAsync.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.GroupAsync.Ip.Arp)), ("vrf", ("vrf", Native.Interface.GroupAsync.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.GroupAsync.Ip.NoAddress)), ("address", ("address", Native.Interface.GroupAsync.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.GroupAsync.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.GroupAsync.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.GroupAsync.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.GroupAsync.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.GroupAsync.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.GroupAsync.Ip.Pim)), ("policy", ("policy", Native.Interface.GroupAsync.Ip.Policy)), ("rip", ("rip", Native.Interface.GroupAsync.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.GroupAsync.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.GroupAsync.Ip.RouteCache)), ("router", ("router", Native.Interface.GroupAsync.Ip.Router)), ("tcp", ("tcp", Native.Interface.GroupAsync.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.GroupAsync.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.GroupAsync.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.GroupAsync.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.GroupAsync.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.GroupAsync.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.GroupAsync.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.GroupAsync.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.GroupAsync.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.GroupAsync.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.GroupAsync.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.GroupAsync.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.GroupAsync.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.GroupAsync.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.GroupAsync.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.GroupAsync.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.GroupAsync.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.GroupAsync.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.GroupAsync.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.GroupAsync.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.GroupAsync.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.GroupAsync.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.GroupAsync.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.GroupAsync.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.GroupAsync.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.GroupAsync.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.GroupAsync.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.GroupAsync.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.GroupAsync.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.GroupAsync.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.GroupAsync.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.GroupAsync.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.GroupAsync.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.GroupAsync.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.GroupAsync.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.GroupAsync.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.GroupAsync.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.GroupAsync.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.GroupAsync.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.GroupAsync.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.GroupAsync.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.GroupAsync.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.GroupAsync.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.GroupAsync.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.GroupAsync.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.GroupAsync.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.GroupAsync.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.GroupAsync.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.GroupAsync.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.GroupAsync.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.GroupAsync.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.GroupAsync.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.GroupAsync.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.GroupAsync.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.GroupAsync.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.GroupAsync.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.GroupAsync.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.GroupAsync.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.GroupAsync.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.GroupAsync.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.GroupAsync.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.GroupAsync.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.GroupAsync.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.GroupAsync.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GroupAsync.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.GroupAsync.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.GroupAsync.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.GroupAsync.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.GroupAsync.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.GroupAsync.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.GroupAsync.Ipv6.Dhcp)), ("address", ("address", Native.Interface.GroupAsync.Ipv6.Address)), ("nd", ("nd", Native.Interface.GroupAsync.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.GroupAsync.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.GroupAsync.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.GroupAsync.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.GroupAsync.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.GroupAsync.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.GroupAsync.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.GroupAsync.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.GroupAsync.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.GroupAsync.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.GroupAsync.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.GroupAsync.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.GroupAsync.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.GroupAsync.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.GroupAsync.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.GroupAsync.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.GroupAsync.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.GroupAsync.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.GroupAsync.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.GroupAsync.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.GroupAsync.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.GroupAsync.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.GroupAsync.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.GroupAsync.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.GroupAsync.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.GroupAsync.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.GroupAsync.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.GroupAsync.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.GroupAsync.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.GroupAsync.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.GroupAsync.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.GroupAsync.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.GroupAsync.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.GroupAsync.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.GroupAsync.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.GroupAsync.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.GroupAsync.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GroupAsync.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.GroupAsync.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.GroupAsync.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.GroupAsync.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.GroupAsync.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.GroupAsync.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.GroupAsync.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.GroupAsync.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.GroupAsync.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.GroupAsync.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.GroupAsync.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.GroupAsync.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.GroupAsync.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.GroupAsync.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.GroupAsync.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.GroupAsync.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.GroupAsync.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.GroupAsync.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.GroupAsync.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.GroupAsync.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.GroupAsync.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.GroupAsync.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.GroupAsync.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.GroupAsync.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.GroupAsync.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.GroupAsync.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.GroupAsync.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.GroupAsync.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.GroupAsync.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.GroupAsync.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.GroupAsync.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.GroupAsync.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.GroupAsync.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.GroupAsync.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.GroupAsync.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.GroupAsync.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.GroupAsync.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.GroupAsync.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.GroupAsync.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.GroupAsync.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.GroupAsync.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.GroupAsync.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.GroupAsync.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.GroupAsync.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.GroupAsync.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.GroupAsync.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.GroupAsync.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.GroupAsync.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.GroupAsync.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.GroupAsync.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.GroupAsync.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.GroupAsync.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.GroupAsync.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.GroupAsync.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.GroupAsync.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.GroupAsync.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.GroupAsync.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.GroupAsync.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.GroupAsync.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.GroupAsync.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.GroupAsync.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.GroupAsync.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.GroupAsync.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.GroupAsync.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.GroupAsync.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.GroupAsync.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.GroupAsync.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GroupAsync.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.GroupAsync.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.GroupAsync.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.GroupAsync.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Group-Async"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.GroupAsync.PmPath, [u'name', u'interface_id'], name, value)


        class Multilink(Entity):
            """
            Multilink\-group interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.PmPath>`
            
            .. attribute:: ppp
            
            	Point\-to\-Point Protocol
            	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Multilink, self).__init__()

                self.yang_name = "Multilink"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.Multilink.SwitchportConf)), ("switchport", ("switchport", Native.Interface.Multilink.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.Multilink.StackwiseVirtual)), ("arp", ("arp", Native.Interface.Multilink.Arp)), ("backup", ("backup", Native.Interface.Multilink.Backup)), ("cemoudp", ("cemoudp", Native.Interface.Multilink.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.Multilink.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.Multilink.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.Multilink.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.Multilink.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.Multilink.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.Multilink.Flowcontrol)), ("isis", ("isis", Native.Interface.Multilink.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.Multilink.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.Multilink.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.Multilink.Bandwidth)), ("dampening", ("dampening", Native.Interface.Multilink.Dampening)), ("domain", ("domain", Native.Interface.Multilink.Domain)), ("hold-queue", ("hold_queue", Native.Interface.Multilink.HoldQueue)), ("mpls", ("mpls", Native.Interface.Multilink.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.Multilink.IpVrf)), ("vrf", ("vrf", Native.Interface.Multilink.Vrf)), ("ip", ("ip", Native.Interface.Multilink.Ip)), ("ipv6", ("ipv6", Native.Interface.Multilink.Ipv6)), ("logging", ("logging", Native.Interface.Multilink.Logging)), ("mdix", ("mdix", Native.Interface.Multilink.Mdix)), ("mop", ("mop", Native.Interface.Multilink.Mop)), ("interface_qos", ("interface_qos", Native.Interface.Multilink.InterfaceQos)), ("source", ("source", Native.Interface.Multilink.Source)), ("standby", ("standby", Native.Interface.Multilink.Standby)), ("access-session", ("access_session", Native.Interface.Multilink.AccessSession)), ("storm-control", ("storm_control", Native.Interface.Multilink.StormControl)), ("trust", ("trust", Native.Interface.Multilink.Trust)), ("priority-queue", ("priority_queue", Native.Interface.Multilink.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.Multilink.RcvQueue)), ("peer", ("peer", Native.Interface.Multilink.Peer)), ("pm-path", ("pm_path", Native.Interface.Multilink.PmPath)), ("Cisco-IOS-XE-ppp:ppp", ("ppp", Native.Interface.Multilink.Ppp))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.Multilink.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.Multilink.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.Multilink.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.Multilink.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.Multilink.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.Multilink.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.Multilink.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.Multilink.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.Multilink.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.Multilink.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.Multilink.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.Multilink.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.Multilink.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.Multilink.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.Multilink.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.Multilink.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.Multilink.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.Multilink.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.Multilink.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.Multilink.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.Multilink.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.Multilink.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.Multilink.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.Multilink.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.Multilink.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.Multilink.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.Multilink.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.Multilink.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.Multilink.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.Multilink.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.Multilink.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.Multilink.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.Multilink.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.Multilink.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.Multilink.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.ppp = Native.Interface.Multilink.Ppp()
                self.ppp.parent = self
                self._children_name_map["ppp"] = "Cisco-IOS-XE-ppp:ppp"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "Multilink" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Multilink, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Multilink.Backup.Delay)), ("interface", ("interface", Native.Interface.Multilink.Backup.Interface_)), ("load", ("load", Native.Interface.Multilink.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Multilink.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Multilink.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Multilink.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Multilink.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Multilink.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Multilink.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Multilink.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Multilink.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Multilink.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Multilink.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Multilink.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Multilink.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Multilink.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Multilink.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Multilink.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Multilink.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Multilink.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Multilink.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Multilink.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Multilink.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Multilink.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Multilink.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.Multilink.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Multilink.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Multilink.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Multilink.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Multilink.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Multilink.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Multilink.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Multilink.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Multilink.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Multilink.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Multilink.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Multilink.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Multilink.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Multilink.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Verify>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Multilink.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.Multilink.Ip.Arp)), ("vrf", ("vrf", Native.Interface.Multilink.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.Multilink.Ip.NoAddress)), ("address", ("address", Native.Interface.Multilink.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Multilink.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Multilink.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.Multilink.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.Multilink.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Multilink.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.Multilink.Ip.Pim)), ("policy", ("policy", Native.Interface.Multilink.Ip.Policy)), ("rip", ("rip", Native.Interface.Multilink.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Multilink.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Multilink.Ip.RouteCache)), ("router", ("router", Native.Interface.Multilink.Ip.Router)), ("tcp", ("tcp", Native.Interface.Multilink.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Multilink.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Multilink.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Multilink.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.Multilink.Ip.Verify))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.Multilink.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Multilink.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Multilink.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Multilink.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Multilink.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Multilink.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Multilink.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Multilink.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Multilink.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Multilink.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Multilink.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Multilink.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Multilink.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Multilink.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Multilink.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Multilink.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Multilink.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Multilink.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Multilink.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.Multilink.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Multilink.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Multilink.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Multilink.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Multilink.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Multilink.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Multilink.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Multilink.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Multilink.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Multilink.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Multilink.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Multilink.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Multilink.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Multilink.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Multilink.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Multilink.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Multilink.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Multilink.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.Multilink.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Multilink.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Multilink.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Multilink.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Multilink.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Multilink.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Multilink.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Multilink.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Multilink.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Multilink.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Multilink.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Multilink.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Multilink.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Multilink.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Multilink.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Multilink.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.Multilink.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Multilink.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Multilink.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Multilink.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Multilink.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Multilink.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Multilink.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Multilink.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Multilink.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Multilink.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Multilink.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Multilink.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Multilink.Ipv6.Dhcp)), ("address", ("address", Native.Interface.Multilink.Ipv6.Address)), ("nd", ("nd", Native.Interface.Multilink.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.Multilink.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Multilink.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Multilink.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Multilink.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Multilink.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Multilink.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Multilink.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Multilink.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Multilink.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Multilink.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Multilink.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Multilink.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Multilink.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Multilink.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Multilink.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Multilink.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Multilink.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Multilink.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Multilink.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Multilink.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.Multilink.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Multilink.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Multilink.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Multilink.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Multilink.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Multilink.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Multilink.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Multilink.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Multilink.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Multilink.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.Multilink.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Multilink.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Multilink.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Multilink.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Multilink.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Multilink.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Multilink.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Multilink.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Multilink.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Multilink.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Multilink.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Multilink.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Multilink.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Multilink.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Multilink.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Multilink.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Multilink.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Multilink.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Multilink.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Multilink.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Multilink.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Multilink.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Multilink.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Multilink.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Multilink.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Multilink.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Multilink.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Multilink.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Multilink.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Multilink.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Multilink.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Multilink.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Multilink.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Multilink.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Multilink.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Multilink.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Multilink.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Multilink.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Multilink.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Multilink.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Multilink.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Multilink.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Multilink.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Multilink.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Multilink.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Multilink.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Multilink.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Multilink.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Multilink.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Multilink.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Multilink.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Multilink.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Multilink.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Multilink.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Multilink.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Multilink.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Multilink.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Multilink.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Multilink.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Multilink.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Multilink.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Multilink.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Multilink.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Multilink.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Multilink.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Multilink.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Multilink.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Multilink.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Multilink.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Multilink.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Multilink.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Multilink.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Multilink.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Multilink.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.PmPath, [u'name', u'interface_id'], name, value)


            class Ppp(Entity):
                """
                Point\-to\-Point Protocol
                
                .. attribute:: accounting
                
                	Set PPP network accounting method
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Accounting>`
                
                .. attribute:: chap
                
                	Set CHAP authentication parameters
                	**type**\:  :py:class:`Chap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp.Chap>`
                
                .. attribute:: authentication
                
                	Set PPP link authentication method
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp.Authentication>`
                
                .. attribute:: authorization
                
                	Set PPP network authorization method
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Authorization>`
                
                .. attribute:: ipcp
                
                	Set IPCP negotiation options
                	**type**\:  :py:class:`Ipcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp.Ipcp>`
                
                .. attribute:: multilink
                
                	Make interface multilink capable
                	**type**\:  :py:class:`Multilink_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp.Multilink_>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-ppp'
                _revision = '2018-02-03'

                def __init__(self):
                    super(Native.Interface.Multilink.Ppp, self).__init__()

                    self.yang_name = "ppp"
                    self.yang_parent_name = "Multilink"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("chap", ("chap", Native.Interface.Multilink.Ppp.Chap)), ("authentication", ("authentication", Native.Interface.Multilink.Ppp.Authentication)), ("ipcp", ("ipcp", Native.Interface.Multilink.Ppp.Ipcp)), ("multilink", ("multilink", Native.Interface.Multilink.Ppp.Multilink_))])
                    self._leafs = OrderedDict([
                        ('accounting', (YLeaf(YType.str, 'accounting'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Ppp.Accounting')])),
                        ('authorization', (YLeaf(YType.str, 'authorization'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Ppp.Authorization')])),
                    ])
                    self.accounting = None
                    self.authorization = None

                    self.chap = Native.Interface.Multilink.Ppp.Chap()
                    self.chap.parent = self
                    self._children_name_map["chap"] = "chap"

                    self.authentication = Native.Interface.Multilink.Ppp.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.ipcp = Native.Interface.Multilink.Ppp.Ipcp()
                    self.ipcp.parent = self
                    self._children_name_map["ipcp"] = "ipcp"

                    self.multilink = None
                    self._children_name_map["multilink"] = "multilink"
                    self._segment_path = lambda: "Cisco-IOS-XE-ppp:ppp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Multilink.Ppp, ['accounting', 'authorization'], name, value)

                class Accounting(Enum):
                    """
                    Accounting (Enum Class)

                    Set PPP network accounting method

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")


                class Authorization(Enum):
                    """
                    Authorization (Enum Class)

                    Set PPP network authorization method

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")



                class Chap(Entity):
                    """
                    Set CHAP authentication parameters
                    
                    .. attribute:: hostname
                    
                    	Set alternate CHAP hostname
                    	**type**\: str
                    
                    .. attribute:: challenge_length
                    
                    	Challenge Length for CHAP
                    	**type**\: int
                    
                    	**range:** 16..63
                    
                    

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ppp.Chap, self).__init__()

                        self.yang_name = "chap"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ('challenge_length', (YLeaf(YType.uint8, 'challenge-length'), ['int'])),
                        ])
                        self.hostname = None
                        self.challenge_length = None
                        self._segment_path = lambda: "chap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ppp.Chap, ['hostname', 'challenge_length'], name, value)


                class Authentication(Entity):
                    """
                    Set PPP link authentication method
                    
                    .. attribute:: method
                    
                    	
                    	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp.Authentication.Method>`
                    
                    .. attribute:: list_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: chap
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: callback
                    
                    	Authenticate remote on callback only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: callin
                    
                    	Authenticate remote on incoming call only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: callout
                    
                    	Authenticate remote on outgoing call only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default
                    
                    	Use the default authentication list
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: eap
                    
                    	Extensible Authentication Protocol (EAP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ms_chap
                    
                    	Microsoft Challenge Handshake Authentication Protocol (MS\-CHAP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ms_chap_v2
                    
                    	Microsoft CHAP Version 2 (MS\-CHAP\-V2)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: one_time
                    
                    	Allow use of username\*OTP for one\-time passwords
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: optional
                    
                    	Allow peer to refuse to authenticate
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pap
                    
                    	Password Authentication Protocol (PAP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ppp.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('method', (YLeaf(YType.enumeration, 'method'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Multilink.Ppp.Authentication.Method')])),
                            ('list_name', (YLeaf(YType.str, 'list-name'), ['str'])),
                            ('chap', (YLeaf(YType.empty, 'chap'), ['Empty'])),
                            ('callback', (YLeaf(YType.empty, 'callback'), ['Empty'])),
                            ('callin', (YLeaf(YType.empty, 'callin'), ['Empty'])),
                            ('callout', (YLeaf(YType.empty, 'callout'), ['Empty'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                            ('ms_chap', (YLeaf(YType.empty, 'ms-chap'), ['Empty'])),
                            ('ms_chap_v2', (YLeaf(YType.empty, 'ms-chap-v2'), ['Empty'])),
                            ('one_time', (YLeaf(YType.empty, 'one-time'), ['Empty'])),
                            ('optional', (YLeaf(YType.empty, 'optional'), ['Empty'])),
                            ('pap', (YLeaf(YType.empty, 'pap'), ['Empty'])),
                        ])
                        self.method = None
                        self.list_name = None
                        self.chap = None
                        self.callback = None
                        self.callin = None
                        self.callout = None
                        self.default = None
                        self.eap = None
                        self.ms_chap = None
                        self.ms_chap_v2 = None
                        self.one_time = None
                        self.optional = None
                        self.pap = None
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ppp.Authentication, ['method', 'list_name', 'chap', 'callback', 'callin', 'callout', 'default', 'eap', 'ms_chap', 'ms_chap_v2', 'one_time', 'optional', 'pap'], name, value)

                    class Method(Enum):
                        """
                        Method (Enum Class)

                        .. data:: chap = 0

                        .. data:: eap = 1

                        .. data:: ms_chap = 2

                        .. data:: ms_chap_v2 = 3

                        .. data:: pap = 4

                        """

                        chap = Enum.YLeaf(0, "chap")

                        eap = Enum.YLeaf(1, "eap")

                        ms_chap = Enum.YLeaf(2, "ms-chap")

                        ms_chap_v2 = Enum.YLeaf(3, "ms-chap-v2")

                        pap = Enum.YLeaf(4, "pap")



                class Ipcp(Entity):
                    """
                    Set IPCP negotiation options
                    
                    .. attribute:: dns
                    
                    	Specify DNS negotiation options
                    	**type**\:  :py:class:`Dns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp.Ipcp.Dns>`
                    
                    

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ppp.Ipcp, self).__init__()

                        self.yang_name = "ipcp"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dns", ("dns", Native.Interface.Multilink.Ppp.Ipcp.Dns))])
                        self._leafs = OrderedDict()

                        self.dns = Native.Interface.Multilink.Ppp.Ipcp.Dns()
                        self.dns.parent = self
                        self._children_name_map["dns"] = "dns"
                        self._segment_path = lambda: "ipcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ppp.Ipcp, [], name, value)


                    class Dns(Entity):
                        """
                        Specify DNS negotiation options
                        
                        .. attribute:: primary
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ppp.Ipcp.Dns, self).__init__()

                            self.yang_name = "dns"
                            self.yang_parent_name = "ipcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary', (YLeaf(YType.str, 'primary'), ['str'])),
                            ])
                            self.primary = None
                            self._segment_path = lambda: "dns"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ppp.Ipcp.Dns, ['primary'], name, value)


                class Multilink_(Entity):
                    """
                    Make interface multilink capable
                    
                    .. attribute:: links
                    
                    	Specify the limits on the number of links in a bundle
                    	**type**\:  :py:class:`Links <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp.Multilink_.Links>`
                    
                    .. attribute:: group
                    
                    	Put interface in a multilink bundle
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: endpoint
                    
                    	Configure the local Endpoint Discriminator
                    	**type**\:  :py:class:`Endpoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp.Multilink_.Endpoint>`
                    
                    .. attribute:: fragment
                    
                    	Specify fragmentation parameters
                    	**type**\:  :py:class:`Fragment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp.Multilink_.Fragment>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.Multilink.Ppp.Multilink_, self).__init__()

                        self.yang_name = "multilink"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("links", ("links", Native.Interface.Multilink.Ppp.Multilink_.Links)), ("endpoint", ("endpoint", Native.Interface.Multilink.Ppp.Multilink_.Endpoint)), ("fragment", ("fragment", Native.Interface.Multilink.Ppp.Multilink_.Fragment))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                        ])
                        self.group = None

                        self.links = Native.Interface.Multilink.Ppp.Multilink_.Links()
                        self.links.parent = self
                        self._children_name_map["links"] = "links"

                        self.endpoint = Native.Interface.Multilink.Ppp.Multilink_.Endpoint()
                        self.endpoint.parent = self
                        self._children_name_map["endpoint"] = "endpoint"

                        self.fragment = Native.Interface.Multilink.Ppp.Multilink_.Fragment()
                        self.fragment.parent = self
                        self._children_name_map["fragment"] = "fragment"
                        self._segment_path = lambda: "multilink"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Multilink.Ppp.Multilink_, ['group'], name, value)


                    class Links(Entity):
                        """
                        Specify the limits on the number of links in a bundle
                        
                        .. attribute:: minimum
                        
                        	Minimum number of links desired in the bundle
                        	**type**\:  :py:class:`Minimum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp.Multilink_.Links.Minimum>`
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ppp.Multilink_.Links, self).__init__()

                            self.yang_name = "links"
                            self.yang_parent_name = "multilink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimum", ("minimum", Native.Interface.Multilink.Ppp.Multilink_.Links.Minimum))])
                            self._leafs = OrderedDict()

                            self.minimum = Native.Interface.Multilink.Ppp.Multilink_.Links.Minimum()
                            self.minimum.parent = self
                            self._children_name_map["minimum"] = "minimum"
                            self._segment_path = lambda: "links"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ppp.Multilink_.Links, [], name, value)


                        class Minimum(Entity):
                            """
                            Minimum number of links desired in the bundle
                            
                            .. attribute:: minimum_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: mandatory
                            
                            	Disable network layer until minimum number of links is reach
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ppp'
                            _revision = '2018-02-03'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ppp.Multilink_.Links.Minimum, self).__init__()

                                self.yang_name = "minimum"
                                self.yang_parent_name = "links"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum_value', (YLeaf(YType.uint8, 'minimum-value'), ['int'])),
                                    ('mandatory', (YLeaf(YType.empty, 'mandatory'), ['Empty'])),
                                ])
                                self.minimum_value = None
                                self.mandatory = None
                                self._segment_path = lambda: "minimum"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Ppp.Multilink_.Links.Minimum, ['minimum_value', 'mandatory'], name, value)


                    class Endpoint(Entity):
                        """
                        Configure the local Endpoint Discriminator
                        
                        .. attribute:: string
                        
                        	Use specified string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ppp.Multilink_.Endpoint, self).__init__()

                            self.yang_name = "endpoint"
                            self.yang_parent_name = "multilink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                            ])
                            self.string = None
                            self._segment_path = lambda: "endpoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ppp.Multilink_.Endpoint, ['string'], name, value)


                    class Fragment(Entity):
                        """
                        Specify fragmentation parameters
                        
                        .. attribute:: delay
                        
                        	Specify the maximum delay for each fragment
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Multilink.Ppp.Multilink_.Fragment.Delay>`
                        
                        .. attribute:: disable
                        
                        	Suppress multilink fragmentation when possible
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.Multilink.Ppp.Multilink_.Fragment, self).__init__()

                            self.yang_name = "fragment"
                            self.yang_parent_name = "multilink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Multilink.Ppp.Multilink_.Fragment.Delay))])
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None

                            self.delay = Native.Interface.Multilink.Ppp.Multilink_.Fragment.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "fragment"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Multilink.Ppp.Multilink_.Fragment, ['disable'], name, value)


                        class Delay(Entity):
                            """
                            Specify the maximum delay for each fragment
                            
                            .. attribute:: delay_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..1000
                            
                            .. attribute:: additional_delay_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..999
                            
                            

                            """

                            _prefix = 'ios-ppp'
                            _revision = '2018-02-03'

                            def __init__(self):
                                super(Native.Interface.Multilink.Ppp.Multilink_.Fragment.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "fragment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('delay_value', (YLeaf(YType.uint16, 'delay-value'), ['int'])),
                                    ('additional_delay_value', (YLeaf(YType.uint16, 'additional-delay-value'), ['int'])),
                                ])
                                self.delay_value = None
                                self.additional_delay_value = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Multilink.Ppp.Multilink_.Fragment.Delay, ['delay_value', 'additional_delay_value'], name, value)


        class Serial(Entity):
            """
            Serial interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.PmPath>`
            
            .. attribute:: ppp
            
            	Point\-to\-Point Protocol
            	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp>`
            
            .. attribute:: analysis_module
            
            	Configure NAM on the interface
            	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.AnalysisModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Serial, self).__init__()

                self.yang_name = "Serial"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.Serial.SwitchportConf)), ("switchport", ("switchport", Native.Interface.Serial.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.Serial.StackwiseVirtual)), ("arp", ("arp", Native.Interface.Serial.Arp)), ("backup", ("backup", Native.Interface.Serial.Backup)), ("cemoudp", ("cemoudp", Native.Interface.Serial.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.Serial.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.Serial.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.Serial.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.Serial.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.Serial.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.Serial.Flowcontrol)), ("isis", ("isis", Native.Interface.Serial.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.Serial.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.Serial.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.Serial.Bandwidth)), ("dampening", ("dampening", Native.Interface.Serial.Dampening)), ("domain", ("domain", Native.Interface.Serial.Domain)), ("hold-queue", ("hold_queue", Native.Interface.Serial.HoldQueue)), ("mpls", ("mpls", Native.Interface.Serial.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.Serial.IpVrf)), ("vrf", ("vrf", Native.Interface.Serial.Vrf)), ("ip", ("ip", Native.Interface.Serial.Ip)), ("ipv6", ("ipv6", Native.Interface.Serial.Ipv6)), ("logging", ("logging", Native.Interface.Serial.Logging)), ("mdix", ("mdix", Native.Interface.Serial.Mdix)), ("mop", ("mop", Native.Interface.Serial.Mop)), ("interface_qos", ("interface_qos", Native.Interface.Serial.InterfaceQos)), ("source", ("source", Native.Interface.Serial.Source)), ("standby", ("standby", Native.Interface.Serial.Standby)), ("access-session", ("access_session", Native.Interface.Serial.AccessSession)), ("storm-control", ("storm_control", Native.Interface.Serial.StormControl)), ("trust", ("trust", Native.Interface.Serial.Trust)), ("priority-queue", ("priority_queue", Native.Interface.Serial.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.Serial.RcvQueue)), ("peer", ("peer", Native.Interface.Serial.Peer)), ("pm-path", ("pm_path", Native.Interface.Serial.PmPath)), ("Cisco-IOS-XE-ppp:ppp", ("ppp", Native.Interface.Serial.Ppp)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Interface.Serial.AnalysisModule))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.Serial.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.Serial.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.Serial.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.Serial.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.Serial.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.Serial.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.Serial.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.Serial.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.Serial.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.Serial.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.Serial.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.Serial.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.Serial.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.Serial.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.Serial.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.Serial.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.Serial.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.Serial.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.Serial.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.Serial.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.Serial.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.Serial.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.Serial.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.Serial.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.Serial.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.Serial.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.Serial.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.Serial.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.Serial.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.Serial.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.Serial.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.Serial.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.Serial.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.Serial.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.Serial.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.ppp = Native.Interface.Serial.Ppp()
                self.ppp.parent = self
                self._children_name_map["ppp"] = "Cisco-IOS-XE-ppp:ppp"

                self.analysis_module = Native.Interface.Serial.AnalysisModule()
                self.analysis_module.parent = self
                self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "Serial" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Serial, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Serial.Backup.Delay)), ("interface", ("interface", Native.Interface.Serial.Backup.Interface_)), ("load", ("load", Native.Interface.Serial.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Serial.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Serial.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Serial.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Serial.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Serial.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Serial.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Serial.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Serial.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Serial.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Serial.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Serial.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Serial.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Serial.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Serial.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Serial.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Serial.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Serial.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Serial.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Serial.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Serial.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Serial.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Serial.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.Serial.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Serial.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Serial.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Serial.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Serial.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Serial.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Serial.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Serial.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Serial.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Serial.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Serial.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Serial.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Serial.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Serial.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Verify>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Nat>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Serial.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.Serial.Ip.Arp)), ("vrf", ("vrf", Native.Interface.Serial.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.Serial.Ip.NoAddress)), ("address", ("address", Native.Interface.Serial.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Serial.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Serial.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.Serial.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.Serial.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Serial.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.Serial.Ip.Pim)), ("policy", ("policy", Native.Interface.Serial.Ip.Policy)), ("rip", ("rip", Native.Interface.Serial.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Serial.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Serial.Ip.RouteCache)), ("router", ("router", Native.Interface.Serial.Ip.Router)), ("tcp", ("tcp", Native.Interface.Serial.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Serial.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Serial.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Serial.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.Serial.Ip.Verify)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.Serial.Ip.Nat))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.Serial.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Serial.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Serial.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Serial.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Serial.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Serial.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Serial.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Serial.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Serial.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Serial.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Serial.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Serial.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Serial.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Serial.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Serial.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Serial.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Serial.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Serial.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.nat = Native.Interface.Serial.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Serial.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.Serial.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Serial.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Serial.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Serial.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Serial.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Serial.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Serial.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Serial.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Serial.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Serial.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Serial.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Serial.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Serial.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Serial.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Serial.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Serial.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Serial.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Serial.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.Serial.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Serial.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Serial.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Serial.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Serial.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Serial.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Serial.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Serial.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Serial.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Serial.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Serial.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Serial.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Serial.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Serial.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Serial.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Serial.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.Serial.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Serial.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Serial.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Serial.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Serial.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Serial.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Serial.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Serial.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Serial.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Serial.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.Serial.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Serial.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Serial.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Serial.Ipv6.Dhcp)), ("address", ("address", Native.Interface.Serial.Ipv6.Address)), ("nd", ("nd", Native.Interface.Serial.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.Serial.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Serial.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Serial.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Serial.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Serial.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Serial.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Serial.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Serial.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Serial.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Serial.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Serial.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Serial.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Serial.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Serial.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Serial.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Serial.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Serial.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Serial.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Serial.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Serial.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.Serial.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Serial.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Serial.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Serial.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Serial.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Serial.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Serial.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Serial.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Serial.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Serial.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.Serial.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Serial.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Serial.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Serial.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Serial.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Serial.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Serial.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Serial.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Serial.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Serial.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Serial.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Serial.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Serial.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Serial.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Serial.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Serial.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Serial.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Serial.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Serial.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Serial.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Serial.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Serial.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Serial.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Serial.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Serial.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Serial.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Serial.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Serial.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Serial.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Serial.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Serial.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Serial.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Serial.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Serial.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Serial.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Serial.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Serial.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Serial.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Serial.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Serial.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Serial.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Serial.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Serial.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Serial.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Serial.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Serial.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Serial.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Serial.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Serial.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Serial.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Serial.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Serial.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Serial.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Serial.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Serial.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Serial.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Serial.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Serial.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Serial.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Serial.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Serial.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Serial.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Serial.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Serial.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Serial.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Serial.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Serial.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Serial.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Serial.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Serial.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Serial.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Serial.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Serial.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Serial.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.PmPath, [u'name', u'interface_id'], name, value)


            class Ppp(Entity):
                """
                Point\-to\-Point Protocol
                
                .. attribute:: accounting
                
                	Set PPP network accounting method
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Accounting>`
                
                .. attribute:: chap
                
                	Set CHAP authentication parameters
                	**type**\:  :py:class:`Chap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp.Chap>`
                
                .. attribute:: authentication
                
                	Set PPP link authentication method
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp.Authentication>`
                
                .. attribute:: authorization
                
                	Set PPP network authorization method
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Authorization>`
                
                .. attribute:: ipcp
                
                	Set IPCP negotiation options
                	**type**\:  :py:class:`Ipcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp.Ipcp>`
                
                .. attribute:: multilink
                
                	Make interface multilink capable
                	**type**\:  :py:class:`Multilink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp.Multilink>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-ppp'
                _revision = '2018-02-03'

                def __init__(self):
                    super(Native.Interface.Serial.Ppp, self).__init__()

                    self.yang_name = "ppp"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("chap", ("chap", Native.Interface.Serial.Ppp.Chap)), ("authentication", ("authentication", Native.Interface.Serial.Ppp.Authentication)), ("ipcp", ("ipcp", Native.Interface.Serial.Ppp.Ipcp)), ("multilink", ("multilink", Native.Interface.Serial.Ppp.Multilink))])
                    self._leafs = OrderedDict([
                        ('accounting', (YLeaf(YType.str, 'accounting'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Ppp.Accounting')])),
                        ('authorization', (YLeaf(YType.str, 'authorization'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Ppp.Authorization')])),
                    ])
                    self.accounting = None
                    self.authorization = None

                    self.chap = Native.Interface.Serial.Ppp.Chap()
                    self.chap.parent = self
                    self._children_name_map["chap"] = "chap"

                    self.authentication = Native.Interface.Serial.Ppp.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.ipcp = Native.Interface.Serial.Ppp.Ipcp()
                    self.ipcp.parent = self
                    self._children_name_map["ipcp"] = "ipcp"

                    self.multilink = None
                    self._children_name_map["multilink"] = "multilink"
                    self._segment_path = lambda: "Cisco-IOS-XE-ppp:ppp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.Ppp, ['accounting', 'authorization'], name, value)

                class Accounting(Enum):
                    """
                    Accounting (Enum Class)

                    Set PPP network accounting method

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")


                class Authorization(Enum):
                    """
                    Authorization (Enum Class)

                    Set PPP network authorization method

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")



                class Chap(Entity):
                    """
                    Set CHAP authentication parameters
                    
                    .. attribute:: hostname
                    
                    	Set alternate CHAP hostname
                    	**type**\: str
                    
                    .. attribute:: challenge_length
                    
                    	Challenge Length for CHAP
                    	**type**\: int
                    
                    	**range:** 16..63
                    
                    

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.Serial.Ppp.Chap, self).__init__()

                        self.yang_name = "chap"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ('challenge_length', (YLeaf(YType.uint8, 'challenge-length'), ['int'])),
                        ])
                        self.hostname = None
                        self.challenge_length = None
                        self._segment_path = lambda: "chap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ppp.Chap, ['hostname', 'challenge_length'], name, value)


                class Authentication(Entity):
                    """
                    Set PPP link authentication method
                    
                    .. attribute:: method
                    
                    	
                    	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp.Authentication.Method>`
                    
                    .. attribute:: list_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: chap
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: callback
                    
                    	Authenticate remote on callback only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: callin
                    
                    	Authenticate remote on incoming call only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: callout
                    
                    	Authenticate remote on outgoing call only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default
                    
                    	Use the default authentication list
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: eap
                    
                    	Extensible Authentication Protocol (EAP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ms_chap
                    
                    	Microsoft Challenge Handshake Authentication Protocol (MS\-CHAP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ms_chap_v2
                    
                    	Microsoft CHAP Version 2 (MS\-CHAP\-V2)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: one_time
                    
                    	Allow use of username\*OTP for one\-time passwords
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: optional
                    
                    	Allow peer to refuse to authenticate
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pap
                    
                    	Password Authentication Protocol (PAP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.Serial.Ppp.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('method', (YLeaf(YType.enumeration, 'method'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Serial.Ppp.Authentication.Method')])),
                            ('list_name', (YLeaf(YType.str, 'list-name'), ['str'])),
                            ('chap', (YLeaf(YType.empty, 'chap'), ['Empty'])),
                            ('callback', (YLeaf(YType.empty, 'callback'), ['Empty'])),
                            ('callin', (YLeaf(YType.empty, 'callin'), ['Empty'])),
                            ('callout', (YLeaf(YType.empty, 'callout'), ['Empty'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                            ('ms_chap', (YLeaf(YType.empty, 'ms-chap'), ['Empty'])),
                            ('ms_chap_v2', (YLeaf(YType.empty, 'ms-chap-v2'), ['Empty'])),
                            ('one_time', (YLeaf(YType.empty, 'one-time'), ['Empty'])),
                            ('optional', (YLeaf(YType.empty, 'optional'), ['Empty'])),
                            ('pap', (YLeaf(YType.empty, 'pap'), ['Empty'])),
                        ])
                        self.method = None
                        self.list_name = None
                        self.chap = None
                        self.callback = None
                        self.callin = None
                        self.callout = None
                        self.default = None
                        self.eap = None
                        self.ms_chap = None
                        self.ms_chap_v2 = None
                        self.one_time = None
                        self.optional = None
                        self.pap = None
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ppp.Authentication, ['method', 'list_name', 'chap', 'callback', 'callin', 'callout', 'default', 'eap', 'ms_chap', 'ms_chap_v2', 'one_time', 'optional', 'pap'], name, value)

                    class Method(Enum):
                        """
                        Method (Enum Class)

                        .. data:: chap = 0

                        .. data:: eap = 1

                        .. data:: ms_chap = 2

                        .. data:: ms_chap_v2 = 3

                        .. data:: pap = 4

                        """

                        chap = Enum.YLeaf(0, "chap")

                        eap = Enum.YLeaf(1, "eap")

                        ms_chap = Enum.YLeaf(2, "ms-chap")

                        ms_chap_v2 = Enum.YLeaf(3, "ms-chap-v2")

                        pap = Enum.YLeaf(4, "pap")



                class Ipcp(Entity):
                    """
                    Set IPCP negotiation options
                    
                    .. attribute:: dns
                    
                    	Specify DNS negotiation options
                    	**type**\:  :py:class:`Dns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp.Ipcp.Dns>`
                    
                    

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.Serial.Ppp.Ipcp, self).__init__()

                        self.yang_name = "ipcp"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dns", ("dns", Native.Interface.Serial.Ppp.Ipcp.Dns))])
                        self._leafs = OrderedDict()

                        self.dns = Native.Interface.Serial.Ppp.Ipcp.Dns()
                        self.dns.parent = self
                        self._children_name_map["dns"] = "dns"
                        self._segment_path = lambda: "ipcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ppp.Ipcp, [], name, value)


                    class Dns(Entity):
                        """
                        Specify DNS negotiation options
                        
                        .. attribute:: primary
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.Serial.Ppp.Ipcp.Dns, self).__init__()

                            self.yang_name = "dns"
                            self.yang_parent_name = "ipcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary', (YLeaf(YType.str, 'primary'), ['str'])),
                            ])
                            self.primary = None
                            self._segment_path = lambda: "dns"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ppp.Ipcp.Dns, ['primary'], name, value)


                class Multilink(Entity):
                    """
                    Make interface multilink capable
                    
                    .. attribute:: links
                    
                    	Specify the limits on the number of links in a bundle
                    	**type**\:  :py:class:`Links <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp.Multilink.Links>`
                    
                    .. attribute:: group
                    
                    	Put interface in a multilink bundle
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: endpoint
                    
                    	Configure the local Endpoint Discriminator
                    	**type**\:  :py:class:`Endpoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp.Multilink.Endpoint>`
                    
                    .. attribute:: fragment
                    
                    	Specify fragmentation parameters
                    	**type**\:  :py:class:`Fragment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp.Multilink.Fragment>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.Serial.Ppp.Multilink, self).__init__()

                        self.yang_name = "multilink"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("links", ("links", Native.Interface.Serial.Ppp.Multilink.Links)), ("endpoint", ("endpoint", Native.Interface.Serial.Ppp.Multilink.Endpoint)), ("fragment", ("fragment", Native.Interface.Serial.Ppp.Multilink.Fragment))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                        ])
                        self.group = None

                        self.links = Native.Interface.Serial.Ppp.Multilink.Links()
                        self.links.parent = self
                        self._children_name_map["links"] = "links"

                        self.endpoint = Native.Interface.Serial.Ppp.Multilink.Endpoint()
                        self.endpoint.parent = self
                        self._children_name_map["endpoint"] = "endpoint"

                        self.fragment = Native.Interface.Serial.Ppp.Multilink.Fragment()
                        self.fragment.parent = self
                        self._children_name_map["fragment"] = "fragment"
                        self._segment_path = lambda: "multilink"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.Ppp.Multilink, ['group'], name, value)


                    class Links(Entity):
                        """
                        Specify the limits on the number of links in a bundle
                        
                        .. attribute:: minimum
                        
                        	Minimum number of links desired in the bundle
                        	**type**\:  :py:class:`Minimum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp.Multilink.Links.Minimum>`
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.Serial.Ppp.Multilink.Links, self).__init__()

                            self.yang_name = "links"
                            self.yang_parent_name = "multilink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimum", ("minimum", Native.Interface.Serial.Ppp.Multilink.Links.Minimum))])
                            self._leafs = OrderedDict()

                            self.minimum = Native.Interface.Serial.Ppp.Multilink.Links.Minimum()
                            self.minimum.parent = self
                            self._children_name_map["minimum"] = "minimum"
                            self._segment_path = lambda: "links"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ppp.Multilink.Links, [], name, value)


                        class Minimum(Entity):
                            """
                            Minimum number of links desired in the bundle
                            
                            .. attribute:: minimum_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: mandatory
                            
                            	Disable network layer until minimum number of links is reach
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ppp'
                            _revision = '2018-02-03'

                            def __init__(self):
                                super(Native.Interface.Serial.Ppp.Multilink.Links.Minimum, self).__init__()

                                self.yang_name = "minimum"
                                self.yang_parent_name = "links"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum_value', (YLeaf(YType.uint8, 'minimum-value'), ['int'])),
                                    ('mandatory', (YLeaf(YType.empty, 'mandatory'), ['Empty'])),
                                ])
                                self.minimum_value = None
                                self.mandatory = None
                                self._segment_path = lambda: "minimum"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Ppp.Multilink.Links.Minimum, ['minimum_value', 'mandatory'], name, value)


                    class Endpoint(Entity):
                        """
                        Configure the local Endpoint Discriminator
                        
                        .. attribute:: string
                        
                        	Use specified string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.Serial.Ppp.Multilink.Endpoint, self).__init__()

                            self.yang_name = "endpoint"
                            self.yang_parent_name = "multilink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                            ])
                            self.string = None
                            self._segment_path = lambda: "endpoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ppp.Multilink.Endpoint, ['string'], name, value)


                    class Fragment(Entity):
                        """
                        Specify fragmentation parameters
                        
                        .. attribute:: delay
                        
                        	Specify the maximum delay for each fragment
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.Ppp.Multilink.Fragment.Delay>`
                        
                        .. attribute:: disable
                        
                        	Suppress multilink fragmentation when possible
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.Serial.Ppp.Multilink.Fragment, self).__init__()

                            self.yang_name = "fragment"
                            self.yang_parent_name = "multilink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Serial.Ppp.Multilink.Fragment.Delay))])
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None

                            self.delay = Native.Interface.Serial.Ppp.Multilink.Fragment.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "fragment"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Serial.Ppp.Multilink.Fragment, ['disable'], name, value)


                        class Delay(Entity):
                            """
                            Specify the maximum delay for each fragment
                            
                            .. attribute:: delay_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..1000
                            
                            .. attribute:: additional_delay_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..999
                            
                            

                            """

                            _prefix = 'ios-ppp'
                            _revision = '2018-02-03'

                            def __init__(self):
                                super(Native.Interface.Serial.Ppp.Multilink.Fragment.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "fragment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('delay_value', (YLeaf(YType.uint16, 'delay-value'), ['int'])),
                                    ('additional_delay_value', (YLeaf(YType.uint16, 'additional-delay-value'), ['int'])),
                                ])
                                self.delay_value = None
                                self.additional_delay_value = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Serial.Ppp.Multilink.Fragment.Delay, ['delay_value', 'additional_delay_value'], name, value)


            class AnalysisModule(Entity):
                """
                Configure NAM on the interface
                
                .. attribute:: monitoring
                
                	Configure NAM monitoring on the interface
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Serial.AnalysisModule.Monitoring>`
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Interface.Serial.AnalysisModule, self).__init__()

                    self.yang_name = "analysis-module"
                    self.yang_parent_name = "Serial"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Interface.Serial.AnalysisModule.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = Native.Interface.Serial.AnalysisModule.Monitoring()
                    self.monitoring.parent = self
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Serial.AnalysisModule, [], name, value)


                class Monitoring(Entity):
                    """
                    Configure NAM monitoring on the interface
                    
                    .. attribute:: interface_name
                    
                    	The name of the output interface.  E.g., 'ucse 1/0/0'
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nam'
                    _revision = '2017-12-28'

                    def __init__(self):
                        super(Native.Interface.Serial.AnalysisModule.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "analysis-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "monitoring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Serial.AnalysisModule.Monitoring, ['interface_name'], name, value)


        class Tunnel(Entity):
            """
            Tunnel interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.PmPath>`
            
            .. attribute:: qos
            
            	Quality of Service related commands
            	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Qos>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.ServicePolicy>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Snmp>`
            
            .. attribute:: nhrp
            
            	NHRP Interface commands
            	**type**\:  :py:class:`Nhrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Nhrp>`
            
            .. attribute:: tunnel
            
            	protocol\-over\-protocol tunneling
            	**type**\:  :py:class:`Tunnel_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Crypto>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Utd>`
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol
            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Lisp>`
            
            .. attribute:: cdp
            
            	CDP interface subcommands
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cdp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ntp>`
            
            .. attribute:: performance
            
            	Global performance monitor configuration
            	**type**\:  :py:class:`Performance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Performance>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Umbrella>`
            
            .. attribute:: nat66
            
            	NAT66 interface commands
            	**type**\:  :py:class:`Nat66 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Nat66>`
            
            .. attribute:: ospfv3
            
            	OSPFv3 interface commands
            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3>`
            
            .. attribute:: udld
            
            	Configure UDLD enabled or disabled and ignore global UDLD setting
            	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Udld>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts>`
            
            .. attribute:: analysis_module
            
            	Configure NAM on the interface
            	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.AnalysisModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Tunnel, self).__init__()

                self.yang_name = "Tunnel"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.Tunnel.SwitchportConf)), ("switchport", ("switchport", Native.Interface.Tunnel.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.Tunnel.StackwiseVirtual)), ("arp", ("arp", Native.Interface.Tunnel.Arp)), ("backup", ("backup", Native.Interface.Tunnel.Backup)), ("cemoudp", ("cemoudp", Native.Interface.Tunnel.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.Tunnel.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.Tunnel.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.Tunnel.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.Tunnel.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.Tunnel.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.Tunnel.Flowcontrol)), ("isis", ("isis", Native.Interface.Tunnel.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.Tunnel.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.Tunnel.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.Tunnel.Bandwidth)), ("dampening", ("dampening", Native.Interface.Tunnel.Dampening)), ("domain", ("domain", Native.Interface.Tunnel.Domain)), ("hold-queue", ("hold_queue", Native.Interface.Tunnel.HoldQueue)), ("mpls", ("mpls", Native.Interface.Tunnel.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.Tunnel.IpVrf)), ("vrf", ("vrf", Native.Interface.Tunnel.Vrf)), ("ip", ("ip", Native.Interface.Tunnel.Ip)), ("ipv6", ("ipv6", Native.Interface.Tunnel.Ipv6)), ("logging", ("logging", Native.Interface.Tunnel.Logging)), ("mdix", ("mdix", Native.Interface.Tunnel.Mdix)), ("mop", ("mop", Native.Interface.Tunnel.Mop)), ("interface_qos", ("interface_qos", Native.Interface.Tunnel.InterfaceQos)), ("source", ("source", Native.Interface.Tunnel.Source)), ("standby", ("standby", Native.Interface.Tunnel.Standby)), ("access-session", ("access_session", Native.Interface.Tunnel.AccessSession)), ("storm-control", ("storm_control", Native.Interface.Tunnel.StormControl)), ("trust", ("trust", Native.Interface.Tunnel.Trust)), ("priority-queue", ("priority_queue", Native.Interface.Tunnel.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.Tunnel.RcvQueue)), ("peer", ("peer", Native.Interface.Tunnel.Peer)), ("pm-path", ("pm_path", Native.Interface.Tunnel.PmPath)), ("qos", ("qos", Native.Interface.Tunnel.Qos)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.Tunnel.ServicePolicy)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.Tunnel.Snmp)), ("Cisco-IOS-XE-tunnel:nhrp", ("nhrp", Native.Interface.Tunnel.Nhrp)), ("Cisco-IOS-XE-tunnel:tunnel", ("tunnel", Native.Interface.Tunnel.Tunnel_)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.Tunnel.Crypto)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.Tunnel.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.Tunnel.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.Tunnel.Utd)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.Tunnel.Lisp)), ("Cisco-IOS-XE-cdp:cdp", ("cdp", Native.Interface.Tunnel.Cdp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.Tunnel.Ntp)), ("Cisco-IOS-XE-ezpm:performance", ("performance", Native.Interface.Tunnel.Performance)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.Tunnel.Umbrella)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Interface.Tunnel.Ospfv3)), ("Cisco-IOS-XE-udld:udld", ("udld", Native.Interface.Tunnel.Udld)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.Tunnel.Cts)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Interface.Tunnel.AnalysisModule))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint32, 'name'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.ServiceInsertion')])),
                    ('nat66', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-nat:nat66'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Nat66')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.nat66 = None

                self.switchport_conf = Native.Interface.Tunnel.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.Tunnel.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.Tunnel.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.Tunnel.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.Tunnel.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.Tunnel.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.Tunnel.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.Tunnel.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.Tunnel.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.Tunnel.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.Tunnel.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.Tunnel.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.Tunnel.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.Tunnel.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.Tunnel.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.Tunnel.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.Tunnel.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.Tunnel.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.Tunnel.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.Tunnel.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.Tunnel.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.Tunnel.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.Tunnel.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.Tunnel.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.Tunnel.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.Tunnel.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.Tunnel.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.Tunnel.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.Tunnel.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.Tunnel.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.Tunnel.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.Tunnel.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.Tunnel.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.Tunnel.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.Tunnel.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.qos = Native.Interface.Tunnel.Qos()
                self.qos.parent = self
                self._children_name_map["qos"] = "qos"

                self.service_policy = Native.Interface.Tunnel.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.snmp = Native.Interface.Tunnel.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.nhrp = Native.Interface.Tunnel.Nhrp()
                self.nhrp.parent = self
                self._children_name_map["nhrp"] = "Cisco-IOS-XE-tunnel:nhrp"

                self.tunnel = Native.Interface.Tunnel.Tunnel_()
                self.tunnel.parent = self
                self._children_name_map["tunnel"] = "Cisco-IOS-XE-tunnel:tunnel"

                self.crypto = Native.Interface.Tunnel.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.et_analytics = Native.Interface.Tunnel.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.Tunnel.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.Tunnel.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.lisp = Native.Interface.Tunnel.Lisp()
                self.lisp.parent = self
                self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                self.cdp = Native.Interface.Tunnel.Cdp()
                self.cdp.parent = self
                self._children_name_map["cdp"] = "Cisco-IOS-XE-cdp:cdp"

                self.ntp = Native.Interface.Tunnel.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.performance = Native.Interface.Tunnel.Performance()
                self.performance.parent = self
                self._children_name_map["performance"] = "Cisco-IOS-XE-ezpm:performance"

                self.umbrella = Native.Interface.Tunnel.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.ospfv3 = Native.Interface.Tunnel.Ospfv3()
                self.ospfv3.parent = self
                self._children_name_map["ospfv3"] = "Cisco-IOS-XE-ospfv3:ospfv3"

                self.udld = Native.Interface.Tunnel.Udld()
                self.udld.parent = self
                self._children_name_map["udld"] = "Cisco-IOS-XE-udld:udld"

                self.cts = Native.Interface.Tunnel.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.analysis_module = Native.Interface.Tunnel.AnalysisModule()
                self.analysis_module.parent = self
                self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "Tunnel" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Tunnel, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'nat66'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class Nat66(Enum):
                """
                Nat66 (Enum Class)

                NAT66 interface commands

                .. data:: inside = 0

                .. data:: outside = 1

                """

                inside = Enum.YLeaf(0, "inside")

                outside = Enum.YLeaf(1, "outside")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Tunnel.Backup.Delay)), ("interface", ("interface", Native.Interface.Tunnel.Backup.Interface_)), ("load", ("load", Native.Interface.Tunnel.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Tunnel.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Tunnel.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Tunnel.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Tunnel.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Tunnel.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Tunnel.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Tunnel.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Tunnel.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Tunnel.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Tunnel.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Tunnel.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Tunnel.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Tunnel.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Tunnel.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Tunnel.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Tunnel.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Tunnel.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Tunnel.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Tunnel.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Tunnel.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Tunnel.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Tunnel.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.Tunnel.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Tunnel.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Tunnel.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Tunnel.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.Tunnel.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.Tunnel.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.Tunnel.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.Tunnel.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.Tunnel.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.Tunnel.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.Tunnel.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.Tunnel.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.Tunnel.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.Tunnel.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.Tunnel.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.Tunnel.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.Tunnel.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.Tunnel.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.Tunnel.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.Tunnel.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.Tunnel.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.Tunnel.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.Tunnel.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.Tunnel.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.Tunnel.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.Tunnel.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.Tunnel.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.Tunnel.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.Tunnel.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Tunnel.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.Tunnel.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.Tunnel.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.Tunnel.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.Tunnel.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Tunnel.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.Tunnel.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.Tunnel.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.Tunnel.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.Tunnel.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.Tunnel.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.Tunnel.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.Tunnel.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.Tunnel.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.Tunnel.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.Tunnel.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.Tunnel.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.Tunnel.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.Tunnel.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Tunnel.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.Tunnel.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.Tunnel.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Tunnel.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Tunnel.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Tunnel.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Tunnel.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Tunnel.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                .. attribute:: accounting
                
                	Enable MPLS accounting on this interface
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.Accounting>`
                
                .. attribute:: bgp
                
                	MPLS BGP
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.Bgp>`
                
                .. attribute:: ip
                
                	Configure dynamic MPLS forwarding for IP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: label
                
                	Label properties
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.Label>`
                
                .. attribute:: ldp
                
                	Configure Label Distribution Protocol (LDP) parameters
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.Ldp>`
                
                .. attribute:: mtu
                
                	Set MPLS Maximum Transmission Unit
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1501..1524
                
                		**type**\: int
                
                			**range:** 64..1500
                
                		**type**\: int
                
                			**range:** 64..9216
                
                .. attribute:: traffic_eng
                
                	Configure Traffic Engineering parameters
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:accounting", ("accounting", Native.Interface.Tunnel.Mpls.Accounting)), ("Cisco-IOS-XE-mpls:bgp", ("bgp", Native.Interface.Tunnel.Mpls.Bgp)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Interface.Tunnel.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Interface.Tunnel.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Interface.Tunnel.Mpls.TrafficEng))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.empty, 'Cisco-IOS-XE-mpls:ip'), ['Empty'])),
                        ('mtu', (YLeaf(YType.str, 'Cisco-IOS-XE-mpls:mtu'), ['int','int','int'])),
                    ])
                    self.ip = None
                    self.mtu = None

                    self.accounting = Native.Interface.Tunnel.Mpls.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "Cisco-IOS-XE-mpls:accounting"

                    self.bgp = Native.Interface.Tunnel.Mpls.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "Cisco-IOS-XE-mpls:bgp"

                    self.label = Native.Interface.Tunnel.Mpls.Label()
                    self.label.parent = self
                    self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

                    self.ldp = Native.Interface.Tunnel.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

                    self.traffic_eng = Native.Interface.Tunnel.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Mpls, [u'ip', u'mtu'], name, value)


                class Accounting(Entity):
                    """
                    Enable MPLS accounting on this interface
                    
                    .. attribute:: experimental
                    
                    	Count packets by MPLS experimental value on this interface
                    	**type**\:  :py:class:`Experimental <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.Accounting.Experimental>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Mpls.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("experimental", ("experimental", Native.Interface.Tunnel.Mpls.Accounting.Experimental))])
                        self._leafs = OrderedDict()

                        self.experimental = Native.Interface.Tunnel.Mpls.Accounting.Experimental()
                        self.experimental.parent = self
                        self._children_name_map["experimental"] = "experimental"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:accounting"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Mpls.Accounting, [], name, value)


                    class Experimental(Entity):
                        """
                        Count packets by MPLS experimental value on this interface
                        
                        .. attribute:: input
                        
                        	received packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	transmitted packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Mpls.Accounting.Experimental, self).__init__()

                            self.yang_name = "experimental"
                            self.yang_parent_name = "accounting"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                            ])
                            self.input = None
                            self.output = None
                            self._segment_path = lambda: "experimental"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Mpls.Accounting.Experimental, [u'input', u'output'], name, value)


                class Bgp(Entity):
                    """
                    MPLS BGP
                    
                    .. attribute:: forwarding
                    
                    	Configure MPLS forwarding for directly connected BGP peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Mpls.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarding', (YLeaf(YType.empty, 'forwarding'), ['Empty'])),
                        ])
                        self.forwarding = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Mpls.Bgp, [u'forwarding'], name, value)


                class Label(Entity):
                    """
                    Label properties
                    
                    .. attribute:: protocol
                    
                    	Configure label/tag distribution protocol (LDP/TDP)
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.Label.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Mpls.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Mpls.Label.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Mpls.Label, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        Configure label/tag distribution protocol (LDP/TDP)

                        .. data:: both = 0

                        .. data:: ldp = 1

                        .. data:: tdp = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        ldp = Enum.YLeaf(1, "ldp")

                        tdp = Enum.YLeaf(2, "tdp")



                class Ldp(Entity):
                    """
                    Configure Label Distribution Protocol (LDP) parameters
                    
                    .. attribute:: discovery
                    
                    	Configure interface LDP Discovery parameters
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.Ldp.Discovery>`
                    
                    .. attribute:: igp
                    
                    	Configure IGP\-related parameters
                    	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.Ldp.Igp>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", Native.Interface.Tunnel.Mpls.Ldp.Discovery)), ("igp", ("igp", Native.Interface.Tunnel.Mpls.Ldp.Igp))])
                        self._leafs = OrderedDict()

                        self.discovery = Native.Interface.Tunnel.Mpls.Ldp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"

                        self.igp = Native.Interface.Tunnel.Mpls.Ldp.Igp()
                        self.igp.parent = self
                        self._children_name_map["igp"] = "igp"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Mpls.Ldp, [], name, value)


                    class Discovery(Entity):
                        """
                        Configure interface LDP Discovery parameters
                        
                        .. attribute:: transport_address
                        
                        	Specify interface LDP transport address
                        	**type**\: union of the below types:
                        
                        		**type**\:  :py:class:`LdpDiscoveryAddressType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.LdpDiscoveryAddressType>`
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Mpls.Ldp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transport_address', (YLeaf(YType.str, 'transport-address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'LdpDiscoveryAddressType', ''),'str'])),
                            ])
                            self.transport_address = None
                            self._segment_path = lambda: "discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Mpls.Ldp.Discovery, [u'transport_address'], name, value)


                    class Igp(Entity):
                        """
                        Configure IGP\-related parameters
                        
                        .. attribute:: sync
                        
                        	Allow LDP\-IGP Synchronization on this interface
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.Ldp.Igp.Sync>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Mpls.Ldp.Igp, self).__init__()

                            self.yang_name = "igp"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sync", ("sync", Native.Interface.Tunnel.Mpls.Ldp.Igp.Sync))])
                            self._leafs = OrderedDict()

                            self.sync = None
                            self._children_name_map["sync"] = "sync"
                            self._segment_path = lambda: "igp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Mpls.Ldp.Igp, [], name, value)


                        class Sync(Entity):
                            """
                            Allow LDP\-IGP Synchronization on this interface
                            
                            .. attribute:: delay
                            
                            	Configure LDP to IGP sync achieved notification delay time (seconds)
                            	**type**\: int
                            
                            	**range:** 5..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Mpls.Ldp.Igp.Sync, self).__init__()

                                self.yang_name = "sync"
                                self.yang_parent_name = "igp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                ])
                                self.delay = None
                                self._segment_path = lambda: "sync"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Mpls.Ldp.Igp.Sync, [u'delay'], name, value)


                class TrafficEng(Entity):
                    """
                    Configure Traffic Engineering parameters
                    
                    .. attribute:: administrative_weight
                    
                    	Set the administrative weight for the interface\: <0..4294967295>
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: attribute_flags
                    
                    	Set user\-defined interface attibute flags\:  <0x0\-0xFFFFFFFF>
                    	**type**\: str
                    
                    	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: backup_path
                    
                    	Configure an MPLS TE backup for this interface
                    	**type**\:  :py:class:`BackupPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.TrafficEng.BackupPath>`
                    
                    .. attribute:: flooding
                    
                    	Set flooding parameters
                    	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.TrafficEng.Flooding>`
                    
                    .. attribute:: passive_interface
                    
                    	Force a flood of non\-IGP link
                    	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.TrafficEng.PassiveInterface>`
                    
                    .. attribute:: tunnels
                    
                    	enable MPLS Traffic Engineering tunnels
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup-path", ("backup_path", Native.Interface.Tunnel.Mpls.TrafficEng.BackupPath)), ("flooding", ("flooding", Native.Interface.Tunnel.Mpls.TrafficEng.Flooding)), ("passive-interface", ("passive_interface", Native.Interface.Tunnel.Mpls.TrafficEng.PassiveInterface))])
                        self._leafs = OrderedDict([
                            ('administrative_weight', (YLeaf(YType.uint32, 'administrative-weight'), ['int'])),
                            ('attribute_flags', (YLeaf(YType.str, 'attribute-flags'), ['str'])),
                            ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                        ])
                        self.administrative_weight = None
                        self.attribute_flags = None
                        self.tunnels = None

                        self.backup_path = Native.Interface.Tunnel.Mpls.TrafficEng.BackupPath()
                        self.backup_path.parent = self
                        self._children_name_map["backup_path"] = "backup-path"

                        self.flooding = Native.Interface.Tunnel.Mpls.TrafficEng.Flooding()
                        self.flooding.parent = self
                        self._children_name_map["flooding"] = "flooding"

                        self.passive_interface = Native.Interface.Tunnel.Mpls.TrafficEng.PassiveInterface()
                        self.passive_interface.parent = self
                        self._children_name_map["passive_interface"] = "passive-interface"
                        self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Mpls.TrafficEng, [u'administrative_weight', u'attribute_flags', u'tunnels'], name, value)


                    class BackupPath(Entity):
                        """
                        Configure an MPLS TE backup for this interface
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number\: <0..2147483647>
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Mpls.TrafficEng.BackupPath, self).__init__()

                            self.yang_name = "backup-path"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ])
                            self.tunnel = None
                            self._segment_path = lambda: "backup-path"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Mpls.TrafficEng.BackupPath, [u'tunnel'], name, value)


                    class Flooding(Entity):
                        """
                        Set flooding parameters
                        
                        .. attribute:: thresholds
                        
                        	Set flooding thresholds
                        	**type**\:  :py:class:`Thresholds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.TrafficEng.Flooding.Thresholds>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Mpls.TrafficEng.Flooding, self).__init__()

                            self.yang_name = "flooding"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("thresholds", ("thresholds", Native.Interface.Tunnel.Mpls.TrafficEng.Flooding.Thresholds))])
                            self._leafs = OrderedDict()

                            self.thresholds = Native.Interface.Tunnel.Mpls.TrafficEng.Flooding.Thresholds()
                            self.thresholds.parent = self
                            self._children_name_map["thresholds"] = "thresholds"
                            self._segment_path = lambda: "flooding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Mpls.TrafficEng.Flooding, [], name, value)


                        class Thresholds(Entity):
                            """
                            Set flooding thresholds
                            
                            .. attribute:: down
                            
                            	Set the thresholds for decreased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            .. attribute:: up
                            
                            	Set the thresholds for increased resource availability in percentage\: <0..100>
                            	**type**\: list of int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Mpls.TrafficEng.Flooding.Thresholds, self).__init__()

                                self.yang_name = "thresholds"
                                self.yang_parent_name = "flooding"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('down', (YLeafList(YType.uint8, 'down'), ['int'])),
                                    ('up', (YLeafList(YType.uint8, 'up'), ['int'])),
                                ])
                                self.down = []
                                self.up = []
                                self._segment_path = lambda: "thresholds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Mpls.TrafficEng.Flooding.Thresholds, [u'down', u'up'], name, value)


                    class PassiveInterface(Entity):
                        """
                        Force a flood of non\-IGP link
                        
                        .. attribute:: nbr_te_id
                        
                        	Set the neighbor TE ID (router\-id)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_if_addr
                        
                        	Set the Neighbor IP interface address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_igp_id
                        
                        	Set the Neighbor IGP ID (system\-id)
                        	**type**\:  :py:class:`NbrIgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Mpls.TrafficEng.PassiveInterface.NbrIgpId>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Mpls.TrafficEng.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nbr-igp-id", ("nbr_igp_id", Native.Interface.Tunnel.Mpls.TrafficEng.PassiveInterface.NbrIgpId))])
                            self._leafs = OrderedDict([
                                ('nbr_te_id', (YLeaf(YType.str, 'nbr-te-id'), ['str'])),
                                ('nbr_if_addr', (YLeaf(YType.str, 'nbr-if-addr'), ['str'])),
                            ])
                            self.nbr_te_id = None
                            self.nbr_if_addr = None

                            self.nbr_igp_id = Native.Interface.Tunnel.Mpls.TrafficEng.PassiveInterface.NbrIgpId()
                            self.nbr_igp_id.parent = self
                            self._children_name_map["nbr_igp_id"] = "nbr-igp-id"
                            self._segment_path = lambda: "passive-interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Mpls.TrafficEng.PassiveInterface, [u'nbr_te_id', u'nbr_if_addr'], name, value)


                        class NbrIgpId(Entity):
                            """
                            Set the Neighbor IGP ID (system\-id)
                            
                            .. attribute:: isis
                            
                            	Set the neighbor ISIS node ID
                            	**type**\: str
                            
                            .. attribute:: ospf
                            
                            	Set the neighbor OSPF node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Mpls.TrafficEng.PassiveInterface.NbrIgpId, self).__init__()

                                self.yang_name = "nbr-igp-id"
                                self.yang_parent_name = "passive-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis', (YLeaf(YType.str, 'isis'), ['str'])),
                                    ('ospf', (YLeaf(YType.str, 'ospf'), ['str'])),
                                ])
                                self.isis = None
                                self.ospf = None
                                self._segment_path = lambda: "nbr-igp-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Mpls.TrafficEng.PassiveInterface.NbrIgpId, [u'isis', u'ospf'], name, value)


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Tunnel.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Tunnel.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Tunnel.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Tunnel.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Igmp>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Flow>`
                
                .. attribute:: nbar
                
                	Network\-Based Application Recognition
                	**type**\:  :py:class:`Nbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nbar>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf>`
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Lisp>`
                
                .. attribute:: nhrp
                
                	NHRP interface subcommands
                	**type**\:  :py:class:`Nhrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp>`
                
                .. attribute:: rsvp
                
                	RSVP Interface Commands
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Tunnel.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.Tunnel.Ip.Arp)), ("vrf", ("vrf", Native.Interface.Tunnel.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.Tunnel.Ip.NoAddress)), ("address", ("address", Native.Interface.Tunnel.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Tunnel.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Tunnel.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.Tunnel.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.Tunnel.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Tunnel.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.Tunnel.Ip.Pim)), ("policy", ("policy", Native.Interface.Tunnel.Ip.Policy)), ("rip", ("rip", Native.Interface.Tunnel.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Tunnel.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Tunnel.Ip.RouteCache)), ("router", ("router", Native.Interface.Tunnel.Ip.Router)), ("tcp", ("tcp", Native.Interface.Tunnel.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Tunnel.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Tunnel.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Tunnel.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.Tunnel.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.Tunnel.Ip.Igmp)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.Tunnel.Ip.Flow)), ("Cisco-IOS-XE-nbar:nbar", ("nbar", Native.Interface.Tunnel.Ip.Nbar)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.Tunnel.Ip.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Interface.Tunnel.Ip.Lisp)), ("Cisco-IOS-XE-nhrp:nhrp", ("nhrp", Native.Interface.Tunnel.Ip.Nhrp)), ("Cisco-IOS-XE-rsvp:rsvp", ("rsvp", Native.Interface.Tunnel.Ip.Rsvp)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.Tunnel.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None
                    self.unreachables = None

                    self.access_group = Native.Interface.Tunnel.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Tunnel.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Tunnel.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Tunnel.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Tunnel.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Tunnel.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Tunnel.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Tunnel.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Tunnel.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Tunnel.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Tunnel.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Tunnel.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Tunnel.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Tunnel.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Tunnel.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Tunnel.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Tunnel.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Tunnel.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.Tunnel.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.flow = Native.Interface.Tunnel.Ip.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.nbar = Native.Interface.Tunnel.Ip.Nbar()
                    self.nbar.parent = self
                    self._children_name_map["nbar"] = "Cisco-IOS-XE-nbar:nbar"

                    self.ospf = Native.Interface.Tunnel.Ip.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.lisp = Native.Interface.Tunnel.Ip.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

                    self.nhrp = Native.Interface.Tunnel.Ip.Nhrp()
                    self.nhrp.parent = self
                    self._children_name_map["nhrp"] = "Cisco-IOS-XE-nhrp:nhrp"

                    self.rsvp = Native.Interface.Tunnel.Ip.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "Cisco-IOS-XE-rsvp:rsvp"

                    self.wccp = Native.Interface.Tunnel.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache', 'unreachables'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Tunnel.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.Tunnel.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Tunnel.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Tunnel.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Tunnel.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Tunnel.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Tunnel.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Tunnel.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Tunnel.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Tunnel.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Tunnel.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Tunnel.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Tunnel.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Tunnel.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Tunnel.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Tunnel.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Tunnel.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Tunnel.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Tunnel.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.Tunnel.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Tunnel.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Tunnel.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Tunnel.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Tunnel.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Tunnel.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Tunnel.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Tunnel.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Tunnel.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: accept_register
                    
                    	
                    	**type**\:  :py:class:`AcceptRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Pim.AcceptRegister>`
                    
                    .. attribute:: pim_mode
                    
                    	
                    	**type**\:  :py:class:`PimMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Pim.PimMode>`
                    
                    .. attribute:: nbma_mode
                    
                    	Enable PIM nbma\-mode operation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM router DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: query_interval
                    
                    	PIM router query interval
                    	**type**\:  :py:class:`QueryInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Pim.QueryInterval>`
                    
                    .. attribute:: spt_threshold
                    
                    	
                    	**type**\:  :py:class:`SptThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Pim.SptThreshold>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-multicast:accept-register", ("accept_register", Native.Interface.Tunnel.Ip.Pim.AcceptRegister)), ("Cisco-IOS-XE-multicast:query-interval", ("query_interval", Native.Interface.Tunnel.Ip.Pim.QueryInterval))])
                        self._leafs = OrderedDict([
                            ('pim_mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:pim-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ip.Pim.PimMode')])),
                            ('nbma_mode', (YLeaf(YType.empty, 'Cisco-IOS-XE-multicast:nbma-mode'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'Cisco-IOS-XE-multicast:dr-priority'), ['int'])),
                            ('spt_threshold', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-multicast:spt-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ip.Pim.SptThreshold')])),
                        ])
                        self.pim_mode = None
                        self.nbma_mode = None
                        self.dr_priority = None
                        self.spt_threshold = None

                        self.accept_register = Native.Interface.Tunnel.Ip.Pim.AcceptRegister()
                        self.accept_register.parent = self
                        self._children_name_map["accept_register"] = "Cisco-IOS-XE-multicast:accept-register"

                        self.query_interval = Native.Interface.Tunnel.Ip.Pim.QueryInterval()
                        self.query_interval.parent = self
                        self._children_name_map["query_interval"] = "Cisco-IOS-XE-multicast:query-interval"
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Pim, ['pim_mode', 'nbma_mode', 'dr_priority', 'spt_threshold'], name, value)

                    class PimMode(Enum):
                        """
                        PimMode (Enum Class)

                        .. data:: passive = 0

                        .. data:: dense_mode = 1

                        .. data:: sparse_mode = 2

                        .. data:: sparse_dense_mode = 3

                        """

                        passive = Enum.YLeaf(0, "passive")

                        dense_mode = Enum.YLeaf(1, "dense-mode")

                        sparse_mode = Enum.YLeaf(2, "sparse-mode")

                        sparse_dense_mode = Enum.YLeaf(3, "sparse-dense-mode")


                    class SptThreshold(Enum):
                        """
                        SptThreshold (Enum Class)

                        .. data:: infinity = 0

                        """

                        infinity = Enum.YLeaf(0, "infinity")



                    class AcceptRegister(Entity):
                        """
                        
                        
                        .. attribute:: list
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Pim.AcceptRegister, self).__init__()

                            self.yang_name = "accept-register"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:accept-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Pim.AcceptRegister, ['list'], name, value)


                    class QueryInterval(Entity):
                        """
                        PIM router query interval
                        
                        .. attribute:: seconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..18725
                        
                        .. attribute:: milliseconds_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 100..65535
                        
                        .. attribute:: msec
                        
                        	Query interval in milliseconds
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Pim.QueryInterval, self).__init__()

                            self.yang_name = "query-interval"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds_interval', (YLeaf(YType.uint16, 'seconds-interval'), ['int'])),
                                ('milliseconds_interval', (YLeaf(YType.uint16, 'milliseconds-interval'), ['int'])),
                                ('msec', (YLeaf(YType.empty, 'msec'), ['Empty'])),
                            ])
                            self.seconds_interval = None
                            self.milliseconds_interval = None
                            self.msec = None
                            self._segment_path = lambda: "Cisco-IOS-XE-multicast:query-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Pim.QueryInterval, ['seconds_interval', 'milliseconds_interval', 'msec'], name, value)


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Tunnel.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Tunnel.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Tunnel.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Tunnel.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Tunnel.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.Tunnel.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.Tunnel.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.Tunnel.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.Tunnel.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.Tunnel.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.Tunnel.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.Tunnel.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.Tunnel.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.Tunnel.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.Tunnel.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.Tunnel.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.Tunnel.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.Tunnel.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.Tunnel.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.Tunnel.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Tunnel.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Tunnel.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Tunnel.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Tunnel.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.Tunnel.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Tunnel.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Tunnel.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Tunnel.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Tunnel.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Tunnel.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Tunnel.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Tunnel.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.Tunnel.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.Tunnel.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.Tunnel.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.Tunnel.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.Tunnel.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.Tunnel.Ip.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.Tunnel.Ip.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ip.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Nbar(Entity):
                    """
                    Network\-Based Application Recognition
                    
                    .. attribute:: protocol_discovery
                    
                    	Enable protocol discovery for both ipv4 and ipv6
                    	**type**\:  :py:class:`ProtocolDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nbar.ProtocolDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-nbar'
                    _revision = '2018-06-06'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Nbar, self).__init__()

                        self.yang_name = "nbar"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-discovery", ("protocol_discovery", Native.Interface.Tunnel.Ip.Nbar.ProtocolDiscovery))])
                        self._leafs = OrderedDict()

                        self.protocol_discovery = None
                        self._children_name_map["protocol_discovery"] = "protocol-discovery"
                        self._segment_path = lambda: "Cisco-IOS-XE-nbar:nbar"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Nbar, [], name, value)


                    class ProtocolDiscovery(Entity):
                        """
                        Enable protocol discovery for both ipv4 and ipv6
                        
                        .. attribute:: ipv4_ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv4Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nbar'
                        _revision = '2018-06-06'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nbar.ProtocolDiscovery, self).__init__()

                            self.yang_name = "protocol-discovery"
                            self.yang_parent_name = "nbar"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4_ipv6', (YLeaf(YType.enumeration, 'ipv4-ipv6'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ip.Nbar.ProtocolDiscovery.Ipv4Ipv6')])),
                            ])
                            self.ipv4_ipv6 = None
                            self._segment_path = lambda: "protocol-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nbar.ProtocolDiscovery, ['ipv4_ipv6'], name, value)

                        class Ipv4Ipv6(Enum):
                            """
                            Ipv4Ipv6 (Enum Class)

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process_id
                    
                    	
                    	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.ProcessId>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.AuthenticationKey>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.Network>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.DeadInterval>`
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF Demand Circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fast_reroute
                    
                    	LFA FastReroute parameters
                    	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: lls
                    
                    	Link\-local Signaling (LLS) support
                    	**type**\:  :py:class:`Lls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.Lls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.MessageDigestKey>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.MultiArea>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: resync_timeout
                    
                    	Interval after which adjacency is reset if oob\-resync is not started
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Set OSPF protocol's state to disable under current interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.TtlSecurity>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.Tunnel.Ip.Ospf.ProcessId)), ("authentication", ("authentication", Native.Interface.Tunnel.Ip.Ospf.Authentication)), ("authentication-key", ("authentication_key", Native.Interface.Tunnel.Ip.Ospf.AuthenticationKey)), ("bfd", ("bfd", Native.Interface.Tunnel.Ip.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.Tunnel.Ip.Ospf.DatabaseFilter)), ("dead-interval", ("dead_interval", Native.Interface.Tunnel.Ip.Ospf.DeadInterval)), ("demand-circuit", ("demand_circuit", Native.Interface.Tunnel.Ip.Ospf.DemandCircuit)), ("fast-reroute", ("fast_reroute", Native.Interface.Tunnel.Ip.Ospf.FastReroute)), ("lls", ("lls", Native.Interface.Tunnel.Ip.Ospf.Lls)), ("message-digest-key", ("message_digest_key", Native.Interface.Tunnel.Ip.Ospf.MessageDigestKey)), ("multi-area", ("multi_area", Native.Interface.Tunnel.Ip.Ospf.MultiArea)), ("prefix-suppression", ("prefix_suppression", Native.Interface.Tunnel.Ip.Ospf.PrefixSuppression)), ("ttl-security", ("ttl_security", Native.Interface.Tunnel.Ip.Ospf.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('network', (YLeaf(YType.enumeration, 'network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ip.Ospf.Network')])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('resync_timeout', (YLeaf(YType.uint32, 'resync-timeout'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.network = None
                        self.cost = None
                        self.flood_reduction = None
                        self.hello_interval = None
                        self.mtu_ignore = None
                        self.priority = None
                        self.resync_timeout = None
                        self.retransmit_interval = None
                        self.shutdown = None
                        self.transmit_delay = None

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.authentication_key = Native.Interface.Tunnel.Ip.Ospf.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.Tunnel.Ip.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.dead_interval = Native.Interface.Tunnel.Ip.Ospf.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.fast_reroute = Native.Interface.Tunnel.Ip.Ospf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"

                        self.lls = None
                        self._children_name_map["lls"] = "lls"

                        self.multi_area = Native.Interface.Tunnel.Ip.Ospf.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.ttl_security = None
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.process_id = YList(self)
                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf, ['network', 'cost', 'flood_reduction', 'hello_interval', 'mtu_ignore', 'priority', 'resync_timeout', 'retransmit_interval', 'shutdown', 'transmit_delay'], name, value)

                    class Network(Enum):
                        """
                        Network (Enum Class)

                        Network type

                        .. data:: broadcast = 0

                        .. data:: non_broadcast = 1

                        .. data:: point_to_multipoint = 2

                        .. data:: point_to_point = 3

                        """

                        broadcast = Enum.YLeaf(0, "broadcast")

                        non_broadcast = Enum.YLeaf(1, "non-broadcast")

                        point_to_multipoint = Enum.YLeaf(2, "point-to-multipoint")

                        point_to_point = Enum.YLeaf(3, "point-to-point")



                    class ProcessId(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
                        
                        .. attribute:: area
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondaries
                        
                        	Include or exclude secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: none
                        
                        	Do not include secondary IP addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.ProcessId, self).__init__()

                            self.yang_name = "process-id"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('secondaries', (YLeaf(YType.empty, 'secondaries'), ['Empty'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.id = None
                            self.area = None
                            self.secondaries = None
                            self.none = None
                            self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.ProcessId, ['id', 'area', 'secondaries', 'none'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Use message\-digest authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Tunnel.Ip.Ospf.Authentication.KeyChain))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.message_digest = None
                            self.null = None

                            self.key_chain = Native.Interface.Tunnel.Ip.Ospf.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.Authentication, ['message_digest', 'null'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Ospf.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.Authentication.KeyChain, ['name'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.all = None
                            self.out = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.DatabaseFilter, ['all', 'out'], name, value)


                    class DeadInterval(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Set to 1 second
                        	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.DeadInterval.Minimal>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimal", ("minimal", Native.Interface.Tunnel.Ip.Ospf.DeadInterval.Minimal))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.minimal = Native.Interface.Tunnel.Ip.Ospf.DeadInterval.Minimal()
                            self.minimal.parent = self
                            self._children_name_map["minimal"] = "minimal"
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.DeadInterval, ['value'], name, value)


                        class Minimal(Entity):
                            """
                            Set to 1 second
                            
                            .. attribute:: hello_multiplier
                            
                            	Set multiplier for Hellos
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Ospf.DeadInterval.Minimal, self).__init__()

                                self.yang_name = "minimal"
                                self.yang_parent_name = "dead-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                ])
                                self.hello_multiplier = None
                                self._segment_path = lambda: "minimal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.DeadInterval.Minimal, ['hello_multiplier'], name, value)


                    class DemandCircuit(Entity):
                        """
                        OSPF Demand Circuit
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.DemandCircuit, ['ignore'], name, value)


                    class FastReroute(Entity):
                        """
                        LFA FastReroute parameters
                        
                        .. attribute:: per_prefix
                        
                        	Per\-prefix LFA FRR parameters
                        	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix))])
                            self._leafs = OrderedDict()

                            self.per_prefix = Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.FastReroute, [], name, value)


                        class PerPrefix(Entity):
                            """
                            Per\-prefix LFA FRR parameters
                            
                            .. attribute:: candidate
                            
                            	If interface can be protecting
                            	**type**\:  :py:class:`Candidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix.Candidate>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: protection
                            
                            	If interface can be protected
                            	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix.Protection>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("candidate", ("candidate", Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix.Candidate)), ("protection", ("protection", Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix.Protection))])
                                self._leafs = OrderedDict()

                                self.candidate = None
                                self._children_name_map["candidate"] = "candidate"

                                self.protection = None
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "per-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix, [], name, value)


                            class Candidate(Entity):
                                """
                                If interface can be protecting
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix.Candidate, self).__init__()

                                    self.yang_name = "candidate"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "candidate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix.Candidate, ['disable'], name, value)


                            class Protection(Entity):
                                """
                                If interface can be protected
                                
                                .. attribute:: disable
                                
                                	Disable LFA FRR interface protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix.Protection, self).__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.FastReroute.PerPrefix.Protection, ['disable'], name, value)


                    class Lls(Entity):
                        """
                        Link\-local Signaling (LLS) support
                        
                        .. attribute:: disable
                        
                        	disable LLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.Lls, self).__init__()

                            self.yang_name = "lls"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "lls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.Lls, ['disable'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Ospf.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Tunnel.Ip.Ospf.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Interface.Tunnel.Ip.Ospf.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Ospf.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.MultiArea, ['id', 'cost'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.PrefixSuppression, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: diable
                        
                        	disable TTL security check
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Ospf.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('diable', (YLeaf(YType.empty, 'diable'), ['Empty'])),
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.diable = None
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Ospf.TtlSecurity, ['diable', 'hops'], name, value)


                class Lisp(Entity):
                    """
                    Locator/ID Separation Protocol
                    
                    .. attribute:: source_locator
                    
                    	Choose IP source address for LISP packets egressing this interface
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_locator', (YLeaf(YType.str, 'source-locator'), ['str'])),
                        ])
                        self.source_locator = None
                        self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Lisp, ['source_locator'], name, value)


                class Nhrp(Entity):
                    """
                    NHRP interface subcommands
                    
                    .. attribute:: attribute
                    
                    	NHRP attribute set
                    	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Attribute>`
                    
                    .. attribute:: authentication
                    
                    	authentication string
                    	**type**\: str
                    
                    .. attribute:: cache
                    
                    	NHRP Cache related commands
                    	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Cache>`
                    
                    .. attribute:: connect
                    
                    	NHRP event request id
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: holdtime
                    
                    	Number of seconds
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: interest
                    
                    	Specify an access list
                    	**type**\:  :py:class:`Interest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Interest>`
                    
                    .. attribute:: map
                    
                    	Map dest IP addresses to NBMA addresses
                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Map>`
                    
                    .. attribute:: max_send
                    
                    	Rate limit NHRP traffic
                    	**type**\:  :py:class:`MaxSend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.MaxSend>`
                    
                    .. attribute:: network_id
                    
                    	Network identifier
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: nhs
                    
                    	Specify a next hop server
                    	**type**\:  :py:class:`Nhs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs>`
                    
                    .. attribute:: record
                    
                    	Allow NHRP record option
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: redirect
                    
                    	Enable NHRP redirect traffic indication
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Redirect>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: registration
                    
                    	Settings for registration packets
                    	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Registration>`
                    
                    .. attribute:: reject
                    
                    	NHRP resolution reject request
                    	**type**\:  :py:class:`Reject <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Reject>`
                    
                    .. attribute:: responder
                    
                    	Responder interface
                    	**type**\:  :py:class:`Responder <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Responder>`
                    
                    .. attribute:: server_only
                    
                    	Disable NHRP requests
                    	**type**\:  :py:class:`ServerOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.ServerOnly>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: shortcut
                    
                    	Enable shortcut switching
                    	**type**\:  :py:class:`Shortcut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Shortcut>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trigger_svc
                    
                    	Create NHRP cut\-through based on traffic load
                    	**type**\:  :py:class:`TriggerSvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.TriggerSvc>`
                    
                    .. attribute:: use
                    
                    	Number of packets to cause NHRP request
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-nhrp'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Nhrp, self).__init__()

                        self.yang_name = "nhrp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attribute", ("attribute", Native.Interface.Tunnel.Ip.Nhrp.Attribute)), ("cache", ("cache", Native.Interface.Tunnel.Ip.Nhrp.Cache)), ("interest", ("interest", Native.Interface.Tunnel.Ip.Nhrp.Interest)), ("map", ("map", Native.Interface.Tunnel.Ip.Nhrp.Map)), ("max-send", ("max_send", Native.Interface.Tunnel.Ip.Nhrp.MaxSend)), ("nhs", ("nhs", Native.Interface.Tunnel.Ip.Nhrp.Nhs)), ("redirect", ("redirect", Native.Interface.Tunnel.Ip.Nhrp.Redirect)), ("registration", ("registration", Native.Interface.Tunnel.Ip.Nhrp.Registration)), ("reject", ("reject", Native.Interface.Tunnel.Ip.Nhrp.Reject)), ("responder", ("responder", Native.Interface.Tunnel.Ip.Nhrp.Responder)), ("server-only", ("server_only", Native.Interface.Tunnel.Ip.Nhrp.ServerOnly)), ("shortcut", ("shortcut", Native.Interface.Tunnel.Ip.Nhrp.Shortcut)), ("trigger-svc", ("trigger_svc", Native.Interface.Tunnel.Ip.Nhrp.TriggerSvc))])
                        self._leafs = OrderedDict([
                            ('authentication', (YLeaf(YType.str, 'authentication'), ['str'])),
                            ('connect', (YLeaf(YType.uint16, 'connect'), ['int'])),
                            ('group', (YLeaf(YType.str, 'group'), ['str'])),
                            ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                            ('network_id', (YLeaf(YType.uint32, 'network-id'), ['int'])),
                            ('record', (YLeaf(YType.empty, 'record'), ['Empty'])),
                            ('use', (YLeaf(YType.uint16, 'use'), ['int'])),
                        ])
                        self.authentication = None
                        self.connect = None
                        self.group = None
                        self.holdtime = None
                        self.network_id = None
                        self.record = None
                        self.use = None

                        self.attribute = Native.Interface.Tunnel.Ip.Nhrp.Attribute()
                        self.attribute.parent = self
                        self._children_name_map["attribute"] = "attribute"

                        self.cache = Native.Interface.Tunnel.Ip.Nhrp.Cache()
                        self.cache.parent = self
                        self._children_name_map["cache"] = "cache"

                        self.interest = Native.Interface.Tunnel.Ip.Nhrp.Interest()
                        self.interest.parent = self
                        self._children_name_map["interest"] = "interest"

                        self.map = Native.Interface.Tunnel.Ip.Nhrp.Map()
                        self.map.parent = self
                        self._children_name_map["map"] = "map"

                        self.max_send = Native.Interface.Tunnel.Ip.Nhrp.MaxSend()
                        self.max_send.parent = self
                        self._children_name_map["max_send"] = "max-send"

                        self.nhs = Native.Interface.Tunnel.Ip.Nhrp.Nhs()
                        self.nhs.parent = self
                        self._children_name_map["nhs"] = "nhs"

                        self.redirect = None
                        self._children_name_map["redirect"] = "redirect"

                        self.registration = Native.Interface.Tunnel.Ip.Nhrp.Registration()
                        self.registration.parent = self
                        self._children_name_map["registration"] = "registration"

                        self.reject = Native.Interface.Tunnel.Ip.Nhrp.Reject()
                        self.reject.parent = self
                        self._children_name_map["reject"] = "reject"

                        self.responder = Native.Interface.Tunnel.Ip.Nhrp.Responder()
                        self.responder.parent = self
                        self._children_name_map["responder"] = "responder"

                        self.server_only = None
                        self._children_name_map["server_only"] = "server-only"

                        self.shortcut = None
                        self._children_name_map["shortcut"] = "shortcut"

                        self.trigger_svc = Native.Interface.Tunnel.Ip.Nhrp.TriggerSvc()
                        self.trigger_svc.parent = self
                        self._children_name_map["trigger_svc"] = "trigger-svc"
                        self._segment_path = lambda: "Cisco-IOS-XE-nhrp:nhrp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp, ['authentication', 'connect', 'group', 'holdtime', 'network_id', 'record', 'use'], name, value)


                    class Attribute(Entity):
                        """
                        NHRP attribute set
                        
                        .. attribute:: set
                        
                        	attribute set
                        	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Attribute.Set>`
                        
                        

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.Attribute, self).__init__()

                            self.yang_name = "attribute"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("set", ("set", Native.Interface.Tunnel.Ip.Nhrp.Attribute.Set))])
                            self._leafs = OrderedDict()

                            self.set = Native.Interface.Tunnel.Ip.Nhrp.Attribute.Set()
                            self.set.parent = self
                            self._children_name_map["set"] = "set"
                            self._segment_path = lambda: "attribute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Attribute, [], name, value)


                        class Set(Entity):
                            """
                            attribute set
                            
                            .. attribute:: attr_type
                            
                            	
                            	**type**\: list of  		 :py:class:`AttrType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Attribute.Set.AttrType>`
                            
                            

                            """

                            _prefix = 'ios-nhrp'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Nhrp.Attribute.Set, self).__init__()

                                self.yang_name = "set"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("attr-type", ("attr_type", Native.Interface.Tunnel.Ip.Nhrp.Attribute.Set.AttrType))])
                                self._leafs = OrderedDict()

                                self.attr_type = YList(self)
                                self._segment_path = lambda: "set"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Attribute.Set, [], name, value)


                            class AttrType(Entity):
                                """
                                
                                
                                .. attribute:: attr_type  (key)
                                
                                	attribute type
                                	**type**\: str
                                
                                .. attribute:: attr_val
                                
                                	attribute value
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-nhrp'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Nhrp.Attribute.Set.AttrType, self).__init__()

                                    self.yang_name = "attr-type"
                                    self.yang_parent_name = "set"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['attr_type']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('attr_type', (YLeaf(YType.str, 'attr-type'), ['str'])),
                                        ('attr_val', (YLeaf(YType.str, 'attr-val'), ['str'])),
                                    ])
                                    self.attr_type = None
                                    self.attr_val = None
                                    self._segment_path = lambda: "attr-type" + "[attr-type='" + str(self.attr_type) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Attribute.Set.AttrType, ['attr_type', 'attr_val'], name, value)


                    class Cache(Entity):
                        """
                        NHRP Cache related commands.
                        
                        .. attribute:: non_authoritative
                        
                        	Mark cache entries non\-authoritative
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.Cache, self).__init__()

                            self.yang_name = "cache"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('non_authoritative', (YLeaf(YType.empty, 'non-authoritative'), ['Empty'])),
                            ])
                            self.non_authoritative = None
                            self._segment_path = lambda: "cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Cache, ['non_authoritative'], name, value)


                    class Interest(Entity):
                        """
                        Specify an access list
                        
                        .. attribute:: acl_range
                        
                        	IP access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        .. attribute:: none
                        
                        	No traffic is interesting
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.Interest, self).__init__()

                            self.yang_name = "interest"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('acl_range', (YLeaf(YType.uint8, 'acl-range'), ['int'])),
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.acl_range = None
                            self.none = None
                            self._segment_path = lambda: "interest"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Interest, ['acl_range', 'none'], name, value)


                    class Map(Entity):
                        """
                        Map dest IP addresses to NBMA addresses
                        
                        .. attribute:: dest_ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`DestIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4>`
                        
                        .. attribute:: multicast
                        
                        	Use this NBMA mapping for broadcasts/multicasts
                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Map.Multicast>`
                        
                        .. attribute:: group
                        
                        	
                        	**type**\: list of  		 :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Map.Group>`
                        
                        

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.Map, self).__init__()

                            self.yang_name = "map"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dest-ipv4", ("dest_ipv4", Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4)), ("multicast", ("multicast", Native.Interface.Tunnel.Ip.Nhrp.Map.Multicast)), ("group", ("group", Native.Interface.Tunnel.Ip.Nhrp.Map.Group))])
                            self._leafs = OrderedDict()

                            self.multicast = Native.Interface.Tunnel.Ip.Nhrp.Map.Multicast()
                            self.multicast.parent = self
                            self._children_name_map["multicast"] = "multicast"

                            self.dest_ipv4 = YList(self)
                            self.group = YList(self)
                            self._segment_path = lambda: "map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Map, [], name, value)


                        class DestIpv4(Entity):
                            """
                            
                            
                            .. attribute:: dest_ipv4  (key)
                            
                            	IP address of destination
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: nbma_ipv4
                            
                            	
                            	**type**\: list of  		 :py:class:`NbmaIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4.NbmaIpv4>`
                            
                            .. attribute:: dest_mask
                            
                            	
                            	**type**\: list of  		 :py:class:`DestMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4.DestMask>`
                            
                            .. attribute:: nbma_ipv6
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-nhrp'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4, self).__init__()

                                self.yang_name = "dest-ipv4"
                                self.yang_parent_name = "map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['dest_ipv4']
                                self._child_classes = OrderedDict([("nbma-ipv4", ("nbma_ipv4", Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4.NbmaIpv4)), ("dest-mask", ("dest_mask", Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4.DestMask))])
                                self._leafs = OrderedDict([
                                    ('dest_ipv4', (YLeaf(YType.str, 'dest-ipv4'), ['str'])),
                                    ('nbma_ipv6', (YLeaf(YType.str, 'nbma-ipv6'), ['str'])),
                                ])
                                self.dest_ipv4 = None
                                self.nbma_ipv6 = None

                                self.nbma_ipv4 = YList(self)
                                self.dest_mask = YList(self)
                                self._segment_path = lambda: "dest-ipv4" + "[dest-ipv4='" + str(self.dest_ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4, ['dest_ipv4', 'nbma_ipv6'], name, value)


                            class NbmaIpv4(Entity):
                                """
                                
                                
                                .. attribute:: nbma_ipv4  (key)
                                
                                	IP NBMA address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-nhrp'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4.NbmaIpv4, self).__init__()

                                    self.yang_name = "nbma-ipv4"
                                    self.yang_parent_name = "dest-ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['nbma_ipv4']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nbma_ipv4', (YLeaf(YType.str, 'nbma-ipv4'), ['str'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.nbma_ipv4 = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "nbma-ipv4" + "[nbma-ipv4='" + str(self.nbma_ipv4) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4.NbmaIpv4, ['nbma_ipv4', 'ipv4', 'ipv6'], name, value)


                            class DestMask(Entity):
                                """
                                
                                
                                .. attribute:: dest_mask  (key)
                                
                                	IP mask of destination
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-nhrp'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4.DestMask, self).__init__()

                                    self.yang_name = "dest-mask"
                                    self.yang_parent_name = "dest-ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['dest_mask']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dest_mask', (YLeaf(YType.str, 'dest-mask'), ['str'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.dest_mask = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "dest-mask" + "[dest-mask='" + str(self.dest_mask) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Map.DestIpv4.DestMask, ['dest_mask', 'ipv4', 'ipv6'], name, value)


                        class Multicast(Entity):
                            """
                            Use this NBMA mapping for broadcasts/multicasts
                            
                            .. attribute:: nbma_ipv4
                            
                            	
                            	**type**\: list of str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: nbma_ipv6
                            
                            	
                            	**type**\: list of str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: dynamic
                            
                            	Dynamically learn destinations from client registrations on hub
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-nhrp'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Nhrp.Map.Multicast, self).__init__()

                                self.yang_name = "multicast"
                                self.yang_parent_name = "map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nbma_ipv4', (YLeafList(YType.str, 'nbma_ipv4'), ['str'])),
                                    ('nbma_ipv6', (YLeafList(YType.str, 'nbma_ipv6'), ['str'])),
                                    ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                                ])
                                self.nbma_ipv4 = []
                                self.nbma_ipv6 = []
                                self.dynamic = None
                                self._segment_path = lambda: "multicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Map.Multicast, ['nbma_ipv4', 'nbma_ipv6', 'dynamic'], name, value)


                        class Group(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: service_policy
                            
                            	
                            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Map.Group.ServicePolicy>`
                            
                            

                            """

                            _prefix = 'ios-nhrp'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Nhrp.Map.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.Tunnel.Ip.Nhrp.Map.Group.ServicePolicy))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.service_policy = Native.Interface.Tunnel.Ip.Nhrp.Map.Group.ServicePolicy()
                                self.service_policy.parent = self
                                self._children_name_map["service_policy"] = "service-policy"
                                self._segment_path = lambda: "group" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Map.Group, ['name'], name, value)


                            class ServicePolicy(Entity):
                                """
                                
                                
                                .. attribute:: output
                                
                                	Policy
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-nhrp'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Nhrp.Map.Group.ServicePolicy, self).__init__()

                                    self.yang_name = "service-policy"
                                    self.yang_parent_name = "group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                                    ])
                                    self.output = None
                                    self._segment_path = lambda: "service-policy"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Map.Group.ServicePolicy, ['output'], name, value)


                    class MaxSend(Entity):
                        """
                        Rate limit NHRP traffic
                        
                        .. attribute:: pkt_count
                        
                        	
                        	**type**\: list of  		 :py:class:`PktCount <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.MaxSend.PktCount>`
                        
                        

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.MaxSend, self).__init__()

                            self.yang_name = "max-send"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pkt-count", ("pkt_count", Native.Interface.Tunnel.Ip.Nhrp.MaxSend.PktCount))])
                            self._leafs = OrderedDict()

                            self.pkt_count = YList(self)
                            self._segment_path = lambda: "max-send"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.MaxSend, [], name, value)


                        class PktCount(Entity):
                            """
                            
                            
                            .. attribute:: pkt_count  (key)
                            
                            	Packet count
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: every
                            
                            	Interval in seconds
                            	**type**\: int
                            
                            	**range:** 10..65535
                            
                            

                            """

                            _prefix = 'ios-nhrp'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Nhrp.MaxSend.PktCount, self).__init__()

                                self.yang_name = "pkt-count"
                                self.yang_parent_name = "max-send"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['pkt_count']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pkt_count', (YLeaf(YType.uint16, 'pkt-count'), ['int'])),
                                    ('every', (YLeaf(YType.uint16, 'every'), ['int'])),
                                ])
                                self.pkt_count = None
                                self.every = None
                                self._segment_path = lambda: "pkt-count" + "[pkt-count='" + str(self.pkt_count) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.MaxSend.PktCount, ['pkt_count', 'every'], name, value)


                    class Nhs(Entity):
                        """
                        Specify a next hop server
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4>`
                        
                        .. attribute:: cluster
                        
                        	NHS Redundancy cluster configurations
                        	**type**\:  :py:class:`Cluster <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Cluster>`
                        
                        .. attribute:: dynamic
                        
                        	NHS protocol address dynamically learnt
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic>`
                        
                        .. attribute:: fallback
                        
                        	NHS Redundancy Fallback time, 0 \-60 seconds
                        	**type**\: int
                        
                        	**range:** 0..60
                        
                        

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs, self).__init__()

                            self.yang_name = "nhs"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4)), ("cluster", ("cluster", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Cluster)), ("dynamic", ("dynamic", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic))])
                            self._leafs = OrderedDict([
                                ('fallback', (YLeaf(YType.uint8, 'fallback'), ['int'])),
                            ])
                            self.fallback = None

                            self.cluster = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Cluster()
                            self.cluster.parent = self
                            self._children_name_map["cluster"] = "cluster"

                            self.dynamic = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic()
                            self.dynamic.parent = self
                            self._children_name_map["dynamic"] = "dynamic"

                            self.ipv4 = YList(self)
                            self._segment_path = lambda: "nhs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs, ['fallback'], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	Protocol IP address of NHS
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cluster
                            
                            	NHS cluster number
                            	**type**\: int
                            
                            	**range:** 0..10
                            
                            .. attribute:: nbma
                            
                            	NBMA of NHS
                            	**type**\:  :py:class:`Nbma <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma>`
                            
                            .. attribute:: priority
                            
                            	NHS priority, don't specify for default priority
                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Priority>`
                            
                            

                            """

                            _prefix = 'ios-nhrp'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "nhs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([("nbma", ("nbma", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma)), ("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Priority))])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                ])
                                self.ipv4 = None
                                self.cluster = None

                                self.nbma = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma()
                                self.nbma.parent = self
                                self._children_name_map["nbma"] = "nbma"

                                self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Priority()
                                self.priority.parent = self
                                self._children_name_map["priority"] = "priority"
                                self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4, ['ipv4', 'cluster'], name, value)


                            class Nbma(Entity):
                                """
                                NBMA of NHS
                                
                                .. attribute:: ipv4
                                
                                	
                                	**type**\: list of  		 :py:class:`Ipv4_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_>`
                                
                                .. attribute:: nhs_fqdn
                                
                                	
                                	**type**\: list of  		 :py:class:`NhsFqdn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn>`
                                
                                .. attribute:: ipv6
                                
                                	
                                	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6>`
                                
                                

                                """

                                _prefix = 'ios-nhrp'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma, self).__init__()

                                    self.yang_name = "nbma"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_)), ("nhs-fqdn", ("nhs_fqdn", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn)), ("ipv6", ("ipv6", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6))])
                                    self._leafs = OrderedDict()

                                    self.ipv4 = YList(self)
                                    self.nhs_fqdn = YList(self)
                                    self.ipv6 = YList(self)
                                    self._segment_path = lambda: "nbma"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma, [], name, value)


                                class Ipv4_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipv4  (key)
                                    
                                    	IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster
                                    
                                    	NHS cluster number
                                    	**type**\: int
                                    
                                    	**range:** 0..10
                                    
                                    .. attribute:: multicast
                                    
                                    	Use this NBMA mapping for broadcasts/multicasts
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: priority
                                    
                                    	NHS priority, don't specify for default priority
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nhrp'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_, self).__init__()

                                        self.yang_name = "ipv4"
                                        self.yang_parent_name = "nbma"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ipv4']
                                        self._child_classes = OrderedDict([("multicast", ("multicast", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast)), ("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Priority))])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                        ])
                                        self.ipv4 = None
                                        self.cluster = None

                                        self.multicast = None
                                        self._children_name_map["multicast"] = "multicast"

                                        self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_, ['ipv4', 'cluster'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Use this NBMA mapping for broadcasts/multicasts
                                        
                                        .. attribute:: cluster
                                        
                                        	NHS cluster number
                                        	**type**\: int
                                        
                                        	**range:** 0..10
                                        
                                        .. attribute:: priority
                                        
                                        	NHS priority, don't specify for default priority
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast.Priority>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast.Priority))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                            ])
                                            self.cluster = None

                                            self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "multicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast, ['cluster'], name, value)


                                        class Priority(Entity):
                                            """
                                            NHS priority, don't specify for default priority
                                            
                                            .. attribute:: prior
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Prior <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast.Priority.Prior>`
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prior", ("prior", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast.Priority.Prior))])
                                                self._leafs = OrderedDict()

                                                self.prior = YList(self)
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast.Priority, [], name, value)


                                            class Prior(Entity):
                                                """
                                                
                                                
                                                .. attribute:: prior  (key)
                                                
                                                	NHS priority, range = 0 to 255, 0 is the highest
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cluster
                                                
                                                	NHS cluster number
                                                	**type**\: int
                                                
                                                	**range:** 0..10
                                                
                                                

                                                """

                                                _prefix = 'ios-nhrp'
                                                _revision = '2017-02-07'

                                                def __init__(self):
                                                    super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast.Priority.Prior, self).__init__()

                                                    self.yang_name = "prior"
                                                    self.yang_parent_name = "priority"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['prior']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prior', (YLeaf(YType.uint8, 'prior'), ['int'])),
                                                        ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                    ])
                                                    self.prior = None
                                                    self.cluster = None
                                                    self._segment_path = lambda: "prior" + "[prior='" + str(self.prior) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Multicast.Priority.Prior, ['prior', 'cluster'], name, value)


                                    class Priority(Entity):
                                        """
                                        NHS priority, don't specify for default priority
                                        
                                        .. attribute:: pri
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Pri <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Priority.Pri>`
                                        
                                        

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("pri", ("pri", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Priority.Pri))])
                                            self._leafs = OrderedDict()

                                            self.pri = YList(self)
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Priority, [], name, value)


                                        class Pri(Entity):
                                            """
                                            
                                            
                                            .. attribute:: pri  (key)
                                            
                                            	NHS priority, range = 0 to 255, 0 is the highest
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cluster
                                            
                                            	NHS cluster number
                                            	**type**\: int
                                            
                                            	**range:** 0..10
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Priority.Pri, self).__init__()

                                                self.yang_name = "pri"
                                                self.yang_parent_name = "priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['pri']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pri', (YLeaf(YType.uint8, 'pri'), ['int'])),
                                                    ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                ])
                                                self.pri = None
                                                self.cluster = None
                                                self._segment_path = lambda: "pri" + "[pri='" + str(self.pri) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv4_.Priority.Pri, ['pri', 'cluster'], name, value)


                                class NhsFqdn(Entity):
                                    """
                                    
                                    
                                    .. attribute:: nhs_fqdn  (key)
                                    
                                    	NHS FQDN string
                                    	**type**\: str
                                    
                                    .. attribute:: cluster
                                    
                                    	NHS cluster number
                                    	**type**\: int
                                    
                                    	**range:** 0..10
                                    
                                    .. attribute:: multicast
                                    
                                    	Use this NBMA mapping for broadcasts/multicasts
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: priority
                                    
                                    	NHS priority, don't specify for default priority
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nhrp'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn, self).__init__()

                                        self.yang_name = "nhs-fqdn"
                                        self.yang_parent_name = "nbma"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['nhs_fqdn']
                                        self._child_classes = OrderedDict([("multicast", ("multicast", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast)), ("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Priority))])
                                        self._leafs = OrderedDict([
                                            ('nhs_fqdn', (YLeaf(YType.str, 'nhs-fqdn'), ['str'])),
                                            ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                        ])
                                        self.nhs_fqdn = None
                                        self.cluster = None

                                        self.multicast = None
                                        self._children_name_map["multicast"] = "multicast"

                                        self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "nhs-fqdn" + "[nhs-fqdn='" + str(self.nhs_fqdn) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn, ['nhs_fqdn', 'cluster'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Use this NBMA mapping for broadcasts/multicasts
                                        
                                        .. attribute:: cluster
                                        
                                        	NHS cluster number
                                        	**type**\: int
                                        
                                        	**range:** 0..10
                                        
                                        .. attribute:: priority
                                        
                                        	NHS priority, don't specify for default priority
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast.Priority>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "nhs-fqdn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast.Priority))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                            ])
                                            self.cluster = None

                                            self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "multicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast, ['cluster'], name, value)


                                        class Priority(Entity):
                                            """
                                            NHS priority, don't specify for default priority
                                            
                                            .. attribute:: mc_pri
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`McPri <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast.Priority.McPri>`
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("mc-pri", ("mc_pri", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast.Priority.McPri))])
                                                self._leafs = OrderedDict()

                                                self.mc_pri = YList(self)
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast.Priority, [], name, value)


                                            class McPri(Entity):
                                                """
                                                
                                                
                                                .. attribute:: mc_pri  (key)
                                                
                                                	NHS priority, range = 0 to 255, 0 is the highest
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cluster
                                                
                                                	NHS cluster number
                                                	**type**\: int
                                                
                                                	**range:** 0..10
                                                
                                                

                                                """

                                                _prefix = 'ios-nhrp'
                                                _revision = '2017-02-07'

                                                def __init__(self):
                                                    super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast.Priority.McPri, self).__init__()

                                                    self.yang_name = "mc-pri"
                                                    self.yang_parent_name = "priority"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['mc_pri']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mc_pri', (YLeaf(YType.uint8, 'mc-pri'), ['int'])),
                                                        ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                    ])
                                                    self.mc_pri = None
                                                    self.cluster = None
                                                    self._segment_path = lambda: "mc-pri" + "[mc-pri='" + str(self.mc_pri) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Multicast.Priority.McPri, ['mc_pri', 'cluster'], name, value)


                                    class Priority(Entity):
                                        """
                                        NHS priority, don't specify for default priority
                                        
                                        .. attribute:: nhs_pri
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`NhsPri <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Priority.NhsPri>`
                                        
                                        

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "nhs-fqdn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("nhs-pri", ("nhs_pri", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Priority.NhsPri))])
                                            self._leafs = OrderedDict()

                                            self.nhs_pri = YList(self)
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Priority, [], name, value)


                                        class NhsPri(Entity):
                                            """
                                            
                                            
                                            .. attribute:: nhs_pri  (key)
                                            
                                            	NHS priority, range = 0 to 255, 0 is the highest
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cluster
                                            
                                            	NHS cluster number
                                            	**type**\: int
                                            
                                            	**range:** 0..10
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Priority.NhsPri, self).__init__()

                                                self.yang_name = "nhs-pri"
                                                self.yang_parent_name = "priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['nhs_pri']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('nhs_pri', (YLeaf(YType.uint8, 'nhs-pri'), ['int'])),
                                                    ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                ])
                                                self.nhs_pri = None
                                                self.cluster = None
                                                self._segment_path = lambda: "nhs-pri" + "[nhs-pri='" + str(self.nhs_pri) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.NhsFqdn.Priority.NhsPri, ['nhs_pri', 'cluster'], name, value)


                                class Ipv6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipv6  (key)
                                    
                                    	IPv6 address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster
                                    
                                    	NHS cluster number
                                    	**type**\: int
                                    
                                    	**range:** 0..10
                                    
                                    .. attribute:: multicast
                                    
                                    	Use this NBMA mapping for broadcasts/multicasts
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: priority
                                    
                                    	NHS priority, don't specify for default priority
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nhrp'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6, self).__init__()

                                        self.yang_name = "ipv6"
                                        self.yang_parent_name = "nbma"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ipv6']
                                        self._child_classes = OrderedDict([("multicast", ("multicast", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast)), ("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Priority))])
                                        self._leafs = OrderedDict([
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                        ])
                                        self.ipv6 = None
                                        self.cluster = None

                                        self.multicast = None
                                        self._children_name_map["multicast"] = "multicast"

                                        self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "ipv6" + "[ipv6='" + str(self.ipv6) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6, ['ipv6', 'cluster'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Use this NBMA mapping for broadcasts/multicasts
                                        
                                        .. attribute:: cluster
                                        
                                        	NHS cluster number
                                        	**type**\: int
                                        
                                        	**range:** 0..10
                                        
                                        .. attribute:: priority
                                        
                                        	NHS priority, don't specify for default priority
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast.Priority>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast.Priority))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                            ])
                                            self.cluster = None

                                            self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "multicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast, ['cluster'], name, value)


                                        class Priority(Entity):
                                            """
                                            NHS priority, don't specify for default priority
                                            
                                            .. attribute:: mc_pri
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`McPri <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast.Priority.McPri>`
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("mc-pri", ("mc_pri", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast.Priority.McPri))])
                                                self._leafs = OrderedDict()

                                                self.mc_pri = YList(self)
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast.Priority, [], name, value)


                                            class McPri(Entity):
                                                """
                                                
                                                
                                                .. attribute:: mc_pri  (key)
                                                
                                                	NHS priority, range = 0 to 255, 0 is the highest
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cluster
                                                
                                                	NHS cluster number
                                                	**type**\: int
                                                
                                                	**range:** 0..10
                                                
                                                

                                                """

                                                _prefix = 'ios-nhrp'
                                                _revision = '2017-02-07'

                                                def __init__(self):
                                                    super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast.Priority.McPri, self).__init__()

                                                    self.yang_name = "mc-pri"
                                                    self.yang_parent_name = "priority"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['mc_pri']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mc_pri', (YLeaf(YType.uint8, 'mc-pri'), ['int'])),
                                                        ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                    ])
                                                    self.mc_pri = None
                                                    self.cluster = None
                                                    self._segment_path = lambda: "mc-pri" + "[mc-pri='" + str(self.mc_pri) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Multicast.Priority.McPri, ['mc_pri', 'cluster'], name, value)


                                    class Priority(Entity):
                                        """
                                        NHS priority, don't specify for default priority
                                        
                                        .. attribute:: mc_prior
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`McPrior <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Priority.McPrior>`
                                        
                                        

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("mc-prior", ("mc_prior", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Priority.McPrior))])
                                            self._leafs = OrderedDict()

                                            self.mc_prior = YList(self)
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Priority, [], name, value)


                                        class McPrior(Entity):
                                            """
                                            
                                            
                                            .. attribute:: mc_prior  (key)
                                            
                                            	NHS priority, range = 0 to 255, 0 is the highest
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cluster
                                            
                                            	NHS cluster number
                                            	**type**\: int
                                            
                                            	**range:** 0..10
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Priority.McPrior, self).__init__()

                                                self.yang_name = "mc-prior"
                                                self.yang_parent_name = "priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mc_prior']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mc_prior', (YLeaf(YType.uint8, 'mc-prior'), ['int'])),
                                                    ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                ])
                                                self.mc_prior = None
                                                self.cluster = None
                                                self._segment_path = lambda: "mc-prior" + "[mc-prior='" + str(self.mc_prior) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Nbma.Ipv6.Priority.McPrior, ['mc_prior', 'cluster'], name, value)


                            class Priority(Entity):
                                """
                                NHS priority, don't specify for default priority
                                
                                .. attribute:: pri_range
                                
                                	
                                	**type**\: list of  		 :py:class:`PriRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Priority.PriRange>`
                                
                                

                                """

                                _prefix = 'ios-nhrp'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Priority, self).__init__()

                                    self.yang_name = "priority"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pri-range", ("pri_range", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Priority.PriRange))])
                                    self._leafs = OrderedDict()

                                    self.pri_range = YList(self)
                                    self._segment_path = lambda: "priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Priority, [], name, value)


                                class PriRange(Entity):
                                    """
                                    
                                    
                                    .. attribute:: pri_range  (key)
                                    
                                    	NHS priority, range = 0 to 255, 0 is the highest
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: cluster
                                    
                                    	NHS cluster number
                                    	**type**\: int
                                    
                                    	**range:** 0..10
                                    
                                    

                                    """

                                    _prefix = 'ios-nhrp'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Priority.PriRange, self).__init__()

                                        self.yang_name = "pri-range"
                                        self.yang_parent_name = "priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['pri_range']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pri_range', (YLeaf(YType.uint8, 'pri-range'), ['int'])),
                                            ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                        ])
                                        self.pri_range = None
                                        self.cluster = None
                                        self._segment_path = lambda: "pri-range" + "[pri-range='" + str(self.pri_range) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Ipv4.Priority.PriRange, ['pri_range', 'cluster'], name, value)


                        class Cluster(Entity):
                            """
                            NHS Redundancy cluster configurations
                            
                            .. attribute:: clus_num
                            
                            	
                            	**type**\: list of  		 :py:class:`ClusNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Cluster.ClusNum>`
                            
                            

                            """

                            _prefix = 'ios-nhrp'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Cluster, self).__init__()

                                self.yang_name = "cluster"
                                self.yang_parent_name = "nhs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("clus-num", ("clus_num", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Cluster.ClusNum))])
                                self._leafs = OrderedDict()

                                self.clus_num = YList(self)
                                self._segment_path = lambda: "cluster"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Cluster, [], name, value)


                            class ClusNum(Entity):
                                """
                                
                                
                                .. attribute:: clus_num  (key)
                                
                                	NHS cluster number
                                	**type**\: int
                                
                                	**range:** 0..10
                                
                                .. attribute:: max_connections
                                
                                	Max\-connections value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-nhrp'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Cluster.ClusNum, self).__init__()

                                    self.yang_name = "clus-num"
                                    self.yang_parent_name = "cluster"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['clus_num']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('clus_num', (YLeaf(YType.uint8, 'clus-num'), ['int'])),
                                        ('max_connections', (YLeaf(YType.uint8, 'max-connections'), ['int'])),
                                    ])
                                    self.clus_num = None
                                    self.max_connections = None
                                    self._segment_path = lambda: "clus-num" + "[clus-num='" + str(self.clus_num) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Cluster.ClusNum, ['clus_num', 'max_connections'], name, value)


                        class Dynamic(Entity):
                            """
                            NHS protocol address dynamically learnt
                            
                            .. attribute:: nbma
                            
                            	NBMA of NHS
                            	**type**\:  :py:class:`Nbma <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma>`
                            
                            

                            """

                            _prefix = 'ios-nhrp'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "nhs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("nbma", ("nbma", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma))])
                                self._leafs = OrderedDict()

                                self.nbma = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma()
                                self.nbma.parent = self
                                self._children_name_map["nbma"] = "nbma"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic, [], name, value)


                            class Nbma(Entity):
                                """
                                NBMA of NHS
                                
                                .. attribute:: ipv4
                                
                                	NBMA of NHS
                                	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4>`
                                
                                .. attribute:: dyn_fqdn
                                
                                	
                                	**type**\: list of  		 :py:class:`DynFqdn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn>`
                                
                                .. attribute:: ipv6
                                
                                	
                                	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6>`
                                
                                

                                """

                                _prefix = 'ios-nhrp'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma, self).__init__()

                                    self.yang_name = "nbma"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4)), ("dyn-fqdn", ("dyn_fqdn", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn)), ("ipv6", ("ipv6", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6))])
                                    self._leafs = OrderedDict()

                                    self.ipv4 = YList(self)
                                    self.dyn_fqdn = YList(self)
                                    self.ipv6 = YList(self)
                                    self._segment_path = lambda: "nbma"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma, [], name, value)


                                class Ipv4(Entity):
                                    """
                                    NBMA of NHS
                                    
                                    .. attribute:: ipv4  (key)
                                    
                                    	IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster
                                    
                                    	NHS cluster number
                                    	**type**\: int
                                    
                                    	**range:** 0..10
                                    
                                    .. attribute:: multicast
                                    
                                    	Use this NBMA mapping for broadcasts/multicasts
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: priority
                                    
                                    	NHS priority, don't specify for default priority
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nhrp'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4, self).__init__()

                                        self.yang_name = "ipv4"
                                        self.yang_parent_name = "nbma"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ipv4']
                                        self._child_classes = OrderedDict([("multicast", ("multicast", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast)), ("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Priority))])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                        ])
                                        self.ipv4 = None
                                        self.cluster = None

                                        self.multicast = None
                                        self._children_name_map["multicast"] = "multicast"

                                        self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4, ['ipv4', 'cluster'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Use this NBMA mapping for broadcasts/multicasts
                                        
                                        .. attribute:: cluster
                                        
                                        	NHS cluster number
                                        	**type**\: int
                                        
                                        	**range:** 0..10
                                        
                                        .. attribute:: priority
                                        
                                        	NHS priority, don't specify for default priority
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast.Priority>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast.Priority))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                            ])
                                            self.cluster = None

                                            self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "multicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast, ['cluster'], name, value)


                                        class Priority(Entity):
                                            """
                                            NHS priority, don't specify for default priority
                                            
                                            .. attribute:: dyn_pri
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`DynPri <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast.Priority.DynPri>`
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dyn-pri", ("dyn_pri", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast.Priority.DynPri))])
                                                self._leafs = OrderedDict()

                                                self.dyn_pri = YList(self)
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast.Priority, [], name, value)


                                            class DynPri(Entity):
                                                """
                                                
                                                
                                                .. attribute:: dyn_pri  (key)
                                                
                                                	NHS priority, range = 0 to 255, 0 is the highest
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cluster
                                                
                                                	NHS cluster number
                                                	**type**\: int
                                                
                                                	**range:** 0..10
                                                
                                                

                                                """

                                                _prefix = 'ios-nhrp'
                                                _revision = '2017-02-07'

                                                def __init__(self):
                                                    super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast.Priority.DynPri, self).__init__()

                                                    self.yang_name = "dyn-pri"
                                                    self.yang_parent_name = "priority"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['dyn_pri']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('dyn_pri', (YLeaf(YType.uint8, 'dyn-pri'), ['int'])),
                                                        ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                    ])
                                                    self.dyn_pri = None
                                                    self.cluster = None
                                                    self._segment_path = lambda: "dyn-pri" + "[dyn-pri='" + str(self.dyn_pri) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Multicast.Priority.DynPri, ['dyn_pri', 'cluster'], name, value)


                                    class Priority(Entity):
                                        """
                                        NHS priority, don't specify for default priority
                                        
                                        .. attribute:: n_prior
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`NPrior <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Priority.NPrior>`
                                        
                                        

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("n-prior", ("n_prior", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Priority.NPrior))])
                                            self._leafs = OrderedDict()

                                            self.n_prior = YList(self)
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Priority, [], name, value)


                                        class NPrior(Entity):
                                            """
                                            
                                            
                                            .. attribute:: n_prior  (key)
                                            
                                            	NHS priority, range = 0 to 255, 0 is the highest
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cluster
                                            
                                            	NHS cluster number
                                            	**type**\: int
                                            
                                            	**range:** 0..10
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Priority.NPrior, self).__init__()

                                                self.yang_name = "n-prior"
                                                self.yang_parent_name = "priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['n_prior']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('n_prior', (YLeaf(YType.uint8, 'n-prior'), ['int'])),
                                                    ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                ])
                                                self.n_prior = None
                                                self.cluster = None
                                                self._segment_path = lambda: "n-prior" + "[n-prior='" + str(self.n_prior) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv4.Priority.NPrior, ['n_prior', 'cluster'], name, value)


                                class DynFqdn(Entity):
                                    """
                                    
                                    
                                    .. attribute:: dyn_fqdn  (key)
                                    
                                    	NHS FQDN string
                                    	**type**\: str
                                    
                                    .. attribute:: cluster
                                    
                                    	NHS cluster number
                                    	**type**\: int
                                    
                                    	**range:** 0..10
                                    
                                    .. attribute:: multicast
                                    
                                    	Use this NBMA mapping for broadcasts/multicasts
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: priority
                                    
                                    	NHS priority, don't specify for default priority
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nhrp'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn, self).__init__()

                                        self.yang_name = "dyn-fqdn"
                                        self.yang_parent_name = "nbma"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['dyn_fqdn']
                                        self._child_classes = OrderedDict([("multicast", ("multicast", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast)), ("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Priority))])
                                        self._leafs = OrderedDict([
                                            ('dyn_fqdn', (YLeaf(YType.str, 'dyn-fqdn'), ['str'])),
                                            ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                        ])
                                        self.dyn_fqdn = None
                                        self.cluster = None

                                        self.multicast = None
                                        self._children_name_map["multicast"] = "multicast"

                                        self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "dyn-fqdn" + "[dyn-fqdn='" + str(self.dyn_fqdn) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn, ['dyn_fqdn', 'cluster'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Use this NBMA mapping for broadcasts/multicasts
                                        
                                        .. attribute:: cluster
                                        
                                        	NHS cluster number
                                        	**type**\: int
                                        
                                        	**range:** 0..10
                                        
                                        .. attribute:: priority
                                        
                                        	NHS priority, don't specify for default priority
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast.Priority>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "dyn-fqdn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast.Priority))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                            ])
                                            self.cluster = None

                                            self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "multicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast, ['cluster'], name, value)


                                        class Priority(Entity):
                                            """
                                            NHS priority, don't specify for default priority
                                            
                                            .. attribute:: dyn_mc_pri
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`DynMcPri <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast.Priority.DynMcPri>`
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dyn-mc-pri", ("dyn_mc_pri", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast.Priority.DynMcPri))])
                                                self._leafs = OrderedDict()

                                                self.dyn_mc_pri = YList(self)
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast.Priority, [], name, value)


                                            class DynMcPri(Entity):
                                                """
                                                
                                                
                                                .. attribute:: dyn_mc_pri  (key)
                                                
                                                	NHS priority, range = 0 to 255, 0 is the highest
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cluster
                                                
                                                	NHS cluster number
                                                	**type**\: int
                                                
                                                	**range:** 0..10
                                                
                                                

                                                """

                                                _prefix = 'ios-nhrp'
                                                _revision = '2017-02-07'

                                                def __init__(self):
                                                    super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast.Priority.DynMcPri, self).__init__()

                                                    self.yang_name = "dyn-mc-pri"
                                                    self.yang_parent_name = "priority"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['dyn_mc_pri']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('dyn_mc_pri', (YLeaf(YType.uint8, 'dyn-mc-pri'), ['int'])),
                                                        ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                    ])
                                                    self.dyn_mc_pri = None
                                                    self.cluster = None
                                                    self._segment_path = lambda: "dyn-mc-pri" + "[dyn-mc-pri='" + str(self.dyn_mc_pri) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Multicast.Priority.DynMcPri, ['dyn_mc_pri', 'cluster'], name, value)


                                    class Priority(Entity):
                                        """
                                        NHS priority, don't specify for default priority
                                        
                                        .. attribute:: dp
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Dp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Priority.Dp>`
                                        
                                        

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "dyn-fqdn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dp", ("dp", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Priority.Dp))])
                                            self._leafs = OrderedDict()

                                            self.dp = YList(self)
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Priority, [], name, value)


                                        class Dp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: dp  (key)
                                            
                                            	NHS priority, range = 0 to 255, 0 is the highest
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cluster
                                            
                                            	NHS cluster number
                                            	**type**\: int
                                            
                                            	**range:** 0..10
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Priority.Dp, self).__init__()

                                                self.yang_name = "dp"
                                                self.yang_parent_name = "priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['dp']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dp', (YLeaf(YType.uint8, 'dp'), ['int'])),
                                                    ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                ])
                                                self.dp = None
                                                self.cluster = None
                                                self._segment_path = lambda: "dp" + "[dp='" + str(self.dp) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.DynFqdn.Priority.Dp, ['dp', 'cluster'], name, value)


                                class Ipv6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipv6  (key)
                                    
                                    	IPv6 address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster
                                    
                                    	NHS cluster number
                                    	**type**\: int
                                    
                                    	**range:** 0..10
                                    
                                    .. attribute:: multicast
                                    
                                    	Use this NBMA mapping for broadcasts/multicasts
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: priority
                                    
                                    	NHS priority, don't specify for default priority
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-nhrp'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6, self).__init__()

                                        self.yang_name = "ipv6"
                                        self.yang_parent_name = "nbma"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ipv6']
                                        self._child_classes = OrderedDict([("multicast", ("multicast", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast)), ("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Priority))])
                                        self._leafs = OrderedDict([
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                        ])
                                        self.ipv6 = None
                                        self.cluster = None

                                        self.multicast = None
                                        self._children_name_map["multicast"] = "multicast"

                                        self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "ipv6" + "[ipv6='" + str(self.ipv6) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6, ['ipv6', 'cluster'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Use this NBMA mapping for broadcasts/multicasts
                                        
                                        .. attribute:: cluster
                                        
                                        	NHS cluster number
                                        	**type**\: int
                                        
                                        	**range:** 0..10
                                        
                                        .. attribute:: priority
                                        
                                        	NHS priority, don't specify for default priority
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast.Priority>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast.Priority))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                            ])
                                            self.cluster = None

                                            self.priority = Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "multicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast, ['cluster'], name, value)


                                        class Priority(Entity):
                                            """
                                            NHS priority, don't specify for default priority
                                            
                                            .. attribute:: v6_pri
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`V6Pri <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast.Priority.V6Pri>`
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("v6-pri", ("v6_pri", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast.Priority.V6Pri))])
                                                self._leafs = OrderedDict()

                                                self.v6_pri = YList(self)
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast.Priority, [], name, value)


                                            class V6Pri(Entity):
                                                """
                                                
                                                
                                                .. attribute:: v6_pri  (key)
                                                
                                                	NHS priority, range = 0 to 255, 0 is the highest
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cluster
                                                
                                                	NHS cluster number
                                                	**type**\: int
                                                
                                                	**range:** 0..10
                                                
                                                

                                                """

                                                _prefix = 'ios-nhrp'
                                                _revision = '2017-02-07'

                                                def __init__(self):
                                                    super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast.Priority.V6Pri, self).__init__()

                                                    self.yang_name = "v6-pri"
                                                    self.yang_parent_name = "priority"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['v6_pri']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('v6_pri', (YLeaf(YType.uint8, 'v6-pri'), ['int'])),
                                                        ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                    ])
                                                    self.v6_pri = None
                                                    self.cluster = None
                                                    self._segment_path = lambda: "v6-pri" + "[v6-pri='" + str(self.v6_pri) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Multicast.Priority.V6Pri, ['v6_pri', 'cluster'], name, value)


                                    class Priority(Entity):
                                        """
                                        NHS priority, don't specify for default priority
                                        
                                        .. attribute:: v6_pri2
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`V6Pri2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Priority.V6Pri2>`
                                        
                                        

                                        """

                                        _prefix = 'ios-nhrp'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("v6-pri2", ("v6_pri2", Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Priority.V6Pri2))])
                                            self._leafs = OrderedDict()

                                            self.v6_pri2 = YList(self)
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Priority, [], name, value)


                                        class V6Pri2(Entity):
                                            """
                                            
                                            
                                            .. attribute:: v6_pri2  (key)
                                            
                                            	NHS priority, range = 0 to 255, 0 is the highest
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cluster
                                            
                                            	NHS cluster number
                                            	**type**\: int
                                            
                                            	**range:** 0..10
                                            
                                            

                                            """

                                            _prefix = 'ios-nhrp'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Priority.V6Pri2, self).__init__()

                                                self.yang_name = "v6-pri2"
                                                self.yang_parent_name = "priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['v6_pri2']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('v6_pri2', (YLeaf(YType.uint8, 'v6-pri2'), ['int'])),
                                                    ('cluster', (YLeaf(YType.uint8, 'cluster'), ['int'])),
                                                ])
                                                self.v6_pri2 = None
                                                self.cluster = None
                                                self._segment_path = lambda: "v6-pri2" + "[v6-pri2='" + str(self.v6_pri2) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Nhs.Dynamic.Nbma.Ipv6.Priority.V6Pri2, ['v6_pri2', 'cluster'], name, value)


                    class Redirect(Entity):
                        """
                        Enable NHRP redirect traffic indication
                        
                        .. attribute:: timeout
                        
                        	Interval in seconds
                        	**type**\: int
                        
                        	**range:** 2..30
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.timeout = None
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Redirect, ['timeout'], name, value)


                    class Registration(Entity):
                        """
                        Settings for registration packets.
                        
                        .. attribute:: no_unique
                        
                        	Do not set the 'Unique' flag in registration requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Number of seconds
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.Registration, self).__init__()

                            self.yang_name = "registration"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('no_unique', (YLeaf(YType.empty, 'no-unique'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                            ])
                            self.no_unique = None
                            self.timeout = None
                            self._segment_path = lambda: "registration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Registration, ['no_unique', 'timeout'], name, value)


                    class Reject(Entity):
                        """
                        NHRP resolution reject request
                        
                        .. attribute:: reqid
                        
                        	
                        	**type**\: list of  		 :py:class:`Reqid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.Reject.Reqid>`
                        
                        

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.Reject, self).__init__()

                            self.yang_name = "reject"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reqid", ("reqid", Native.Interface.Tunnel.Ip.Nhrp.Reject.Reqid))])
                            self._leafs = OrderedDict()

                            self.reqid = YList(self)
                            self._segment_path = lambda: "reject"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Reject, [], name, value)


                        class Reqid(Entity):
                            """
                            
                            
                            .. attribute:: reqid  (key)
                            
                            	reqid value
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: rej_secs
                            
                            	Number of seconds
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-nhrp'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Nhrp.Reject.Reqid, self).__init__()

                                self.yang_name = "reqid"
                                self.yang_parent_name = "reject"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['reqid']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reqid', (YLeaf(YType.uint16, 'reqid'), ['int'])),
                                    ('rej_secs', (YLeaf(YType.uint16, 'rej-secs'), ['int'])),
                                ])
                                self.reqid = None
                                self.rej_secs = None
                                self._segment_path = lambda: "reqid" + "[reqid='" + str(self.reqid) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Reject.Reqid, ['reqid', 'rej_secs'], name, value)


                    class Responder(Entity):
                        """
                        Responder interface
                        
                        .. attribute:: res_int
                        
                        	Virtual ACR interface
                        	**type**\: str
                        
                        .. attribute:: analysis_module
                        
                        	Analysis\-Module interface number
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: fcpa
                        
                        	Fcpa interface number
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: sbc
                        
                        	SBC interface number
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        .. attribute:: sonet_acr
                        
                        	SONET\_ACR interface number
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tb_controller
                        
                        	Telecom\-Bus Clock Controller
                        	**type**\: str
                        
                        .. attribute:: service_engine
                        
                        	Service\-Engine interface number
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface number
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        .. attribute:: tunnel_tp
                        
                        	Tunnel\-tp interface number
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vpn
                        
                        	VPN interface number
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        .. attribute:: virtual_tokenring
                        
                        	Virtual\-TokenRing interface number
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        .. attribute:: virtualportgroup
                        
                        	VirtualPortGroup interface number
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: vlan
                        
                        	Vlan interface number
                        	**type**\: int
                        
                        	**range:** 1..4095
                        
                        .. attribute:: ucse
                        
                        	ucse interface number
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: vasileft
                        
                        	vasileft interface number
                        	**type**\: int
                        
                        	**range:** 1..2000
                        
                        .. attribute:: vasiright
                        
                        	vasiright interface number
                        	**type**\: int
                        
                        	**range:** 1..2000
                        
                        

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.Responder, self).__init__()

                            self.yang_name = "responder"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('res_int', (YLeaf(YType.str, 'res-int'), ['str'])),
                                ('analysis_module', (YLeaf(YType.uint8, 'Analysis-Module'), ['int'])),
                                ('fcpa', (YLeaf(YType.uint8, 'Fcpa'), ['int'])),
                                ('sbc', (YLeaf(YType.uint32, 'SBC'), ['int'])),
                                ('sonet_acr', (YLeaf(YType.uint8, 'SONET_ACR'), ['int'])),
                                ('tb_controller', (YLeaf(YType.str, 'TB-controller'), ['str'])),
                                ('service_engine', (YLeaf(YType.uint8, 'Service-Engine'), ['int'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('tunnel_tp', (YLeaf(YType.uint16, 'Tunnel-tp'), ['int'])),
                                ('vpn', (YLeaf(YType.uint32, 'VPN'), ['int'])),
                                ('virtual_tokenring', (YLeaf(YType.uint32, 'Virtual-TokenRing'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint8, 'VirtualPortGroup'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('ucse', (YLeaf(YType.uint8, 'ucse'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.res_int = None
                            self.analysis_module = None
                            self.fcpa = None
                            self.sbc = None
                            self.sonet_acr = None
                            self.tb_controller = None
                            self.service_engine = None
                            self.tunnel = None
                            self.tunnel_tp = None
                            self.vpn = None
                            self.virtual_tokenring = None
                            self.virtualportgroup = None
                            self.vlan = None
                            self.ucse = None
                            self.vasileft = None
                            self.vasiright = None
                            self._segment_path = lambda: "responder"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Responder, ['res_int', 'analysis_module', 'fcpa', 'sbc', 'sonet_acr', 'tb_controller', 'service_engine', 'tunnel', 'tunnel_tp', 'vpn', 'virtual_tokenring', 'virtualportgroup', 'vlan', 'ucse', 'vasileft', 'vasiright'], name, value)


                    class ServerOnly(Entity):
                        """
                        Disable NHRP requests
                        
                        .. attribute:: non_caching
                        
                        	Do not create NHRP cache entries
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.ServerOnly, self).__init__()

                            self.yang_name = "server-only"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_caching', (YLeaf(YType.empty, 'non-caching'), ['Empty'])),
                            ])
                            self.non_caching = None
                            self._segment_path = lambda: "server-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.ServerOnly, ['non_caching'], name, value)


                    class Shortcut(Entity):
                        """
                        Enable shortcut switching
                        
                        .. attribute:: virtual_template
                        
                        	Virtual template number
                        	**type**\: int
                        
                        	**range:** 1..4095
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.Shortcut, self).__init__()

                            self.yang_name = "shortcut"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('virtual_template', (YLeaf(YType.uint16, 'virtual-template'), ['int'])),
                            ])
                            self.virtual_template = None
                            self._segment_path = lambda: "shortcut"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.Shortcut, ['virtual_template'], name, value)


                    class TriggerSvc(Entity):
                        """
                        Create NHRP cut\-through based on traffic load
                        
                        .. attribute:: kbps
                        
                        	
                        	**type**\: list of  		 :py:class:`Kbps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Nhrp.TriggerSvc.Kbps>`
                        
                        

                        """

                        _prefix = 'ios-nhrp'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Nhrp.TriggerSvc, self).__init__()

                            self.yang_name = "trigger-svc"
                            self.yang_parent_name = "nhrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("kbps", ("kbps", Native.Interface.Tunnel.Ip.Nhrp.TriggerSvc.Kbps))])
                            self._leafs = OrderedDict()

                            self.kbps = YList(self)
                            self._segment_path = lambda: "trigger-svc"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.TriggerSvc, [], name, value)


                        class Kbps(Entity):
                            """
                            
                            
                            .. attribute:: kbps  (key)
                            
                            	Trigger rate in kbps
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: tear_kbps
                            
                            	Teardown rate in kbps
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-nhrp'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Nhrp.TriggerSvc.Kbps, self).__init__()

                                self.yang_name = "kbps"
                                self.yang_parent_name = "trigger-svc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['kbps']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('kbps', (YLeaf(YType.uint32, 'kbps'), ['int'])),
                                    ('tear_kbps', (YLeaf(YType.uint32, 'tear-kbps'), ['int'])),
                                ])
                                self.kbps = None
                                self.tear_kbps = None
                                self._segment_path = lambda: "kbps" + "[kbps='" + str(self.kbps) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Nhrp.TriggerSvc.Kbps, ['kbps', 'tear_kbps'], name, value)


                class Rsvp(Entity):
                    """
                    RSVP Interface Commands
                    
                    .. attribute:: authentication
                    
                    	Enables RSVP neighbor authentication (RFC 2747)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Authentication>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bandwidth
                    
                    	RSVP Reservable Bandwidth (kbps)
                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Bandwidth>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	Select permissible RSVP neighbors
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Neighbor>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: precedence
                    
                    	RSVP precedence setting
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Precedence>`
                    
                    .. attribute:: signalling
                    
                    	RSVP signalling
                    	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Signalling>`
                    
                    .. attribute:: tos
                    
                    	RSVP TOS setting
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Tos>`
                    
                    

                    """

                    _prefix = 'ios-rsvp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Tunnel.Ip.Rsvp.Authentication)), ("bandwidth", ("bandwidth", Native.Interface.Tunnel.Ip.Rsvp.Bandwidth)), ("neighbor", ("neighbor", Native.Interface.Tunnel.Ip.Rsvp.Neighbor)), ("precedence", ("precedence", Native.Interface.Tunnel.Ip.Rsvp.Precedence)), ("signalling", ("signalling", Native.Interface.Tunnel.Ip.Rsvp.Signalling)), ("tos", ("tos", Native.Interface.Tunnel.Ip.Rsvp.Tos))])
                        self._leafs = OrderedDict()

                        self.authentication = None
                        self._children_name_map["authentication"] = "authentication"

                        self.bandwidth = None
                        self._children_name_map["bandwidth"] = "bandwidth"

                        self.neighbor = None
                        self._children_name_map["neighbor"] = "neighbor"

                        self.precedence = Native.Interface.Tunnel.Ip.Rsvp.Precedence()
                        self.precedence.parent = self
                        self._children_name_map["precedence"] = "precedence"

                        self.signalling = Native.Interface.Tunnel.Ip.Rsvp.Signalling()
                        self.signalling.parent = self
                        self._children_name_map["signalling"] = "signalling"

                        self.tos = Native.Interface.Tunnel.Ip.Rsvp.Tos()
                        self.tos.parent = self
                        self._children_name_map["tos"] = "tos"
                        self._segment_path = lambda: "Cisco-IOS-XE-rsvp:rsvp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp, [], name, value)


                    class Authentication(Entity):
                        """
                        Enables RSVP neighbor authentication (RFC 2747)
                        
                        .. attribute:: key
                        
                        	Password (8 to 40 characters, spaces allowed)
                        	**type**\: str
                        
                        .. attribute:: challenge
                        
                        	Perform challenge/response handshake with new neighbor(s)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key_chain
                        
                        	Name of key chain to use (as created by global 'key chain' command)
                        	**type**\: str
                        
                        .. attribute:: lifetime
                        
                        	Maximum lifetime of neighbor authentication state
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Authentication.Lifetime>`
                        
                        .. attribute:: type
                        
                        	Type of authentication algorithm (default = md5)
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Authentication.Type>`
                        
                        .. attribute:: window_size
                        
                        	Maximum number of messages allowed in receive window (default = 1)
                        	**type**\: int
                        
                        	**range:** 1..64
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Rsvp.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime", ("lifetime", Native.Interface.Tunnel.Ip.Rsvp.Authentication.Lifetime))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('challenge', (YLeaf(YType.empty, 'challenge'), ['Empty'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ip.Rsvp.Authentication.Type')])),
                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                            ])
                            self.key = None
                            self.challenge = None
                            self.key_chain = None
                            self.type = None
                            self.window_size = None

                            self.lifetime = Native.Interface.Tunnel.Ip.Rsvp.Authentication.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Authentication, ['key', 'challenge', 'key_chain', 'type', 'window_size'], name, value)

                        class Type(Enum):
                            """
                            Type (Enum Class)

                            Type of authentication algorithm (default = md5)

                            .. data:: md5 = 0

                            .. data:: sha_1 = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            sha_1 = Enum.YLeaf(1, "sha-1")



                        class Lifetime(Entity):
                            """
                            Maximum lifetime of neighbor authentication state
                            
                            .. attribute:: hh_mm_ss
                            
                            	Lifetime (default = 30 mins) in hh\:mm\:ss format
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Rsvp.Authentication.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ])
                                self.hh_mm_ss = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Authentication.Lifetime, ['hh_mm_ss'], name, value)


                    class Bandwidth(Entity):
                        """
                        RSVP Reservable Bandwidth (kbps)
                        
                        .. attribute:: value
                        
                        	
                        	**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Value>`
                        
                        .. attribute:: percent
                        
                        	Percentage of interface bandwidth. Values higher than 100 represent overbooking
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: mam
                        
                        	Use bandwidth with MAM model of DSTE
                        	**type**\:  :py:class:`Mam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Mam>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Rsvp.Bandwidth, self).__init__()

                            self.yang_name = "bandwidth"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("value", ("value", Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Value)), ("mam", ("mam", Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Mam))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('percent', (YLeaf(YType.uint16, 'percent'), ['int'])),
                            ])
                            self.percent = None

                            self.value = Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Value()
                            self.value.parent = self
                            self._children_name_map["value"] = "value"

                            self.mam = Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Mam()
                            self.mam.parent = self
                            self._children_name_map["mam"] = "mam"
                            self._segment_path = lambda: "bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Bandwidth, ['percent'], name, value)


                        class Value(Entity):
                            """
                            
                            
                            .. attribute:: value
                            
                            	Reservable Bandwidth (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            .. attribute:: sub_pool
                            
                            	Reservable Bandwidth for Tunnel using sub (BC1) pool (kbps)
                            	**type**\: int
                            
                            	**range:** 1..10000000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Value, self).__init__()

                                self.yang_name = "value"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.value = None
                                self.sub_pool = None
                                self._segment_path = lambda: "value"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Value, ['value', 'sub_pool'], name, value)


                        class Mam(Entity):
                            """
                            Use bandwidth with MAM model of DSTE
                            
                            .. attribute:: max_reservable_bw
                            
                            	Maximum Reservable bandwidth for MAM
                            	**type**\:  :py:class:`MaxReservableBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Mam, self).__init__()

                                self.yang_name = "mam"
                                self.yang_parent_name = "bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("max-reservable-bw", ("max_reservable_bw", Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw))])
                                self._leafs = OrderedDict()

                                self.max_reservable_bw = None
                                self._children_name_map["max_reservable_bw"] = "max-reservable-bw"
                                self._segment_path = lambda: "mam"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Mam, [], name, value)


                            class MaxReservableBw(Entity):
                                """
                                Maximum Reservable bandwidth for MAM
                                
                                .. attribute:: value
                                
                                	Reservable Bandwidth (kbps)
                                	**type**\: int
                                
                                	**range:** 1..10000000
                                
                                .. attribute:: bc0
                                
                                	Reservable Bandwidth from global (BC0) pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                .. attribute:: bc1
                                
                                	Reservable Bandwidth from sub pool (kbps)
                                	**type**\: int
                                
                                	**range:** 0..10000000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, self).__init__()

                                    self.yang_name = "max-reservable-bw"
                                    self.yang_parent_name = "mam"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                        ('bc0', (YLeaf(YType.uint32, 'bc0'), ['int'])),
                                        ('bc1', (YLeaf(YType.uint32, 'bc1'), ['int'])),
                                    ])
                                    self.value = None
                                    self.bc0 = None
                                    self.bc1 = None
                                    self._segment_path = lambda: "max-reservable-bw"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Bandwidth.Mam.MaxReservableBw, ['value', 'bc0', 'bc1'], name, value)


                    class Neighbor(Entity):
                        """
                        Select permissible RSVP neighbors
                        
                        .. attribute:: acl_number
                        
                        	Access list
                        	**type**\: int
                        
                        	**range:** 1..199
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Rsvp.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('acl_number', (YLeaf(YType.uint8, 'acl-number'), ['int'])),
                            ])
                            self.acl_number = None
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Neighbor, ['acl_number'], name, value)


                    class Precedence(Entity):
                        """
                        RSVP precedence setting
                        
                        .. attribute:: conform
                        
                        	Precedence for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: exceed
                        
                        	Precedence for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Rsvp.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Precedence, ['conform', 'exceed'], name, value)


                    class Signalling(Entity):
                        """
                        RSVP signalling
                        
                        .. attribute:: dscp
                        
                        	DSCP for RSVP signalling messages
                        	**type**\: int
                        
                        	**range:** 0..63
                        
                        .. attribute:: fast_local_repair
                        
                        	Fast Local Repair parameters
                        	**type**\:  :py:class:`FastLocalRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Signalling.FastLocalRepair>`
                        
                        .. attribute:: hello
                        
                        	Enable neighbor\-down detection
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Rsvp.Signalling, self).__init__()

                            self.yang_name = "signalling"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-local-repair", ("fast_local_repair", Native.Interface.Tunnel.Ip.Rsvp.Signalling.FastLocalRepair)), ("hello", ("hello", Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello))])
                            self._leafs = OrderedDict([
                                ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                            ])
                            self.dscp = None

                            self.fast_local_repair = Native.Interface.Tunnel.Ip.Rsvp.Signalling.FastLocalRepair()
                            self.fast_local_repair.parent = self
                            self._children_name_map["fast_local_repair"] = "fast-local-repair"

                            self.hello = None
                            self._children_name_map["hello"] = "hello"
                            self._segment_path = lambda: "signalling"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Signalling, ['dscp'], name, value)


                        class FastLocalRepair(Entity):
                            """
                            Fast Local Repair parameters
                            
                            .. attribute:: wait_time
                            
                            	Wait Time for start of Fast Local Repair in msec
                            	**type**\: int
                            
                            	**range:** 0..5000
                            
                            

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Rsvp.Signalling.FastLocalRepair, self).__init__()

                                self.yang_name = "fast-local-repair"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint16, 'wait-time'), ['int'])),
                                ])
                                self.wait_time = None
                                self._segment_path = lambda: "fast-local-repair"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Signalling.FastLocalRepair, ['wait_time'], name, value)


                        class Hello(Entity):
                            """
                            Enable neighbor\-down detection
                            
                            .. attribute:: bfd
                            
                            	Configure BFD trigger for MPLS/TE FRR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dscp
                            
                            	DSCP for RSVP Hello messages
                            	**type**\: int
                            
                            	**range:** 0..63
                            
                            .. attribute:: graceful_restart
                            
                            	Configure RSVP Graceful Restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: refresh
                            
                            	Configure RSVP Hello refresh behavior for Fast\-Reroute
                            	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Refresh>`
                            
                            .. attribute:: reroute
                            
                            	Configure RSVP Hello refresh behavior for Reroute
                            	**type**\:  :py:class:`Reroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Reroute>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rsvp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "signalling"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Refresh)), ("reroute", ("reroute", Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Reroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ('graceful_restart', (YLeaf(YType.empty, 'graceful-restart'), ['Empty'])),
                                ])
                                self.bfd = None
                                self.dscp = None
                                self.graceful_restart = None

                                self.refresh = Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Refresh()
                                self.refresh.parent = self
                                self._children_name_map["refresh"] = "refresh"

                                self.reroute = Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Reroute()
                                self.reroute.parent = self
                                self._children_name_map["reroute"] = "reroute"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello, ['bfd', 'dscp', 'graceful_restart'], name, value)


                            class Refresh(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Fast\-Reroute
                                
                                .. attribute:: interval
                                
                                	Hello interval in msec
                                	**type**\: int
                                
                                	**range:** 10..30000
                                
                                .. attribute:: misses
                                
                                	Number of missed Hello Acks which triggers neighbor down
                                	**type**\: int
                                
                                	**range:** 4..10
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Refresh, self).__init__()

                                    self.yang_name = "refresh"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.misses = None
                                    self._segment_path = lambda: "refresh"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Refresh, ['interval', 'misses'], name, value)


                            class Reroute(Entity):
                                """
                                Configure RSVP Hello refresh behavior for Reroute
                                
                                .. attribute:: dscp
                                
                                	DSCP for RSVP Hello messages
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: refresh
                                
                                	Configure RSVP Reroute Hello refresh behavior
                                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Reroute.Refresh>`
                                
                                

                                """

                                _prefix = 'ios-rsvp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Reroute, self).__init__()

                                    self.yang_name = "reroute"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("refresh", ("refresh", Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Reroute.Refresh))])
                                    self._leafs = OrderedDict([
                                        ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                                    ])
                                    self.dscp = None

                                    self.refresh = Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Reroute.Refresh()
                                    self.refresh.parent = self
                                    self._children_name_map["refresh"] = "refresh"
                                    self._segment_path = lambda: "reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Reroute, ['dscp'], name, value)


                                class Refresh(Entity):
                                    """
                                    Configure RSVP Reroute Hello refresh behavior
                                    
                                    .. attribute:: interval
                                    
                                    	Hello Reroute interval in msec
                                    	**type**\: int
                                    
                                    	**range:** 1000..30000
                                    
                                    .. attribute:: misses
                                    
                                    	Number of missed Hello Acks which triggers neighbor down
                                    	**type**\: int
                                    
                                    	**range:** 4..10
                                    
                                    

                                    """

                                    _prefix = 'ios-rsvp'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, self).__init__()

                                        self.yang_name = "refresh"
                                        self.yang_parent_name = "reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ('misses', (YLeaf(YType.uint8, 'misses'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.misses = None
                                        self._segment_path = lambda: "refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Signalling.Hello.Reroute.Refresh, ['interval', 'misses'], name, value)


                    class Tos(Entity):
                        """
                        RSVP TOS setting
                        
                        .. attribute:: conform
                        
                        	TOS for packets conforming to RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        .. attribute:: exceed
                        
                        	TOS for packets over RSVP flowspec bandwidth
                        	**type**\: int
                        
                        	**range:** 0..31
                        
                        

                        """

                        _prefix = 'ios-rsvp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Rsvp.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "rsvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('conform', (YLeaf(YType.uint8, 'conform'), ['int'])),
                                ('exceed', (YLeaf(YType.uint8, 'exceed'), ['int'])),
                            ])
                            self.conform = None
                            self.exceed = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Rsvp.Tos, ['conform', 'exceed'], name, value)


                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.Tunnel.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.Tunnel.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.Tunnel.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.Tunnel.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.Tunnel.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.Tunnel.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Tunnel.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.Tunnel.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Tunnel.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.Tunnel.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.Tunnel.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.Tunnel.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.Tunnel.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.Tunnel.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.Tunnel.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Tunnel.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.Tunnel.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Tunnel.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.Tunnel.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.TrafficFilter>`
                
                .. attribute:: flow
                
                	NetFlow related commands
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Flow>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Crypto>`
                
                .. attribute:: ospf
                
                	OSPF interface commands
                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf>`
                
                .. attribute:: no_pim
                
                	
                	**type**\:  :py:class:`NoPim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.NoPim>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Pim>`
                
                .. attribute:: unreachables
                
                	Enable sending ICMP Unreachable messages
                	**type**\: bool
                
                .. attribute:: rip
                
                	Configure RIP routing protocol
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Rip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Tunnel.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Tunnel.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Tunnel.Ipv6.Dhcp)), ("address", ("address", Native.Interface.Tunnel.Ipv6.Address)), ("nd", ("nd", Native.Interface.Tunnel.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.Tunnel.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Tunnel.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-flow:flow", ("flow", Native.Interface.Tunnel.Ipv6.Flow)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.Tunnel.Ipv6.Crypto)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Interface.Tunnel.Ipv6.Ospf)), ("Cisco-IOS-XE-multicast:no-pim", ("no_pim", Native.Interface.Tunnel.Ipv6.NoPim)), ("Cisco-IOS-XE-multicast:pim", ("pim", Native.Interface.Tunnel.Ipv6.Pim)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Interface.Tunnel.Ipv6.Rip))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('unreachables', (YLeaf(YType.boolean, 'Cisco-IOS-XE-icmp:unreachables'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None
                    self.unreachables = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Tunnel.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Tunnel.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Tunnel.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Tunnel.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.flow = Native.Interface.Tunnel.Ipv6.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "Cisco-IOS-XE-flow:flow"

                    self.crypto = Native.Interface.Tunnel.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.ospf = Native.Interface.Tunnel.Ipv6.Ospf()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "Cisco-IOS-XE-ospf:ospf"

                    self.no_pim = Native.Interface.Tunnel.Ipv6.NoPim()
                    self.no_pim.parent = self
                    self._children_name_map["no_pim"] = "Cisco-IOS-XE-multicast:no-pim"

                    self.pim = Native.Interface.Tunnel.Ipv6.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "Cisco-IOS-XE-multicast:pim"

                    self.traffic_filter = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects', 'unreachables'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.Tunnel.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.Tunnel.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.Tunnel.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.Tunnel.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.Tunnel.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.Tunnel.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Tunnel.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Tunnel.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Tunnel.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Tunnel.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.Tunnel.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.Tunnel.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.Tunnel.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.Tunnel.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.Tunnel.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.Tunnel.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.Tunnel.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Flow(Entity):
                    """
                    NetFlow related commands
                    
                    .. attribute:: ingress
                    
                    	Enable inbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: egress
                    
                    	Enable outbound NetFlow
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: monitor
                    
                    	Apply a Flow Monitor
                    	**type**\: list of  		 :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Flow.Monitor>`
                    
                    

                    """

                    _prefix = 'ios-flow'
                    _revision = '2018-01-04'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.Tunnel.Ipv6.Flow.Monitor))])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.egress = None

                        self.monitor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-flow:flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Flow, ['ingress', 'egress'], name, value)


                    class Monitor(Entity):
                        """
                        Apply a Flow Monitor
                        
                        .. attribute:: name  (key)
                        
                        	User defined
                        	**type**\: str
                        
                        .. attribute:: sampler
                        
                        	Optional Sampler to apply to this Flow Monitor
                        	**type**\: list of  		 :py:class:`Sampler <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Flow.Monitor.Sampler>`
                        
                        .. attribute:: input
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: output
                        
                        	Apply Flow Monitor on input traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-flow'
                        _revision = '2018-01-04'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Flow.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "flow"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sampler", ("sampler", Native.Interface.Tunnel.Ipv6.Flow.Monitor.Sampler))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('input', (YLeaf(YType.empty, 'input'), ['Empty'])),
                                ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.name = None
                            self.input = None
                            self.output = None
                            self.multicast = None
                            self.unicast = None

                            self.sampler = YList(self)
                            self._segment_path = lambda: "monitor" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Flow.Monitor, ['name', 'input', 'output', 'multicast', 'unicast'], name, value)


                        class Sampler(Entity):
                            """
                            Optional Sampler to apply to this Flow Monitor
                            
                            .. attribute:: direction  (key)
                            
                            	Apply Flow Monitor on input/output traffic
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Flow.Monitor.Sampler.Direction>`
                            
                            .. attribute:: name
                            
                            	User defined
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-flow'
                            _revision = '2018-01-04'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ipv6.Flow.Monitor.Sampler, self).__init__()

                                self.yang_name = "sampler"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['direction']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ipv6.Flow.Monitor.Sampler.Direction')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.direction = None
                                self.name = None
                                self._segment_path = lambda: "sampler" + "[direction='" + str(self.direction) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ipv6.Flow.Monitor.Sampler, ['direction', 'name'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                Apply Flow Monitor on input/output traffic

                                .. data:: input = 0

                                .. data:: output = 1

                                """

                                input = Enum.YLeaf(0, "input")

                                output = Enum.YLeaf(1, "output")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Crypto, ['map'], name, value)


                class Ospf(Entity):
                    """
                    OSPF interface commands
                    
                    .. attribute:: process
                    
                    	
                    	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Process>`
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: encryption
                    
                    	Enable encryption
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption>`
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Network>`
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("process", ("process", Native.Interface.Tunnel.Ipv6.Ospf.Process)), ("authentication", ("authentication", Native.Interface.Tunnel.Ipv6.Ospf.Authentication)), ("bfd", ("bfd", Native.Interface.Tunnel.Ipv6.Ospf.Bfd)), ("database-filter", ("database_filter", Native.Interface.Tunnel.Ipv6.Ospf.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.Tunnel.Ipv6.Ospf.DemandCircuit)), ("encryption", ("encryption", Native.Interface.Tunnel.Ipv6.Ospf.Encryption)), ("flood-reduction", ("flood_reduction", Native.Interface.Tunnel.Ipv6.Ospf.FloodReduction)), ("mtu-ignore", ("mtu_ignore", Native.Interface.Tunnel.Ipv6.Ospf.MtuIgnore)), ("neighbor", ("neighbor", Native.Interface.Tunnel.Ipv6.Ospf.Neighbor)), ("network", ("network", Native.Interface.Tunnel.Ipv6.Ospf.Network)), ("shutdown", ("shutdown", Native.Interface.Tunnel.Ipv6.Ospf.Shutdown))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.cost = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.Tunnel.Ipv6.Ospf.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.database_filter = Native.Interface.Tunnel.Ipv6.Ospf.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.encryption = Native.Interface.Tunnel.Ipv6.Ospf.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.network = Native.Interface.Tunnel.Ipv6.Ospf.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.process = YList(self)
                        self.neighbor = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf, ['cost', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Process(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: instance
                        
                        	Set the OSPF instance
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..31
                        
                        		**type**\: int
                        
                        			**range:** 32..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Ospf.Process, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['int','int'])),
                            ])
                            self.id = None
                            self.area = None
                            self.instance = None
                            self._segment_path = lambda: "process" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Process, ['id', 'area', 'instance'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec authentication
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Ospf.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Authentication, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec authentication
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 256..4294967295
                            
                            .. attribute:: md5
                            
                            	Use MD5 authentication
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5>`
                            
                            .. attribute:: sha1
                            
                            	Use SHA\-1 authentication
                            	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ])
                                self.spi = None

                                self.md5 = Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.sha1 = Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1()
                                self.sha1.parent = self
                                self._children_name_map["sha1"] = "sha1"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec, ['spi'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Sha1(Entity):
                                """
                                Use SHA\-1 authentication
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1, self).__init__()

                                    self.yang_name = "sha1"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "sha1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "sha1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Ospf.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Bfd, ['disable'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Ospf.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ipv6.Ospf.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.DatabaseFilter, ['all', 'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Ospf.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.DemandCircuit, ['disable', 'ignore'], name, value)


                    class Encryption(Entity):
                        """
                        Enable encryption
                        
                        .. attribute:: null
                        
                        	No IPsec encryption on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec
                        
                        	Use IPsec encryption
                        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Ospf.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.ipsec = Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec()
                            self.ipsec.parent = self
                            self._children_name_map["ipsec"] = "ipsec"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Encryption, ['null'], name, value)


                        class Ipsec(Entity):
                            """
                            Use IPsec encryption
                            
                            .. attribute:: spi
                            
                            	Set the SPI (Security Parameters Index)
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: esp
                            
                            	Use ESP encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipsec_3des
                            
                            	Use 3DES encryption
                            	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des>`
                            
                            .. attribute:: aes_cbc
                            
                            	Use AES\-CBC encryption
                            	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec, self).__init__()

                                self.yang_name = "ipsec"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc))])
                                self._leafs = OrderedDict([
                                    ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                                ])
                                self.spi = None
                                self.esp = None

                                self.ipsec_3des = Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des()
                                self.ipsec_3des.parent = self
                                self._children_name_map["ipsec_3des"] = "ipsec_3des"

                                self.aes_cbc = Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc()
                                self.aes_cbc.parent = self
                                self._children_name_map["aes_cbc"] = "aes-cbc"
                                self._segment_path = lambda: "ipsec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec, ['spi', 'esp'], name, value)


                            class Ipsec3des(Entity):
                                """
                                Use 3DES encryption
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, self).__init__()

                                    self.yang_name = "ipsec_3des"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "ipsec_3des"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "ipsec_3des"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class AesCbc(Entity):
                                """
                                Use AES\-CBC encryption
                                
                                .. attribute:: aes_cbc_128
                                
                                	Use 128 bit key
                                	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128>`
                                
                                .. attribute:: aes_192
                                
                                	Use 192 bit key
                                	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192>`
                                
                                .. attribute:: aes_256
                                
                                	Use 256 bit key
                                	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc, self).__init__()

                                    self.yang_name = "aes-cbc"
                                    self.yang_parent_name = "ipsec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256))])
                                    self._leafs = OrderedDict()

                                    self.aes_cbc_128 = Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128()
                                    self.aes_cbc_128.parent = self
                                    self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                    self.aes_192 = Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192()
                                    self.aes_192.parent = self
                                    self._children_name_map["aes_192"] = "aes-192"

                                    self.aes_256 = Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256()
                                    self.aes_256.parent = self
                                    self._children_name_map["aes_256"] = "aes-256"
                                    self._segment_path = lambda: "aes-cbc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc, [], name, value)


                                class AesCbc128(Entity):
                                    """
                                    Use 128 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                        self.yang_name = "aes-cbc-128"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-cbc-128"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-cbc-128"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes192(Entity):
                                    """
                                    Use 192 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                        self.yang_name = "aes-192"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-192"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-192"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                                class Aes256(Entity):
                                    """
                                    Use 256 bit key
                                    
                                    .. attribute:: key_string
                                    
                                    	
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                        self.yang_name = "aes-256"
                                        self.yang_parent_name = "aes-cbc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                        self._leafs = OrderedDict()

                                        self.key_string = Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "aes-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                    class KeyString(Entity):
                                        """
                                        
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "aes-256"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	Disable Flood Reduction on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Ospf.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.FloodReduction, ['disable'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Ospf.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.MtuIgnore, ['disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Ospf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.Tunnel.Ipv6.Ospf.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.Tunnel.Ipv6.Ospf.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ipv6.Ospf.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ipv6.Ospf.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Ospf.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Ospf.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.Tunnel.Ipv6.Ospf.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ipv6.Ospf.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Ospf.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Ospf.Shutdown, ['disable'], name, value)


                class NoPim(Entity):
                    """
                    
                    
                    .. attribute:: pim
                    
                    	PIM interface commands
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.NoPim, self).__init__()

                        self.yang_name = "no-pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pim', (YLeaf(YType.boolean, 'pim'), ['bool'])),
                        ])
                        self.pim = None
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:no-pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.NoPim, ['pim'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    .. attribute:: bfd
                    
                    	Configure BFD
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bsr
                    
                    	Configure BSR
                    	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Pim.Bsr>`
                    
                    .. attribute:: dr_priority
                    
                    	PIM Hello DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-mc'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr", ("bsr", Native.Interface.Tunnel.Ipv6.Pim.Bsr))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.dr_priority = None

                        self.bsr = Native.Interface.Tunnel.Ipv6.Pim.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                        self._segment_path = lambda: "Cisco-IOS-XE-multicast:pim"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Pim, ['bfd', 'dr_priority'], name, value)


                    class Bsr(Entity):
                        """
                        Configure BSR
                        
                        .. attribute:: border
                        
                        	Border of PIM BSR domain
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mc'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Pim.Bsr, self).__init__()

                            self.yang_name = "bsr"
                            self.yang_parent_name = "pim"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                            ])
                            self.border = None
                            self._segment_path = lambda: "bsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Pim.Bsr, ['border'], name, value)


                class Rip(Entity):
                    """
                    Configure RIP routing protocol
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: enable
                    
                    	Enable/disable RIP routing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default_information
                    
                    	Configure handling of default route
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Rip.DefaultInformation>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ipv6.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("default-information", ("default_information", Native.Interface.Tunnel.Ipv6.Rip.DefaultInformation))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.id = None
                        self.enable = None

                        self.default_information = Native.Interface.Tunnel.Ipv6.Rip.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._segment_path = lambda: "Cisco-IOS-XE-rip:rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ipv6.Rip, ['id', 'enable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Configure handling of default route
                        
                        .. attribute:: route
                        
                        	
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ipv6.Rip.DefaultInformation.Route>`
                        
                        .. attribute:: metric
                        
                        	Default route metric
                        	**type**\: int
                        
                        	**range:** 1..15
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ipv6.Rip.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route', (YLeaf(YType.enumeration, 'route'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ipv6.Rip.DefaultInformation.Route')])),
                                ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                            ])
                            self.route = None
                            self.metric = None
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ipv6.Rip.DefaultInformation, ['route', 'metric'], name, value)

                        class Route(Enum):
                            """
                            Route (Enum Class)

                            .. data:: only = 0

                            .. data:: originate = 1

                            """

                            only = Enum.YLeaf(0, "only")

                            originate = Enum.YLeaf(1, "originate")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Tunnel.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Tunnel.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Tunnel.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Tunnel.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Tunnel.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Tunnel.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Tunnel.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Tunnel.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Tunnel.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Tunnel.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.Tunnel.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Tunnel.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Tunnel.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Tunnel.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Tunnel.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Tunnel.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Tunnel.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Tunnel.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Tunnel.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Tunnel.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.Tunnel.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Tunnel.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Tunnel.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Tunnel.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Tunnel.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Tunnel.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Tunnel.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Tunnel.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Tunnel.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Tunnel.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Tunnel.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Tunnel.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Tunnel.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Tunnel.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Tunnel.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Tunnel.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Tunnel.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Tunnel.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Tunnel.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Tunnel.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Tunnel.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Tunnel.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Tunnel.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Tunnel.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Tunnel.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Tunnel.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Tunnel.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Tunnel.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Tunnel.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Tunnel.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Tunnel.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Tunnel.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Tunnel.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Tunnel.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Tunnel.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Tunnel.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Tunnel.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Tunnel.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Tunnel.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Tunnel.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Tunnel.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Tunnel.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Tunnel.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Tunnel.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Tunnel.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Tunnel.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Tunnel.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Tunnel.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Tunnel.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Tunnel.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Tunnel.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Tunnel.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Tunnel.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Tunnel.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Tunnel.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Tunnel.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Tunnel.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Tunnel.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Tunnel.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Tunnel.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Tunnel.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Tunnel.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Tunnel.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Tunnel.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.PmPath, [u'name', u'interface_id'], name, value)


            class Qos(Entity):
                """
                Quality of Service related commands
                
                .. attribute:: pre_classify
                
                	Enable QOS classification before packets are tunnel encapsulated
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Tunnel.Qos, self).__init__()

                    self.yang_name = "qos"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('pre_classify', (YLeaf(YType.empty, 'pre-classify'), ['Empty'])),
                    ])
                    self.pre_classify = None
                    self._segment_path = lambda: "qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Qos, [u'pre_classify'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Tunnel.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.Tunnel.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.Tunnel.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.Tunnel.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.Tunnel.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.Tunnel.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.Tunnel.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Tunnel.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.Tunnel.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.Tunnel.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.Tunnel.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.Tunnel.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Nhrp(Entity):
                """
                NHRP Interface commands
                
                .. attribute:: event_publisher
                
                	Enable NHRP smart spoke feature
                	**type**\:  :py:class:`EventPublisher <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Nhrp.EventPublisher>`
                
                .. attribute:: group
                
                	group name string
                	**type**\: str
                
                .. attribute:: map
                
                	Map group name to QoS service policy
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Nhrp.Map>`
                
                .. attribute:: route_watch
                
                	Enable NHRP route watch
                	**type**\: bool
                
                

                """

                _prefix = 'ios-tun'
                _revision = '2017-08-28'

                def __init__(self):
                    super(Native.Interface.Tunnel.Nhrp, self).__init__()

                    self.yang_name = "nhrp"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event-publisher", ("event_publisher", Native.Interface.Tunnel.Nhrp.EventPublisher)), ("map", ("map", Native.Interface.Tunnel.Nhrp.Map))])
                    self._leafs = OrderedDict([
                        ('group', (YLeaf(YType.str, 'group'), ['str'])),
                        ('route_watch', (YLeaf(YType.boolean, 'route-watch'), ['bool'])),
                    ])
                    self.group = None
                    self.route_watch = None

                    self.event_publisher = Native.Interface.Tunnel.Nhrp.EventPublisher()
                    self.event_publisher.parent = self
                    self._children_name_map["event_publisher"] = "event-publisher"

                    self.map = Native.Interface.Tunnel.Nhrp.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"
                    self._segment_path = lambda: "Cisco-IOS-XE-tunnel:nhrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Nhrp, [u'group', u'route_watch'], name, value)


                class EventPublisher(Entity):
                    """
                    Enable NHRP smart spoke feature
                    
                    .. attribute:: max_event_timeout
                    
                    	Number of seconds
                    	**type**\: int
                    
                    	**range:** 1..22
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Nhrp.EventPublisher, self).__init__()

                        self.yang_name = "event-publisher"
                        self.yang_parent_name = "nhrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_event_timeout', (YLeaf(YType.uint8, 'max-event-timeout'), ['int'])),
                        ])
                        self.max_event_timeout = None
                        self._segment_path = lambda: "event-publisher"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Nhrp.EventPublisher, [u'max_event_timeout'], name, value)


                class Map(Entity):
                    """
                    Map group name to QoS service policy
                    
                    .. attribute:: group
                    
                    	NHRP group mapping
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Nhrp.Map.Group>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Nhrp.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "nhrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group", ("group", Native.Interface.Tunnel.Nhrp.Map.Group))])
                        self._leafs = OrderedDict()

                        self.group = Native.Interface.Tunnel.Nhrp.Map.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Nhrp.Map, [], name, value)


                    class Group(Entity):
                        """
                        NHRP group mapping
                        
                        .. attribute:: nhrp_name
                        
                        	
                        	**type**\: list of  		 :py:class:`NhrpName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Nhrp.Map.Group.NhrpName>`
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Nhrp.Map.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nhrp-name", ("nhrp_name", Native.Interface.Tunnel.Nhrp.Map.Group.NhrpName))])
                            self._leafs = OrderedDict()

                            self.nhrp_name = YList(self)
                            self._segment_path = lambda: "group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Nhrp.Map.Group, [], name, value)


                        class NhrpName(Entity):
                            """
                            
                            
                            .. attribute:: nhrp_name  (key)
                            
                            	NHRP group name
                            	**type**\: str
                            
                            .. attribute:: service_policy
                            
                            	QoS service\-policy
                            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Nhrp.Map.Group.NhrpName.ServicePolicy>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Nhrp.Map.Group.NhrpName, self).__init__()

                                self.yang_name = "nhrp-name"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['nhrp_name']
                                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.Tunnel.Nhrp.Map.Group.NhrpName.ServicePolicy))])
                                self._leafs = OrderedDict([
                                    ('nhrp_name', (YLeaf(YType.str, 'nhrp-name'), ['str'])),
                                ])
                                self.nhrp_name = None

                                self.service_policy = Native.Interface.Tunnel.Nhrp.Map.Group.NhrpName.ServicePolicy()
                                self.service_policy.parent = self
                                self._children_name_map["service_policy"] = "service-policy"
                                self._segment_path = lambda: "nhrp-name" + "[nhrp-name='" + str(self.nhrp_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Nhrp.Map.Group.NhrpName, [u'nhrp_name'], name, value)


                            class ServicePolicy(Entity):
                                """
                                QoS service\-policy
                                
                                .. attribute:: output
                                
                                	QoS policy\-map name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Nhrp.Map.Group.NhrpName.ServicePolicy, self).__init__()

                                    self.yang_name = "service-policy"
                                    self.yang_parent_name = "nhrp-name"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                                    ])
                                    self.output = None
                                    self._segment_path = lambda: "service-policy"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Nhrp.Map.Group.NhrpName.ServicePolicy, [u'output'], name, value)


            class Tunnel_(Entity):
                """
                protocol\-over\-protocol tunneling
                
                .. attribute:: tun_6rd
                
                	set tunnel 6rd parameters
                	**type**\:  :py:class:`Tun6rd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Tun6rd>`
                
                .. attribute:: bandwidth
                
                	Set tunnel bandwidth informational parameter
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Bandwidth>`
                
                .. attribute:: checksum
                
                	enable end to end checksumming of packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: source
                
                	source of tunnel packets
                	**type**\: str
                
                .. attribute:: destination
                
                	destination of tunnel
                	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Destination>`
                
                .. attribute:: dst_port
                
                	tunnel destination port
                	**type**\:  :py:class:`DstPort <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.DstPort>`
                
                .. attribute:: endpoint
                
                	Set endpoint parameter
                	**type**\:  :py:class:`Endpoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Endpoint>`
                
                .. attribute:: entropy
                
                	Compute hash (entropy) on payload and propagate to tunnel header
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: fixup
                
                	fixup on tunnel interface
                	**type**\:  :py:class:`Fixup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Fixup>`
                
                .. attribute:: flow
                
                	flow options
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Flow>`
                
                .. attribute:: key
                
                	security or selector key
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mode
                
                	tunnel encapsulation method
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode>`
                
                .. attribute:: network_id
                
                	Set network\-id
                	**type**\:  :py:class:`NetworkId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.NetworkId>`
                
                .. attribute:: path_mtu_discovery
                
                	Enable Path MTU Discovery on tunnel
                	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.PathMtuDiscovery>`
                
                	**presence node**\: True
                
                .. attribute:: protection
                
                	Enable tunnel protection
                	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Protection>`
                
                .. attribute:: mpls
                
                	
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls>`
                
                .. attribute:: raw_packet_interface
                
                	physical interface for all packets entering itto be tunneled and for all packets entering the tunnel to exit
                	**type**\: str
                
                .. attribute:: rbscp
                
                	Set tunnel RBSCP parameters
                	**type**\:  :py:class:`Rbscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Rbscp>`
                
                .. attribute:: snooping
                
                	Snooping on tunnel
                	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Snooping>`
                
                .. attribute:: src_port
                
                	tunnel source port
                	**type**\:  :py:class:`SrcPort <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.SrcPort>`
                
                .. attribute:: tos
                
                	set type of sevice byte
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: ttl
                
                	set time to live
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: udlr
                
                	associate tunnel with unidirectional interface
                	**type**\:  :py:class:`Udlr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Udlr>`
                
                .. attribute:: vlan
                
                	Set vlan\-id for ethernet over gre mode
                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Vlan>`
                
                .. attribute:: vrf
                
                	set tunnel vrf membership
                	**type**\: str
                
                

                """

                _prefix = 'ios-tun'
                _revision = '2017-08-28'

                def __init__(self):
                    super(Native.Interface.Tunnel.Tunnel_, self).__init__()

                    self.yang_name = "tunnel"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tun-6rd", ("tun_6rd", Native.Interface.Tunnel.Tunnel_.Tun6rd)), ("bandwidth", ("bandwidth", Native.Interface.Tunnel.Tunnel_.Bandwidth)), ("destination", ("destination", Native.Interface.Tunnel.Tunnel_.Destination)), ("dst-port", ("dst_port", Native.Interface.Tunnel.Tunnel_.DstPort)), ("endpoint", ("endpoint", Native.Interface.Tunnel.Tunnel_.Endpoint)), ("fixup", ("fixup", Native.Interface.Tunnel.Tunnel_.Fixup)), ("flow", ("flow", Native.Interface.Tunnel.Tunnel_.Flow)), ("mode", ("mode", Native.Interface.Tunnel.Tunnel_.Mode)), ("network-id", ("network_id", Native.Interface.Tunnel.Tunnel_.NetworkId)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Interface.Tunnel.Tunnel_.PathMtuDiscovery)), ("protection", ("protection", Native.Interface.Tunnel.Tunnel_.Protection)), ("mpls", ("mpls", Native.Interface.Tunnel.Tunnel_.Mpls)), ("rbscp", ("rbscp", Native.Interface.Tunnel.Tunnel_.Rbscp)), ("src-port", ("src_port", Native.Interface.Tunnel.Tunnel_.SrcPort)), ("udlr", ("udlr", Native.Interface.Tunnel.Tunnel_.Udlr)), ("vlan", ("vlan", Native.Interface.Tunnel.Tunnel_.Vlan))])
                    self._leafs = OrderedDict([
                        ('checksum', (YLeaf(YType.empty, 'checksum'), ['Empty'])),
                        ('source', (YLeaf(YType.str, 'source'), ['str'])),
                        ('entropy', (YLeaf(YType.empty, 'entropy'), ['Empty'])),
                        ('key', (YLeaf(YType.uint64, 'key'), ['int'])),
                        ('raw_packet_interface', (YLeaf(YType.str, 'raw-packet-interface'), ['str'])),
                        ('snooping', (YLeaf(YType.enumeration, 'snooping'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Tunnel_.Snooping')])),
                        ('tos', (YLeaf(YType.uint8, 'tos'), ['int'])),
                        ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ])
                    self.checksum = None
                    self.source = None
                    self.entropy = None
                    self.key = None
                    self.raw_packet_interface = None
                    self.snooping = None
                    self.tos = None
                    self.ttl = None
                    self.vrf = None

                    self.tun_6rd = Native.Interface.Tunnel.Tunnel_.Tun6rd()
                    self.tun_6rd.parent = self
                    self._children_name_map["tun_6rd"] = "tun-6rd"

                    self.bandwidth = Native.Interface.Tunnel.Tunnel_.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"

                    self.destination = Native.Interface.Tunnel.Tunnel_.Destination()
                    self.destination.parent = self
                    self._children_name_map["destination"] = "destination"

                    self.dst_port = Native.Interface.Tunnel.Tunnel_.DstPort()
                    self.dst_port.parent = self
                    self._children_name_map["dst_port"] = "dst-port"

                    self.endpoint = Native.Interface.Tunnel.Tunnel_.Endpoint()
                    self.endpoint.parent = self
                    self._children_name_map["endpoint"] = "endpoint"

                    self.fixup = Native.Interface.Tunnel.Tunnel_.Fixup()
                    self.fixup.parent = self
                    self._children_name_map["fixup"] = "fixup"

                    self.flow = Native.Interface.Tunnel.Tunnel_.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"

                    self.mode = Native.Interface.Tunnel.Tunnel_.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.network_id = Native.Interface.Tunnel.Tunnel_.NetworkId()
                    self.network_id.parent = self
                    self._children_name_map["network_id"] = "network-id"

                    self.path_mtu_discovery = None
                    self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                    self.protection = Native.Interface.Tunnel.Tunnel_.Protection()
                    self.protection.parent = self
                    self._children_name_map["protection"] = "protection"

                    self.mpls = Native.Interface.Tunnel.Tunnel_.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"

                    self.rbscp = Native.Interface.Tunnel.Tunnel_.Rbscp()
                    self.rbscp.parent = self
                    self._children_name_map["rbscp"] = "rbscp"

                    self.src_port = Native.Interface.Tunnel.Tunnel_.SrcPort()
                    self.src_port.parent = self
                    self._children_name_map["src_port"] = "src-port"

                    self.udlr = Native.Interface.Tunnel.Tunnel_.Udlr()
                    self.udlr.parent = self
                    self._children_name_map["udlr"] = "udlr"

                    self.vlan = Native.Interface.Tunnel.Tunnel_.Vlan()
                    self.vlan.parent = self
                    self._children_name_map["vlan"] = "vlan"
                    self._segment_path = lambda: "Cisco-IOS-XE-tunnel:tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_, [u'checksum', u'source', u'entropy', u'key', u'raw_packet_interface', u'snooping', u'tos', u'ttl', u'vrf'], name, value)

                class Snooping(Enum):
                    """
                    Snooping (Enum Class)

                    Snooping on tunnel

                    .. data:: enable = 0

                    """

                    enable = Enum.YLeaf(0, "enable")



                class Tun6rd(Entity):
                    """
                    set tunnel 6rd parameters
                    
                    .. attribute:: br
                    
                    	Border Relay parameters
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv4
                    
                    	Common IPv4 transport source parameters
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Tun6rd.Ipv4>`
                    
                    .. attribute:: prefix
                    
                    	Provider selected common IPv6 prefix
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    .. attribute:: reverse_map_check
                    
                    	Enable source IP address and port verification
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Tun6rd, self).__init__()

                        self.yang_name = "tun-6rd"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.Tunnel.Tunnel_.Tun6rd.Ipv4))])
                        self._leafs = OrderedDict([
                            ('br', (YLeaf(YType.str, 'br'), ['str'])),
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ('reverse_map_check', (YLeaf(YType.empty, 'reverse-map-check'), ['Empty'])),
                        ])
                        self.br = None
                        self.prefix = None
                        self.reverse_map_check = None

                        self.ipv4 = Native.Interface.Tunnel.Tunnel_.Tun6rd.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._segment_path = lambda: "tun-6rd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Tun6rd, [u'br', u'prefix', u'reverse_map_check'], name, value)


                    class Ipv4(Entity):
                        """
                        Common IPv4 transport source parameters
                        
                        .. attribute:: prefix_len
                        
                        	Common IPv4 transport source prefix length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: suffix_len
                        
                        	Common IPv4 transport source suffix length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Tunnel_.Tun6rd.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "tun-6rd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix_len', (YLeaf(YType.uint8, 'prefix-len'), ['int'])),
                                ('suffix_len', (YLeaf(YType.uint8, 'suffix-len'), ['int'])),
                            ])
                            self.prefix_len = None
                            self.suffix_len = None
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Tun6rd.Ipv4, [u'prefix_len', u'suffix_len'], name, value)


                class Bandwidth(Entity):
                    """
                    Set tunnel bandwidth informational parameter
                    
                    .. attribute:: receive
                    
                    	Receive bandwidth
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmit
                    
                    	Transmit bandwidth
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.uint32, 'receive'), ['int'])),
                            ('transmit', (YLeaf(YType.uint32, 'transmit'), ['int'])),
                        ])
                        self.receive = None
                        self.transmit = None
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Bandwidth, [u'receive', u'transmit'], name, value)


                class Destination(Entity):
                    """
                    destination of tunnel
                    
                    .. attribute:: ipaddress_or_host
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                    
                    .. attribute:: list
                    
                    	List of Tunnel destinations
                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Destination.List>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Destination, self).__init__()

                        self.yang_name = "destination"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("list", ("list", Native.Interface.Tunnel.Tunnel_.Destination.List))])
                        self._leafs = OrderedDict([
                            ('ipaddress_or_host', (YLeaf(YType.str, 'ipaddress-or-host'), ['str','str','str'])),
                        ])
                        self.ipaddress_or_host = None

                        self.list = Native.Interface.Tunnel.Tunnel_.Destination.List()
                        self.list.parent = self
                        self._children_name_map["list"] = "list"
                        self._segment_path = lambda: "destination"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Destination, [u'ipaddress_or_host'], name, value)


                    class List(Entity):
                        """
                        List of Tunnel destinations
                        
                        .. attribute:: mpls
                        
                        	MPLS destination list
                        	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Destination.List.Mpls>`
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Tunnel_.Destination.List, self).__init__()

                            self.yang_name = "list"
                            self.yang_parent_name = "destination"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mpls", ("mpls", Native.Interface.Tunnel.Tunnel_.Destination.List.Mpls))])
                            self._leafs = OrderedDict()

                            self.mpls = Native.Interface.Tunnel.Tunnel_.Destination.List.Mpls()
                            self.mpls.parent = self
                            self._children_name_map["mpls"] = "mpls"
                            self._segment_path = lambda: "list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Destination.List, [], name, value)


                        class Mpls(Entity):
                            """
                            MPLS destination list
                            
                            .. attribute:: traffic_eng
                            
                            	MPLS Traffic Engineering destination list
                            	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Destination.List.Mpls.TrafficEng>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Destination.List.Mpls, self).__init__()

                                self.yang_name = "mpls"
                                self.yang_parent_name = "list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("traffic-eng", ("traffic_eng", Native.Interface.Tunnel.Tunnel_.Destination.List.Mpls.TrafficEng))])
                                self._leafs = OrderedDict()

                                self.traffic_eng = Native.Interface.Tunnel.Tunnel_.Destination.List.Mpls.TrafficEng()
                                self.traffic_eng.parent = self
                                self._children_name_map["traffic_eng"] = "traffic-eng"
                                self._segment_path = lambda: "mpls"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Destination.List.Mpls, [], name, value)


                            class TrafficEng(Entity):
                                """
                                MPLS Traffic Engineering destination list
                                
                                .. attribute:: name
                                
                                	Specify a destination list by name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Destination.List.Mpls.TrafficEng, self).__init__()

                                    self.yang_name = "traffic-eng"
                                    self.yang_parent_name = "mpls"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "traffic-eng"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Destination.List.Mpls.TrafficEng, [u'name'], name, value)


                class DstPort(Entity):
                    """
                    tunnel destination port
                    
                    .. attribute:: port_num
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dynamic
                    
                    	Set Destination Port Dynamically
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.DstPort, self).__init__()

                        self.yang_name = "dst-port"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_num', (YLeaf(YType.uint16, 'port-num'), ['int'])),
                            ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                        ])
                        self.port_num = None
                        self.dynamic = None
                        self._segment_path = lambda: "dst-port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.DstPort, [u'port_num', u'dynamic'], name, value)


                class Endpoint(Entity):
                    """
                    Set endpoint parameter
                    
                    .. attribute:: service_policy
                    
                    	Set service\-policy
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Endpoint.ServicePolicy>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Endpoint, self).__init__()

                        self.yang_name = "endpoint"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.Tunnel.Tunnel_.Endpoint.ServicePolicy))])
                        self._leafs = OrderedDict()

                        self.service_policy = Native.Interface.Tunnel.Tunnel_.Endpoint.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"
                        self._segment_path = lambda: "endpoint"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Endpoint, [], name, value)


                    class ServicePolicy(Entity):
                        """
                        Set service\-policy
                        
                        .. attribute:: output
                        
                        	apply QoS service policy in the output direction
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Tunnel_.Endpoint.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "endpoint"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('output', (YLeaf(YType.str, 'output'), ['str'])),
                            ])
                            self.output = None
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Endpoint.ServicePolicy, [u'output'], name, value)


                class Fixup(Entity):
                    """
                    fixup on tunnel interface
                    
                    .. attribute:: nat
                    
                    	enable post nat fixup 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Fixup, self).__init__()

                        self.yang_name = "fixup"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('nat', (YLeaf(YType.empty, 'nat'), ['Empty'])),
                        ])
                        self.nat = None
                        self._segment_path = lambda: "fixup"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Fixup, [u'nat'], name, value)


                class Flow(Entity):
                    """
                    flow options
                    
                    .. attribute:: egress_records
                    
                    	enable egress flow records 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('egress_records', (YLeaf(YType.empty, 'egress-records'), ['Empty'])),
                        ])
                        self.egress_records = None
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Flow, [u'egress_records'], name, value)


                class Mode(Entity):
                    """
                    tunnel encapsulation method
                    
                    .. attribute:: ipsec
                    
                    	IPSec tunnel encapsulation
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Ipsec>`
                    
                    .. attribute:: mpls
                    
                    	MPLS encapsulations
                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Mpls>`
                    
                    .. attribute:: ethernet
                    
                    	Ethernet over gre
                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Ethernet>`
                    
                    .. attribute:: gre
                    
                    	generic route encapsulation protocol
                    	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Gre>`
                    
                    .. attribute:: ipip
                    
                    	IP over IP encapsulation
                    	**type**\:  :py:class:`Ipip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Ipip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Generic packet tunneling in IPv6
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipv6ip
                    
                    	IPv6 over IP encapsulation
                    	**type**\:  :py:class:`Ipv6ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Ipv6ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: udp
                    
                    	UDP encapsulation protocol
                    	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Udp>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.Tunnel.Tunnel_.Mode.Ipsec)), ("mpls", ("mpls", Native.Interface.Tunnel.Tunnel_.Mode.Mpls)), ("ethernet", ("ethernet", Native.Interface.Tunnel.Tunnel_.Mode.Ethernet)), ("gre", ("gre", Native.Interface.Tunnel.Tunnel_.Mode.Gre)), ("ipip", ("ipip", Native.Interface.Tunnel.Tunnel_.Mode.Ipip)), ("ipv6ip", ("ipv6ip", Native.Interface.Tunnel.Tunnel_.Mode.Ipv6ip))])
                        self._leafs = OrderedDict([
                            ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                            ('udp', (YLeaf(YType.enumeration, 'udp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Tunnel_.Mode.Udp')])),
                        ])
                        self.ipv6 = None
                        self.udp = None

                        self.ipsec = Native.Interface.Tunnel.Tunnel_.Mode.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"

                        self.mpls = Native.Interface.Tunnel.Tunnel_.Mode.Mpls()
                        self.mpls.parent = self
                        self._children_name_map["mpls"] = "mpls"

                        self.ethernet = Native.Interface.Tunnel.Tunnel_.Mode.Ethernet()
                        self.ethernet.parent = self
                        self._children_name_map["ethernet"] = "ethernet"

                        self.gre = Native.Interface.Tunnel.Tunnel_.Mode.Gre()
                        self.gre.parent = self
                        self._children_name_map["gre"] = "gre"

                        self.ipip = None
                        self._children_name_map["ipip"] = "ipip"

                        self.ipv6ip = None
                        self._children_name_map["ipv6ip"] = "ipv6ip"
                        self._segment_path = lambda: "mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mode, [u'ipv6', u'udp'], name, value)

                    class Udp(Enum):
                        """
                        Udp (Enum Class)

                        UDP encapsulation protocol

                        .. data:: ip = 0

                        .. data:: multipoint = 1

                        """

                        ip = Enum.YLeaf(0, "ip")

                        multipoint = Enum.YLeaf(1, "multipoint")



                    class Ipsec(Entity):
                        """
                        IPSec tunnel encapsulation
                        
                        .. attribute:: ipv4
                        
                        	over IPv4
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Ipsec.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	over IPv6
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Ipsec.Ipv6>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Tunnel_.Mode.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.Tunnel.Tunnel_.Mode.Ipsec.Ipv4)), ("ipv6", ("ipv6", Native.Interface.Tunnel.Tunnel_.Mode.Ipsec.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = None
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mode.Ipsec, [], name, value)


                        class Ipv4(Entity):
                            """
                            over IPv4
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mode.Ipsec.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True


                        class Ipv6(Entity):
                            """
                            over IPv6
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mode.Ipsec.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True


                    class Mpls(Entity):
                        """
                        MPLS encapsulations
                        
                        .. attribute:: traffic_eng
                        
                        	Traffic engineering tunnels
                        	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Mpls.TrafficEng>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Tunnel_.Mode.Mpls, self).__init__()

                            self.yang_name = "mpls"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("traffic-eng", ("traffic_eng", Native.Interface.Tunnel.Tunnel_.Mode.Mpls.TrafficEng))])
                            self._leafs = OrderedDict()

                            self.traffic_eng = None
                            self._children_name_map["traffic_eng"] = "traffic-eng"
                            self._segment_path = lambda: "mpls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mode.Mpls, [], name, value)


                        class TrafficEng(Entity):
                            """
                            Traffic engineering tunnels
                            
                            .. attribute:: multilsp
                            
                            	Multiple LSP mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	point\-to\-multipoint tunnel mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mode.Mpls.TrafficEng, self).__init__()

                                self.yang_name = "traffic-eng"
                                self.yang_parent_name = "mpls"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('multilsp', (YLeaf(YType.empty, 'multilsp'), ['Empty'])),
                                    ('point_to_multipoint', (YLeaf(YType.empty, 'point-to-multipoint'), ['Empty'])),
                                ])
                                self.multilsp = None
                                self.point_to_multipoint = None
                                self._segment_path = lambda: "traffic-eng"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mode.Mpls.TrafficEng, [u'multilsp', u'point_to_multipoint'], name, value)


                    class Ethernet(Entity):
                        """
                        Ethernet over gre
                        
                        .. attribute:: gre
                        
                        	Ethernet over gre
                        	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Ethernet.Gre>`
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Tunnel_.Mode.Ethernet, self).__init__()

                            self.yang_name = "ethernet"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('gre', (YLeaf(YType.enumeration, 'gre'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Tunnel_.Mode.Ethernet.Gre')])),
                            ])
                            self.gre = None
                            self._segment_path = lambda: "ethernet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mode.Ethernet, [u'gre'], name, value)

                        class Gre(Enum):
                            """
                            Gre (Enum Class)

                            Ethernet over gre

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                    class Gre(Entity):
                        """
                        generic route encapsulation protocol
                        
                        .. attribute:: ip
                        
                        	over IP
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6
                        
                        	over IPv6
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multipoint
                        
                        	over IPv4 (multipoint)
                        	**type**\:  :py:class:`Multipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mode.Gre.Multipoint>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Tunnel_.Mode.Gre, self).__init__()

                            self.yang_name = "gre"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("multipoint", ("multipoint", Native.Interface.Tunnel.Tunnel_.Mode.Gre.Multipoint))])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                            ])
                            self.ip = None
                            self.ipv6 = None

                            self.multipoint = None
                            self._children_name_map["multipoint"] = "multipoint"
                            self._segment_path = lambda: "gre"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mode.Gre, [u'ip', u'ipv6'], name, value)


                        class Multipoint(Entity):
                            """
                            over IPv4 (multipoint)
                            
                            .. attribute:: ipv6
                            
                            	over IPv6
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mode.Gre.Multipoint, self).__init__()

                                self.yang_name = "multipoint"
                                self.yang_parent_name = "gre"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                                ])
                                self.ipv6 = None
                                self._segment_path = lambda: "multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mode.Gre.Multipoint, [u'ipv6'], name, value)


                    class Ipip(Entity):
                        """
                        IP over IP encapsulation
                        
                        .. attribute:: decapsulate_any
                        
                        	Incoming traffic only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Tunnel_.Mode.Ipip, self).__init__()

                            self.yang_name = "ipip"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('decapsulate_any', (YLeaf(YType.empty, 'decapsulate-any'), ['Empty'])),
                            ])
                            self.decapsulate_any = None
                            self._segment_path = lambda: "ipip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mode.Ipip, [u'decapsulate_any'], name, value)


                    class Ipv6ip(Entity):
                        """
                        IPv6 over IP encapsulation
                        
                        .. attribute:: auto_6rd
                        
                        	IPv6 automatic tunnelling using 6rd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: auto_6to4
                        
                        	IPv6 automatic tunnelling using 6to4
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: isatap
                        
                        	IPv6 automatic tunnelling using ISATAP
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Tunnel_.Mode.Ipv6ip, self).__init__()

                            self.yang_name = "ipv6ip"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('auto_6rd', (YLeaf(YType.empty, 'auto-6rd'), ['Empty'])),
                                ('auto_6to4', (YLeaf(YType.empty, 'auto-6to4'), ['Empty'])),
                                ('isatap', (YLeaf(YType.empty, 'isatap'), ['Empty'])),
                            ])
                            self.auto_6rd = None
                            self.auto_6to4 = None
                            self.isatap = None
                            self._segment_path = lambda: "ipv6ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mode.Ipv6ip, [u'auto_6rd', u'auto_6to4', u'isatap'], name, value)


                class NetworkId(Entity):
                    """
                    Set network\-id
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nexthop
                    
                    	nexthop
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: qos
                    
                    	QoS profile
                    	**type**\: str
                    
                    .. attribute:: weight
                    
                    	weight
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.NetworkId, self).__init__()

                        self.yang_name = "network-id"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('nexthop', (YLeaf(YType.str, 'nexthop'), ['str'])),
                            ('qos', (YLeaf(YType.str, 'qos'), ['str'])),
                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                        ])
                        self.id = None
                        self.nexthop = None
                        self.qos = None
                        self.weight = None
                        self._segment_path = lambda: "network-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.NetworkId, [u'id', u'nexthop', u'qos', u'weight'], name, value)


                class PathMtuDiscovery(Entity):
                    """
                    Enable Path MTU Discovery on tunnel
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.PathMtuDiscovery, self).__init__()

                        self.yang_name = "path-mtu-discovery"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "path-mtu-discovery"
                        self._is_frozen = True


                class Protection(Entity):
                    """
                    Enable tunnel protection
                    
                    .. attribute:: ipsec
                    
                    	Use ipsec to protect this tunnel interface
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Protection.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Protection, self).__init__()

                        self.yang_name = "protection"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-crypto:ipsec", ("ipsec", Native.Interface.Tunnel.Tunnel_.Protection.Ipsec))])
                        self._leafs = OrderedDict()

                        self.ipsec = Native.Interface.Tunnel.Tunnel_.Protection.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "Cisco-IOS-XE-crypto:ipsec"
                        self._segment_path = lambda: "protection"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Protection, [], name, value)


                    class Ipsec(Entity):
                        """
                        Use ipsec to protect this tunnel interface
                        
                        .. attribute:: profile
                        
                        	Determine the ipsec policy profile to use
                        	**type**\: str
                        
                        .. attribute:: ikev2_profile
                        
                        	ikev2 policy profile
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Tunnel_.Protection.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "protection"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                                ('ikev2_profile', (YLeaf(YType.str, 'ikev2-profile'), ['str'])),
                            ])
                            self.profile = None
                            self.ikev2_profile = None
                            self._segment_path = lambda: "Cisco-IOS-XE-crypto:ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Protection.Ipsec, ['profile', 'ikev2_profile'], name, value)


                class Mpls(Entity):
                    """
                    
                    
                    .. attribute:: traffic_eng
                    
                    	
                    	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("traffic-eng", ("traffic_eng", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng))])
                        self._leafs = OrderedDict()

                        self.traffic_eng = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng()
                        self.traffic_eng.parent = self
                        self._children_name_map["traffic_eng"] = "traffic-eng"
                        self._segment_path = lambda: "mpls"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls, [], name, value)


                    class TrafficEng(Entity):
                        """
                        
                        
                        .. attribute:: affinity_mask
                        
                        	desired link affinity attributes
                        	**type**\:  :py:class:`AffinityMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AffinityMask>`
                        
                        .. attribute:: auto_bw
                        
                        	Specify mpls tunnel should automatically change BW
                        	**type**\:  :py:class:`AutoBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AutoBw>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: autoroute
                        
                        	parameters for routing over tunnel
                        	**type**\:  :py:class:`Autoroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Autoroute>`
                        
                        .. attribute:: backup_bw
                        
                        	
                        	**type**\:  :py:class:`BackupBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw>`
                        
                        .. attribute:: bandwidth
                        
                        	tunnel bandwidth requirement
                        	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Bandwidth>`
                        
                        .. attribute:: bfd
                        
                        	Bidirectional Forwarding Detection (BFD) configuration
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Bfd>`
                        
                        .. attribute:: binding_sid
                        
                        	Binding Segment Identifier
                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BindingSid>`
                        
                        .. attribute:: exp
                        
                        	Set the experimental values allowed for this interface
                        	**type**\:  :py:class:`Exp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Exp>`
                        
                        .. attribute:: exp_bundle
                        
                        	Configure the tunnel as a bundle
                        	**type**\:  :py:class:`ExpBundle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ExpBundle>`
                        
                        .. attribute:: fast_reroute
                        
                        	Specify mpls tunnel can be fast\-rerouted
                        	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.FastReroute>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forwarding_adjacency
                        
                        	Treat this tunnel as a Forwarding Adjacency
                        	**type**\:  :py:class:`ForwardingAdjacency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ForwardingAdjacency>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: interface
                        
                        	Add tunnel interface config
                        	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Interface_>`
                        
                        .. attribute:: load_share
                        
                        	Specify tunnel load\-sharing metric\: <0..1000000>
                        	**type**\: int
                        
                        	**range:** 0..1000000
                        
                        .. attribute:: name
                        
                        	specify a name describing the TE tunnel
                        	**type**\: str
                        
                        	**length:** 1..63
                        
                        .. attribute:: path_option
                        
                        	
                        	**type**\:  :py:class:`PathOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption>`
                        
                        .. attribute:: path_selection
                        
                        	Path Selection Configuration
                        	**type**\:  :py:class:`PathSelection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection>`
                        
                        .. attribute:: priority
                        
                        	Tunnel priority
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Priority>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: record_route
                        
                        	record the route used by the tunnel
                        	**type**\:  :py:class:`RecordRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.RecordRoute>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng, self).__init__()

                            self.yang_name = "traffic-eng"
                            self.yang_parent_name = "mpls"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("affinity-mask", ("affinity_mask", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AffinityMask)), ("auto-bw", ("auto_bw", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AutoBw)), ("autoroute", ("autoroute", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Autoroute)), ("backup-bw", ("backup_bw", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw)), ("bandwidth", ("bandwidth", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Bandwidth)), ("bfd", ("bfd", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Bfd)), ("binding-sid", ("binding_sid", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BindingSid)), ("exp", ("exp", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Exp)), ("exp-bundle", ("exp_bundle", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ExpBundle)), ("fast-reroute", ("fast_reroute", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.FastReroute)), ("forwarding-adjacency", ("forwarding_adjacency", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ForwardingAdjacency)), ("interface", ("interface", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Interface_)), ("path-option", ("path_option", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption)), ("path-selection", ("path_selection", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection)), ("priority", ("priority", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Priority)), ("record-route", ("record_route", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.RecordRoute))])
                            self._leafs = OrderedDict([
                                ('load_share', (YLeaf(YType.uint32, 'load-share'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.load_share = None
                            self.name = None

                            self.affinity_mask = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AffinityMask()
                            self.affinity_mask.parent = self
                            self._children_name_map["affinity_mask"] = "affinity-mask"

                            self.auto_bw = None
                            self._children_name_map["auto_bw"] = "auto-bw"

                            self.autoroute = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Autoroute()
                            self.autoroute.parent = self
                            self._children_name_map["autoroute"] = "autoroute"

                            self.backup_bw = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw()
                            self.backup_bw.parent = self
                            self._children_name_map["backup_bw"] = "backup-bw"

                            self.bandwidth = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Bandwidth()
                            self.bandwidth.parent = self
                            self._children_name_map["bandwidth"] = "bandwidth"

                            self.bfd = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Bfd()
                            self.bfd.parent = self
                            self._children_name_map["bfd"] = "bfd"

                            self.binding_sid = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BindingSid()
                            self.binding_sid.parent = self
                            self._children_name_map["binding_sid"] = "binding-sid"

                            self.exp = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Exp()
                            self.exp.parent = self
                            self._children_name_map["exp"] = "exp"

                            self.exp_bundle = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ExpBundle()
                            self.exp_bundle.parent = self
                            self._children_name_map["exp_bundle"] = "exp-bundle"

                            self.fast_reroute = None
                            self._children_name_map["fast_reroute"] = "fast-reroute"

                            self.forwarding_adjacency = None
                            self._children_name_map["forwarding_adjacency"] = "forwarding-adjacency"

                            self.interface = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Interface_()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"

                            self.path_option = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption()
                            self.path_option.parent = self
                            self._children_name_map["path_option"] = "path-option"

                            self.path_selection = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection()
                            self.path_selection.parent = self
                            self._children_name_map["path_selection"] = "path-selection"

                            self.priority = None
                            self._children_name_map["priority"] = "priority"

                            self.record_route = None
                            self._children_name_map["record_route"] = "record-route"
                            self._segment_path = lambda: "traffic-eng"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng, [u'load_share', u'name'], name, value)


                        class AffinityMask(Entity):
                            """
                            desired link affinity attributes
                            
                            .. attribute:: affinity
                            
                            	Desired link attributes for links comprising tunnel\: <0x0\-0xFFFFFFFF>
                            	**type**\: str
                            
                            	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                            
                            .. attribute:: mask
                            
                            	Mask on desired link attributes\: <0x0\-0xFFFFFFFF>
                            	**type**\: str
                            
                            	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AffinityMask, self).__init__()

                                self.yang_name = "affinity-mask"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('affinity', (YLeaf(YType.str, 'affinity'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.affinity = None
                                self.mask = None
                                self._segment_path = lambda: "affinity-mask"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AffinityMask, [u'affinity', u'mask'], name, value)


                        class AutoBw(Entity):
                            """
                            Specify mpls tunnel should automatically change BW
                            
                            .. attribute:: frequency
                            
                            	Frequency to change tunnel BW\: <300..604800>
                            	**type**\: int
                            
                            	**range:** 300..604800
                            
                            .. attribute:: collect_bw
                            
                            	Just collect bandwidth info on this tunnel
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: adjustment_threshold
                            
                            	Set the bandwidth change threshold to trigger adjustment
                            	**type**\: int
                            
                            	**range:** 1..99
                            
                            .. attribute:: overflow_limit
                            
                            	Set consecutive samples exceeding threshold which trigger adjustment\: <1..10>
                            	**type**\:  :py:class:`OverflowLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AutoBw.OverflowLimit>`
                            
                            .. attribute:: max_bw
                            
                            	Set the maximum bandwidth for auto\-bw on this tunnel\: <0..4294967295> (kbps)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_bw
                            
                            	Set the minimum bandwidth for auto\-bw on this tunnel\: <0..4294967294> (kbps)
                            	**type**\: int
                            
                            	**range:** 0..4294967294
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AutoBw, self).__init__()

                                self.yang_name = "auto-bw"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("overflow-limit", ("overflow_limit", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AutoBw.OverflowLimit))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('frequency', (YLeaf(YType.uint32, 'frequency'), ['int'])),
                                    ('collect_bw', (YLeaf(YType.empty, 'collect-bw'), ['Empty'])),
                                    ('adjustment_threshold', (YLeaf(YType.uint8, 'adjustment-threshold'), ['int'])),
                                    ('max_bw', (YLeaf(YType.uint32, 'max-bw'), ['int'])),
                                    ('min_bw', (YLeaf(YType.uint32, 'min-bw'), ['int'])),
                                ])
                                self.frequency = None
                                self.collect_bw = None
                                self.adjustment_threshold = None
                                self.max_bw = None
                                self.min_bw = None

                                self.overflow_limit = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AutoBw.OverflowLimit()
                                self.overflow_limit.parent = self
                                self._children_name_map["overflow_limit"] = "overflow-limit"
                                self._segment_path = lambda: "auto-bw"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AutoBw, [u'frequency', u'collect_bw', u'adjustment_threshold', u'max_bw', u'min_bw'], name, value)


                            class OverflowLimit(Entity):
                                """
                                Set consecutive samples exceeding threshold which trigger adjustment\: <1..10>
                                
                                .. attribute:: limit
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                .. attribute:: overflow_threshold
                                
                                	Set the bandwidth change threshold to trigger overflow adjustment\: <1..99> %
                                	**type**\: int
                                
                                	**range:** 1..99
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AutoBw.OverflowLimit, self).__init__()

                                    self.yang_name = "overflow-limit"
                                    self.yang_parent_name = "auto-bw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                                        ('overflow_threshold', (YLeaf(YType.uint8, 'overflow-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.overflow_threshold = None
                                    self._segment_path = lambda: "overflow-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.AutoBw.OverflowLimit, [u'limit', u'overflow_threshold'], name, value)


                        class Autoroute(Entity):
                            """
                            parameters for routing over tunnel
                            
                            .. attribute:: announce
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: metric
                            
                            	Specify mpls tunnel metric
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Autoroute.Metric>`
                            
                            .. attribute:: destination
                            
                            	announce tunnel destination to IP static route
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Autoroute, self).__init__()

                                self.yang_name = "autoroute"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Autoroute.Metric))])
                                self._leafs = OrderedDict([
                                    ('announce', (YLeaf(YType.empty, 'announce'), ['Empty'])),
                                    ('destination', (YLeaf(YType.empty, 'destination'), ['Empty'])),
                                ])
                                self.announce = None
                                self.destination = None

                                self.metric = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Autoroute.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "autoroute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Autoroute, [u'announce', u'destination'], name, value)


                            class Metric(Entity):
                                """
                                Specify mpls tunnel metric
                                
                                .. attribute:: range
                                
                                	Set tunnel metric for autoroutes\: <1..4294967295>
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: absolute
                                
                                	Set absolute metric for all autoroutes over tunnel\: <1..4294967295>
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: relative
                                
                                	Adjust tunnel metric for autoroutes relative to IGP\: <\-10..10>
                                	**type**\: int
                                
                                	**range:** \-10..10
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Autoroute.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "autoroute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                        ('absolute', (YLeaf(YType.uint32, 'absolute'), ['int'])),
                                        ('relative', (YLeaf(YType.int8, 'relative'), ['int'])),
                                    ])
                                    self.range = None
                                    self.absolute = None
                                    self.relative = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Autoroute.Metric, [u'range', u'absolute', u'relative'], name, value)


                        class BackupBw(Entity):
                            """
                            
                            
                            .. attribute:: bandwidth
                            
                            	Amount of allocatable backup bw, any lsp may use\: <1..4294967295> kbps
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: sub_pool
                            
                            	Enter Allocatable amount for Sub\-Pool bw
                            	**type**\:  :py:class:`SubPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool>`
                            
                            .. attribute:: class_type
                            
                            	
                            	**type**\:  :py:class:`ClassType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.ClassType>`
                            
                            .. attribute:: global_pool
                            
                            	
                            	**type**\:  :py:class:`GlobalPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.GlobalPool>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw, self).__init__()

                                self.yang_name = "backup-bw"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sub-pool", ("sub_pool", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool)), ("class-type", ("class_type", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.ClassType)), ("global-pool", ("global_pool", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.GlobalPool))])
                                self._leafs = OrderedDict([
                                    ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                ])
                                self.bandwidth = None

                                self.sub_pool = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool()
                                self.sub_pool.parent = self
                                self._children_name_map["sub_pool"] = "sub-pool"

                                self.class_type = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.ClassType()
                                self.class_type.parent = self
                                self._children_name_map["class_type"] = "class-type"

                                self.global_pool = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.GlobalPool()
                                self.global_pool.parent = self
                                self._children_name_map["global_pool"] = "global-pool"
                                self._segment_path = lambda: "backup-bw"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw, [u'bandwidth'], name, value)


                            class SubPool(Entity):
                                """
                                Enter Allocatable amount for Sub\-Pool bw
                                
                                .. attribute:: unlimited
                                
                                	Unlimited amount for Sub\-Pool bw
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sub_pool_config
                                
                                	
                                	**type**\:  :py:class:`SubPoolConfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool, self).__init__()

                                    self.yang_name = "sub-pool"
                                    self.yang_parent_name = "backup-bw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sub-pool-config", ("sub_pool_config", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig))])
                                    self._leafs = OrderedDict([
                                        ('unlimited', (YLeaf(YType.empty, 'unlimited'), ['Empty'])),
                                    ])
                                    self.unlimited = None

                                    self.sub_pool_config = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig()
                                    self.sub_pool_config.parent = self
                                    self._children_name_map["sub_pool_config"] = "sub-pool-config"
                                    self._segment_path = lambda: "sub-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool, [u'unlimited'], name, value)


                                class SubPoolConfig(Entity):
                                    """
                                    
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Amount of allocatable backup bw, only sub\-pool may use\: <1..4294967295> kbps
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: class_type
                                    
                                    	
                                    	**type**\:  :py:class:`ClassType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.ClassType>`
                                    
                                    .. attribute:: global_pool
                                    
                                    	
                                    	**type**\:  :py:class:`GlobalPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.GlobalPool>`
                                    
                                    

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig, self).__init__()

                                        self.yang_name = "sub-pool-config"
                                        self.yang_parent_name = "sub-pool"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("class-type", ("class_type", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.ClassType)), ("global-pool", ("global_pool", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.GlobalPool))])
                                        self._leafs = OrderedDict([
                                            ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                        ])
                                        self.bandwidth = None

                                        self.class_type = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.ClassType()
                                        self.class_type.parent = self
                                        self._children_name_map["class_type"] = "class-type"

                                        self.global_pool = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.GlobalPool()
                                        self.global_pool.parent = self
                                        self._children_name_map["global_pool"] = "global-pool"
                                        self._segment_path = lambda: "sub-pool-config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig, [u'bandwidth'], name, value)


                                    class ClassType(Entity):
                                        """
                                        
                                        
                                        .. attribute:: class_type_num
                                        
                                        	Enter the Class\-type\: <0..0>
                                        	**type**\: int
                                        
                                        	**range:** 0..1
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Amount of allocatable backup bw\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: unlimited
                                        
                                        	Unlimited amount of allocatable bw
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.ClassType, self).__init__()

                                            self.yang_name = "class-type"
                                            self.yang_parent_name = "sub-pool-config"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('class_type_num', (YLeaf(YType.uint8, 'class-type-num'), ['int'])),
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('unlimited', (YLeaf(YType.empty, 'unlimited'), ['Empty'])),
                                            ])
                                            self.class_type_num = None
                                            self.bandwidth = None
                                            self.unlimited = None
                                            self._segment_path = lambda: "class-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.ClassType, [u'class_type_num', u'bandwidth', u'unlimited'], name, value)


                                    class GlobalPool(Entity):
                                        """
                                        
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Amount of allocatable backup bw\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: unlimited
                                        
                                        	Unlimited amount of allocatable bw
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.GlobalPool, self).__init__()

                                            self.yang_name = "global-pool"
                                            self.yang_parent_name = "sub-pool-config"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('unlimited', (YLeaf(YType.empty, 'unlimited'), ['Empty'])),
                                            ])
                                            self.bandwidth = None
                                            self.unlimited = None
                                            self._segment_path = lambda: "global-pool"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.GlobalPool, [u'bandwidth', u'unlimited'], name, value)


                            class ClassType(Entity):
                                """
                                
                                
                                .. attribute:: class_type_num
                                
                                	Enter the Class\-type\: <0..1>
                                	**type**\: int
                                
                                	**range:** 0..1
                                
                                .. attribute:: bandwidth
                                
                                	Amount of allocatable backup bw\: <1..4294967295> kbps
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: unlimited
                                
                                	Unlimited amount of allocatable bw
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.ClassType, self).__init__()

                                    self.yang_name = "class-type"
                                    self.yang_parent_name = "backup-bw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('class_type_num', (YLeaf(YType.uint8, 'class-type-num'), ['int'])),
                                        ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                        ('unlimited', (YLeaf(YType.empty, 'unlimited'), ['Empty'])),
                                    ])
                                    self.class_type_num = None
                                    self.bandwidth = None
                                    self.unlimited = None
                                    self._segment_path = lambda: "class-type"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.ClassType, [u'class_type_num', u'bandwidth', u'unlimited'], name, value)


                            class GlobalPool(Entity):
                                """
                                
                                
                                .. attribute:: bandwidth
                                
                                	Amount of allocatable backup bw\: <1..4294967295> kbps
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: unlimited
                                
                                	Unlimited amount of allocatable bw
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.GlobalPool, self).__init__()

                                    self.yang_name = "global-pool"
                                    self.yang_parent_name = "backup-bw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                        ('unlimited', (YLeaf(YType.empty, 'unlimited'), ['Empty'])),
                                    ])
                                    self.bandwidth = None
                                    self.unlimited = None
                                    self._segment_path = lambda: "global-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BackupBw.GlobalPool, [u'bandwidth', u'unlimited'], name, value)


                        class Bandwidth(Entity):
                            """
                            tunnel bandwidth requirement
                            
                            .. attribute:: bw
                            
                            	bandwidth requirement\: <0..4294967295> kbps
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: class_type
                            
                            	classtype value
                            	**type**\: int
                            
                            	**range:** 0..1
                            
                            .. attribute:: sub_pool
                            
                            	tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Bandwidth, self).__init__()

                                self.yang_name = "bandwidth"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bw', (YLeaf(YType.uint32, 'bw'), ['int'])),
                                    ('class_type', (YLeaf(YType.uint8, 'class-type'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.bw = None
                                self.class_type = None
                                self.sub_pool = None
                                self._segment_path = lambda: "bandwidth"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Bandwidth, [u'bw', u'class_type', u'sub_pool'], name, value)


                        class Bfd(Entity):
                            """
                            Bidirectional Forwarding Detection (BFD) configuration
                            
                            .. attribute:: sbfd
                            
                            	 Seamless BFD
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sbfd', (YLeaf(YType.str, 'sbfd'), ['str'])),
                                ])
                                self.sbfd = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Bfd, [u'sbfd'], name, value)


                        class BindingSid(Entity):
                            """
                            Binding Segment Identifier
                            
                            .. attribute:: label
                            
                            	MPLS label (depends on the configured static label range)
                            	**type**\: int
                            
                            	**range:** 16..1048575
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BindingSid, self).__init__()

                                self.yang_name = "binding-sid"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                ])
                                self.label = None
                                self._segment_path = lambda: "binding-sid"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.BindingSid, [u'label'], name, value)


                        class Exp(Entity):
                            """
                            Set the experimental values allowed for this interface
                            
                            .. attribute:: exp_value
                            
                            	Enter up to 8 experimental values separated by white\-spaces\: <0..7>
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: default
                            
                            	Default all unconfigured exp to this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Exp, self).__init__()

                                self.yang_name = "exp"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('exp_value', (YLeafList(YType.uint8, 'exp-value'), ['int'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ])
                                self.exp_value = []
                                self.default = None
                                self._segment_path = lambda: "exp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Exp, [u'exp_value', u'default'], name, value)


                        class ExpBundle(Entity):
                            """
                            Configure the tunnel as a bundle
                            
                            .. attribute:: master
                            
                            	Master tunnel for the bundle
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: member
                            
                            	Member tunnel for the bundle
                            	**type**\:  :py:class:`Member <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ExpBundle.Member>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ExpBundle, self).__init__()

                                self.yang_name = "exp-bundle"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("member", ("member", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ExpBundle.Member))])
                                self._leafs = OrderedDict([
                                    ('master', (YLeaf(YType.empty, 'master'), ['Empty'])),
                                ])
                                self.master = None

                                self.member = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ExpBundle.Member()
                                self.member.parent = self
                                self._children_name_map["member"] = "member"
                                self._segment_path = lambda: "exp-bundle"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ExpBundle, [u'master'], name, value)


                            class Member(Entity):
                                """
                                Member tunnel for the bundle
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface number\: <0..2147483647>
                                	**type**\: int
                                
                                	**range:** 0..2147483647
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ExpBundle.Member, self).__init__()

                                    self.yang_name = "member"
                                    self.yang_parent_name = "exp-bundle"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ])
                                    self.tunnel = None
                                    self._segment_path = lambda: "member"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ExpBundle.Member, [u'tunnel'], name, value)


                        class FastReroute(Entity):
                            """
                            Specify mpls tunnel can be fast\-rerouted
                            
                            .. attribute:: bw_protect
                            
                            	bandwidth protection desired
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: node_protect
                            
                            	node protection desired
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.FastReroute, self).__init__()

                                self.yang_name = "fast-reroute"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bw_protect', (YLeaf(YType.empty, 'bw-protect'), ['Empty'])),
                                    ('node_protect', (YLeaf(YType.empty, 'node-protect'), ['Empty'])),
                                ])
                                self.bw_protect = None
                                self.node_protect = None
                                self._segment_path = lambda: "fast-reroute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.FastReroute, [u'bw_protect', u'node_protect'], name, value)


                        class ForwardingAdjacency(Entity):
                            """
                            Treat this tunnel as a Forwarding Adjacency
                            
                            .. attribute:: holdtime
                            
                            	How long to wait upon flooding a down Forwarding Adjacency\: <0..4294967295> msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ForwardingAdjacency, self).__init__()

                                self.yang_name = "forwarding-adjacency"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('holdtime', (YLeaf(YType.uint32, 'holdtime'), ['int'])),
                                ])
                                self.holdtime = None
                                self._segment_path = lambda: "forwarding-adjacency"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.ForwardingAdjacency, [u'holdtime'], name, value)


                        class Interface_(Entity):
                            """
                            Add tunnel interface config
                            
                            .. attribute:: down
                            
                            	 Tunnel interface down config
                            	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Interface_.Down>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Interface_, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("down", ("down", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Interface_.Down))])
                                self._leafs = OrderedDict()

                                self.down = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Interface_.Down()
                                self.down.parent = self
                                self._children_name_map["down"] = "down"
                                self._segment_path = lambda: "interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Interface_, [], name, value)


                            class Down(Entity):
                                """
                                 Tunnel interface down config
                                
                                .. attribute:: delay
                                
                                	Tunnel interface down delay config\: <0..0>
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Interface_.Down, self).__init__()

                                    self.yang_name = "down"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                    ])
                                    self.delay = None
                                    self._segment_path = lambda: "down"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Interface_.Down, [u'delay'], name, value)


                        class PathOption(Entity):
                            """
                            
                            
                            .. attribute:: working
                            
                            	
                            	**type**\: list of  		 :py:class:`Working <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working>`
                            
                            .. attribute:: protect
                            
                            	
                            	**type**\: list of  		 :py:class:`Protect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption, self).__init__()

                                self.yang_name = "path-option"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("working", ("working", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working)), ("protect", ("protect", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect))])
                                self._leafs = OrderedDict()

                                self.working = YList(self)
                                self.protect = YList(self)
                                self._segment_path = lambda: "path-option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption, [], name, value)


                            class Working(Entity):
                                """
                                
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dynamic
                                
                                	Setup based on dynamically calculated path
                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: explicit
                                
                                	Setup based on preconfigured path
                                	**type**\:  :py:class:`Explicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Explicit>`
                                
                                .. attribute:: segment_routing
                                
                                	Specify segment\-routing for this pathoption
                                	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.SegmentRouting>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working, self).__init__()

                                    self.yang_name = "working"
                                    self.yang_parent_name = "path-option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic)), ("explicit", ("explicit", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Explicit)), ("segment-routing", ("segment_routing", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.SegmentRouting))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.dynamic = None
                                    self._children_name_map["dynamic"] = "dynamic"

                                    self.explicit = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Explicit()
                                    self.explicit.parent = self
                                    self._children_name_map["explicit"] = "explicit"

                                    self.segment_routing = None
                                    self._children_name_map["segment_routing"] = "segment-routing"
                                    self._segment_path = lambda: "working" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working, [u'id'], name, value)


                                class Dynamic(Entity):
                                    """
                                    Setup based on dynamically calculated path
                                    
                                    .. attribute:: segment_routing
                                    
                                    	Specify segment\-routing for this pathoption
                                    	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic.SegmentRouting>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: pce
                                    
                                    	Use PCE for path computation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: address
                                    
                                    	PCE IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: verbatim
                                    
                                    	Do not validate links from the ERO object
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: lockdown
                                    
                                    	Not a candidate for reoptimization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sticky
                                    
                                    	Stay on the same path after change in required resources
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Override the bandwidth configured on the tunnel
                                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic.Bandwidth>`
                                    
                                    .. attribute:: attributes
                                    
                                    	Specify name of LSP attribute list
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic, self).__init__()

                                        self.yang_name = "dynamic"
                                        self.yang_parent_name = "working"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("segment-routing", ("segment_routing", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic.SegmentRouting)), ("bandwidth", ("bandwidth", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic.Bandwidth))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('pce', (YLeaf(YType.empty, 'pce'), ['Empty'])),
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                            ('lockdown', (YLeaf(YType.empty, 'lockdown'), ['Empty'])),
                                            ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                            ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                        ])
                                        self.pce = None
                                        self.address = None
                                        self.verbatim = None
                                        self.lockdown = None
                                        self.sticky = None
                                        self.attributes = None

                                        self.segment_routing = None
                                        self._children_name_map["segment_routing"] = "segment-routing"

                                        self.bandwidth = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic.Bandwidth()
                                        self.bandwidth.parent = self
                                        self._children_name_map["bandwidth"] = "bandwidth"
                                        self._segment_path = lambda: "dynamic"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic, [u'pce', u'address', u'verbatim', u'lockdown', u'sticky', u'attributes'], name, value)


                                    class SegmentRouting(Entity):
                                        """
                                        Specify segment\-routing for this pathoption
                                        
                                        .. attribute:: attributes
                                        
                                        	Specify name of LSP attribute list
                                        	**type**\: str
                                        
                                        .. attribute:: lockdown
                                        
                                        	Not a candidate for reoptimization
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: sticky
                                        
                                        	Stay on the same path after change in required resources
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: pce
                                        
                                        	Use PCE for path computation
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: address
                                        
                                        	PCE IPv4 address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: verbatim
                                        
                                        	Do not validate links from the ERO object
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic.SegmentRouting, self).__init__()

                                            self.yang_name = "segment-routing"
                                            self.yang_parent_name = "dynamic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                                ('lockdown', (YLeaf(YType.empty, 'lockdown'), ['Empty'])),
                                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                                ('pce', (YLeaf(YType.empty, 'pce'), ['Empty'])),
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                            ])
                                            self.attributes = None
                                            self.lockdown = None
                                            self.sticky = None
                                            self.pce = None
                                            self.address = None
                                            self.verbatim = None
                                            self._segment_path = lambda: "segment-routing"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic.SegmentRouting, [u'attributes', u'lockdown', u'sticky', u'pce', u'address', u'verbatim'], name, value)


                                    class Bandwidth(Entity):
                                        """
                                        Override the bandwidth configured on the tunnel
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Bandwidth requirement\: <0..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_pool
                                        
                                        	Tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic.Bandwidth, self).__init__()

                                            self.yang_name = "bandwidth"
                                            self.yang_parent_name = "dynamic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                            ])
                                            self.bandwidth = None
                                            self.sub_pool = None
                                            self._segment_path = lambda: "bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Dynamic.Bandwidth, [u'bandwidth', u'sub_pool'], name, value)


                                class Explicit(Entity):
                                    """
                                    Setup based on preconfigured path
                                    
                                    .. attribute:: identifier
                                    
                                    	Specify an IP explicit path by number\: <1..65535>
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: name
                                    
                                    	Specify an IP explicit path by name
                                    	**type**\: str
                                    
                                    .. attribute:: segment_routing
                                    
                                    	Specify segment\-routing for this pathoption
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verbatim
                                    
                                    	Send out path as is, with no checking
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attributes
                                    
                                    	Specify name of LSP attribute list
                                    	**type**\: str
                                    
                                    .. attribute:: lockdown
                                    
                                    	Not a candidate for reoptimization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sticky
                                    
                                    	Stay on the same path after change in required resources
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Override the bandwidth configured on the tunnel
                                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Explicit.Bandwidth>`
                                    
                                    

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Explicit, self).__init__()

                                        self.yang_name = "explicit"
                                        self.yang_parent_name = "working"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Explicit.Bandwidth))])
                                        self._leafs = OrderedDict([
                                            ('identifier', (YLeaf(YType.uint16, 'identifier'), ['int'])),
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('segment_routing', (YLeaf(YType.empty, 'segment-routing'), ['Empty'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                            ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                            ('lockdown', (YLeaf(YType.empty, 'lockdown'), ['Empty'])),
                                            ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                        ])
                                        self.identifier = None
                                        self.name = None
                                        self.segment_routing = None
                                        self.verbatim = None
                                        self.attributes = None
                                        self.lockdown = None
                                        self.sticky = None

                                        self.bandwidth = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Explicit.Bandwidth()
                                        self.bandwidth.parent = self
                                        self._children_name_map["bandwidth"] = "bandwidth"
                                        self._segment_path = lambda: "explicit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Explicit, [u'identifier', u'name', u'segment_routing', u'verbatim', u'attributes', u'lockdown', u'sticky'], name, value)


                                    class Bandwidth(Entity):
                                        """
                                        Override the bandwidth configured on the tunnel
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Bandwidth requirement\: <0..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_pool
                                        
                                        	Tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Explicit.Bandwidth, self).__init__()

                                            self.yang_name = "bandwidth"
                                            self.yang_parent_name = "explicit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                            ])
                                            self.bandwidth = None
                                            self.sub_pool = None
                                            self._segment_path = lambda: "bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.Explicit.Bandwidth, [u'bandwidth', u'sub_pool'], name, value)


                                class SegmentRouting(Entity):
                                    """
                                    Specify segment\-routing for this pathoption
                                    
                                    .. attribute:: lockdown
                                    
                                    	Not a candidate for reoptimization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sticky
                                    
                                    	Stay on the same path after change in required resources
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.SegmentRouting, self).__init__()

                                        self.yang_name = "segment-routing"
                                        self.yang_parent_name = "working"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('lockdown', (YLeaf(YType.empty, 'lockdown'), ['Empty'])),
                                            ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                        ])
                                        self.lockdown = None
                                        self.sticky = None
                                        self._segment_path = lambda: "segment-routing"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working.SegmentRouting, [u'lockdown', u'sticky'], name, value)


                            class Protect(Entity):
                                """
                                
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Working>`
                                
                                .. attribute:: diverse
                                
                                	Setup based on dynamically calculated diverse path
                                	**type**\:  :py:class:`Diverse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Diverse>`
                                
                                .. attribute:: explicit
                                
                                	Setup based on preconfigured path
                                	**type**\:  :py:class:`Explicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Explicit>`
                                
                                .. attribute:: list
                                
                                	A list of backup paths
                                	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.List>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect, self).__init__()

                                    self.yang_name = "protect"
                                    self.yang_parent_name = "path-option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("diverse", ("diverse", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Diverse)), ("explicit", ("explicit", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Explicit)), ("list", ("list", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.List))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.diverse = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Diverse()
                                    self.diverse.parent = self
                                    self._children_name_map["diverse"] = "diverse"

                                    self.explicit = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Explicit()
                                    self.explicit.parent = self
                                    self._children_name_map["explicit"] = "explicit"

                                    self.list = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.List()
                                    self.list.parent = self
                                    self._children_name_map["list"] = "list"
                                    self._segment_path = lambda: "protect" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect, [u'id'], name, value)


                                class Diverse(Entity):
                                    """
                                    Setup based on dynamically calculated diverse path
                                    
                                    .. attribute:: node
                                    
                                    	Use at least node diverse path
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: srlg
                                    
                                    	Use at least srlg diverse path
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: segment_routing
                                    
                                    	Specify segment\-routing for this pathoption
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: non_revertive
                                    
                                    	Diverse non\-revertive
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: pce
                                    
                                    	Use PCE for path computation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: address
                                    
                                    	PCE IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: verbatim
                                    
                                    	Do not validate links from the ERO object
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: lockdown
                                    
                                    	Not a candidate for reoptimization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attributes
                                    
                                    	Specify name of LSP attribute list
                                    	**type**\: str
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Override the bandwidth configured on the tunnel
                                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Diverse.Bandwidth>`
                                    
                                    

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Diverse, self).__init__()

                                        self.yang_name = "diverse"
                                        self.yang_parent_name = "protect"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Diverse.Bandwidth))])
                                        self._leafs = OrderedDict([
                                            ('node', (YLeaf(YType.empty, 'node'), ['Empty'])),
                                            ('srlg', (YLeaf(YType.empty, 'srlg'), ['Empty'])),
                                            ('segment_routing', (YLeaf(YType.empty, 'segment-routing'), ['Empty'])),
                                            ('non_revertive', (YLeaf(YType.empty, 'non-revertive'), ['Empty'])),
                                            ('pce', (YLeaf(YType.empty, 'pce'), ['Empty'])),
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                            ('lockdown', (YLeaf(YType.empty, 'lockdown'), ['Empty'])),
                                            ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                        ])
                                        self.node = None
                                        self.srlg = None
                                        self.segment_routing = None
                                        self.non_revertive = None
                                        self.pce = None
                                        self.address = None
                                        self.verbatim = None
                                        self.lockdown = None
                                        self.attributes = None

                                        self.bandwidth = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Diverse.Bandwidth()
                                        self.bandwidth.parent = self
                                        self._children_name_map["bandwidth"] = "bandwidth"
                                        self._segment_path = lambda: "diverse"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Diverse, [u'node', u'srlg', u'segment_routing', u'non_revertive', u'pce', u'address', u'verbatim', u'lockdown', u'attributes'], name, value)


                                    class Bandwidth(Entity):
                                        """
                                        Override the bandwidth configured on the tunnel
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Bandwidth requirement\: <0..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_pool
                                        
                                        	Tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Diverse.Bandwidth, self).__init__()

                                            self.yang_name = "bandwidth"
                                            self.yang_parent_name = "diverse"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                            ])
                                            self.bandwidth = None
                                            self.sub_pool = None
                                            self._segment_path = lambda: "bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Diverse.Bandwidth, [u'bandwidth', u'sub_pool'], name, value)


                                class Explicit(Entity):
                                    """
                                    Setup based on preconfigured path
                                    
                                    .. attribute:: identifier
                                    
                                    	Specify an IP explicit path by number\: <1..65535>
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: name
                                    
                                    	Specify an IP explicit path by name
                                    	**type**\: str
                                    
                                    .. attribute:: segment_routing
                                    
                                    	Specify segment\-routing for this pathoption
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: non_revertive
                                    
                                    	Diverse non\-revertive
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verbatim
                                    
                                    	Send out path as is, with no checking
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attributes
                                    
                                    	Specify name of LSP attribute list
                                    	**type**\: str
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Override the bandwidth configured on the tunnel
                                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Explicit.Bandwidth>`
                                    
                                    

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Explicit, self).__init__()

                                        self.yang_name = "explicit"
                                        self.yang_parent_name = "protect"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Explicit.Bandwidth))])
                                        self._leafs = OrderedDict([
                                            ('identifier', (YLeaf(YType.uint16, 'identifier'), ['int'])),
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('segment_routing', (YLeaf(YType.empty, 'segment-routing'), ['Empty'])),
                                            ('non_revertive', (YLeaf(YType.empty, 'non-revertive'), ['Empty'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                            ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                        ])
                                        self.identifier = None
                                        self.name = None
                                        self.segment_routing = None
                                        self.non_revertive = None
                                        self.verbatim = None
                                        self.attributes = None

                                        self.bandwidth = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Explicit.Bandwidth()
                                        self.bandwidth.parent = self
                                        self._children_name_map["bandwidth"] = "bandwidth"
                                        self._segment_path = lambda: "explicit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Explicit, [u'identifier', u'name', u'segment_routing', u'non_revertive', u'verbatim', u'attributes'], name, value)


                                    class Bandwidth(Entity):
                                        """
                                        Override the bandwidth configured on the tunnel
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Bandwidth requirement\: <0..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_pool
                                        
                                        	Tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Explicit.Bandwidth, self).__init__()

                                            self.yang_name = "bandwidth"
                                            self.yang_parent_name = "explicit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                            ])
                                            self.bandwidth = None
                                            self.sub_pool = None
                                            self._segment_path = lambda: "bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.Explicit.Bandwidth, [u'bandwidth', u'sub_pool'], name, value)


                                class List(Entity):
                                    """
                                    A list of backup paths
                                    
                                    .. attribute:: identifier
                                    
                                    	Specify an IP explicit path by number\: <1..65535>
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: name
                                    
                                    	Specify an IP explicit path by name
                                    	**type**\: str
                                    
                                    .. attribute:: segment_routing
                                    
                                    	Specify segment\-routing for this pathoption
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: non_revertive
                                    
                                    	Make the protect path non\-revertive
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attributes
                                    
                                    	Specify name of LSP attribute list
                                    	**type**\: str
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Override the bandwidth configured on the tunnel
                                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.List.Bandwidth>`
                                    
                                    .. attribute:: pce
                                    
                                    	Use PCE for path computation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: address
                                    
                                    	PCE IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: verbatim
                                    
                                    	Do not validate links from the ERO object
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.List, self).__init__()

                                        self.yang_name = "list"
                                        self.yang_parent_name = "protect"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.List.Bandwidth))])
                                        self._leafs = OrderedDict([
                                            ('identifier', (YLeaf(YType.uint16, 'identifier'), ['int'])),
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('segment_routing', (YLeaf(YType.empty, 'segment-routing'), ['Empty'])),
                                            ('non_revertive', (YLeaf(YType.empty, 'non-revertive'), ['Empty'])),
                                            ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                            ('pce', (YLeaf(YType.empty, 'pce'), ['Empty'])),
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                        ])
                                        self.identifier = None
                                        self.name = None
                                        self.segment_routing = None
                                        self.non_revertive = None
                                        self.attributes = None
                                        self.pce = None
                                        self.address = None
                                        self.verbatim = None

                                        self.bandwidth = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.List.Bandwidth()
                                        self.bandwidth.parent = self
                                        self._children_name_map["bandwidth"] = "bandwidth"
                                        self._segment_path = lambda: "list"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.List, [u'identifier', u'name', u'segment_routing', u'non_revertive', u'attributes', u'pce', u'address', u'verbatim'], name, value)


                                    class Bandwidth(Entity):
                                        """
                                        Override the bandwidth configured on the tunnel
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Bandwidth requirement\: <0..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_pool
                                        
                                        	Tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.List.Bandwidth, self).__init__()

                                            self.yang_name = "bandwidth"
                                            self.yang_parent_name = "list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                            ])
                                            self.bandwidth = None
                                            self.sub_pool = None
                                            self._segment_path = lambda: "bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathOption.Protect.List.Bandwidth, [u'bandwidth', u'sub_pool'], name, value)


                        class PathSelection(Entity):
                            """
                            Path Selection Configuration
                            
                            .. attribute:: metric
                            
                            	Metric Type Configuration\: < te \| igp >
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.Metric>`
                            
                            .. attribute:: invalidation
                            
                            	Path invalidation configuration
                            	**type**\:  :py:class:`Invalidation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.Invalidation>`
                            
                            .. attribute:: segment_routing
                            
                            	Segment\-routing path\-selection options
                            	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.SegmentRouting>`
                            
                            .. attribute:: cost_limit
                            
                            	Cost Limit Configuration\: <1..4294967295>
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: hop_limit
                            
                            	Cost Limit Configuration\: <1..255>
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: tiebreaker
                            
                            	Tiebreaker Configuration\: < max\-fill \| min\-fill \| random >
                            	**type**\:  :py:class:`MplsTeTiebreakerType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.MplsTeTiebreakerType>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection, self).__init__()

                                self.yang_name = "path-selection"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("invalidation", ("invalidation", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.Invalidation)), ("segment-routing", ("segment_routing", Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.SegmentRouting))])
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.enumeration, 'metric'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.Metric')])),
                                    ('cost_limit', (YLeaf(YType.uint32, 'cost-limit'), ['int'])),
                                    ('hop_limit', (YLeaf(YType.uint8, 'hop-limit'), ['int'])),
                                    ('tiebreaker', (YLeaf(YType.enumeration, 'tiebreaker'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'MplsTeTiebreakerType', '')])),
                                ])
                                self.metric = None
                                self.cost_limit = None
                                self.hop_limit = None
                                self.tiebreaker = None

                                self.invalidation = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.Invalidation()
                                self.invalidation.parent = self
                                self._children_name_map["invalidation"] = "invalidation"

                                self.segment_routing = Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.SegmentRouting()
                                self.segment_routing.parent = self
                                self._children_name_map["segment_routing"] = "segment-routing"
                                self._segment_path = lambda: "path-selection"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection, [u'metric', u'cost_limit', u'hop_limit', u'tiebreaker'], name, value)

                            class Metric(Enum):
                                """
                                Metric (Enum Class)

                                Metric Type Configuration\: < te \| igp >

                                .. data:: igp = 0

                                .. data:: te = 1

                                """

                                igp = Enum.YLeaf(0, "igp")

                                te = Enum.YLeaf(1, "te")



                            class Invalidation(Entity):
                                """
                                Path invalidation configuration
                                
                                .. attribute:: value
                                
                                	Path invalidation timer value\: <0..60000> milliseconds, (default 10000)
                                	**type**\: int
                                
                                	**range:** 0..60000
                                
                                .. attribute:: drop
                                
                                	Drop Tunnel Traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.Invalidation, self).__init__()

                                    self.yang_name = "invalidation"
                                    self.yang_parent_name = "path-selection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.int32, 'value'), ['int'])),
                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                    ])
                                    self.value = None
                                    self.drop = None
                                    self._segment_path = lambda: "invalidation"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.Invalidation, [u'value', u'drop'], name, value)


                            class SegmentRouting(Entity):
                                """
                                Segment\-routing path\-selection options
                                
                                .. attribute:: adjacency
                                
                                	Segment\-routing adjacency path\-selection type
                                	**type**\:  :py:class:`Adjacency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.SegmentRouting.Adjacency>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.SegmentRouting, self).__init__()

                                    self.yang_name = "segment-routing"
                                    self.yang_parent_name = "path-selection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('adjacency', (YLeaf(YType.enumeration, 'adjacency'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.SegmentRouting.Adjacency')])),
                                    ])
                                    self.adjacency = None
                                    self._segment_path = lambda: "segment-routing"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.PathSelection.SegmentRouting, [u'adjacency'], name, value)

                                class Adjacency(Enum):
                                    """
                                    Adjacency (Enum Class)

                                    Segment\-routing adjacency path\-selection type

                                    .. data:: protected = 0

                                    .. data:: unprotected = 1

                                    """

                                    protected = Enum.YLeaf(0, "protected")

                                    unprotected = Enum.YLeaf(1, "unprotected")



                        class Priority(Entity):
                            """
                            Tunnel priority
                            
                            .. attribute:: setup_priority
                            
                            	Setup priority\: <0..7>
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            	**mandatory**\: True
                            
                            .. attribute:: hold_priority
                            
                            	Hold priority\: <0..7>
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('setup_priority', (YLeaf(YType.uint8, 'setup-priority'), ['int'])),
                                    ('hold_priority', (YLeaf(YType.uint8, 'hold-priority'), ['int'])),
                                ])
                                self.setup_priority = None
                                self.hold_priority = None
                                self._segment_path = lambda: "priority"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.Priority, [u'setup_priority', u'hold_priority'], name, value)


                        class RecordRoute(Entity):
                            """
                            record the route used by the tunnel
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Tunnel_.Mpls.TrafficEng.RecordRoute, self).__init__()

                                self.yang_name = "record-route"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "record-route"
                                self._is_frozen = True


                class Rbscp(Entity):
                    """
                    Set tunnel RBSCP parameters
                    
                    .. attribute:: ack_split
                    
                    	ACK splitting
                    	**type**\: int
                    
                    	**range:** 1..32
                    
                    .. attribute:: delay
                    
                    	enable delay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: input_drop
                    
                    	max tunnel queue size (number of bw\*delay)
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: long_drop
                    
                    	Drop non\-transmitted packets w/excessive delay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: report
                    
                    	enable SCTP report chunk
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: window_stuff
                    
                    	Window stuffing
                    	**type**\: int
                    
                    	**range:** 1..20
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Rbscp, self).__init__()

                        self.yang_name = "rbscp"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ack_split', (YLeaf(YType.uint8, 'ack-split'), ['int'])),
                            ('delay', (YLeaf(YType.empty, 'delay'), ['Empty'])),
                            ('input_drop', (YLeaf(YType.uint8, 'input-drop'), ['int'])),
                            ('long_drop', (YLeaf(YType.empty, 'long-drop'), ['Empty'])),
                            ('report', (YLeaf(YType.empty, 'report'), ['Empty'])),
                            ('window_stuff', (YLeaf(YType.uint8, 'window-stuff'), ['int'])),
                        ])
                        self.ack_split = None
                        self.delay = None
                        self.input_drop = None
                        self.long_drop = None
                        self.report = None
                        self.window_stuff = None
                        self._segment_path = lambda: "rbscp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Rbscp, [u'ack_split', u'delay', u'input_drop', u'long_drop', u'report', u'window_stuff'], name, value)


                class SrcPort(Entity):
                    """
                    tunnel source port
                    
                    .. attribute:: port_num
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dynamic
                    
                    	Set Source Port Dynamically
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.SrcPort, self).__init__()

                        self.yang_name = "src-port"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_num', (YLeaf(YType.uint16, 'port-num'), ['int'])),
                            ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                        ])
                        self.port_num = None
                        self.dynamic = None
                        self._segment_path = lambda: "src-port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.SrcPort, [u'port_num', u'dynamic'], name, value)


                class Udlr(Entity):
                    """
                    associate tunnel with unidirectional interface
                    
                    .. attribute:: address_resolution
                    
                    	Enable ARP and NHRP over a UDLR Tunnel
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: receive_only
                    
                    	Tunnel is receive\-only capable
                    	**type**\: str
                    
                    .. attribute:: send_only
                    
                    	Tunnel is send\-only capable
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Udlr, self).__init__()

                        self.yang_name = "udlr"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address_resolution', (YLeaf(YType.empty, 'address-resolution'), ['Empty'])),
                            ('receive_only', (YLeaf(YType.str, 'receive-only'), ['str'])),
                            ('send_only', (YLeaf(YType.str, 'send-only'), ['str'])),
                        ])
                        self.address_resolution = None
                        self.receive_only = None
                        self.send_only = None
                        self._segment_path = lambda: "udlr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Udlr, [u'address_resolution', u'receive_only', u'send_only'], name, value)


                class Vlan(Entity):
                    """
                    Set vlan\-id for ethernet over gre mode
                    
                    .. attribute:: id1
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hyphen
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: id2
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Tunnel_.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id1', (YLeaf(YType.uint16, 'id1'), ['int'])),
                            ('hyphen', (YLeaf(YType.empty, 'hyphen'), ['Empty'])),
                            ('id2', (YLeaf(YType.uint16, 'id2'), ['int'])),
                        ])
                        self.id1 = None
                        self.hyphen = None
                        self.id2 = None
                        self._segment_path = lambda: "vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Tunnel_.Vlan, [u'id1', u'hyphen', u'id2'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Tunnel.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.Tunnel.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.Tunnel.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.Tunnel.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.Tunnel.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Tunnel.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.Tunnel.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Tunnel.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Utd, ['enable'], name, value)


            class Lisp(Entity):
                """
                Locator/ID Separation Protocol
                
                .. attribute:: extended_subnet_mode
                
                	Configures to enable extended subnet mode on the interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobility
                
                	Configures to allow EID mobility on interface
                	**type**\:  :py:class:`Mobility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Lisp.Mobility>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Interface.Tunnel.Lisp, self).__init__()

                    self.yang_name = "lisp"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mobility", ("mobility", Native.Interface.Tunnel.Lisp.Mobility))])
                    self._leafs = OrderedDict([
                        ('extended_subnet_mode', (YLeaf(YType.empty, 'extended-subnet-mode'), ['Empty'])),
                    ])
                    self.extended_subnet_mode = None

                    self.mobility = Native.Interface.Tunnel.Lisp.Mobility()
                    self.mobility.parent = self
                    self._children_name_map["mobility"] = "mobility"
                    self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Lisp, ['extended_subnet_mode'], name, value)


                class Mobility(Entity):
                    """
                    Configures to allow EID mobility on interface
                    
                    .. attribute:: dynamic_eid
                    
                    	
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Lisp.Mobility.DynamicEid>`
                    
                    .. attribute:: discover
                    
                    	Configure mobility dynamic EID discover settings
                    	**type**\:  :py:class:`Discover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Lisp.Mobility.Discover>`
                    
                    .. attribute:: liveness
                    
                    	Configure mobility liveness settings
                    	**type**\:  :py:class:`Liveness <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Lisp.Mobility.Liveness>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Lisp.Mobility, self).__init__()

                        self.yang_name = "mobility"
                        self.yang_parent_name = "lisp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic-eid", ("dynamic_eid", Native.Interface.Tunnel.Lisp.Mobility.DynamicEid)), ("discover", ("discover", Native.Interface.Tunnel.Lisp.Mobility.Discover)), ("liveness", ("liveness", Native.Interface.Tunnel.Lisp.Mobility.Liveness))])
                        self._leafs = OrderedDict()

                        self.discover = Native.Interface.Tunnel.Lisp.Mobility.Discover()
                        self.discover.parent = self
                        self._children_name_map["discover"] = "discover"

                        self.liveness = Native.Interface.Tunnel.Lisp.Mobility.Liveness()
                        self.liveness.parent = self
                        self._children_name_map["liveness"] = "liveness"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "mobility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Lisp.Mobility, [], name, value)


                    class DynamicEid(Entity):
                        """
                        
                        
                        .. attribute:: dynamic_eid_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: nbr_proxy_reply
                        
                        	Neighbor proxy reply behavior for dynamic EID group
                        	**type**\:  :py:class:`NbrProxyReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Lisp.Mobility.DynamicEid.NbrProxyReply>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Lisp.Mobility.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dynamic_eid_name']
                            self._child_classes = OrderedDict([("nbr-proxy-reply", ("nbr_proxy_reply", Native.Interface.Tunnel.Lisp.Mobility.DynamicEid.NbrProxyReply))])
                            self._leafs = OrderedDict([
                                ('dynamic_eid_name', (YLeaf(YType.str, 'dynamic-eid-name'), ['str'])),
                            ])
                            self.dynamic_eid_name = None

                            self.nbr_proxy_reply = None
                            self._children_name_map["nbr_proxy_reply"] = "nbr-proxy-reply"
                            self._segment_path = lambda: "dynamic-eid" + "[dynamic-eid-name='" + str(self.dynamic_eid_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Lisp.Mobility.DynamicEid, ['dynamic_eid_name'], name, value)


                        class NbrProxyReply(Entity):
                            """
                            Neighbor proxy reply behavior for dynamic EID group
                            
                            .. attribute:: requests
                            
                            	Send neighbor proxy reply after reaching request threshold
                            	**type**\: int
                            
                            	**range:** 0..5
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Lisp.Mobility.DynamicEid.NbrProxyReply, self).__init__()

                                self.yang_name = "nbr-proxy-reply"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('requests', (YLeaf(YType.uint8, 'requests'), ['int'])),
                                ])
                                self.requests = None
                                self._segment_path = lambda: "nbr-proxy-reply"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Lisp.Mobility.DynamicEid.NbrProxyReply, ['requests'], name, value)


                    class Discover(Entity):
                        """
                        Configure mobility dynamic EID discover settings
                        
                        .. attribute:: arp
                        
                        	Dynamic EID discover through ARP events on this interface
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Lisp.Mobility.Discover, self).__init__()

                            self.yang_name = "discover"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                            ])
                            self.arp = None
                            self._segment_path = lambda: "discover"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Lisp.Mobility.Discover, ['arp'], name, value)


                    class Liveness(Entity):
                        """
                        Configure mobility liveness settings
                        
                        .. attribute:: test
                        
                        	Perform liveness test on dynamic\-EID discovered on this interface
                        	**type**\: bool
                        
                        .. attribute:: ttl
                        
                        	Configures the TTL in the liveness test packet
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Lisp.Mobility.Liveness, self).__init__()

                            self.yang_name = "liveness"
                            self.yang_parent_name = "mobility"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('test', (YLeaf(YType.boolean, 'test'), ['bool'])),
                                ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                            ])
                            self.test = None
                            self.ttl = None
                            self._segment_path = lambda: "liveness"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Lisp.Mobility.Liveness, ['test', 'ttl'], name, value)


            class Cdp(Entity):
                """
                CDP interface subcommands
                
                .. attribute:: enable
                
                	Enable CDP on interface
                	**type**\: bool
                
                .. attribute:: tlv
                
                	Enable exchange of specific tlv information
                	**type**\:  :py:class:`Tlv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cdp.Tlv>`
                
                

                """

                _prefix = 'ios-cdp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.Tunnel.Cdp, self).__init__()

                    self.yang_name = "cdp"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tlv", ("tlv", Native.Interface.Tunnel.Cdp.Tlv))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                    ])
                    self.enable = None

                    self.tlv = Native.Interface.Tunnel.Cdp.Tlv()
                    self.tlv.parent = self
                    self._children_name_map["tlv"] = "tlv"
                    self._segment_path = lambda: "Cisco-IOS-XE-cdp:cdp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Cdp, ['enable'], name, value)


                class Tlv(Entity):
                    """
                    Enable exchange of specific tlv information
                    
                    .. attribute:: app
                    
                    	Enable/Configure Application TLV
                    	**type**\:  :py:class:`App <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cdp.Tlv.App>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: server_location
                    
                    	Enable CDP location server on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	Exchange location information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cdp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Cdp.Tlv, self).__init__()

                        self.yang_name = "tlv"
                        self.yang_parent_name = "cdp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("app", ("app", Native.Interface.Tunnel.Cdp.Tlv.App))])
                        self._leafs = OrderedDict([
                            ('server_location', (YLeaf(YType.empty, 'server-location'), ['Empty'])),
                            ('location', (YLeaf(YType.empty, 'location'), ['Empty'])),
                        ])
                        self.server_location = None
                        self.location = None

                        self.app = None
                        self._children_name_map["app"] = "app"
                        self._segment_path = lambda: "tlv"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Cdp.Tlv, ['server_location', 'location'], name, value)


                    class App(Entity):
                        """
                        Enable/Configure Application TLV
                        
                        .. attribute:: tlvtype
                        
                        	Configure APP TLV
                        	**type**\: int
                        
                        	**range:** 1001..65535
                        
                        .. attribute:: value
                        
                        	Configure App TLV Value information
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cdp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Cdp.Tlv.App, self).__init__()

                            self.yang_name = "app"
                            self.yang_parent_name = "tlv"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tlvtype', (YLeaf(YType.uint16, 'tlvtype'), ['int'])),
                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                            ])
                            self.tlvtype = None
                            self.value = None
                            self._segment_path = lambda: "app"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Cdp.Tlv.App, ['tlvtype', 'value'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Tunnel.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.Tunnel.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.Tunnel.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.Tunnel.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.Tunnel.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class Performance(Entity):
                """
                Global performance monitor configuration
                
                .. attribute:: monitor
                
                	monitor
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Performance.Monitor>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.Tunnel.Performance, self).__init__()

                    self.yang_name = "performance"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitor", ("monitor", Native.Interface.Tunnel.Performance.Monitor))])
                    self._leafs = OrderedDict()

                    self.monitor = Native.Interface.Tunnel.Performance.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"
                    self._segment_path = lambda: "Cisco-IOS-XE-ezpm:performance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Performance, [], name, value)


                class Monitor(Entity):
                    """
                    monitor
                    
                    .. attribute:: context
                    
                    	Select ezPM context
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Performance.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "performance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('context', (YLeafList(YType.str, 'context'), ['str'])),
                        ])
                        self.context = []
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Performance.Monitor, ['context'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.Tunnel.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Umbrella, ['out', 'in_'], name, value)


            class Ospfv3(Entity):
                """
                OSPFv3 interface commands
                
                .. attribute:: process_id
                
                	
                	**type**\: list of  		 :py:class:`ProcessId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId>`
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Authentication>`
                
                .. attribute:: bfd
                
                	Enable BFD on this interface
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: cost
                
                	Route cost of this interface
                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Cost>`
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.DatabaseFilter>`
                
                .. attribute:: dead_interval
                
                	Interval after which a neighbor is declared dead
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: demand_circuit
                
                	OSPF Demand Circuit
                	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.DemandCircuit>`
                
                	**presence node**\: True
                
                .. attribute:: encryption
                
                	Enable encryption
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption>`
                
                .. attribute:: flood_reduction
                
                	OSPF Flood Reduction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hello_interval
                
                	Time between HELLO packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: manet
                
                	Mobile Adhoc Networking options
                	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Manet>`
                
                .. attribute:: mtu_ignore
                
                	Ignores the MTU in DBD packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: multi_area
                
                	Set the OSPF multi\-area ID
                	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.MultiArea>`
                
                .. attribute:: neighbor
                
                	OSPF neighbor
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Neighbor>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Network>`
                
                .. attribute:: prefix_suppression
                
                	OSPF prefix suppression
                	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.PrefixSuppression>`
                
                	**presence node**\: True
                
                .. attribute:: priority
                
                	Router priority
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: retransmit_interval
                
                	Time between retransmitting lost link state advertisements
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Shut down the interface in OSPFv3
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: transmit_delay
                
                	Link state transmit delay
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Tunnel.Ospfv3, self).__init__()

                    self.yang_name = "ospfv3"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("process-id", ("process_id", Native.Interface.Tunnel.Ospfv3.ProcessId)), ("authentication", ("authentication", Native.Interface.Tunnel.Ospfv3.Authentication)), ("bfd", ("bfd", Native.Interface.Tunnel.Ospfv3.Bfd)), ("cost", ("cost", Native.Interface.Tunnel.Ospfv3.Cost)), ("database-filter", ("database_filter", Native.Interface.Tunnel.Ospfv3.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.Tunnel.Ospfv3.DemandCircuit)), ("encryption", ("encryption", Native.Interface.Tunnel.Ospfv3.Encryption)), ("manet", ("manet", Native.Interface.Tunnel.Ospfv3.Manet)), ("multi-area", ("multi_area", Native.Interface.Tunnel.Ospfv3.MultiArea)), ("neighbor", ("neighbor", Native.Interface.Tunnel.Ospfv3.Neighbor)), ("network", ("network", Native.Interface.Tunnel.Ospfv3.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.Tunnel.Ospfv3.PrefixSuppression))])
                    self._leafs = OrderedDict([
                        ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                        ('flood_reduction', (YLeaf(YType.empty, 'flood-reduction'), ['Empty'])),
                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                        ('mtu_ignore', (YLeaf(YType.empty, 'mtu-ignore'), ['Empty'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                    ])
                    self.dead_interval = None
                    self.flood_reduction = None
                    self.hello_interval = None
                    self.mtu_ignore = None
                    self.priority = None
                    self.retransmit_interval = None
                    self.shutdown = None
                    self.transmit_delay = None

                    self.authentication = Native.Interface.Tunnel.Ospfv3.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"

                    self.cost = Native.Interface.Tunnel.Ospfv3.Cost()
                    self.cost.parent = self
                    self._children_name_map["cost"] = "cost"

                    self.database_filter = Native.Interface.Tunnel.Ospfv3.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"

                    self.demand_circuit = None
                    self._children_name_map["demand_circuit"] = "demand-circuit"

                    self.encryption = Native.Interface.Tunnel.Ospfv3.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.manet = Native.Interface.Tunnel.Ospfv3.Manet()
                    self.manet.parent = self
                    self._children_name_map["manet"] = "manet"

                    self.multi_area = Native.Interface.Tunnel.Ospfv3.MultiArea()
                    self.multi_area.parent = self
                    self._children_name_map["multi_area"] = "multi-area"

                    self.network = Native.Interface.Tunnel.Ospfv3.Network()
                    self.network.parent = self
                    self._children_name_map["network"] = "network"

                    self.prefix_suppression = None
                    self._children_name_map["prefix_suppression"] = "prefix-suppression"

                    self.process_id = YList(self)
                    self.neighbor = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3, ['dead_interval', u'flood_reduction', 'hello_interval', u'mtu_ignore', 'priority', 'retransmit_interval', u'shutdown', 'transmit_delay'], name, value)


                class ProcessId(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Enable authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Enable BFD on this interface
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cost
                    
                    	Route cost of this interface
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Cost>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.DatabaseFilter>`
                    
                    .. attribute:: dead_interval
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: demand_circuit
                    
                    	OSPF demand circuit
                    	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.DemandCircuit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flood_reduction
                    
                    	OSPF Flood Reduction
                    	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.FloodReduction>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: hello_interval
                    
                    	Time between HELLO packets
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: manet
                    
                    	Mobile Adhoc Networking options
                    	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Manet>`
                    
                    .. attribute:: mtu_ignore
                    
                    	Ignores the MTU in DBD packets
                    	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.MtuIgnore>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: multi_area
                    
                    	Set the OSPF multi\-area ID
                    	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.MultiArea>`
                    
                    .. attribute:: neighbor
                    
                    	OSPF neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Network type
                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Network>`
                    
                    .. attribute:: prefix_suppression
                    
                    	OSPF prefix suppression
                    	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.PrefixSuppression>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Router priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: retransmit_interval
                    
                    	Time between retransmitting lost link state advertisements
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: shutdown
                    
                    	Shut down the interface in OSPFv3
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Shutdown>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transmit_delay
                    
                    	Link state transmit delay
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: ipv4
                    
                    	Specify parameters for IPv4
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Specify parameters for IPv6
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.ProcessId, self).__init__()

                        self.yang_name = "process-id"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Tunnel.Ospfv3.ProcessId.Authentication)), ("bfd", ("bfd", Native.Interface.Tunnel.Ospfv3.ProcessId.Bfd)), ("cost", ("cost", Native.Interface.Tunnel.Ospfv3.ProcessId.Cost)), ("database-filter", ("database_filter", Native.Interface.Tunnel.Ospfv3.ProcessId.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.Tunnel.Ospfv3.ProcessId.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.Tunnel.Ospfv3.ProcessId.FloodReduction)), ("manet", ("manet", Native.Interface.Tunnel.Ospfv3.ProcessId.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.Tunnel.Ospfv3.ProcessId.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.Tunnel.Ospfv3.ProcessId.MultiArea)), ("neighbor", ("neighbor", Native.Interface.Tunnel.Ospfv3.ProcessId.Neighbor)), ("network", ("network", Native.Interface.Tunnel.Ospfv3.ProcessId.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.Tunnel.Ospfv3.ProcessId.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.Tunnel.Ospfv3.ProcessId.Shutdown)), ("ipv4", ("ipv4", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4)), ("ipv6", ("ipv6", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                            ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                        ])
                        self.id = None
                        self.dead_interval = None
                        self.hello_interval = None
                        self.priority = None
                        self.retransmit_interval = None
                        self.transmit_delay = None

                        self.authentication = Native.Interface.Tunnel.Ospfv3.ProcessId.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"

                        self.cost = Native.Interface.Tunnel.Ospfv3.ProcessId.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.database_filter = Native.Interface.Tunnel.Ospfv3.ProcessId.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"

                        self.demand_circuit = None
                        self._children_name_map["demand_circuit"] = "demand-circuit"

                        self.flood_reduction = None
                        self._children_name_map["flood_reduction"] = "flood-reduction"

                        self.manet = Native.Interface.Tunnel.Ospfv3.ProcessId.Manet()
                        self.manet.parent = self
                        self._children_name_map["manet"] = "manet"

                        self.mtu_ignore = None
                        self._children_name_map["mtu_ignore"] = "mtu-ignore"

                        self.multi_area = Native.Interface.Tunnel.Ospfv3.ProcessId.MultiArea()
                        self.multi_area.parent = self
                        self._children_name_map["multi_area"] = "multi-area"

                        self.network = Native.Interface.Tunnel.Ospfv3.ProcessId.Network()
                        self.network.parent = self
                        self._children_name_map["network"] = "network"

                        self.prefix_suppression = None
                        self._children_name_map["prefix_suppression"] = "prefix-suppression"

                        self.shutdown = None
                        self._children_name_map["shutdown"] = "shutdown"

                        self.ipv4 = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "process-id" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId, [u'id', 'dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Enable authentication
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\: str
                        
                        .. attribute:: null
                        
                        	Use no authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.null = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Authentication, [u'key_chain', u'null'], name, value)


                    class Bfd(Entity):
                        """
                        Enable BFD on this interface
                        
                        .. attribute:: disable
                        
                        	Disable BFD on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Bfd, ['disable'], name, value)


                    class Cost(Entity):
                        """
                        Route cost of this interface
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: dynamic
                        
                        	Specify dynamic cost options
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ])
                            self.value = None

                            self.dynamic = None
                            self._children_name_map["dynamic"] = "dynamic"
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost, [u'value'], name, value)


                        class Dynamic(Entity):
                            """
                            Specify dynamic cost options
                            
                            .. attribute:: default
                            
                            	Specify default link metric value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: hysteresis
                            
                            	Specify hysteresis value for LSA dampening
                            	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: weight
                            
                            	Specify weight to be placed on individual metrics
                            	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ])
                                self.default = None

                                self.hysteresis = None
                                self._children_name_map["hysteresis"] = "hysteresis"

                                self.weight = Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight()
                                self.weight.parent = self
                                self._children_name_map["weight"] = "weight"
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic, [u'default'], name, value)


                            class Hysteresis(Entity):
                                """
                                Specify hysteresis value for LSA dampening
                                
                                .. attribute:: percent
                                
                                	Specify hysteresis percent changed
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold
                                
                                	Specify hysteresis threshold value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, self).__init__()

                                    self.yang_name = "hysteresis"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "hysteresis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                            class Weight(Entity):
                                """
                                Specify weight to be placed on individual metrics
                                
                                .. attribute:: l2_factor
                                
                                	Specify weight to be given to L2\-factor metric
                                	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: latency
                                
                                	Specify weight to be given to latency metric
                                	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: resources
                                
                                	Specify weight to be given to resources metric
                                	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: throughput
                                
                                	Specify weight to be given to throughput metric
                                	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight, self).__init__()

                                    self.yang_name = "weight"
                                    self.yang_parent_name = "dynamic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput))])
                                    self._leafs = OrderedDict()

                                    self.l2_factor = None
                                    self._children_name_map["l2_factor"] = "L2-factor"

                                    self.latency = None
                                    self._children_name_map["latency"] = "latency"

                                    self.resources = None
                                    self._children_name_map["resources"] = "resources"

                                    self.throughput = None
                                    self._children_name_map["throughput"] = "throughput"
                                    self._segment_path = lambda: "weight"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight, [], name, value)


                                class L2Factor(Entity):
                                    """
                                    Specify weight to be given to L2\-factor metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                        self.yang_name = "L2-factor"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "L2-factor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                class Latency(Entity):
                                    """
                                    Specify weight to be given to latency metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, self).__init__()

                                        self.yang_name = "latency"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "latency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                class Resources(Entity):
                                    """
                                    Specify weight to be given to resources metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, self).__init__()

                                        self.yang_name = "resources"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "resources"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                class Throughput(Entity):
                                    """
                                    Specify weight to be given to throughput metric
                                    
                                    .. attribute:: value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, self).__init__()

                                        self.yang_name = "throughput"
                                        self.yang_parent_name = "weight"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                        ])
                                        self.value = None
                                        self._segment_path = lambda: "throughput"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.DatabaseFilter.All>`
                        
                        .. attribute:: disable
                        
                        	Disable LSA Filter on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.ProcessId.DatabaseFilter.All')])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.all = None
                            self.disable = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.DatabaseFilter, [u'all', u'disable'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                    class DemandCircuit(Entity):
                        """
                        OSPF demand circuit
                        
                        .. attribute:: disable
                        
                        	Disable demand circuit on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore demand circuit auto\-negotiation requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.DemandCircuit, self).__init__()

                            self.yang_name = "demand-circuit"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.disable = None
                            self.ignore = None
                            self._segment_path = lambda: "demand-circuit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.DemandCircuit, [u'disable', u'ignore'], name, value)


                    class FloodReduction(Entity):
                        """
                        OSPF Flood Reduction
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.FloodReduction, self).__init__()

                            self.yang_name = "flood-reduction"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flood-reduction"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.FloodReduction, [u'disable'], name, value)


                    class Manet(Entity):
                        """
                        Mobile Adhoc Networking options
                        
                        .. attribute:: peering
                        
                        	MANET Peering options
                        	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Manet.Peering>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Manet, self).__init__()

                            self.yang_name = "manet"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.Tunnel.Ospfv3.ProcessId.Manet.Peering))])
                            self._leafs = OrderedDict()

                            self.peering = Native.Interface.Tunnel.Ospfv3.ProcessId.Manet.Peering()
                            self.peering.parent = self
                            self._children_name_map["peering"] = "peering"
                            self._segment_path = lambda: "manet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Manet, [], name, value)


                        class Peering(Entity):
                            """
                            MANET Peering options
                            
                            .. attribute:: cost
                            
                            	Redundant path cost improvement required to peer
                            	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Manet.Peering.Cost>`
                            
                            .. attribute:: link_metrics
                            
                            	Require link metrics
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Manet.Peering, self).__init__()

                                self.yang_name = "peering"
                                self.yang_parent_name = "manet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.Tunnel.Ospfv3.ProcessId.Manet.Peering.Cost))])
                                self._leafs = OrderedDict([
                                    ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                ])
                                self.link_metrics = None

                                self.cost = Native.Interface.Tunnel.Ospfv3.ProcessId.Manet.Peering.Cost()
                                self.cost.parent = self
                                self._children_name_map["cost"] = "cost"
                                self._segment_path = lambda: "peering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Manet.Peering, [u'link_metrics'], name, value)


                            class Cost(Entity):
                                """
                                Redundant path cost improvement required to peer
                                
                                .. attribute:: percent
                                
                                	Relative incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                .. attribute:: threshold
                                
                                	Absolute incremental path cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.ProcessId.Manet.Peering.Cost, self).__init__()

                                    self.yang_name = "cost"
                                    self.yang_parent_name = "peering"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                    ])
                                    self.percent = None
                                    self.threshold = None
                                    self._segment_path = lambda: "cost"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                    class MtuIgnore(Entity):
                        """
                        Ignores the MTU in DBD packets
                        
                        .. attribute:: disable
                        
                        	Disable Ingore MTU on this interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.MtuIgnore, self).__init__()

                            self.yang_name = "mtu-ignore"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "mtu-ignore"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.MtuIgnore, [u'disable'], name, value)


                    class MultiArea(Entity):
                        """
                        Set the OSPF multi\-area ID
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: disable
                        
                        	disable OSPF multi\-area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.MultiArea, self).__init__()

                            self.yang_name = "multi-area"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.disable = None
                            self._segment_path = lambda: "multi-area"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.MultiArea, [u'id', u'cost', u'disable'], name, value)


                    class Neighbor(Entity):
                        """
                        OSPF neighbor
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: cost
                        
                        	OSPF cost for point\-to\-multipoint neighbor
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Neighbor.DatabaseFilter>`
                        
                        .. attribute:: poll_interval
                        
                        	OSPF dead\-router polling interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	OSPF priority of non\-broadcast neighbor
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.Tunnel.Ospfv3.ProcessId.Neighbor.DatabaseFilter))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.id = None
                            self.cost = None
                            self.poll_interval = None
                            self.priority = None

                            self.database_filter = Native.Interface.Tunnel.Ospfv3.ProcessId.Neighbor.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Neighbor.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.ProcessId.Neighbor.DatabaseFilter.All')])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Neighbor.DatabaseFilter, ['all'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                    class Network(Entity):
                        """
                        Network type
                        
                        .. attribute:: broadcast
                        
                        	Specify OSPF broadcast multi\-access network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF interface type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_broadcast
                        
                        	Specify OSPF NBMA network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: point_to_multipoint
                        
                        	Specify OSPF point\-to\-multipoint network
                        	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Network.PointToMultipoint>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: point_to_point
                        
                        	Specify OSPF point\-to\-point network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.Tunnel.Ospfv3.ProcessId.Network.PointToMultipoint))])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                            ])
                            self.broadcast = None
                            self.manet = None
                            self.non_broadcast = None
                            self.point_to_point = None

                            self.point_to_multipoint = None
                            self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                            self._segment_path = lambda: "network"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                        class PointToMultipoint(Entity):
                            """
                            Specify OSPF point\-to\-multipoint network
                            
                            .. attribute:: non_broadcast
                            
                            	Specify non\-broadcast point\-to\-mpoint network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Network.PointToMultipoint, self).__init__()

                                self.yang_name = "point-to-multipoint"
                                self.yang_parent_name = "network"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                ])
                                self.non_broadcast = None
                                self._segment_path = lambda: "point-to-multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Network.PointToMultipoint, ['non_broadcast'], name, value)


                    class PrefixSuppression(Entity):
                        """
                        OSPF prefix suppression
                        
                        .. attribute:: disable
                        
                        	Disable prefix suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.PrefixSuppression, self).__init__()

                            self.yang_name = "prefix-suppression"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "prefix-suppression"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.PrefixSuppression, ['disable'], name, value)


                    class Shutdown(Entity):
                        """
                        Shut down the interface in OSPFv3
                        
                        .. attribute:: disable
                        
                        	Disable inherited shutdown
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "shutdown"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Shutdown, [u'disable'], name, value)


                    class Ipv4(Entity):
                        """
                        Specify parameters for IPv4
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Area)), ("authentication", ("authentication", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Authentication)), ("bfd", ("bfd", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Bfd)), ("cost", ("cost", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost)), ("database-filter", ("database_filter", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.FloodReduction)), ("manet", ("manet", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.MultiArea)), ("neighbor", ("neighbor", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Neighbor)), ("network", ("network", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 64..95
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.ProcessId.Ipv4.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv4.Shutdown, [u'disable'], name, value)


                    class Ipv6(Entity):
                        """
                        Specify parameters for IPv6
                        
                        .. attribute:: area
                        
                        	Set the OSPF area ID
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Area>`
                        
                        .. attribute:: authentication
                        
                        	Enable authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Enable BFD on this interface
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cost
                        
                        	Route cost of this interface
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.DatabaseFilter>`
                        
                        .. attribute:: dead_interval
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: demand_circuit
                        
                        	OSPF demand circuit
                        	**type**\:  :py:class:`DemandCircuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.DemandCircuit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: flood_reduction
                        
                        	OSPF Flood Reduction
                        	**type**\:  :py:class:`FloodReduction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.FloodReduction>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: hello_interval
                        
                        	Time between HELLO packets
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: manet
                        
                        	Mobile Adhoc Networking options
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet>`
                        
                        .. attribute:: mtu_ignore
                        
                        	Ignores the MTU in DBD packets
                        	**type**\:  :py:class:`MtuIgnore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.MtuIgnore>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: multi_area
                        
                        	Set the OSPF multi\-area ID
                        	**type**\:  :py:class:`MultiArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.MultiArea>`
                        
                        .. attribute:: neighbor
                        
                        	OSPF neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Network type
                        	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Network>`
                        
                        .. attribute:: prefix_suppression
                        
                        	OSPF prefix suppression
                        	**type**\:  :py:class:`PrefixSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.PrefixSuppression>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Router priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retransmit_interval
                        
                        	Time between retransmitting lost link state advertisements
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: shutdown
                        
                        	Shut down the interface in OSPFv3
                        	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Shutdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: transmit_delay
                        
                        	Link state transmit delay
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "process-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Area)), ("authentication", ("authentication", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Authentication)), ("bfd", ("bfd", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Bfd)), ("cost", ("cost", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost)), ("database-filter", ("database_filter", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.DatabaseFilter)), ("demand-circuit", ("demand_circuit", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.DemandCircuit)), ("flood-reduction", ("flood_reduction", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.FloodReduction)), ("manet", ("manet", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet)), ("mtu-ignore", ("mtu_ignore", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.MtuIgnore)), ("multi-area", ("multi_area", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.MultiArea)), ("neighbor", ("neighbor", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Neighbor)), ("network", ("network", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Network)), ("prefix-suppression", ("prefix_suppression", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.PrefixSuppression)), ("shutdown", ("shutdown", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Shutdown))])
                            self._leafs = OrderedDict([
                                ('dead_interval', (YLeaf(YType.uint16, 'dead-interval'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('retransmit_interval', (YLeaf(YType.uint32, 'retransmit-interval'), ['int'])),
                                ('transmit_delay', (YLeaf(YType.uint32, 'transmit-delay'), ['int'])),
                            ])
                            self.dead_interval = None
                            self.hello_interval = None
                            self.priority = None
                            self.retransmit_interval = None
                            self.transmit_delay = None

                            self.authentication = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"

                            self.cost = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"

                            self.database_filter = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.DatabaseFilter()
                            self.database_filter.parent = self
                            self._children_name_map["database_filter"] = "database-filter"

                            self.demand_circuit = None
                            self._children_name_map["demand_circuit"] = "demand-circuit"

                            self.flood_reduction = None
                            self._children_name_map["flood_reduction"] = "flood-reduction"

                            self.manet = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.mtu_ignore = None
                            self._children_name_map["mtu_ignore"] = "mtu-ignore"

                            self.multi_area = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.MultiArea()
                            self.multi_area.parent = self
                            self._children_name_map["multi_area"] = "multi-area"

                            self.network = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Network()
                            self.network.parent = self
                            self._children_name_map["network"] = "network"

                            self.prefix_suppression = None
                            self._children_name_map["prefix_suppression"] = "prefix-suppression"

                            self.shutdown = None
                            self._children_name_map["shutdown"] = "shutdown"

                            self.area = YList(self)
                            self.neighbor = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6, ['dead_interval', 'hello_interval', 'priority', 'retransmit_interval', 'transmit_delay'], name, value)


                        class Area(Entity):
                            """
                            Set the OSPF area ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: instance
                            
                            	Set the OSPF instance
                            	**type**\: int
                            
                            	**range:** 0..31
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('instance', (YLeaf(YType.uint8, 'instance'), ['int'])),
                                ])
                                self.id = None
                                self.instance = None
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Area, [u'id', u'instance'], name, value)


                        class Authentication(Entity):
                            """
                            Enable authentication
                            
                            .. attribute:: key_chain
                            
                            	Use a key\-chain for cryptographic authentication keys
                            	**type**\: str
                            
                            .. attribute:: null
                            
                            	Use no authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.null = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Authentication, [u'key_chain', u'null'], name, value)


                        class Bfd(Entity):
                            """
                            Enable BFD on this interface
                            
                            .. attribute:: disable
                            
                            	Disable BFD on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Bfd, ['disable'], name, value)


                        class Cost(Entity):
                            """
                            Route cost of this interface
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: dynamic
                            
                            	Specify dynamic cost options
                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.dynamic = None
                                self._children_name_map["dynamic"] = "dynamic"
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost, [u'value'], name, value)


                            class Dynamic(Entity):
                                """
                                Specify dynamic cost options
                                
                                .. attribute:: default
                                
                                	Specify default link metric value
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: hysteresis
                                
                                	Specify hysteresis value for LSA dampening
                                	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: weight
                                
                                	Specify weight to be placed on individual metrics
                                	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, self).__init__()

                                    self.yang_name = "dynamic"
                                    self.yang_parent_name = "cost"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                    ])
                                    self.default = None

                                    self.hysteresis = None
                                    self._children_name_map["hysteresis"] = "hysteresis"

                                    self.weight = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight()
                                    self.weight.parent = self
                                    self._children_name_map["weight"] = "weight"
                                    self._segment_path = lambda: "dynamic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic, [u'default'], name, value)


                                class Hysteresis(Entity):
                                    """
                                    Specify hysteresis value for LSA dampening
                                    
                                    .. attribute:: percent
                                    
                                    	Specify hysteresis percent changed
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Specify hysteresis threshold value
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, self).__init__()

                                        self.yang_name = "hysteresis"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "hysteresis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                                class Weight(Entity):
                                    """
                                    Specify weight to be placed on individual metrics
                                    
                                    .. attribute:: l2_factor
                                    
                                    	Specify weight to be given to L2\-factor metric
                                    	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: latency
                                    
                                    	Specify weight to be given to latency metric
                                    	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: resources
                                    
                                    	Specify weight to be given to resources metric
                                    	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: throughput
                                    
                                    	Specify weight to be given to throughput metric
                                    	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, self).__init__()

                                        self.yang_name = "weight"
                                        self.yang_parent_name = "dynamic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput))])
                                        self._leafs = OrderedDict()

                                        self.l2_factor = None
                                        self._children_name_map["l2_factor"] = "L2-factor"

                                        self.latency = None
                                        self._children_name_map["latency"] = "latency"

                                        self.resources = None
                                        self._children_name_map["resources"] = "resources"

                                        self.throughput = None
                                        self._children_name_map["throughput"] = "throughput"
                                        self._segment_path = lambda: "weight"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight, [], name, value)


                                    class L2Factor(Entity):
                                        """
                                        Specify weight to be given to L2\-factor metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                            self.yang_name = "L2-factor"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "L2-factor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                                    class Latency(Entity):
                                        """
                                        Specify weight to be given to latency metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, self).__init__()

                                            self.yang_name = "latency"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "latency"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                                    class Resources(Entity):
                                        """
                                        Specify weight to be given to resources metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, self).__init__()

                                            self.yang_name = "resources"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "resources"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                                    class Throughput(Entity):
                                        """
                                        Specify weight to be given to throughput metric
                                        
                                        .. attribute:: value
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, self).__init__()

                                            self.yang_name = "throughput"
                                            self.yang_parent_name = "weight"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                            ])
                                            self.value = None
                                            self._segment_path = lambda: "throughput"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                        class DatabaseFilter(Entity):
                            """
                            Filter OSPF LSA during synchronization and flooding
                            
                            .. attribute:: all
                            
                            	Filter all LSA
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All>`
                            
                            .. attribute:: disable
                            
                            	Disable LSA Filter on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.DatabaseFilter, self).__init__()

                                self.yang_name = "database-filter"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.ProcessId.Ipv6.DatabaseFilter.All')])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.all = None
                                self.disable = None
                                self._segment_path = lambda: "database-filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.DatabaseFilter, [u'all', u'disable'], name, value)

                            class All(Enum):
                                """
                                All (Enum Class)

                                Filter all LSA

                                .. data:: out = 0

                                """

                                out = Enum.YLeaf(0, "out")



                        class DemandCircuit(Entity):
                            """
                            OSPF demand circuit
                            
                            .. attribute:: disable
                            
                            	Disable demand circuit on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore demand circuit auto\-negotiation requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.DemandCircuit, self).__init__()

                                self.yang_name = "demand-circuit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.disable = None
                                self.ignore = None
                                self._segment_path = lambda: "demand-circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.DemandCircuit, [u'disable', u'ignore'], name, value)


                        class FloodReduction(Entity):
                            """
                            OSPF Flood Reduction
                            
                            .. attribute:: disable
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.FloodReduction, self).__init__()

                                self.yang_name = "flood-reduction"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flood-reduction"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.FloodReduction, [u'disable'], name, value)


                        class Manet(Entity):
                            """
                            Mobile Adhoc Networking options
                            
                            .. attribute:: peering
                            
                            	MANET Peering options
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet.Peering>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet.Peering))])
                                self._leafs = OrderedDict()

                                self.peering = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet, [], name, value)


                            class Peering(Entity):
                                """
                                MANET Peering options
                                
                                .. attribute:: cost
                                
                                	Redundant path cost improvement required to peer
                                	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost>`
                                
                                .. attribute:: link_metrics
                                
                                	Require link metrics
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost))])
                                    self._leafs = OrderedDict([
                                        ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                                    ])
                                    self.link_metrics = None

                                    self.cost = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost()
                                    self.cost.parent = self
                                    self._children_name_map["cost"] = "cost"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet.Peering, [u'link_metrics'], name, value)


                                class Cost(Entity):
                                    """
                                    Redundant path cost improvement required to peer
                                    
                                    .. attribute:: percent
                                    
                                    	Relative incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    .. attribute:: threshold
                                    
                                    	Absolute incremental path cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, self).__init__()

                                        self.yang_name = "cost"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                        ])
                                        self.percent = None
                                        self.threshold = None
                                        self._segment_path = lambda: "cost"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                        class MtuIgnore(Entity):
                            """
                            Ignores the MTU in DBD packets
                            
                            .. attribute:: disable
                            
                            	Disable Ingore MTU on this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.MtuIgnore, self).__init__()

                                self.yang_name = "mtu-ignore"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "mtu-ignore"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.MtuIgnore, [u'disable'], name, value)


                        class MultiArea(Entity):
                            """
                            Set the OSPF multi\-area ID
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disable
                            
                            	disable OSPF multi\-area
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.MultiArea, self).__init__()

                                self.yang_name = "multi-area"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.disable = None
                                self._segment_path = lambda: "multi-area"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.MultiArea, [u'id', u'cost', u'disable'], name, value)


                        class Neighbor(Entity):
                            """
                            OSPF neighbor
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cost
                            
                            	OSPF cost for point\-to\-multipoint neighbor
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                            	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter>`
                            
                            .. attribute:: poll_interval
                            
                            	OSPF dead\-router polling interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: priority
                            
                            	OSPF priority of non\-broadcast neighbor
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.id = None
                                self.cost = None
                                self.poll_interval = None
                                self.priority = None

                                self.database_filter = Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter()
                                self.database_filter.parent = self
                                self._children_name_map["database_filter"] = "database-filter"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                            class DatabaseFilter(Entity):
                                """
                                Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                                
                                .. attribute:: all
                                
                                	Filter all LSA
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, self).__init__()

                                    self.yang_name = "database-filter"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter.All')])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "database-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Neighbor.DatabaseFilter, ['all'], name, value)

                                class All(Enum):
                                    """
                                    All (Enum Class)

                                    Filter all LSA

                                    .. data:: out = 0

                                    """

                                    out = Enum.YLeaf(0, "out")



                        class Network(Entity):
                            """
                            Network type
                            
                            .. attribute:: broadcast
                            
                            	Specify OSPF broadcast multi\-access network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: manet
                            
                            	Specify MANET OSPF interface type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_broadcast
                            
                            	Specify OSPF NBMA network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	Specify OSPF point\-to\-multipoint network
                            	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: point_to_point
                            
                            	Specify OSPF point\-to\-point network
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint))])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                                    ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                                ])
                                self.broadcast = None
                                self.manet = None
                                self.non_broadcast = None
                                self.point_to_point = None

                                self.point_to_multipoint = None
                                self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                                self._segment_path = lambda: "network"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                            class PointToMultipoint(Entity):
                                """
                                Specify OSPF point\-to\-multipoint network
                                
                                .. attribute:: non_broadcast
                                
                                	Specify non\-broadcast point\-to\-mpoint network
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, self).__init__()

                                    self.yang_name = "point-to-multipoint"
                                    self.yang_parent_name = "network"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                                    ])
                                    self.non_broadcast = None
                                    self._segment_path = lambda: "point-to-multipoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Network.PointToMultipoint, ['non_broadcast'], name, value)


                        class PrefixSuppression(Entity):
                            """
                            OSPF prefix suppression
                            
                            .. attribute:: disable
                            
                            	Disable prefix suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.PrefixSuppression, self).__init__()

                                self.yang_name = "prefix-suppression"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "prefix-suppression"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.PrefixSuppression, ['disable'], name, value)


                        class Shutdown(Entity):
                            """
                            Shut down the interface in OSPFv3
                            
                            .. attribute:: disable
                            
                            	Disable inherited shutdown
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Shutdown, self).__init__()

                                self.yang_name = "shutdown"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "shutdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.ProcessId.Ipv6.Shutdown, [u'disable'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: key_chain
                    
                    	Use a key\-chain for cryptographic authentication keys
                    	**type**\: str
                    
                    .. attribute:: null
                    
                    	Use no authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec authentication
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.null = None

                        self.ipsec = Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Authentication, [u'key_chain', u'null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec authentication
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 256..4294967295
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5>`
                        
                        .. attribute:: sha1
                        
                        	Use SHA\-1 authentication
                        	**type**\:  :py:class:`Sha1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5)), ("sha1", ("sha1", Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                            ])
                            self.spi = None

                            self.md5 = Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"

                            self.sha1 = Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1()
                            self.sha1.parent = self
                            self._children_name_map["sha1"] = "sha1"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec, ['spi'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Md5.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class Sha1(Entity):
                            """
                            Use SHA\-1 authentication
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1, self).__init__()

                                self.yang_name = "sha1"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "sha1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "sha1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Authentication.Ipsec.Sha1.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                class Bfd(Entity):
                    """
                    Enable BFD on this interface
                    
                    .. attribute:: disable
                    
                    	Disable BFD on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Bfd, ['disable'], name, value)


                class Cost(Entity):
                    """
                    Route cost of this interface
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: dynamic
                    
                    	Specify dynamic cost options
                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Cost.Dynamic>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.Cost, self).__init__()

                        self.yang_name = "cost"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.Tunnel.Ospfv3.Cost.Dynamic))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.dynamic = None
                        self._children_name_map["dynamic"] = "dynamic"
                        self._segment_path = lambda: "cost"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Cost, [u'value'], name, value)


                    class Dynamic(Entity):
                        """
                        Specify dynamic cost options
                        
                        .. attribute:: default
                        
                        	Specify default link metric value
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hysteresis
                        
                        	Specify hysteresis value for LSA dampening
                        	**type**\:  :py:class:`Hysteresis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Hysteresis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: weight
                        
                        	Specify weight to be placed on individual metrics
                        	**type**\:  :py:class:`Weight <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic, self).__init__()

                            self.yang_name = "dynamic"
                            self.yang_parent_name = "cost"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hysteresis", ("hysteresis", Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Hysteresis)), ("weight", ("weight", Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                            ])
                            self.default = None

                            self.hysteresis = None
                            self._children_name_map["hysteresis"] = "hysteresis"

                            self.weight = Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight()
                            self.weight.parent = self
                            self._children_name_map["weight"] = "weight"
                            self._segment_path = lambda: "dynamic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic, [u'default'], name, value)


                        class Hysteresis(Entity):
                            """
                            Specify hysteresis value for LSA dampening
                            
                            .. attribute:: percent
                            
                            	Specify hysteresis percent changed
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold
                            
                            	Specify hysteresis threshold value
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Hysteresis, self).__init__()

                                self.yang_name = "hysteresis"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "hysteresis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Hysteresis, [u'percent', u'threshold'], name, value)


                        class Weight(Entity):
                            """
                            Specify weight to be placed on individual metrics
                            
                            .. attribute:: l2_factor
                            
                            	Specify weight to be given to L2\-factor metric
                            	**type**\:  :py:class:`L2Factor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.L2Factor>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: latency
                            
                            	Specify weight to be given to latency metric
                            	**type**\:  :py:class:`Latency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Latency>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: resources
                            
                            	Specify weight to be given to resources metric
                            	**type**\:  :py:class:`Resources <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Resources>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: throughput
                            
                            	Specify weight to be given to throughput metric
                            	**type**\:  :py:class:`Throughput <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Throughput>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight, self).__init__()

                                self.yang_name = "weight"
                                self.yang_parent_name = "dynamic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("L2-factor", ("l2_factor", Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.L2Factor)), ("latency", ("latency", Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Latency)), ("resources", ("resources", Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Resources)), ("throughput", ("throughput", Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Throughput))])
                                self._leafs = OrderedDict()

                                self.l2_factor = None
                                self._children_name_map["l2_factor"] = "L2-factor"

                                self.latency = None
                                self._children_name_map["latency"] = "latency"

                                self.resources = None
                                self._children_name_map["resources"] = "resources"

                                self.throughput = None
                                self._children_name_map["throughput"] = "throughput"
                                self._segment_path = lambda: "weight"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight, [], name, value)


                            class L2Factor(Entity):
                                """
                                Specify weight to be given to L2\-factor metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.L2Factor, self).__init__()

                                    self.yang_name = "L2-factor"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "L2-factor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.L2Factor, [u'value'], name, value)


                            class Latency(Entity):
                                """
                                Specify weight to be given to latency metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Latency, self).__init__()

                                    self.yang_name = "latency"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "latency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Latency, [u'value'], name, value)


                            class Resources(Entity):
                                """
                                Specify weight to be given to resources metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Resources, self).__init__()

                                    self.yang_name = "resources"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "resources"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Resources, [u'value'], name, value)


                            class Throughput(Entity):
                                """
                                Specify weight to be given to throughput metric
                                
                                .. attribute:: value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Throughput, self).__init__()

                                    self.yang_name = "throughput"
                                    self.yang_parent_name = "weight"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None
                                    self._segment_path = lambda: "throughput"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Cost.Dynamic.Weight.Throughput, [u'value'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.DatabaseFilter.All')])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.DatabaseFilter, [u'all'], name, value)

                    class All(Enum):
                        """
                        All (Enum Class)

                        Filter all LSA

                        .. data:: out = 0

                        """

                        out = Enum.YLeaf(0, "out")



                class DemandCircuit(Entity):
                    """
                    OSPF Demand Circuit
                    
                    .. attribute:: ignore
                    
                    	Ignore demand circuit auto\-negotiation requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.DemandCircuit, self).__init__()

                        self.yang_name = "demand-circuit"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.ignore = None
                        self._segment_path = lambda: "demand-circuit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.DemandCircuit, [u'ignore'], name, value)


                class Encryption(Entity):
                    """
                    Enable encryption
                    
                    .. attribute:: null
                    
                    	No IPsec encryption on this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Use IPsec encryption
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec))])
                        self._leafs = OrderedDict([
                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                        ])
                        self.null = None

                        self.ipsec = Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Encryption, ['null'], name, value)


                    class Ipsec(Entity):
                        """
                        Use IPsec encryption
                        
                        .. attribute:: spi
                        
                        	Set the SPI (Security Parameters Index)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: esp
                        
                        	Use ESP encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipsec_3des
                        
                        	Use 3DES encryption
                        	**type**\:  :py:class:`Ipsec3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des>`
                        
                        .. attribute:: aes_cbc
                        
                        	Use AES\-CBC encryption
                        	**type**\:  :py:class:`AesCbc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipsec_3des", ("ipsec_3des", Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des)), ("aes-cbc", ("aes_cbc", Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc))])
                            self._leafs = OrderedDict([
                                ('spi', (YLeaf(YType.uint64, 'spi'), ['int'])),
                                ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                            ])
                            self.spi = None
                            self.esp = None

                            self.ipsec_3des = Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des()
                            self.ipsec_3des.parent = self
                            self._children_name_map["ipsec_3des"] = "ipsec_3des"

                            self.aes_cbc = Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc()
                            self.aes_cbc.parent = self
                            self._children_name_map["aes_cbc"] = "aes-cbc"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec, ['spi', 'esp'], name, value)


                        class Ipsec3des(Entity):
                            """
                            Use 3DES encryption
                            
                            .. attribute:: key_string
                            
                            	
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des, self).__init__()

                                self.yang_name = "ipsec_3des"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString))])
                                self._leafs = OrderedDict()

                                self.key_string = Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "ipsec_3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des, [], name, value)


                            class KeyString(Entity):
                                """
                                
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "ipsec_3des"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.Ipsec3des.KeyString, ['encrypt', 'string'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                        class AesCbc(Entity):
                            """
                            Use AES\-CBC encryption
                            
                            .. attribute:: aes_cbc_128
                            
                            	Use 128 bit key
                            	**type**\:  :py:class:`AesCbc128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128>`
                            
                            .. attribute:: aes_192
                            
                            	Use 192 bit key
                            	**type**\:  :py:class:`Aes192 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192>`
                            
                            .. attribute:: aes_256
                            
                            	Use 256 bit key
                            	**type**\:  :py:class:`Aes256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc, self).__init__()

                                self.yang_name = "aes-cbc"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aes-cbc-128", ("aes_cbc_128", Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128)), ("aes-192", ("aes_192", Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192)), ("aes-256", ("aes_256", Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256))])
                                self._leafs = OrderedDict()

                                self.aes_cbc_128 = Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128()
                                self.aes_cbc_128.parent = self
                                self._children_name_map["aes_cbc_128"] = "aes-cbc-128"

                                self.aes_192 = Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192()
                                self.aes_192.parent = self
                                self._children_name_map["aes_192"] = "aes-192"

                                self.aes_256 = Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256()
                                self.aes_256.parent = self
                                self._children_name_map["aes_256"] = "aes-256"
                                self._segment_path = lambda: "aes-cbc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc, [], name, value)


                            class AesCbc128(Entity):
                                """
                                Use 128 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, self).__init__()

                                    self.yang_name = "aes-cbc-128"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-cbc-128"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-cbc-128"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.AesCbc128.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes192(Entity):
                                """
                                Use 192 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, self).__init__()

                                    self.yang_name = "aes-192"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-192"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-192"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes192.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                            class Aes256(Entity):
                                """
                                Use 256 bit key
                                
                                .. attribute:: key_string
                                
                                	
                                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, self).__init__()

                                    self.yang_name = "aes-256"
                                    self.yang_parent_name = "aes-cbc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString))])
                                    self._leafs = OrderedDict()

                                    self.key_string = Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString()
                                    self.key_string.parent = self
                                    self._children_name_map["key_string"] = "key-string"
                                    self._segment_path = lambda: "aes-256"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256, [], name, value)


                                class KeyString(Entity):
                                    """
                                    
                                    
                                    .. attribute:: encrypt
                                    
                                    	
                                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt>`
                                    
                                    .. attribute:: string
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, self).__init__()

                                        self.yang_name = "key-string"
                                        self.yang_parent_name = "aes-256"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString.Encrypt')])),
                                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ])
                                        self.encrypt = None
                                        self.string = None
                                        self._segment_path = lambda: "key-string"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Encryption.Ipsec.AesCbc.Aes256.KeyString, ['encrypt', 'string'], name, value)

                                    class Encrypt(Enum):
                                        """
                                        Encrypt (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_7 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_7 = Enum.YLeaf(1, "7")



                class Manet(Entity):
                    """
                    Mobile Adhoc Networking options
                    
                    .. attribute:: peering
                    
                    	MANET Peering options
                    	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Manet.Peering>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.Manet, self).__init__()

                        self.yang_name = "manet"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peering", ("peering", Native.Interface.Tunnel.Ospfv3.Manet.Peering))])
                        self._leafs = OrderedDict()

                        self.peering = Native.Interface.Tunnel.Ospfv3.Manet.Peering()
                        self.peering.parent = self
                        self._children_name_map["peering"] = "peering"
                        self._segment_path = lambda: "manet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Manet, [], name, value)


                    class Peering(Entity):
                        """
                        MANET Peering options
                        
                        .. attribute:: cost
                        
                        	Redundant path cost improvement required to peer
                        	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Manet.Peering.Cost>`
                        
                        .. attribute:: link_metrics
                        
                        	Require link metrics
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.Manet.Peering, self).__init__()

                            self.yang_name = "peering"
                            self.yang_parent_name = "manet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cost", ("cost", Native.Interface.Tunnel.Ospfv3.Manet.Peering.Cost))])
                            self._leafs = OrderedDict([
                                ('link_metrics', (YLeaf(YType.uint32, 'link-metrics'), ['int'])),
                            ])
                            self.link_metrics = None

                            self.cost = Native.Interface.Tunnel.Ospfv3.Manet.Peering.Cost()
                            self.cost.parent = self
                            self._children_name_map["cost"] = "cost"
                            self._segment_path = lambda: "peering"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Manet.Peering, [u'link_metrics'], name, value)


                        class Cost(Entity):
                            """
                            Redundant path cost improvement required to peer
                            
                            .. attribute:: percent
                            
                            	Relative incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            .. attribute:: threshold
                            
                            	Absolute incremental path cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Ospfv3.Manet.Peering.Cost, self).__init__()

                                self.yang_name = "cost"
                                self.yang_parent_name = "peering"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                    ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ])
                                self.percent = None
                                self.threshold = None
                                self._segment_path = lambda: "cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Manet.Peering.Cost, [u'percent', u'threshold'], name, value)


                class MultiArea(Entity):
                    """
                    Set the OSPF multi\-area ID
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.MultiArea, self).__init__()

                        self.yang_name = "multi-area"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self._segment_path = lambda: "multi-area"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.MultiArea, [u'id', u'cost'], name, value)


                class Neighbor(Entity):
                    """
                    OSPF neighbor
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	OSPF cost for point\-to\-multipoint neighbor
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Neighbor.DatabaseFilter>`
                    
                    .. attribute:: poll_interval
                    
                    	OSPF dead\-router polling interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: priority
                    
                    	OSPF priority of non\-broadcast neighbor
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Interface.Tunnel.Ospfv3.Neighbor.DatabaseFilter))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.id = None
                        self.cost = None
                        self.poll_interval = None
                        self.priority = None

                        self.database_filter = Native.Interface.Tunnel.Ospfv3.Neighbor.DatabaseFilter()
                        self.database_filter.parent = self
                        self._children_name_map["database_filter"] = "database-filter"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Neighbor, ['id', 'cost', 'poll_interval', 'priority'], name, value)


                    class DatabaseFilter(Entity):
                        """
                        Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                        
                        .. attribute:: all
                        
                        	Filter all LSA
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Neighbor.DatabaseFilter.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.Neighbor.DatabaseFilter, self).__init__()

                            self.yang_name = "database-filter"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.enumeration, 'all'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Ospfv3.Neighbor.DatabaseFilter.All')])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "database-filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Neighbor.DatabaseFilter, ['all'], name, value)

                        class All(Enum):
                            """
                            All (Enum Class)

                            Filter all LSA

                            .. data:: out = 0

                            """

                            out = Enum.YLeaf(0, "out")



                class Network(Entity):
                    """
                    Network type
                    
                    .. attribute:: broadcast
                    
                    	Specify OSPF broadcast multi\-access network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: manet
                    
                    	Specify MANET OSPF interface type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: non_broadcast
                    
                    	Specify OSPF NBMA network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: point_to_multipoint
                    
                    	Specify OSPF point\-to\-multipoint network
                    	**type**\:  :py:class:`PointToMultipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Ospfv3.Network.PointToMultipoint>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: point_to_point
                    
                    	Specify OSPF point\-to\-point network
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("point-to-multipoint", ("point_to_multipoint", Native.Interface.Tunnel.Ospfv3.Network.PointToMultipoint))])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('manet', (YLeaf(YType.empty, 'manet'), ['Empty'])),
                            ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ('point_to_point', (YLeaf(YType.empty, 'point-to-point'), ['Empty'])),
                        ])
                        self.broadcast = None
                        self.manet = None
                        self.non_broadcast = None
                        self.point_to_point = None

                        self.point_to_multipoint = None
                        self._children_name_map["point_to_multipoint"] = "point-to-multipoint"
                        self._segment_path = lambda: "network"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Network, ['broadcast', 'manet', 'non_broadcast', 'point_to_point'], name, value)


                    class PointToMultipoint(Entity):
                        """
                        Specify OSPF point\-to\-multipoint network
                        
                        .. attribute:: non_broadcast
                        
                        	Specify non\-broadcast point\-to\-mpoint network
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Ospfv3.Network.PointToMultipoint, self).__init__()

                            self.yang_name = "point-to-multipoint"
                            self.yang_parent_name = "network"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('non_broadcast', (YLeaf(YType.empty, 'non-broadcast'), ['Empty'])),
                            ])
                            self.non_broadcast = None
                            self._segment_path = lambda: "point-to-multipoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Ospfv3.Network.PointToMultipoint, ['non_broadcast'], name, value)


                class PrefixSuppression(Entity):
                    """
                    OSPF prefix suppression
                    
                    .. attribute:: disable
                    
                    	Disable prefix suppression
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Ospfv3.PrefixSuppression, self).__init__()

                        self.yang_name = "prefix-suppression"
                        self.yang_parent_name = "ospfv3"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "prefix-suppression"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Ospfv3.PrefixSuppression, ['disable'], name, value)


            class Udld(Entity):
                """
                Configure UDLD enabled or disabled and ignore global UDLD setting
                
                .. attribute:: port
                
                	Enable UDLD protocol on this interface despite global UDLD setting
                	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Udld.Port>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-udld'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.Tunnel.Udld, self).__init__()

                    self.yang_name = "udld"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port", ("port", Native.Interface.Tunnel.Udld.Port))])
                    self._leafs = OrderedDict()

                    self.port = None
                    self._children_name_map["port"] = "port"
                    self._segment_path = lambda: "Cisco-IOS-XE-udld:udld"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Udld, [], name, value)


                class Port(Entity):
                    """
                    Enable UDLD protocol on this interface despite global UDLD setting
                    
                    .. attribute:: aggressive
                    
                    	Enable UDLD protocol in aggressive mode on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	Disable UDLD protocol on this interface despite global UDLD setting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-udld'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Udld.Port, self).__init__()

                        self.yang_name = "port"
                        self.yang_parent_name = "udld"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aggressive', (YLeaf(YType.empty, 'aggressive'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.aggressive = None
                        self.disable = None
                        self._segment_path = lambda: "port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Udld.Port, ['aggressive', 'disable'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Manual>`
                
                	**presence node**\: True
                
                .. attribute:: role_based
                
                	Role\-based Access Control per\-port config commands
                	**type**\:  :py:class:`RoleBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.RoleBased>`
                
                .. attribute:: sgt
                
                	SGT command options
                	**type**\:  :py:class:`Sgt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Sgt>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.Tunnel.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.Tunnel.Cts.Manual)), ("role-based", ("role_based", Native.Interface.Tunnel.Cts.RoleBased))])
                    self._leafs = OrderedDict([
                        ('sgt', (YLeaf(YType.enumeration, 'sgt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Cts.Sgt')])),
                    ])
                    self.sgt = None

                    self.manual = None
                    self._children_name_map["manual"] = "manual"

                    self.role_based = Native.Interface.Tunnel.Cts.RoleBased()
                    self.role_based.parent = self
                    self._children_name_map["role_based"] = "role-based"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.Cts, ['sgt'], name, value)

                class Sgt(Enum):
                    """
                    Sgt (Enum Class)

                    SGT command options

                    .. data:: inline = 0

                    """

                    inline = Enum.YLeaf(0, "inline")



                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.Tunnel.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.Tunnel.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.Tunnel.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.Tunnel.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.Tunnel.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.Tunnel.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.Tunnel.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.Tunnel.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.Tunnel.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Tunnel.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Cts.Manual.Propagate, ['sgt'], name, value)


                class RoleBased(Entity):
                    """
                    Role\-based Access Control per\-port config commands
                    
                    .. attribute:: sgt_cache
                    
                    	Enable SGT caching on the interface
                    	**type**\: list of   :py:class:`SgtCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.RoleBased.SgtCache>`
                    
                    .. attribute:: enforcement
                    
                    	Enable Role\-based Access Control enforcement
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sgt_map
                    
                    	Assign Security Group Tag (SGT) to IP host or network address
                    	**type**\:  :py:class:`SgtMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.Cts.RoleBased.SgtMap>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Tunnel.Cts.RoleBased, self).__init__()

                        self.yang_name = "role-based"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sgt-map", ("sgt_map", Native.Interface.Tunnel.Cts.RoleBased.SgtMap))])
                        self._leafs = OrderedDict([
                            ('sgt_cache', (YLeafList(YType.enumeration, 'sgt-cache'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Tunnel.Cts.RoleBased.SgtCache')])),
                            ('enforcement', (YLeaf(YType.empty, 'enforcement'), ['Empty'])),
                        ])
                        self.sgt_cache = []
                        self.enforcement = None

                        self.sgt_map = Native.Interface.Tunnel.Cts.RoleBased.SgtMap()
                        self.sgt_map.parent = self
                        self._children_name_map["sgt_map"] = "sgt-map"
                        self._segment_path = lambda: "role-based"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.Cts.RoleBased, ['sgt_cache', 'enforcement'], name, value)

                    class SgtCache(Enum):
                        """
                        SgtCache (Enum Class)

                        Enable SGT caching on the interface

                        .. data:: egress = 0

                        .. data:: ingress = 1

                        """

                        egress = Enum.YLeaf(0, "egress")

                        ingress = Enum.YLeaf(1, "ingress")



                    class SgtMap(Entity):
                        """
                        Assign Security Group Tag (SGT) to IP host or network address
                        
                        .. attribute:: security_group
                        
                        	Security Group Name
                        	**type**\: str
                        
                        .. attribute:: sgt
                        
                        	Security Group Tag (SGT)
                        	**type**\: int
                        
                        	**range:** 2..65519
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Tunnel.Cts.RoleBased.SgtMap, self).__init__()

                            self.yang_name = "sgt-map"
                            self.yang_parent_name = "role-based"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('security_group', (YLeaf(YType.str, 'security-group'), ['str'])),
                                ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                            ])
                            self.security_group = None
                            self.sgt = None
                            self._segment_path = lambda: "sgt-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Tunnel.Cts.RoleBased.SgtMap, ['security_group', 'sgt'], name, value)


            class AnalysisModule(Entity):
                """
                Configure NAM on the interface
                
                .. attribute:: monitoring
                
                	Configure NAM monitoring on the interface
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Tunnel.AnalysisModule.Monitoring>`
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Interface.Tunnel.AnalysisModule, self).__init__()

                    self.yang_name = "analysis-module"
                    self.yang_parent_name = "Tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Interface.Tunnel.AnalysisModule.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = Native.Interface.Tunnel.AnalysisModule.Monitoring()
                    self.monitoring.parent = self
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Tunnel.AnalysisModule, [], name, value)


                class Monitoring(Entity):
                    """
                    Configure NAM monitoring on the interface
                    
                    .. attribute:: interface_name
                    
                    	The name of the output interface.  E.g., 'ucse 1/0/0'
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-nam'
                    _revision = '2017-12-28'

                    def __init__(self):
                        super(Native.Interface.Tunnel.AnalysisModule.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "analysis-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "monitoring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Tunnel.AnalysisModule.Monitoring, ['interface_name'], name, value)


        class VirtualTemplate(Entity):
            """
            Virtual Template interface
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..4095
            
            .. attribute:: type
            
            	type of the virtual\-template
            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Type>`
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service>`
            
            .. attribute:: lacp
            
            	LACP interface subcommands
            	**type**\:  :py:class:`Lacp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Lacp>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ServicePolicy>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Snmp>`
            
            .. attribute:: nhrp
            
            	NHRP Interface commands
            	**type**\:  :py:class:`Nhrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Nhrp>`
            
            .. attribute:: tunnel
            
            	protocol\-over\-protocol tunneling
            	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel>`
            
            .. attribute:: crypto
            
            	Encryption/Decryption commands
            	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Crypto>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Utd>`
            
            .. attribute:: cdp
            
            	CDP interface subcommands
            	**type**\:  :py:class:`Cdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cdp>`
            
            .. attribute:: ntp
            
            	Configure NTP
            	**type**\:  :py:class:`Ntp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ntp>`
            
            .. attribute:: mab
            
            	
            	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Mab>`
            
            	**presence node**\: True
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Umbrella>`
            
            .. attribute:: ppp
            
            	Point\-to\-Point Protocol
            	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp>`
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.VirtualTemplate, self).__init__()

                self.yang_name = "Virtual-Template"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.VirtualTemplate.SwitchportConf)), ("switchport", ("switchport", Native.Interface.VirtualTemplate.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.VirtualTemplate.StackwiseVirtual)), ("arp", ("arp", Native.Interface.VirtualTemplate.Arp)), ("backup", ("backup", Native.Interface.VirtualTemplate.Backup)), ("cemoudp", ("cemoudp", Native.Interface.VirtualTemplate.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.VirtualTemplate.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.VirtualTemplate.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.VirtualTemplate.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.VirtualTemplate.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.VirtualTemplate.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.VirtualTemplate.Flowcontrol)), ("isis", ("isis", Native.Interface.VirtualTemplate.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.VirtualTemplate.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.VirtualTemplate.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.VirtualTemplate.Bandwidth)), ("dampening", ("dampening", Native.Interface.VirtualTemplate.Dampening)), ("domain", ("domain", Native.Interface.VirtualTemplate.Domain)), ("hold-queue", ("hold_queue", Native.Interface.VirtualTemplate.HoldQueue)), ("mpls", ("mpls", Native.Interface.VirtualTemplate.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.VirtualTemplate.IpVrf)), ("vrf", ("vrf", Native.Interface.VirtualTemplate.Vrf)), ("ip", ("ip", Native.Interface.VirtualTemplate.Ip)), ("ipv6", ("ipv6", Native.Interface.VirtualTemplate.Ipv6)), ("logging", ("logging", Native.Interface.VirtualTemplate.Logging)), ("mdix", ("mdix", Native.Interface.VirtualTemplate.Mdix)), ("mop", ("mop", Native.Interface.VirtualTemplate.Mop)), ("interface_qos", ("interface_qos", Native.Interface.VirtualTemplate.InterfaceQos)), ("source", ("source", Native.Interface.VirtualTemplate.Source)), ("standby", ("standby", Native.Interface.VirtualTemplate.Standby)), ("access-session", ("access_session", Native.Interface.VirtualTemplate.AccessSession)), ("storm-control", ("storm_control", Native.Interface.VirtualTemplate.StormControl)), ("trust", ("trust", Native.Interface.VirtualTemplate.Trust)), ("priority-queue", ("priority_queue", Native.Interface.VirtualTemplate.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.VirtualTemplate.RcvQueue)), ("peer", ("peer", Native.Interface.VirtualTemplate.Peer)), ("pm-path", ("pm_path", Native.Interface.VirtualTemplate.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.VirtualTemplate.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.VirtualTemplate.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.VirtualTemplate.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.VirtualTemplate.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.VirtualTemplate.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.VirtualTemplate.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.VirtualTemplate.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.VirtualTemplate.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.VirtualTemplate.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.VirtualTemplate.Service)), ("Cisco-IOS-XE-ethernet:lacp", ("lacp", Native.Interface.VirtualTemplate.Lacp)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.VirtualTemplate.ServicePolicy)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.VirtualTemplate.Snmp)), ("Cisco-IOS-XE-tunnel:nhrp", ("nhrp", Native.Interface.VirtualTemplate.Nhrp)), ("Cisco-IOS-XE-tunnel:tunnel", ("tunnel", Native.Interface.VirtualTemplate.Tunnel)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.VirtualTemplate.Crypto)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.VirtualTemplate.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.VirtualTemplate.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.VirtualTemplate.Utd)), ("Cisco-IOS-XE-cdp:cdp", ("cdp", Native.Interface.VirtualTemplate.Cdp)), ("Cisco-IOS-XE-ntp:ntp", ("ntp", Native.Interface.VirtualTemplate.Ntp)), ("Cisco-IOS-XE-sanet:mab", ("mab", Native.Interface.VirtualTemplate.Mab)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.VirtualTemplate.Umbrella)), ("Cisco-IOS-XE-ppp:ppp", ("ppp", Native.Interface.VirtualTemplate.Ppp)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.VirtualTemplate.Cts))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Type')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Duplex')])),
                ])
                self.name = None
                self.type = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None

                self.switchport_conf = Native.Interface.VirtualTemplate.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.VirtualTemplate.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.VirtualTemplate.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.VirtualTemplate.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.VirtualTemplate.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.VirtualTemplate.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.VirtualTemplate.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.VirtualTemplate.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.VirtualTemplate.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.VirtualTemplate.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.VirtualTemplate.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.VirtualTemplate.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.VirtualTemplate.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.VirtualTemplate.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.VirtualTemplate.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.VirtualTemplate.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.VirtualTemplate.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.VirtualTemplate.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.VirtualTemplate.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.VirtualTemplate.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.VirtualTemplate.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.VirtualTemplate.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.VirtualTemplate.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.VirtualTemplate.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.VirtualTemplate.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.VirtualTemplate.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.VirtualTemplate.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.VirtualTemplate.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.VirtualTemplate.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.VirtualTemplate.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.VirtualTemplate.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.VirtualTemplate.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.VirtualTemplate.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.VirtualTemplate.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.VirtualTemplate.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.VirtualTemplate.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.VirtualTemplate.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.VirtualTemplate.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.VirtualTemplate.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.VirtualTemplate.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.VirtualTemplate.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.VirtualTemplate.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.VirtualTemplate.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.VirtualTemplate.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.VirtualTemplate.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.lacp = Native.Interface.VirtualTemplate.Lacp()
                self.lacp.parent = self
                self._children_name_map["lacp"] = "Cisco-IOS-XE-ethernet:lacp"

                self.service_policy = Native.Interface.VirtualTemplate.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.snmp = Native.Interface.VirtualTemplate.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.nhrp = Native.Interface.VirtualTemplate.Nhrp()
                self.nhrp.parent = self
                self._children_name_map["nhrp"] = "Cisco-IOS-XE-tunnel:nhrp"

                self.tunnel = Native.Interface.VirtualTemplate.Tunnel()
                self.tunnel.parent = self
                self._children_name_map["tunnel"] = "Cisco-IOS-XE-tunnel:tunnel"

                self.crypto = Native.Interface.VirtualTemplate.Crypto()
                self.crypto.parent = self
                self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                self.et_analytics = Native.Interface.VirtualTemplate.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.VirtualTemplate.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.VirtualTemplate.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.cdp = Native.Interface.VirtualTemplate.Cdp()
                self.cdp.parent = self
                self._children_name_map["cdp"] = "Cisco-IOS-XE-cdp:cdp"

                self.ntp = Native.Interface.VirtualTemplate.Ntp()
                self.ntp.parent = self
                self._children_name_map["ntp"] = "Cisco-IOS-XE-ntp:ntp"

                self.mab = None
                self._children_name_map["mab"] = "Cisco-IOS-XE-sanet:mab"

                self.umbrella = Native.Interface.VirtualTemplate.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.ppp = Native.Interface.VirtualTemplate.Ppp()
                self.ppp.parent = self
                self._children_name_map["ppp"] = "Cisco-IOS-XE-ppp:ppp"

                self.cts = Native.Interface.VirtualTemplate.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "Virtual-Template" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.VirtualTemplate, [u'name', u'type', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")


            class Type(Enum):
                """
                Type (Enum Class)

                type of the virtual\-template

                .. data:: ethernet = 0

                .. data:: serial = 1

                .. data:: tunnel = 2

                .. data:: vpn = 3

                """

                ethernet = Enum.YLeaf(0, "ethernet")

                serial = Enum.YLeaf(1, "serial")

                tunnel = Enum.YLeaf(2, "tunnel")

                vpn = Enum.YLeaf(3, "vpn")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.VirtualTemplate.Backup.Delay)), ("interface", ("interface", Native.Interface.VirtualTemplate.Backup.Interface_)), ("load", ("load", Native.Interface.VirtualTemplate.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.VirtualTemplate.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.VirtualTemplate.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.VirtualTemplate.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.VirtualTemplate.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.VirtualTemplate.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.VirtualTemplate.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.VirtualTemplate.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.VirtualTemplate.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.VirtualTemplate.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.VirtualTemplate.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.VirtualTemplate.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.VirtualTemplate.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.VirtualTemplate.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.VirtualTemplate.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.VirtualTemplate.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.VirtualTemplate.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.VirtualTemplate.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.VirtualTemplate.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.VirtualTemplate.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.VirtualTemplate.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.VirtualTemplate.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.VirtualTemplate.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.VirtualTemplate.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.VirtualTemplate.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.VirtualTemplate.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.VirtualTemplate.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                .. attribute:: adjacency_filter
                
                	Filter IS\-IS adjacencies
                	**type**\:  :py:class:`AdjacencyFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.AdjacencyFilter>`
                
                .. attribute:: advertise
                
                	Control addresses advertisements in LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Advertise>`
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Authentication>`
                
                .. attribute:: circuit_type
                
                	Configure circuit type for interface
                	**type**\:  :py:class:`CircuitType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.CircuitType>`
                
                	**presence node**\: True
                
                .. attribute:: csnp_interval
                
                	Set CSNP interval in seconds
                	**type**\:  :py:class:`CsnpInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.CsnpInterval>`
                
                .. attribute:: hello
                
                	Add padding to IS\-IS hello packets
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Hello>`
                
                .. attribute:: hello_interval
                
                	Set Hello interval in seconds
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval>`
                
                .. attribute:: hello_multiplier
                
                	Set multiplier for Hello holding time
                	**type**\:  :py:class:`HelloMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloMultiplier>`
                
                .. attribute:: ipv6
                
                	IPv6 interface configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Ipv6>`
                
                .. attribute:: lsp_interval
                
                	Set LSP transmission interval
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: mesh_group
                
                	Set ISIS mesh group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.MeshGroup>`
                
                .. attribute:: metric
                
                	Configure the metric for interface
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric>`
                
                .. attribute:: network
                
                	Network type
                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Network>`
                
                .. attribute:: password
                
                	Configure the authentication password for interface
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Password>`
                
                .. attribute:: priority
                
                	Set priority for Designated Router election
                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Priority>`
                
                .. attribute:: protocol
                
                	Set ISIS protocol's state under current interface
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Protocol>`
                
                .. attribute:: retransmit_interval
                
                	Set per\-LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: retransmit_throttle_interval
                
                	Set interface LSP retransmission interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: tag
                
                	Assign an admin tag to an ISIS interface IP route
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: bfd
                
                	Bidirectional Forwarding Protocol
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Bfd>`
                
                	**presence node**\: True
                
                .. attribute:: three_way_handshake
                
                	Select Cisco or IETF three\-way handshake
                	**type**\:  :py:class:`ThreeWayHandshake <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.ThreeWayHandshake>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:adjacency-filter", ("adjacency_filter", Native.Interface.VirtualTemplate.Isis.AdjacencyFilter)), ("Cisco-IOS-XE-isis:advertise", ("advertise", Native.Interface.VirtualTemplate.Isis.Advertise)), ("Cisco-IOS-XE-isis:authentication", ("authentication", Native.Interface.VirtualTemplate.Isis.Authentication)), ("Cisco-IOS-XE-isis:circuit-type", ("circuit_type", Native.Interface.VirtualTemplate.Isis.CircuitType)), ("Cisco-IOS-XE-isis:csnp-interval", ("csnp_interval", Native.Interface.VirtualTemplate.Isis.CsnpInterval)), ("Cisco-IOS-XE-isis:hello", ("hello", Native.Interface.VirtualTemplate.Isis.Hello)), ("Cisco-IOS-XE-isis:hello-interval", ("hello_interval", Native.Interface.VirtualTemplate.Isis.HelloInterval)), ("Cisco-IOS-XE-isis:hello-multiplier", ("hello_multiplier", Native.Interface.VirtualTemplate.Isis.HelloMultiplier)), ("Cisco-IOS-XE-isis:ipv6", ("ipv6", Native.Interface.VirtualTemplate.Isis.Ipv6)), ("Cisco-IOS-XE-isis:metric", ("metric", Native.Interface.VirtualTemplate.Isis.Metric)), ("Cisco-IOS-XE-isis:password", ("password", Native.Interface.VirtualTemplate.Isis.Password)), ("Cisco-IOS-XE-isis:priority", ("priority", Native.Interface.VirtualTemplate.Isis.Priority)), ("Cisco-IOS-XE-isis:bfd", ("bfd", Native.Interface.VirtualTemplate.Isis.Bfd)), ("Cisco-IOS-XE-isis:three-way-handshake", ("three_way_handshake", Native.Interface.VirtualTemplate.Isis.ThreeWayHandshake))])
                    self._leafs = OrderedDict([
                        ('lsp_interval', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:lsp-interval'), ['int'])),
                        ('mesh_group', (YLeaf(YType.str, 'Cisco-IOS-XE-isis:mesh-group'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.MeshGroup')])),
                        ('network', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:network'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Network')])),
                        ('protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-isis:protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Protocol')])),
                        ('retransmit_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-interval'), ['int'])),
                        ('retransmit_throttle_interval', (YLeaf(YType.uint16, 'Cisco-IOS-XE-isis:retransmit-throttle-interval'), ['int'])),
                        ('tag', (YLeaf(YType.uint32, 'Cisco-IOS-XE-isis:tag'), ['int'])),
                    ])
                    self.lsp_interval = None
                    self.mesh_group = None
                    self.network = None
                    self.protocol = None
                    self.retransmit_interval = None
                    self.retransmit_throttle_interval = None
                    self.tag = None

                    self.adjacency_filter = Native.Interface.VirtualTemplate.Isis.AdjacencyFilter()
                    self.adjacency_filter.parent = self
                    self._children_name_map["adjacency_filter"] = "Cisco-IOS-XE-isis:adjacency-filter"

                    self.advertise = Native.Interface.VirtualTemplate.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "Cisco-IOS-XE-isis:advertise"

                    self.authentication = Native.Interface.VirtualTemplate.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "Cisco-IOS-XE-isis:authentication"

                    self.circuit_type = None
                    self._children_name_map["circuit_type"] = "Cisco-IOS-XE-isis:circuit-type"

                    self.csnp_interval = Native.Interface.VirtualTemplate.Isis.CsnpInterval()
                    self.csnp_interval.parent = self
                    self._children_name_map["csnp_interval"] = "Cisco-IOS-XE-isis:csnp-interval"

                    self.hello = Native.Interface.VirtualTemplate.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "Cisco-IOS-XE-isis:hello"

                    self.hello_interval = Native.Interface.VirtualTemplate.Isis.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "Cisco-IOS-XE-isis:hello-interval"

                    self.hello_multiplier = Native.Interface.VirtualTemplate.Isis.HelloMultiplier()
                    self.hello_multiplier.parent = self
                    self._children_name_map["hello_multiplier"] = "Cisco-IOS-XE-isis:hello-multiplier"

                    self.ipv6 = Native.Interface.VirtualTemplate.Isis.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "Cisco-IOS-XE-isis:ipv6"

                    self.metric = Native.Interface.VirtualTemplate.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "Cisco-IOS-XE-isis:metric"

                    self.password = Native.Interface.VirtualTemplate.Isis.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "Cisco-IOS-XE-isis:password"

                    self.priority = Native.Interface.VirtualTemplate.Isis.Priority()
                    self.priority.parent = self
                    self._children_name_map["priority"] = "Cisco-IOS-XE-isis:priority"

                    self.bfd = None
                    self._children_name_map["bfd"] = "Cisco-IOS-XE-isis:bfd"

                    self.three_way_handshake = None
                    self._children_name_map["three_way_handshake"] = "Cisco-IOS-XE-isis:three-way-handshake"
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Isis, [u'lsp_interval', u'mesh_group', u'network', u'protocol', u'retransmit_interval', u'retransmit_throttle_interval', u'tag'], name, value)

                class MeshGroup(Enum):
                    """
                    MeshGroup (Enum Class)

                    Set ISIS mesh group

                    .. data:: blocked = 0

                    """

                    blocked = Enum.YLeaf(0, "blocked")


                class Network(Enum):
                    """
                    Network (Enum Class)

                    Network type

                    .. data:: point_to_point = 0

                    """

                    point_to_point = Enum.YLeaf(0, "point-to-point")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    Set ISIS protocol's state under current interface

                    .. data:: shutdown = 0

                    """

                    shutdown = Enum.YLeaf(0, "shutdown")



                class AdjacencyFilter(Entity):
                    """
                    Filter IS\-IS adjacencies
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: match_all
                    
                    	Match all area addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.AdjacencyFilter, self).__init__()

                        self.yang_name = "adjacency-filter"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('match_all', (YLeaf(YType.empty, 'match-all'), ['Empty'])),
                        ])
                        self.name = None
                        self.match_all = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:adjacency-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.AdjacencyFilter, [u'name', u'match_all'], name, value)


                class Advertise(Entity):
                    """
                    Control addresses advertisements in LSPs
                    
                    .. attribute:: prefix
                    
                    	Interface IP address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Advertise, [u'prefix'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.VirtualTemplate.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Interface.VirtualTemplate.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Interface.VirtualTemplate.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Interface.VirtualTemplate.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Interface.VirtualTemplate.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.VirtualTemplate.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Interface.VirtualTemplate.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Interface.VirtualTemplate.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class CircuitType(Entity):
                    """
                    Configure circuit type for interface
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.CircuitType.Levels>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.CircuitType, self).__init__()

                        self.yang_name = "circuit-type"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.CircuitType.Levels')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:circuit-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.CircuitType, [u'levels'], name, value)

                    class Levels(Enum):
                        """
                        Levels (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2_only = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2_only = Enum.YLeaf(2, "level-2-only")



                class CsnpInterval(Entity):
                    """
                    Set CSNP interval in seconds
                    
                    .. attribute:: csnp_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CsnpIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.CsnpInterval.CsnpIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.CsnpInterval, self).__init__()

                        self.yang_name = "csnp-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("csnp-interval-list", ("csnp_interval_list", Native.Interface.VirtualTemplate.Isis.CsnpInterval.CsnpIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.csnp_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:csnp-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.CsnpInterval, [u'value'], name, value)


                    class CsnpIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.CsnpInterval.CsnpIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.CsnpInterval.CsnpIntervalList, self).__init__()

                            self.yang_name = "csnp-interval-list"
                            self.yang_parent_name = "csnp-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.CsnpInterval.CsnpIntervalList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "csnp-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.CsnpInterval.CsnpIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Hello(Entity):
                    """
                    Add padding to IS\-IS hello packets
                    
                    .. attribute:: padding
                    
                    	Pad hello packets
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Interface.VirtualTemplate.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello packets
                        
                        .. attribute:: always
                        
                        	Never pad hello packets if no prefix present
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ])
                            self.always = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Hello.Padding, [u'always'], name, value)


                class HelloInterval(Entity):
                    """
                    Set Hello interval in seconds
                    
                    .. attribute:: hello_interval_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloIntervalList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..65535
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-interval-list", ("hello_interval_list", Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.Value')])),
                        ])
                        self.value = None

                        self.hello_interval_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.HelloInterval, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: minimal = 0

                        """

                        minimal = Enum.YLeaf(0, "minimal")



                    class HelloIntervalList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..65535
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList, self).__init__()

                            self.yang_name = "hello-interval-list"
                            self.yang_parent_name = "hello-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-interval-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.HelloInterval.HelloIntervalList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: minimal = 0

                            """

                            minimal = Enum.YLeaf(0, "minimal")



                class HelloMultiplier(Entity):
                    """
                    Set multiplier for Hello holding time
                    
                    .. attribute:: hello_multiplier_list
                    
                    	
                    	**type**\: list of  		 :py:class:`HelloMultiplierList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloMultiplier.HelloMultiplierList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.HelloMultiplier, self).__init__()

                        self.yang_name = "hello-multiplier"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello-multiplier-list", ("hello_multiplier_list", Native.Interface.VirtualTemplate.Isis.HelloMultiplier.HelloMultiplierList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.hello_multiplier_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:hello-multiplier"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.HelloMultiplier, [u'value'], name, value)


                    class HelloMultiplierList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.HelloMultiplier.HelloMultiplierList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.HelloMultiplier.HelloMultiplierList, self).__init__()

                            self.yang_name = "hello-multiplier-list"
                            self.yang_parent_name = "hello-multiplier"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.HelloMultiplier.HelloMultiplierList.Levels')])),
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "hello-multiplier-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.HelloMultiplier.HelloMultiplierList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Ipv6(Entity):
                    """
                    IPv6 interface configuration
                    
                    .. attribute:: metric
                    
                    	Configure the metric for interface
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Ipv6.Metric>`
                    
                    .. attribute:: tag
                    
                    	Assign an admin tag to an ISIS interface IPv6 route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Ipv6.Bfd>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.VirtualTemplate.Isis.Ipv6.Metric)), ("bfd", ("bfd", Native.Interface.VirtualTemplate.Isis.Ipv6.Bfd))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.tag = None

                        self.metric = Native.Interface.VirtualTemplate.Isis.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Ipv6, [u'tag'], name, value)


                    class Metric(Entity):
                        """
                        Configure the metric for interface
                        
                        .. attribute:: metric_list
                        
                        	
                        	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Ipv6.Metric.MetricList>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.VirtualTemplate.Isis.Ipv6.Metric.MetricList))])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                            ])
                            self.value = None

                            self.metric_list = YList(self)
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Ipv6.Metric, [u'value'], name, value)

                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                        class MetricList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Ipv6.Metric.MetricList.Levels>`
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..16777214
                            
                            		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Isis.Ipv6.Metric.MetricList, self).__init__()

                                self.yang_name = "metric-list"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Ipv6.Metric.MetricList.Levels')])),
                                    ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                                ])
                                self.levels = None
                                self.value = None
                                self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Ipv6.Metric.MetricList, [u'levels', u'value'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class Value(Enum):
                                """
                                Value (Enum Class)

                                .. data:: maximum = 0

                                """

                                maximum = Enum.YLeaf(0, "maximum")



                    class Bfd(Entity):
                        """
                        Bidirectional Forwarding Protocol
                        
                        .. attribute:: disable
                        
                        	disable bfd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Ipv6.Bfd, [u'disable'], name, value)


                class Metric(Entity):
                    """
                    Configure the metric for interface
                    
                    .. attribute:: metric_list
                    
                    	
                    	**type**\: list of  		 :py:class:`MetricList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..16777214
                    
                    		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.Value>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric-list", ("metric_list", Native.Interface.VirtualTemplate.Isis.Metric.MetricList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.Value')])),
                        ])
                        self.value = None

                        self.metric_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Metric, [u'value'], name, value)

                    class Value(Enum):
                        """
                        Value (Enum Class)

                        .. data:: maximum = 0

                        """

                        maximum = Enum.YLeaf(0, "maximum")



                    class MetricList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..16777214
                        
                        		**type**\:  :py:class:`Value <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Metric.MetricList.Value>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.Metric.MetricList, self).__init__()

                            self.yang_name = "metric-list"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Levels')])),
                                ('value', (YLeaf(YType.str, 'value'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Metric.MetricList.Value')])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "metric-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Metric.MetricList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class Value(Enum):
                            """
                            Value (Enum Class)

                            .. data:: maximum = 0

                            """

                            maximum = Enum.YLeaf(0, "maximum")



                class Password(Entity):
                    """
                    Configure the authentication password for interface
                    
                    .. attribute:: password_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PasswordList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Password.PasswordList>`
                    
                    .. attribute:: password
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password-list", ("password_list", Native.Interface.VirtualTemplate.Isis.Password.PasswordList))])
                        self._leafs = OrderedDict([
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.password = None

                        self.password_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Password, [u'password'], name, value)


                    class PasswordList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Password.PasswordList.Levels>`
                        
                        .. attribute:: password
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.Password.PasswordList, self).__init__()

                            self.yang_name = "password-list"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Password.PasswordList.Levels')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.levels = None
                            self.password = None
                            self._segment_path = lambda: "password-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Password.PasswordList, [u'levels', u'password'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Priority(Entity):
                    """
                    Set priority for Designated Router election
                    
                    .. attribute:: priority_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PriorityList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Priority.PriorityList>`
                    
                    .. attribute:: value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.Priority, self).__init__()

                        self.yang_name = "priority"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority-list", ("priority_list", Native.Interface.VirtualTemplate.Isis.Priority.PriorityList))])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                        ])
                        self.value = None

                        self.priority_list = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:priority"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Priority, [u'value'], name, value)


                    class PriorityList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.Priority.PriorityList.Levels>`
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Isis.Priority.PriorityList, self).__init__()

                            self.yang_name = "priority-list"
                            self.yang_parent_name = "priority"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.Priority.PriorityList.Levels')])),
                                ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                            ])
                            self.levels = None
                            self.value = None
                            self._segment_path = lambda: "priority-list" + "[levels='" + str(self.levels) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Priority.PriorityList, [u'levels', u'value'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class Bfd(Entity):
                    """
                    Bidirectional Forwarding Protocol
                    
                    .. attribute:: disable
                    
                    	disable bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.Bfd, [u'disable'], name, value)


                class ThreeWayHandshake(Entity):
                    """
                    Select Cisco or IETF three\-way handshake
                    
                    .. attribute:: implementor
                    
                    	
                    	**type**\:  :py:class:`Implementor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Isis.ThreeWayHandshake.Implementor>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Isis.ThreeWayHandshake, self).__init__()

                        self.yang_name = "three-way-handshake"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('implementor', (YLeaf(YType.enumeration, 'implementor'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Isis.ThreeWayHandshake.Implementor')])),
                        ])
                        self.implementor = None
                        self._segment_path = lambda: "Cisco-IOS-XE-isis:three-way-handshake"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Isis.ThreeWayHandshake, [u'implementor'], name, value)

                    class Implementor(Enum):
                        """
                        Implementor (Enum Class)

                        .. data:: cisco = 0

                        .. data:: ietf = 1

                        """

                        cisco = Enum.YLeaf(0, "cisco")

                        ietf = Enum.YLeaf(1, "ietf")



            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.VirtualTemplate.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.VirtualTemplate.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.VirtualTemplate.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.VirtualTemplate.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.VirtualTemplate.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.VirtualTemplate.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.VirtualTemplate.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.VirtualTemplate.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.VirtualTemplate.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.VirtualTemplate.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Igmp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.VirtualTemplate.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.VirtualTemplate.Ip.Arp)), ("vrf", ("vrf", Native.Interface.VirtualTemplate.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.VirtualTemplate.Ip.NoAddress)), ("address", ("address", Native.Interface.VirtualTemplate.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.VirtualTemplate.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.VirtualTemplate.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.VirtualTemplate.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.VirtualTemplate.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.VirtualTemplate.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.VirtualTemplate.Ip.Pim)), ("policy", ("policy", Native.Interface.VirtualTemplate.Ip.Policy)), ("rip", ("rip", Native.Interface.VirtualTemplate.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.VirtualTemplate.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.VirtualTemplate.Ip.RouteCache)), ("router", ("router", Native.Interface.VirtualTemplate.Ip.Router)), ("tcp", ("tcp", Native.Interface.VirtualTemplate.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.VirtualTemplate.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.VirtualTemplate.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.VirtualTemplate.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.VirtualTemplate.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.VirtualTemplate.Ip.Igmp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.VirtualTemplate.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.VirtualTemplate.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.VirtualTemplate.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.VirtualTemplate.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.VirtualTemplate.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.VirtualTemplate.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.VirtualTemplate.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.VirtualTemplate.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.VirtualTemplate.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.VirtualTemplate.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.VirtualTemplate.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.VirtualTemplate.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.VirtualTemplate.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.VirtualTemplate.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.VirtualTemplate.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.VirtualTemplate.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.VirtualTemplate.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.VirtualTemplate.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.VirtualTemplate.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.VirtualTemplate.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.VirtualTemplate.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.VirtualTemplate.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.VirtualTemplate.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.VirtualTemplate.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.VirtualTemplate.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.VirtualTemplate.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.VirtualTemplate.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.VirtualTemplate.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.VirtualTemplate.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.VirtualTemplate.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.VirtualTemplate.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.VirtualTemplate.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.VirtualTemplate.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.VirtualTemplate.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.VirtualTemplate.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.VirtualTemplate.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.VirtualTemplate.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.VirtualTemplate.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.VirtualTemplate.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.VirtualTemplate.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.VirtualTemplate.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.VirtualTemplate.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.VirtualTemplate.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.VirtualTemplate.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.VirtualTemplate.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.VirtualTemplate.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.VirtualTemplate.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.VirtualTemplate.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.VirtualTemplate.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.VirtualTemplate.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.VirtualTemplate.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.VirtualTemplate.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.VirtualTemplate.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.VirtualTemplate.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.VirtualTemplate.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.VirtualTemplate.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.VirtualTemplate.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.VirtualTemplate.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.VirtualTemplate.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.VirtualTemplate.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.VirtualTemplate.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.VirtualTemplate.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.VirtualTemplate.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.TrafficFilter>`
                
                .. attribute:: crypto
                
                	Encryption/Decryption commands
                	**type**\:  :py:class:`Crypto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.Crypto>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.VirtualTemplate.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.VirtualTemplate.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.VirtualTemplate.Ipv6.Dhcp)), ("address", ("address", Native.Interface.VirtualTemplate.Ipv6.Address)), ("nd", ("nd", Native.Interface.VirtualTemplate.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.VirtualTemplate.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.VirtualTemplate.Ipv6.TrafficFilter)), ("Cisco-IOS-XE-crypto:crypto", ("crypto", Native.Interface.VirtualTemplate.Ipv6.Crypto))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.VirtualTemplate.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.VirtualTemplate.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.VirtualTemplate.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.VirtualTemplate.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.crypto = Native.Interface.VirtualTemplate.Ipv6.Crypto()
                    self.crypto.parent = self
                    self._children_name_map["crypto"] = "Cisco-IOS-XE-crypto:crypto"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.VirtualTemplate.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.VirtualTemplate.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.VirtualTemplate.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.VirtualTemplate.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Crypto(Entity):
                    """
                    Encryption/Decryption commands
                    
                    .. attribute:: map
                    
                    	Assign an IPv6  Crypto Map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ipv6.Crypto, self).__init__()

                        self.yang_name = "crypto"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('map', (YLeaf(YType.str, 'map'), ['str'])),
                        ])
                        self.map = None
                        self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ipv6.Crypto, ['map'], name, value)


            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.VirtualTemplate.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.VirtualTemplate.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.VirtualTemplate.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.VirtualTemplate.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.VirtualTemplate.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.VirtualTemplate.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.VirtualTemplate.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.VirtualTemplate.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.VirtualTemplate.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.VirtualTemplate.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.VirtualTemplate.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.VirtualTemplate.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.VirtualTemplate.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.VirtualTemplate.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.VirtualTemplate.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.VirtualTemplate.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.VirtualTemplate.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.VirtualTemplate.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.VirtualTemplate.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.VirtualTemplate.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.VirtualTemplate.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.VirtualTemplate.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.VirtualTemplate.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.VirtualTemplate.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.VirtualTemplate.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.VirtualTemplate.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.VirtualTemplate.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.VirtualTemplate.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.VirtualTemplate.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.VirtualTemplate.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.VirtualTemplate.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.VirtualTemplate.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.VirtualTemplate.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.VirtualTemplate.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.VirtualTemplate.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.VirtualTemplate.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.VirtualTemplate.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.VirtualTemplate.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.VirtualTemplate.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.VirtualTemplate.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.VirtualTemplate.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.VirtualTemplate.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.VirtualTemplate.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.VirtualTemplate.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.VirtualTemplate.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.VirtualTemplate.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.VirtualTemplate.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.VirtualTemplate.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.VirtualTemplate.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.VirtualTemplate.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.VirtualTemplate.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.VirtualTemplate.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.VirtualTemplate.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.VirtualTemplate.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.VirtualTemplate.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.VirtualTemplate.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.VirtualTemplate.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.VirtualTemplate.CarrierDelay.Down)), ("up", ("up", Native.Interface.VirtualTemplate.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.VirtualTemplate.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.VirtualTemplate.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.VirtualTemplate.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.VirtualTemplate.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.VirtualTemplate.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.VirtualTemplate.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.VirtualTemplate.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.VirtualTemplate.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.VirtualTemplate.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.VirtualTemplate.Plim.Ethernet)), ("qos", ("qos", Native.Interface.VirtualTemplate.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.VirtualTemplate.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.VirtualTemplate.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.VirtualTemplate.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.VirtualTemplate.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.VirtualTemplate.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.VirtualTemplate.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.VirtualTemplate.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.VirtualTemplate.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.VirtualTemplate.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.VirtualTemplate.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.L2protocol>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.VirtualTemplate.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.VirtualTemplate.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.VirtualTemplate.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.VirtualTemplate.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.VirtualTemplate.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.VirtualTemplate.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.VirtualTemplate.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.VirtualTemplate.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.VirtualTemplate.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.VirtualTemplate.Service.Instance.L2protocol))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.VirtualTemplate.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.VirtualTemplate.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.VirtualTemplate.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.VirtualTemplate.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.VirtualTemplate.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.VirtualTemplate.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.VirtualTemplate.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.VirtualTemplate.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.VirtualTemplate.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.VirtualTemplate.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.VirtualTemplate.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.VirtualTemplate.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.VirtualTemplate.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.VirtualTemplate.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.VirtualTemplate.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.VirtualTemplate.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.VirtualTemplate.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.VirtualTemplate.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.VirtualTemplate.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.VirtualTemplate.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.VirtualTemplate.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.VirtualTemplate.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.VirtualTemplate.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.VirtualTemplate.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.VirtualTemplate.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.VirtualTemplate.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.VirtualTemplate.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.VirtualTemplate.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.VirtualTemplate.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.VirtualTemplate.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.VirtualTemplate.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.VirtualTemplate.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



            class Lacp(Entity):
                """
                LACP interface subcommands
                
                .. attribute:: port_priority
                
                	LACP priority on this interface 
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rate
                
                	Rate at which the LACP packets are requested to be ingressed to this interface
                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Lacp.Rate>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Lacp, self).__init__()

                    self.yang_name = "lacp"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_priority', (YLeaf(YType.uint32, 'port-priority'), ['int'])),
                        ('rate', (YLeaf(YType.enumeration, 'rate'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Lacp.Rate')])),
                    ])
                    self.port_priority = None
                    self.rate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:lacp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Lacp, ['port_priority', 'rate'], name, value)

                class Rate(Enum):
                    """
                    Rate (Enum Class)

                    Rate at which the LACP packets are requested to be ingressed to this interface

                    .. data:: fast = 0

                    .. data:: normal = 1

                    """

                    fast = Enum.YLeaf(0, "fast")

                    normal = Enum.YLeaf(1, "normal")



            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.VirtualTemplate.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.VirtualTemplate.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.VirtualTemplate.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.VirtualTemplate.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.VirtualTemplate.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.VirtualTemplate.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.VirtualTemplate.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.VirtualTemplate.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.VirtualTemplate.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.VirtualTemplate.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Nhrp(Entity):
                """
                NHRP Interface commands
                
                .. attribute:: event_publisher
                
                	Enable NHRP smart spoke feature
                	**type**\:  :py:class:`EventPublisher <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Nhrp.EventPublisher>`
                
                .. attribute:: group
                
                	group name string
                	**type**\: str
                
                .. attribute:: map
                
                	Map group name to QoS service policy
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Nhrp.Map>`
                
                .. attribute:: route_watch
                
                	Enable NHRP route watch
                	**type**\: bool
                
                

                """

                _prefix = 'ios-tun'
                _revision = '2017-08-28'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Nhrp, self).__init__()

                    self.yang_name = "nhrp"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event-publisher", ("event_publisher", Native.Interface.VirtualTemplate.Nhrp.EventPublisher)), ("map", ("map", Native.Interface.VirtualTemplate.Nhrp.Map))])
                    self._leafs = OrderedDict([
                        ('group', (YLeaf(YType.str, 'group'), ['str'])),
                        ('route_watch', (YLeaf(YType.boolean, 'route-watch'), ['bool'])),
                    ])
                    self.group = None
                    self.route_watch = None

                    self.event_publisher = Native.Interface.VirtualTemplate.Nhrp.EventPublisher()
                    self.event_publisher.parent = self
                    self._children_name_map["event_publisher"] = "event-publisher"

                    self.map = Native.Interface.VirtualTemplate.Nhrp.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"
                    self._segment_path = lambda: "Cisco-IOS-XE-tunnel:nhrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Nhrp, [u'group', u'route_watch'], name, value)


                class EventPublisher(Entity):
                    """
                    Enable NHRP smart spoke feature
                    
                    .. attribute:: max_event_timeout
                    
                    	Number of seconds
                    	**type**\: int
                    
                    	**range:** 1..22
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Nhrp.EventPublisher, self).__init__()

                        self.yang_name = "event-publisher"
                        self.yang_parent_name = "nhrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_event_timeout', (YLeaf(YType.uint8, 'max-event-timeout'), ['int'])),
                        ])
                        self.max_event_timeout = None
                        self._segment_path = lambda: "event-publisher"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Nhrp.EventPublisher, [u'max_event_timeout'], name, value)


                class Map(Entity):
                    """
                    Map group name to QoS service policy
                    
                    .. attribute:: group
                    
                    	NHRP group mapping
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Nhrp.Map.Group>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Nhrp.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "nhrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group", ("group", Native.Interface.VirtualTemplate.Nhrp.Map.Group))])
                        self._leafs = OrderedDict()

                        self.group = Native.Interface.VirtualTemplate.Nhrp.Map.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Nhrp.Map, [], name, value)


                    class Group(Entity):
                        """
                        NHRP group mapping
                        
                        .. attribute:: nhrp_name
                        
                        	
                        	**type**\: list of  		 :py:class:`NhrpName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Nhrp.Map.Group.NhrpName>`
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Nhrp.Map.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nhrp-name", ("nhrp_name", Native.Interface.VirtualTemplate.Nhrp.Map.Group.NhrpName))])
                            self._leafs = OrderedDict()

                            self.nhrp_name = YList(self)
                            self._segment_path = lambda: "group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Nhrp.Map.Group, [], name, value)


                        class NhrpName(Entity):
                            """
                            
                            
                            .. attribute:: nhrp_name  (key)
                            
                            	NHRP group name
                            	**type**\: str
                            
                            .. attribute:: service_policy
                            
                            	QoS service\-policy
                            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Nhrp.Map.Group.NhrpName.ServicePolicy>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Nhrp.Map.Group.NhrpName, self).__init__()

                                self.yang_name = "nhrp-name"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['nhrp_name']
                                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.VirtualTemplate.Nhrp.Map.Group.NhrpName.ServicePolicy))])
                                self._leafs = OrderedDict([
                                    ('nhrp_name', (YLeaf(YType.str, 'nhrp-name'), ['str'])),
                                ])
                                self.nhrp_name = None

                                self.service_policy = Native.Interface.VirtualTemplate.Nhrp.Map.Group.NhrpName.ServicePolicy()
                                self.service_policy.parent = self
                                self._children_name_map["service_policy"] = "service-policy"
                                self._segment_path = lambda: "nhrp-name" + "[nhrp-name='" + str(self.nhrp_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Nhrp.Map.Group.NhrpName, [u'nhrp_name'], name, value)


                            class ServicePolicy(Entity):
                                """
                                QoS service\-policy
                                
                                .. attribute:: output
                                
                                	QoS policy\-map name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Nhrp.Map.Group.NhrpName.ServicePolicy, self).__init__()

                                    self.yang_name = "service-policy"
                                    self.yang_parent_name = "nhrp-name"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                                    ])
                                    self.output = None
                                    self._segment_path = lambda: "service-policy"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Nhrp.Map.Group.NhrpName.ServicePolicy, [u'output'], name, value)


            class Tunnel(Entity):
                """
                protocol\-over\-protocol tunneling
                
                .. attribute:: tun_6rd
                
                	set tunnel 6rd parameters
                	**type**\:  :py:class:`Tun6rd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Tun6rd>`
                
                .. attribute:: bandwidth
                
                	Set tunnel bandwidth informational parameter
                	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Bandwidth>`
                
                .. attribute:: checksum
                
                	enable end to end checksumming of packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: source
                
                	source of tunnel packets
                	**type**\: str
                
                .. attribute:: destination
                
                	destination of tunnel
                	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Destination>`
                
                .. attribute:: dst_port
                
                	tunnel destination port
                	**type**\:  :py:class:`DstPort <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.DstPort>`
                
                .. attribute:: endpoint
                
                	Set endpoint parameter
                	**type**\:  :py:class:`Endpoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Endpoint>`
                
                .. attribute:: entropy
                
                	Compute hash (entropy) on payload and propagate to tunnel header
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: fixup
                
                	fixup on tunnel interface
                	**type**\:  :py:class:`Fixup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Fixup>`
                
                .. attribute:: flow
                
                	flow options
                	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Flow>`
                
                .. attribute:: key
                
                	security or selector key
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mode
                
                	tunnel encapsulation method
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode>`
                
                .. attribute:: network_id
                
                	Set network\-id
                	**type**\:  :py:class:`NetworkId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.NetworkId>`
                
                .. attribute:: path_mtu_discovery
                
                	Enable Path MTU Discovery on tunnel
                	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.PathMtuDiscovery>`
                
                	**presence node**\: True
                
                .. attribute:: protection
                
                	Enable tunnel protection
                	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Protection>`
                
                .. attribute:: mpls
                
                	
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls>`
                
                .. attribute:: raw_packet_interface
                
                	physical interface for all packets entering itto be tunneled and for all packets entering the tunnel to exit
                	**type**\: str
                
                .. attribute:: rbscp
                
                	Set tunnel RBSCP parameters
                	**type**\:  :py:class:`Rbscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Rbscp>`
                
                .. attribute:: snooping
                
                	Snooping on tunnel
                	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Snooping>`
                
                .. attribute:: src_port
                
                	tunnel source port
                	**type**\:  :py:class:`SrcPort <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.SrcPort>`
                
                .. attribute:: tos
                
                	set type of sevice byte
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: ttl
                
                	set time to live
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: udlr
                
                	associate tunnel with unidirectional interface
                	**type**\:  :py:class:`Udlr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Udlr>`
                
                .. attribute:: vlan
                
                	Set vlan\-id for ethernet over gre mode
                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Vlan>`
                
                .. attribute:: vrf
                
                	set tunnel vrf membership
                	**type**\: str
                
                

                """

                _prefix = 'ios-tun'
                _revision = '2017-08-28'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Tunnel, self).__init__()

                    self.yang_name = "tunnel"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tun-6rd", ("tun_6rd", Native.Interface.VirtualTemplate.Tunnel.Tun6rd)), ("bandwidth", ("bandwidth", Native.Interface.VirtualTemplate.Tunnel.Bandwidth)), ("destination", ("destination", Native.Interface.VirtualTemplate.Tunnel.Destination)), ("dst-port", ("dst_port", Native.Interface.VirtualTemplate.Tunnel.DstPort)), ("endpoint", ("endpoint", Native.Interface.VirtualTemplate.Tunnel.Endpoint)), ("fixup", ("fixup", Native.Interface.VirtualTemplate.Tunnel.Fixup)), ("flow", ("flow", Native.Interface.VirtualTemplate.Tunnel.Flow)), ("mode", ("mode", Native.Interface.VirtualTemplate.Tunnel.Mode)), ("network-id", ("network_id", Native.Interface.VirtualTemplate.Tunnel.NetworkId)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Interface.VirtualTemplate.Tunnel.PathMtuDiscovery)), ("protection", ("protection", Native.Interface.VirtualTemplate.Tunnel.Protection)), ("mpls", ("mpls", Native.Interface.VirtualTemplate.Tunnel.Mpls)), ("rbscp", ("rbscp", Native.Interface.VirtualTemplate.Tunnel.Rbscp)), ("src-port", ("src_port", Native.Interface.VirtualTemplate.Tunnel.SrcPort)), ("udlr", ("udlr", Native.Interface.VirtualTemplate.Tunnel.Udlr)), ("vlan", ("vlan", Native.Interface.VirtualTemplate.Tunnel.Vlan))])
                    self._leafs = OrderedDict([
                        ('checksum', (YLeaf(YType.empty, 'checksum'), ['Empty'])),
                        ('source', (YLeaf(YType.str, 'source'), ['str'])),
                        ('entropy', (YLeaf(YType.empty, 'entropy'), ['Empty'])),
                        ('key', (YLeaf(YType.uint64, 'key'), ['int'])),
                        ('raw_packet_interface', (YLeaf(YType.str, 'raw-packet-interface'), ['str'])),
                        ('snooping', (YLeaf(YType.enumeration, 'snooping'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Tunnel.Snooping')])),
                        ('tos', (YLeaf(YType.uint8, 'tos'), ['int'])),
                        ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ])
                    self.checksum = None
                    self.source = None
                    self.entropy = None
                    self.key = None
                    self.raw_packet_interface = None
                    self.snooping = None
                    self.tos = None
                    self.ttl = None
                    self.vrf = None

                    self.tun_6rd = Native.Interface.VirtualTemplate.Tunnel.Tun6rd()
                    self.tun_6rd.parent = self
                    self._children_name_map["tun_6rd"] = "tun-6rd"

                    self.bandwidth = Native.Interface.VirtualTemplate.Tunnel.Bandwidth()
                    self.bandwidth.parent = self
                    self._children_name_map["bandwidth"] = "bandwidth"

                    self.destination = Native.Interface.VirtualTemplate.Tunnel.Destination()
                    self.destination.parent = self
                    self._children_name_map["destination"] = "destination"

                    self.dst_port = Native.Interface.VirtualTemplate.Tunnel.DstPort()
                    self.dst_port.parent = self
                    self._children_name_map["dst_port"] = "dst-port"

                    self.endpoint = Native.Interface.VirtualTemplate.Tunnel.Endpoint()
                    self.endpoint.parent = self
                    self._children_name_map["endpoint"] = "endpoint"

                    self.fixup = Native.Interface.VirtualTemplate.Tunnel.Fixup()
                    self.fixup.parent = self
                    self._children_name_map["fixup"] = "fixup"

                    self.flow = Native.Interface.VirtualTemplate.Tunnel.Flow()
                    self.flow.parent = self
                    self._children_name_map["flow"] = "flow"

                    self.mode = Native.Interface.VirtualTemplate.Tunnel.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.network_id = Native.Interface.VirtualTemplate.Tunnel.NetworkId()
                    self.network_id.parent = self
                    self._children_name_map["network_id"] = "network-id"

                    self.path_mtu_discovery = None
                    self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                    self.protection = Native.Interface.VirtualTemplate.Tunnel.Protection()
                    self.protection.parent = self
                    self._children_name_map["protection"] = "protection"

                    self.mpls = Native.Interface.VirtualTemplate.Tunnel.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"

                    self.rbscp = Native.Interface.VirtualTemplate.Tunnel.Rbscp()
                    self.rbscp.parent = self
                    self._children_name_map["rbscp"] = "rbscp"

                    self.src_port = Native.Interface.VirtualTemplate.Tunnel.SrcPort()
                    self.src_port.parent = self
                    self._children_name_map["src_port"] = "src-port"

                    self.udlr = Native.Interface.VirtualTemplate.Tunnel.Udlr()
                    self.udlr.parent = self
                    self._children_name_map["udlr"] = "udlr"

                    self.vlan = Native.Interface.VirtualTemplate.Tunnel.Vlan()
                    self.vlan.parent = self
                    self._children_name_map["vlan"] = "vlan"
                    self._segment_path = lambda: "Cisco-IOS-XE-tunnel:tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel, [u'checksum', u'source', u'entropy', u'key', u'raw_packet_interface', u'snooping', u'tos', u'ttl', u'vrf'], name, value)

                class Snooping(Enum):
                    """
                    Snooping (Enum Class)

                    Snooping on tunnel

                    .. data:: enable = 0

                    """

                    enable = Enum.YLeaf(0, "enable")



                class Tun6rd(Entity):
                    """
                    set tunnel 6rd parameters
                    
                    .. attribute:: br
                    
                    	Border Relay parameters
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv4
                    
                    	Common IPv4 transport source parameters
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Tun6rd.Ipv4>`
                    
                    .. attribute:: prefix
                    
                    	Provider selected common IPv6 prefix
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    .. attribute:: reverse_map_check
                    
                    	Enable source IP address and port verification
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Tun6rd, self).__init__()

                        self.yang_name = "tun-6rd"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.VirtualTemplate.Tunnel.Tun6rd.Ipv4))])
                        self._leafs = OrderedDict([
                            ('br', (YLeaf(YType.str, 'br'), ['str'])),
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ('reverse_map_check', (YLeaf(YType.empty, 'reverse-map-check'), ['Empty'])),
                        ])
                        self.br = None
                        self.prefix = None
                        self.reverse_map_check = None

                        self.ipv4 = Native.Interface.VirtualTemplate.Tunnel.Tun6rd.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._segment_path = lambda: "tun-6rd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Tun6rd, [u'br', u'prefix', u'reverse_map_check'], name, value)


                    class Ipv4(Entity):
                        """
                        Common IPv4 transport source parameters
                        
                        .. attribute:: prefix_len
                        
                        	Common IPv4 transport source prefix length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: suffix_len
                        
                        	Common IPv4 transport source suffix length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Tunnel.Tun6rd.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "tun-6rd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix_len', (YLeaf(YType.uint8, 'prefix-len'), ['int'])),
                                ('suffix_len', (YLeaf(YType.uint8, 'suffix-len'), ['int'])),
                            ])
                            self.prefix_len = None
                            self.suffix_len = None
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Tun6rd.Ipv4, [u'prefix_len', u'suffix_len'], name, value)


                class Bandwidth(Entity):
                    """
                    Set tunnel bandwidth informational parameter
                    
                    .. attribute:: receive
                    
                    	Receive bandwidth
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmit
                    
                    	Transmit bandwidth
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.uint32, 'receive'), ['int'])),
                            ('transmit', (YLeaf(YType.uint32, 'transmit'), ['int'])),
                        ])
                        self.receive = None
                        self.transmit = None
                        self._segment_path = lambda: "bandwidth"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Bandwidth, [u'receive', u'transmit'], name, value)


                class Destination(Entity):
                    """
                    destination of tunnel
                    
                    .. attribute:: ipaddress_or_host
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                    
                    .. attribute:: list
                    
                    	List of Tunnel destinations
                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Destination.List>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Destination, self).__init__()

                        self.yang_name = "destination"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("list", ("list", Native.Interface.VirtualTemplate.Tunnel.Destination.List))])
                        self._leafs = OrderedDict([
                            ('ipaddress_or_host', (YLeaf(YType.str, 'ipaddress-or-host'), ['str','str','str'])),
                        ])
                        self.ipaddress_or_host = None

                        self.list = Native.Interface.VirtualTemplate.Tunnel.Destination.List()
                        self.list.parent = self
                        self._children_name_map["list"] = "list"
                        self._segment_path = lambda: "destination"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Destination, [u'ipaddress_or_host'], name, value)


                    class List(Entity):
                        """
                        List of Tunnel destinations
                        
                        .. attribute:: mpls
                        
                        	MPLS destination list
                        	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Destination.List.Mpls>`
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Tunnel.Destination.List, self).__init__()

                            self.yang_name = "list"
                            self.yang_parent_name = "destination"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mpls", ("mpls", Native.Interface.VirtualTemplate.Tunnel.Destination.List.Mpls))])
                            self._leafs = OrderedDict()

                            self.mpls = Native.Interface.VirtualTemplate.Tunnel.Destination.List.Mpls()
                            self.mpls.parent = self
                            self._children_name_map["mpls"] = "mpls"
                            self._segment_path = lambda: "list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Destination.List, [], name, value)


                        class Mpls(Entity):
                            """
                            MPLS destination list
                            
                            .. attribute:: traffic_eng
                            
                            	MPLS Traffic Engineering destination list
                            	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Destination.List.Mpls.TrafficEng>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Destination.List.Mpls, self).__init__()

                                self.yang_name = "mpls"
                                self.yang_parent_name = "list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("traffic-eng", ("traffic_eng", Native.Interface.VirtualTemplate.Tunnel.Destination.List.Mpls.TrafficEng))])
                                self._leafs = OrderedDict()

                                self.traffic_eng = Native.Interface.VirtualTemplate.Tunnel.Destination.List.Mpls.TrafficEng()
                                self.traffic_eng.parent = self
                                self._children_name_map["traffic_eng"] = "traffic-eng"
                                self._segment_path = lambda: "mpls"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Destination.List.Mpls, [], name, value)


                            class TrafficEng(Entity):
                                """
                                MPLS Traffic Engineering destination list
                                
                                .. attribute:: name
                                
                                	Specify a destination list by name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Destination.List.Mpls.TrafficEng, self).__init__()

                                    self.yang_name = "traffic-eng"
                                    self.yang_parent_name = "mpls"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "traffic-eng"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Destination.List.Mpls.TrafficEng, [u'name'], name, value)


                class DstPort(Entity):
                    """
                    tunnel destination port
                    
                    .. attribute:: port_num
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dynamic
                    
                    	Set Destination Port Dynamically
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.DstPort, self).__init__()

                        self.yang_name = "dst-port"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_num', (YLeaf(YType.uint16, 'port-num'), ['int'])),
                            ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                        ])
                        self.port_num = None
                        self.dynamic = None
                        self._segment_path = lambda: "dst-port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.DstPort, [u'port_num', u'dynamic'], name, value)


                class Endpoint(Entity):
                    """
                    Set endpoint parameter
                    
                    .. attribute:: service_policy
                    
                    	Set service\-policy
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Endpoint.ServicePolicy>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Endpoint, self).__init__()

                        self.yang_name = "endpoint"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Interface.VirtualTemplate.Tunnel.Endpoint.ServicePolicy))])
                        self._leafs = OrderedDict()

                        self.service_policy = Native.Interface.VirtualTemplate.Tunnel.Endpoint.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"
                        self._segment_path = lambda: "endpoint"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Endpoint, [], name, value)


                    class ServicePolicy(Entity):
                        """
                        Set service\-policy
                        
                        .. attribute:: output
                        
                        	apply QoS service policy in the output direction
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Tunnel.Endpoint.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "endpoint"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('output', (YLeaf(YType.str, 'output'), ['str'])),
                            ])
                            self.output = None
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Endpoint.ServicePolicy, [u'output'], name, value)


                class Fixup(Entity):
                    """
                    fixup on tunnel interface
                    
                    .. attribute:: nat
                    
                    	enable post nat fixup 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Fixup, self).__init__()

                        self.yang_name = "fixup"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('nat', (YLeaf(YType.empty, 'nat'), ['Empty'])),
                        ])
                        self.nat = None
                        self._segment_path = lambda: "fixup"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Fixup, [u'nat'], name, value)


                class Flow(Entity):
                    """
                    flow options
                    
                    .. attribute:: egress_records
                    
                    	enable egress flow records 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Flow, self).__init__()

                        self.yang_name = "flow"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('egress_records', (YLeaf(YType.empty, 'egress-records'), ['Empty'])),
                        ])
                        self.egress_records = None
                        self._segment_path = lambda: "flow"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Flow, [u'egress_records'], name, value)


                class Mode(Entity):
                    """
                    tunnel encapsulation method
                    
                    .. attribute:: ipsec
                    
                    	IPSec tunnel encapsulation
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Ipsec>`
                    
                    .. attribute:: mpls
                    
                    	MPLS encapsulations
                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Mpls>`
                    
                    .. attribute:: ethernet
                    
                    	Ethernet over gre
                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Ethernet>`
                    
                    .. attribute:: gre
                    
                    	generic route encapsulation protocol
                    	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Gre>`
                    
                    .. attribute:: ipip
                    
                    	IP over IP encapsulation
                    	**type**\:  :py:class:`Ipip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Ipip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Generic packet tunneling in IPv6
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipv6ip
                    
                    	IPv6 over IP encapsulation
                    	**type**\:  :py:class:`Ipv6ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Ipv6ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: udp
                    
                    	UDP encapsulation protocol
                    	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Udp>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Interface.VirtualTemplate.Tunnel.Mode.Ipsec)), ("mpls", ("mpls", Native.Interface.VirtualTemplate.Tunnel.Mode.Mpls)), ("ethernet", ("ethernet", Native.Interface.VirtualTemplate.Tunnel.Mode.Ethernet)), ("gre", ("gre", Native.Interface.VirtualTemplate.Tunnel.Mode.Gre)), ("ipip", ("ipip", Native.Interface.VirtualTemplate.Tunnel.Mode.Ipip)), ("ipv6ip", ("ipv6ip", Native.Interface.VirtualTemplate.Tunnel.Mode.Ipv6ip))])
                        self._leafs = OrderedDict([
                            ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                            ('udp', (YLeaf(YType.enumeration, 'udp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Tunnel.Mode.Udp')])),
                        ])
                        self.ipv6 = None
                        self.udp = None

                        self.ipsec = Native.Interface.VirtualTemplate.Tunnel.Mode.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"

                        self.mpls = Native.Interface.VirtualTemplate.Tunnel.Mode.Mpls()
                        self.mpls.parent = self
                        self._children_name_map["mpls"] = "mpls"

                        self.ethernet = Native.Interface.VirtualTemplate.Tunnel.Mode.Ethernet()
                        self.ethernet.parent = self
                        self._children_name_map["ethernet"] = "ethernet"

                        self.gre = Native.Interface.VirtualTemplate.Tunnel.Mode.Gre()
                        self.gre.parent = self
                        self._children_name_map["gre"] = "gre"

                        self.ipip = None
                        self._children_name_map["ipip"] = "ipip"

                        self.ipv6ip = None
                        self._children_name_map["ipv6ip"] = "ipv6ip"
                        self._segment_path = lambda: "mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mode, [u'ipv6', u'udp'], name, value)

                    class Udp(Enum):
                        """
                        Udp (Enum Class)

                        UDP encapsulation protocol

                        .. data:: ip = 0

                        .. data:: multipoint = 1

                        """

                        ip = Enum.YLeaf(0, "ip")

                        multipoint = Enum.YLeaf(1, "multipoint")



                    class Ipsec(Entity):
                        """
                        IPSec tunnel encapsulation
                        
                        .. attribute:: ipv4
                        
                        	over IPv4
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Ipsec.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	over IPv6
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Ipsec.Ipv6>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Tunnel.Mode.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Interface.VirtualTemplate.Tunnel.Mode.Ipsec.Ipv4)), ("ipv6", ("ipv6", Native.Interface.VirtualTemplate.Tunnel.Mode.Ipsec.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = None
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "ipsec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mode.Ipsec, [], name, value)


                        class Ipv4(Entity):
                            """
                            over IPv4
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mode.Ipsec.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True


                        class Ipv6(Entity):
                            """
                            over IPv6
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mode.Ipsec.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True


                    class Mpls(Entity):
                        """
                        MPLS encapsulations
                        
                        .. attribute:: traffic_eng
                        
                        	Traffic engineering tunnels
                        	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Mpls.TrafficEng>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Tunnel.Mode.Mpls, self).__init__()

                            self.yang_name = "mpls"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("traffic-eng", ("traffic_eng", Native.Interface.VirtualTemplate.Tunnel.Mode.Mpls.TrafficEng))])
                            self._leafs = OrderedDict()

                            self.traffic_eng = None
                            self._children_name_map["traffic_eng"] = "traffic-eng"
                            self._segment_path = lambda: "mpls"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mode.Mpls, [], name, value)


                        class TrafficEng(Entity):
                            """
                            Traffic engineering tunnels
                            
                            .. attribute:: multilsp
                            
                            	Multiple LSP mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: point_to_multipoint
                            
                            	point\-to\-multipoint tunnel mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mode.Mpls.TrafficEng, self).__init__()

                                self.yang_name = "traffic-eng"
                                self.yang_parent_name = "mpls"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('multilsp', (YLeaf(YType.empty, 'multilsp'), ['Empty'])),
                                    ('point_to_multipoint', (YLeaf(YType.empty, 'point-to-multipoint'), ['Empty'])),
                                ])
                                self.multilsp = None
                                self.point_to_multipoint = None
                                self._segment_path = lambda: "traffic-eng"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mode.Mpls.TrafficEng, [u'multilsp', u'point_to_multipoint'], name, value)


                    class Ethernet(Entity):
                        """
                        Ethernet over gre
                        
                        .. attribute:: gre
                        
                        	Ethernet over gre
                        	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Ethernet.Gre>`
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Tunnel.Mode.Ethernet, self).__init__()

                            self.yang_name = "ethernet"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('gre', (YLeaf(YType.enumeration, 'gre'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Tunnel.Mode.Ethernet.Gre')])),
                            ])
                            self.gre = None
                            self._segment_path = lambda: "ethernet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mode.Ethernet, [u'gre'], name, value)

                        class Gre(Enum):
                            """
                            Gre (Enum Class)

                            Ethernet over gre

                            .. data:: ipv4 = 0

                            .. data:: ipv6 = 1

                            """

                            ipv4 = Enum.YLeaf(0, "ipv4")

                            ipv6 = Enum.YLeaf(1, "ipv6")



                    class Gre(Entity):
                        """
                        generic route encapsulation protocol
                        
                        .. attribute:: ip
                        
                        	over IP
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6
                        
                        	over IPv6
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multipoint
                        
                        	over IPv4 (multipoint)
                        	**type**\:  :py:class:`Multipoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mode.Gre.Multipoint>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Tunnel.Mode.Gre, self).__init__()

                            self.yang_name = "gre"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("multipoint", ("multipoint", Native.Interface.VirtualTemplate.Tunnel.Mode.Gre.Multipoint))])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                            ])
                            self.ip = None
                            self.ipv6 = None

                            self.multipoint = None
                            self._children_name_map["multipoint"] = "multipoint"
                            self._segment_path = lambda: "gre"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mode.Gre, [u'ip', u'ipv6'], name, value)


                        class Multipoint(Entity):
                            """
                            over IPv4 (multipoint)
                            
                            .. attribute:: ipv6
                            
                            	over IPv6
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mode.Gre.Multipoint, self).__init__()

                                self.yang_name = "multipoint"
                                self.yang_parent_name = "gre"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                                ])
                                self.ipv6 = None
                                self._segment_path = lambda: "multipoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mode.Gre.Multipoint, [u'ipv6'], name, value)


                    class Ipip(Entity):
                        """
                        IP over IP encapsulation
                        
                        .. attribute:: decapsulate_any
                        
                        	Incoming traffic only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Tunnel.Mode.Ipip, self).__init__()

                            self.yang_name = "ipip"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('decapsulate_any', (YLeaf(YType.empty, 'decapsulate-any'), ['Empty'])),
                            ])
                            self.decapsulate_any = None
                            self._segment_path = lambda: "ipip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mode.Ipip, [u'decapsulate_any'], name, value)


                    class Ipv6ip(Entity):
                        """
                        IPv6 over IP encapsulation
                        
                        .. attribute:: auto_6rd
                        
                        	IPv6 automatic tunnelling using 6rd
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: auto_6to4
                        
                        	IPv6 automatic tunnelling using 6to4
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: isatap
                        
                        	IPv6 automatic tunnelling using ISATAP
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Tunnel.Mode.Ipv6ip, self).__init__()

                            self.yang_name = "ipv6ip"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('auto_6rd', (YLeaf(YType.empty, 'auto-6rd'), ['Empty'])),
                                ('auto_6to4', (YLeaf(YType.empty, 'auto-6to4'), ['Empty'])),
                                ('isatap', (YLeaf(YType.empty, 'isatap'), ['Empty'])),
                            ])
                            self.auto_6rd = None
                            self.auto_6to4 = None
                            self.isatap = None
                            self._segment_path = lambda: "ipv6ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mode.Ipv6ip, [u'auto_6rd', u'auto_6to4', u'isatap'], name, value)


                class NetworkId(Entity):
                    """
                    Set network\-id
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nexthop
                    
                    	nexthop
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: qos
                    
                    	QoS profile
                    	**type**\: str
                    
                    .. attribute:: weight
                    
                    	weight
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.NetworkId, self).__init__()

                        self.yang_name = "network-id"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('nexthop', (YLeaf(YType.str, 'nexthop'), ['str'])),
                            ('qos', (YLeaf(YType.str, 'qos'), ['str'])),
                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                        ])
                        self.id = None
                        self.nexthop = None
                        self.qos = None
                        self.weight = None
                        self._segment_path = lambda: "network-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.NetworkId, [u'id', u'nexthop', u'qos', u'weight'], name, value)


                class PathMtuDiscovery(Entity):
                    """
                    Enable Path MTU Discovery on tunnel
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.PathMtuDiscovery, self).__init__()

                        self.yang_name = "path-mtu-discovery"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "path-mtu-discovery"
                        self._is_frozen = True


                class Protection(Entity):
                    """
                    Enable tunnel protection
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Protection, self).__init__()

                        self.yang_name = "protection"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "protection"
                        self._is_frozen = True


                class Mpls(Entity):
                    """
                    
                    
                    .. attribute:: traffic_eng
                    
                    	
                    	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("traffic-eng", ("traffic_eng", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng))])
                        self._leafs = OrderedDict()

                        self.traffic_eng = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng()
                        self.traffic_eng.parent = self
                        self._children_name_map["traffic_eng"] = "traffic-eng"
                        self._segment_path = lambda: "mpls"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls, [], name, value)


                    class TrafficEng(Entity):
                        """
                        
                        
                        .. attribute:: affinity_mask
                        
                        	desired link affinity attributes
                        	**type**\:  :py:class:`AffinityMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AffinityMask>`
                        
                        .. attribute:: auto_bw
                        
                        	Specify mpls tunnel should automatically change BW
                        	**type**\:  :py:class:`AutoBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AutoBw>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: autoroute
                        
                        	parameters for routing over tunnel
                        	**type**\:  :py:class:`Autoroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Autoroute>`
                        
                        .. attribute:: backup_bw
                        
                        	
                        	**type**\:  :py:class:`BackupBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw>`
                        
                        .. attribute:: bandwidth
                        
                        	tunnel bandwidth requirement
                        	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Bandwidth>`
                        
                        .. attribute:: bfd
                        
                        	Bidirectional Forwarding Detection (BFD) configuration
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Bfd>`
                        
                        .. attribute:: binding_sid
                        
                        	Binding Segment Identifier
                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BindingSid>`
                        
                        .. attribute:: exp
                        
                        	Set the experimental values allowed for this interface
                        	**type**\:  :py:class:`Exp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Exp>`
                        
                        .. attribute:: exp_bundle
                        
                        	Configure the tunnel as a bundle
                        	**type**\:  :py:class:`ExpBundle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ExpBundle>`
                        
                        .. attribute:: fast_reroute
                        
                        	Specify mpls tunnel can be fast\-rerouted
                        	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.FastReroute>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forwarding_adjacency
                        
                        	Treat this tunnel as a Forwarding Adjacency
                        	**type**\:  :py:class:`ForwardingAdjacency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ForwardingAdjacency>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: interface
                        
                        	Add tunnel interface config
                        	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Interface_>`
                        
                        .. attribute:: load_share
                        
                        	Specify tunnel load\-sharing metric\: <0..1000000>
                        	**type**\: int
                        
                        	**range:** 0..1000000
                        
                        .. attribute:: name
                        
                        	specify a name describing the TE tunnel
                        	**type**\: str
                        
                        	**length:** 1..63
                        
                        .. attribute:: path_option
                        
                        	
                        	**type**\:  :py:class:`PathOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption>`
                        
                        .. attribute:: path_selection
                        
                        	Path Selection Configuration
                        	**type**\:  :py:class:`PathSelection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection>`
                        
                        .. attribute:: priority
                        
                        	Tunnel priority
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Priority>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: record_route
                        
                        	record the route used by the tunnel
                        	**type**\:  :py:class:`RecordRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.RecordRoute>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-tun'
                        _revision = '2017-08-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng, self).__init__()

                            self.yang_name = "traffic-eng"
                            self.yang_parent_name = "mpls"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("affinity-mask", ("affinity_mask", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AffinityMask)), ("auto-bw", ("auto_bw", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AutoBw)), ("autoroute", ("autoroute", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Autoroute)), ("backup-bw", ("backup_bw", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw)), ("bandwidth", ("bandwidth", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Bandwidth)), ("bfd", ("bfd", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Bfd)), ("binding-sid", ("binding_sid", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BindingSid)), ("exp", ("exp", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Exp)), ("exp-bundle", ("exp_bundle", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ExpBundle)), ("fast-reroute", ("fast_reroute", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.FastReroute)), ("forwarding-adjacency", ("forwarding_adjacency", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ForwardingAdjacency)), ("interface", ("interface", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Interface_)), ("path-option", ("path_option", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption)), ("path-selection", ("path_selection", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection)), ("priority", ("priority", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Priority)), ("record-route", ("record_route", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.RecordRoute))])
                            self._leafs = OrderedDict([
                                ('load_share', (YLeaf(YType.uint32, 'load-share'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.load_share = None
                            self.name = None

                            self.affinity_mask = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AffinityMask()
                            self.affinity_mask.parent = self
                            self._children_name_map["affinity_mask"] = "affinity-mask"

                            self.auto_bw = None
                            self._children_name_map["auto_bw"] = "auto-bw"

                            self.autoroute = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Autoroute()
                            self.autoroute.parent = self
                            self._children_name_map["autoroute"] = "autoroute"

                            self.backup_bw = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw()
                            self.backup_bw.parent = self
                            self._children_name_map["backup_bw"] = "backup-bw"

                            self.bandwidth = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Bandwidth()
                            self.bandwidth.parent = self
                            self._children_name_map["bandwidth"] = "bandwidth"

                            self.bfd = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Bfd()
                            self.bfd.parent = self
                            self._children_name_map["bfd"] = "bfd"

                            self.binding_sid = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BindingSid()
                            self.binding_sid.parent = self
                            self._children_name_map["binding_sid"] = "binding-sid"

                            self.exp = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Exp()
                            self.exp.parent = self
                            self._children_name_map["exp"] = "exp"

                            self.exp_bundle = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ExpBundle()
                            self.exp_bundle.parent = self
                            self._children_name_map["exp_bundle"] = "exp-bundle"

                            self.fast_reroute = None
                            self._children_name_map["fast_reroute"] = "fast-reroute"

                            self.forwarding_adjacency = None
                            self._children_name_map["forwarding_adjacency"] = "forwarding-adjacency"

                            self.interface = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Interface_()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"

                            self.path_option = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption()
                            self.path_option.parent = self
                            self._children_name_map["path_option"] = "path-option"

                            self.path_selection = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection()
                            self.path_selection.parent = self
                            self._children_name_map["path_selection"] = "path-selection"

                            self.priority = None
                            self._children_name_map["priority"] = "priority"

                            self.record_route = None
                            self._children_name_map["record_route"] = "record-route"
                            self._segment_path = lambda: "traffic-eng"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng, [u'load_share', u'name'], name, value)


                        class AffinityMask(Entity):
                            """
                            desired link affinity attributes
                            
                            .. attribute:: affinity
                            
                            	Desired link attributes for links comprising tunnel\: <0x0\-0xFFFFFFFF>
                            	**type**\: str
                            
                            	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                            
                            .. attribute:: mask
                            
                            	Mask on desired link attributes\: <0x0\-0xFFFFFFFF>
                            	**type**\: str
                            
                            	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AffinityMask, self).__init__()

                                self.yang_name = "affinity-mask"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('affinity', (YLeaf(YType.str, 'affinity'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.affinity = None
                                self.mask = None
                                self._segment_path = lambda: "affinity-mask"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AffinityMask, [u'affinity', u'mask'], name, value)


                        class AutoBw(Entity):
                            """
                            Specify mpls tunnel should automatically change BW
                            
                            .. attribute:: frequency
                            
                            	Frequency to change tunnel BW\: <300..604800>
                            	**type**\: int
                            
                            	**range:** 300..604800
                            
                            .. attribute:: collect_bw
                            
                            	Just collect bandwidth info on this tunnel
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: adjustment_threshold
                            
                            	Set the bandwidth change threshold to trigger adjustment
                            	**type**\: int
                            
                            	**range:** 1..99
                            
                            .. attribute:: overflow_limit
                            
                            	Set consecutive samples exceeding threshold which trigger adjustment\: <1..10>
                            	**type**\:  :py:class:`OverflowLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AutoBw.OverflowLimit>`
                            
                            .. attribute:: max_bw
                            
                            	Set the maximum bandwidth for auto\-bw on this tunnel\: <0..4294967295> (kbps)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_bw
                            
                            	Set the minimum bandwidth for auto\-bw on this tunnel\: <0..4294967294> (kbps)
                            	**type**\: int
                            
                            	**range:** 0..4294967294
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AutoBw, self).__init__()

                                self.yang_name = "auto-bw"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("overflow-limit", ("overflow_limit", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AutoBw.OverflowLimit))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('frequency', (YLeaf(YType.uint32, 'frequency'), ['int'])),
                                    ('collect_bw', (YLeaf(YType.empty, 'collect-bw'), ['Empty'])),
                                    ('adjustment_threshold', (YLeaf(YType.uint8, 'adjustment-threshold'), ['int'])),
                                    ('max_bw', (YLeaf(YType.uint32, 'max-bw'), ['int'])),
                                    ('min_bw', (YLeaf(YType.uint32, 'min-bw'), ['int'])),
                                ])
                                self.frequency = None
                                self.collect_bw = None
                                self.adjustment_threshold = None
                                self.max_bw = None
                                self.min_bw = None

                                self.overflow_limit = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AutoBw.OverflowLimit()
                                self.overflow_limit.parent = self
                                self._children_name_map["overflow_limit"] = "overflow-limit"
                                self._segment_path = lambda: "auto-bw"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AutoBw, [u'frequency', u'collect_bw', u'adjustment_threshold', u'max_bw', u'min_bw'], name, value)


                            class OverflowLimit(Entity):
                                """
                                Set consecutive samples exceeding threshold which trigger adjustment\: <1..10>
                                
                                .. attribute:: limit
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                .. attribute:: overflow_threshold
                                
                                	Set the bandwidth change threshold to trigger overflow adjustment\: <1..99> %
                                	**type**\: int
                                
                                	**range:** 1..99
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AutoBw.OverflowLimit, self).__init__()

                                    self.yang_name = "overflow-limit"
                                    self.yang_parent_name = "auto-bw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                                        ('overflow_threshold', (YLeaf(YType.uint8, 'overflow-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.overflow_threshold = None
                                    self._segment_path = lambda: "overflow-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.AutoBw.OverflowLimit, [u'limit', u'overflow_threshold'], name, value)


                        class Autoroute(Entity):
                            """
                            parameters for routing over tunnel
                            
                            .. attribute:: announce
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: metric
                            
                            	Specify mpls tunnel metric
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Autoroute.Metric>`
                            
                            .. attribute:: destination
                            
                            	announce tunnel destination to IP static route
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Autoroute, self).__init__()

                                self.yang_name = "autoroute"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Autoroute.Metric))])
                                self._leafs = OrderedDict([
                                    ('announce', (YLeaf(YType.empty, 'announce'), ['Empty'])),
                                    ('destination', (YLeaf(YType.empty, 'destination'), ['Empty'])),
                                ])
                                self.announce = None
                                self.destination = None

                                self.metric = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Autoroute.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "autoroute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Autoroute, [u'announce', u'destination'], name, value)


                            class Metric(Entity):
                                """
                                Specify mpls tunnel metric
                                
                                .. attribute:: range
                                
                                	Set tunnel metric for autoroutes\: <1..4294967295>
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: absolute
                                
                                	Set absolute metric for all autoroutes over tunnel\: <1..4294967295>
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: relative
                                
                                	Adjust tunnel metric for autoroutes relative to IGP\: <\-10..10>
                                	**type**\: int
                                
                                	**range:** \-10..10
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Autoroute.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "autoroute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                        ('absolute', (YLeaf(YType.uint32, 'absolute'), ['int'])),
                                        ('relative', (YLeaf(YType.int8, 'relative'), ['int'])),
                                    ])
                                    self.range = None
                                    self.absolute = None
                                    self.relative = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Autoroute.Metric, [u'range', u'absolute', u'relative'], name, value)


                        class BackupBw(Entity):
                            """
                            
                            
                            .. attribute:: bandwidth
                            
                            	Amount of allocatable backup bw, any lsp may use\: <1..4294967295> kbps
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: sub_pool
                            
                            	Enter Allocatable amount for Sub\-Pool bw
                            	**type**\:  :py:class:`SubPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool>`
                            
                            .. attribute:: class_type
                            
                            	
                            	**type**\:  :py:class:`ClassType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.ClassType>`
                            
                            .. attribute:: global_pool
                            
                            	
                            	**type**\:  :py:class:`GlobalPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.GlobalPool>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw, self).__init__()

                                self.yang_name = "backup-bw"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sub-pool", ("sub_pool", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool)), ("class-type", ("class_type", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.ClassType)), ("global-pool", ("global_pool", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.GlobalPool))])
                                self._leafs = OrderedDict([
                                    ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                ])
                                self.bandwidth = None

                                self.sub_pool = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool()
                                self.sub_pool.parent = self
                                self._children_name_map["sub_pool"] = "sub-pool"

                                self.class_type = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.ClassType()
                                self.class_type.parent = self
                                self._children_name_map["class_type"] = "class-type"

                                self.global_pool = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.GlobalPool()
                                self.global_pool.parent = self
                                self._children_name_map["global_pool"] = "global-pool"
                                self._segment_path = lambda: "backup-bw"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw, [u'bandwidth'], name, value)


                            class SubPool(Entity):
                                """
                                Enter Allocatable amount for Sub\-Pool bw
                                
                                .. attribute:: unlimited
                                
                                	Unlimited amount for Sub\-Pool bw
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sub_pool_config
                                
                                	
                                	**type**\:  :py:class:`SubPoolConfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool, self).__init__()

                                    self.yang_name = "sub-pool"
                                    self.yang_parent_name = "backup-bw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sub-pool-config", ("sub_pool_config", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig))])
                                    self._leafs = OrderedDict([
                                        ('unlimited', (YLeaf(YType.empty, 'unlimited'), ['Empty'])),
                                    ])
                                    self.unlimited = None

                                    self.sub_pool_config = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig()
                                    self.sub_pool_config.parent = self
                                    self._children_name_map["sub_pool_config"] = "sub-pool-config"
                                    self._segment_path = lambda: "sub-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool, [u'unlimited'], name, value)


                                class SubPoolConfig(Entity):
                                    """
                                    
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Amount of allocatable backup bw, only sub\-pool may use\: <1..4294967295> kbps
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: class_type
                                    
                                    	
                                    	**type**\:  :py:class:`ClassType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.ClassType>`
                                    
                                    .. attribute:: global_pool
                                    
                                    	
                                    	**type**\:  :py:class:`GlobalPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.GlobalPool>`
                                    
                                    

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig, self).__init__()

                                        self.yang_name = "sub-pool-config"
                                        self.yang_parent_name = "sub-pool"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("class-type", ("class_type", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.ClassType)), ("global-pool", ("global_pool", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.GlobalPool))])
                                        self._leafs = OrderedDict([
                                            ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                        ])
                                        self.bandwidth = None

                                        self.class_type = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.ClassType()
                                        self.class_type.parent = self
                                        self._children_name_map["class_type"] = "class-type"

                                        self.global_pool = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.GlobalPool()
                                        self.global_pool.parent = self
                                        self._children_name_map["global_pool"] = "global-pool"
                                        self._segment_path = lambda: "sub-pool-config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig, [u'bandwidth'], name, value)


                                    class ClassType(Entity):
                                        """
                                        
                                        
                                        .. attribute:: class_type_num
                                        
                                        	Enter the Class\-type\: <0..0>
                                        	**type**\: int
                                        
                                        	**range:** 0..1
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Amount of allocatable backup bw\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: unlimited
                                        
                                        	Unlimited amount of allocatable bw
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.ClassType, self).__init__()

                                            self.yang_name = "class-type"
                                            self.yang_parent_name = "sub-pool-config"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('class_type_num', (YLeaf(YType.uint8, 'class-type-num'), ['int'])),
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('unlimited', (YLeaf(YType.empty, 'unlimited'), ['Empty'])),
                                            ])
                                            self.class_type_num = None
                                            self.bandwidth = None
                                            self.unlimited = None
                                            self._segment_path = lambda: "class-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.ClassType, [u'class_type_num', u'bandwidth', u'unlimited'], name, value)


                                    class GlobalPool(Entity):
                                        """
                                        
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Amount of allocatable backup bw\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: unlimited
                                        
                                        	Unlimited amount of allocatable bw
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.GlobalPool, self).__init__()

                                            self.yang_name = "global-pool"
                                            self.yang_parent_name = "sub-pool-config"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('unlimited', (YLeaf(YType.empty, 'unlimited'), ['Empty'])),
                                            ])
                                            self.bandwidth = None
                                            self.unlimited = None
                                            self._segment_path = lambda: "global-pool"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.SubPool.SubPoolConfig.GlobalPool, [u'bandwidth', u'unlimited'], name, value)


                            class ClassType(Entity):
                                """
                                
                                
                                .. attribute:: class_type_num
                                
                                	Enter the Class\-type\: <0..1>
                                	**type**\: int
                                
                                	**range:** 0..1
                                
                                .. attribute:: bandwidth
                                
                                	Amount of allocatable backup bw\: <1..4294967295> kbps
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: unlimited
                                
                                	Unlimited amount of allocatable bw
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.ClassType, self).__init__()

                                    self.yang_name = "class-type"
                                    self.yang_parent_name = "backup-bw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('class_type_num', (YLeaf(YType.uint8, 'class-type-num'), ['int'])),
                                        ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                        ('unlimited', (YLeaf(YType.empty, 'unlimited'), ['Empty'])),
                                    ])
                                    self.class_type_num = None
                                    self.bandwidth = None
                                    self.unlimited = None
                                    self._segment_path = lambda: "class-type"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.ClassType, [u'class_type_num', u'bandwidth', u'unlimited'], name, value)


                            class GlobalPool(Entity):
                                """
                                
                                
                                .. attribute:: bandwidth
                                
                                	Amount of allocatable backup bw\: <1..4294967295> kbps
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: unlimited
                                
                                	Unlimited amount of allocatable bw
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.GlobalPool, self).__init__()

                                    self.yang_name = "global-pool"
                                    self.yang_parent_name = "backup-bw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                        ('unlimited', (YLeaf(YType.empty, 'unlimited'), ['Empty'])),
                                    ])
                                    self.bandwidth = None
                                    self.unlimited = None
                                    self._segment_path = lambda: "global-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BackupBw.GlobalPool, [u'bandwidth', u'unlimited'], name, value)


                        class Bandwidth(Entity):
                            """
                            tunnel bandwidth requirement
                            
                            .. attribute:: bw
                            
                            	bandwidth requirement\: <0..4294967295> kbps
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: class_type
                            
                            	classtype value
                            	**type**\: int
                            
                            	**range:** 0..1
                            
                            .. attribute:: sub_pool
                            
                            	tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Bandwidth, self).__init__()

                                self.yang_name = "bandwidth"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bw', (YLeaf(YType.uint32, 'bw'), ['int'])),
                                    ('class_type', (YLeaf(YType.uint8, 'class-type'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.bw = None
                                self.class_type = None
                                self.sub_pool = None
                                self._segment_path = lambda: "bandwidth"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Bandwidth, [u'bw', u'class_type', u'sub_pool'], name, value)


                        class Bfd(Entity):
                            """
                            Bidirectional Forwarding Detection (BFD) configuration
                            
                            .. attribute:: sbfd
                            
                            	 Seamless BFD
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sbfd', (YLeaf(YType.str, 'sbfd'), ['str'])),
                                ])
                                self.sbfd = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Bfd, [u'sbfd'], name, value)


                        class BindingSid(Entity):
                            """
                            Binding Segment Identifier
                            
                            .. attribute:: label
                            
                            	MPLS label (depends on the configured static label range)
                            	**type**\: int
                            
                            	**range:** 16..1048575
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BindingSid, self).__init__()

                                self.yang_name = "binding-sid"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                ])
                                self.label = None
                                self._segment_path = lambda: "binding-sid"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.BindingSid, [u'label'], name, value)


                        class Exp(Entity):
                            """
                            Set the experimental values allowed for this interface
                            
                            .. attribute:: exp_value
                            
                            	Enter up to 8 experimental values separated by white\-spaces\: <0..7>
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: default
                            
                            	Default all unconfigured exp to this interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Exp, self).__init__()

                                self.yang_name = "exp"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('exp_value', (YLeafList(YType.uint8, 'exp-value'), ['int'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ])
                                self.exp_value = []
                                self.default = None
                                self._segment_path = lambda: "exp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Exp, [u'exp_value', u'default'], name, value)


                        class ExpBundle(Entity):
                            """
                            Configure the tunnel as a bundle
                            
                            .. attribute:: master
                            
                            	Master tunnel for the bundle
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: member
                            
                            	Member tunnel for the bundle
                            	**type**\:  :py:class:`Member <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ExpBundle.Member>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ExpBundle, self).__init__()

                                self.yang_name = "exp-bundle"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("member", ("member", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ExpBundle.Member))])
                                self._leafs = OrderedDict([
                                    ('master', (YLeaf(YType.empty, 'master'), ['Empty'])),
                                ])
                                self.master = None

                                self.member = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ExpBundle.Member()
                                self.member.parent = self
                                self._children_name_map["member"] = "member"
                                self._segment_path = lambda: "exp-bundle"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ExpBundle, [u'master'], name, value)


                            class Member(Entity):
                                """
                                Member tunnel for the bundle
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface number\: <0..2147483647>
                                	**type**\: int
                                
                                	**range:** 0..2147483647
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ExpBundle.Member, self).__init__()

                                    self.yang_name = "member"
                                    self.yang_parent_name = "exp-bundle"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ])
                                    self.tunnel = None
                                    self._segment_path = lambda: "member"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ExpBundle.Member, [u'tunnel'], name, value)


                        class FastReroute(Entity):
                            """
                            Specify mpls tunnel can be fast\-rerouted
                            
                            .. attribute:: bw_protect
                            
                            	bandwidth protection desired
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: node_protect
                            
                            	node protection desired
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.FastReroute, self).__init__()

                                self.yang_name = "fast-reroute"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('bw_protect', (YLeaf(YType.empty, 'bw-protect'), ['Empty'])),
                                    ('node_protect', (YLeaf(YType.empty, 'node-protect'), ['Empty'])),
                                ])
                                self.bw_protect = None
                                self.node_protect = None
                                self._segment_path = lambda: "fast-reroute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.FastReroute, [u'bw_protect', u'node_protect'], name, value)


                        class ForwardingAdjacency(Entity):
                            """
                            Treat this tunnel as a Forwarding Adjacency
                            
                            .. attribute:: holdtime
                            
                            	How long to wait upon flooding a down Forwarding Adjacency\: <0..4294967295> msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ForwardingAdjacency, self).__init__()

                                self.yang_name = "forwarding-adjacency"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('holdtime', (YLeaf(YType.uint32, 'holdtime'), ['int'])),
                                ])
                                self.holdtime = None
                                self._segment_path = lambda: "forwarding-adjacency"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.ForwardingAdjacency, [u'holdtime'], name, value)


                        class Interface_(Entity):
                            """
                            Add tunnel interface config
                            
                            .. attribute:: down
                            
                            	 Tunnel interface down config
                            	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Interface_.Down>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Interface_, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("down", ("down", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Interface_.Down))])
                                self._leafs = OrderedDict()

                                self.down = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Interface_.Down()
                                self.down.parent = self
                                self._children_name_map["down"] = "down"
                                self._segment_path = lambda: "interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Interface_, [], name, value)


                            class Down(Entity):
                                """
                                 Tunnel interface down config
                                
                                .. attribute:: delay
                                
                                	Tunnel interface down delay config\: <0..0>
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Interface_.Down, self).__init__()

                                    self.yang_name = "down"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                    ])
                                    self.delay = None
                                    self._segment_path = lambda: "down"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Interface_.Down, [u'delay'], name, value)


                        class PathOption(Entity):
                            """
                            
                            
                            .. attribute:: working
                            
                            	
                            	**type**\: list of  		 :py:class:`Working <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working>`
                            
                            .. attribute:: protect
                            
                            	
                            	**type**\: list of  		 :py:class:`Protect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption, self).__init__()

                                self.yang_name = "path-option"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("working", ("working", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working)), ("protect", ("protect", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect))])
                                self._leafs = OrderedDict()

                                self.working = YList(self)
                                self.protect = YList(self)
                                self._segment_path = lambda: "path-option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption, [], name, value)


                            class Working(Entity):
                                """
                                
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dynamic
                                
                                	Setup based on dynamically calculated path
                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: explicit
                                
                                	Setup based on preconfigured path
                                	**type**\:  :py:class:`Explicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Explicit>`
                                
                                .. attribute:: segment_routing
                                
                                	Specify segment\-routing for this pathoption
                                	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.SegmentRouting>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working, self).__init__()

                                    self.yang_name = "working"
                                    self.yang_parent_name = "path-option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic)), ("explicit", ("explicit", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Explicit)), ("segment-routing", ("segment_routing", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.SegmentRouting))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.dynamic = None
                                    self._children_name_map["dynamic"] = "dynamic"

                                    self.explicit = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Explicit()
                                    self.explicit.parent = self
                                    self._children_name_map["explicit"] = "explicit"

                                    self.segment_routing = None
                                    self._children_name_map["segment_routing"] = "segment-routing"
                                    self._segment_path = lambda: "working" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working, [u'id'], name, value)


                                class Dynamic(Entity):
                                    """
                                    Setup based on dynamically calculated path
                                    
                                    .. attribute:: segment_routing
                                    
                                    	Specify segment\-routing for this pathoption
                                    	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic.SegmentRouting>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: pce
                                    
                                    	Use PCE for path computation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: address
                                    
                                    	PCE IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: verbatim
                                    
                                    	Do not validate links from the ERO object
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: lockdown
                                    
                                    	Not a candidate for reoptimization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sticky
                                    
                                    	Stay on the same path after change in required resources
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Override the bandwidth configured on the tunnel
                                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic.Bandwidth>`
                                    
                                    .. attribute:: attributes
                                    
                                    	Specify name of LSP attribute list
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic, self).__init__()

                                        self.yang_name = "dynamic"
                                        self.yang_parent_name = "working"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("segment-routing", ("segment_routing", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic.SegmentRouting)), ("bandwidth", ("bandwidth", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic.Bandwidth))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('pce', (YLeaf(YType.empty, 'pce'), ['Empty'])),
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                            ('lockdown', (YLeaf(YType.empty, 'lockdown'), ['Empty'])),
                                            ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                            ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                        ])
                                        self.pce = None
                                        self.address = None
                                        self.verbatim = None
                                        self.lockdown = None
                                        self.sticky = None
                                        self.attributes = None

                                        self.segment_routing = None
                                        self._children_name_map["segment_routing"] = "segment-routing"

                                        self.bandwidth = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic.Bandwidth()
                                        self.bandwidth.parent = self
                                        self._children_name_map["bandwidth"] = "bandwidth"
                                        self._segment_path = lambda: "dynamic"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic, [u'pce', u'address', u'verbatim', u'lockdown', u'sticky', u'attributes'], name, value)


                                    class SegmentRouting(Entity):
                                        """
                                        Specify segment\-routing for this pathoption
                                        
                                        .. attribute:: attributes
                                        
                                        	Specify name of LSP attribute list
                                        	**type**\: str
                                        
                                        .. attribute:: lockdown
                                        
                                        	Not a candidate for reoptimization
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: sticky
                                        
                                        	Stay on the same path after change in required resources
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: pce
                                        
                                        	Use PCE for path computation
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: address
                                        
                                        	PCE IPv4 address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: verbatim
                                        
                                        	Do not validate links from the ERO object
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic.SegmentRouting, self).__init__()

                                            self.yang_name = "segment-routing"
                                            self.yang_parent_name = "dynamic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                                ('lockdown', (YLeaf(YType.empty, 'lockdown'), ['Empty'])),
                                                ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                                ('pce', (YLeaf(YType.empty, 'pce'), ['Empty'])),
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                            ])
                                            self.attributes = None
                                            self.lockdown = None
                                            self.sticky = None
                                            self.pce = None
                                            self.address = None
                                            self.verbatim = None
                                            self._segment_path = lambda: "segment-routing"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic.SegmentRouting, [u'attributes', u'lockdown', u'sticky', u'pce', u'address', u'verbatim'], name, value)


                                    class Bandwidth(Entity):
                                        """
                                        Override the bandwidth configured on the tunnel
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Bandwidth requirement\: <0..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_pool
                                        
                                        	Tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic.Bandwidth, self).__init__()

                                            self.yang_name = "bandwidth"
                                            self.yang_parent_name = "dynamic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                            ])
                                            self.bandwidth = None
                                            self.sub_pool = None
                                            self._segment_path = lambda: "bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Dynamic.Bandwidth, [u'bandwidth', u'sub_pool'], name, value)


                                class Explicit(Entity):
                                    """
                                    Setup based on preconfigured path
                                    
                                    .. attribute:: identifier
                                    
                                    	Specify an IP explicit path by number\: <1..65535>
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: name
                                    
                                    	Specify an IP explicit path by name
                                    	**type**\: str
                                    
                                    .. attribute:: segment_routing
                                    
                                    	Specify segment\-routing for this pathoption
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verbatim
                                    
                                    	Send out path as is, with no checking
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attributes
                                    
                                    	Specify name of LSP attribute list
                                    	**type**\: str
                                    
                                    .. attribute:: lockdown
                                    
                                    	Not a candidate for reoptimization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sticky
                                    
                                    	Stay on the same path after change in required resources
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Override the bandwidth configured on the tunnel
                                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Explicit.Bandwidth>`
                                    
                                    

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Explicit, self).__init__()

                                        self.yang_name = "explicit"
                                        self.yang_parent_name = "working"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Explicit.Bandwidth))])
                                        self._leafs = OrderedDict([
                                            ('identifier', (YLeaf(YType.uint16, 'identifier'), ['int'])),
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('segment_routing', (YLeaf(YType.empty, 'segment-routing'), ['Empty'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                            ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                            ('lockdown', (YLeaf(YType.empty, 'lockdown'), ['Empty'])),
                                            ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                        ])
                                        self.identifier = None
                                        self.name = None
                                        self.segment_routing = None
                                        self.verbatim = None
                                        self.attributes = None
                                        self.lockdown = None
                                        self.sticky = None

                                        self.bandwidth = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Explicit.Bandwidth()
                                        self.bandwidth.parent = self
                                        self._children_name_map["bandwidth"] = "bandwidth"
                                        self._segment_path = lambda: "explicit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Explicit, [u'identifier', u'name', u'segment_routing', u'verbatim', u'attributes', u'lockdown', u'sticky'], name, value)


                                    class Bandwidth(Entity):
                                        """
                                        Override the bandwidth configured on the tunnel
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Bandwidth requirement\: <0..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_pool
                                        
                                        	Tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Explicit.Bandwidth, self).__init__()

                                            self.yang_name = "bandwidth"
                                            self.yang_parent_name = "explicit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                            ])
                                            self.bandwidth = None
                                            self.sub_pool = None
                                            self._segment_path = lambda: "bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.Explicit.Bandwidth, [u'bandwidth', u'sub_pool'], name, value)


                                class SegmentRouting(Entity):
                                    """
                                    Specify segment\-routing for this pathoption
                                    
                                    .. attribute:: lockdown
                                    
                                    	Not a candidate for reoptimization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sticky
                                    
                                    	Stay on the same path after change in required resources
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.SegmentRouting, self).__init__()

                                        self.yang_name = "segment-routing"
                                        self.yang_parent_name = "working"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('lockdown', (YLeaf(YType.empty, 'lockdown'), ['Empty'])),
                                            ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                        ])
                                        self.lockdown = None
                                        self.sticky = None
                                        self._segment_path = lambda: "segment-routing"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working.SegmentRouting, [u'lockdown', u'sticky'], name, value)


                            class Protect(Entity):
                                """
                                
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**refers to**\:  :py:class:`id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Working>`
                                
                                .. attribute:: diverse
                                
                                	Setup based on dynamically calculated diverse path
                                	**type**\:  :py:class:`Diverse <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Diverse>`
                                
                                .. attribute:: explicit
                                
                                	Setup based on preconfigured path
                                	**type**\:  :py:class:`Explicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Explicit>`
                                
                                .. attribute:: list
                                
                                	A list of backup paths
                                	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.List>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect, self).__init__()

                                    self.yang_name = "protect"
                                    self.yang_parent_name = "path-option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("diverse", ("diverse", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Diverse)), ("explicit", ("explicit", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Explicit)), ("list", ("list", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.List))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.diverse = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Diverse()
                                    self.diverse.parent = self
                                    self._children_name_map["diverse"] = "diverse"

                                    self.explicit = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Explicit()
                                    self.explicit.parent = self
                                    self._children_name_map["explicit"] = "explicit"

                                    self.list = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.List()
                                    self.list.parent = self
                                    self._children_name_map["list"] = "list"
                                    self._segment_path = lambda: "protect" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect, [u'id'], name, value)


                                class Diverse(Entity):
                                    """
                                    Setup based on dynamically calculated diverse path
                                    
                                    .. attribute:: node
                                    
                                    	Use at least node diverse path
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: srlg
                                    
                                    	Use at least srlg diverse path
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: segment_routing
                                    
                                    	Specify segment\-routing for this pathoption
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: non_revertive
                                    
                                    	Diverse non\-revertive
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: pce
                                    
                                    	Use PCE for path computation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: address
                                    
                                    	PCE IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: verbatim
                                    
                                    	Do not validate links from the ERO object
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: lockdown
                                    
                                    	Not a candidate for reoptimization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attributes
                                    
                                    	Specify name of LSP attribute list
                                    	**type**\: str
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Override the bandwidth configured on the tunnel
                                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Diverse.Bandwidth>`
                                    
                                    

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Diverse, self).__init__()

                                        self.yang_name = "diverse"
                                        self.yang_parent_name = "protect"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Diverse.Bandwidth))])
                                        self._leafs = OrderedDict([
                                            ('node', (YLeaf(YType.empty, 'node'), ['Empty'])),
                                            ('srlg', (YLeaf(YType.empty, 'srlg'), ['Empty'])),
                                            ('segment_routing', (YLeaf(YType.empty, 'segment-routing'), ['Empty'])),
                                            ('non_revertive', (YLeaf(YType.empty, 'non-revertive'), ['Empty'])),
                                            ('pce', (YLeaf(YType.empty, 'pce'), ['Empty'])),
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                            ('lockdown', (YLeaf(YType.empty, 'lockdown'), ['Empty'])),
                                            ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                        ])
                                        self.node = None
                                        self.srlg = None
                                        self.segment_routing = None
                                        self.non_revertive = None
                                        self.pce = None
                                        self.address = None
                                        self.verbatim = None
                                        self.lockdown = None
                                        self.attributes = None

                                        self.bandwidth = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Diverse.Bandwidth()
                                        self.bandwidth.parent = self
                                        self._children_name_map["bandwidth"] = "bandwidth"
                                        self._segment_path = lambda: "diverse"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Diverse, [u'node', u'srlg', u'segment_routing', u'non_revertive', u'pce', u'address', u'verbatim', u'lockdown', u'attributes'], name, value)


                                    class Bandwidth(Entity):
                                        """
                                        Override the bandwidth configured on the tunnel
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Bandwidth requirement\: <0..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_pool
                                        
                                        	Tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Diverse.Bandwidth, self).__init__()

                                            self.yang_name = "bandwidth"
                                            self.yang_parent_name = "diverse"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                            ])
                                            self.bandwidth = None
                                            self.sub_pool = None
                                            self._segment_path = lambda: "bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Diverse.Bandwidth, [u'bandwidth', u'sub_pool'], name, value)


                                class Explicit(Entity):
                                    """
                                    Setup based on preconfigured path
                                    
                                    .. attribute:: identifier
                                    
                                    	Specify an IP explicit path by number\: <1..65535>
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: name
                                    
                                    	Specify an IP explicit path by name
                                    	**type**\: str
                                    
                                    .. attribute:: segment_routing
                                    
                                    	Specify segment\-routing for this pathoption
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: non_revertive
                                    
                                    	Diverse non\-revertive
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verbatim
                                    
                                    	Send out path as is, with no checking
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attributes
                                    
                                    	Specify name of LSP attribute list
                                    	**type**\: str
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Override the bandwidth configured on the tunnel
                                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Explicit.Bandwidth>`
                                    
                                    

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Explicit, self).__init__()

                                        self.yang_name = "explicit"
                                        self.yang_parent_name = "protect"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Explicit.Bandwidth))])
                                        self._leafs = OrderedDict([
                                            ('identifier', (YLeaf(YType.uint16, 'identifier'), ['int'])),
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('segment_routing', (YLeaf(YType.empty, 'segment-routing'), ['Empty'])),
                                            ('non_revertive', (YLeaf(YType.empty, 'non-revertive'), ['Empty'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                            ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                        ])
                                        self.identifier = None
                                        self.name = None
                                        self.segment_routing = None
                                        self.non_revertive = None
                                        self.verbatim = None
                                        self.attributes = None

                                        self.bandwidth = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Explicit.Bandwidth()
                                        self.bandwidth.parent = self
                                        self._children_name_map["bandwidth"] = "bandwidth"
                                        self._segment_path = lambda: "explicit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Explicit, [u'identifier', u'name', u'segment_routing', u'non_revertive', u'verbatim', u'attributes'], name, value)


                                    class Bandwidth(Entity):
                                        """
                                        Override the bandwidth configured on the tunnel
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Bandwidth requirement\: <0..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_pool
                                        
                                        	Tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Explicit.Bandwidth, self).__init__()

                                            self.yang_name = "bandwidth"
                                            self.yang_parent_name = "explicit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                            ])
                                            self.bandwidth = None
                                            self.sub_pool = None
                                            self._segment_path = lambda: "bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.Explicit.Bandwidth, [u'bandwidth', u'sub_pool'], name, value)


                                class List(Entity):
                                    """
                                    A list of backup paths
                                    
                                    .. attribute:: identifier
                                    
                                    	Specify an IP explicit path by number\: <1..65535>
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: name
                                    
                                    	Specify an IP explicit path by name
                                    	**type**\: str
                                    
                                    .. attribute:: segment_routing
                                    
                                    	Specify segment\-routing for this pathoption
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: non_revertive
                                    
                                    	Make the protect path non\-revertive
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attributes
                                    
                                    	Specify name of LSP attribute list
                                    	**type**\: str
                                    
                                    .. attribute:: bandwidth
                                    
                                    	Override the bandwidth configured on the tunnel
                                    	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.List.Bandwidth>`
                                    
                                    .. attribute:: pce
                                    
                                    	Use PCE for path computation
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: address
                                    
                                    	PCE IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: verbatim
                                    
                                    	Do not validate links from the ERO object
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-tun'
                                    _revision = '2017-08-28'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.List, self).__init__()

                                        self.yang_name = "list"
                                        self.yang_parent_name = "protect"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bandwidth", ("bandwidth", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.List.Bandwidth))])
                                        self._leafs = OrderedDict([
                                            ('identifier', (YLeaf(YType.uint16, 'identifier'), ['int'])),
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('segment_routing', (YLeaf(YType.empty, 'segment-routing'), ['Empty'])),
                                            ('non_revertive', (YLeaf(YType.empty, 'non-revertive'), ['Empty'])),
                                            ('attributes', (YLeaf(YType.str, 'attributes'), ['str'])),
                                            ('pce', (YLeaf(YType.empty, 'pce'), ['Empty'])),
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                        ])
                                        self.identifier = None
                                        self.name = None
                                        self.segment_routing = None
                                        self.non_revertive = None
                                        self.attributes = None
                                        self.pce = None
                                        self.address = None
                                        self.verbatim = None

                                        self.bandwidth = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.List.Bandwidth()
                                        self.bandwidth.parent = self
                                        self._children_name_map["bandwidth"] = "bandwidth"
                                        self._segment_path = lambda: "list"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.List, [u'identifier', u'name', u'segment_routing', u'non_revertive', u'attributes', u'pce', u'address', u'verbatim'], name, value)


                                    class Bandwidth(Entity):
                                        """
                                        Override the bandwidth configured on the tunnel
                                        
                                        .. attribute:: bandwidth
                                        
                                        	Bandwidth requirement\: <0..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_pool
                                        
                                        	Tunnel uses sub\-pool bandwidth\: <1..4294967295> kbps
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-tun'
                                        _revision = '2017-08-28'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.List.Bandwidth, self).__init__()

                                            self.yang_name = "bandwidth"
                                            self.yang_parent_name = "list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                                ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                            ])
                                            self.bandwidth = None
                                            self.sub_pool = None
                                            self._segment_path = lambda: "bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathOption.Protect.List.Bandwidth, [u'bandwidth', u'sub_pool'], name, value)


                        class PathSelection(Entity):
                            """
                            Path Selection Configuration
                            
                            .. attribute:: metric
                            
                            	Metric Type Configuration\: < te \| igp >
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.Metric>`
                            
                            .. attribute:: invalidation
                            
                            	Path invalidation configuration
                            	**type**\:  :py:class:`Invalidation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.Invalidation>`
                            
                            .. attribute:: segment_routing
                            
                            	Segment\-routing path\-selection options
                            	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.SegmentRouting>`
                            
                            .. attribute:: cost_limit
                            
                            	Cost Limit Configuration\: <1..4294967295>
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: hop_limit
                            
                            	Cost Limit Configuration\: <1..255>
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: tiebreaker
                            
                            	Tiebreaker Configuration\: < max\-fill \| min\-fill \| random >
                            	**type**\:  :py:class:`MplsTeTiebreakerType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.MplsTeTiebreakerType>`
                            
                            

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection, self).__init__()

                                self.yang_name = "path-selection"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("invalidation", ("invalidation", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.Invalidation)), ("segment-routing", ("segment_routing", Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.SegmentRouting))])
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.enumeration, 'metric'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.Metric')])),
                                    ('cost_limit', (YLeaf(YType.uint32, 'cost-limit'), ['int'])),
                                    ('hop_limit', (YLeaf(YType.uint8, 'hop-limit'), ['int'])),
                                    ('tiebreaker', (YLeaf(YType.enumeration, 'tiebreaker'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'MplsTeTiebreakerType', '')])),
                                ])
                                self.metric = None
                                self.cost_limit = None
                                self.hop_limit = None
                                self.tiebreaker = None

                                self.invalidation = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.Invalidation()
                                self.invalidation.parent = self
                                self._children_name_map["invalidation"] = "invalidation"

                                self.segment_routing = Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.SegmentRouting()
                                self.segment_routing.parent = self
                                self._children_name_map["segment_routing"] = "segment-routing"
                                self._segment_path = lambda: "path-selection"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection, [u'metric', u'cost_limit', u'hop_limit', u'tiebreaker'], name, value)

                            class Metric(Enum):
                                """
                                Metric (Enum Class)

                                Metric Type Configuration\: < te \| igp >

                                .. data:: igp = 0

                                .. data:: te = 1

                                """

                                igp = Enum.YLeaf(0, "igp")

                                te = Enum.YLeaf(1, "te")



                            class Invalidation(Entity):
                                """
                                Path invalidation configuration
                                
                                .. attribute:: value
                                
                                	Path invalidation timer value\: <0..60000> milliseconds, (default 10000)
                                	**type**\: int
                                
                                	**range:** 0..60000
                                
                                .. attribute:: drop
                                
                                	Drop Tunnel Traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.Invalidation, self).__init__()

                                    self.yang_name = "invalidation"
                                    self.yang_parent_name = "path-selection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.int32, 'value'), ['int'])),
                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                    ])
                                    self.value = None
                                    self.drop = None
                                    self._segment_path = lambda: "invalidation"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.Invalidation, [u'value', u'drop'], name, value)


                            class SegmentRouting(Entity):
                                """
                                Segment\-routing path\-selection options
                                
                                .. attribute:: adjacency
                                
                                	Segment\-routing adjacency path\-selection type
                                	**type**\:  :py:class:`Adjacency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.SegmentRouting.Adjacency>`
                                
                                

                                """

                                _prefix = 'ios-tun'
                                _revision = '2017-08-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.SegmentRouting, self).__init__()

                                    self.yang_name = "segment-routing"
                                    self.yang_parent_name = "path-selection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('adjacency', (YLeaf(YType.enumeration, 'adjacency'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.SegmentRouting.Adjacency')])),
                                    ])
                                    self.adjacency = None
                                    self._segment_path = lambda: "segment-routing"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.PathSelection.SegmentRouting, [u'adjacency'], name, value)

                                class Adjacency(Enum):
                                    """
                                    Adjacency (Enum Class)

                                    Segment\-routing adjacency path\-selection type

                                    .. data:: protected = 0

                                    .. data:: unprotected = 1

                                    """

                                    protected = Enum.YLeaf(0, "protected")

                                    unprotected = Enum.YLeaf(1, "unprotected")



                        class Priority(Entity):
                            """
                            Tunnel priority
                            
                            .. attribute:: setup_priority
                            
                            	Setup priority\: <0..7>
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            	**mandatory**\: True
                            
                            .. attribute:: hold_priority
                            
                            	Hold priority\: <0..7>
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('setup_priority', (YLeaf(YType.uint8, 'setup-priority'), ['int'])),
                                    ('hold_priority', (YLeaf(YType.uint8, 'hold-priority'), ['int'])),
                                ])
                                self.setup_priority = None
                                self.hold_priority = None
                                self._segment_path = lambda: "priority"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.Priority, [u'setup_priority', u'hold_priority'], name, value)


                        class RecordRoute(Entity):
                            """
                            record the route used by the tunnel
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-tun'
                            _revision = '2017-08-28'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Tunnel.Mpls.TrafficEng.RecordRoute, self).__init__()

                                self.yang_name = "record-route"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "record-route"
                                self._is_frozen = True


                class Rbscp(Entity):
                    """
                    Set tunnel RBSCP parameters
                    
                    .. attribute:: ack_split
                    
                    	ACK splitting
                    	**type**\: int
                    
                    	**range:** 1..32
                    
                    .. attribute:: delay
                    
                    	enable delay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: input_drop
                    
                    	max tunnel queue size (number of bw\*delay)
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: long_drop
                    
                    	Drop non\-transmitted packets w/excessive delay
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: report
                    
                    	enable SCTP report chunk
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: window_stuff
                    
                    	Window stuffing
                    	**type**\: int
                    
                    	**range:** 1..20
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Rbscp, self).__init__()

                        self.yang_name = "rbscp"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ack_split', (YLeaf(YType.uint8, 'ack-split'), ['int'])),
                            ('delay', (YLeaf(YType.empty, 'delay'), ['Empty'])),
                            ('input_drop', (YLeaf(YType.uint8, 'input-drop'), ['int'])),
                            ('long_drop', (YLeaf(YType.empty, 'long-drop'), ['Empty'])),
                            ('report', (YLeaf(YType.empty, 'report'), ['Empty'])),
                            ('window_stuff', (YLeaf(YType.uint8, 'window-stuff'), ['int'])),
                        ])
                        self.ack_split = None
                        self.delay = None
                        self.input_drop = None
                        self.long_drop = None
                        self.report = None
                        self.window_stuff = None
                        self._segment_path = lambda: "rbscp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Rbscp, [u'ack_split', u'delay', u'input_drop', u'long_drop', u'report', u'window_stuff'], name, value)


                class SrcPort(Entity):
                    """
                    tunnel source port
                    
                    .. attribute:: port_num
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dynamic
                    
                    	Set Source Port Dynamically
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.SrcPort, self).__init__()

                        self.yang_name = "src-port"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_num', (YLeaf(YType.uint16, 'port-num'), ['int'])),
                            ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                        ])
                        self.port_num = None
                        self.dynamic = None
                        self._segment_path = lambda: "src-port"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.SrcPort, [u'port_num', u'dynamic'], name, value)


                class Udlr(Entity):
                    """
                    associate tunnel with unidirectional interface
                    
                    .. attribute:: address_resolution
                    
                    	Enable ARP and NHRP over a UDLR Tunnel
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: receive_only
                    
                    	Tunnel is receive\-only capable
                    	**type**\: str
                    
                    .. attribute:: send_only
                    
                    	Tunnel is send\-only capable
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Udlr, self).__init__()

                        self.yang_name = "udlr"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address_resolution', (YLeaf(YType.empty, 'address-resolution'), ['Empty'])),
                            ('receive_only', (YLeaf(YType.str, 'receive-only'), ['str'])),
                            ('send_only', (YLeaf(YType.str, 'send-only'), ['str'])),
                        ])
                        self.address_resolution = None
                        self.receive_only = None
                        self.send_only = None
                        self._segment_path = lambda: "udlr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Udlr, [u'address_resolution', u'receive_only', u'send_only'], name, value)


                class Vlan(Entity):
                    """
                    Set vlan\-id for ethernet over gre mode
                    
                    .. attribute:: id1
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hyphen
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: id2
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-tun'
                    _revision = '2017-08-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Tunnel.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id1', (YLeaf(YType.uint16, 'id1'), ['int'])),
                            ('hyphen', (YLeaf(YType.empty, 'hyphen'), ['Empty'])),
                            ('id2', (YLeaf(YType.uint16, 'id2'), ['int'])),
                        ])
                        self.id1 = None
                        self.hyphen = None
                        self.id2 = None
                        self._segment_path = lambda: "vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Tunnel.Vlan, [u'id1', u'hyphen', u'id2'], name, value)


            class Crypto(Entity):
                """
                Encryption/Decryption commands
                
                .. attribute:: map
                
                	Assign a Crypto Map
                	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Crypto.Map>`
                
                .. attribute:: ipsec
                
                	Set IPSec parameters
                	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Crypto.Ipsec>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Crypto, self).__init__()

                    self.yang_name = "crypto"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map", ("map", Native.Interface.VirtualTemplate.Crypto.Map)), ("ipsec", ("ipsec", Native.Interface.VirtualTemplate.Crypto.Ipsec))])
                    self._leafs = OrderedDict()

                    self.map = Native.Interface.VirtualTemplate.Crypto.Map()
                    self.map.parent = self
                    self._children_name_map["map"] = "map"

                    self.ipsec = Native.Interface.VirtualTemplate.Crypto.Ipsec()
                    self.ipsec.parent = self
                    self._children_name_map["ipsec"] = "ipsec"
                    self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Crypto, [], name, value)


                class Map(Entity):
                    """
                    Assign a Crypto Map
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	enable redundancy
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Crypto.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('redundancy', (YLeaf(YType.str, 'redundancy'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.tag = None
                        self.redundancy = None
                        self.stateful = None
                        self._segment_path = lambda: "map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Crypto.Map, ['tag', 'redundancy', 'stateful'], name, value)


                class Ipsec(Entity):
                    """
                    Set IPSec parameters
                    
                    .. attribute:: df_bit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Crypto.Ipsec.DfBit>`
                    
                    .. attribute:: fragmentation
                    
                    	Handling of fragmentation of near\-MTU sized packets
                    	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Crypto.Ipsec.Fragmentation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Crypto.Ipsec, self).__init__()

                        self.yang_name = "ipsec"
                        self.yang_parent_name = "crypto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Crypto.Ipsec.DfBit')])),
                            ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Crypto.Ipsec.Fragmentation')])),
                        ])
                        self.df_bit = None
                        self.fragmentation = None
                        self._segment_path = lambda: "ipsec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Crypto.Ipsec, ['df_bit', 'fragmentation'], name, value)

                    class DfBit(Enum):
                        """
                        DfBit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Fragmentation(Enum):
                        """
                        Fragmentation (Enum Class)

                        Handling of fragmentation of near\-MTU sized packets

                        .. data:: after_encryption = 0

                        .. data:: before_encryption = 1

                        """

                        after_encryption = Enum.YLeaf(0, "after-encryption")

                        before_encryption = Enum.YLeaf(1, "before-encryption")



            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Utd, ['enable'], name, value)


            class Cdp(Entity):
                """
                CDP interface subcommands
                
                .. attribute:: enable
                
                	Enable CDP on interface
                	**type**\: bool
                
                .. attribute:: tlv
                
                	Enable exchange of specific tlv information
                	**type**\:  :py:class:`Tlv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cdp.Tlv>`
                
                

                """

                _prefix = 'ios-cdp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Cdp, self).__init__()

                    self.yang_name = "cdp"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tlv", ("tlv", Native.Interface.VirtualTemplate.Cdp.Tlv))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                    ])
                    self.enable = None

                    self.tlv = Native.Interface.VirtualTemplate.Cdp.Tlv()
                    self.tlv.parent = self
                    self._children_name_map["tlv"] = "tlv"
                    self._segment_path = lambda: "Cisco-IOS-XE-cdp:cdp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Cdp, ['enable'], name, value)


                class Tlv(Entity):
                    """
                    Enable exchange of specific tlv information
                    
                    .. attribute:: app
                    
                    	Enable/Configure Application TLV
                    	**type**\:  :py:class:`App <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cdp.Tlv.App>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: server_location
                    
                    	Enable CDP location server on interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	Exchange location information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cdp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Cdp.Tlv, self).__init__()

                        self.yang_name = "tlv"
                        self.yang_parent_name = "cdp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("app", ("app", Native.Interface.VirtualTemplate.Cdp.Tlv.App))])
                        self._leafs = OrderedDict([
                            ('server_location', (YLeaf(YType.empty, 'server-location'), ['Empty'])),
                            ('location', (YLeaf(YType.empty, 'location'), ['Empty'])),
                        ])
                        self.server_location = None
                        self.location = None

                        self.app = None
                        self._children_name_map["app"] = "app"
                        self._segment_path = lambda: "tlv"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Cdp.Tlv, ['server_location', 'location'], name, value)


                    class App(Entity):
                        """
                        Enable/Configure Application TLV
                        
                        .. attribute:: tlvtype
                        
                        	Configure APP TLV
                        	**type**\: int
                        
                        	**range:** 1001..65535
                        
                        .. attribute:: value
                        
                        	Configure App TLV Value information
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cdp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Cdp.Tlv.App, self).__init__()

                            self.yang_name = "app"
                            self.yang_parent_name = "tlv"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tlvtype', (YLeaf(YType.uint16, 'tlvtype'), ['int'])),
                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                            ])
                            self.tlvtype = None
                            self.value = None
                            self._segment_path = lambda: "app"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Cdp.Tlv.App, ['tlvtype', 'value'], name, value)


            class Ntp(Entity):
                """
                Configure NTP
                
                .. attribute:: broadcast
                
                	Configure NTP broadcast service
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: broadcast_option
                
                	Configure NTP broadcast service
                	**type**\:  :py:class:`BroadcastOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ntp.BroadcastOption>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Ntp, self).__init__()

                    self.yang_name = "ntp"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast-option", ("broadcast_option", Native.Interface.VirtualTemplate.Ntp.BroadcastOption))])
                    self._leafs = OrderedDict([
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.broadcast = None

                    self.broadcast_option = Native.Interface.VirtualTemplate.Ntp.BroadcastOption()
                    self.broadcast_option.parent = self
                    self._children_name_map["broadcast_option"] = "broadcast-option"
                    self._segment_path = lambda: "Cisco-IOS-XE-ntp:ntp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Ntp, ['broadcast'], name, value)


                class BroadcastOption(Entity):
                    """
                    Configure NTP broadcast service
                    
                    .. attribute:: broadcast
                    
                    	
                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ntp.BroadcastOption.Broadcast>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ntp.BroadcastOption, self).__init__()

                        self.yang_name = "broadcast-option"
                        self.yang_parent_name = "ntp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Interface.VirtualTemplate.Ntp.BroadcastOption.Broadcast))])
                        self._leafs = OrderedDict()

                        self.broadcast = Native.Interface.VirtualTemplate.Ntp.BroadcastOption.Broadcast()
                        self.broadcast.parent = self
                        self._children_name_map["broadcast"] = "broadcast"
                        self._segment_path = lambda: "broadcast-option"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ntp.BroadcastOption, [], name, value)


                    class Broadcast(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Listen to NTP broadcasts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ntp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ntp.BroadcastOption.Broadcast, self).__init__()

                            self.yang_name = "broadcast"
                            self.yang_parent_name = "broadcast-option"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('client', (YLeaf(YType.empty, 'client'), ['Empty'])),
                            ])
                            self.client = None
                            self._segment_path = lambda: "broadcast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ntp.BroadcastOption.Broadcast, ['client'], name, value)


            class Mab(Entity):
                """
                
                
                .. attribute:: eap
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Mab, self).__init__()

                    self.yang_name = "mab"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                    ])
                    self.eap = None
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:mab"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Mab, ['eap'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Umbrella, ['out', 'in_'], name, value)


            class Ppp(Entity):
                """
                Point\-to\-Point Protocol
                
                .. attribute:: accounting
                
                	Set PPP network accounting method
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Accounting>`
                
                .. attribute:: chap
                
                	Set CHAP authentication parameters
                	**type**\:  :py:class:`Chap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Chap>`
                
                .. attribute:: authentication
                
                	Set PPP link authentication method
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Authentication>`
                
                .. attribute:: authorization
                
                	Set PPP network authorization method
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Authorization>`
                
                .. attribute:: ipcp
                
                	Set IPCP negotiation options
                	**type**\:  :py:class:`Ipcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Ipcp>`
                
                .. attribute:: multilink
                
                	Make interface multilink capable
                	**type**\:  :py:class:`Multilink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Multilink>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-ppp'
                _revision = '2018-02-03'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Ppp, self).__init__()

                    self.yang_name = "ppp"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("chap", ("chap", Native.Interface.VirtualTemplate.Ppp.Chap)), ("authentication", ("authentication", Native.Interface.VirtualTemplate.Ppp.Authentication)), ("ipcp", ("ipcp", Native.Interface.VirtualTemplate.Ppp.Ipcp)), ("multilink", ("multilink", Native.Interface.VirtualTemplate.Ppp.Multilink))])
                    self._leafs = OrderedDict([
                        ('accounting', (YLeaf(YType.str, 'accounting'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Ppp.Accounting')])),
                        ('authorization', (YLeaf(YType.str, 'authorization'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Ppp.Authorization')])),
                    ])
                    self.accounting = None
                    self.authorization = None

                    self.chap = Native.Interface.VirtualTemplate.Ppp.Chap()
                    self.chap.parent = self
                    self._children_name_map["chap"] = "chap"

                    self.authentication = Native.Interface.VirtualTemplate.Ppp.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.ipcp = Native.Interface.VirtualTemplate.Ppp.Ipcp()
                    self.ipcp.parent = self
                    self._children_name_map["ipcp"] = "ipcp"

                    self.multilink = None
                    self._children_name_map["multilink"] = "multilink"
                    self._segment_path = lambda: "Cisco-IOS-XE-ppp:ppp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Ppp, ['accounting', 'authorization'], name, value)

                class Accounting(Enum):
                    """
                    Accounting (Enum Class)

                    Set PPP network accounting method

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")


                class Authorization(Enum):
                    """
                    Authorization (Enum Class)

                    Set PPP network authorization method

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")



                class Chap(Entity):
                    """
                    Set CHAP authentication parameters
                    
                    .. attribute:: hostname
                    
                    	Set alternate CHAP hostname
                    	**type**\: str
                    
                    .. attribute:: challenge_length
                    
                    	Challenge Length for CHAP
                    	**type**\: int
                    
                    	**range:** 16..63
                    
                    

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ppp.Chap, self).__init__()

                        self.yang_name = "chap"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ('challenge_length', (YLeaf(YType.uint8, 'challenge-length'), ['int'])),
                        ])
                        self.hostname = None
                        self.challenge_length = None
                        self._segment_path = lambda: "chap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ppp.Chap, ['hostname', 'challenge_length'], name, value)


                class Authentication(Entity):
                    """
                    Set PPP link authentication method
                    
                    .. attribute:: method
                    
                    	
                    	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Authentication.Method>`
                    
                    .. attribute:: list_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: chap
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: callback
                    
                    	Authenticate remote on callback only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: callin
                    
                    	Authenticate remote on incoming call only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: callout
                    
                    	Authenticate remote on outgoing call only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: default
                    
                    	Use the default authentication list
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: eap
                    
                    	Extensible Authentication Protocol (EAP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ms_chap
                    
                    	Microsoft Challenge Handshake Authentication Protocol (MS\-CHAP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ms_chap_v2
                    
                    	Microsoft CHAP Version 2 (MS\-CHAP\-V2)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: one_time
                    
                    	Allow use of username\*OTP for one\-time passwords
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: optional
                    
                    	Allow peer to refuse to authenticate
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pap
                    
                    	Password Authentication Protocol (PAP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ppp.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('method', (YLeaf(YType.enumeration, 'method'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualTemplate.Ppp.Authentication.Method')])),
                            ('list_name', (YLeaf(YType.str, 'list-name'), ['str'])),
                            ('chap', (YLeaf(YType.empty, 'chap'), ['Empty'])),
                            ('callback', (YLeaf(YType.empty, 'callback'), ['Empty'])),
                            ('callin', (YLeaf(YType.empty, 'callin'), ['Empty'])),
                            ('callout', (YLeaf(YType.empty, 'callout'), ['Empty'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                            ('ms_chap', (YLeaf(YType.empty, 'ms-chap'), ['Empty'])),
                            ('ms_chap_v2', (YLeaf(YType.empty, 'ms-chap-v2'), ['Empty'])),
                            ('one_time', (YLeaf(YType.empty, 'one-time'), ['Empty'])),
                            ('optional', (YLeaf(YType.empty, 'optional'), ['Empty'])),
                            ('pap', (YLeaf(YType.empty, 'pap'), ['Empty'])),
                        ])
                        self.method = None
                        self.list_name = None
                        self.chap = None
                        self.callback = None
                        self.callin = None
                        self.callout = None
                        self.default = None
                        self.eap = None
                        self.ms_chap = None
                        self.ms_chap_v2 = None
                        self.one_time = None
                        self.optional = None
                        self.pap = None
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ppp.Authentication, ['method', 'list_name', 'chap', 'callback', 'callin', 'callout', 'default', 'eap', 'ms_chap', 'ms_chap_v2', 'one_time', 'optional', 'pap'], name, value)

                    class Method(Enum):
                        """
                        Method (Enum Class)

                        .. data:: chap = 0

                        .. data:: eap = 1

                        .. data:: ms_chap = 2

                        .. data:: ms_chap_v2 = 3

                        .. data:: pap = 4

                        """

                        chap = Enum.YLeaf(0, "chap")

                        eap = Enum.YLeaf(1, "eap")

                        ms_chap = Enum.YLeaf(2, "ms-chap")

                        ms_chap_v2 = Enum.YLeaf(3, "ms-chap-v2")

                        pap = Enum.YLeaf(4, "pap")



                class Ipcp(Entity):
                    """
                    Set IPCP negotiation options
                    
                    .. attribute:: dns
                    
                    	Specify DNS negotiation options
                    	**type**\:  :py:class:`Dns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Ipcp.Dns>`
                    
                    

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ppp.Ipcp, self).__init__()

                        self.yang_name = "ipcp"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dns", ("dns", Native.Interface.VirtualTemplate.Ppp.Ipcp.Dns))])
                        self._leafs = OrderedDict()

                        self.dns = Native.Interface.VirtualTemplate.Ppp.Ipcp.Dns()
                        self.dns.parent = self
                        self._children_name_map["dns"] = "dns"
                        self._segment_path = lambda: "ipcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ppp.Ipcp, [], name, value)


                    class Dns(Entity):
                        """
                        Specify DNS negotiation options
                        
                        .. attribute:: primary
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ppp.Ipcp.Dns, self).__init__()

                            self.yang_name = "dns"
                            self.yang_parent_name = "ipcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('primary', (YLeaf(YType.str, 'primary'), ['str'])),
                            ])
                            self.primary = None
                            self._segment_path = lambda: "dns"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ppp.Ipcp.Dns, ['primary'], name, value)


                class Multilink(Entity):
                    """
                    Make interface multilink capable
                    
                    .. attribute:: links
                    
                    	Specify the limits on the number of links in a bundle
                    	**type**\:  :py:class:`Links <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Multilink.Links>`
                    
                    .. attribute:: group
                    
                    	Put interface in a multilink bundle
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: endpoint
                    
                    	Configure the local Endpoint Discriminator
                    	**type**\:  :py:class:`Endpoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Multilink.Endpoint>`
                    
                    .. attribute:: fragment
                    
                    	Specify fragmentation parameters
                    	**type**\:  :py:class:`Fragment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Multilink.Fragment>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ppp'
                    _revision = '2018-02-03'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Ppp.Multilink, self).__init__()

                        self.yang_name = "multilink"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("links", ("links", Native.Interface.VirtualTemplate.Ppp.Multilink.Links)), ("endpoint", ("endpoint", Native.Interface.VirtualTemplate.Ppp.Multilink.Endpoint)), ("fragment", ("fragment", Native.Interface.VirtualTemplate.Ppp.Multilink.Fragment))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                        ])
                        self.group = None

                        self.links = Native.Interface.VirtualTemplate.Ppp.Multilink.Links()
                        self.links.parent = self
                        self._children_name_map["links"] = "links"

                        self.endpoint = Native.Interface.VirtualTemplate.Ppp.Multilink.Endpoint()
                        self.endpoint.parent = self
                        self._children_name_map["endpoint"] = "endpoint"

                        self.fragment = Native.Interface.VirtualTemplate.Ppp.Multilink.Fragment()
                        self.fragment.parent = self
                        self._children_name_map["fragment"] = "fragment"
                        self._segment_path = lambda: "multilink"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Ppp.Multilink, ['group'], name, value)


                    class Links(Entity):
                        """
                        Specify the limits on the number of links in a bundle
                        
                        .. attribute:: minimum
                        
                        	Minimum number of links desired in the bundle
                        	**type**\:  :py:class:`Minimum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Multilink.Links.Minimum>`
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ppp.Multilink.Links, self).__init__()

                            self.yang_name = "links"
                            self.yang_parent_name = "multilink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minimum", ("minimum", Native.Interface.VirtualTemplate.Ppp.Multilink.Links.Minimum))])
                            self._leafs = OrderedDict()

                            self.minimum = Native.Interface.VirtualTemplate.Ppp.Multilink.Links.Minimum()
                            self.minimum.parent = self
                            self._children_name_map["minimum"] = "minimum"
                            self._segment_path = lambda: "links"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ppp.Multilink.Links, [], name, value)


                        class Minimum(Entity):
                            """
                            Minimum number of links desired in the bundle
                            
                            .. attribute:: minimum_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: mandatory
                            
                            	Disable network layer until minimum number of links is reach
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ppp'
                            _revision = '2018-02-03'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ppp.Multilink.Links.Minimum, self).__init__()

                                self.yang_name = "minimum"
                                self.yang_parent_name = "links"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum_value', (YLeaf(YType.uint8, 'minimum-value'), ['int'])),
                                    ('mandatory', (YLeaf(YType.empty, 'mandatory'), ['Empty'])),
                                ])
                                self.minimum_value = None
                                self.mandatory = None
                                self._segment_path = lambda: "minimum"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ppp.Multilink.Links.Minimum, ['minimum_value', 'mandatory'], name, value)


                    class Endpoint(Entity):
                        """
                        Configure the local Endpoint Discriminator
                        
                        .. attribute:: string
                        
                        	Use specified string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ppp.Multilink.Endpoint, self).__init__()

                            self.yang_name = "endpoint"
                            self.yang_parent_name = "multilink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                            ])
                            self.string = None
                            self._segment_path = lambda: "endpoint"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ppp.Multilink.Endpoint, ['string'], name, value)


                    class Fragment(Entity):
                        """
                        Specify fragmentation parameters
                        
                        .. attribute:: delay
                        
                        	Specify the maximum delay for each fragment
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Ppp.Multilink.Fragment.Delay>`
                        
                        .. attribute:: disable
                        
                        	Suppress multilink fragmentation when possible
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ppp'
                        _revision = '2018-02-03'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Ppp.Multilink.Fragment, self).__init__()

                            self.yang_name = "fragment"
                            self.yang_parent_name = "multilink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.VirtualTemplate.Ppp.Multilink.Fragment.Delay))])
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None

                            self.delay = Native.Interface.VirtualTemplate.Ppp.Multilink.Fragment.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "fragment"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Ppp.Multilink.Fragment, ['disable'], name, value)


                        class Delay(Entity):
                            """
                            Specify the maximum delay for each fragment
                            
                            .. attribute:: delay_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..1000
                            
                            .. attribute:: additional_delay_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..999
                            
                            

                            """

                            _prefix = 'ios-ppp'
                            _revision = '2018-02-03'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Ppp.Multilink.Fragment.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "fragment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('delay_value', (YLeaf(YType.uint16, 'delay-value'), ['int'])),
                                    ('additional_delay_value', (YLeaf(YType.uint16, 'additional-delay-value'), ['int'])),
                                ])
                                self.delay_value = None
                                self.additional_delay_value = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Ppp.Multilink.Fragment.Delay, ['delay_value', 'additional_delay_value'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts.Manual>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.VirtualTemplate.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "Virtual-Template"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.VirtualTemplate.Cts.Manual))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualTemplate.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.VirtualTemplate.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.VirtualTemplate.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.VirtualTemplate.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.VirtualTemplate.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.VirtualTemplate.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.VirtualTemplate.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.VirtualTemplate.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualTemplate.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.VirtualTemplate.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.VirtualTemplate.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualTemplate.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.VirtualTemplate.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualTemplate.Cts.Manual.Propagate, ['sgt'], name, value)


        class VirtualPortGroup(Entity):
            """
            Virtual Port Group
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..31
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.PmPath>`
            
            .. attribute:: carrier_delay
            
            	Specify delay for interface transitions
            	**type**\:  :py:class:`CarrierDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.CarrierDelay>`
            
            .. attribute:: channel_group
            
            	Add this interface to an Etherchannel group
            	**type**\:  :py:class:`ChannelGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ChannelGroup>`
            
            .. attribute:: channel_protocol
            
            	Select the channel protocol (LACP, PAgP)
            	**type**\:  :py:class:`ChannelProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ChannelProtocol>`
            
            .. attribute:: ethernet
            
            	Ethernet interface parameters
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet>`
            
            .. attribute:: eapol
            
            	eapol
            	**type**\:  :py:class:`Eapol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Eapol>`
            
            .. attribute:: synchronous
            
            	Synchronous
            	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Synchronous>`
            
            .. attribute:: speed
            
            	Configure speed operation
            	**type**\:  :py:class:`Speed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Speed>`
            
            .. attribute:: duplex
            
            	Configure duplex operation
            	**type**\:  :py:class:`Duplex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Duplex>`
            
            .. attribute:: negotiation
            
            	Select autonegotiation mode
            	**type**\:  :py:class:`Negotiation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Negotiation>`
            
            .. attribute:: plim
            
            	Configure features on the PLIM
            	**type**\:  :py:class:`Plim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Plim>`
            
            .. attribute:: pppoe
            
            	pppoe interface subcommands
            	**type**\:  :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe>`
            
            .. attribute:: service
            
            	Configure Ether Service
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service>`
            
            .. attribute:: lacp
            
            	LACP interface subcommands
            	**type**\:  :py:class:`Lacp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Lacp>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ServicePolicy>`
            
            .. attribute:: snmp
            
            	Modify SNMP interface parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Snmp>`
            
            .. attribute:: mab
            
            	
            	**type**\:  :py:class:`Mab <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Mab>`
            
            	**presence node**\: True
            
            .. attribute:: cts
            
            	Configure Cisco Trusted Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.VirtualPortGroup, self).__init__()

                self.yang_name = "VirtualPortGroup"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.VirtualPortGroup.SwitchportConf)), ("switchport", ("switchport", Native.Interface.VirtualPortGroup.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.VirtualPortGroup.StackwiseVirtual)), ("arp", ("arp", Native.Interface.VirtualPortGroup.Arp)), ("backup", ("backup", Native.Interface.VirtualPortGroup.Backup)), ("cemoudp", ("cemoudp", Native.Interface.VirtualPortGroup.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.VirtualPortGroup.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.VirtualPortGroup.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.VirtualPortGroup.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.VirtualPortGroup.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.VirtualPortGroup.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.VirtualPortGroup.Flowcontrol)), ("isis", ("isis", Native.Interface.VirtualPortGroup.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.VirtualPortGroup.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.VirtualPortGroup.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.VirtualPortGroup.Bandwidth)), ("dampening", ("dampening", Native.Interface.VirtualPortGroup.Dampening)), ("domain", ("domain", Native.Interface.VirtualPortGroup.Domain)), ("hold-queue", ("hold_queue", Native.Interface.VirtualPortGroup.HoldQueue)), ("mpls", ("mpls", Native.Interface.VirtualPortGroup.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.VirtualPortGroup.IpVrf)), ("vrf", ("vrf", Native.Interface.VirtualPortGroup.Vrf)), ("ip", ("ip", Native.Interface.VirtualPortGroup.Ip)), ("ipv6", ("ipv6", Native.Interface.VirtualPortGroup.Ipv6)), ("logging", ("logging", Native.Interface.VirtualPortGroup.Logging)), ("mdix", ("mdix", Native.Interface.VirtualPortGroup.Mdix)), ("mop", ("mop", Native.Interface.VirtualPortGroup.Mop)), ("interface_qos", ("interface_qos", Native.Interface.VirtualPortGroup.InterfaceQos)), ("source", ("source", Native.Interface.VirtualPortGroup.Source)), ("standby", ("standby", Native.Interface.VirtualPortGroup.Standby)), ("access-session", ("access_session", Native.Interface.VirtualPortGroup.AccessSession)), ("storm-control", ("storm_control", Native.Interface.VirtualPortGroup.StormControl)), ("trust", ("trust", Native.Interface.VirtualPortGroup.Trust)), ("priority-queue", ("priority_queue", Native.Interface.VirtualPortGroup.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.VirtualPortGroup.RcvQueue)), ("peer", ("peer", Native.Interface.VirtualPortGroup.Peer)), ("pm-path", ("pm_path", Native.Interface.VirtualPortGroup.PmPath)), ("Cisco-IOS-XE-ethernet:carrier-delay", ("carrier_delay", Native.Interface.VirtualPortGroup.CarrierDelay)), ("Cisco-IOS-XE-ethernet:channel-group", ("channel_group", Native.Interface.VirtualPortGroup.ChannelGroup)), ("Cisco-IOS-XE-ethernet:ethernet", ("ethernet", Native.Interface.VirtualPortGroup.Ethernet)), ("Cisco-IOS-XE-ethernet:eapol", ("eapol", Native.Interface.VirtualPortGroup.Eapol)), ("Cisco-IOS-XE-ethernet:synchronous", ("synchronous", Native.Interface.VirtualPortGroup.Synchronous)), ("Cisco-IOS-XE-ethernet:speed", ("speed", Native.Interface.VirtualPortGroup.Speed)), ("Cisco-IOS-XE-ethernet:negotiation", ("negotiation", Native.Interface.VirtualPortGroup.Negotiation)), ("Cisco-IOS-XE-ethernet:plim", ("plim", Native.Interface.VirtualPortGroup.Plim)), ("Cisco-IOS-XE-ethernet:pppoe", ("pppoe", Native.Interface.VirtualPortGroup.Pppoe)), ("Cisco-IOS-XE-ethernet:service", ("service", Native.Interface.VirtualPortGroup.Service)), ("Cisco-IOS-XE-ethernet:lacp", ("lacp", Native.Interface.VirtualPortGroup.Lacp)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.VirtualPortGroup.ServicePolicy)), ("Cisco-IOS-XE-snmp:snmp", ("snmp", Native.Interface.VirtualPortGroup.Snmp)), ("Cisco-IOS-XE-sanet:mab", ("mab", Native.Interface.VirtualPortGroup.Mab)), ("Cisco-IOS-XE-cts:cts", ("cts", Native.Interface.VirtualPortGroup.Cts))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.ServiceInsertion')])),
                    ('channel_protocol', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:channel-protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.ChannelProtocol')])),
                    ('duplex', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ethernet:duplex'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Duplex')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None
                self.channel_protocol = None
                self.duplex = None

                self.switchport_conf = Native.Interface.VirtualPortGroup.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.VirtualPortGroup.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.VirtualPortGroup.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.VirtualPortGroup.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.VirtualPortGroup.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.VirtualPortGroup.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.VirtualPortGroup.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.VirtualPortGroup.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.VirtualPortGroup.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.VirtualPortGroup.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.VirtualPortGroup.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.VirtualPortGroup.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.VirtualPortGroup.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.VirtualPortGroup.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.VirtualPortGroup.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.VirtualPortGroup.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.VirtualPortGroup.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.VirtualPortGroup.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.VirtualPortGroup.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.VirtualPortGroup.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.VirtualPortGroup.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.VirtualPortGroup.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.VirtualPortGroup.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.VirtualPortGroup.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.VirtualPortGroup.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.VirtualPortGroup.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.VirtualPortGroup.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.VirtualPortGroup.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.VirtualPortGroup.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.VirtualPortGroup.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.VirtualPortGroup.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.VirtualPortGroup.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.VirtualPortGroup.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.VirtualPortGroup.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.VirtualPortGroup.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.carrier_delay = Native.Interface.VirtualPortGroup.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "Cisco-IOS-XE-ethernet:carrier-delay"

                self.channel_group = Native.Interface.VirtualPortGroup.ChannelGroup()
                self.channel_group.parent = self
                self._children_name_map["channel_group"] = "Cisco-IOS-XE-ethernet:channel-group"

                self.ethernet = Native.Interface.VirtualPortGroup.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "Cisco-IOS-XE-ethernet:ethernet"

                self.eapol = Native.Interface.VirtualPortGroup.Eapol()
                self.eapol.parent = self
                self._children_name_map["eapol"] = "Cisco-IOS-XE-ethernet:eapol"

                self.synchronous = Native.Interface.VirtualPortGroup.Synchronous()
                self.synchronous.parent = self
                self._children_name_map["synchronous"] = "Cisco-IOS-XE-ethernet:synchronous"

                self.speed = Native.Interface.VirtualPortGroup.Speed()
                self.speed.parent = self
                self._children_name_map["speed"] = "Cisco-IOS-XE-ethernet:speed"

                self.negotiation = Native.Interface.VirtualPortGroup.Negotiation()
                self.negotiation.parent = self
                self._children_name_map["negotiation"] = "Cisco-IOS-XE-ethernet:negotiation"

                self.plim = Native.Interface.VirtualPortGroup.Plim()
                self.plim.parent = self
                self._children_name_map["plim"] = "Cisco-IOS-XE-ethernet:plim"

                self.pppoe = Native.Interface.VirtualPortGroup.Pppoe()
                self.pppoe.parent = self
                self._children_name_map["pppoe"] = "Cisco-IOS-XE-ethernet:pppoe"

                self.service = Native.Interface.VirtualPortGroup.Service()
                self.service.parent = self
                self._children_name_map["service"] = "Cisco-IOS-XE-ethernet:service"

                self.lacp = Native.Interface.VirtualPortGroup.Lacp()
                self.lacp.parent = self
                self._children_name_map["lacp"] = "Cisco-IOS-XE-ethernet:lacp"

                self.service_policy = Native.Interface.VirtualPortGroup.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.snmp = Native.Interface.VirtualPortGroup.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "Cisco-IOS-XE-snmp:snmp"

                self.mab = None
                self._children_name_map["mab"] = "Cisco-IOS-XE-sanet:mab"

                self.cts = Native.Interface.VirtualPortGroup.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "Cisco-IOS-XE-cts:cts"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "VirtualPortGroup" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.VirtualPortGroup, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion', 'channel_protocol', 'duplex'], name, value)

            class ChannelProtocol(Enum):
                """
                ChannelProtocol (Enum Class)

                Select the channel protocol (LACP, PAgP)

                .. data:: lacp = 0

                .. data:: pagp = 1

                """

                lacp = Enum.YLeaf(0, "lacp")

                pagp = Enum.YLeaf(1, "pagp")


            class Duplex(Enum):
                """
                Duplex (Enum Class)

                Configure duplex operation.

                .. data:: auto = 0

                .. data:: full = 1

                .. data:: half = 2

                """

                auto = Enum.YLeaf(0, "auto")

                full = Enum.YLeaf(1, "full")

                half = Enum.YLeaf(2, "half")


            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.VirtualPortGroup.Backup.Delay)), ("interface", ("interface", Native.Interface.VirtualPortGroup.Backup.Interface_)), ("load", ("load", Native.Interface.VirtualPortGroup.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.VirtualPortGroup.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.VirtualPortGroup.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.VirtualPortGroup.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.VirtualPortGroup.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.VirtualPortGroup.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.VirtualPortGroup.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.VirtualPortGroup.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.VirtualPortGroup.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.VirtualPortGroup.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.VirtualPortGroup.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.VirtualPortGroup.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.VirtualPortGroup.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.VirtualPortGroup.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.VirtualPortGroup.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.VirtualPortGroup.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.VirtualPortGroup.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.VirtualPortGroup.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.VirtualPortGroup.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.VirtualPortGroup.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.VirtualPortGroup.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.VirtualPortGroup.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.VirtualPortGroup.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.VirtualPortGroup.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.VirtualPortGroup.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.VirtualPortGroup.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.VirtualPortGroup.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.VirtualPortGroup.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                .. attribute:: template
                
                	BFD template
                	**type**\: str
                
                .. attribute:: interval
                
                	Transmit interval between BFD packets
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Bfd.Interval>`
                
                .. attribute:: echo
                
                	Use echo adjunct as bfd detection mechanism
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:interval", ("interval", Native.Interface.VirtualPortGroup.Bfd.Interval))])
                    self._leafs = OrderedDict([
                        ('template', (YLeaf(YType.str, 'Cisco-IOS-XE-bfd:template'), ['str'])),
                        ('echo', (YLeaf(YType.boolean, 'Cisco-IOS-XE-bfd:echo'), ['bool'])),
                    ])
                    self.template = None
                    self.echo = None

                    self.interval = Native.Interface.VirtualPortGroup.Bfd.Interval()
                    self.interval.parent = self
                    self._children_name_map["interval"] = "Cisco-IOS-XE-bfd:interval"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Bfd, ['template', 'echo'], name, value)


                class Interval(Entity):
                    """
                    Transmit interval between BFD packets
                    
                    .. attribute:: msecs
                    
                    	
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: min_rx
                    
                    	Minimum receive interval capability
                    	**type**\: int
                    
                    	**range:** 50..9999
                    
                    .. attribute:: multiplier
                    
                    	Multiplier value used to compute holddown
                    	**type**\: int
                    
                    	**range:** 3..50
                    
                    

                    """

                    _prefix = 'ios-bfd'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Bfd.Interval, self).__init__()

                        self.yang_name = "interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('msecs', (YLeaf(YType.uint16, 'msecs'), ['int'])),
                            ('min_rx', (YLeaf(YType.uint16, 'min_rx'), ['int'])),
                            ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                        ])
                        self.msecs = None
                        self.min_rx = None
                        self.multiplier = None
                        self._segment_path = lambda: "Cisco-IOS-XE-bfd:interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Bfd.Interval, ['msecs', 'min_rx', 'multiplier'], name, value)


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.VirtualPortGroup.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.VirtualPortGroup.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.VirtualPortGroup.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.VirtualPortGroup.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.VirtualPortGroup.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.VirtualPortGroup.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.VirtualPortGroup.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.VirtualPortGroup.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.VirtualPortGroup.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Verify>`
                
                .. attribute:: igmp
                
                	IGMP interface commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp>`
                
                .. attribute:: nat
                
                	NAT interface commands
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Nat>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.VirtualPortGroup.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.VirtualPortGroup.Ip.Arp)), ("vrf", ("vrf", Native.Interface.VirtualPortGroup.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.VirtualPortGroup.Ip.NoAddress)), ("address", ("address", Native.Interface.VirtualPortGroup.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.VirtualPortGroup.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.VirtualPortGroup.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.VirtualPortGroup.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.VirtualPortGroup.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.VirtualPortGroup.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.VirtualPortGroup.Ip.Pim)), ("policy", ("policy", Native.Interface.VirtualPortGroup.Ip.Policy)), ("rip", ("rip", Native.Interface.VirtualPortGroup.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.VirtualPortGroup.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.VirtualPortGroup.Ip.RouteCache)), ("router", ("router", Native.Interface.VirtualPortGroup.Ip.Router)), ("tcp", ("tcp", Native.Interface.VirtualPortGroup.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.VirtualPortGroup.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.VirtualPortGroup.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.VirtualPortGroup.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.VirtualPortGroup.Ip.Verify)), ("Cisco-IOS-XE-igmp:igmp", ("igmp", Native.Interface.VirtualPortGroup.Ip.Igmp)), ("Cisco-IOS-XE-nat:nat", ("nat", Native.Interface.VirtualPortGroup.Ip.Nat))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.VirtualPortGroup.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.VirtualPortGroup.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.VirtualPortGroup.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.VirtualPortGroup.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.VirtualPortGroup.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.VirtualPortGroup.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.VirtualPortGroup.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.VirtualPortGroup.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.VirtualPortGroup.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.VirtualPortGroup.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.VirtualPortGroup.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.VirtualPortGroup.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.VirtualPortGroup.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.VirtualPortGroup.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.VirtualPortGroup.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.VirtualPortGroup.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.VirtualPortGroup.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.VirtualPortGroup.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.igmp = Native.Interface.VirtualPortGroup.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "Cisco-IOS-XE-igmp:igmp"

                    self.nat = Native.Interface.VirtualPortGroup.Ip.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "Cisco-IOS-XE-nat:nat"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.VirtualPortGroup.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.VirtualPortGroup.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.VirtualPortGroup.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.VirtualPortGroup.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.VirtualPortGroup.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.VirtualPortGroup.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.VirtualPortGroup.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.VirtualPortGroup.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.VirtualPortGroup.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.VirtualPortGroup.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.VirtualPortGroup.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.VirtualPortGroup.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.VirtualPortGroup.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.VirtualPortGroup.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.VirtualPortGroup.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.VirtualPortGroup.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.VirtualPortGroup.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.VirtualPortGroup.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.VirtualPortGroup.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.VirtualPortGroup.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.VirtualPortGroup.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.VirtualPortGroup.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.VirtualPortGroup.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.VirtualPortGroup.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.VirtualPortGroup.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.VirtualPortGroup.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.VirtualPortGroup.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.VirtualPortGroup.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.VirtualPortGroup.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.VirtualPortGroup.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.VirtualPortGroup.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.VirtualPortGroup.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.VirtualPortGroup.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.VirtualPortGroup.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.VirtualPortGroup.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.VirtualPortGroup.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.VirtualPortGroup.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Igmp(Entity):
                    """
                    IGMP interface commands
                    
                    .. attribute:: static_group
                    
                    	IGMP static multicast group
                    	**type**\:  :py:class:`StaticGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup>`
                    
                    .. attribute:: join_group
                    
                    	IGMP join multicast group
                    	**type**\: list of  		 :py:class:`JoinGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.JoinGroup>`
                    
                    .. attribute:: version
                    
                    	IGMP version
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-igmp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-group", ("static_group", Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup)), ("join-group", ("join_group", Native.Interface.VirtualPortGroup.Ip.Igmp.JoinGroup))])
                        self._leafs = OrderedDict([
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.version = None

                        self.static_group = Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup()
                        self.static_group.parent = self
                        self._children_name_map["static_group"] = "static-group"

                        self.join_group = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-igmp:igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Igmp, [u'version'], name, value)


                    class StaticGroup(Entity):
                        """
                        IGMP static multicast group
                        
                        .. attribute:: groups
                        
                        	
                        	**type**\: list of  		 :py:class:`Groups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups>`
                        
                        .. attribute:: class_map
                        
                        	Class map of type multicast\-flows
                        	**type**\: list of  		 :py:class:`ClassMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.ClassMap>`
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup, self).__init__()

                            self.yang_name = "static-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("groups", ("groups", Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups)), ("class-map", ("class_map", Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.ClassMap))])
                            self._leafs = OrderedDict()

                            self.groups = YList(self)
                            self.class_map = YList(self)
                            self._segment_path = lambda: "static-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup, [], name, value)


                        class Groups(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name>`
                            
                            .. attribute:: source
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of   :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups, self).__init__()

                                self.yang_name = "groups"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Name')])),
                                    ('source', (YLeafList(YType.str, 'source'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups.Source')])),
                                ])
                                self.name = None
                                self.source = []
                                self._segment_path = lambda: "groups" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.Groups, [u'name', u'source'], name, value)

                            class Name(Enum):
                                """
                                Name (Enum Class)

                                .. data:: Y__STAR__ = 0

                                """

                                Y__STAR__ = Enum.YLeaf(0, "*")


                            class Source(Enum):
                                """
                                Source (Enum Class)

                                .. data:: ssm_map = 0

                                """

                                ssm_map = Enum.YLeaf(0, "ssm-map")



                        class ClassMap(Entity):
                            """
                            Class map of type multicast\-flows
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            	**refers to**\:  :py:class:`name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Policy.ClassMap>`
                            
                            

                            """

                            _prefix = 'ios-igmp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.ClassMap, self).__init__()

                                self.yang_name = "class-map"
                                self.yang_parent_name = "static-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "class-map" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Igmp.StaticGroup.ClassMap, [u'id'], name, value)


                    class JoinGroup(Entity):
                        """
                        IGMP join multicast group
                        
                        .. attribute:: ip_group_address  (key)
                        
                        	IP group address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	IP source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-igmp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ip.Igmp.JoinGroup, self).__init__()

                            self.yang_name = "join-group"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_group_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_group_address', (YLeaf(YType.str, 'ip-group-address'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.ip_group_address = None
                            self.source = None
                            self._segment_path = lambda: "join-group" + "[ip-group-address='" + str(self.ip_group_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Igmp.JoinGroup, [u'ip_group_address', u'source'], name, value)


                class Nat(Entity):
                    """
                    NAT interface commands
                    
                    .. attribute:: allow_static_host
                    
                    	Allow static\-ip clients
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Enable Address Translation (NVI)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: inside
                    
                    	Inside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: outside
                    
                    	Outside interface for address translation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-nat'
                    _revision = '2018-06-30'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ip.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('allow_static_host', (YLeaf(YType.empty, 'allow-static-host'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('inside', (YLeaf(YType.empty, 'inside'), ['Empty'])),
                            ('outside', (YLeaf(YType.empty, 'outside'), ['Empty'])),
                        ])
                        self.allow_static_host = None
                        self.enable = None
                        self.inside = None
                        self.outside = None
                        self._segment_path = lambda: "Cisco-IOS-XE-nat:nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ip.Nat, ['allow_static_host', 'enable', 'inside', 'outside'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.VirtualPortGroup.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.VirtualPortGroup.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.VirtualPortGroup.Ipv6.Dhcp)), ("address", ("address", Native.Interface.VirtualPortGroup.Ipv6.Address)), ("nd", ("nd", Native.Interface.VirtualPortGroup.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.VirtualPortGroup.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.VirtualPortGroup.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.VirtualPortGroup.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.VirtualPortGroup.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.VirtualPortGroup.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.VirtualPortGroup.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.VirtualPortGroup.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.VirtualPortGroup.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.VirtualPortGroup.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.VirtualPortGroup.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.VirtualPortGroup.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.VirtualPortGroup.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.VirtualPortGroup.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.VirtualPortGroup.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.VirtualPortGroup.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.VirtualPortGroup.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.VirtualPortGroup.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.VirtualPortGroup.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.VirtualPortGroup.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.VirtualPortGroup.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.VirtualPortGroup.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.VirtualPortGroup.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.VirtualPortGroup.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.VirtualPortGroup.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.VirtualPortGroup.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.VirtualPortGroup.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.VirtualPortGroup.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.VirtualPortGroup.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.VirtualPortGroup.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.VirtualPortGroup.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.VirtualPortGroup.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.VirtualPortGroup.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.VirtualPortGroup.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.VirtualPortGroup.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.VirtualPortGroup.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.VirtualPortGroup.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.VirtualPortGroup.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.VirtualPortGroup.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.VirtualPortGroup.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.VirtualPortGroup.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.VirtualPortGroup.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.VirtualPortGroup.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.VirtualPortGroup.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.VirtualPortGroup.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.VirtualPortGroup.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.VirtualPortGroup.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.VirtualPortGroup.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.VirtualPortGroup.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.VirtualPortGroup.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.VirtualPortGroup.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.VirtualPortGroup.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.VirtualPortGroup.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.VirtualPortGroup.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.VirtualPortGroup.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.VirtualPortGroup.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.PmPath, [u'name', u'interface_id'], name, value)


            class CarrierDelay(Entity):
                """
                Specify delay for interface transitions
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 0..60
                
                .. attribute:: msec
                
                	delay specified in milliseconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: down
                
                	Carrier Down Transitions
                	**type**\:  :py:class:`Down <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.CarrierDelay.Down>`
                
                .. attribute:: up
                
                	Carrier Up Transitions
                	**type**\:  :py:class:`Up <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.CarrierDelay.Up>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("down", ("down", Native.Interface.VirtualPortGroup.CarrierDelay.Down)), ("up", ("up", Native.Interface.VirtualPortGroup.CarrierDelay.Up))])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                        ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                    ])
                    self.seconds = None
                    self.msec = None

                    self.down = Native.Interface.VirtualPortGroup.CarrierDelay.Down()
                    self.down.parent = self
                    self._children_name_map["down"] = "down"

                    self.up = Native.Interface.VirtualPortGroup.CarrierDelay.Up()
                    self.up.parent = self
                    self._children_name_map["up"] = "up"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:carrier-delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.CarrierDelay, ['seconds', 'msec'], name, value)


                class Down(Entity):
                    """
                    Carrier Down Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.CarrierDelay.Down, self).__init__()

                        self.yang_name = "down"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.CarrierDelay.Down, ['seconds', 'msec'], name, value)


                class Up(Entity):
                    """
                    Carrier Up Transitions
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..60
                    
                    .. attribute:: msec
                    
                    	delay specified in milliseconds
                    	**type**\: int
                    
                    	**range:** 0..1000
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.CarrierDelay.Up, self).__init__()

                        self.yang_name = "up"
                        self.yang_parent_name = "carrier-delay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                        ])
                        self.seconds = None
                        self.msec = None
                        self._segment_path = lambda: "up"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.CarrierDelay.Up, ['seconds', 'msec'], name, value)


            class ChannelGroup(Entity):
                """
                Add this interface to an Etherchannel group
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..512
                
                .. attribute:: mode
                
                	Etherchannel Mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ChannelGroup.Mode>`
                
                .. attribute:: non_silent
                
                	Start negotiation only after data packets received
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link
                
                	Assign a link identifier used for load\-balancing
                	**type**\: int
                
                	**range:** 1..4
                
                .. attribute:: auto
                
                	LACP auto
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.ChannelGroup, self).__init__()

                    self.yang_name = "channel-group"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.ChannelGroup.Mode')])),
                        ('non_silent', (YLeaf(YType.empty, 'non-silent'), ['Empty'])),
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ])
                    self.number = None
                    self.mode = None
                    self.non_silent = None
                    self.link = None
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:channel-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.ChannelGroup, ['number', 'mode', 'non_silent', 'link', 'auto'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Etherchannel Mode of the interface

                    .. data:: active = 0

                    .. data:: auto = 1

                    .. data:: desirable = 2

                    .. data:: on = 3

                    .. data:: passive = 4

                    """

                    active = Enum.YLeaf(0, "active")

                    auto = Enum.YLeaf(1, "auto")

                    desirable = Enum.YLeaf(2, "desirable")

                    on = Enum.YLeaf(3, "on")

                    passive = Enum.YLeaf(4, "passive")



            class Ethernet(Entity):
                """
                Ethernet interface parameters
                
                .. attribute:: oam
                
                	To enable Ethernet Link OAM
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam>`
                
                	**presence node**\: True
                
                .. attribute:: dot1ad
                
                	ethernet dot1ad port
                	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Dot1ad>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Interface.VirtualPortGroup.Ethernet.Oam)), ("dot1ad", ("dot1ad", Native.Interface.VirtualPortGroup.Ethernet.Dot1ad))])
                    self._leafs = OrderedDict()

                    self.oam = None
                    self._children_name_map["oam"] = "oam"

                    self.dot1ad = Native.Interface.VirtualPortGroup.Ethernet.Dot1ad()
                    self.dot1ad.parent = self
                    self._children_name_map["dot1ad"] = "dot1ad"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    To enable Ethernet Link OAM
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: max_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: min_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    .. attribute:: mode
                    
                    	
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.Mode>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure>`
                    
                    .. attribute:: remote_loopback
                    
                    	Ethernet OAM Remote Loopback
                    	**type**\:  :py:class:`RemoteLoopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteLoopback>`
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..30
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure)), ("remote-loopback", ("remote_loopback", Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteLoopback))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_rate', (YLeaf(YType.uint8, 'max-rate'), ['int'])),
                            ('min_rate', (YLeaf(YType.uint8, 'min-rate'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Ethernet.Oam.Mode')])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.max_rate = None
                        self.min_rate = None
                        self.mode = None
                        self.timeout = None

                        self.link_monitor = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"

                        self.remote_loopback = Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteLoopback()
                        self.remote_loopback.parent = self
                        self._children_name_map["remote_loopback"] = "remote-loopback"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam, ['max_rate', 'min_rate', 'mode', 'timeout'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: on
                        
                        	Enable link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: supported
                        
                        	Support link monitoring on the interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod))])
                            self._leafs = OrderedDict([
                                ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                            ])
                            self.on = None
                            self.supported = None

                            self.frame = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor, ['on', 'supported'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	Errored frame threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..600
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: thresh
                                    
                                    	Set the high errored frame threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('thresh', (YLeaf(YType.uint16, 'thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['thresh', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-period threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: f_thresh
                                    
                                    	Set the high errored frame\-period threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('f_thresh', (YLeaf(YType.uint16, 'f-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.f_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['f_thresh', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: e_thresh
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('e_thresh', (YLeaf(YType.uint16, 'e-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.e_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['e_thresh', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low received crc error threshold in number of frames
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: crc_thresh
                                    
                                    	Set the high received crc error threshold in number of frames
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('crc_thresh', (YLeaf(YType.uint16, 'crc-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.crc_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['crc_thresh', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	Error symbol\-period threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 1048576 symbols
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Error symbol\-period threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low error symbol\-period threshold in number of symbols
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: err_thresh
                                    
                                    	Set the high error symbol\-period threshold in number of symbols
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('err_thresh', (YLeaf(YType.uint16, 'err-thresh'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.err_thresh = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['err_thresh', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	Error\-disable the interface
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


                    class RemoteLoopback(Entity):
                        """
                        Ethernet OAM Remote Loopback
                        
                        .. attribute:: supported
                        
                        	Support remote loopback functionality
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	Set timeout value in number of seconds
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteLoopback, self).__init__()

                            self.yang_name = "remote-loopback"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('supported', (YLeaf(YType.empty, 'supported'), ['Empty'])),
                                ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                            ])
                            self.supported = None
                            self.timeout = None
                            self._segment_path = lambda: "remote-loopback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Oam.RemoteLoopback, ['supported', 'timeout'], name, value)


                class Dot1ad(Entity):
                    """
                    ethernet dot1ad port
                    
                    .. attribute:: nni
                    
                    	dot1ad nni port
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uni
                    
                    	dot1ad uni
                    	**type**\:  :py:class:`Uni <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Ethernet.Dot1ad.Uni>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Ethernet.Dot1ad, self).__init__()

                        self.yang_name = "dot1ad"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("uni", ("uni", Native.Interface.VirtualPortGroup.Ethernet.Dot1ad.Uni))])
                        self._leafs = OrderedDict([
                            ('nni', (YLeaf(YType.empty, 'nni'), ['Empty'])),
                        ])
                        self.nni = None

                        self.uni = Native.Interface.VirtualPortGroup.Ethernet.Dot1ad.Uni()
                        self.uni.parent = self
                        self._children_name_map["uni"] = "uni"
                        self._segment_path = lambda: "dot1ad"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Dot1ad, ['nni'], name, value)


                    class Uni(Entity):
                        """
                        dot1ad uni
                        
                        .. attribute:: c_port
                        
                        	dot1ad uni customer bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s_port
                        
                        	dot1ad uni s bridge port
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Ethernet.Dot1ad.Uni, self).__init__()

                            self.yang_name = "uni"
                            self.yang_parent_name = "dot1ad"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('c_port', (YLeaf(YType.empty, 'c-port'), ['Empty'])),
                                ('s_port', (YLeaf(YType.empty, 's-port'), ['Empty'])),
                            ])
                            self.c_port = None
                            self.s_port = None
                            self._segment_path = lambda: "uni"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Ethernet.Dot1ad.Uni, ['c_port', 's_port'], name, value)


            class Eapol(Entity):
                """
                eapol
                
                .. attribute:: destination_address
                
                	Configure destination MAC address
                	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Eapol.DestinationAddress>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Eapol, self).__init__()

                    self.yang_name = "eapol"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.Interface.VirtualPortGroup.Eapol.DestinationAddress))])
                    self._leafs = OrderedDict()

                    self.destination_address = Native.Interface.VirtualPortGroup.Eapol.DestinationAddress()
                    self.destination_address.parent = self
                    self._children_name_map["destination_address"] = "destination-address"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:eapol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Eapol, [], name, value)


                class DestinationAddress(Entity):
                    """
                    Configure destination MAC address
                    
                    .. attribute:: broadcast_address
                    
                    	Configure broadcast MAC address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Eapol.DestinationAddress, self).__init__()

                        self.yang_name = "destination-address"
                        self.yang_parent_name = "eapol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast_address', (YLeaf(YType.empty, 'broadcast-address'), ['Empty'])),
                        ])
                        self.broadcast_address = None
                        self._segment_path = lambda: "destination-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Eapol.DestinationAddress, ['broadcast_address'], name, value)


            class Synchronous(Entity):
                """
                Synchronous
                
                .. attribute:: mode
                
                	Mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Synchronous, self).__init__()

                    self.yang_name = "synchronous"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:synchronous"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Synchronous, ['mode'], name, value)


            class Speed(Entity):
                """
                Configure speed operation
                
                .. attribute:: auto
                
                	Enable AUTO speed configuration
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10
                
                	10 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_100
                
                	100 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_1000
                
                	1000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value_10000
                
                	10000 Mbps operation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nonegotiate
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Speed, self).__init__()

                    self.yang_name = "speed"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ('value_10', (YLeaf(YType.empty, 'value-10'), ['Empty'])),
                        ('value_100', (YLeaf(YType.empty, 'value-100'), ['Empty'])),
                        ('value_1000', (YLeaf(YType.empty, 'value-1000'), ['Empty'])),
                        ('value_10000', (YLeaf(YType.empty, 'value-10000'), ['Empty'])),
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.auto = None
                    self.value_10 = None
                    self.value_100 = None
                    self.value_1000 = None
                    self.value_10000 = None
                    self.nonegotiate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:speed"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Speed, ['auto', 'value_10', 'value_100', 'value_1000', 'value_10000', 'nonegotiate'], name, value)


            class Negotiation(Entity):
                """
                Select autonegotiation mode
                
                .. attribute:: auto
                
                	Enable link autonegotiation
                	**type**\: bool
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Negotiation, self).__init__()

                    self.yang_name = "negotiation"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:negotiation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Negotiation, ['auto'], name, value)


            class Plim(Entity):
                """
                Configure features on the PLIM
                
                .. attribute:: ethernet
                
                	Configure features on the ethernet interface
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Plim.Ethernet>`
                
                .. attribute:: qos
                
                	QoS on the PLIM
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Plim.Qos>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Plim, self).__init__()

                    self.yang_name = "plim"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.VirtualPortGroup.Plim.Ethernet)), ("qos", ("qos", Native.Interface.VirtualPortGroup.Plim.Qos))])
                    self._leafs = OrderedDict()

                    self.ethernet = Native.Interface.VirtualPortGroup.Plim.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"

                    self.qos = Native.Interface.VirtualPortGroup.Plim.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:plim"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Plim, [], name, value)


                class Ethernet(Entity):
                    """
                    Configure features on the ethernet interface
                    
                    .. attribute:: vlan
                    
                    	vlan specific features
                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Plim.Ethernet.Vlan>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Plim.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.VirtualPortGroup.Plim.Ethernet.Vlan))])
                        self._leafs = OrderedDict()

                        self.vlan = Native.Interface.VirtualPortGroup.Plim.Ethernet.Vlan()
                        self.vlan.parent = self
                        self._children_name_map["vlan"] = "vlan"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Plim.Ethernet, [], name, value)


                    class Vlan(Entity):
                        """
                        vlan specific features
                        
                        .. attribute:: filter
                        
                        	Configure VLAN filtering
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Plim.Ethernet.Vlan.Filter>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Plim.Ethernet.Vlan, self).__init__()

                            self.yang_name = "vlan"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Interface.VirtualPortGroup.Plim.Ethernet.Vlan.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Interface.VirtualPortGroup.Plim.Ethernet.Vlan.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "vlan"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Plim.Ethernet.Vlan, [], name, value)


                        class Filter(Entity):
                            """
                            Configure VLAN filtering
                            
                            .. attribute:: disable
                            
                            	Configure the interface to accept all VLAN traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Plim.Ethernet.Vlan.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "vlan"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Plim.Ethernet.Vlan.Filter, ['disable'], name, value)


                class Qos(Entity):
                    """
                    QoS on the PLIM
                    
                    .. attribute:: input
                    
                    	Configure PLIM QoS at the input of an interface
                    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Plim.Qos.Input>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Plim.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "plim"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("input", ("input", Native.Interface.VirtualPortGroup.Plim.Qos.Input))])
                        self._leafs = OrderedDict()

                        self.input = Native.Interface.VirtualPortGroup.Plim.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Plim.Qos, [], name, value)


                    class Input(Entity):
                        """
                        Configure PLIM QoS at the input of an interface
                        
                        .. attribute:: queue
                        
                        	Queue number
                        	**type**\:  :py:class:`Queue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Plim.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("queue", ("queue", Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue))])
                            self._leafs = OrderedDict()

                            self.queue = Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                            self._segment_path = lambda: "input"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Plim.Qos.Input, [], name, value)


                        class Queue(Entity):
                            """
                            Queue number
                            
                            .. attribute:: zero
                            
                            	Low priority queue
                            	**type**\:  :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.Zero>`
                            
                            .. attribute:: strict_priority
                            
                            	High priority queue
                            	**type**\:  :py:class:`StrictPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.StrictPriority>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue, self).__init__()

                                self.yang_name = "queue"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("zero", ("zero", Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.Zero)), ("strict-priority", ("strict_priority", Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.StrictPriority))])
                                self._leafs = OrderedDict()

                                self.zero = Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.Zero()
                                self.zero.parent = self
                                self._children_name_map["zero"] = "zero"

                                self.strict_priority = Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.StrictPriority()
                                self.strict_priority.parent = self
                                self._children_name_map["strict_priority"] = "strict-priority"
                                self._segment_path = lambda: "queue"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue, [], name, value)


                            class Zero(Entity):
                                """
                                Low priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.Zero.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.Zero, self).__init__()

                                    self.yang_name = "zero"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.Zero.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.Zero.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "zero"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.Zero, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.Zero.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "zero"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.Zero.Pause, ['enable', 'threshold'], name, value)


                            class StrictPriority(Entity):
                                """
                                High priority queue
                                
                                .. attribute:: pause
                                
                                	Pause Frame generation and threshold
                                	**type**\:  :py:class:`Pause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.StrictPriority.Pause>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.StrictPriority, self).__init__()

                                    self.yang_name = "strict-priority"
                                    self.yang_parent_name = "queue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pause", ("pause", Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.StrictPriority.Pause))])
                                    self._leafs = OrderedDict()

                                    self.pause = Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.StrictPriority.Pause()
                                    self.pause.parent = self
                                    self._children_name_map["pause"] = "pause"
                                    self._segment_path = lambda: "strict-priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.StrictPriority, [], name, value)


                                class Pause(Entity):
                                    """
                                    Pause Frame generation and threshold
                                    
                                    .. attribute:: enable
                                    
                                    	Enable pause\-frame generation
                                    	**type**\: bool
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold as a percent of queue limit for pause frame generation
                                    	**type**\: int
                                    
                                    	**range:** 0..99
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.StrictPriority.Pause, self).__init__()

                                        self.yang_name = "pause"
                                        self.yang_parent_name = "strict-priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ])
                                        self.enable = None
                                        self.threshold = None
                                        self._segment_path = lambda: "pause"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Plim.Qos.Input.Queue.StrictPriority.Pause, ['enable', 'threshold'], name, value)


            class Pppoe(Entity):
                """
                pppoe interface subcommands
                
                .. attribute:: enable
                
                	Enable pppoe
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: max_sessions
                
                	Maximum PPPOE sessions
                	**type**\: int
                
                	**range:** 1..4085
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Pppoe, self).__init__()

                    self.yang_name = "pppoe"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.Interface.VirtualPortGroup.Pppoe.Enable))])
                    self._leafs = OrderedDict([
                        ('max_sessions', (YLeaf(YType.uint16, 'max-sessions'), ['int'])),
                    ])
                    self.max_sessions = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:pppoe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Pppoe, ['max_sessions'], name, value)


                class Enable(Entity):
                    """
                    Enable pppoe
                    
                    .. attribute:: group
                    
                    	attach a BBA group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Pppoe.Enable.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Pppoe.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "pppoe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Pppoe.Enable.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Pppoe.Enable, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        attach a BBA group

                        .. data:: global_ = 0

                        """

                        global_ = Enum.YLeaf(0, "global")



            class Service(Entity):
                """
                Configure Ether Service
                
                .. attribute:: instance
                
                	Configure Ether Service Instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.Interface.VirtualPortGroup.Service.Instance))])
                    self._leafs = OrderedDict()

                    self.instance = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service, [], name, value)


                class Instance(Entity):
                    """
                    Configure Ether Service Instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: trunk
                    
                    	Trunk Service Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gigabitethernet
                    
                    	Configure an GigabitEthernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	Configure an Ethernet Instance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet_evc_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	Service instance specific description
                    	**type**\: str
                    
                    	**length:** 0..240
                    
                    .. attribute:: evc_name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..100
                    
                    .. attribute:: encapsulation
                    
                    	Configure ethernet frame match criteria
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation>`
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 interface subcommands
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Ipv6>`
                    
                    .. attribute:: rewrite
                    
                    	Configure ethernet rewrite criteria
                    	**type**\:  :py:class:`Rewrite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite>`
                    
                    .. attribute:: group
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: errdisable
                    
                    	Configure error disable
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Errdisable>`
                    
                    .. attribute:: ethernet_container
                    
                    	
                    	**type**\:  :py:class:`EthernetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer>`
                    
                    .. attribute:: snmp
                    
                    	Modify SNMP service instance parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Snmp>`
                    
                    .. attribute:: bridge_domain
                    
                    	Bridge\-domain
                    	**type**\:  :py:class:`BridgeDomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.BridgeDomain>`
                    
                    .. attribute:: mac
                    
                    	Commands for MAC Address\-based features
                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Mac>`
                    
                    .. attribute:: service_policy
                    
                    	Attach a policy\-map to an EFP
                    	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cfm
                    
                    	Ethernet CFM EFP subcommands
                    	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Cfm>`
                    
                    .. attribute:: l2protocol
                    
                    	Configure l2 control protocol processing
                    	**type**\:  :py:class:`L2protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.L2protocol>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Service.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation)), ("ip", ("ip", Native.Interface.VirtualPortGroup.Service.Instance.Ip)), ("ipv6", ("ipv6", Native.Interface.VirtualPortGroup.Service.Instance.Ipv6)), ("rewrite", ("rewrite", Native.Interface.VirtualPortGroup.Service.Instance.Rewrite)), ("errdisable", ("errdisable", Native.Interface.VirtualPortGroup.Service.Instance.Errdisable)), ("ethernet-container", ("ethernet_container", Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer)), ("snmp", ("snmp", Native.Interface.VirtualPortGroup.Service.Instance.Snmp)), ("bridge-domain", ("bridge_domain", Native.Interface.VirtualPortGroup.Service.Instance.BridgeDomain)), ("mac", ("mac", Native.Interface.VirtualPortGroup.Service.Instance.Mac)), ("service-policy", ("service_policy", Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy)), ("cfm", ("cfm", Native.Interface.VirtualPortGroup.Service.Instance.Cfm)), ("l2protocol", ("l2protocol", Native.Interface.VirtualPortGroup.Service.Instance.L2protocol))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('gigabitethernet', (YLeaf(YType.empty, 'GigabitEthernet'), ['Empty'])),
                            ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                            ('ethernet_evc_name', (YLeaf(YType.str, 'ethernet-evc-name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('evc_name', (YLeaf(YType.str, 'evc-name'), ['str'])),
                            ('group', (YLeaf(YType.uint32, 'group'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.id = None
                        self.trunk = None
                        self.gigabitethernet = None
                        self.ethernet = None
                        self.ethernet_evc_name = None
                        self.description = None
                        self.evc_name = None
                        self.group = None
                        self.shutdown = None

                        self.encapsulation = Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.ip = Native.Interface.VirtualPortGroup.Service.Instance.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.Interface.VirtualPortGroup.Service.Instance.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.rewrite = Native.Interface.VirtualPortGroup.Service.Instance.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"

                        self.errdisable = Native.Interface.VirtualPortGroup.Service.Instance.Errdisable()
                        self.errdisable.parent = self
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet_container = Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer()
                        self.ethernet_container.parent = self
                        self._children_name_map["ethernet_container"] = "ethernet-container"

                        self.snmp = Native.Interface.VirtualPortGroup.Service.Instance.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.bridge_domain = Native.Interface.VirtualPortGroup.Service.Instance.BridgeDomain()
                        self.bridge_domain.parent = self
                        self._children_name_map["bridge_domain"] = "bridge-domain"

                        self.mac = Native.Interface.VirtualPortGroup.Service.Instance.Mac()
                        self.mac.parent = self
                        self._children_name_map["mac"] = "mac"

                        self.service_policy = Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"

                        self.cfm = Native.Interface.VirtualPortGroup.Service.Instance.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"

                        self.l2protocol = Native.Interface.VirtualPortGroup.Service.Instance.L2protocol()
                        self.l2protocol.parent = self
                        self._children_name_map["l2protocol"] = "l2protocol"
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance, ['id', 'trunk', 'gigabitethernet', 'ethernet', 'ethernet_evc_name', 'description', 'evc_name', 'group', 'shutdown'], name, value)


                    class Encapsulation(Entity):
                        """
                        Configure ethernet frame match criteria
                        
                        .. attribute:: default
                        
                        	catch\-all unconfigured encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dot1ad
                        
                        	802.1ad \- Provider Bridges
                        	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad>`
                        
                        .. attribute:: dot1q
                        
                        	IEEE 802.1Q Virtual LAN or S\-VLAN
                        	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q>`
                        
                        .. attribute:: priority_tagged
                        
                        	Priority tagged EFP
                        	**type**\:  :py:class:`PriorityTagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.PriorityTagged>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: untagged
                        
                        	Untagged encapsulation
                        	**type**\:  :py:class:`Untagged <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Untagged>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q)), ("priority-tagged", ("priority_tagged", Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.PriorityTagged)), ("untagged", ("untagged", Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Untagged))])
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None

                            self.dot1ad = Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad()
                            self.dot1ad.parent = self
                            self._children_name_map["dot1ad"] = "dot1ad"

                            self.dot1q = Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q()
                            self.dot1q.parent = self
                            self._children_name_map["dot1q"] = "dot1q"

                            self.priority_tagged = None
                            self._children_name_map["priority_tagged"] = "priority-tagged"

                            self.untagged = None
                            self._children_name_map["untagged"] = "untagged"
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation, ['default'], name, value)


                        class Dot1ad(Entity):
                            """
                            802.1ad \- Provider Bridges
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	CoS value to use for CFM packets
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: dot1q
                            
                            	Second tag (dot1q)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad, self).__init__()

                                self.yang_name = "dot1ad"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('dot1q', (YLeafList(YType.str, 'dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Dot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                ])
                                self.id = []
                                self.cos = []
                                self.dot1q = []
                                self.etype = []
                                self.exact = None

                                self.cos2 = Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1ad"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad, ['id', 'cos', 'dot1q', 'etype', 'exact'], name, value)

                            class Dot1q(Enum):
                                """
                                Dot1q (Enum Class)

                                Second tag (dot1q)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1ad"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1ad.Cos2, ['cos'], name, value)


                        class Dot1q(Entity):
                            """
                            IEEE 802.1Q Virtual LAN or S\-VLAN
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos
                            
                            	cos Vlan
                            	**type**\: list of int
                            
                            	**range:** 0..7
                            
                            .. attribute:: second_dot1q
                            
                            	inner 802.1Q Virtual LAN or C\-VLAN
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..4094
                            
                            		**type**\: list of   :py:class:`SecondDot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q>`
                            
                            		**type**\: list of str
                            
                            .. attribute:: cos2
                            
                            	
                            	**type**\:  :py:class:`Cos2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Cos2>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Etype>`
                            
                            .. attribute:: exact
                            
                            	payload Ethertype does not include 802.1q/802.1ad Tags
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan_type
                            
                            	Vlan Protocol Type
                            	**type**\:  :py:class:`VlanType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.VlanType>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q, self).__init__()

                                self.yang_name = "dot1q"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos2", ("cos2", Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Cos2))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeafList(YType.str, 'id'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Id'),'str'])),
                                    ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ('second_dot1q', (YLeafList(YType.str, 'second-dot1q'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.SecondDot1q'),'str'])),
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Etype')])),
                                    ('exact', (YLeaf(YType.empty, 'exact'), ['Empty'])),
                                    ('vlan_type', (YLeaf(YType.enumeration, 'vlan-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.VlanType')])),
                                ])
                                self.id = []
                                self.cos = []
                                self.second_dot1q = []
                                self.etype = []
                                self.exact = None
                                self.vlan_type = None

                                self.cos2 = Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Cos2()
                                self.cos2.parent = self
                                self._children_name_map["cos2"] = "cos2"
                                self._segment_path = lambda: "dot1q"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q, ['id', 'cos', 'second_dot1q', 'etype', 'exact', 'vlan_type'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")


                            class Id(Enum):
                                """
                                Id (Enum Class)

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class SecondDot1q(Enum):
                                """
                                SecondDot1q (Enum Class)

                                inner 802.1Q Virtual LAN or C\-VLAN

                                .. data:: any = 0

                                """

                                any = Enum.YLeaf(0, "any")


                            class VlanType(Enum):
                                """
                                VlanType (Enum Class)

                                Vlan Protocol Type

                                .. data:: Y_0x88A8 = 0

                                .. data:: Y_0x9100 = 1

                                .. data:: Y_0x9200 = 2

                                """

                                Y_0x88A8 = Enum.YLeaf(0, "0x88A8")

                                Y_0x9100 = Enum.YLeaf(1, "0x9100")

                                Y_0x9200 = Enum.YLeaf(2, "0x9200")



                            class Cos2(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Cos2, self).__init__()

                                    self.yang_name = "cos2"
                                    self.yang_parent_name = "dot1q"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Dot1q.Cos2, ['cos'], name, value)


                        class PriorityTagged(Entity):
                            """
                            Priority tagged EFP
                            
                            .. attribute:: cos_container
                            
                            	
                            	**type**\:  :py:class:`CosContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.PriorityTagged.CosContainer>`
                            
                            .. attribute:: etype
                            
                            	payload ethertype after Vlan Field
                            	**type**\: list of   :py:class:`Etype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.PriorityTagged.Etype>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.PriorityTagged, self).__init__()

                                self.yang_name = "priority-tagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cos-container", ("cos_container", Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.PriorityTagged.CosContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('etype', (YLeafList(YType.enumeration, 'etype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Encapsulation.PriorityTagged.Etype')])),
                                ])
                                self.etype = []

                                self.cos_container = Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.PriorityTagged.CosContainer()
                                self.cos_container.parent = self
                                self._children_name_map["cos_container"] = "cos-container"
                                self._segment_path = lambda: "priority-tagged"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.PriorityTagged, ['etype'], name, value)

                            class Etype(Enum):
                                """
                                Etype (Enum Class)

                                payload ethertype after Vlan Field

                                .. data:: ipv4 = 0

                                .. data:: ipv6 = 1

                                .. data:: pppoe_all = 2

                                .. data:: pppoe_discovery = 3

                                .. data:: pppoe_session = 4

                                """

                                ipv4 = Enum.YLeaf(0, "ipv4")

                                ipv6 = Enum.YLeaf(1, "ipv6")

                                pppoe_all = Enum.YLeaf(2, "pppoe-all")

                                pppoe_discovery = Enum.YLeaf(3, "pppoe-discovery")

                                pppoe_session = Enum.YLeaf(4, "pppoe-session")



                            class CosContainer(Entity):
                                """
                                
                                
                                .. attribute:: cos
                                
                                	cos Vlan
                                	**type**\: list of int
                                
                                	**range:** 0..7
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.PriorityTagged.CosContainer, self).__init__()

                                    self.yang_name = "cos-container"
                                    self.yang_parent_name = "priority-tagged"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cos', (YLeafList(YType.uint8, 'cos'), ['int'])),
                                    ])
                                    self.cos = []
                                    self._segment_path = lambda: "cos-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.PriorityTagged.CosContainer, ['cos'], name, value)


                        class Untagged(Entity):
                            """
                            Untagged encapsulation
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Encapsulation.Untagged, self).__init__()

                                self.yang_name = "untagged"
                                self.yang_parent_name = "encapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "untagged"
                                self._is_frozen = True


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Ip.Acl>`
                        
                        .. attribute:: dhcp
                        
                        	DHCP
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp>`
                        
                        .. attribute:: verify
                        
                        	verify
                        	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Ip.Verify>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.Interface.VirtualPortGroup.Service.Instance.Ip.Acl)), ("dhcp", ("dhcp", Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp)), ("verify", ("verify", Native.Interface.VirtualPortGroup.Service.Instance.Ip.Verify))])
                            self._leafs = OrderedDict()

                            self.acl = Native.Interface.VirtualPortGroup.Service.Instance.Ip.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.dhcp = Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.verify = Native.Interface.VirtualPortGroup.Service.Instance.Ip.Verify()
                            self.verify.parent = self
                            self._children_name_map["verify"] = "verify"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Ip, [], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: access_group
                            
                            	Specify access control for packets
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.access_group = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Acl, ['access_group', 'in_', 'out'], name, value)


                        class Dhcp(Entity):
                            """
                            DHCP
                            
                            .. attribute:: relay
                            
                            	DHCP relay
                            	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("relay", ("relay", Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay))])
                                self._leafs = OrderedDict()

                                self.relay = Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay()
                                self.relay.parent = self
                                self._children_name_map["relay"] = "relay"
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp, [], name, value)


                            class Relay(Entity):
                                """
                                DHCP relay
                                
                                .. attribute:: information
                                
                                	DHCP relay information
                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay.Information>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay, self).__init__()

                                    self.yang_name = "relay"
                                    self.yang_parent_name = "dhcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("information", ("information", Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay.Information))])
                                    self._leafs = OrderedDict()

                                    self.information = Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay.Information()
                                    self.information.parent = self
                                    self._children_name_map["information"] = "information"
                                    self._segment_path = lambda: "relay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay, [], name, value)


                                class Information(Entity):
                                    """
                                    DHCP relay information
                                    
                                    .. attribute:: option
                                    
                                    	DHCP relay information option
                                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay.Information.Option>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay.Information, self).__init__()

                                        self.yang_name = "information"
                                        self.yang_parent_name = "relay"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("option", ("option", Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay.Information.Option))])
                                        self._leafs = OrderedDict()

                                        self.option = Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay.Information.Option()
                                        self.option.parent = self
                                        self._children_name_map["option"] = "option"
                                        self._segment_path = lambda: "information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay.Information, [], name, value)


                                    class Option(Entity):
                                        """
                                        DHCP relay information option
                                        
                                        .. attribute:: subscriber_id
                                        
                                        	DHCP relay information option subscriber\-id
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                            self.yang_name = "option"
                                            self.yang_parent_name = "information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                            ])
                                            self.subscriber_id = None
                                            self._segment_path = lambda: "option"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                        class Verify(Entity):
                            """
                            verify
                            
                            .. attribute:: source
                            
                            	source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vlan
                            
                            	vlan specification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: port_security
                            
                            	port security
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Verify, self).__init__()

                                self.yang_name = "verify"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source', (YLeaf(YType.empty, 'source'), ['Empty'])),
                                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                                    ('dhcp_snooping', (YLeaf(YType.empty, 'dhcp-snooping'), ['Empty'])),
                                    ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                ])
                                self.source = None
                                self.vlan = None
                                self.dhcp_snooping = None
                                self.port_security = None
                                self._segment_path = lambda: "verify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Ip.Verify, ['source', 'vlan', 'dhcp_snooping', 'port_security'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 interface subcommands
                        
                        .. attribute:: traffic_filter
                        
                        	Access control list for packets
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('traffic_filter', (YLeaf(YType.str, 'traffic-filter'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.traffic_filter = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Ipv6, ['traffic_filter', 'in_', 'out'], name, value)


                    class Rewrite(Entity):
                        """
                        Configure ethernet rewrite criteria
                        
                        .. attribute:: ingress
                        
                        	Ingress Rewrite
                        	**type**\:  :py:class:`Ingress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite, self).__init__()

                            self.yang_name = "rewrite"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ingress", ("ingress", Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress))])
                            self._leafs = OrderedDict()

                            self.ingress = Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"
                            self._segment_path = lambda: "rewrite"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite, [], name, value)


                        class Ingress(Entity):
                            """
                            Ingress Rewrite
                            
                            .. attribute:: tag
                            
                            	Configure Rewrite Tag
                            	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress, self).__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "rewrite"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("tag", ("tag", Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag))])
                                self._leafs = OrderedDict()

                                self.tag = Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag()
                                self.tag.parent = self
                                self._children_name_map["tag"] = "tag"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress, [], name, value)


                            class Tag(Entity):
                                """
                                Configure Rewrite Tag
                                
                                .. attribute:: pop
                                
                                	Pop the tag
                                	**type**\:  :py:class:`Pop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Pop>`
                                
                                .. attribute:: push
                                
                                	Rewrite Operation of push
                                	**type**\:  :py:class:`Push <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Push>`
                                
                                .. attribute:: translate
                                
                                	Translate Tag
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag, self).__init__()

                                    self.yang_name = "tag"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pop", ("pop", Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Pop)), ("push", ("push", Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Push)), ("translate", ("translate", Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate))])
                                    self._leafs = OrderedDict()

                                    self.pop = Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Pop()
                                    self.pop.parent = self
                                    self._children_name_map["pop"] = "pop"

                                    self.push = Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Push()
                                    self.push.parent = self
                                    self._children_name_map["push"] = "push"

                                    self.translate = Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "tag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag, [], name, value)


                                class Pop(Entity):
                                    """
                                    Pop the tag
                                    
                                    .. attribute:: way
                                    
                                    	
                                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Pop.Way>`
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Pop, self).__init__()

                                        self.yang_name = "pop"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Pop.Way')])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Pop.Mode')])),
                                        ])
                                        self.way = None
                                        self.mode = None
                                        self._segment_path = lambda: "pop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Pop, ['way', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")


                                    class Way(Enum):
                                        """
                                        Way (Enum Class)

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class Push(Entity):
                                    """
                                    Rewrite Operation of push
                                    
                                    .. attribute:: dot1q
                                    
                                    	Push dot1q tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    .. attribute:: mode
                                    
                                    	
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Push.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Push, self).__init__()

                                        self.yang_name = "push"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Push.Mode')])),
                                        ])
                                        self.dot1q = None
                                        self.mode = None
                                        self._segment_path = lambda: "push"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Push, ['dot1q', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: symmetric = 0

                                        """

                                        symmetric = Enum.YLeaf(0, "symmetric")



                                class Translate(Entity):
                                    """
                                    Translate Tag
                                    
                                    .. attribute:: t1_to_1
                                    
                                    	Translate 1\-to\-1
                                    	**type**\:  :py:class:`T1To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1>`
                                    
                                    .. attribute:: t1_to_2
                                    
                                    	Translate 1\-to\-2
                                    	**type**\:  :py:class:`T1To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2>`
                                    
                                    .. attribute:: t2_to_1
                                    
                                    	Translate 2\-to\-1
                                    	**type**\:  :py:class:`T2To1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1>`
                                    
                                    .. attribute:: t2_to_2
                                    
                                    	Translate 2\-to\-2
                                    	**type**\:  :py:class:`T2To2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "tag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("t1-to-1", ("t1_to_1", Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1)), ("t1-to-2", ("t1_to_2", Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2)), ("t2-to-1", ("t2_to_1", Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1)), ("t2-to-2", ("t2_to_2", Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2))])
                                        self._leafs = OrderedDict()

                                        self.t1_to_1 = Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1()
                                        self.t1_to_1.parent = self
                                        self._children_name_map["t1_to_1"] = "t1-to-1"

                                        self.t1_to_2 = Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2()
                                        self.t1_to_2.parent = self
                                        self._children_name_map["t1_to_2"] = "t1-to-2"

                                        self.t2_to_1 = Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1()
                                        self.t2_to_1.parent = self
                                        self._children_name_map["t2_to_1"] = "t2-to-1"

                                        self.t2_to_2 = Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2()
                                        self.t2_to_2.parent = self
                                        self._children_name_map["t2_to_2"] = "t2-to-2"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate, [], name, value)


                                    class T1To1(Entity):
                                        """
                                        Translate 1\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, self).__init__()

                                            self.yang_name = "t1-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T1To2(Entity):
                                        """
                                        Translate 1\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, self).__init__()

                                            self.yang_name = "t1-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t1-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T1To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To1(Entity):
                                        """
                                        Translate 2\-to\-1
                                        
                                        .. attribute:: dot1q
                                        
                                        	Ethertype dot1q of the translation
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, self).__init__()

                                            self.yang_name = "t2-to-1"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-1"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To1, ['dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                                    class T2To2(Entity):
                                        """
                                        Translate 2\-to\-2
                                        
                                        .. attribute:: dot1q
                                        
                                        	Translate ethertype of dot1q
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: second_dot1q
                                        
                                        	Second dot1q tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        .. attribute:: mode
                                        
                                        	
                                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode>`
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, self).__init__()

                                            self.yang_name = "t2-to-2"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                                ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2.Mode')])),
                                            ])
                                            self.dot1q = None
                                            self.second_dot1q = None
                                            self.mode = None
                                            self._segment_path = lambda: "t2-to-2"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Rewrite.Ingress.Tag.Translate.T2To2, ['dot1q', 'second_dot1q', 'mode'], name, value)

                                        class Mode(Enum):
                                            """
                                            Mode (Enum Class)

                                            .. data:: symmetric = 0

                                            """

                                            symmetric = Enum.YLeaf(0, "symmetric")



                    class Errdisable(Entity):
                        """
                        Configure error disable
                        
                        .. attribute:: recovery
                        
                        	enable auto recovery
                        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Errdisable.Recovery>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("recovery", ("recovery", Native.Interface.VirtualPortGroup.Service.Instance.Errdisable.Recovery))])
                            self._leafs = OrderedDict()

                            self.recovery = Native.Interface.VirtualPortGroup.Service.Instance.Errdisable.Recovery()
                            self.recovery.parent = self
                            self._children_name_map["recovery"] = "recovery"
                            self._segment_path = lambda: "errdisable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Errdisable, [], name, value)


                        class Recovery(Entity):
                            """
                            enable auto recovery
                            
                            .. attribute:: cause
                            
                            	error disable cause
                            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Errdisable.Recovery.Cause>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Errdisable.Recovery, self).__init__()

                                self.yang_name = "recovery"
                                self.yang_parent_name = "errdisable"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cause", ("cause", Native.Interface.VirtualPortGroup.Service.Instance.Errdisable.Recovery.Cause))])
                                self._leafs = OrderedDict()

                                self.cause = Native.Interface.VirtualPortGroup.Service.Instance.Errdisable.Recovery.Cause()
                                self.cause.parent = self
                                self._children_name_map["cause"] = "cause"
                                self._segment_path = lambda: "recovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Errdisable.Recovery, [], name, value)


                            class Cause(Entity):
                                """
                                error disable cause
                                
                                .. attribute:: mac_security
                                
                                	mac\-security violation
                                	**type**\: int
                                
                                	**range:** 30..86400
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Service.Instance.Errdisable.Recovery.Cause, self).__init__()

                                    self.yang_name = "cause"
                                    self.yang_parent_name = "recovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_security', (YLeaf(YType.uint32, 'mac-security'), ['int'])),
                                    ])
                                    self.mac_security = None
                                    self._segment_path = lambda: "cause"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Errdisable.Recovery.Cause, ['mac_security'], name, value)


                    class EthernetContainer(Entity):
                        """
                        
                        
                        .. attribute:: ethernet
                        
                        	ethernet
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer, self).__init__()

                            self.yang_name = "ethernet-container"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet))])
                            self._leafs = OrderedDict()

                            self.ethernet = Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet()
                            self.ethernet.parent = self
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "ethernet-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer, [], name, value)


                        class Ethernet(Entity):
                            """
                            ethernet
                            
                            .. attribute:: lmi
                            
                            	Configure ether lmi parameters
                            	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi>`
                            
                            .. attribute:: loopback
                            
                            	Ethernet Dataplane Loopback
                            	**type**\:  :py:class:`Loopback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Loopback>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "ethernet-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lmi", ("lmi", Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi)), ("loopback", ("loopback", Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Loopback))])
                                self._leafs = OrderedDict()

                                self.lmi = Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi()
                                self.lmi.parent = self
                                self._children_name_map["lmi"] = "lmi"

                                self.loopback = Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Loopback()
                                self.loopback.parent = self
                                self._children_name_map["loopback"] = "loopback"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet, [], name, value)


                            class Lmi(Entity):
                                """
                                Configure ether lmi parameters
                                
                                .. attribute:: ce_vlan
                                
                                	Configure ether lmi customer vlans
                                	**type**\:  :py:class:`CeVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi, self).__init__()

                                    self.yang_name = "lmi"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ce-vlan", ("ce_vlan", Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan))])
                                    self._leafs = OrderedDict()

                                    self.ce_vlan = Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan()
                                    self.ce_vlan.parent = self
                                    self._children_name_map["ce_vlan"] = "ce-vlan"
                                    self._segment_path = lambda: "lmi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi, [], name, value)


                                class CeVlan(Entity):
                                    """
                                    Configure ether lmi customer vlans
                                    
                                    .. attribute:: map
                                    
                                    	Configure ether lmi ce\-vlan/evc map
                                    	**type**\:  :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, self).__init__()

                                        self.yang_name = "ce-vlan"
                                        self.yang_parent_name = "lmi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map", ("map", Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map))])
                                        self._leafs = OrderedDict()

                                        self.map = Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map()
                                        self.map.parent = self
                                        self._children_name_map["map"] = "map"
                                        self._segment_path = lambda: "ce-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan, [], name, value)


                                    class Map(Entity):
                                        """
                                        Configure ether lmi ce\-vlan/evc map
                                        
                                        .. attribute:: any
                                        
                                        	For all VLANS [1\-4094,untagged]
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default
                                        
                                        	Default EFP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: untagged
                                        
                                        	Untagged frames
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (\\d+(.\*\-.\*\\d+)?)(,.\*\\d+(.\*\-.\*\\d+)?)\*(,.\*untagged)?
                                        
                                        

                                        """

                                        _prefix = 'ios-eth'
                                        _revision = '2018-04-09'

                                        def __init__(self):
                                            super(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, self).__init__()

                                            self.yang_name = "map"
                                            self.yang_parent_name = "ce-vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('untagged', (YLeaf(YType.empty, 'untagged'), ['Empty'])),
                                                ('vlan_range', (YLeaf(YType.str, 'vlan-range'), ['str'])),
                                            ])
                                            self.any = None
                                            self.default = None
                                            self.untagged = None
                                            self.vlan_range = None
                                            self._segment_path = lambda: "map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Lmi.CeVlan.Map, ['any', 'default', 'untagged', 'vlan_range'], name, value)


                            class Loopback(Entity):
                                """
                                Ethernet Dataplane Loopback
                                
                                .. attribute:: permit
                                
                                	Allow data plane loopback to be activated
                                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Loopback, self).__init__()

                                    self.yang_name = "loopback"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit))])
                                    self._leafs = OrderedDict()

                                    self.permit = Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit()
                                    self.permit.parent = self
                                    self._children_name_map["permit"] = "permit"
                                    self._segment_path = lambda: "loopback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Loopback, [], name, value)


                                class Permit(Entity):
                                    """
                                    Allow data plane loopback to be activated
                                    
                                    .. attribute:: external
                                    
                                    	Allow to loopback the traffic from the wire
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: internal
                                    
                                    	Allow to loopback the traffic from the relay
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eth'
                                    _revision = '2018-04-09'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, self).__init__()

                                        self.yang_name = "permit"
                                        self.yang_parent_name = "loopback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.internal = None
                                        self._segment_path = lambda: "permit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.EthernetContainer.Ethernet.Loopback.Permit, ['external', 'internal'], name, value)


                    class Snmp(Entity):
                        """
                        Modify SNMP service instance parameters
                        
                        .. attribute:: trap
                        
                        	Allow a specific SNMP trap
                        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Snmp.Trap>`
                        
                        .. attribute:: ifindex
                        
                        	Persist ifindex for the service instance
                        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Snmp.Ifindex>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("trap", ("trap", Native.Interface.VirtualPortGroup.Service.Instance.Snmp.Trap)), ("ifindex", ("ifindex", Native.Interface.VirtualPortGroup.Service.Instance.Snmp.Ifindex))])
                            self._leafs = OrderedDict()

                            self.trap = Native.Interface.VirtualPortGroup.Service.Instance.Snmp.Trap()
                            self.trap.parent = self
                            self._children_name_map["trap"] = "trap"

                            self.ifindex = Native.Interface.VirtualPortGroup.Service.Instance.Snmp.Ifindex()
                            self.ifindex.parent = self
                            self._children_name_map["ifindex"] = "ifindex"
                            self._segment_path = lambda: "snmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Snmp, [], name, value)


                        class Trap(Entity):
                            """
                            Allow a specific SNMP trap
                            
                            .. attribute:: link_status
                            
                            	Allow SNMP LINKUP and LINKDOWN traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Snmp.Trap, self).__init__()

                                self.yang_name = "trap"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                                ])
                                self.link_status = None
                                self._segment_path = lambda: "trap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Snmp.Trap, ['link_status'], name, value)


                        class Ifindex(Entity):
                            """
                            Persist ifindex for the service instance
                            
                            .. attribute:: persist
                            
                            	Enable/Disable ifIndex persistence
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Snmp.Ifindex, self).__init__()

                                self.yang_name = "ifindex"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                                ])
                                self.persist = None
                                self._segment_path = lambda: "ifindex"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Snmp.Ifindex, ['persist'], name, value)


                    class BridgeDomain(Entity):
                        """
                        Bridge\-domain
                        
                        .. attribute:: bridge_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.BridgeDomain.SplitHorizon>`
                        
                        .. attribute:: from_encapsulation
                        
                        	from\-encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.BridgeDomain, self).__init__()

                            self.yang_name = "bridge-domain"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.Interface.VirtualPortGroup.Service.Instance.BridgeDomain.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('bridge_id', (YLeaf(YType.uint16, 'bridge-id'), ['int'])),
                                ('from_encapsulation', (YLeaf(YType.empty, 'from-encapsulation'), ['Empty'])),
                            ])
                            self.bridge_id = None
                            self.from_encapsulation = None

                            self.split_horizon = Native.Interface.VirtualPortGroup.Service.Instance.BridgeDomain.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "bridge-domain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.BridgeDomain, ['bridge_id', 'from_encapsulation'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..13
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.BridgeDomain.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "bridge-domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.BridgeDomain.SplitHorizon, ['group'], name, value)


                    class Mac(Entity):
                        """
                        Commands for MAC Address\-based features
                        
                        .. attribute:: security
                        
                        	MAC Security commands
                        	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Mac.Security>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Mac.AccessGroup>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.Mac, self).__init__()

                            self.yang_name = "mac"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security", ("security", Native.Interface.VirtualPortGroup.Service.Instance.Mac.Security)), ("access-group", ("access_group", Native.Interface.VirtualPortGroup.Service.Instance.Mac.AccessGroup))])
                            self._leafs = OrderedDict()

                            self.security = None
                            self._children_name_map["security"] = "security"

                            self.access_group = YList(self)
                            self._segment_path = lambda: "mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Mac, [], name, value)


                        class Security(Entity):
                            """
                            MAC Security commands
                            
                            .. attribute:: maximum
                            
                            	Configure an upper bound
                            	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Mac.Security.Maximum>`
                            
                            .. attribute:: violation
                            
                            	Configure the response when a MAC security policy is violated
                            	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Mac.Security.Violation>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Mac.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum", ("maximum", Native.Interface.VirtualPortGroup.Service.Instance.Mac.Security.Maximum))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('violation', (YLeaf(YType.enumeration, 'violation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.Mac.Security.Violation')])),
                                ])
                                self.violation = None

                                self.maximum = Native.Interface.VirtualPortGroup.Service.Instance.Mac.Security.Maximum()
                                self.maximum.parent = self
                                self._children_name_map["maximum"] = "maximum"
                                self._segment_path = lambda: "security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Mac.Security, ['violation'], name, value)

                            class Violation(Enum):
                                """
                                Violation (Enum Class)

                                Configure the response when a MAC security policy is violated

                                .. data:: protect = 0

                                .. data:: restrict = 1

                                """

                                protect = Enum.YLeaf(0, "protect")

                                restrict = Enum.YLeaf(1, "restrict")



                            class Maximum(Entity):
                                """
                                Configure an upper bound
                                
                                .. attribute:: addresses
                                
                                	Maximum addresses that can be learnt on this service instance
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Service.Instance.Mac.Security.Maximum, self).__init__()

                                    self.yang_name = "maximum"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('addresses', (YLeaf(YType.uint16, 'addresses'), ['int'])),
                                    ])
                                    self.addresses = None
                                    self._segment_path = lambda: "maximum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Mac.Security.Maximum, ['addresses'], name, value)


                        class AccessGroup(Entity):
                            """
                            Specify access control for packets
                            
                            .. attribute:: acl_name  (key)
                            
                            	ACL name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Apply to ingress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Apply to Egress
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Mac.AccessGroup, self).__init__()

                                self.yang_name = "access-group"
                                self.yang_parent_name = "mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['acl_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "access-group" + "[acl-name='" + str(self.acl_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Mac.AccessGroup, ['acl_name', 'in_', 'out'], name, value)


                    class ServicePolicy(Entity):
                        """
                        Attach a policy\-map to an EFP
                        
                        .. attribute:: input
                        
                        	service policy input
                        	**type**\: list of  		 :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy.Input>`
                        
                        .. attribute:: output
                        
                        	service policy output
                        	**type**\: list of  		 :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy.Output>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy.Input)), ("output", ("output", Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy.Output))])
                            self._leafs = OrderedDict()

                            self.input = YList(self)
                            self.output = YList(self)
                            self._segment_path = lambda: "service-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy, [], name, value)


                        class Input(Entity):
                            """
                            service policy input
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            service policy output
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.ServicePolicy.Output, ['name'], name, value)


                    class Cfm(Entity):
                        """
                        Ethernet CFM EFP subcommands
                        
                        .. attribute:: encapsulation
                        
                        	Configure CFM ethernet frame encapsulation
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation>`
                        
                        .. attribute:: mep
                        
                        	Maintenance End Point
                        	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Mep>`
                        
                        .. attribute:: mip
                        
                        	Maintenance Intermediate Point
                        	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Mip>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.Cfm, self).__init__()

                            self.yang_name = "cfm"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation)), ("mep", ("mep", Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Mep)), ("mip", ("mip", Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Mip))])
                            self._leafs = OrderedDict()

                            self.encapsulation = Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mep = Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"

                            self.mip = Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Mip()
                            self.mip.parent = self
                            self._children_name_map["mip"] = "mip"
                            self._segment_path = lambda: "cfm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Cfm, [], name, value)


                        class Encapsulation(Entity):
                            """
                            Configure CFM ethernet frame encapsulation
                            
                            .. attribute:: dot1ad
                            
                            	802.1ad \- Provider Bridges
                            	**type**\:  :py:class:`Dot1ad <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation.Dot1ad>`
                            
                            .. attribute:: dot1q
                            
                            	IEEE 802.1Q Virtual LAN or S\-VLAN
                            	**type**\:  :py:class:`Dot1q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation.Dot1q>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dot1ad", ("dot1ad", Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation.Dot1ad)), ("dot1q", ("dot1q", Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation.Dot1q))])
                                self._leafs = OrderedDict()

                                self.dot1ad = Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation.Dot1ad()
                                self.dot1ad.parent = self
                                self._children_name_map["dot1ad"] = "dot1ad"

                                self.dot1q = Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation.Dot1q()
                                self.dot1q.parent = self
                                self._children_name_map["dot1q"] = "dot1q"
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation, [], name, value)


                            class Dot1ad(Entity):
                                """
                                802.1ad \- Provider Bridges
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: dot1q
                                
                                	Second tag (dot1q)
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation.Dot1ad, self).__init__()

                                    self.yang_name = "dot1ad"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('dot1q', (YLeaf(YType.uint16, 'dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.dot1q = None
                                    self._segment_path = lambda: "dot1ad"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation.Dot1ad, ['vlan_id', 'cos', 'dot1q'], name, value)


                            class Dot1q(Entity):
                                """
                                IEEE 802.1Q Virtual LAN or S\-VLAN
                                
                                .. attribute:: vlan_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                .. attribute:: cos
                                
                                	CoS value to use for CFM packets
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: second_dot1q
                                
                                	inner 802.1Q Virtual LAN or C\-VLAN
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation.Dot1q, self).__init__()

                                    self.yang_name = "dot1q"
                                    self.yang_parent_name = "encapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                                        ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
                                        ('second_dot1q', (YLeaf(YType.uint16, 'second-dot1q'), ['int'])),
                                    ])
                                    self.vlan_id = None
                                    self.cos = None
                                    self.second_dot1q = None
                                    self._segment_path = lambda: "dot1q"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Encapsulation.Dot1q, ['vlan_id', 'cos', 'second_dot1q'], name, value)


                        class Mep(Entity):
                            """
                            Maintenance End Point
                            
                            .. attribute:: domain
                            
                            	Configure a domain for this mep
                            	**type**\: str
                            
                            .. attribute:: mpid
                            
                            	Maintenance End Point Identifier
                            	**type**\: int
                            
                            	**range:** 1..8191
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ('mpid', (YLeaf(YType.uint16, 'mpid'), ['int'])),
                                ])
                                self.domain = None
                                self.mpid = None
                                self._segment_path = lambda: "mep"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Mep, ['domain', 'mpid'], name, value)


                        class Mip(Entity):
                            """
                            Maintenance Intermediate Point
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Mip, self).__init__()

                                self.yang_name = "mip"
                                self.yang_parent_name = "cfm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "mip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.Cfm.Mip, ['level'], name, value)


                    class L2protocol(Entity):
                        """
                        Configure l2 control protocol processing
                        
                        .. attribute:: discard
                        
                        	discard L2 control protocol packets as data
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Discard>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: peer
                        
                        	peer L2 control protocol packets as data
                        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Peer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: forward
                        
                        	forward L2 control protocol packets as data
                        	**type**\:  :py:class:`Forward <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Forward>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: tunnel
                        
                        	tunnel L2 control protocol packets as data
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Tunnel>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Service.Instance.L2protocol, self).__init__()

                            self.yang_name = "l2protocol"
                            self.yang_parent_name = "instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Discard)), ("peer", ("peer", Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Peer)), ("forward", ("forward", Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Forward)), ("tunnel", ("tunnel", Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Tunnel))])
                            self._leafs = OrderedDict()

                            self.discard = None
                            self._children_name_map["discard"] = "discard"

                            self.peer = None
                            self._children_name_map["peer"] = "peer"

                            self.forward = None
                            self._children_name_map["forward"] = "forward"

                            self.tunnel = None
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "l2protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.L2protocol, [], name, value)


                        class Discard(Entity):
                            """
                            discard L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Discard.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.L2protocol.Discard.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Discard, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Peer(Entity):
                            """
                            peer L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Peer.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Peer, self).__init__()

                                self.yang_name = "peer"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.L2protocol.Peer.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Peer, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Forward(Entity):
                            """
                            forward L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Forward.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Forward, self).__init__()

                                self.yang_name = "forward"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.L2protocol.Forward.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "forward"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Forward, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



                        class Tunnel(Entity):
                            """
                            tunnel L2 control protocol packets as data
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\: list of   :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Tunnel.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "l2protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeafList(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Service.Instance.L2protocol.Tunnel.Protocol')])),
                                ])
                                self.protocol = []
                                self._segment_path = lambda: "tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Service.Instance.L2protocol.Tunnel, ['protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: R4 = 0

                                .. data:: R5 = 1

                                .. data:: R6 = 2

                                .. data:: R8 = 3

                                .. data:: R9 = 4

                                .. data:: RA = 5

                                .. data:: RB = 6

                                .. data:: RC = 7

                                .. data:: RD = 8

                                .. data:: RF = 9

                                .. data:: cdp = 10

                                .. data:: dtp = 11

                                .. data:: elmi = 12

                                .. data:: esmc = 13

                                .. data:: lacp = 14

                                .. data:: lldp = 15

                                .. data:: loam = 16

                                .. data:: pagp = 17

                                .. data:: ptppd = 18

                                .. data:: stp = 19

                                .. data:: udld = 20

                                .. data:: vtp = 21

                                """

                                R4 = Enum.YLeaf(0, "R4")

                                R5 = Enum.YLeaf(1, "R5")

                                R6 = Enum.YLeaf(2, "R6")

                                R8 = Enum.YLeaf(3, "R8")

                                R9 = Enum.YLeaf(4, "R9")

                                RA = Enum.YLeaf(5, "RA")

                                RB = Enum.YLeaf(6, "RB")

                                RC = Enum.YLeaf(7, "RC")

                                RD = Enum.YLeaf(8, "RD")

                                RF = Enum.YLeaf(9, "RF")

                                cdp = Enum.YLeaf(10, "cdp")

                                dtp = Enum.YLeaf(11, "dtp")

                                elmi = Enum.YLeaf(12, "elmi")

                                esmc = Enum.YLeaf(13, "esmc")

                                lacp = Enum.YLeaf(14, "lacp")

                                lldp = Enum.YLeaf(15, "lldp")

                                loam = Enum.YLeaf(16, "loam")

                                pagp = Enum.YLeaf(17, "pagp")

                                ptppd = Enum.YLeaf(18, "ptppd")

                                stp = Enum.YLeaf(19, "stp")

                                udld = Enum.YLeaf(20, "udld")

                                vtp = Enum.YLeaf(21, "vtp")



            class Lacp(Entity):
                """
                LACP interface subcommands
                
                .. attribute:: port_priority
                
                	LACP priority on this interface 
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rate
                
                	Rate at which the LACP packets are requested to be ingressed to this interface
                	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Lacp.Rate>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Lacp, self).__init__()

                    self.yang_name = "lacp"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_priority', (YLeaf(YType.uint32, 'port-priority'), ['int'])),
                        ('rate', (YLeaf(YType.enumeration, 'rate'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.Lacp.Rate')])),
                    ])
                    self.port_priority = None
                    self.rate = None
                    self._segment_path = lambda: "Cisco-IOS-XE-ethernet:lacp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Lacp, ['port_priority', 'rate'], name, value)

                class Rate(Enum):
                    """
                    Rate (Enum Class)

                    Rate at which the LACP packets are requested to be ingressed to this interface

                    .. data:: fast = 0

                    .. data:: normal = 1

                    """

                    fast = Enum.YLeaf(0, "fast")

                    normal = Enum.YLeaf(1, "normal")



            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.VirtualPortGroup.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.VirtualPortGroup.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.VirtualPortGroup.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.VirtualPortGroup.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.VirtualPortGroup.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.VirtualPortGroup.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.VirtualPortGroup.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class Snmp(Entity):
                """
                Modify SNMP interface parameters
                
                .. attribute:: ifindex
                
                	Persist ifindex for the interface
                	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Snmp.Ifindex>`
                
                .. attribute:: trap
                
                	Allow a specific SNMP trap
                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Snmp.Trap>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Interface.VirtualPortGroup.Snmp.Ifindex)), ("trap", ("trap", Native.Interface.VirtualPortGroup.Snmp.Trap))])
                    self._leafs = OrderedDict()

                    self.ifindex = Native.Interface.VirtualPortGroup.Snmp.Ifindex()
                    self.ifindex.parent = self
                    self._children_name_map["ifindex"] = "ifindex"

                    self.trap = Native.Interface.VirtualPortGroup.Snmp.Trap()
                    self.trap.parent = self
                    self._children_name_map["trap"] = "trap"
                    self._segment_path = lambda: "Cisco-IOS-XE-snmp:snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Snmp, [], name, value)


                class Ifindex(Entity):
                    """
                    Persist ifindex for the interface
                    
                    .. attribute:: persist
                    
                    	Enable/Disable ifIndex persistence 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: clear
                    
                    	Clear Enable/Disable ifIndex persistence
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Snmp.Ifindex, self).__init__()

                        self.yang_name = "ifindex"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                            ('clear', (YLeaf(YType.boolean, 'clear'), ['bool'])),
                        ])
                        self.persist = None
                        self.clear = None
                        self._segment_path = lambda: "ifindex"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Snmp.Ifindex, [u'persist', u'clear'], name, value)


                class Trap(Entity):
                    """
                    Allow a specific SNMP trap
                    
                    .. attribute:: link_status
                    
                    	Allow SNMP LINKUP and LINKDOWN traps
                    	**type**\: bool
                    
                    .. attribute:: link_status_capas
                    
                    	
                    	**type**\:  :py:class:`LinkStatusCapas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas>`
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Snmp.Trap, self).__init__()

                        self.yang_name = "trap"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-status-capas", ("link_status_capas", Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas))])
                        self._leafs = OrderedDict([
                            ('link_status', (YLeaf(YType.boolean, 'link-status'), ['bool'])),
                        ])
                        self.link_status = None

                        self.link_status_capas = Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas()
                        self.link_status_capas.parent = self
                        self._children_name_map["link_status_capas"] = "link-status-capas"
                        self._segment_path = lambda: "trap"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Snmp.Trap, [u'link_status'], name, value)


                    class LinkStatusCapas(Entity):
                        """
                        
                        
                        .. attribute:: link_status
                        
                        	Allow SNMP LINKUP and LINKDOWN traps
                        	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas.LinkStatus>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas, self).__init__()

                            self.yang_name = "link-status-capas"
                            self.yang_parent_name = "trap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("link-status", ("link_status", Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas.LinkStatus))])
                            self._leafs = OrderedDict()

                            self.link_status = Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas.LinkStatus()
                            self.link_status.parent = self
                            self._children_name_map["link_status"] = "link-status"
                            self._segment_path = lambda: "link-status-capas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas, [], name, value)


                        class LinkStatus(Entity):
                            """
                            Allow SNMP LINKUP and LINKDOWN traps
                            
                            .. attribute:: permit
                            
                            	Permit the following capability
                            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas.LinkStatus, self).__init__()

                                self.yang_name = "link-status"
                                self.yang_parent_name = "link-status-capas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permit", ("permit", Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit))])
                                self._leafs = OrderedDict()

                                self.permit = Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit()
                                self.permit.parent = self
                                self._children_name_map["permit"] = "permit"
                                self._segment_path = lambda: "link-status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas.LinkStatus, [], name, value)


                            class Permit(Entity):
                                """
                                Permit the following capability
                                
                                .. attribute:: duplicates
                                
                                	Permit duplicate SNMP LINKUP and LINKDOWN traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, self).__init__()

                                    self.yang_name = "permit"
                                    self.yang_parent_name = "link-status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duplicates', (YLeaf(YType.empty, 'duplicates'), ['Empty'])),
                                    ])
                                    self.duplicates = None
                                    self._segment_path = lambda: "permit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Snmp.Trap.LinkStatusCapas.LinkStatus.Permit, [u'duplicates'], name, value)


            class Mab(Entity):
                """
                
                
                .. attribute:: eap
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Mab, self).__init__()

                    self.yang_name = "mab"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('eap', (YLeaf(YType.empty, 'eap'), ['Empty'])),
                    ])
                    self.eap = None
                    self._segment_path = lambda: "Cisco-IOS-XE-sanet:mab"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Mab, ['eap'], name, value)


            class Cts(Entity):
                """
                Configure Cisco Trusted Security
                
                .. attribute:: manual
                
                	Supply local configuration for CTS parameters
                	**type**\:  :py:class:`Manual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts.Manual>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Interface.VirtualPortGroup.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "VirtualPortGroup"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual", ("manual", Native.Interface.VirtualPortGroup.Cts.Manual))])
                    self._leafs = OrderedDict()

                    self.manual = None
                    self._children_name_map["manual"] = "manual"
                    self._segment_path = lambda: "Cisco-IOS-XE-cts:cts"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.VirtualPortGroup.Cts, [], name, value)


                class Manual(Entity):
                    """
                    Supply local configuration for CTS parameters
                    
                    .. attribute:: policy
                    
                    	CTS policy for manual mode
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts.Manual.Policy>`
                    
                    .. attribute:: sap
                    
                    	CTS SAP configuration for manual mode
                    	**type**\:  :py:class:`Sap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts.Manual.Sap>`
                    
                    .. attribute:: propagate
                    
                    	CTS SGT Propagation configuration for manual mode
                    	**type**\:  :py:class:`Propagate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts.Manual.Propagate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.VirtualPortGroup.Cts.Manual, self).__init__()

                        self.yang_name = "manual"
                        self.yang_parent_name = "cts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Interface.VirtualPortGroup.Cts.Manual.Policy)), ("sap", ("sap", Native.Interface.VirtualPortGroup.Cts.Manual.Sap)), ("propagate", ("propagate", Native.Interface.VirtualPortGroup.Cts.Manual.Propagate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.policy = Native.Interface.VirtualPortGroup.Cts.Manual.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"

                        self.sap = Native.Interface.VirtualPortGroup.Cts.Manual.Sap()
                        self.sap.parent = self
                        self._children_name_map["sap"] = "sap"

                        self.propagate = Native.Interface.VirtualPortGroup.Cts.Manual.Propagate()
                        self.propagate.parent = self
                        self._children_name_map["propagate"] = "propagate"
                        self._segment_path = lambda: "manual"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.VirtualPortGroup.Cts.Manual, [], name, value)


                    class Policy(Entity):
                        """
                        CTS policy for manual mode
                        
                        .. attribute:: static
                        
                        	Configure policy to be applied on the link
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts.Manual.Policy.Static>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Cts.Manual.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("static", ("static", Native.Interface.VirtualPortGroup.Cts.Manual.Policy.Static))])
                            self._leafs = OrderedDict()

                            self.static = Native.Interface.VirtualPortGroup.Cts.Manual.Policy.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Cts.Manual.Policy, [], name, value)


                        class Static(Entity):
                            """
                            Configure policy to be applied on the link
                            
                            .. attribute:: sgt
                            
                            	Source Security Group Tag to apply to untagged or non\-trusted  incoming traffic
                            	**type**\: int
                            
                            	**range:** 2..65519
                            
                            .. attribute:: trusted
                            
                            	Trust the Source Group Tags (SGT) that the peer uses for  sending
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Cts.Manual.Policy.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.sgt = None
                                self.trusted = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Cts.Manual.Policy.Static, ['sgt', 'trusted'], name, value)


                    class Sap(Entity):
                        """
                        CTS SAP configuration for manual mode
                        
                        .. attribute:: pmk
                        
                        	Pre\-Master Key (PMK) to use for CTS SAP
                        	**type**\: list of  		 :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Cts.Manual.Sap, self).__init__()

                            self.yang_name = "sap"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pmk", ("pmk", Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk))])
                            self._leafs = OrderedDict()

                            self.pmk = YList(self)
                            self._segment_path = lambda: "sap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Cts.Manual.Sap, [], name, value)


                        class Pmk(Entity):
                            """
                            Pre\-Master Key (PMK) to use for CTS SAP
                            
                            .. attribute:: word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mode_list
                            
                            	List of advertised modes (prioritized from highest to lowest)
                            	**type**\:  :py:class:`ModeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk, self).__init__()

                                self.yang_name = "pmk"
                                self.yang_parent_name = "sap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['word']
                                self._child_classes = OrderedDict([("mode-list", ("mode_list", Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList))])
                                self._leafs = OrderedDict([
                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ])
                                self.word = None

                                self.mode_list = Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList()
                                self.mode_list.parent = self
                                self._children_name_map["mode_list"] = "mode-list"
                                self._segment_path = lambda: "pmk" + "[word='" + str(self.word) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk, ['word'], name, value)


                            class ModeList(Entity):
                                """
                                List of advertised modes (prioritized from highest to lowest)
                                
                                .. attribute:: gcm_encrypt
                                
                                	GCM authentication, GCM encryption
                                	**type**\:  :py:class:`GcmEncrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_encap
                                
                                	No encapsulation
                                	**type**\:  :py:class:`NoEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.NoEncap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList, self).__init__()

                                    self.yang_name = "mode-list"
                                    self.yang_parent_name = "pmk"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gcm-encrypt", ("gcm_encrypt", Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt)), ("no-encap", ("no_encap", Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.NoEncap))])
                                    self._leafs = OrderedDict()

                                    self.gcm_encrypt = None
                                    self._children_name_map["gcm_encrypt"] = "gcm-encrypt"

                                    self.no_encap = None
                                    self._children_name_map["no_encap"] = "no-encap"
                                    self._segment_path = lambda: "mode-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList, [], name, value)


                                class GcmEncrypt(Entity):
                                    """
                                    GCM authentication, GCM encryption
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, self).__init__()

                                        self.yang_name = "gcm-encrypt"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "gcm-encrypt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: null
                                        
                                        	Encapsulation present, no authentication,  no encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "gcm-encrypt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                            ])
                                            self.null = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.GcmEncrypt.Gmac, ['null'], name, value)


                                class NoEncap(Entity):
                                    """
                                    No encapsulation
                                    
                                    .. attribute:: gmac
                                    
                                    	GCM authentication, no encryption
                                    	**type**\:  :py:class:`Gmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.NoEncap, self).__init__()

                                        self.yang_name = "no-encap"
                                        self.yang_parent_name = "mode-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("gmac", ("gmac", Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.gmac = None
                                        self._children_name_map["gmac"] = "gmac"
                                        self._segment_path = lambda: "no-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.NoEncap, [], name, value)


                                    class Gmac(Entity):
                                        """
                                        GCM authentication, no encryption
                                        
                                        .. attribute:: gcm_encrypt
                                        
                                        	GCM authentication, GCM encryption
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, self).__init__()

                                            self.yang_name = "gmac"
                                            self.yang_parent_name = "no-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('gcm_encrypt', (YLeaf(YType.empty, 'gcm-encrypt'), ['Empty'])),
                                            ])
                                            self.gcm_encrypt = None
                                            self._segment_path = lambda: "gmac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.VirtualPortGroup.Cts.Manual.Sap.Pmk.ModeList.NoEncap.Gmac, ['gcm_encrypt'], name, value)


                    class Propagate(Entity):
                        """
                        CTS SGT Propagation configuration for manual mode
                        
                        .. attribute:: sgt
                        
                        	CTS SGT Propagation configuration
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.VirtualPortGroup.Cts.Manual.Propagate, self).__init__()

                            self.yang_name = "propagate"
                            self.yang_parent_name = "manual"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.boolean, 'sgt'), ['bool'])),
                            ])
                            self.sgt = None
                            self._segment_path = lambda: "propagate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.VirtualPortGroup.Cts.Manual.Propagate, ['sgt'], name, value)


        class Vasileft(Entity):
            """
            vasileft
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..2000
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.PmPath>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.ServicePolicy>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Utd>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Umbrella>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Vasileft, self).__init__()

                self.yang_name = "vasileft"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.Vasileft.SwitchportConf)), ("switchport", ("switchport", Native.Interface.Vasileft.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.Vasileft.StackwiseVirtual)), ("arp", ("arp", Native.Interface.Vasileft.Arp)), ("backup", ("backup", Native.Interface.Vasileft.Backup)), ("cemoudp", ("cemoudp", Native.Interface.Vasileft.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.Vasileft.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.Vasileft.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.Vasileft.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.Vasileft.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.Vasileft.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.Vasileft.Flowcontrol)), ("isis", ("isis", Native.Interface.Vasileft.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.Vasileft.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.Vasileft.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.Vasileft.Bandwidth)), ("dampening", ("dampening", Native.Interface.Vasileft.Dampening)), ("domain", ("domain", Native.Interface.Vasileft.Domain)), ("hold-queue", ("hold_queue", Native.Interface.Vasileft.HoldQueue)), ("mpls", ("mpls", Native.Interface.Vasileft.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.Vasileft.IpVrf)), ("vrf", ("vrf", Native.Interface.Vasileft.Vrf)), ("ip", ("ip", Native.Interface.Vasileft.Ip)), ("ipv6", ("ipv6", Native.Interface.Vasileft.Ipv6)), ("logging", ("logging", Native.Interface.Vasileft.Logging)), ("mdix", ("mdix", Native.Interface.Vasileft.Mdix)), ("mop", ("mop", Native.Interface.Vasileft.Mop)), ("interface_qos", ("interface_qos", Native.Interface.Vasileft.InterfaceQos)), ("source", ("source", Native.Interface.Vasileft.Source)), ("standby", ("standby", Native.Interface.Vasileft.Standby)), ("access-session", ("access_session", Native.Interface.Vasileft.AccessSession)), ("storm-control", ("storm_control", Native.Interface.Vasileft.StormControl)), ("trust", ("trust", Native.Interface.Vasileft.Trust)), ("priority-queue", ("priority_queue", Native.Interface.Vasileft.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.Vasileft.RcvQueue)), ("peer", ("peer", Native.Interface.Vasileft.Peer)), ("pm-path", ("pm_path", Native.Interface.Vasileft.PmPath)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.Vasileft.ServicePolicy)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.Vasileft.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.Vasileft.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.Vasileft.Utd)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.Vasileft.Umbrella))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.Vasileft.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.Vasileft.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.Vasileft.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.Vasileft.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.Vasileft.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.Vasileft.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.Vasileft.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.Vasileft.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.Vasileft.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.Vasileft.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.Vasileft.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.Vasileft.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.Vasileft.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.Vasileft.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.Vasileft.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.Vasileft.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.Vasileft.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.Vasileft.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.Vasileft.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.Vasileft.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.Vasileft.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.Vasileft.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.Vasileft.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.Vasileft.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.Vasileft.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.Vasileft.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.Vasileft.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.Vasileft.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.Vasileft.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.Vasileft.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.Vasileft.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.Vasileft.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.Vasileft.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.Vasileft.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.Vasileft.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.service_policy = Native.Interface.Vasileft.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.et_analytics = Native.Interface.Vasileft.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.Vasileft.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.Vasileft.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.umbrella = Native.Interface.Vasileft.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "vasileft" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Vasileft, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vasileft.Backup.Delay)), ("interface", ("interface", Native.Interface.Vasileft.Backup.Interface_)), ("load", ("load", Native.Interface.Vasileft.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Vasileft.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Vasileft.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Vasileft.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Vasileft.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Vasileft.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Vasileft.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Vasileft.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Vasileft.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Vasileft.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Vasileft.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Vasileft.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Vasileft.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Vasileft.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Vasileft.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Vasileft.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Vasileft.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Vasileft.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Vasileft.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Vasileft.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Vasileft.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Vasileft.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Vasileft.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.Vasileft.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Vasileft.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Vasileft.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Vasileft.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Vasileft.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Vasileft.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Vasileft.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Vasileft.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Vasileft.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Vasileft.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Vasileft.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Vasileft.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Vasileft.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Vasileft.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Verify>`
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Vasileft.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.Vasileft.Ip.Arp)), ("vrf", ("vrf", Native.Interface.Vasileft.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.Vasileft.Ip.NoAddress)), ("address", ("address", Native.Interface.Vasileft.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Vasileft.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Vasileft.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.Vasileft.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.Vasileft.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Vasileft.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.Vasileft.Ip.Pim)), ("policy", ("policy", Native.Interface.Vasileft.Ip.Policy)), ("rip", ("rip", Native.Interface.Vasileft.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Vasileft.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Vasileft.Ip.RouteCache)), ("router", ("router", Native.Interface.Vasileft.Ip.Router)), ("tcp", ("tcp", Native.Interface.Vasileft.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Vasileft.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Vasileft.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Vasileft.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.Vasileft.Ip.Verify)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.Vasileft.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.Vasileft.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Vasileft.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Vasileft.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Vasileft.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Vasileft.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Vasileft.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Vasileft.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Vasileft.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Vasileft.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Vasileft.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Vasileft.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Vasileft.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Vasileft.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Vasileft.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Vasileft.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Vasileft.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Vasileft.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Vasileft.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.wccp = Native.Interface.Vasileft.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Vasileft.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.Vasileft.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Vasileft.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Vasileft.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Vasileft.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Vasileft.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Vasileft.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Vasileft.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Vasileft.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Vasileft.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Vasileft.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Vasileft.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Vasileft.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Vasileft.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Vasileft.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Vasileft.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Vasileft.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Vasileft.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Vasileft.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.Vasileft.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Vasileft.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Vasileft.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Vasileft.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Vasileft.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Vasileft.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Vasileft.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Vasileft.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Vasileft.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vasileft.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Vasileft.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Vasileft.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Vasileft.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Vasileft.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.Vasileft.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.Vasileft.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.Vasileft.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.Vasileft.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.Vasileft.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.Vasileft.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.Vasileft.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.Vasileft.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.Vasileft.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.Vasileft.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.Vasileft.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.Vasileft.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.Vasileft.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.Vasileft.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.Vasileft.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Vasileft.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Vasileft.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Vasileft.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Vasileft.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Vasileft.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.Vasileft.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Vasileft.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Vasileft.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Vasileft.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Vasileft.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Vasileft.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Vasileft.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Vasileft.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.Vasileft.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.Vasileft.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.Vasileft.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.Vasileft.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.Vasileft.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.Vasileft.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Vasileft.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.Vasileft.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Vasileft.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.Vasileft.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.Vasileft.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.Vasileft.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.Vasileft.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.Vasileft.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.Vasileft.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Vasileft.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.Vasileft.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Vasileft.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.Vasileft.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Vasileft.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Vasileft.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Vasileft.Ipv6.Dhcp)), ("address", ("address", Native.Interface.Vasileft.Ipv6.Address)), ("nd", ("nd", Native.Interface.Vasileft.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.Vasileft.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Vasileft.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Vasileft.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Vasileft.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Vasileft.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Vasileft.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.Vasileft.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.Vasileft.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.Vasileft.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.Vasileft.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.Vasileft.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.Vasileft.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Vasileft.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Vasileft.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Vasileft.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Vasileft.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.Vasileft.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.Vasileft.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.Vasileft.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.Vasileft.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.Vasileft.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.Vasileft.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.Vasileft.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Vasileft.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Vasileft.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Vasileft.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Vasileft.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Vasileft.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Vasileft.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Vasileft.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Vasileft.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Vasileft.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vasileft.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.Vasileft.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Vasileft.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Vasileft.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Vasileft.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Vasileft.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vasileft.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Vasileft.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Vasileft.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Vasileft.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Vasileft.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.Vasileft.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Vasileft.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Vasileft.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Vasileft.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Vasileft.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Vasileft.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Vasileft.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Vasileft.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vasileft.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Vasileft.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Vasileft.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Vasileft.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Vasileft.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Vasileft.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Vasileft.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Vasileft.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Vasileft.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Vasileft.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Vasileft.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Vasileft.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Vasileft.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Vasileft.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Vasileft.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Vasileft.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Vasileft.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Vasileft.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Vasileft.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Vasileft.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Vasileft.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Vasileft.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Vasileft.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Vasileft.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vasileft.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vasileft.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Vasileft.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vasileft.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vasileft.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vasileft.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Vasileft.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Vasileft.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vasileft.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vasileft.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Vasileft.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vasileft.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vasileft.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vasileft.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Vasileft.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Vasileft.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vasileft.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vasileft.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Vasileft.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vasileft.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vasileft.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vasileft.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Vasileft.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Vasileft.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Vasileft.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Vasileft.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Vasileft.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasileft.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Vasileft.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Vasileft.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasileft.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Vasileft.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Vasileft.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasileft.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Vasileft.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Vasileft.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vasileft.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasileft.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasileft.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.PmPath, [u'name', u'interface_id'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vasileft.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.Vasileft.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.Vasileft.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vasileft.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.Vasileft.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.Vasileft.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.Vasileft.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.Vasileft.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasileft.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vasileft.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vasileft.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasileft.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasileft.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vasileft.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.Vasileft.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vasileft.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Utd, ['enable'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.Vasileft.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "vasileft"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasileft.Umbrella, ['out', 'in_'], name, value)


        class Vasiright(Entity):
            """
            vasiright
            
            .. attribute:: name  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..2000
            
            .. attribute:: description
            
            	Interface specific description
            	**type**\: str
            
            	**length:** 0..240
            
            .. attribute:: switchport_conf
            
            	
            	**type**\:  :py:class:`SwitchportConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.SwitchportConf>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Switchport>`
            
            .. attribute:: stackwise_virtual
            
            	Configure stackwise\-virtual link values
            	**type**\:  :py:class:`StackwiseVirtual <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StackwiseVirtual>`
            
            .. attribute:: mac_address
            
            	Manually set interface MAC address
            	**type**\: str
            
            .. attribute:: shutdown
            
            	Shutdown the selected interface
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: arp
            
            	Set arp type (arpa, probe, snap), timeout, log options or  packet priority
            	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Arp>`
            
            .. attribute:: backup
            
            	Modify backup parameters
            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup>`
            
            .. attribute:: cemoudp
            
            	cemoudp
            	**type**\:  :py:class:`Cemoudp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Cemoudp>`
            
            .. attribute:: cws_tunnel
            
            	Configure Cloud Web Security Tunnel
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.CwsTunnel>`
            
            .. attribute:: l2protocol_tunnel
            
            	Tunnel Layer2 protocols
            	**type**\:  :py:class:`L2protocolTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.L2protocolTunnel>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Set encapsulation type for an interface
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Encapsulation>`
            
            .. attribute:: fair_queue_conf
            
            	
            	**type**\:  :py:class:`FairQueueConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.FairQueueConf>`
            
            .. attribute:: fair_queue
            
            	Enable Fair Queuing on an Interface
            	**type**\:  :py:class:`FairQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.FairQueue>`
            
            .. attribute:: flowcontrol
            
            	Configure flow operation
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Flowcontrol>`
            
            .. attribute:: isis
            
            	IS\-IS commands
            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Isis>`
            
            .. attribute:: keepalive
            
            	Enable keepalive
            	**type**\: bool
            
            .. attribute:: keepalive_settings
            
            	
            	**type**\:  :py:class:`KeepaliveSettings <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.KeepaliveSettings>`
            
            .. attribute:: bfd
            
            	BFD interface configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Bfd>`
            
            .. attribute:: bandwidth
            
            	Set bandwidth informational parameter
            	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Bandwidth>`
            
            .. attribute:: dampening
            
            	Enable event dampening
            	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Dampening>`
            
            .. attribute:: if_state
            
            	
            	**type**\:  :py:class:`IfState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.IfState>`
            
            .. attribute:: delay
            
            	Specify interface throughput delay
            	**type**\: int
            
            	**range:** 1..16777215
            
            .. attribute:: domain
            
            	Specify a domain
            	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Domain>`
            
            .. attribute:: hold_queue
            
            	Set hold queue depth
            	**type**\: list of  		 :py:class:`HoldQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.HoldQueue>`
            
            .. attribute:: mpls
            
            	
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Mpls>`
            
            .. attribute:: ip_vrf
            
            	
            	**type**\:  :py:class:`IpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.IpVrf>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding parameters on the interface
            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Vrf>`
            
            .. attribute:: ip
            
            	Interface Internet Protocol config commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 interface subcommands
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6>`
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\: int
            
            	**range:** 0..600
            
            .. attribute:: logging
            
            	Configure logging for interface
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Logging>`
            
            .. attribute:: mdix
            
            	Set Media Dependent Interface with Crossover
            	**type**\:  :py:class:`Mdix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Mdix>`
            
            .. attribute:: mop
            
            	
            	**type**\:  :py:class:`Mop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Mop>`
            
            .. attribute:: max_reserved_bandwidth
            
            	Maximum Reservable Bandwidth on an Interface
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: mtu
            
            	Set the interface Maximum Transmission Unit (MTU)
            	**type**\: int
            
            	**range:** 64..18000
            
            .. attribute:: interface_qos
            
            	
            	**type**\:  :py:class:`InterfaceQos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.InterfaceQos>`
            
            .. attribute:: service_insertion
            
            	Service\-insertion AppNav Controller
            	**type**\:  :py:class:`ServiceInsertion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.ServiceInsertion>`
            
            .. attribute:: source
            
            	Get config from another source
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Source>`
            
            .. attribute:: standby
            
            	HSRP interface configuration commands
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby>`
            
            .. attribute:: access_session
            
            	Access Session specific Interface Configuration Commands
            	**type**\:  :py:class:`AccessSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.AccessSession>`
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl>`
            
            .. attribute:: trust
            
            	Set trust value for the interface
            	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Trust>`
            
            .. attribute:: priority_queue
            
            	Configure priority scheduling
            	**type**\:  :py:class:`PriorityQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.PriorityQueue>`
            
            .. attribute:: rcv_queue
            
            	Configure receive queue(s)
            	**type**\:  :py:class:`RcvQueue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.RcvQueue>`
            
            .. attribute:: peer
            
            	Peer parameters for point to point interfaces
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Peer>`
            
            .. attribute:: pm_path
            
            	Global pm\-path configuration
            	**type**\:  :py:class:`PmPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.PmPath>`
            
            .. attribute:: service_policy
            
            	Configure QoS Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.ServicePolicy>`
            
            .. attribute:: et_analytics
            
            	et\-analytics support on this interface
            	**type**\:  :py:class:`EtAnalytics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.EtAnalytics>`
            
            .. attribute:: zone_member
            
            	Apply zone name
            	**type**\:  :py:class:`ZoneMember <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.ZoneMember>`
            
            .. attribute:: utd
            
            	UTD support on this interface
            	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Utd>`
            
            .. attribute:: umbrella
            
            	Umbrella interface commands
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Umbrella>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Interface.Vasiright, self).__init__()

                self.yang_name = "vasiright"
                self.yang_parent_name = "interface"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("switchport-conf", ("switchport_conf", Native.Interface.Vasiright.SwitchportConf)), ("switchport", ("switchport", Native.Interface.Vasiright.Switchport)), ("stackwise-virtual", ("stackwise_virtual", Native.Interface.Vasiright.StackwiseVirtual)), ("arp", ("arp", Native.Interface.Vasiright.Arp)), ("backup", ("backup", Native.Interface.Vasiright.Backup)), ("cemoudp", ("cemoudp", Native.Interface.Vasiright.Cemoudp)), ("cws-tunnel", ("cws_tunnel", Native.Interface.Vasiright.CwsTunnel)), ("l2protocol-tunnel", ("l2protocol_tunnel", Native.Interface.Vasiright.L2protocolTunnel)), ("encapsulation", ("encapsulation", Native.Interface.Vasiright.Encapsulation)), ("fair-queue-conf", ("fair_queue_conf", Native.Interface.Vasiright.FairQueueConf)), ("fair-queue", ("fair_queue", Native.Interface.Vasiright.FairQueue)), ("flowcontrol", ("flowcontrol", Native.Interface.Vasiright.Flowcontrol)), ("isis", ("isis", Native.Interface.Vasiright.Isis)), ("keepalive-settings", ("keepalive_settings", Native.Interface.Vasiright.KeepaliveSettings)), ("bfd", ("bfd", Native.Interface.Vasiright.Bfd)), ("bandwidth", ("bandwidth", Native.Interface.Vasiright.Bandwidth)), ("dampening", ("dampening", Native.Interface.Vasiright.Dampening)), ("domain", ("domain", Native.Interface.Vasiright.Domain)), ("hold-queue", ("hold_queue", Native.Interface.Vasiright.HoldQueue)), ("mpls", ("mpls", Native.Interface.Vasiright.Mpls)), ("ip-vrf", ("ip_vrf", Native.Interface.Vasiright.IpVrf)), ("vrf", ("vrf", Native.Interface.Vasiright.Vrf)), ("ip", ("ip", Native.Interface.Vasiright.Ip)), ("ipv6", ("ipv6", Native.Interface.Vasiright.Ipv6)), ("logging", ("logging", Native.Interface.Vasiright.Logging)), ("mdix", ("mdix", Native.Interface.Vasiright.Mdix)), ("mop", ("mop", Native.Interface.Vasiright.Mop)), ("interface_qos", ("interface_qos", Native.Interface.Vasiright.InterfaceQos)), ("source", ("source", Native.Interface.Vasiright.Source)), ("standby", ("standby", Native.Interface.Vasiright.Standby)), ("access-session", ("access_session", Native.Interface.Vasiright.AccessSession)), ("storm-control", ("storm_control", Native.Interface.Vasiright.StormControl)), ("trust", ("trust", Native.Interface.Vasiright.Trust)), ("priority-queue", ("priority_queue", Native.Interface.Vasiright.PriorityQueue)), ("rcv-queue", ("rcv_queue", Native.Interface.Vasiright.RcvQueue)), ("peer", ("peer", Native.Interface.Vasiright.Peer)), ("pm-path", ("pm_path", Native.Interface.Vasiright.PmPath)), ("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.Interface.Vasiright.ServicePolicy)), ("Cisco-IOS-XE-eta:et-analytics", ("et_analytics", Native.Interface.Vasiright.EtAnalytics)), ("Cisco-IOS-XE-zone:zone-member", ("zone_member", Native.Interface.Vasiright.ZoneMember)), ("Cisco-IOS-XE-utd:utd", ("utd", Native.Interface.Vasiright.Utd)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.Interface.Vasiright.Umbrella))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('keepalive', (YLeaf(YType.boolean, 'keepalive'), ['bool'])),
                    ('if_state', (YLeaf(YType.enumeration, 'if-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.IfState')])),
                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                    ('max_reserved_bandwidth', (YLeaf(YType.uint8, 'max-reserved-bandwidth'), ['int'])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ('service_insertion', (YLeaf(YType.enumeration, 'service-insertion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.ServiceInsertion')])),
                ])
                self.name = None
                self.description = None
                self.mac_address = None
                self.shutdown = None
                self.keepalive = None
                self.if_state = None
                self.delay = None
                self.load_interval = None
                self.max_reserved_bandwidth = None
                self.mtu = None
                self.service_insertion = None

                self.switchport_conf = Native.Interface.Vasiright.SwitchportConf()
                self.switchport_conf.parent = self
                self._children_name_map["switchport_conf"] = "switchport-conf"

                self.switchport = Native.Interface.Vasiright.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.stackwise_virtual = Native.Interface.Vasiright.StackwiseVirtual()
                self.stackwise_virtual.parent = self
                self._children_name_map["stackwise_virtual"] = "stackwise-virtual"

                self.arp = Native.Interface.Vasiright.Arp()
                self.arp.parent = self
                self._children_name_map["arp"] = "arp"

                self.backup = Native.Interface.Vasiright.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"

                self.cemoudp = Native.Interface.Vasiright.Cemoudp()
                self.cemoudp.parent = self
                self._children_name_map["cemoudp"] = "cemoudp"

                self.cws_tunnel = Native.Interface.Vasiright.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "cws-tunnel"

                self.l2protocol_tunnel = None
                self._children_name_map["l2protocol_tunnel"] = "l2protocol-tunnel"

                self.encapsulation = Native.Interface.Vasiright.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.fair_queue_conf = Native.Interface.Vasiright.FairQueueConf()
                self.fair_queue_conf.parent = self
                self._children_name_map["fair_queue_conf"] = "fair-queue-conf"

                self.fair_queue = Native.Interface.Vasiright.FairQueue()
                self.fair_queue.parent = self
                self._children_name_map["fair_queue"] = "fair-queue"

                self.flowcontrol = Native.Interface.Vasiright.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.isis = Native.Interface.Vasiright.Isis()
                self.isis.parent = self
                self._children_name_map["isis"] = "isis"

                self.keepalive_settings = Native.Interface.Vasiright.KeepaliveSettings()
                self.keepalive_settings.parent = self
                self._children_name_map["keepalive_settings"] = "keepalive-settings"

                self.bfd = Native.Interface.Vasiright.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.bandwidth = Native.Interface.Vasiright.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"

                self.dampening = Native.Interface.Vasiright.Dampening()
                self.dampening.parent = self
                self._children_name_map["dampening"] = "dampening"

                self.domain = Native.Interface.Vasiright.Domain()
                self.domain.parent = self
                self._children_name_map["domain"] = "domain"

                self.mpls = Native.Interface.Vasiright.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ip_vrf = Native.Interface.Vasiright.IpVrf()
                self.ip_vrf.parent = self
                self._children_name_map["ip_vrf"] = "ip-vrf"

                self.vrf = Native.Interface.Vasiright.Vrf()
                self.vrf.parent = self
                self._children_name_map["vrf"] = "vrf"

                self.ip = Native.Interface.Vasiright.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Interface.Vasiright.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Interface.Vasiright.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.mdix = Native.Interface.Vasiright.Mdix()
                self.mdix.parent = self
                self._children_name_map["mdix"] = "mdix"

                self.mop = Native.Interface.Vasiright.Mop()
                self.mop.parent = self
                self._children_name_map["mop"] = "mop"

                self.interface_qos = Native.Interface.Vasiright.InterfaceQos()
                self.interface_qos.parent = self
                self._children_name_map["interface_qos"] = "interface_qos"

                self.source = Native.Interface.Vasiright.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.standby = Native.Interface.Vasiright.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"

                self.access_session = Native.Interface.Vasiright.AccessSession()
                self.access_session.parent = self
                self._children_name_map["access_session"] = "access-session"

                self.storm_control = Native.Interface.Vasiright.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.trust = Native.Interface.Vasiright.Trust()
                self.trust.parent = self
                self._children_name_map["trust"] = "trust"

                self.priority_queue = Native.Interface.Vasiright.PriorityQueue()
                self.priority_queue.parent = self
                self._children_name_map["priority_queue"] = "priority-queue"

                self.rcv_queue = Native.Interface.Vasiright.RcvQueue()
                self.rcv_queue.parent = self
                self._children_name_map["rcv_queue"] = "rcv-queue"

                self.peer = Native.Interface.Vasiright.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.pm_path = Native.Interface.Vasiright.PmPath()
                self.pm_path.parent = self
                self._children_name_map["pm_path"] = "pm-path"

                self.service_policy = Native.Interface.Vasiright.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"

                self.et_analytics = Native.Interface.Vasiright.EtAnalytics()
                self.et_analytics.parent = self
                self._children_name_map["et_analytics"] = "Cisco-IOS-XE-eta:et-analytics"

                self.zone_member = Native.Interface.Vasiright.ZoneMember()
                self.zone_member.parent = self
                self._children_name_map["zone_member"] = "Cisco-IOS-XE-zone:zone-member"

                self.utd = Native.Interface.Vasiright.Utd()
                self.utd.parent = self
                self._children_name_map["utd"] = "Cisco-IOS-XE-utd:utd"

                self.umbrella = Native.Interface.Vasiright.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.hold_queue = YList(self)
                self._segment_path = lambda: "vasiright" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/interface/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Interface.Vasiright, [u'name', u'description', u'mac_address', u'shutdown', u'keepalive', u'if_state', u'delay', u'load_interval', u'max_reserved_bandwidth', u'mtu', u'service_insertion'], name, value)

            class IfState(Enum):
                """
                IfState (Enum Class)

                .. data:: nhrp = 0

                """

                nhrp = Enum.YLeaf(0, "nhrp")


            class ServiceInsertion(Enum):
                """
                ServiceInsertion (Enum Class)

                Service\-insertion AppNav Controller

                .. data:: waas = 0

                """

                waas = Enum.YLeaf(0, "waas")



            class SwitchportConf(Entity):
                """
                
                
                .. attribute:: switchport
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.SwitchportConf, self).__init__()

                    self.yang_name = "switchport-conf"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switchport', (YLeaf(YType.boolean, 'switchport'), ['bool'])),
                    ])
                    self.switchport = None
                    self._segment_path = lambda: "switchport-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.SwitchportConf, [u'switchport'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True


            class StackwiseVirtual(Entity):
                """
                Configure stackwise\-virtual link values
                
                .. attribute:: link
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: dual_active_detection
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.StackwiseVirtual, self).__init__()

                    self.yang_name = "stackwise-virtual"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('link', (YLeaf(YType.uint8, 'link'), ['int'])),
                        ('dual_active_detection', (YLeaf(YType.empty, 'dual-active-detection'), ['Empty'])),
                    ])
                    self.link = None
                    self.dual_active_detection = None
                    self._segment_path = lambda: "stackwise-virtual"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.StackwiseVirtual, [u'link', u'dual_active_detection'], name, value)


            class Arp(Entity):
                """
                Set arp type (arpa, probe, snap), timeout, log options or 
                packet priority
                
                .. attribute:: timeout
                
                	Set ARP cache timeout
                	**type**\: int
                
                	**range:** 0..2147483
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Arp, self).__init__()

                    self.yang_name = "arp"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "arp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Arp, [u'timeout'], name, value)


            class Backup(Entity):
                """
                Modify backup parameters
                
                .. attribute:: delay
                
                	Delays before backup line up or down transitions
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay>`
                
                .. attribute:: interface
                
                	Configure an interface as a backup
                	**type**\:  :py:class:`Interface_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Interface_>`
                
                .. attribute:: load
                
                	Load thresholds for line up or down transitions
                	**type**\:  :py:class:`Load <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vasiright.Backup.Delay)), ("interface", ("interface", Native.Interface.Vasiright.Backup.Interface_)), ("load", ("load", Native.Interface.Vasiright.Backup.Load))])
                    self._leafs = OrderedDict()

                    self.delay = Native.Interface.Vasiright.Backup.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.interface = Native.Interface.Vasiright.Backup.Interface_()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.load = Native.Interface.Vasiright.Backup.Load()
                    self.load.parent = self
                    self._children_name_map["load"] = "load"
                    self._segment_path = lambda: "backup"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Backup, [], name, value)


                class Delay(Entity):
                    """
                    Delays before backup line up or down transitions
                    
                    .. attribute:: failure
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.Failure>`
                    
                    .. attribute:: secondary_disable
                    
                    	Seconds
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967294
                    
                    		**type**\:  :py:class:`SecondaryDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Delay.SecondaryDisable>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Backup.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('failure', (YLeaf(YType.str, 'failure'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.Failure')])),
                            ('secondary_disable', (YLeaf(YType.str, 'secondary-disable'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Delay.SecondaryDisable')])),
                        ])
                        self.failure = None
                        self.secondary_disable = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Backup.Delay, [u'failure', u'secondary_disable'], name, value)

                    class Failure(Enum):
                        """
                        Failure (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class SecondaryDisable(Enum):
                        """
                        SecondaryDisable (Enum Class)

                        Seconds

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



                class Interface_(Entity):
                    """
                    Configure an interface as a backup
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Interface_.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Interface_.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Interface_.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Interface_.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Backup.Interface_, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Interface.Vasiright.Backup.Interface_.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Interface.Vasiright.Backup.Interface_.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Interface.Vasiright.Backup.Interface_.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Interface.Vasiright.Backup.Interface_.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Interface.Vasiright.Backup.Interface_.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Interface.Vasiright.Backup.Interface_.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Interface.Vasiright.Backup.Interface_.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Interface.Vasiright.Backup.Interface_.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Backup.Interface_, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Backup.Interface_.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Backup.Interface_.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Backup.Interface_.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Backup.Interface_.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Backup.Interface_.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Backup.Interface_.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Backup.Interface_.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Backup.Interface_.PortChannelSubinterface, [u'port_channel'], name, value)


                class Load(Entity):
                    """
                    Load thresholds for line up or down transitions
                    
                    .. attribute:: kickin
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickin>`
                    
                    .. attribute:: kickout
                    
                    	Percentage
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..100
                    
                    		**type**\:  :py:class:`Kickout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Backup.Load.Kickout>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Backup.Load, self).__init__()

                        self.yang_name = "load"
                        self.yang_parent_name = "backup"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('kickin', (YLeaf(YType.str, 'kickin'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickin')])),
                            ('kickout', (YLeaf(YType.str, 'kickout'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Backup.Load.Kickout')])),
                        ])
                        self.kickin = None
                        self.kickout = None
                        self._segment_path = lambda: "load"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Backup.Load, [u'kickin', u'kickout'], name, value)

                    class Kickin(Enum):
                        """
                        Kickin (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")


                    class Kickout(Enum):
                        """
                        Kickout (Enum Class)

                        Percentage

                        .. data:: never = 0

                        """

                        never = Enum.YLeaf(0, "never")



            class Cemoudp(Entity):
                """
                cemoudp
                
                .. attribute:: reserve
                
                	
                	**type**\:  :py:class:`Reserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Cemoudp.Reserve>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Cemoudp, self).__init__()

                    self.yang_name = "cemoudp"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("reserve", ("reserve", Native.Interface.Vasiright.Cemoudp.Reserve))])
                    self._leafs = OrderedDict()

                    self.reserve = Native.Interface.Vasiright.Cemoudp.Reserve()
                    self.reserve.parent = self
                    self._children_name_map["reserve"] = "reserve"
                    self._segment_path = lambda: "cemoudp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Cemoudp, [], name, value)


                class Reserve(Entity):
                    """
                    
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Cemoudp.Reserve, self).__init__()

                        self.yang_name = "reserve"
                        self.yang_parent_name = "cemoudp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acr', (YLeaf(YType.uint8, 'acr'), ['int'])),
                        ])
                        self.acr = None
                        self._segment_path = lambda: "reserve"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Cemoudp.Reserve, [u'acr'], name, value)


            class CwsTunnel(Entity):
                """
                Configure Cloud Web Security Tunnel
                
                .. attribute:: in_
                
                	Inbound traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: out
                
                	Outbound traffic
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.CwsTunnel.Out>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("out", ("out", Native.Interface.Vasiright.CwsTunnel.Out))])
                    self._leafs = OrderedDict([
                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                    ])
                    self.in_ = None

                    self.out = Native.Interface.Vasiright.CwsTunnel.Out()
                    self.out.parent = self
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "cws-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.CwsTunnel, [u'in_'], name, value)


                class Out(Entity):
                    """
                    Outbound traffic
                    
                    .. attribute:: tunnel_number
                    
                    	Outboud traffic tunnel identifier
                    	**type**\: int
                    
                    	**range:** 0..65534
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.CwsTunnel.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tunnel_number', (YLeaf(YType.uint16, 'tunnel-number'), ['int'])),
                        ])
                        self.tunnel_number = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.CwsTunnel.Out, [u'tunnel_number'], name, value)


            class L2protocolTunnel(Entity):
                """
                Tunnel Layer2 protocols
                
                .. attribute:: cdp
                
                	Cisco Discovery Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: drop_threshold
                
                	Set drop threshold for protocol packets
                	**type**\:  :py:class:`DropThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.L2protocolTunnel.DropThreshold>`
                
                .. attribute:: shutdown_threshold
                
                	Set shutdown threshold for protocol packets
                	**type**\:  :py:class:`ShutdownThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.L2protocolTunnel.ShutdownThreshold>`
                
                .. attribute:: stp
                
                	Spanning Tree Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vtp
                
                	Vlan Trunking Protocol
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.L2protocolTunnel, self).__init__()

                    self.yang_name = "l2protocol-tunnel"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("drop-threshold", ("drop_threshold", Native.Interface.Vasiright.L2protocolTunnel.DropThreshold)), ("shutdown-threshold", ("shutdown_threshold", Native.Interface.Vasiright.L2protocolTunnel.ShutdownThreshold))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                        ('stp', (YLeaf(YType.empty, 'stp'), ['Empty'])),
                        ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                    ])
                    self.cdp = None
                    self.stp = None
                    self.vtp = None

                    self.drop_threshold = Native.Interface.Vasiright.L2protocolTunnel.DropThreshold()
                    self.drop_threshold.parent = self
                    self._children_name_map["drop_threshold"] = "drop-threshold"

                    self.shutdown_threshold = Native.Interface.Vasiright.L2protocolTunnel.ShutdownThreshold()
                    self.shutdown_threshold.parent = self
                    self._children_name_map["shutdown_threshold"] = "shutdown-threshold"
                    self._segment_path = lambda: "l2protocol-tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.L2protocolTunnel, [u'cdp', u'stp', u'vtp'], name, value)


                class DropThreshold(Entity):
                    """
                    Set drop threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.L2protocolTunnel.DropThreshold, self).__init__()

                        self.yang_name = "drop-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "drop-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.L2protocolTunnel.DropThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


                class ShutdownThreshold(Entity):
                    """
                    Set shutdown threshold for protocol packets
                    
                    .. attribute:: packet_rate
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: cdp
                    
                    	Cisco Discovery Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: stp
                    
                    	Spanning Tree Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    .. attribute:: vtp
                    
                    	Vlan Trunking Protocol
                    	**type**\: int
                    
                    	**range:** 1..4096
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.L2protocolTunnel.ShutdownThreshold, self).__init__()

                        self.yang_name = "shutdown-threshold"
                        self.yang_parent_name = "l2protocol-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packet_rate', (YLeaf(YType.uint16, 'packet-rate'), ['int'])),
                            ('cdp', (YLeaf(YType.uint16, 'cdp'), ['int'])),
                            ('stp', (YLeaf(YType.uint16, 'stp'), ['int'])),
                            ('vtp', (YLeaf(YType.uint16, 'vtp'), ['int'])),
                        ])
                        self.packet_rate = None
                        self.cdp = None
                        self.stp = None
                        self.vtp = None
                        self._segment_path = lambda: "shutdown-threshold"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.L2protocolTunnel.ShutdownThreshold, [u'packet_rate', u'cdp', u'stp', u'vtp'], name, value)


            class Encapsulation(Entity):
                """
                Set encapsulation type for an interface
                
                .. attribute:: dot1q
                
                	IEEE 802.1Q Virtual LAN
                	**type**\:  :py:class:`Dot1Q <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Encapsulation.Dot1Q>`
                
                .. attribute:: isl
                
                	Inter Switch Link \- Virtual LAN encapsulation
                	**type**\:  :py:class:`Isl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Encapsulation.Isl>`
                
                .. attribute:: ppp
                
                	Point\-to\-Point protocol
                	**type**\:  :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Encapsulation.Ppp>`
                
                	**presence node**\: True
                
                .. attribute:: slip
                
                	Serial Line IP
                	**type**\:  :py:class:`Slip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Encapsulation.Slip>`
                
                	**presence node**\: True
                
                .. attribute:: frame_relay
                
                	Frame Relay networks
                	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Encapsulation.FrameRelay>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1Q", ("dot1q", Native.Interface.Vasiright.Encapsulation.Dot1Q)), ("isl", ("isl", Native.Interface.Vasiright.Encapsulation.Isl)), ("ppp", ("ppp", Native.Interface.Vasiright.Encapsulation.Ppp)), ("slip", ("slip", Native.Interface.Vasiright.Encapsulation.Slip)), ("frame-relay", ("frame_relay", Native.Interface.Vasiright.Encapsulation.FrameRelay))])
                    self._leafs = OrderedDict()

                    self.dot1q = Native.Interface.Vasiright.Encapsulation.Dot1Q()
                    self.dot1q.parent = self
                    self._children_name_map["dot1q"] = "dot1Q"

                    self.isl = Native.Interface.Vasiright.Encapsulation.Isl()
                    self.isl.parent = self
                    self._children_name_map["isl"] = "isl"

                    self.ppp = None
                    self._children_name_map["ppp"] = "ppp"

                    self.slip = None
                    self._children_name_map["slip"] = "slip"

                    self.frame_relay = None
                    self._children_name_map["frame_relay"] = "frame-relay"
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Encapsulation, [], name, value)


                class Dot1Q(Entity):
                    """
                    IEEE 802.1Q Virtual LAN
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: native
                    
                    	Make this as native vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Encapsulation.Dot1Q, self).__init__()

                        self.yang_name = "dot1Q"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('native', (YLeaf(YType.empty, 'native'), ['Empty'])),
                        ])
                        self.vlan_id = None
                        self.native = None
                        self._segment_path = lambda: "dot1Q"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Encapsulation.Dot1Q, [u'vlan_id', u'native'], name, value)


                class Isl(Entity):
                    """
                    Inter Switch Link \- Virtual LAN encapsulation
                    
                    .. attribute:: vlan_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Encapsulation.Isl, self).__init__()

                        self.yang_name = "isl"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                        ])
                        self.vlan_id = None
                        self._segment_path = lambda: "isl"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Encapsulation.Isl, [u'vlan_id'], name, value)


                class Ppp(Entity):
                    """
                    Point\-to\-Point protocol
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Encapsulation.Ppp, self).__init__()

                        self.yang_name = "ppp"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ppp"
                        self._is_frozen = True


                class Slip(Entity):
                    """
                    Serial Line IP
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Encapsulation.Slip, self).__init__()

                        self.yang_name = "slip"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "slip"
                        self._is_frozen = True


                class FrameRelay(Entity):
                    """
                    Frame Relay networks
                    
                    .. attribute:: ietf
                    
                    	Use RFC1490/RFC2427 encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Encapsulation.FrameRelay, self).__init__()

                        self.yang_name = "frame-relay"
                        self.yang_parent_name = "encapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ])
                        self.ietf = None
                        self._segment_path = lambda: "frame-relay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Encapsulation.FrameRelay, [u'ietf'], name, value)


            class FairQueueConf(Entity):
                """
                
                
                .. attribute:: fair_queue
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.FairQueueConf, self).__init__()

                    self.yang_name = "fair-queue-conf"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('fair_queue', (YLeaf(YType.boolean, 'fair-queue'), ['bool'])),
                    ])
                    self.fair_queue = None
                    self._segment_path = lambda: "fair-queue-conf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.FairQueueConf, [u'fair_queue'], name, value)


            class FairQueue(Entity):
                """
                Enable Fair Queuing on an Interface
                
                .. attribute:: incomplete
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.FairQueue, self).__init__()

                    self.yang_name = "fair-queue"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('incomplete', (YLeaf(YType.empty, 'incomplete'), ['Empty'])),
                    ])
                    self.incomplete = None
                    self._segment_path = lambda: "fair-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.FairQueue, [u'incomplete'], name, value)


            class Flowcontrol(Entity):
                """
                Configure flow operation.
                
                .. attribute:: receive
                
                	Configure receiving flow operation
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Flowcontrol.Receive>`
                
                .. attribute:: send
                
                	Configure sending flow operation
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Flowcontrol.Send>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('receive', (YLeaf(YType.enumeration, 'receive'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Flowcontrol.Receive')])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Flowcontrol.Send')])),
                    ])
                    self.receive = None
                    self.send = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Flowcontrol, [u'receive', u'send'], name, value)

                class Receive(Enum):
                    """
                    Receive (Enum Class)

                    Configure receiving flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")


                class Send(Enum):
                    """
                    Send (Enum Class)

                    Configure sending flow operation

                    .. data:: desired = 0

                    .. data:: off = 1

                    .. data:: on = 2

                    """

                    desired = Enum.YLeaf(0, "desired")

                    off = Enum.YLeaf(1, "off")

                    on = Enum.YLeaf(2, "on")



            class Isis(Entity):
                """
                IS\-IS commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "isis"
                    self._is_frozen = True


            class KeepaliveSettings(Entity):
                """
                
                
                .. attribute:: keepalive
                
                	Enable keepalive
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.KeepaliveSettings.Keepalive>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.KeepaliveSettings, self).__init__()

                    self.yang_name = "keepalive-settings"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("keepalive", ("keepalive", Native.Interface.Vasiright.KeepaliveSettings.Keepalive))])
                    self._leafs = OrderedDict()

                    self.keepalive = None
                    self._children_name_map["keepalive"] = "keepalive"
                    self._segment_path = lambda: "keepalive-settings"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.KeepaliveSettings, [], name, value)


                class Keepalive(Entity):
                    """
                    Enable keepalive
                    
                    .. attribute:: period
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..32767
                    
                    .. attribute:: retries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.KeepaliveSettings.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "keepalive-settings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ('retries', (YLeaf(YType.uint8, 'retries'), ['int'])),
                        ])
                        self.period = None
                        self.retries = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.KeepaliveSettings.Keepalive, [u'period', u'retries'], name, value)


            class Bfd(Entity):
                """
                BFD interface configuration commands
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True


            class Bandwidth(Entity):
                """
                Set bandwidth informational parameter
                
                .. attribute:: receive
                
                	Specify receive\-side bandwidth
                	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Bandwidth.Receive>`
                
                .. attribute:: inherit
                
                	Specify how bandwidth is inherited
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Bandwidth.Inherit>`
                
                	**presence node**\: True
                
                .. attribute:: qos_reference
                
                	Reference bandwidth for QOS
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: kilobits
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("receive", ("receive", Native.Interface.Vasiright.Bandwidth.Receive)), ("inherit", ("inherit", Native.Interface.Vasiright.Bandwidth.Inherit))])
                    self._leafs = OrderedDict([
                        ('qos_reference', (YLeaf(YType.uint32, 'qos-reference'), ['int'])),
                        ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                    ])
                    self.qos_reference = None
                    self.kilobits = None

                    self.receive = Native.Interface.Vasiright.Bandwidth.Receive()
                    self.receive.parent = self
                    self._children_name_map["receive"] = "receive"

                    self.inherit = None
                    self._children_name_map["inherit"] = "inherit"
                    self._segment_path = lambda: "bandwidth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Bandwidth, [u'qos_reference', u'kilobits'], name, value)


                class Receive(Entity):
                    """
                    Specify receive\-side bandwidth
                    
                    .. attribute:: inherit
                    
                    	Specify how bandwidth is inherited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Bandwidth.Receive, self).__init__()

                        self.yang_name = "receive"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inherit', (YLeaf(YType.empty, 'inherit'), ['Empty'])),
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.inherit = None
                        self.kilobits = None
                        self._segment_path = lambda: "receive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Bandwidth.Receive, [u'inherit', u'kilobits'], name, value)


                class Inherit(Entity):
                    """
                    Specify how bandwidth is inherited
                    
                    .. attribute:: kilobits
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Bandwidth.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('kilobits', (YLeaf(YType.uint32, 'kilobits'), ['int'])),
                        ])
                        self.kilobits = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Bandwidth.Inherit, [u'kilobits'], name, value)


            class Dampening(Entity):
                """
                Enable event dampening
                
                .. attribute:: dampening_time
                
                	<1\-30>;;Half\-life time for penalty
                	**type**\: int
                
                	**range:** 1..30
                
                .. attribute:: start_reusing_time
                
                	<1\-20000>;;Value to start reusing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: start_supressing_time
                
                	<1\-20000>;;Value to start supressing an interface
                	**type**\: int
                
                	**range:** 1..20000
                
                .. attribute:: maximum_supressing_time
                
                	<1\-255>;;Maximum duration to suppress an interface
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: restart
                
                	Enable restart penalty
                	**type**\:  :py:class:`Restart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Dampening.Restart>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Dampening, self).__init__()

                    self.yang_name = "dampening"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("restart", ("restart", Native.Interface.Vasiright.Dampening.Restart))])
                    self._leafs = OrderedDict([
                        ('dampening_time', (YLeaf(YType.uint16, 'dampening-time'), ['int'])),
                        ('start_reusing_time', (YLeaf(YType.uint16, 'start-reusing-time'), ['int'])),
                        ('start_supressing_time', (YLeaf(YType.uint16, 'start-supressing-time'), ['int'])),
                        ('maximum_supressing_time', (YLeaf(YType.uint16, 'maximum-supressing-time'), ['int'])),
                    ])
                    self.dampening_time = None
                    self.start_reusing_time = None
                    self.start_supressing_time = None
                    self.maximum_supressing_time = None

                    self.restart = Native.Interface.Vasiright.Dampening.Restart()
                    self.restart.parent = self
                    self._children_name_map["restart"] = "restart"
                    self._segment_path = lambda: "dampening"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Dampening, [u'dampening_time', u'start_reusing_time', u'start_supressing_time', u'maximum_supressing_time'], name, value)


                class Restart(Entity):
                    """
                    Enable restart penalty
                    
                    .. attribute:: restart
                    
                    	Enable restart penalty
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_penalty
                    
                    	<1\-20000>;;Penalty applied at restart
                    	**type**\: int
                    
                    	**range:** 1..20000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Dampening.Restart, self).__init__()

                        self.yang_name = "restart"
                        self.yang_parent_name = "dampening"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('restart', (YLeaf(YType.empty, 'restart'), ['Empty'])),
                            ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                        ])
                        self.restart = None
                        self.restart_penalty = None
                        self._segment_path = lambda: "restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Dampening.Restart, [u'restart', u'restart_penalty'], name, value)


            class Domain(Entity):
                """
                Specify a domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: path
                
                	Specify a service provider for this interface
                	**type**\: str
                
                .. attribute:: internet_bound
                
                	Specify Internet\-bound interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: path_id
                
                	Specify service provider path\-id for this interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: path_last_resort
                
                	Specify if you want this interface to be a path of last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: zero_sla
                
                	Specify if you want this interface to be a 0\-sla interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ('internet_bound', (YLeaf(YType.empty, 'internet-bound'), ['Empty'])),
                        ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                        ('path_last_resort', (YLeaf(YType.empty, 'path-last-resort'), ['Empty'])),
                        ('zero_sla', (YLeaf(YType.empty, 'zero-sla'), ['Empty'])),
                    ])
                    self.name = None
                    self.path = None
                    self.internet_bound = None
                    self.path_id = None
                    self.path_last_resort = None
                    self.zero_sla = None
                    self._segment_path = lambda: "domain"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Domain, [u'name', u'path', u'internet_bound', u'path_id', u'path_last_resort', u'zero_sla'], name, value)


            class HoldQueue(Entity):
                """
                Set hold queue depth
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.HoldQueue.Direction>`
                
                .. attribute:: queue_length
                
                	
                	**type**\: int
                
                	**range:** 0..4096
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.HoldQueue, self).__init__()

                    self.yang_name = "hold-queue"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.HoldQueue.Direction')])),
                        ('queue_length', (YLeaf(YType.uint16, 'queue-length'), ['int'])),
                    ])
                    self.direction = None
                    self.queue_length = None
                    self._segment_path = lambda: "hold-queue" + "[direction='" + str(self.direction) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.HoldQueue, [u'direction', u'queue_length'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: in_ = 0

                    .. data:: out = 1

                    """

                    in_ = Enum.YLeaf(0, "in")

                    out = Enum.YLeaf(1, "out")



            class Mpls(Entity):
                """
                
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True


            class IpVrf(Entity):
                """
                
                
                .. attribute:: ip
                
                	
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.IpVrf.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.IpVrf, self).__init__()

                    self.yang_name = "ip-vrf"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Vasiright.IpVrf.Ip))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Interface.Vasiright.IpVrf.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "ip-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.IpVrf, [], name, value)


                class Ip(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.IpVrf.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.IpVrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "ip-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Interface.Vasiright.IpVrf.Ip.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Interface.Vasiright.IpVrf.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.IpVrf.Ip, [], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: forwarding
                        
                        	Configure forwarding table
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.IpVrf.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                            ])
                            self.forwarding = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.IpVrf.Ip.Vrf, [u'forwarding'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding parameters on the interface
                
                .. attribute:: forwarding
                
                	Configure forwarding table
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                    ])
                    self.forwarding = None
                    self._segment_path = lambda: "vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Vrf, [u'forwarding'], name, value)


            class Ip(Entity):
                """
                Interface Internet Protocol config commands
                
                .. attribute:: admission
                
                	Apply Network Admission Control
                	**type**\: str
                
                .. attribute:: access_group
                
                	Specify access control for packets
                	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.AccessGroup>`
                
                .. attribute:: arp
                
                	Configure ARP features
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Arp>`
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding parameters on the interface
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Vrf>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\: str
                
                .. attribute:: no_address
                
                	
                	**type**\:  :py:class:`NoAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.NoAddress>`
                
                .. attribute:: address
                
                	Set the IP address of an interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Address>`
                
                .. attribute:: directed_broadcast
                
                	Enable forwarding of directed broadcasts
                	**type**\:  :py:class:`DirectedBroadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.DirectedBroadcast>`
                
                	**presence node**\: True
                
                .. attribute:: hello_interval
                
                	Configures EIGRP\-IPv4 hello interval
                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.HelloInterval>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Authentication>`
                
                .. attribute:: hold_time
                
                	Configures EIGRP\-IPv4 hold time
                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.HoldTime>`
                
                .. attribute:: helper_address
                
                	Specify a destination address for UDP broadcasts
                	**type**\: list of  		 :py:class:`HelperAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.HelperAddress>`
                
                .. attribute:: pim
                
                	PIM interface commands
                	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Pim>`
                
                .. attribute:: policy
                
                	Enable policy routing
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Policy>`
                
                .. attribute:: local_proxy_arp
                
                	Enable local\-proxy ARP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_arp
                
                	Enable proxy ARP
                	**type**\: bool
                
                .. attribute:: rip
                
                	Router Information Protocol
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Rip>`
                
                .. attribute:: route_cache_conf
                
                	
                	**type**\:  :py:class:`RouteCacheConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.RouteCacheConf>`
                
                .. attribute:: route_cache
                
                	Enable fast\-switching cache for outgoing packets
                	**type**\:  :py:class:`RouteCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.RouteCache>`
                
                	**presence node**\: True
                
                .. attribute:: router
                
                	IP router interface commands
                	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Router>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Tcp>`
                
                .. attribute:: virtual_reassembly
                
                	
                	**type**\:  :py:class:`VirtualReassembly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.VirtualReassembly>`
                
                .. attribute:: dhcp
                
                	Configure DHCP parameters for this interface
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp>`
                
                .. attribute:: mtu
                
                	Set IP Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 68..9216
                
                .. attribute:: mroute_cache
                
                	Enable switching cache for incoming multicast packets
                	**type**\: bool
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.SummaryAddress>`
                
                .. attribute:: verify
                
                	Enable per packet validation
                	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Verify>`
                
                .. attribute:: wccp
                
                	WCCP IPv4 interface commands
                	**type**\:  :py:class:`Wccp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-group", ("access_group", Native.Interface.Vasiright.Ip.AccessGroup)), ("arp", ("arp", Native.Interface.Vasiright.Ip.Arp)), ("vrf", ("vrf", Native.Interface.Vasiright.Ip.Vrf)), ("no-address", ("no_address", Native.Interface.Vasiright.Ip.NoAddress)), ("address", ("address", Native.Interface.Vasiright.Ip.Address)), ("directed-broadcast", ("directed_broadcast", Native.Interface.Vasiright.Ip.DirectedBroadcast)), ("hello-interval", ("hello_interval", Native.Interface.Vasiright.Ip.HelloInterval)), ("authentication", ("authentication", Native.Interface.Vasiright.Ip.Authentication)), ("hold-time", ("hold_time", Native.Interface.Vasiright.Ip.HoldTime)), ("helper-address", ("helper_address", Native.Interface.Vasiright.Ip.HelperAddress)), ("pim", ("pim", Native.Interface.Vasiright.Ip.Pim)), ("policy", ("policy", Native.Interface.Vasiright.Ip.Policy)), ("rip", ("rip", Native.Interface.Vasiright.Ip.Rip)), ("route-cache-conf", ("route_cache_conf", Native.Interface.Vasiright.Ip.RouteCacheConf)), ("route-cache", ("route_cache", Native.Interface.Vasiright.Ip.RouteCache)), ("router", ("router", Native.Interface.Vasiright.Ip.Router)), ("tcp", ("tcp", Native.Interface.Vasiright.Ip.Tcp)), ("virtual-reassembly", ("virtual_reassembly", Native.Interface.Vasiright.Ip.VirtualReassembly)), ("dhcp", ("dhcp", Native.Interface.Vasiright.Ip.Dhcp)), ("summary-address", ("summary_address", Native.Interface.Vasiright.Ip.SummaryAddress)), ("verify", ("verify", Native.Interface.Vasiright.Ip.Verify)), ("Cisco-IOS-XE-wccp:wccp", ("wccp", Native.Interface.Vasiright.Ip.Wccp))])
                    self._leafs = OrderedDict([
                        ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('local_proxy_arp', (YLeaf(YType.empty, 'local-proxy-arp'), ['Empty'])),
                        ('proxy_arp', (YLeaf(YType.boolean, 'proxy-arp'), ['bool'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('mroute_cache', (YLeaf(YType.boolean, 'mroute-cache'), ['bool'])),
                    ])
                    self.admission = None
                    self.unnumbered = None
                    self.local_proxy_arp = None
                    self.proxy_arp = None
                    self.redirects = None
                    self.mtu = None
                    self.mroute_cache = None

                    self.access_group = Native.Interface.Vasiright.Ip.AccessGroup()
                    self.access_group.parent = self
                    self._children_name_map["access_group"] = "access-group"

                    self.arp = Native.Interface.Vasiright.Ip.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.vrf = Native.Interface.Vasiright.Ip.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.no_address = Native.Interface.Vasiright.Ip.NoAddress()
                    self.no_address.parent = self
                    self._children_name_map["no_address"] = "no-address"

                    self.address = Native.Interface.Vasiright.Ip.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.directed_broadcast = None
                    self._children_name_map["directed_broadcast"] = "directed-broadcast"

                    self.hello_interval = Native.Interface.Vasiright.Ip.HelloInterval()
                    self.hello_interval.parent = self
                    self._children_name_map["hello_interval"] = "hello-interval"

                    self.authentication = Native.Interface.Vasiright.Ip.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.hold_time = Native.Interface.Vasiright.Ip.HoldTime()
                    self.hold_time.parent = self
                    self._children_name_map["hold_time"] = "hold-time"

                    self.pim = Native.Interface.Vasiright.Ip.Pim()
                    self.pim.parent = self
                    self._children_name_map["pim"] = "pim"

                    self.policy = Native.Interface.Vasiright.Ip.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"

                    self.rip = Native.Interface.Vasiright.Ip.Rip()
                    self.rip.parent = self
                    self._children_name_map["rip"] = "rip"

                    self.route_cache_conf = Native.Interface.Vasiright.Ip.RouteCacheConf()
                    self.route_cache_conf.parent = self
                    self._children_name_map["route_cache_conf"] = "route-cache-conf"

                    self.route_cache = None
                    self._children_name_map["route_cache"] = "route-cache"

                    self.router = Native.Interface.Vasiright.Ip.Router()
                    self.router.parent = self
                    self._children_name_map["router"] = "router"

                    self.tcp = Native.Interface.Vasiright.Ip.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.virtual_reassembly = Native.Interface.Vasiright.Ip.VirtualReassembly()
                    self.virtual_reassembly.parent = self
                    self._children_name_map["virtual_reassembly"] = "virtual-reassembly"

                    self.dhcp = Native.Interface.Vasiright.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.summary_address = Native.Interface.Vasiright.Ip.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"

                    self.verify = Native.Interface.Vasiright.Ip.Verify()
                    self.verify.parent = self
                    self._children_name_map["verify"] = "verify"

                    self.wccp = Native.Interface.Vasiright.Ip.Wccp()
                    self.wccp.parent = self
                    self._children_name_map["wccp"] = "Cisco-IOS-XE-wccp:wccp"

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Ip, [u'admission', u'unnumbered', u'local_proxy_arp', u'proxy_arp', u'redirects', u'mtu', u'mroute_cache'], name, value)


                class AccessGroup(Entity):
                    """
                    Specify access control for packets
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.AccessGroup.In>`
                    
                    .. attribute:: out
                    
                    	
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.AccessGroup.Out>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.AccessGroup, self).__init__()

                        self.yang_name = "access-group"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("in", ("in_", Native.Interface.Vasiright.Ip.AccessGroup.In)), ("out", ("out", Native.Interface.Vasiright.Ip.AccessGroup.Out))])
                        self._leafs = OrderedDict()

                        self.in_ = Native.Interface.Vasiright.Ip.AccessGroup.In()
                        self.in_.parent = self
                        self._children_name_map["in_"] = "in"

                        self.out = Native.Interface.Vasiright.Ip.AccessGroup.Out()
                        self.out.parent = self
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "access-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.AccessGroup, [], name, value)


                    class In(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.AccessGroup.In.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.AccessGroup.In.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.AccessGroup.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Vasiright.Ip.AccessGroup.In.CommonAcl)), ("acl", ("acl", Native.Interface.Vasiright.Ip.AccessGroup.In.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Vasiright.Ip.AccessGroup.In.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Vasiright.Ip.AccessGroup.In.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.AccessGroup.In, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.AccessGroup.In.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.common = None
                                self.in_ = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.AccessGroup.In.CommonAcl, [u'common', u'in_'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: in_
                            
                            	inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.AccessGroup.In.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "in"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.in_ = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.AccessGroup.In.Acl, [u'acl_name', u'in_'], name, value)


                    class Out(Entity):
                        """
                        
                        
                        .. attribute:: common_acl
                        
                        	
                        	**type**\:  :py:class:`CommonAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.AccessGroup.Out.CommonAcl>`
                        
                        .. attribute:: acl
                        
                        	
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.AccessGroup.Out.Acl>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.AccessGroup.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "access-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-acl", ("common_acl", Native.Interface.Vasiright.Ip.AccessGroup.Out.CommonAcl)), ("acl", ("acl", Native.Interface.Vasiright.Ip.AccessGroup.Out.Acl))])
                            self._leafs = OrderedDict()

                            self.common_acl = Native.Interface.Vasiright.Ip.AccessGroup.Out.CommonAcl()
                            self.common_acl.parent = self
                            self._children_name_map["common_acl"] = "common-acl"

                            self.acl = Native.Interface.Vasiright.Ip.AccessGroup.Out.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.AccessGroup.Out, [], name, value)


                        class CommonAcl(Entity):
                            """
                            
                            
                            .. attribute:: common
                            
                            	specify ipv4 common ACL for packet filtering
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.AccessGroup.Out.CommonAcl, self).__init__()

                                self.yang_name = "common-acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('common', (YLeaf(YType.str, 'common'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.common = None
                                self.out = None
                                self._segment_path = lambda: "common-acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.AccessGroup.Out.CommonAcl, [u'common', u'out'], name, value)


                        class Acl(Entity):
                            """
                            
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            	**mandatory**\: True
                            
                            .. attribute:: out
                            
                            	outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.AccessGroup.Out.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "out"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','str'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.acl_name = None
                                self.out = None
                                self._segment_path = lambda: "acl"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.AccessGroup.Out.Acl, [u'acl_name', u'out'], name, value)


                class Arp(Entity):
                    """
                    Configure ARP features
                    
                    .. attribute:: inspection
                    
                    	Arp Inspection configuration
                    	**type**\:  :py:class:`Inspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Arp.Inspection>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("inspection", ("inspection", Native.Interface.Vasiright.Ip.Arp.Inspection))])
                        self._leafs = OrderedDict()

                        self.inspection = Native.Interface.Vasiright.Ip.Arp.Inspection()
                        self.inspection.parent = self
                        self._children_name_map["inspection"] = "inspection"
                        self._segment_path = lambda: "arp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.Arp, [], name, value)


                    class Inspection(Entity):
                        """
                        Arp Inspection configuration
                        
                        .. attribute:: limit
                        
                        	Configure Rate limit of incoming ARP packets
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Arp.Inspection.Limit>`
                        
                        .. attribute:: trust
                        
                        	Configure Trust state
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Arp.Inspection, self).__init__()

                            self.yang_name = "inspection"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Vasiright.Ip.Arp.Inspection.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Vasiright.Ip.Arp.Inspection.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "inspection"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Arp.Inspection, [u'trust'], name, value)


                        class Limit(Entity):
                            """
                            Configure Rate limit of incoming ARP packets
                            
                            .. attribute:: none
                            
                            	No limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rate
                            
                            	Rate Limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Arp.Inspection.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ('rate', (YLeaf(YType.uint32, 'rate'), ['int'])),
                                ])
                                self.none = None
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Arp.Inspection.Limit, [u'none', u'rate'], name, value)


                class Vrf(Entity):
                    """
                    VPN Routing/Forwarding parameters on the interface
                    
                    .. attribute:: receive
                    
                    	Add Interface Address into VRF Table
                    	**type**\: str
                    
                    .. attribute:: sitemap
                    
                    	Configure route\-map for routesreceived from this site
                    	**type**\: str
                    
                    .. attribute:: forwarding
                    
                    	Configure forwarding table
                    	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Vrf.Forwarding>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding", ("forwarding", Native.Interface.Vasiright.Ip.Vrf.Forwarding))])
                        self._leafs = OrderedDict([
                            ('receive', (YLeaf(YType.str, 'receive'), ['str'])),
                            ('sitemap', (YLeaf(YType.str, 'sitemap'), ['str'])),
                        ])
                        self.receive = None
                        self.sitemap = None

                        self.forwarding = Native.Interface.Vasiright.Ip.Vrf.Forwarding()
                        self.forwarding.parent = self
                        self._children_name_map["forwarding"] = "forwarding"
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.Vrf, [u'receive', u'sitemap'], name, value)


                    class Forwarding(Entity):
                        """
                        Configure forwarding table
                        
                        .. attribute:: liin_vrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mgmtvrf
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Vrf.Forwarding, self).__init__()

                            self.yang_name = "forwarding"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('liin_vrf', (YLeaf(YType.empty, 'Liin-vrf'), ['Empty'])),
                                ('mgmtvrf', (YLeaf(YType.empty, 'mgmtVrf'), ['Empty'])),
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.liin_vrf = None
                            self.mgmtvrf = None
                            self.word = None
                            self._segment_path = lambda: "forwarding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Vrf.Forwarding, [u'liin_vrf', u'mgmtvrf', u'word'], name, value)


                class NoAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.NoAddress, self).__init__()

                        self.yang_name = "no-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.boolean, 'address'), ['bool'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "no-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.NoAddress, [u'address'], name, value)


                class Address(Entity):
                    """
                    Set the IP address of an interface
                    
                    .. attribute:: secondary
                    
                    	
                    	**type**\: list of  		 :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Address.Secondary>`
                    
                    .. attribute:: primary
                    
                    	
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Address.Primary>`
                    
                    .. attribute:: dhcp
                    
                    	IP Address negotiated via DHCP
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: negotiated
                    
                    	IP Address negotiated via IKEv2 Modeconfig
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("secondary", ("secondary", Native.Interface.Vasiright.Ip.Address.Secondary)), ("primary", ("primary", Native.Interface.Vasiright.Ip.Address.Primary)), ("dhcp", ("dhcp", Native.Interface.Vasiright.Ip.Address.Dhcp))])
                        self._leafs = OrderedDict([
                            ('negotiated', (YLeaf(YType.empty, 'negotiated'), ['Empty'])),
                        ])
                        self.negotiated = None

                        self.primary = Native.Interface.Vasiright.Ip.Address.Primary()
                        self.primary.parent = self
                        self._children_name_map["primary"] = "primary"

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.secondary = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.Address, [u'negotiated'], name, value)


                    class Secondary(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Address.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.secondary = None
                            self._segment_path = lambda: "secondary" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Address.Secondary, [u'address', u'mask', u'secondary'], name, value)


                    class Primary(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Address.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.address = None
                            self.mask = None
                            self._segment_path = lambda: "primary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Address.Primary, [u'address', u'mask'], name, value)


                    class Dhcp(Entity):
                        """
                        IP Address negotiated via DHCP
                        
                        .. attribute:: client_id
                        
                        	Specify client\-id to use
                        	**type**\:  :py:class:`ClientId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Address.Dhcp.ClientId>`
                        
                        .. attribute:: hostname
                        
                        	Specify value for hostname option
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client-id", ("client_id", Native.Interface.Vasiright.Ip.Address.Dhcp.ClientId))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.client_id = Native.Interface.Vasiright.Ip.Address.Dhcp.ClientId()
                            self.client_id.parent = self
                            self._children_name_map["client_id"] = "client-id"
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Address.Dhcp, [u'hostname'], name, value)


                        class ClientId(Entity):
                            """
                            Specify client\-id to use
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two Gigabit Ethernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	Catalyst Vlans
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Address.Dhcp.ClientId, self).__init__()

                                self.yang_name = "client-id"
                                self.yang_parent_name = "dhcp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.port_channel = None
                                self.tengigabitethernet = None
                                self.twentyfivegige = None
                                self.fortygigabitethernet = None
                                self.twogigabitethernet = None
                                self.hundredgige = None
                                self.vlan = None
                                self._segment_path = lambda: "client-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Address.Dhcp.ClientId, [u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'port_channel', u'tengigabitethernet', u'twentyfivegige', u'fortygigabitethernet', u'twogigabitethernet', u'hundredgige', u'vlan'], name, value)


                class DirectedBroadcast(Entity):
                    """
                    Enable forwarding of directed broadcasts
                    
                    .. attribute:: direct_broadcast
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.DirectedBroadcast, self).__init__()

                        self.yang_name = "directed-broadcast"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('direct_broadcast', (YLeaf(YType.str, 'direct-broadcast'), ['int','str'])),
                        ])
                        self.direct_broadcast = None
                        self._segment_path = lambda: "directed-broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.DirectedBroadcast, [u'direct_broadcast'], name, value)


                class HelloInterval(Entity):
                    """
                    Configures EIGRP\-IPv4 hello interval
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds between hello transmissions
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.HelloInterval, self).__init__()

                        self.yang_name = "hello-interval"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hello-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.HelloInterval, [u'eigrp', u'seconds'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Authentication.KeyChain>`
                    
                    .. attribute:: mode
                    
                    	mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Authentication.Mode>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Interface.Vasiright.Ip.Authentication.KeyChain)), ("mode", ("mode", Native.Interface.Vasiright.Ip.Authentication.Mode))])
                        self._leafs = OrderedDict()

                        self.key_chain = Native.Interface.Vasiright.Ip.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.mode = Native.Interface.Vasiright.Ip.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.Authentication, [], name, value)


                    class KeyChain(Entity):
                        """
                        key\-chain
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: name
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.eigrp = None
                            self.name = None
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Authentication.KeyChain, [u'eigrp', u'name'], name, value)


                    class Mode(Entity):
                        """
                        mode
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.eigrp = None
                            self.md5 = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Authentication.Mode, [u'eigrp', u'md5'], name, value)


                class HoldTime(Entity):
                    """
                    Configures EIGRP\-IPv4 hold time
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: seconds
                    
                    	Seconds before neighbor is considered down
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.HoldTime, self).__init__()

                        self.yang_name = "hold-time"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.eigrp = None
                        self.seconds = None
                        self._segment_path = lambda: "hold-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.HoldTime, [u'eigrp', u'seconds'], name, value)


                class HelperAddress(Entity):
                    """
                    Specify a destination address for UDP broadcasts
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: global_
                    
                    	Helper\-address is global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name for helper\-address (if different from interface VRF)
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.address = None
                        self.global_ = None
                        self.vrf = None
                        self._segment_path = lambda: "helper-address" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.HelperAddress, [u'address', u'global_', u'vrf'], name, value)


                class Pim(Entity):
                    """
                    PIM interface commands
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Pim, self).__init__()

                        self.yang_name = "pim"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "pim"
                        self._is_frozen = True


                class Policy(Entity):
                    """
                    Enable policy routing
                    
                    .. attribute:: route_map
                    
                    	Policy route\-map
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.Policy, [u'route_map'], name, value)


                class Rip(Entity):
                    """
                    Router Information Protocol
                    
                    .. attribute:: authentication
                    
                    	Authentication control
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Rip.Authentication>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vasiright.Ip.Rip.Authentication))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Interface.Vasiright.Ip.Rip.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.Rip, [], name, value)


                    class Authentication(Entity):
                        """
                        Authentication control
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Rip.Authentication.Mode>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Rip.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Interface.Vasiright.Ip.Rip.Authentication.Mode))])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.key_chain = None

                            self.mode = Native.Interface.Vasiright.Ip.Rip.Authentication.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Rip.Authentication, [u'key_chain'], name, value)


                        class Mode(Entity):
                            """
                            Authentication mode
                            
                            .. attribute:: md5
                            
                            	Keyed message digest
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: text
                            
                            	Clear text authentication
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Rip.Authentication.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ('text', (YLeaf(YType.empty, 'text'), ['Empty'])),
                                ])
                                self.md5 = None
                                self.text = None
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Rip.Authentication.Mode, [u'md5', u'text'], name, value)


                class RouteCacheConf(Entity):
                    """
                    
                    
                    .. attribute:: route_cache
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.RouteCacheConf, self).__init__()

                        self.yang_name = "route-cache-conf"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_cache', (YLeaf(YType.boolean, 'route-cache'), ['bool'])),
                        ])
                        self.route_cache = None
                        self._segment_path = lambda: "route-cache-conf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.RouteCacheConf, [u'route_cache'], name, value)


                class RouteCache(Entity):
                    """
                    Enable fast\-switching cache for outgoing packets
                    
                    .. attribute:: cef
                    
                    	Enable Cisco Express Forwarding
                    	**type**\: bool
                    
                    .. attribute:: flow
                    
                    	Enable Flow fast\-switching cache
                    	**type**\: bool
                    
                    .. attribute:: policy
                    
                    	Enable fast\-switching policy cache for outgoing packets
                    	**type**\: bool
                    
                    .. attribute:: same_interface
                    
                    	Enable fast\-switching on the same interface
                    	**type**\: bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.RouteCache, self).__init__()

                        self.yang_name = "route-cache"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cef', (YLeaf(YType.boolean, 'cef'), ['bool'])),
                            ('flow', (YLeaf(YType.boolean, 'flow'), ['bool'])),
                            ('policy', (YLeaf(YType.boolean, 'policy'), ['bool'])),
                            ('same_interface', (YLeaf(YType.boolean, 'same-interface'), ['bool'])),
                        ])
                        self.cef = None
                        self.flow = None
                        self.policy = None
                        self.same_interface = None
                        self._segment_path = lambda: "route-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.RouteCache, [u'cef', u'flow', u'policy', u'same_interface'], name, value)


                class Router(Entity):
                    """
                    IP router interface commands
                    
                    .. attribute:: isis
                    
                    	IS\-IS Routing for IP
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Router.Isis>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Router, self).__init__()

                        self.yang_name = "router"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Interface.Vasiright.Ip.Router.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = None
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "router"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.Router, [], name, value)


                    class Isis(Entity):
                        """
                        IS\-IS Routing for IP
                        
                        .. attribute:: tag
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Router.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "router"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ])
                            self.tag = None
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Router.Isis, [u'tag'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 500..1460
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.Tcp, [u'adjust_mss'], name, value)


                class VirtualReassembly(Entity):
                    """
                    
                    
                    .. attribute:: max_reassemblies
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_fragments
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: timeout
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop_fragments
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: in_
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.VirtualReassembly, self).__init__()

                        self.yang_name = "virtual-reassembly"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_reassemblies', (YLeaf(YType.uint32, 'max-reassemblies'), ['int'])),
                            ('max_fragments', (YLeaf(YType.uint32, 'max-fragments'), ['int'])),
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                            ('drop_fragments', (YLeaf(YType.empty, 'drop-fragments'), ['Empty'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.max_reassemblies = None
                        self.max_fragments = None
                        self.timeout = None
                        self.drop_fragments = None
                        self.in_ = None
                        self._segment_path = lambda: "virtual-reassembly"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.VirtualReassembly, [u'max_reassemblies', u'max_fragments', u'timeout', u'drop_fragments', u'in_'], name, value)


                class Dhcp(Entity):
                    """
                    Configure DHCP parameters for this interface
                    
                    .. attribute:: client
                    
                    	DHCP client configuration
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Client>`
                    
                    .. attribute:: relay
                    
                    	DHCP relay configuration parameters
                    	**type**\:  :py:class:`Relay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Relay>`
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.Vasiright.Ip.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:relay", ("relay", Native.Interface.Vasiright.Ip.Dhcp.Relay)), ("Cisco-IOS-XE-dhcp:snooping", ("snooping", Native.Interface.Vasiright.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.Vasiright.Ip.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.relay = Native.Interface.Vasiright.Ip.Dhcp.Relay()
                        self.relay.parent = self
                        self._children_name_map["relay"] = "Cisco-IOS-XE-dhcp:relay"

                        self.snooping = Native.Interface.Vasiright.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "Cisco-IOS-XE-dhcp:snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        DHCP client configuration
                        
                        .. attribute:: hostname
                        
                        	Specify hostname to use
                        	**type**\: str
                        
                        .. attribute:: option
                        
                        	DHCP Client options
                        	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Client.Option>`
                        
                        .. attribute:: request
                        
                        	Specify options (not) to request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Client.Request>`
                        
                        .. attribute:: route
                        
                        	Options for routes installed by dhcp
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Client.Route>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("option", ("option", Native.Interface.Vasiright.Ip.Dhcp.Client.Option)), ("request", ("request", Native.Interface.Vasiright.Ip.Dhcp.Client.Request)), ("route", ("route", Native.Interface.Vasiright.Ip.Dhcp.Client.Route))])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                            ])
                            self.hostname = None

                            self.option = Native.Interface.Vasiright.Ip.Dhcp.Client.Option()
                            self.option.parent = self
                            self._children_name_map["option"] = "option"

                            self.request = Native.Interface.Vasiright.Ip.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"

                            self.route = Native.Interface.Vasiright.Ip.Dhcp.Client.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Client, ['hostname'], name, value)


                        class Option(Entity):
                            """
                            DHCP Client options
                            
                            .. attribute:: option_range
                            
                            	
                            	**type**\: list of  		 :py:class:`OptionRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Client.Option.OptionRange>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Dhcp.Client.Option, self).__init__()

                                self.yang_name = "option"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("option-range", ("option_range", Native.Interface.Vasiright.Ip.Dhcp.Client.Option.OptionRange))])
                                self._leafs = OrderedDict()

                                self.option_range = YList(self)
                                self._segment_path = lambda: "option"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Client.Option, [], name, value)


                            class OptionRange(Entity):
                                """
                                
                                
                                .. attribute:: option_range  (key)
                                
                                	DHCP option code (1\-254)
                                	**type**\: int
                                
                                	**range:** 1..254
                                
                                .. attribute:: ascii
                                
                                	Input ascii string
                                	**type**\: str
                                
                                .. attribute:: hex
                                
                                	Input hex string
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Input IP Address
                                	**type**\: union of the below types:
                                
                                		**type**\: list of str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: list of str
                                
                                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Ip.Dhcp.Client.Option.OptionRange, self).__init__()

                                    self.yang_name = "option-range"
                                    self.yang_parent_name = "option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['option_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('option_range', (YLeaf(YType.uint8, 'option-range'), ['int'])),
                                        ('ascii', (YLeaf(YType.str, 'ascii'), ['str'])),
                                        ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                                        ('ip', (YLeafList(YType.str, 'ip'), ['str','str','str'])),
                                    ])
                                    self.option_range = None
                                    self.ascii = None
                                    self.hex = None
                                    self.ip = []
                                    self._segment_path = lambda: "option-range" + "[option-range='" + str(self.option_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Client.Option.OptionRange, ['option_range', 'ascii', 'hex', 'ip'], name, value)


                        class Request(Entity):
                            """
                            Specify options (not) to request
                            
                            .. attribute:: option
                            
                            	DHCP options
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('option', (YLeaf(YType.uint8, 'option'), ['int'])),
                                ])
                                self.option = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Client.Request, ['option'], name, value)


                        class Route(Entity):
                            """
                            Options for routes installed by dhcp
                            
                            .. attribute:: distance
                            
                            	set distance for dhcp static routes
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: track
                            
                            	Track dhcp routes
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Dhcp.Client.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.distance = None
                                self.track = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Client.Route, ['distance', 'track'], name, value)


                    class Relay(Entity):
                        """
                        DHCP relay configuration parameters
                        
                        .. attribute:: information
                        
                        	DHCP relay information option
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Relay.Information>`
                        
                        .. attribute:: source_interface
                        
                        	Set source interface for relayed messages
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Dhcp.Relay, self).__init__()

                            self.yang_name = "relay"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("information", ("information", Native.Interface.Vasiright.Ip.Dhcp.Relay.Information))])
                            self._leafs = OrderedDict([
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.source_interface = None

                            self.information = Native.Interface.Vasiright.Ip.Dhcp.Relay.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:relay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Relay, ['source_interface'], name, value)


                        class Information(Entity):
                            """
                            DHCP relay information option
                            
                            .. attribute:: check_reply
                            
                            	Validate relay information in BOOTREPLY
                            	**type**\:  :py:class:`CheckReply <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.CheckReply>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: option
                            
                            	DHCP relay information option
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.Option>`
                            
                            .. attribute:: option_insert
                            
                            	Insert relay information in BOOTREQUEST
                            	**type**\:  :py:class:`OptionInsert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.OptionInsert>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: policy_action
                            
                            	Define reforwarding policy
                            	**type**\:  :py:class:`PolicyAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.PolicyAction>`
                            
                            .. attribute:: trusted
                            
                            	Received DHCP packet may contain relay info option with zero giaddr
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Dhcp.Relay.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check-reply", ("check_reply", Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.CheckReply)), ("option", ("option", Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.Option)), ("option-insert", ("option_insert", Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.OptionInsert))])
                                self._leafs = OrderedDict([
                                    ('policy_action', (YLeaf(YType.enumeration, 'policy-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Ip.Dhcp.Relay.Information.PolicyAction')])),
                                    ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                                ])
                                self.policy_action = None
                                self.trusted = None

                                self.check_reply = None
                                self._children_name_map["check_reply"] = "check-reply"

                                self.option = Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.option_insert = None
                                self._children_name_map["option_insert"] = "option-insert"
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Relay.Information, ['policy_action', 'trusted'], name, value)

                            class PolicyAction(Enum):
                                """
                                PolicyAction (Enum Class)

                                Define reforwarding policy

                                .. data:: drop = 0

                                .. data:: encapsulate = 1

                                .. data:: keep = 2

                                .. data:: replace = 3

                                """

                                drop = Enum.YLeaf(0, "drop")

                                encapsulate = Enum.YLeaf(1, "encapsulate")

                                keep = Enum.YLeaf(2, "keep")

                                replace = Enum.YLeaf(3, "replace")



                            class CheckReply(Entity):
                                """
                                Validate relay information in BOOTREPLY
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.CheckReply, self).__init__()

                                    self.yang_name = "check-reply"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "check-reply"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.CheckReply, ['none'], name, value)


                            class Option(Entity):
                                """
                                DHCP relay information option
                                
                                .. attribute:: subscriber_id
                                
                                	Subscriber identifier sub option
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('subscriber_id', (YLeaf(YType.str, 'subscriber-id'), ['str'])),
                                    ])
                                    self.subscriber_id = None
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.Option, ['subscriber_id'], name, value)


                            class OptionInsert(Entity):
                                """
                                Insert relay information in BOOTREQUEST
                                
                                .. attribute:: none
                                
                                	Set to none
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.OptionInsert, self).__init__()

                                    self.yang_name = "option-insert"
                                    self.yang_parent_name = "information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None
                                    self._segment_path = lambda: "option-insert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Relay.Information.OptionInsert, ['none'], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	DHCP Snooping vlan
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Interface.Vasiright.Ip.Dhcp.Snooping.Limit)), ("vlan", ("vlan", Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Interface.Vasiright.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP Snooping limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


                        class Vlan(Entity):
                            """
                            DHCP Snooping vlan
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: information
                            
                            	DHCP Snooping information
                            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("information", ("information", Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.information = Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information()
                                self.information.parent = self
                                self._children_name_map["information"] = "information"
                                self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan, ['id'], name, value)


                            class Information(Entity):
                                """
                                DHCP Snooping information
                                
                                .. attribute:: option
                                
                                	DHCP Snooping information option
                                	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option>`
                                
                                

                                """

                                _prefix = 'ios-dhcp'
                                _revision = '2018-06-16'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information, self).__init__()

                                    self.yang_name = "information"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("option", ("option", Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option))])
                                    self._leafs = OrderedDict()

                                    self.option = Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option()
                                    self.option.parent = self
                                    self._children_name_map["option"] = "option"
                                    self._segment_path = lambda: "information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information, [], name, value)


                                class Option(Entity):
                                    """
                                    DHCP Snooping information option
                                    
                                    .. attribute:: format_type
                                    
                                    	Option 82 information format
                                    	**type**\:  :py:class:`FormatType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-dhcp'
                                    _revision = '2018-06-16'

                                    def __init__(self):
                                        super(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option, self).__init__()

                                        self.yang_name = "option"
                                        self.yang_parent_name = "information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("format-type", ("format_type", Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType))])
                                        self._leafs = OrderedDict()

                                        self.format_type = Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType()
                                        self.format_type.parent = self
                                        self._children_name_map["format_type"] = "format-type"
                                        self._segment_path = lambda: "option"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option, [], name, value)


                                    class FormatType(Entity):
                                        """
                                        Option 82 information format
                                        
                                        .. attribute:: circuit_id
                                        
                                        	Circuit id option 82 format
                                        	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId>`
                                        
                                        

                                        """

                                        _prefix = 'ios-dhcp'
                                        _revision = '2018-06-16'

                                        def __init__(self):
                                            super(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, self).__init__()

                                            self.yang_name = "format-type"
                                            self.yang_parent_name = "option"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId))])
                                            self._leafs = OrderedDict()

                                            self.circuit_id = Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId()
                                            self.circuit_id.parent = self
                                            self._children_name_map["circuit_id"] = "circuit-id"
                                            self._segment_path = lambda: "format-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType, [], name, value)


                                        class CircuitId(Entity):
                                            """
                                            Circuit id option 82 format
                                            
                                            .. attribute:: string
                                            
                                            	User defined string for circuit id
                                            	**type**\: str
                                            
                                            	**length:** 3..63
                                            
                                            

                                            """

                                            _prefix = 'ios-dhcp'
                                            _revision = '2018-06-16'

                                            def __init__(self):
                                                super(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, self).__init__()

                                                self.yang_name = "circuit-id"
                                                self.yang_parent_name = "format-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ])
                                                self.string = None
                                                self._segment_path = lambda: "circuit-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Interface.Vasiright.Ip.Dhcp.Snooping.Vlan.Information.Option.FormatType.CircuitId, ['string'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: eigrp
                    
                    	
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.SummaryAddress.Eigrp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Interface.Vasiright.Ip.SummaryAddress.Eigrp))])
                        self._leafs = OrderedDict()

                        self.eigrp = YList(self)
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.SummaryAddress, [], name, value)


                    class Eigrp(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.SummaryAddress.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.id = None
                            self.ip = None
                            self.mask = None
                            self.metric = None
                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.SummaryAddress.Eigrp, [u'id', u'ip', u'mask', u'metric'], name, value)


                class Verify(Entity):
                    """
                    Enable per packet validation
                    
                    .. attribute:: source
                    
                    	Validation of source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Verify.Source>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unicast
                    
                    	Enable per packet validation for unicast
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Verify.Unicast>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Verify, self).__init__()

                        self.yang_name = "verify"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Interface.Vasiright.Ip.Verify.Source)), ("unicast", ("unicast", Native.Interface.Vasiright.Ip.Verify.Unicast))])
                        self._leafs = OrderedDict()

                        self.source = None
                        self._children_name_map["source"] = "source"

                        self.unicast = Native.Interface.Vasiright.Ip.Verify.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"
                        self._segment_path = lambda: "verify"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.Verify, [], name, value)


                    class Source(Entity):
                        """
                        Validation of source address
                        
                        .. attribute:: vlan
                        
                        	vlan specification
                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Verify.Source.Vlan>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Verify.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Interface.Vasiright.Ip.Verify.Source.Vlan))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.vlan = Native.Interface.Vasiright.Ip.Verify.Source.Vlan()
                            self.vlan.parent = self
                            self._children_name_map["vlan"] = "vlan"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Verify.Source, [], name, value)


                        class Vlan(Entity):
                            """
                            vlan specification
                            
                            .. attribute:: dhcp_snooping
                            
                            	snooping enable vlan
                            	**type**\:  :py:class:`DhcpSnooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Verify.Source.Vlan.DhcpSnooping>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Verify.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-snooping", ("dhcp_snooping", Native.Interface.Vasiright.Ip.Verify.Source.Vlan.DhcpSnooping))])
                                self._leafs = OrderedDict()

                                self.dhcp_snooping = None
                                self._children_name_map["dhcp_snooping"] = "dhcp-snooping"
                                self._segment_path = lambda: "vlan"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Verify.Source.Vlan, [], name, value)


                            class DhcpSnooping(Entity):
                                """
                                snooping enable vlan
                                
                                .. attribute:: port_security
                                
                                	port security
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Ip.Verify.Source.Vlan.DhcpSnooping, self).__init__()

                                    self.yang_name = "dhcp-snooping"
                                    self.yang_parent_name = "vlan"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('port_security', (YLeaf(YType.empty, 'port-security'), ['Empty'])),
                                    ])
                                    self.port_security = None
                                    self._segment_path = lambda: "dhcp-snooping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Ip.Verify.Source.Vlan.DhcpSnooping, [u'port_security'], name, value)


                    class Unicast(Entity):
                        """
                        Enable per packet validation for unicast
                        
                        .. attribute:: reverse_path
                        
                        	Reverse path validation of source address (old command format)
                        	**type**\:  :py:class:`ReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Verify.Unicast.ReversePath>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: source
                        
                        	Validation of source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Verify.Unicast.Source>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Verify.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "verify"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reverse-path", ("reverse_path", Native.Interface.Vasiright.Ip.Verify.Unicast.ReversePath)), ("source", ("source", Native.Interface.Vasiright.Ip.Verify.Unicast.Source))])
                            self._leafs = OrderedDict()

                            self.reverse_path = None
                            self._children_name_map["reverse_path"] = "reverse-path"

                            self.source = Native.Interface.Vasiright.Ip.Verify.Unicast.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Verify.Unicast, [], name, value)


                        class ReversePath(Entity):
                            """
                            Reverse path validation of source address (old command format)
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Verify.Unicast.ReversePath, self).__init__()

                                self.yang_name = "reverse-path"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-path"
                                self._is_frozen = True


                        class Source(Entity):
                            """
                            Validation of source address
                            
                            .. attribute:: reachable_via
                            
                            	Specify reachability check to apply to the source address
                            	**type**\:  :py:class:`ReachableVia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Verify.Unicast.Source.ReachableVia>`
                            
                            .. attribute:: allow_self_ping
                            
                            	Allow router to ping itself (opens vulnerability in verification)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allow_default
                            
                            	Allow default route to match when checking source address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Verify.Unicast.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reachable_via', (YLeaf(YType.enumeration, 'reachable-via'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Ip.Verify.Unicast.Source.ReachableVia')])),
                                    ('allow_self_ping', (YLeaf(YType.empty, 'allow-self-ping'), ['Empty'])),
                                    ('allow_default', (YLeaf(YType.empty, 'allow-default'), ['Empty'])),
                                ])
                                self.reachable_via = None
                                self.allow_self_ping = None
                                self.allow_default = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Verify.Unicast.Source, [u'reachable_via', u'allow_self_ping', u'allow_default'], name, value)

                            class ReachableVia(Enum):
                                """
                                ReachableVia (Enum Class)

                                Specify reachability check to apply to the source address

                                .. data:: any = 0

                                .. data:: rx = 1

                                """

                                any = Enum.YLeaf(0, "any")

                                rx = Enum.YLeaf(1, "rx")



                class Wccp(Entity):
                    """
                    WCCP IPv4 interface commands
                    
                    .. attribute:: wccp_list
                    
                    	
                    	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp.WccpList>`
                    
                    .. attribute:: web_cache
                    
                    	Standard web caching service
                    	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp.WebCache>`
                    
                    .. attribute:: redirect
                    
                    	Set packet redirection options
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp.Redirect>`
                    
                    .. attribute:: vrf
                    
                    	Configure WCCP for a VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-wccp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ip.Wccp, self).__init__()

                        self.yang_name = "wccp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.Vasiright.Ip.Wccp.WccpList)), ("web-cache", ("web_cache", Native.Interface.Vasiright.Ip.Wccp.WebCache)), ("redirect", ("redirect", Native.Interface.Vasiright.Ip.Wccp.Redirect)), ("vrf", ("vrf", Native.Interface.Vasiright.Ip.Wccp.Vrf))])
                        self._leafs = OrderedDict()

                        self.web_cache = Native.Interface.Vasiright.Ip.Wccp.WebCache()
                        self.web_cache.parent = self
                        self._children_name_map["web_cache"] = "web-cache"

                        self.redirect = Native.Interface.Vasiright.Ip.Wccp.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.wccp_list = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "Cisco-IOS-XE-wccp:wccp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp, [], name, value)


                    class WccpList(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..254
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp.WccpList.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Wccp.WccpList, self).__init__()

                            self.yang_name = "wccp-list"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Vasiright.Ip.Wccp.WccpList.Redirect))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.id = None
                            self.group_listen = None

                            self.redirect = Native.Interface.Vasiright.Ip.Wccp.WccpList.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp.WccpList, ['id', 'group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Wccp.WccpList.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "wccp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp.WccpList.Redirect, ['in_', 'out'], name, value)


                    class WebCache(Entity):
                        """
                        Standard web caching service
                        
                        .. attribute:: group_listen
                        
                        	Listen for multicasted WCCP protocol packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redirect
                        
                        	Set packet redirection options for the service
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp.WebCache.Redirect>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Wccp.WebCache, self).__init__()

                            self.yang_name = "web-cache"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Vasiright.Ip.Wccp.WebCache.Redirect))])
                            self._leafs = OrderedDict([
                                ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                            ])
                            self.group_listen = None

                            self.redirect = Native.Interface.Vasiright.Ip.Wccp.WebCache.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"
                            self._segment_path = lambda: "web-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp.WebCache, ['group_listen'], name, value)


                        class Redirect(Entity):
                            """
                            Set packet redirection options for the service
                            
                            .. attribute:: in_
                            
                            	Redirect to a Cache Engine appropriate inbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Redirect to a Cache Engine appropriate outbound packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Wccp.WebCache.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "web-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "redirect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp.WebCache.Redirect, ['in_', 'out'], name, value)


                    class Redirect(Entity):
                        """
                        Set packet redirection options
                        
                        .. attribute:: exclude
                        
                        	Exclude packets from redirection
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp.Redirect.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Wccp.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exclude", ("exclude", Native.Interface.Vasiright.Ip.Wccp.Redirect.Exclude))])
                            self._leafs = OrderedDict()

                            self.exclude = Native.Interface.Vasiright.Ip.Wccp.Redirect.Exclude()
                            self.exclude.parent = self
                            self._children_name_map["exclude"] = "exclude"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp.Redirect, [], name, value)


                        class Exclude(Entity):
                            """
                            Exclude packets from redirection
                            
                            .. attribute:: in_
                            
                            	Exclude inbound packets from outbound redirection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Wccp.Redirect.Exclude, self).__init__()

                                self.yang_name = "exclude"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.in_ = None
                                self._segment_path = lambda: "exclude"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp.Redirect.Exclude, ['in_'], name, value)


                    class Vrf(Entity):
                        """
                        Configure WCCP for a VRF
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: wccp_list
                        
                        	
                        	**type**\: list of  		 :py:class:`WccpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp.Vrf.WccpList>`
                        
                        .. attribute:: web_cache
                        
                        	Standard web caching service
                        	**type**\:  :py:class:`WebCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp.Vrf.WebCache>`
                        
                        

                        """

                        _prefix = 'ios-wccp'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ip.Wccp.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "wccp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("wccp-list", ("wccp_list", Native.Interface.Vasiright.Ip.Wccp.Vrf.WccpList)), ("web-cache", ("web_cache", Native.Interface.Vasiright.Ip.Wccp.Vrf.WebCache))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.web_cache = Native.Interface.Vasiright.Ip.Wccp.Vrf.WebCache()
                            self.web_cache.parent = self
                            self._children_name_map["web_cache"] = "web-cache"

                            self.wccp_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp.Vrf, ['name'], name, value)


                        class WccpList(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..254
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp.Vrf.WccpList.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Wccp.Vrf.WccpList, self).__init__()

                                self.yang_name = "wccp-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Vasiright.Ip.Wccp.Vrf.WccpList.Redirect))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.id = None
                                self.group_listen = None

                                self.redirect = Native.Interface.Vasiright.Ip.Wccp.Vrf.WccpList.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "wccp-list" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp.Vrf.WccpList, ['id', 'group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Ip.Wccp.Vrf.WccpList.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "wccp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp.Vrf.WccpList.Redirect, ['in_', 'out'], name, value)


                        class WebCache(Entity):
                            """
                            Standard web caching service
                            
                            .. attribute:: group_listen
                            
                            	Listen for multicasted WCCP protocol packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redirect
                            
                            	Set packet redirection options for the service
                            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ip.Wccp.Vrf.WebCache.Redirect>`
                            
                            

                            """

                            _prefix = 'ios-wccp'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ip.Wccp.Vrf.WebCache, self).__init__()

                                self.yang_name = "web-cache"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redirect", ("redirect", Native.Interface.Vasiright.Ip.Wccp.Vrf.WebCache.Redirect))])
                                self._leafs = OrderedDict([
                                    ('group_listen', (YLeaf(YType.empty, 'group-listen'), ['Empty'])),
                                ])
                                self.group_listen = None

                                self.redirect = Native.Interface.Vasiright.Ip.Wccp.Vrf.WebCache.Redirect()
                                self.redirect.parent = self
                                self._children_name_map["redirect"] = "redirect"
                                self._segment_path = lambda: "web-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp.Vrf.WebCache, ['group_listen'], name, value)


                            class Redirect(Entity):
                                """
                                Set packet redirection options for the service
                                
                                .. attribute:: in_
                                
                                	Redirect to a Cache Engine appropriate inbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Redirect to a Cache Engine appropriate outbound packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-wccp'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Ip.Wccp.Vrf.WebCache.Redirect, self).__init__()

                                    self.yang_name = "redirect"
                                    self.yang_parent_name = "web-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "redirect"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Ip.Wccp.Vrf.WebCache.Redirect, ['in_', 'out'], name, value)


            class Ipv6(Entity):
                """
                IPv6 interface subcommands
                
                .. attribute:: destination_guard
                
                	Configure ipv6 destination guard on the interface
                	**type**\:  :py:class:`DestinationGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.DestinationGuard>`
                
                	**presence node**\: True
                
                .. attribute:: source_guard
                
                	Configure ipv6 source guard on the interface
                	**type**\:  :py:class:`SourceGuard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.SourceGuard>`
                
                	**presence node**\: True
                
                .. attribute:: dhcp
                
                	IPv6 DHCP interface subcommands
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Dhcp>`
                
                .. attribute:: address
                
                	Configure IPv6 address on interface
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Address>`
                
                .. attribute:: unnumbered
                
                	Preferred interface for source address selection
                	**type**\: str
                
                .. attribute:: enable
                
                	Enable IPv6 on interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mtu
                
                	Set IPv6 Maximum Transmission Unit
                	**type**\: int
                
                	**range:** 1280..9216
                
                .. attribute:: nd
                
                	IPv6 interface Neighbor Discovery subcommands
                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Nd>`
                
                .. attribute:: redirects
                
                	Enable sending ICMP Redirect messages
                	**type**\: bool
                
                .. attribute:: tcp
                
                	TCP header compression and other parameters
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Tcp>`
                
                .. attribute:: traffic_filter
                
                	Access control list for packets
                	**type**\: list of  		 :py:class:`TrafficFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.TrafficFilter>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination-guard", ("destination_guard", Native.Interface.Vasiright.Ipv6.DestinationGuard)), ("source-guard", ("source_guard", Native.Interface.Vasiright.Ipv6.SourceGuard)), ("dhcp", ("dhcp", Native.Interface.Vasiright.Ipv6.Dhcp)), ("address", ("address", Native.Interface.Vasiright.Ipv6.Address)), ("nd", ("nd", Native.Interface.Vasiright.Ipv6.Nd)), ("tcp", ("tcp", Native.Interface.Vasiright.Ipv6.Tcp)), ("traffic-filter", ("traffic_filter", Native.Interface.Vasiright.Ipv6.TrafficFilter))])
                    self._leafs = OrderedDict([
                        ('unnumbered', (YLeaf(YType.str, 'unnumbered'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                        ('redirects', (YLeaf(YType.boolean, 'redirects'), ['bool'])),
                    ])
                    self.unnumbered = None
                    self.enable = None
                    self.mtu = None
                    self.redirects = None

                    self.destination_guard = None
                    self._children_name_map["destination_guard"] = "destination-guard"

                    self.source_guard = None
                    self._children_name_map["source_guard"] = "source-guard"

                    self.dhcp = Native.Interface.Vasiright.Ipv6.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"

                    self.address = Native.Interface.Vasiright.Ipv6.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.nd = Native.Interface.Vasiright.Ipv6.Nd()
                    self.nd.parent = self
                    self._children_name_map["nd"] = "nd"

                    self.tcp = Native.Interface.Vasiright.Ipv6.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.traffic_filter = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Ipv6, [u'unnumbered', u'enable', u'mtu', u'redirects'], name, value)


                class DestinationGuard(Entity):
                    """
                    Configure ipv6 destination guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 destguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ipv6.DestinationGuard, self).__init__()

                        self.yang_name = "destination-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "destination-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ipv6.DestinationGuard, [u'attach_policy'], name, value)


                class SourceGuard(Entity):
                    """
                    Configure ipv6 source guard on the interface
                    
                    .. attribute:: attach_policy
                    
                    	Apply a policy for feature ipv6 sourceguard
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ipv6.SourceGuard, self).__init__()

                        self.yang_name = "source-guard"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                        ])
                        self.attach_policy = None
                        self._segment_path = lambda: "source-guard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ipv6.SourceGuard, [u'attach_policy'], name, value)


                class Dhcp(Entity):
                    """
                    IPv6 DHCP interface subcommands
                    
                    .. attribute:: client
                    
                    	Act as an IPv6 DHCP client
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Dhcp.Client>`
                    
                    .. attribute:: server
                    
                    	Act as an IPv6 DHCP server
                    	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Dhcp.Server>`
                    
                    .. attribute:: guard
                    
                    	Configure IPv6 DHCP guard on the interface
                    	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Dhcp.Guard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ipv6.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-dhcp:client", ("client", Native.Interface.Vasiright.Ipv6.Dhcp.Client)), ("Cisco-IOS-XE-dhcp:server", ("server", Native.Interface.Vasiright.Ipv6.Dhcp.Server)), ("Cisco-IOS-XE-dhcp:guard", ("guard", Native.Interface.Vasiright.Ipv6.Dhcp.Guard))])
                        self._leafs = OrderedDict()

                        self.client = Native.Interface.Vasiright.Ipv6.Dhcp.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "Cisco-IOS-XE-dhcp:client"

                        self.guard = None
                        self._children_name_map["guard"] = "Cisco-IOS-XE-dhcp:guard"

                        self.server = YList(self)
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ipv6.Dhcp, [], name, value)


                    class Client(Entity):
                        """
                        Act as an IPv6 DHCP client
                        
                        .. attribute:: request
                        
                        	Request
                        	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Dhcp.Client.Request>`
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ipv6.Dhcp.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Native.Interface.Vasiright.Ipv6.Dhcp.Client.Request))])
                            self._leafs = OrderedDict()

                            self.request = Native.Interface.Vasiright.Ipv6.Dhcp.Client.Request()
                            self.request.parent = self
                            self._children_name_map["request"] = "request"
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ipv6.Dhcp.Client, [], name, value)


                        class Request(Entity):
                            """
                            Request
                            
                            .. attribute:: vendor
                            
                            	Request Vendor specific options
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-dhcp'
                            _revision = '2018-06-16'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ipv6.Dhcp.Client.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.empty, 'vendor'), ['Empty'])),
                                ])
                                self.vendor = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ipv6.Dhcp.Client.Request, ['vendor'], name, value)


                    class Server(Entity):
                        """
                        Act as an IPv6 DHCP server
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Preference
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ipv6.Dhcp.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                            ])
                            self.word = None
                            self.preference = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:server" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ipv6.Dhcp.Server, ['word', 'preference'], name, value)


                    class Guard(Entity):
                        """
                        Configure IPv6 DHCP guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature DHCP Guard
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-dhcp'
                        _revision = '2018-06-16'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ipv6.Dhcp.Guard, self).__init__()

                            self.yang_name = "guard"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-dhcp:guard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ipv6.Dhcp.Guard, ['attach_policy'], name, value)


                class Address(Entity):
                    """
                    Configure IPv6 address on interface
                    
                    .. attribute:: dhcp
                    
                    	Obtain IPv6 address from DHCP server
                    	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Address.Dhcp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Address.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Address.PrefixList>`
                    
                    .. attribute:: link_local_address
                    
                    	
                    	**type**\: list of  		 :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Address.LinkLocalAddress>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ipv6.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Interface.Vasiright.Ipv6.Address.Dhcp)), ("autoconfig", ("autoconfig", Native.Interface.Vasiright.Ipv6.Address.Autoconfig)), ("prefix-list", ("prefix_list", Native.Interface.Vasiright.Ipv6.Address.PrefixList)), ("link-local-address", ("link_local_address", Native.Interface.Vasiright.Ipv6.Address.LinkLocalAddress))])
                        self._leafs = OrderedDict()

                        self.dhcp = None
                        self._children_name_map["dhcp"] = "dhcp"

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.prefix_list = YList(self)
                        self.link_local_address = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ipv6.Address, [], name, value)


                    class Dhcp(Entity):
                        """
                        Obtain IPv6 address from DHCP server
                        
                        .. attribute:: rapid_commit
                        
                        	rapid\-commit for prefix delegation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ipv6.Address.Dhcp, self).__init__()

                            self.yang_name = "dhcp"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rapid_commit', (YLeaf(YType.empty, 'rapid-commit'), ['Empty'])),
                            ])
                            self.rapid_commit = None
                            self._segment_path = lambda: "dhcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ipv6.Address.Dhcp, [u'rapid_commit'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ipv6.Address.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.default = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ipv6.Address.Autoconfig, [u'default'], name, value)


                    class PrefixList(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: anycast
                        
                        	Configure as an anycast
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: eui_64
                        
                        	Use eui\-64 interface identifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ipv6.Address.PrefixList, self).__init__()

                            self.yang_name = "prefix-list"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('anycast', (YLeaf(YType.empty, 'anycast'), ['Empty'])),
                                ('eui_64', (YLeaf(YType.empty, 'eui-64'), ['Empty'])),
                            ])
                            self.prefix = None
                            self.anycast = None
                            self.eui_64 = None
                            self._segment_path = lambda: "prefix-list" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ipv6.Address.PrefixList, [u'prefix', u'anycast', u'eui_64'], name, value)


                    class LinkLocalAddress(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: link_local
                        
                        	Use link\-local address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ipv6.Address.LinkLocalAddress, self).__init__()

                            self.yang_name = "link-local-address"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('link_local', (YLeaf(YType.empty, 'link-local'), ['Empty'])),
                            ])
                            self.address = None
                            self.link_local = None
                            self._segment_path = lambda: "link-local-address" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ipv6.Address.LinkLocalAddress, [u'address', u'link_local'], name, value)


                class Nd(Entity):
                    """
                    IPv6 interface Neighbor Discovery subcommands
                    
                    .. attribute:: raguard
                    
                    	Configure RA guard on the interface
                    	**type**\:  :py:class:`Raguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Nd.Raguard>`
                    
                    .. attribute:: autoconfig
                    
                    	Obtain address using autoconfiguration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Nd.Autoconfig>`
                    
                    .. attribute:: managed_config_flag
                    
                    	Use DHCP for IPv6 address configuration
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ra
                    
                    	IPv6 nd router alert configuration
                    	**type**\:  :py:class:`Ra <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Nd.Ra>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ipv6.Nd, self).__init__()

                        self.yang_name = "nd"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("Cisco-IOS-XE-nd:raguard", ("raguard", Native.Interface.Vasiright.Ipv6.Nd.Raguard)), ("Cisco-IOS-XE-nd:autoconfig", ("autoconfig", Native.Interface.Vasiright.Ipv6.Nd.Autoconfig)), ("Cisco-IOS-XE-nd:ra", ("ra", Native.Interface.Vasiright.Ipv6.Nd.Ra))])
                        self._leafs = OrderedDict([
                            ('managed_config_flag', (YLeaf(YType.empty, 'Cisco-IOS-XE-nd:managed-config-flag'), ['Empty'])),
                        ])
                        self.managed_config_flag = None

                        self.raguard = Native.Interface.Vasiright.Ipv6.Nd.Raguard()
                        self.raguard.parent = self
                        self._children_name_map["raguard"] = "Cisco-IOS-XE-nd:raguard"

                        self.autoconfig = Native.Interface.Vasiright.Ipv6.Nd.Autoconfig()
                        self.autoconfig.parent = self
                        self._children_name_map["autoconfig"] = "Cisco-IOS-XE-nd:autoconfig"

                        self.ra = Native.Interface.Vasiright.Ipv6.Nd.Ra()
                        self.ra.parent = self
                        self._children_name_map["ra"] = "Cisco-IOS-XE-nd:ra"
                        self._segment_path = lambda: "nd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ipv6.Nd, ['managed_config_flag'], name, value)


                    class Raguard(Entity):
                        """
                        Configure RA guard on the interface
                        
                        .. attribute:: attach_policy
                        
                        	Apply a policy for feature RA guard
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ipv6.Nd.Raguard, self).__init__()

                            self.yang_name = "raguard"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('attach_policy', (YLeaf(YType.str, 'attach-policy'), ['str'])),
                            ])
                            self.attach_policy = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:raguard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ipv6.Nd.Raguard, ['attach_policy'], name, value)


                    class Autoconfig(Entity):
                        """
                        Obtain address using autoconfiguration
                        
                        .. attribute:: default_route
                        
                        	Insert default route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: prefix
                        
                        	Insert auto\-configured prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ipv6.Nd.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                                ('prefix', (YLeaf(YType.empty, 'prefix'), ['Empty'])),
                            ])
                            self.default_route = None
                            self.prefix = None
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ipv6.Nd.Autoconfig, ['default_route', 'prefix'], name, value)


                    class Ra(Entity):
                        """
                        IPv6 nd router alert configuration
                        
                        .. attribute:: suppress
                        
                        	Suppress IPv6 router\-alert configuration
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.Nd.Ra.Suppress>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-nd'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Ipv6.Nd.Ra, self).__init__()

                            self.yang_name = "ra"
                            self.yang_parent_name = "nd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Interface.Vasiright.Ipv6.Nd.Ra.Suppress))])
                            self._leafs = OrderedDict()

                            self.suppress = None
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "Cisco-IOS-XE-nd:ra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Ipv6.Nd.Ra, [], name, value)


                        class Suppress(Entity):
                            """
                            Suppress IPv6 router\-alert configuration
                            
                            .. attribute:: all
                            
                            	Suppress all IPv6 RA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-nd'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Ipv6.Nd.Ra.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "ra"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ])
                                self.all = None
                                self._segment_path = lambda: "suppress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Ipv6.Nd.Ra.Suppress, ['all'], name, value)


                class Tcp(Entity):
                    """
                    TCP header compression and other parameters
                    
                    .. attribute:: adjust_mss
                    
                    	Adjust the mss of transit packets
                    	**type**\: int
                    
                    	**range:** 40..1454
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ipv6.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('adjust_mss', (YLeaf(YType.uint16, 'adjust-mss'), ['int'])),
                        ])
                        self.adjust_mss = None
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ipv6.Tcp, [u'adjust_mss'], name, value)


                class TrafficFilter(Entity):
                    """
                    Access control list for packets
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Ipv6.TrafficFilter.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Ipv6.TrafficFilter, self).__init__()

                        self.yang_name = "traffic-filter"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Ipv6.TrafficFilter.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self._segment_path = lambda: "traffic-filter" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Ipv6.TrafficFilter, [u'direction', u'access_list'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Configure logging for interface
                
                .. attribute:: event
                
                	Interface events
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Logging.Event>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event", ("event", Native.Interface.Vasiright.Logging.Event))])
                    self._leafs = OrderedDict()

                    self.event = Native.Interface.Vasiright.Logging.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Logging, [], name, value)


                class Event(Entity):
                    """
                    Interface events
                    
                    .. attribute:: bundle_status
                    
                    	BUNDLE/UNBUNDLE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_status
                    
                    	UPDOWN and CHANGE messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trunk_status
                    
                    	TRUNK status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nfas_status
                    
                    	NFAS D\-channel status messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power_inline_status
                    
                    	Inline power messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: status
                    
                    	Spanning\-tree state change messages
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spanning_tree
                    
                    	Spanning\-tree Interface events
                    	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Logging.Event.SpanningTree>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: subif_link_status
                    
                    	Sub\-interface UPDOWN and CHANGE messages
                    	**type**\:  :py:class:`SubifLinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Logging.Event.SubifLinkStatus>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Logging.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spanning-tree", ("spanning_tree", Native.Interface.Vasiright.Logging.Event.SpanningTree)), ("subif-link-status", ("subif_link_status", Native.Interface.Vasiright.Logging.Event.SubifLinkStatus))])
                        self._leafs = OrderedDict([
                            ('bundle_status', (YLeaf(YType.empty, 'bundle-status'), ['Empty'])),
                            ('link_status', (YLeaf(YType.empty, 'link-status'), ['Empty'])),
                            ('trunk_status', (YLeaf(YType.empty, 'trunk-status'), ['Empty'])),
                            ('nfas_status', (YLeaf(YType.empty, 'nfas-status'), ['Empty'])),
                            ('power_inline_status', (YLeaf(YType.empty, 'power-inline-status'), ['Empty'])),
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.bundle_status = None
                        self.link_status = None
                        self.trunk_status = None
                        self.nfas_status = None
                        self.power_inline_status = None
                        self.status = None

                        self.spanning_tree = None
                        self._children_name_map["spanning_tree"] = "spanning-tree"

                        self.subif_link_status = None
                        self._children_name_map["subif_link_status"] = "subif-link-status"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Logging.Event, [u'bundle_status', u'link_status', u'trunk_status', u'nfas_status', u'power_inline_status', u'status'], name, value)


                    class SpanningTree(Entity):
                        """
                        Spanning\-tree Interface events
                        
                        .. attribute:: status
                        
                        	Spanning\-tree state change messages
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Logging.Event.SpanningTree, self).__init__()

                            self.yang_name = "spanning-tree"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "spanning-tree"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Logging.Event.SpanningTree, [u'status'], name, value)


                    class SubifLinkStatus(Entity):
                        """
                        Sub\-interface UPDOWN and CHANGE messages
                        
                        .. attribute:: ignore_bulk
                        
                        	Do not log messages when the main interface is transitioning
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Logging.Event.SubifLinkStatus, self).__init__()

                            self.yang_name = "subif-link-status"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ignore_bulk', (YLeaf(YType.empty, 'ignore-bulk'), ['Empty'])),
                            ])
                            self.ignore_bulk = None
                            self._segment_path = lambda: "subif-link-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Logging.Event.SubifLinkStatus, [u'ignore_bulk'], name, value)


            class Mdix(Entity):
                """
                Set Media Dependent Interface with Crossover
                
                .. attribute:: auto
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Mdix, self).__init__()

                    self.yang_name = "mdix"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('auto', (YLeaf(YType.boolean, 'auto'), ['bool'])),
                    ])
                    self.auto = None
                    self._segment_path = lambda: "mdix"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Mdix, [u'auto'], name, value)


            class Mop(Entity):
                """
                
                
                .. attribute:: enabled
                
                	
                	**type**\: bool
                
                .. attribute:: sysid
                
                	Send out MOP periodic system ID messages
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Mop, self).__init__()

                    self.yang_name = "mop"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('sysid', (YLeaf(YType.boolean, 'sysid'), ['bool'])),
                    ])
                    self.enabled = None
                    self.sysid = None
                    self._segment_path = lambda: "mop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Mop, [u'enabled', u'sysid'], name, value)


            class InterfaceQos(Entity):
                """
                
                
                .. attribute:: trust
                
                	
                	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.InterfaceQos.Trust>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.InterfaceQos, self).__init__()

                    self.yang_name = "interface_qos"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trust", ("trust", Native.Interface.Vasiright.InterfaceQos.Trust))])
                    self._leafs = OrderedDict()

                    self.trust = Native.Interface.Vasiright.InterfaceQos.Trust()
                    self.trust.parent = self
                    self._children_name_map["trust"] = "trust"
                    self._segment_path = lambda: "interface_qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.InterfaceQos, [], name, value)


                class Trust(Entity):
                    """
                    
                    
                    .. attribute:: device
                    
                    	
                    	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.InterfaceQos.Trust.Device>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.InterfaceQos.Trust, self).__init__()

                        self.yang_name = "trust"
                        self.yang_parent_name = "interface_qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.InterfaceQos.Trust.Device')])),
                        ])
                        self.device = None
                        self._segment_path = lambda: "trust"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.InterfaceQos.Trust, [u'device'], name, value)

                    class Device(Enum):
                        """
                        Device (Enum Class)

                        .. data:: cisco_phone = 0

                        """

                        cisco_phone = Enum.YLeaf(0, "cisco-phone")



            class Source(Entity):
                """
                Get config from another source
                
                .. attribute:: template
                
                	Get config from a template
                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Source.Template>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.Interface.Vasiright.Source.Template))])
                    self._leafs = OrderedDict()

                    self.template = Native.Interface.Vasiright.Source.Template()
                    self.template.parent = self
                    self._children_name_map["template"] = "template"
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Source, [], name, value)


                class Template(Entity):
                    """
                    Get config from a template
                    
                    .. attribute:: template_name
                    
                    	
                    	**type**\: list of  		 :py:class:`TemplateName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Source.Template.TemplateName>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Source.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("template-name", ("template_name", Native.Interface.Vasiright.Source.Template.TemplateName))])
                        self._leafs = OrderedDict()

                        self.template_name = YList(self)
                        self._segment_path = lambda: "template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Source.Template, [], name, value)


                    class TemplateName(Entity):
                        """
                        
                        
                        .. attribute:: template_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: merge
                        
                        	merge option of binding
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Source.Template.TemplateName, self).__init__()

                            self.yang_name = "template-name"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['template_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('template_name', (YLeaf(YType.str, 'template-name'), ['str'])),
                                ('merge', (YLeaf(YType.empty, 'merge'), ['Empty'])),
                            ])
                            self.template_name = None
                            self.merge = None
                            self._segment_path = lambda: "template-name" + "[template-name='" + str(self.template_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Source.Template.TemplateName, [u'template_name', u'merge'], name, value)


            class Standby(Entity):
                """
                HSRP interface configuration commands
                
                .. attribute:: version
                
                	HSRP version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.Version>`
                
                .. attribute:: bfd
                
                	Enable HSRP BFD
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay
                
                	HSRP initialisation delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.Delay>`
                
                .. attribute:: mac_refresh
                
                	Refresh MAC cache on switch by periodically sending packet from virtual mac address
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: use_bia
                
                	HSRP uses interface's burned in address
                	**type**\:  :py:class:`UseBia <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.UseBia>`
                
                	**presence node**\: True
                
                .. attribute:: standby_list
                
                	
                	**type**\: list of  		 :py:class:`StandbyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vasiright.Standby.Delay)), ("use-bia", ("use_bia", Native.Interface.Vasiright.Standby.UseBia)), ("standby-list", ("standby_list", Native.Interface.Vasiright.Standby.StandbyList))])
                    self._leafs = OrderedDict([
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.Version')])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('mac_refresh', (YLeaf(YType.uint8, 'mac-refresh'), ['int'])),
                    ])
                    self.version = None
                    self.bfd = None
                    self.mac_refresh = None

                    self.delay = Native.Interface.Vasiright.Standby.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.use_bia = None
                    self._children_name_map["use_bia"] = "use-bia"

                    self.standby_list = YList(self)
                    self._segment_path = lambda: "standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Standby, [u'version', u'bfd', u'mac_refresh'], name, value)

                class Version(Enum):
                    """
                    Version (Enum Class)

                    HSRP version

                    .. data:: Y_1 = 0

                    .. data:: Y_2 = 1

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_2 = Enum.YLeaf(1, "2")



                class Delay(Entity):
                    """
                    HSRP initialisation delay
                    
                    .. attribute:: minimum
                    
                    	Minimum delay
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    .. attribute:: reload
                    
                    	Delay after reload
                    	**type**\: int
                    
                    	**range:** 0..10000
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Standby.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                            ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                        ])
                        self.minimum = None
                        self.reload = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Standby.Delay, [u'minimum', u'reload'], name, value)


                class UseBia(Entity):
                    """
                    HSRP uses interface's burned in address
                    
                    .. attribute:: scope
                    
                    	Specify the scope of use\-bia
                    	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.UseBia.Scope>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Standby.UseBia, self).__init__()

                        self.yang_name = "use-bia"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("scope", ("scope", Native.Interface.Vasiright.Standby.UseBia.Scope))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.scope = Native.Interface.Vasiright.Standby.UseBia.Scope()
                        self.scope.parent = self
                        self._children_name_map["scope"] = "scope"
                        self._segment_path = lambda: "use-bia"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Standby.UseBia, [], name, value)


                    class Scope(Entity):
                        """
                        Specify the scope of use\-bia
                        
                        .. attribute:: interface
                        
                        	Use\-bia applies to all groups on this interface or sub\-interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Standby.UseBia.Scope, self).__init__()

                            self.yang_name = "scope"
                            self.yang_parent_name = "use-bia"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "scope"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Standby.UseBia.Scope, [u'interface'], name, value)


                class StandbyList(Entity):
                    """
                    
                    
                    .. attribute:: group_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Authentication>`
                    
                    .. attribute:: follow
                    
                    	Name of HSRP group to follow
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Enable HSRP and set the virtual IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	Enable HSRP IPv6
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    		**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Ipv6>`
                    
                    .. attribute:: mac_address
                    
                    	Virtual MAC address
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Redundancy name string
                    	**type**\: str
                    
                    .. attribute:: preempt
                    
                    	Overthrow lower priority Active routers
                    	**type**\:  :py:class:`Preempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Preempt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: priority
                    
                    	Priority level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: redirect
                    
                    	Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                    	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Redirect>`
                    
                    .. attribute:: timers
                    
                    	Hello and hold timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Timers>`
                    
                    .. attribute:: track
                    
                    	Priority tracking
                    	**type**\: list of  		 :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Track>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Standby.StandbyList, self).__init__()

                        self.yang_name = "standby-list"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_number']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vasiright.Standby.StandbyList.Authentication)), ("ip", ("ip", Native.Interface.Vasiright.Standby.StandbyList.Ip)), ("preempt", ("preempt", Native.Interface.Vasiright.Standby.StandbyList.Preempt)), ("redirect", ("redirect", Native.Interface.Vasiright.Standby.StandbyList.Redirect)), ("timers", ("timers", Native.Interface.Vasiright.Standby.StandbyList.Timers)), ("track", ("track", Native.Interface.Vasiright.Standby.StandbyList.Track))])
                        self._leafs = OrderedDict([
                            ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                            ('follow', (YLeaf(YType.str, 'follow'), ['str'])),
                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Ipv6')])),
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.group_number = None
                        self.follow = None
                        self.ipv6 = None
                        self.mac_address = None
                        self.name = None
                        self.priority = None

                        self.authentication = Native.Interface.Vasiright.Standby.StandbyList.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"

                        self.preempt = None
                        self._children_name_map["preempt"] = "preempt"

                        self.redirect = Native.Interface.Vasiright.Standby.StandbyList.Redirect()
                        self.redirect.parent = self
                        self._children_name_map["redirect"] = "redirect"

                        self.timers = Native.Interface.Vasiright.Standby.StandbyList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.track = YList(self)
                        self._segment_path = lambda: "standby-list" + "[group-number='" + str(self.group_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList, [u'group_number', u'follow', u'ipv6', u'mac_address', u'name', u'priority'], name, value)

                    class Ipv6(Enum):
                        """
                        Ipv6 (Enum Class)

                        Enable HSRP IPv6

                        .. data:: autoconfig = 0

                        """

                        autoconfig = Enum.YLeaf(0, "autoconfig")



                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: word
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: md5
                        
                        	Use MD5 authentication
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Authentication.Md5>`
                        
                        .. attribute:: text
                        
                        	Plain text authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Standby.StandbyList.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Vasiright.Standby.StandbyList.Authentication.Md5))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.word = None
                            self.text = None

                            self.md5 = Native.Interface.Vasiright.Standby.StandbyList.Authentication.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Authentication, [u'word', u'text'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 authentication
                            
                            .. attribute:: key_chain
                            
                            	Set key chain
                            	**type**\: str
                            
                            .. attribute:: key_string
                            
                            	Set key string
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Authentication.Md5.KeyString>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Standby.StandbyList.Authentication.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Vasiright.Standby.StandbyList.Authentication.Md5.KeyString))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.key_string = Native.Interface.Vasiright.Standby.StandbyList.Authentication.Md5.KeyString()
                                self.key_string.parent = self
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Authentication.Md5, [u'key_chain'], name, value)


                            class KeyString(Entity):
                                """
                                Set key string
                                
                                .. attribute:: encrypt
                                
                                	
                                	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: timeout
                                
                                	Set timeout
                                	**type**\: int
                                
                                	**range:** 0..32767
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Standby.StandbyList.Authentication.Md5.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "md5"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Authentication.Md5.KeyString.Encrypt')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                        ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                    ])
                                    self.encrypt = None
                                    self.string = None
                                    self.timeout = None
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                class Encrypt(Enum):
                                    """
                                    Encrypt (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_7 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Enable HSRP and set the virtual IP address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Make this IP address a secondary virtual IP address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Standby.StandbyList.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                            ])
                            self.address = None
                            self.secondary = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Ip, [u'address', u'secondary'], name, value)


                    class Preempt(Entity):
                        """
                        Overthrow lower priority Active routers
                        
                        .. attribute:: delay
                        
                        	Wait before preempting
                        	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Preempt.Delay>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Standby.StandbyList.Preempt, self).__init__()

                            self.yang_name = "preempt"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("delay", ("delay", Native.Interface.Vasiright.Standby.StandbyList.Preempt.Delay))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.delay = Native.Interface.Vasiright.Standby.StandbyList.Preempt.Delay()
                            self.delay.parent = self
                            self._children_name_map["delay"] = "delay"
                            self._segment_path = lambda: "preempt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Preempt, [], name, value)


                        class Delay(Entity):
                            """
                            Wait before preempting
                            
                            .. attribute:: minimum
                            
                            	Delay at least this long
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: reload
                            
                            	Delay after reload
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: sync
                            
                            	Wait for IP redundancy client
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Standby.StandbyList.Preempt.Delay, self).__init__()

                                self.yang_name = "delay"
                                self.yang_parent_name = "preempt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('minimum', (YLeaf(YType.uint16, 'minimum'), ['int'])),
                                    ('reload', (YLeaf(YType.uint16, 'reload'), ['int'])),
                                    ('sync', (YLeaf(YType.uint16, 'sync'), ['int'])),
                                ])
                                self.minimum = None
                                self.reload = None
                                self.sync = None
                                self._segment_path = lambda: "delay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Preempt.Delay, [u'minimum', u'reload', u'sync'], name, value)


                    class Redirect(Entity):
                        """
                        Configure sending of ICMP Redirect messages with an HSRP virtual IP address as the gateway IP address
                        
                        .. attribute:: advertisement
                        
                        	Redirect advertisement messages
                        	**type**\:  :py:class:`Advertisement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement>`
                        
                        .. attribute:: timers
                        
                        	Adjust redirect timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Redirect.Timers>`
                        
                        .. attribute:: unknown
                        
                        	Redirect to non\-HSRP routers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Standby.StandbyList.Redirect, self).__init__()

                            self.yang_name = "redirect"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertisement", ("advertisement", Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement)), ("timers", ("timers", Native.Interface.Vasiright.Standby.StandbyList.Redirect.Timers))])
                            self._leafs = OrderedDict([
                                ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                            ])
                            self.unknown = None

                            self.advertisement = Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement()
                            self.advertisement.parent = self
                            self._children_name_map["advertisement"] = "advertisement"

                            self.timers = Native.Interface.Vasiright.Standby.StandbyList.Redirect.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._segment_path = lambda: "redirect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Redirect, [u'unknown'], name, value)


                        class Advertisement(Entity):
                            """
                            Redirect advertisement messages
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement, self).__init__()

                                self.yang_name = "advertisement"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication))])
                                self._leafs = OrderedDict()

                                self.authentication = Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "advertisement"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement, [], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: md5
                                
                                	Use MD5 authentication
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "advertisement"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5))])
                                    self._leafs = OrderedDict()

                                    self.md5 = Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication, [], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 authentication
                                    
                                    .. attribute:: key_chain
                                    
                                    	Set key chain
                                    	**type**\: str
                                    
                                    .. attribute:: key_string
                                    
                                    	Set key string
                                    	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-string", ("key_string", Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString))])
                                        self._leafs = OrderedDict([
                                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                        ])
                                        self.key_chain = None

                                        self.key_string = Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString()
                                        self.key_string.parent = self
                                        self._children_name_map["key_string"] = "key-string"
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5, [u'key_chain'], name, value)


                                    class KeyString(Entity):
                                        """
                                        Set key string
                                        
                                        .. attribute:: encrypt
                                        
                                        	
                                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt>`
                                        
                                        .. attribute:: string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: timeout
                                        
                                        	Set timeout
                                        	**type**\: int
                                        
                                        	**range:** 0..32767
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, self).__init__()

                                            self.yang_name = "key-string"
                                            self.yang_parent_name = "md5"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString.Encrypt')])),
                                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                            ])
                                            self.encrypt = None
                                            self.string = None
                                            self.timeout = None
                                            self._segment_path = lambda: "key-string"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Redirect.Advertisement.Authentication.Md5.KeyString, [u'encrypt', u'string', u'timeout'], name, value)

                                        class Encrypt(Enum):
                                            """
                                            Encrypt (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_7 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_7 = Enum.YLeaf(1, "7")



                        class Timers(Entity):
                            """
                            Adjust redirect timers
                            
                            .. attribute:: advertisement
                            
                            	
                            	**type**\: int
                            
                            	**range:** 10..180
                            
                            .. attribute:: holddown
                            
                            	
                            	**type**\: int
                            
                            	**range:** 30..3600
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Standby.StandbyList.Redirect.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "redirect"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('advertisement', (YLeaf(YType.uint16, 'advertisement'), ['int'])),
                                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                                ])
                                self.advertisement = None
                                self.holddown = None
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Redirect.Timers, [u'advertisement', u'holddown'], name, value)


                    class Timers(Entity):
                        """
                        Hello and hold timers
                        
                        .. attribute:: hello_interval
                        
                        	
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Timers.HelloInterval>`
                        
                        .. attribute:: hold_time
                        
                        	
                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Standby.StandbyList.Timers.HoldTime>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Standby.StandbyList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hello-interval", ("hello_interval", Native.Interface.Vasiright.Standby.StandbyList.Timers.HelloInterval)), ("hold-time", ("hold_time", Native.Interface.Vasiright.Standby.StandbyList.Timers.HoldTime))])
                            self._leafs = OrderedDict()

                            self.hello_interval = Native.Interface.Vasiright.Standby.StandbyList.Timers.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"

                            self.hold_time = Native.Interface.Vasiright.Standby.StandbyList.Timers.HoldTime()
                            self.hold_time.parent = self
                            self._children_name_map["hold_time"] = "hold-time"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Timers, [], name, value)


                        class HelloInterval(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            .. attribute:: msec
                            
                            	Specify hello interval in milliseconds
                            	**type**\: int
                            
                            	**range:** 15..999
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Standby.StandbyList.Timers.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Timers.HelloInterval, [u'seconds', u'msec'], name, value)


                        class HoldTime(Entity):
                            """
                            
                            
                            .. attribute:: seconds
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: msec
                            
                            	Specify hold time in milliseconds
                            	**type**\: int
                            
                            	**range:** 50..3000
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Standby.StandbyList.Timers.HoldTime, self).__init__()

                                self.yang_name = "hold-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                    ('msec', (YLeaf(YType.uint16, 'msec'), ['int'])),
                                ])
                                self.seconds = None
                                self.msec = None
                                self._segment_path = lambda: "hold-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Timers.HoldTime, [u'seconds', u'msec'], name, value)


                    class Track(Entity):
                        """
                        Priority tracking
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: decrement
                        
                        	Priority decrement
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: shutdown
                        
                        	Shutdown group
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Standby.StandbyList.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "standby-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                                ('decrement', (YLeaf(YType.uint8, 'decrement'), ['int'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.number = None
                            self.decrement = None
                            self.shutdown = None
                            self._segment_path = lambda: "track" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Standby.StandbyList.Track, [u'number', u'decrement', u'shutdown'], name, value)


            class AccessSession(Entity):
                """
                Access Session specific Interface Configuration Commands
                
                .. attribute:: closed
                
                	Enable closed access on port (disabled by default, i.e. open access)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_control
                
                	Set the port\-control value
                	**type**\:  :py:class:`PortControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.AccessSession.PortControl>`
                
                .. attribute:: control_direction
                
                	Set the control\-direction on the interface
                	**type**\:  :py:class:`ControlDirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.AccessSession.ControlDirection>`
                
                .. attribute:: host_mode
                
                	Set the Host mode for authentication on this interface
                	**type**\:  :py:class:`HostMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.AccessSession.HostMode>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.AccessSession, self).__init__()

                    self.yang_name = "access-session"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("port-control", ("port_control", Native.Interface.Vasiright.AccessSession.PortControl)), ("control-direction", ("control_direction", Native.Interface.Vasiright.AccessSession.ControlDirection))])
                    self._leafs = OrderedDict([
                        ('closed', (YLeaf(YType.empty, 'closed'), ['Empty'])),
                        ('host_mode', (YLeaf(YType.enumeration, 'host-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.AccessSession.HostMode')])),
                    ])
                    self.closed = None
                    self.host_mode = None

                    self.port_control = Native.Interface.Vasiright.AccessSession.PortControl()
                    self.port_control.parent = self
                    self._children_name_map["port_control"] = "port-control"

                    self.control_direction = Native.Interface.Vasiright.AccessSession.ControlDirection()
                    self.control_direction.parent = self
                    self._children_name_map["control_direction"] = "control-direction"
                    self._segment_path = lambda: "access-session"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.AccessSession, [u'closed', u'host_mode'], name, value)

                class HostMode(Enum):
                    """
                    HostMode (Enum Class)

                    Set the Host mode for authentication on this interface

                    .. data:: multi_auth = 0

                    .. data:: multi_domain = 1

                    .. data:: multi_host = 2

                    .. data:: single_host = 3

                    """

                    multi_auth = Enum.YLeaf(0, "multi-auth")

                    multi_domain = Enum.YLeaf(1, "multi-domain")

                    multi_host = Enum.YLeaf(2, "multi-host")

                    single_host = Enum.YLeaf(3, "single-host")



                class PortControl(Entity):
                    """
                    Set the port\-control value
                    
                    .. attribute:: auto
                    
                    	PortState set to automatic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.AccessSession.PortControl, self).__init__()

                        self.yang_name = "port-control"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                        ])
                        self.auto = None
                        self._segment_path = lambda: "port-control"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.AccessSession.PortControl, [u'auto'], name, value)


                class ControlDirection(Entity):
                    """
                    Set the control\-direction on the interface
                    
                    .. attribute:: in_
                    
                    	Control inbound traffic only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.AccessSession.ControlDirection, self).__init__()

                        self.yang_name = "control-direction"
                        self.yang_parent_name = "access-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                        ])
                        self.in_ = None
                        self._segment_path = lambda: "control-direction"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.AccessSession.ControlDirection, [u'in_'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: action
                
                	Action to take for storm..control;
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Action>`
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Multicast>`
                
                .. attribute:: unicast
                
                	Unicast address storm control
                	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Unicast>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("action", ("action", Native.Interface.Vasiright.StormControl.Action)), ("broadcast", ("broadcast", Native.Interface.Vasiright.StormControl.Broadcast)), ("multicast", ("multicast", Native.Interface.Vasiright.StormControl.Multicast)), ("unicast", ("unicast", Native.Interface.Vasiright.StormControl.Unicast))])
                    self._leafs = OrderedDict()

                    self.action = Native.Interface.Vasiright.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"

                    self.broadcast = Native.Interface.Vasiright.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Interface.Vasiright.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.unicast = Native.Interface.Vasiright.StormControl.Unicast()
                    self.unicast.parent = self
                    self._children_name_map["unicast"] = "unicast"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.StormControl, [], name, value)


                class Action(Entity):
                    """
                    Action to take for storm..control;
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\: Decimal64
                    
                    	**range:** 0..100
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.str, 'level'), ['Decimal64'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.level = None
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.StormControl.Action, [u'level', u'shutdown', u'trap'], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: include
                    
                    	
                    	**type**\:  :py:class:`Include <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Broadcast.Include>`
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("include", ("include", Native.Interface.Vasiright.StormControl.Broadcast.Include)), ("level", ("level", Native.Interface.Vasiright.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.include = Native.Interface.Vasiright.StormControl.Broadcast.Include()
                        self.include.parent = self
                        self._children_name_map["include"] = "include"

                        self.level = Native.Interface.Vasiright.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.StormControl.Broadcast, [], name, value)


                    class Include(Entity):
                        """
                        
                        
                        .. attribute:: multicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.StormControl.Broadcast.Include, self).__init__()

                            self.yang_name = "include"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('multicast', (YLeaf(YType.empty, 'multicast'), ['Empty'])),
                            ])
                            self.multicast = None
                            self._segment_path = lambda: "include"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.StormControl.Broadcast.Include, [u'multicast'], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Broadcast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Broadcast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vasiright.StormControl.Broadcast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vasiright.StormControl.Broadcast.Level.Bps)), ("pps", ("pps", Native.Interface.Vasiright.StormControl.Broadcast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vasiright.StormControl.Broadcast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vasiright.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vasiright.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.StormControl.Broadcast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.StormControl.Broadcast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.StormControl.Broadcast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.StormControl.Broadcast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.StormControl.Broadcast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Vasiright.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Vasiright.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Multicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Multicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vasiright.StormControl.Multicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vasiright.StormControl.Multicast.Level.Bps)), ("pps", ("pps", Native.Interface.Vasiright.StormControl.Multicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vasiright.StormControl.Multicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vasiright.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vasiright.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.StormControl.Multicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.StormControl.Multicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.StormControl.Multicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.StormControl.Multicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.StormControl.Multicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


                class Unicast(Entity):
                    """
                    Unicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Unicast.Level>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.StormControl.Unicast, self).__init__()

                        self.yang_name = "unicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Interface.Vasiright.StormControl.Unicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Interface.Vasiright.StormControl.Unicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.StormControl.Unicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: threshold
                        
                        	Broadcast address storm control
                        	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Unicast.Level.Threshold>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Unicast.Level.Bps>`
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.StormControl.Unicast.Level.Pps>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.StormControl.Unicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("threshold", ("threshold", Native.Interface.Vasiright.StormControl.Unicast.Level.Threshold)), ("bps", ("bps", Native.Interface.Vasiright.StormControl.Unicast.Level.Bps)), ("pps", ("pps", Native.Interface.Vasiright.StormControl.Unicast.Level.Pps))])
                            self._leafs = OrderedDict()

                            self.threshold = Native.Interface.Vasiright.StormControl.Unicast.Level.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"

                            self.bps = Native.Interface.Vasiright.StormControl.Unicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"

                            self.pps = Native.Interface.Vasiright.StormControl.Unicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.StormControl.Unicast.Level, [], name, value)


                        class Threshold(Entity):
                            """
                            Broadcast address storm control
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.StormControl.Unicast.Level.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['Decimal64'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['Decimal64'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.StormControl.Unicast.Level.Threshold, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]>
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g]> 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.StormControl.Unicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.StormControl.Unicast.Level.Bps, [u'rising_threshold', u'falling_threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: rising_threshold
                            
                            	Enter rising threshold \- <0.0 \- 10000000000.0>[k\|m\|g]
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            .. attribute:: falling_threshold
                            
                            	Enter falling threshold \- <0.0 \- 10000000000.0>[k\|m\|g] 
                            	**type**\: str
                            
                            	**pattern:** [0\-9]+.?[0\-9]\*[k\|m\|g]?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.StormControl.Unicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rising_threshold', (YLeaf(YType.str, 'rising-threshold'), ['str'])),
                                    ('falling_threshold', (YLeaf(YType.str, 'falling-threshold'), ['str'])),
                                ])
                                self.rising_threshold = None
                                self.falling_threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.StormControl.Unicast.Level.Pps, [u'rising_threshold', u'falling_threshold'], name, value)


            class Trust(Entity):
                """
                Set trust value for the interface
                
                .. attribute:: device
                
                	trusted device class
                	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Trust.Device>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Trust, self).__init__()

                    self.yang_name = "trust"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('device', (YLeaf(YType.enumeration, 'device'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.Trust.Device')])),
                    ])
                    self.device = None
                    self._segment_path = lambda: "trust"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Trust, [u'device'], name, value)

                class Device(Enum):
                    """
                    Device (Enum Class)

                    trusted device class

                    .. data:: cisco_phone = 0

                    .. data:: cts = 1

                    .. data:: ip_camera = 2

                    .. data:: media_player = 3

                    """

                    cisco_phone = Enum.YLeaf(0, "cisco-phone")

                    cts = Enum.YLeaf(1, "cts")

                    ip_camera = Enum.YLeaf(2, "ip-camera")

                    media_player = Enum.YLeaf(3, "media-player")



            class PriorityQueue(Entity):
                """
                Configure priority scheduling
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue
                	**type**\:  :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.PriorityQueue.CosMap>`
                
                .. attribute:: out
                
                	egress priority queue
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.PriorityQueue, self).__init__()

                    self.yang_name = "priority-queue"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Vasiright.PriorityQueue.CosMap))])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                    ])
                    self.out = None

                    self.cos_map = Native.Interface.Vasiright.PriorityQueue.CosMap()
                    self.cos_map.parent = self
                    self._children_name_map["cos_map"] = "cos-map"
                    self._segment_path = lambda: "priority-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.PriorityQueue, [u'out'], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.PriorityQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "priority-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.PriorityQueue.CosMap, [u'id', u'cos_values'], name, value)


            class RcvQueue(Entity):
                """
                Configure receive queue(s)
                
                .. attribute:: cos_map
                
                	Configure cos\-map for a queue threshold
                	**type**\: list of  		 :py:class:`CosMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.RcvQueue.CosMap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.RcvQueue, self).__init__()

                    self.yang_name = "rcv-queue"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cos-map", ("cos_map", Native.Interface.Vasiright.RcvQueue.CosMap))])
                    self._leafs = OrderedDict()

                    self.cos_map = YList(self)
                    self._segment_path = lambda: "rcv-queue"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.RcvQueue, [], name, value)


                class CosMap(Entity):
                    """
                    Configure cos\-map for a queue threshold
                    
                    .. attribute:: queue_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    .. attribute:: threshold_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..8
                    
                    .. attribute:: cos_values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.RcvQueue.CosMap, self).__init__()

                        self.yang_name = "cos-map"
                        self.yang_parent_name = "rcv-queue"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['queue_id','threshold_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('queue_id', (YLeaf(YType.uint8, 'queue-id'), ['int'])),
                            ('threshold_id', (YLeaf(YType.uint8, 'threshold-id'), ['int'])),
                            ('cos_values', (YLeafList(YType.uint8, 'cos-values'), ['int'])),
                        ])
                        self.queue_id = None
                        self.threshold_id = None
                        self.cos_values = []
                        self._segment_path = lambda: "cos-map" + "[queue-id='" + str(self.queue_id) + "']" + "[threshold-id='" + str(self.threshold_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.RcvQueue.CosMap, [u'queue_id', u'threshold_id', u'cos_values'], name, value)


            class Peer(Entity):
                """
                Peer parameters for point to point interfaces
                
                .. attribute:: default
                
                	Specify default parameters
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Peer.Default>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Interface.Vasiright.Peer.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Interface.Vasiright.Peer.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Peer, [], name, value)


                class Default(Entity):
                    """
                    Specify default parameters
                    
                    .. attribute:: ip
                    
                    	Specify default IP parameters
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Peer.Default.Ip>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Interface.Vasiright.Peer.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Interface.Vasiright.Peer.Default.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Interface.Vasiright.Peer.Default.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.Peer.Default, [], name, value)


                    class Ip(Entity):
                        """
                        Specify default IP parameters
                        
                        .. attribute:: address
                        
                        	Specify default IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Peer.Default.Ip.Address>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Interface.Vasiright.Peer.Default.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Interface.Vasiright.Peer.Default.Ip.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Interface.Vasiright.Peer.Default.Ip.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.Peer.Default.Ip, [], name, value)


                        class Address(Entity):
                            """
                            Specify default IP address
                            
                            .. attribute:: dhcp
                            
                            	Use DHCP proxy client mechanism to allocate a peer IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_pool
                            
                            	Use local DHCP pools to allocate a peer IP address
                            	**type**\:  :py:class:`DhcpPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Peer.Default.Ip.Address.DhcpPool>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: pool
                            
                            	Use IP pool mechanism to allocate a peer IP address
                            	**type**\:  :py:class:`Pool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.Peer.Default.Ip.Address.Pool>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Interface.Vasiright.Peer.Default.Ip.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dhcp-pool", ("dhcp_pool", Native.Interface.Vasiright.Peer.Default.Ip.Address.DhcpPool)), ("pool", ("pool", Native.Interface.Vasiright.Peer.Default.Ip.Address.Pool))])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None

                                self.dhcp_pool = None
                                self._children_name_map["dhcp_pool"] = "dhcp-pool"

                                self.pool = None
                                self._children_name_map["pool"] = "pool"
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.Peer.Default.Ip.Address, [u'dhcp'], name, value)


                            class DhcpPool(Entity):
                                """
                                Use local DHCP pools to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Peer.Default.Ip.Address.DhcpPool, self).__init__()

                                    self.yang_name = "dhcp-pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "dhcp-pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Peer.Default.Ip.Address.DhcpPool, [u'pools'], name, value)


                            class Pool(Entity):
                                """
                                Use IP pool mechanism to allocate a peer IP address
                                
                                .. attribute:: pools
                                
                                	
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Interface.Vasiright.Peer.Default.Ip.Address.Pool, self).__init__()

                                    self.yang_name = "pool"
                                    self.yang_parent_name = "address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pools', (YLeaf(YType.str, 'pools'), ['str'])),
                                    ])
                                    self.pools = None
                                    self._segment_path = lambda: "pool"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Interface.Vasiright.Peer.Default.Ip.Address.Pool, [u'pools'], name, value)


            class PmPath(Entity):
                """
                Global pm\-path configuration
                
                .. attribute:: name
                
                	WORD Path name
                	**type**\: str
                
                .. attribute:: interface_id
                
                	<1\-255> Specify the interface\-id value
                	**type**\: int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Interface.Vasiright.PmPath, self).__init__()

                    self.yang_name = "pm-path"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('interface_id', (YLeaf(YType.uint8, 'interface-id'), ['int'])),
                    ])
                    self.name = None
                    self.interface_id = None
                    self._segment_path = lambda: "pm-path"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.PmPath, [u'name', u'interface_id'], name, value)


            class ServicePolicy(Entity):
                """
                Configure QoS Service Policy
                
                .. attribute:: history
                
                	Keep history of QoS metrics
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\: str
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\: str
                
                .. attribute:: type
                
                	Configure CPL Service Policy
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vasiright.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Interface.Vasiright.ServicePolicy.Type))])
                    self._leafs = OrderedDict([
                        ('history', (YLeaf(YType.empty, 'history'), ['Empty'])),
                        ('input', (YLeaf(YType.str, 'input'), ['str'])),
                        ('output', (YLeaf(YType.str, 'output'), ['str'])),
                    ])
                    self.history = None
                    self.input = None
                    self.output = None

                    self.type = Native.Interface.Vasiright.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.ServicePolicy, ['history', 'input', 'output'], name, value)


                class Type(Entity):
                    """
                    Configure CPL Service Policy
                    
                    .. attribute:: control
                    
                    	
                    	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.ServicePolicy.Type.Control>`
                    
                    .. attribute:: performance_monitor
                    
                    	Configure media monitor service\-policy type
                    	**type**\:  :py:class:`PerformanceMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.ServicePolicy.Type.PerformanceMonitor>`
                    
                    .. attribute:: service_chain
                    
                    	Configure Service\-chain Service Policy
                    	**type**\:  :py:class:`ServiceChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Interface.Vasiright.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("control", ("control", Native.Interface.Vasiright.ServicePolicy.Type.Control)), ("performance-monitor", ("performance_monitor", Native.Interface.Vasiright.ServicePolicy.Type.PerformanceMonitor)), ("service-chain", ("service_chain", Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain))])
                        self._leafs = OrderedDict()

                        self.control = Native.Interface.Vasiright.ServicePolicy.Type.Control()
                        self.control.parent = self
                        self._children_name_map["control"] = "control"

                        self.performance_monitor = Native.Interface.Vasiright.ServicePolicy.Type.PerformanceMonitor()
                        self.performance_monitor.parent = self
                        self._children_name_map["performance_monitor"] = "performance-monitor"

                        self.service_chain = Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain()
                        self.service_chain.parent = self
                        self._children_name_map["service_chain"] = "service-chain"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Interface.Vasiright.ServicePolicy.Type, [], name, value)


                    class Control(Entity):
                        """
                        
                        
                        .. attribute:: subscriber
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vasiright.ServicePolicy.Type.Control, self).__init__()

                            self.yang_name = "control"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('subscriber', (YLeaf(YType.str, 'subscriber'), ['str'])),
                            ])
                            self.subscriber = None
                            self._segment_path = lambda: "control"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.ServicePolicy.Type.Control, ['subscriber'], name, value)


                    class PerformanceMonitor(Entity):
                        """
                        Configure media monitor service\-policy type
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.ServicePolicy.Type.PerformanceMonitor.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vasiright.ServicePolicy.Type.PerformanceMonitor, self).__init__()

                            self.yang_name = "performance-monitor"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Interface.Vasiright.ServicePolicy.Type.PerformanceMonitor.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "performance-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.ServicePolicy.Type.PerformanceMonitor, ['direction', 'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                    class ServiceChain(Entity):
                        """
                        Configure Service\-chain Service Policy
                        
                        .. attribute:: input
                        
                        	Assign policy\-map to the input of an interface
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain.Input>`
                        
                        .. attribute:: output
                        
                        	Assign policy\-map to the output of an interface
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain.Output>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain, self).__init__()

                            self.yang_name = "service-chain"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("input", ("input", Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain.Input)), ("output", ("output", Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain.Output))])
                            self._leafs = OrderedDict()

                            self.input = Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "service-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain, [], name, value)


                        class Input(Entity):
                            """
                            Assign policy\-map to the input of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain.Input, ['name'], name, value)


                        class Output(Entity):
                            """
                            Assign policy\-map to the output of an interface
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "service-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Interface.Vasiright.ServicePolicy.Type.ServiceChain.Output, ['name'], name, value)


            class EtAnalytics(Entity):
                """
                et\-analytics support on this interface
                
                .. attribute:: enable
                
                	Enable et\-analytics on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vasiright.EtAnalytics, self).__init__()

                    self.yang_name = "et-analytics"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.EtAnalytics, ['enable'], name, value)


            class ZoneMember(Entity):
                """
                Apply zone name
                
                .. attribute:: security
                
                	Security zone
                	**type**\: str
                
                	**length:** 1..64
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.Interface.Vasiright.ZoneMember, self).__init__()

                    self.yang_name = "zone-member"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security', (YLeaf(YType.str, 'security'), ['str'])),
                    ])
                    self.security = None
                    self._segment_path = lambda: "Cisco-IOS-XE-zone:zone-member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.ZoneMember, ['security'], name, value)


            class Utd(Entity):
                """
                UTD support on this interface
                
                .. attribute:: enable
                
                	Enable threat defense on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Interface.Vasiright.Utd, self).__init__()

                    self.yang_name = "utd"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Utd, ['enable'], name, value)


            class Umbrella(Entity):
                """
                Umbrella interface commands
                
                .. attribute:: out
                
                	Umbrella Out direction
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: in_
                
                	Umbrella In direction
                	**type**\: str
                
                	**length:** 1..49
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.Interface.Vasiright.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "vasiright"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                    ])
                    self.out = None
                    self.in_ = None
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Interface.Vasiright.Umbrella, ['out', 'in_'], name, value)


    class RouteMap(Entity):
        """
        Route map tag
        
        .. attribute:: name  (key)
        
        	WORD;;Route map tag
        	**type**\: str
        
        .. attribute:: route_map_seq
        
        	
        	**type**\: list of  		 :py:class:`RouteMapSeq <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq>`
        
        .. attribute:: route_map_without_order_seq
        
        	
        	**type**\: list of  		 :py:class:`RouteMapWithoutOrderSeq <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.RouteMap, self).__init__()

            self.yang_name = "route-map"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['name']
            self._child_classes = OrderedDict([("Cisco-IOS-XE-route-map:route-map-seq", ("route_map_seq", Native.RouteMap.RouteMapSeq)), ("Cisco-IOS-XE-route-map:route-map-without-order-seq", ("route_map_without_order_seq", Native.RouteMap.RouteMapWithoutOrderSeq))])
            self._leafs = OrderedDict([
                ('name', (YLeaf(YType.str, 'name'), ['str'])),
            ])
            self.name = None

            self.route_map_seq = YList(self)
            self.route_map_without_order_seq = YList(self)
            self._segment_path = lambda: "route-map" + "[name='" + str(self.name) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.RouteMap, [u'name'], name, value)


        class RouteMapSeq(Entity):
            """
            
            
            .. attribute:: ordering_seq  (key)
            
            	Ordering seq tag
            	**type**\: str
            
            .. attribute:: operation_
            
            	
            	**type**\:  :py:class:`Operation_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Operation_>`
            
            .. attribute:: sequence
            
            	
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: description
            
            	Route\-map comment
            	**type**\: str
            
            .. attribute:: set
            
            	Set values in destination routing protocol
            	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set>`
            
            .. attribute:: match
            
            	Match values from routing table
            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match>`
            
            

            """

            _prefix = 'ios-route-map'
            _revision = '2018-03-08'

            def __init__(self):
                super(Native.RouteMap.RouteMapSeq, self).__init__()

                self.yang_name = "route-map-seq"
                self.yang_parent_name = "route-map"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = ['ordering_seq']
                self._child_classes = OrderedDict([("set", ("set", Native.RouteMap.RouteMapSeq.Set)), ("match", ("match", Native.RouteMap.RouteMapSeq.Match))])
                self._leafs = OrderedDict([
                    ('ordering_seq', (YLeaf(YType.str, 'ordering-seq'), ['str'])),
                    ('operation_', (YLeaf(YType.enumeration, 'operation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapSeq.Operation_')])),
                    ('sequence', (YLeaf(YType.uint16, 'sequence'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                ])
                self.ordering_seq = None
                self.operation_ = None
                self.sequence = None
                self.description = None

                self.set = Native.RouteMap.RouteMapSeq.Set()
                self.set.parent = self
                self._children_name_map["set"] = "set"

                self.match = Native.RouteMap.RouteMapSeq.Match()
                self.match.parent = self
                self._children_name_map["match"] = "match"
                self._segment_path = lambda: "Cisco-IOS-XE-route-map:route-map-seq" + "[ordering-seq='" + str(self.ordering_seq) + "']"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.RouteMap.RouteMapSeq, ['ordering_seq', 'operation_', 'sequence', 'description'], name, value)

            class Operation_(Enum):
                """
                Operation\_ (Enum Class)

                .. data:: deny = 0

                .. data:: permit = 1

                """

                deny = Enum.YLeaf(0, "deny")

                permit = Enum.YLeaf(1, "permit")



            class Set(Entity):
                """
                Set values in destination routing protocol
                
                .. attribute:: aigp_metric
                
                	accumulated metric value
                	**type**\:  :py:class:`AigpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.AigpMetric>`
                
                .. attribute:: as_path
                
                	Prepend string for a BGP AS\-path attribute
                	**type**\:  :py:class:`AsPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.AsPath>`
                
                .. attribute:: automatic_tag
                
                	Automatically compute TAG value
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: clns
                
                	OSI summary address
                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Clns>`
                
                .. attribute:: community
                
                	BGP community attribute
                	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Community>`
                
                .. attribute:: comm_list
                
                	set BGP community list (for deletion)
                	**type**\:  :py:class:`CommList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.CommList>`
                
                .. attribute:: dampening
                
                	Set BGP route flap dampening parameters
                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Dampening>`
                
                .. attribute:: default
                
                	
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Default>`
                
                .. attribute:: extcomm_list
                
                	Set BGP/VPN extended community list (for deletion)
                	**type**\:  :py:class:`ExtcommList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.ExtcommList>`
                
                .. attribute:: extcommunity
                
                	BGP extended community attribute
                	**type**\:  :py:class:`Extcommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity>`
                
                .. attribute:: global_
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface
                
                	
                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Interface>`
                
                .. attribute:: ip
                
                	IP specific information
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip>`
                
                .. attribute:: ipv6
                
                	IPv6 specific information
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6>`
                
                .. attribute:: level
                
                	Where to import route
                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Level>`
                
                .. attribute:: lisp
                
                	Locator ID Separation Protocol specific information
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Lisp>`
                
                .. attribute:: local_preference
                
                	Preference value
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: metric
                
                	Metric value for destination routing protocol
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Metric>`
                
                .. attribute:: metric_type
                
                	Type of metric for destination routing protocol
                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.MetricType>`
                
                .. attribute:: mpls_label
                
                	Set MPLS label for prefix
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: weight
                
                	BGP weight for routing table
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: origin
                
                	BGP origin code
                	**type**\:  :py:class:`Origin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Origin>`
                
                .. attribute:: tag
                
                	Tag value for destination routing protocol
                	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Tag>`
                
                .. attribute:: traffic_index
                
                	Bucket number
                	**type**\: int
                
                	**range:** 1..64
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding instance name
                	**type**\: str
                
                

                """

                _prefix = 'ios-route-map'
                _revision = '2018-03-08'

                def __init__(self):
                    super(Native.RouteMap.RouteMapSeq.Set, self).__init__()

                    self.yang_name = "set"
                    self.yang_parent_name = "route-map-seq"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("aigp-metric", ("aigp_metric", Native.RouteMap.RouteMapSeq.Set.AigpMetric)), ("as-path", ("as_path", Native.RouteMap.RouteMapSeq.Set.AsPath)), ("clns", ("clns", Native.RouteMap.RouteMapSeq.Set.Clns)), ("community", ("community", Native.RouteMap.RouteMapSeq.Set.Community)), ("comm-list", ("comm_list", Native.RouteMap.RouteMapSeq.Set.CommList)), ("dampening", ("dampening", Native.RouteMap.RouteMapSeq.Set.Dampening)), ("default", ("default", Native.RouteMap.RouteMapSeq.Set.Default)), ("extcomm-list", ("extcomm_list", Native.RouteMap.RouteMapSeq.Set.ExtcommList)), ("extcommunity", ("extcommunity", Native.RouteMap.RouteMapSeq.Set.Extcommunity)), ("interface", ("interface", Native.RouteMap.RouteMapSeq.Set.Interface)), ("ip", ("ip", Native.RouteMap.RouteMapSeq.Set.Ip)), ("ipv6", ("ipv6", Native.RouteMap.RouteMapSeq.Set.Ipv6)), ("level", ("level", Native.RouteMap.RouteMapSeq.Set.Level)), ("lisp", ("lisp", Native.RouteMap.RouteMapSeq.Set.Lisp)), ("metric", ("metric", Native.RouteMap.RouteMapSeq.Set.Metric)), ("origin", ("origin", Native.RouteMap.RouteMapSeq.Set.Origin)), ("tag", ("tag", Native.RouteMap.RouteMapSeq.Set.Tag))])
                    self._leafs = OrderedDict([
                        ('automatic_tag', (YLeaf(YType.empty, 'automatic-tag'), ['Empty'])),
                        ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapSeq.Set.MetricType')])),
                        ('mpls_label', (YLeaf(YType.empty, 'mpls-label'), ['Empty'])),
                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                        ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ])
                    self.automatic_tag = None
                    self.global_ = None
                    self.local_preference = None
                    self.metric_type = None
                    self.mpls_label = None
                    self.weight = None
                    self.traffic_index = None
                    self.vrf = None

                    self.aigp_metric = Native.RouteMap.RouteMapSeq.Set.AigpMetric()
                    self.aigp_metric.parent = self
                    self._children_name_map["aigp_metric"] = "aigp-metric"

                    self.as_path = Native.RouteMap.RouteMapSeq.Set.AsPath()
                    self.as_path.parent = self
                    self._children_name_map["as_path"] = "as-path"

                    self.clns = Native.RouteMap.RouteMapSeq.Set.Clns()
                    self.clns.parent = self
                    self._children_name_map["clns"] = "clns"

                    self.community = Native.RouteMap.RouteMapSeq.Set.Community()
                    self.community.parent = self
                    self._children_name_map["community"] = "community"

                    self.comm_list = Native.RouteMap.RouteMapSeq.Set.CommList()
                    self.comm_list.parent = self
                    self._children_name_map["comm_list"] = "comm-list"

                    self.dampening = Native.RouteMap.RouteMapSeq.Set.Dampening()
                    self.dampening.parent = self
                    self._children_name_map["dampening"] = "dampening"

                    self.default = Native.RouteMap.RouteMapSeq.Set.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.extcomm_list = Native.RouteMap.RouteMapSeq.Set.ExtcommList()
                    self.extcomm_list.parent = self
                    self._children_name_map["extcomm_list"] = "extcomm-list"

                    self.extcommunity = Native.RouteMap.RouteMapSeq.Set.Extcommunity()
                    self.extcommunity.parent = self
                    self._children_name_map["extcommunity"] = "extcommunity"

                    self.interface = Native.RouteMap.RouteMapSeq.Set.Interface()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.ip = Native.RouteMap.RouteMapSeq.Set.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.ipv6 = Native.RouteMap.RouteMapSeq.Set.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.level = Native.RouteMap.RouteMapSeq.Set.Level()
                    self.level.parent = self
                    self._children_name_map["level"] = "level"

                    self.lisp = Native.RouteMap.RouteMapSeq.Set.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "lisp"

                    self.metric = Native.RouteMap.RouteMapSeq.Set.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "metric"

                    self.origin = Native.RouteMap.RouteMapSeq.Set.Origin()
                    self.origin.parent = self
                    self._children_name_map["origin"] = "origin"

                    self.tag = Native.RouteMap.RouteMapSeq.Set.Tag()
                    self.tag.parent = self
                    self._children_name_map["tag"] = "tag"
                    self._segment_path = lambda: "set"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set, ['automatic_tag', 'global_', 'local_preference', 'metric_type', 'mpls_label', 'weight', 'traffic_index', 'vrf'], name, value)

                class MetricType(Enum):
                    """
                    MetricType (Enum Class)

                    Type of metric for destination routing protocol

                    .. data:: external = 0

                    .. data:: internal = 1

                    .. data:: type_1 = 2

                    .. data:: type_2 = 3

                    """

                    external = Enum.YLeaf(0, "external")

                    internal = Enum.YLeaf(1, "internal")

                    type_1 = Enum.YLeaf(2, "type-1")

                    type_2 = Enum.YLeaf(3, "type-2")



                class AigpMetric(Entity):
                    """
                    accumulated metric value
                    
                    .. attribute:: value
                    
                    	manual value
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: igp_metric
                    
                    	metric value from rib
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.AigpMetric, self).__init__()

                        self.yang_name = "aigp-metric"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ('igp_metric', (YLeaf(YType.empty, 'igp-metric'), ['Empty'])),
                        ])
                        self.value = None
                        self.igp_metric = None
                        self._segment_path = lambda: "aigp-metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.AigpMetric, ['value', 'igp_metric'], name, value)


                class AsPath(Entity):
                    """
                    Prepend string for a BGP AS\-path attribute
                    
                    .. attribute:: prepend
                    
                    	Prepend to the as\-path
                    	**type**\:  :py:class:`Prepend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend>`
                    
                    .. attribute:: tag
                    
                    	Set the tag as an AS\-path attribute
                    	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.AsPath.Tag>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.AsPath, self).__init__()

                        self.yang_name = "as-path"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prepend", ("prepend", Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend)), ("tag", ("tag", Native.RouteMap.RouteMapSeq.Set.AsPath.Tag))])
                        self._leafs = OrderedDict()

                        self.prepend = Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend()
                        self.prepend.parent = self
                        self._children_name_map["prepend"] = "prepend"

                        self.tag = None
                        self._children_name_map["tag"] = "tag"
                        self._segment_path = lambda: "as-path"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.AsPath, [], name, value)


                    class Prepend(Entity):
                        """
                        Prepend to the as\-path
                        
                        .. attribute:: as_container
                        
                        	
                        	**type**\:  :py:class:`AsContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend.AsContainer>`
                        
                        .. attribute:: last_as_cont
                        
                        	
                        	**type**\:  :py:class:`LastAsCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend.LastAsCont>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend, self).__init__()

                            self.yang_name = "prepend"
                            self.yang_parent_name = "as-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("as-container", ("as_container", Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend.AsContainer)), ("last-as-cont", ("last_as_cont", Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend.LastAsCont))])
                            self._leafs = OrderedDict()

                            self.as_container = Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend.AsContainer()
                            self.as_container.parent = self
                            self._children_name_map["as_container"] = "as-container"

                            self.last_as_cont = Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend.LastAsCont()
                            self.last_as_cont.parent = self
                            self._children_name_map["last_as_cont"] = "last-as-cont"
                            self._segment_path = lambda: "prepend"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend, [], name, value)


                        class AsContainer(Entity):
                            """
                            
                            
                            .. attribute:: as_number
                            
                            	<1\-65535>;;AS number
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend.AsContainer, self).__init__()

                                self.yang_name = "as-container"
                                self.yang_parent_name = "prepend"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('as_number', (YLeaf(YType.str, 'as-number'), ['str'])),
                                ])
                                self.as_number = None
                                self._segment_path = lambda: "as-container"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend.AsContainer, ['as_number'], name, value)


                        class LastAsCont(Entity):
                            """
                            
                            
                            .. attribute:: last_as
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend.LastAsCont, self).__init__()

                                self.yang_name = "last-as-cont"
                                self.yang_parent_name = "prepend"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('last_as', (YLeaf(YType.uint16, 'last-as'), ['int'])),
                                ])
                                self.last_as = None
                                self._segment_path = lambda: "last-as-cont"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.AsPath.Prepend.LastAsCont, ['last_as'], name, value)


                    class Tag(Entity):
                        """
                        Set the tag as an AS\-path attribute
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.AsPath.Tag, self).__init__()

                            self.yang_name = "tag"
                            self.yang_parent_name = "as-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "tag"
                            self._is_frozen = True


                class Clns(Entity):
                    """
                    OSI summary address
                    
                    .. attribute:: next_hop
                    
                    	Next hop along path
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Clns.NextHop>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Clns, self).__init__()

                        self.yang_name = "clns"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Set.Clns.NextHop))])
                        self._leafs = OrderedDict()

                        self.next_hop = Native.RouteMap.RouteMapSeq.Set.Clns.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._segment_path = lambda: "clns"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Clns, [], name, value)


                    class NextHop(Entity):
                        """
                        Next hop along path
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: list of str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Clns.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "clns"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeafList(YType.str, 'address'), ['str'])),
                            ])
                            self.address = []
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Clns.NextHop, ['address'], name, value)


                class Community(Entity):
                    """
                    BGP community attribute
                    
                    .. attribute:: none
                    
                    	No community attribute
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: community_well_known
                    
                    	
                    	**type**\:  :py:class:`CommunityWellKnown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Community.CommunityWellKnown>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Community, self).__init__()

                        self.yang_name = "community"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("community-well-known", ("community_well_known", Native.RouteMap.RouteMapSeq.Set.Community.CommunityWellKnown))])
                        self._leafs = OrderedDict([
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ])
                        self.none = None

                        self.community_well_known = Native.RouteMap.RouteMapSeq.Set.Community.CommunityWellKnown()
                        self.community_well_known.parent = self
                        self._children_name_map["community_well_known"] = "community-well-known"
                        self._segment_path = lambda: "community"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Community, ['none'], name, value)


                    class CommunityWellKnown(Entity):
                        """
                        
                        
                        .. attribute:: community_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..4294967295
                        
                        		**type**\: list of str
                        
                        			**pattern:** (\\d+\:\\d+)
                        
                        		**type**\: list of   :py:class:`CommunityWellKnownAddType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CommunityWellKnownAddType>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Community.CommunityWellKnown, self).__init__()

                            self.yang_name = "community-well-known"
                            self.yang_parent_name = "community"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('community_list', (YLeafList(YType.str, 'community-list'), ['int','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CommunityWellKnownAddType', '')])),
                            ])
                            self.community_list = []
                            self._segment_path = lambda: "community-well-known"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Community.CommunityWellKnown, ['community_list'], name, value)


                class CommList(Entity):
                    """
                    set BGP community list (for deletion)
                    
                    .. attribute:: comm_list_standard
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..99
                    
                    .. attribute:: comm_list_expanded
                    
                    	
                    	**type**\: int
                    
                    	**range:** 100..500
                    
                    .. attribute:: comm_list_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: delete
                    
                    	Delete matching communities
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.CommList, self).__init__()

                        self.yang_name = "comm-list"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('comm_list_standard', (YLeaf(YType.uint16, 'comm-list-standard'), ['int'])),
                            ('comm_list_expanded', (YLeaf(YType.uint16, 'comm-list-expanded'), ['int'])),
                            ('comm_list_name', (YLeaf(YType.str, 'comm-list-name'), ['str'])),
                            ('delete', (YLeaf(YType.empty, 'delete'), ['Empty'])),
                        ])
                        self.comm_list_standard = None
                        self.comm_list_expanded = None
                        self.comm_list_name = None
                        self.delete = None
                        self._segment_path = lambda: "comm-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.CommList, ['comm_list_standard', 'comm_list_expanded', 'comm_list_name', 'delete'], name, value)


                class Dampening(Entity):
                    """
                    Set BGP route flap dampening parameters
                    
                    .. attribute:: dampening_list
                    
                    	
                    	**type**\: list of  		 :py:class:`DampeningList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Dampening.DampeningList>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Dampening, self).__init__()

                        self.yang_name = "dampening"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dampening-list", ("dampening_list", Native.RouteMap.RouteMapSeq.Set.Dampening.DampeningList))])
                        self._leafs = OrderedDict()

                        self.dampening_list = YList(self)
                        self._segment_path = lambda: "dampening"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Dampening, [], name, value)


                    class DampeningList(Entity):
                        """
                        
                        
                        .. attribute:: half_life_penalty  (key)
                        
                        	half\-life time for the penalty
                        	**type**\: int
                        
                        	**range:** 1..45
                        
                        .. attribute:: restart_penalty  (key)
                        
                        	penalty to start reusing a route
                        	**type**\: int
                        
                        	**range:** 1..20000
                        
                        .. attribute:: suppress_penalty  (key)
                        
                        	penalty to start suppressing a route
                        	**type**\: int
                        
                        	**range:** 1..20000
                        
                        .. attribute:: max_suppress_penalty  (key)
                        
                        	Maximum duration to suppress a stable route
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Dampening.DampeningList, self).__init__()

                            self.yang_name = "dampening-list"
                            self.yang_parent_name = "dampening"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['half_life_penalty','restart_penalty','suppress_penalty','max_suppress_penalty']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('half_life_penalty', (YLeaf(YType.uint8, 'half-life-penalty'), ['int'])),
                                ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                                ('suppress_penalty', (YLeaf(YType.uint16, 'suppress-penalty'), ['int'])),
                                ('max_suppress_penalty', (YLeaf(YType.uint8, 'max-suppress-penalty'), ['int'])),
                            ])
                            self.half_life_penalty = None
                            self.restart_penalty = None
                            self.suppress_penalty = None
                            self.max_suppress_penalty = None
                            self._segment_path = lambda: "dampening-list" + "[half-life-penalty='" + str(self.half_life_penalty) + "']" + "[restart-penalty='" + str(self.restart_penalty) + "']" + "[suppress-penalty='" + str(self.suppress_penalty) + "']" + "[max-suppress-penalty='" + str(self.max_suppress_penalty) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Dampening.DampeningList, ['half_life_penalty', 'restart_penalty', 'suppress_penalty', 'max_suppress_penalty'], name, value)


                class Default(Entity):
                    """
                    
                    
                    .. attribute:: interface
                    
                    	SPAN source interface
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Default.Interface>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Native.RouteMap.RouteMapSeq.Set.Default.Interface))])
                        self._leafs = OrderedDict()

                        self.interface = Native.RouteMap.RouteMapSeq.Set.Default.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Default, [], name, value)


                    class Interface(Entity):
                        """
                        SPAN source interface
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Default.Interface.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Default.Interface.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Default.Interface.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Default.Interface.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Default.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.RouteMap.RouteMapSeq.Set.Default.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.RouteMap.RouteMapSeq.Set.Default.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.RouteMap.RouteMapSeq.Set.Default.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.RouteMap.RouteMapSeq.Set.Default.Interface.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.RouteMap.RouteMapSeq.Set.Default.Interface.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.RouteMap.RouteMapSeq.Set.Default.Interface.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.RouteMap.RouteMapSeq.Set.Default.Interface.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.RouteMap.RouteMapSeq.Set.Default.Interface.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Default.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Default.Interface.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Default.Interface.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Default.Interface.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Default.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Default.Interface.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Default.Interface.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Default.Interface.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Default.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                class ExtcommList(Entity):
                    """
                    Set BGP/VPN extended community list (for deletion)
                    
                    .. attribute:: ext_range
                    
                    	
                    	**type**\: list of  		 :py:class:`ExtRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.ExtcommList.ExtRange>`
                    
                    .. attribute:: excomm_list_name
                    
                    	
                    	**type**\: list of  		 :py:class:`ExcommListName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.ExtcommList.ExcommListName>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.ExtcommList, self).__init__()

                        self.yang_name = "extcomm-list"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ext-range", ("ext_range", Native.RouteMap.RouteMapSeq.Set.ExtcommList.ExtRange)), ("excomm-list-name", ("excomm_list_name", Native.RouteMap.RouteMapSeq.Set.ExtcommList.ExcommListName))])
                        self._leafs = OrderedDict()

                        self.ext_range = YList(self)
                        self.excomm_list_name = YList(self)
                        self._segment_path = lambda: "extcomm-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.ExtcommList, [], name, value)


                    class ExtRange(Entity):
                        """
                        
                        
                        .. attribute:: comm_list_num  (key)
                        
                        	Extended community\-list number (expanded)
                        	**type**\: int
                        
                        	**range:** 1..500
                        
                        .. attribute:: delete
                        
                        	Delete matching extended communities
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.ExtcommList.ExtRange, self).__init__()

                            self.yang_name = "ext-range"
                            self.yang_parent_name = "extcomm-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['comm_list_num']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('comm_list_num', (YLeaf(YType.uint16, 'comm-list-num'), ['int'])),
                                ('delete', (YLeaf(YType.empty, 'delete'), ['Empty'])),
                            ])
                            self.comm_list_num = None
                            self.delete = None
                            self._segment_path = lambda: "ext-range" + "[comm-list-num='" + str(self.comm_list_num) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.ExtcommList.ExtRange, ['comm_list_num', 'delete'], name, value)


                    class ExcommListName(Entity):
                        """
                        
                        
                        .. attribute:: name  (key)
                        
                        	extcommunity\-list name
                        	**type**\: str
                        
                        .. attribute:: delete
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.ExtcommList.ExcommListName, self).__init__()

                            self.yang_name = "excomm-list-name"
                            self.yang_parent_name = "extcomm-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('delete', (YLeaf(YType.empty, 'delete'), ['Empty'])),
                            ])
                            self.name = None
                            self.delete = None
                            self._segment_path = lambda: "excomm-list-name" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.ExtcommList.ExcommListName, ['name', 'delete'], name, value)


                class Extcommunity(Entity):
                    """
                    BGP extended community attribute
                    
                    .. attribute:: cost
                    
                    	Cost extended community
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost>`
                    
                    .. attribute:: rt
                    
                    	Route Target extended community
                    	**type**\:  :py:class:`Rt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity.Rt>`
                    
                    .. attribute:: soo
                    
                    	Site\-of\-Origin extended community
                    	**type**\:  :py:class:`Soo <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity.Soo>`
                    
                    .. attribute:: vpn_distinguisher
                    
                    	VPN Distinguisher
                    	**type**\:  :py:class:`VpnDistinguisher <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity.VpnDistinguisher>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Extcommunity, self).__init__()

                        self.yang_name = "extcommunity"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("cost", ("cost", Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost)), ("rt", ("rt", Native.RouteMap.RouteMapSeq.Set.Extcommunity.Rt)), ("soo", ("soo", Native.RouteMap.RouteMapSeq.Set.Extcommunity.Soo)), ("vpn-distinguisher", ("vpn_distinguisher", Native.RouteMap.RouteMapSeq.Set.Extcommunity.VpnDistinguisher))])
                        self._leafs = OrderedDict()

                        self.cost = Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.rt = Native.RouteMap.RouteMapSeq.Set.Extcommunity.Rt()
                        self.rt.parent = self
                        self._children_name_map["rt"] = "rt"

                        self.soo = Native.RouteMap.RouteMapSeq.Set.Extcommunity.Soo()
                        self.soo.parent = self
                        self._children_name_map["soo"] = "soo"

                        self.vpn_distinguisher = Native.RouteMap.RouteMapSeq.Set.Extcommunity.VpnDistinguisher()
                        self.vpn_distinguisher.parent = self
                        self._children_name_map["vpn_distinguisher"] = "vpn-distinguisher"
                        self._segment_path = lambda: "extcommunity"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity, [], name, value)


                    class Cost(Entity):
                        """
                        Cost extended community
                        
                        .. attribute:: community_id
                        
                        	
                        	**type**\: list of  		 :py:class:`CommunityId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.CommunityId>`
                        
                        .. attribute:: igp
                        
                        	Compare following IGP cost comparison
                        	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.Igp>`
                        
                        .. attribute:: pre_bestpath
                        
                        	Compare before all other steps in bestpath calculation
                        	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.PreBestpath>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "extcommunity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("community-id", ("community_id", Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.CommunityId)), ("igp", ("igp", Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.Igp)), ("pre-bestpath", ("pre_bestpath", Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.PreBestpath))])
                            self._leafs = OrderedDict()

                            self.igp = Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.Igp()
                            self.igp.parent = self
                            self._children_name_map["igp"] = "igp"

                            self.pre_bestpath = Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.PreBestpath()
                            self.pre_bestpath.parent = self
                            self._children_name_map["pre_bestpath"] = "pre-bestpath"

                            self.community_id = YList(self)
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost, [], name, value)


                        class CommunityId(Entity):
                            """
                            
                            
                            .. attribute:: community_id  (key)
                            
                            	Community ID
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: cost_value  (key)
                            
                            	Cost Value (No\-preference Cost = 2147483647)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.CommunityId, self).__init__()

                                self.yang_name = "community-id"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['community_id','cost_value']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('community_id', (YLeaf(YType.uint8, 'community-id'), ['int'])),
                                    ('cost_value', (YLeaf(YType.uint32, 'cost-value'), ['int'])),
                                ])
                                self.community_id = None
                                self.cost_value = None
                                self._segment_path = lambda: "community-id" + "[community-id='" + str(self.community_id) + "']" + "[cost-value='" + str(self.cost_value) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.CommunityId, ['community_id', 'cost_value'], name, value)


                        class Igp(Entity):
                            """
                            Compare following IGP cost comparison
                            
                            .. attribute:: community_id
                            
                            	
                            	**type**\: list of  		 :py:class:`CommunityId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.Igp.CommunityId>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.Igp, self).__init__()

                                self.yang_name = "igp"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("community-id", ("community_id", Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.Igp.CommunityId))])
                                self._leafs = OrderedDict()

                                self.community_id = YList(self)
                                self._segment_path = lambda: "igp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.Igp, [], name, value)


                            class CommunityId(Entity):
                                """
                                
                                
                                .. attribute:: community_id  (key)
                                
                                	Community ID
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: cost_value  (key)
                                
                                	Cost Value (No\-preference Cost = 2147483647)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.Igp.CommunityId, self).__init__()

                                    self.yang_name = "community-id"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['community_id','cost_value']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('community_id', (YLeaf(YType.uint8, 'community-id'), ['int'])),
                                        ('cost_value', (YLeaf(YType.uint32, 'cost-value'), ['int'])),
                                    ])
                                    self.community_id = None
                                    self.cost_value = None
                                    self._segment_path = lambda: "community-id" + "[community-id='" + str(self.community_id) + "']" + "[cost-value='" + str(self.cost_value) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.Igp.CommunityId, ['community_id', 'cost_value'], name, value)


                        class PreBestpath(Entity):
                            """
                            Compare before all other steps in bestpath calculation
                            
                            .. attribute:: community_id
                            
                            	
                            	**type**\: list of  		 :py:class:`CommunityId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.PreBestpath.CommunityId>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.PreBestpath, self).__init__()

                                self.yang_name = "pre-bestpath"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("community-id", ("community_id", Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.PreBestpath.CommunityId))])
                                self._leafs = OrderedDict()

                                self.community_id = YList(self)
                                self._segment_path = lambda: "pre-bestpath"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.PreBestpath, [], name, value)


                            class CommunityId(Entity):
                                """
                                
                                
                                .. attribute:: community_id  (key)
                                
                                	Community ID
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: cost_value  (key)
                                
                                	Cost Value (No\-preference Cost = 2147483647)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.PreBestpath.CommunityId, self).__init__()

                                    self.yang_name = "community-id"
                                    self.yang_parent_name = "pre-bestpath"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['community_id','cost_value']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('community_id', (YLeaf(YType.uint8, 'community-id'), ['int'])),
                                        ('cost_value', (YLeaf(YType.uint32, 'cost-value'), ['int'])),
                                    ])
                                    self.community_id = None
                                    self.cost_value = None
                                    self._segment_path = lambda: "community-id" + "[community-id='" + str(self.community_id) + "']" + "[cost-value='" + str(self.cost_value) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Cost.PreBestpath.CommunityId, ['community_id', 'cost_value'], name, value)


                    class Rt(Entity):
                        """
                        Route Target extended community
                        
                        .. attribute:: asn_nn
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of str
                        
                        			**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                        
                        		**type**\: list of   :py:class:`AsnNn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt.AsnNn>`
                        
                        .. attribute:: range
                        
                        	Specify a range of extended community
                        	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity.Rt.Range>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Rt, self).__init__()

                            self.yang_name = "rt"
                            self.yang_parent_name = "extcommunity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.RouteMap.RouteMapSeq.Set.Extcommunity.Rt.Range))])
                            self._leafs = OrderedDict([
                                ('asn_nn', (YLeafList(YType.str, 'asn-nn'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt.AsnNn')])),
                            ])
                            self.asn_nn = []

                            self.range = Native.RouteMap.RouteMapSeq.Set.Extcommunity.Rt.Range()
                            self.range.parent = self
                            self._children_name_map["range"] = "range"
                            self._segment_path = lambda: "rt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Rt, ['asn_nn'], name, value)

                        class AsnNn(Enum):
                            """
                            AsnNn (Enum Class)

                            .. data:: additive = 0

                            """

                            additive = Enum.YLeaf(0, "additive")



                        class Range(Entity):
                            """
                            Specify a range of extended community
                            
                            .. attribute:: lower_limit
                            
                            	VPN extended community lower limit
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: high_limit
                            
                            	VPN extended community high limit
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: additive
                            
                            	Add to the existing extcommunity
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Rt.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lower_limit', (YLeaf(YType.str, 'lower-limit'), ['str'])),
                                    ('high_limit', (YLeaf(YType.str, 'high-limit'), ['str'])),
                                    ('additive', (YLeaf(YType.empty, 'additive'), ['Empty'])),
                                ])
                                self.lower_limit = None
                                self.high_limit = None
                                self.additive = None
                                self._segment_path = lambda: "range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Rt.Range, ['lower_limit', 'high_limit', 'additive'], name, value)


                    class Soo(Entity):
                        """
                        Site\-of\-Origin extended community
                        
                        .. attribute:: asn_nn
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Soo, self).__init__()

                            self.yang_name = "soo"
                            self.yang_parent_name = "extcommunity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('asn_nn', (YLeaf(YType.str, 'asn-nn'), ['str'])),
                            ])
                            self.asn_nn = None
                            self._segment_path = lambda: "soo"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity.Soo, ['asn_nn'], name, value)


                    class VpnDistinguisher(Entity):
                        """
                        VPN Distinguisher
                        
                        .. attribute:: asn_nn
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                        
                        .. attribute:: range
                        
                        	Specify a range of extended community
                        	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Extcommunity.VpnDistinguisher.Range>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Extcommunity.VpnDistinguisher, self).__init__()

                            self.yang_name = "vpn-distinguisher"
                            self.yang_parent_name = "extcommunity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.RouteMap.RouteMapSeq.Set.Extcommunity.VpnDistinguisher.Range))])
                            self._leafs = OrderedDict([
                                ('asn_nn', (YLeaf(YType.str, 'asn-nn'), ['str'])),
                            ])
                            self.asn_nn = None

                            self.range = Native.RouteMap.RouteMapSeq.Set.Extcommunity.VpnDistinguisher.Range()
                            self.range.parent = self
                            self._children_name_map["range"] = "range"
                            self._segment_path = lambda: "vpn-distinguisher"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity.VpnDistinguisher, ['asn_nn'], name, value)


                        class Range(Entity):
                            """
                            Specify a range of extended community
                            
                            .. attribute:: lower_limit
                            
                            	VPN extended community lower limit
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: high_limit
                            
                            	VPN extended community high limit
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: additive
                            
                            	Add to the existing extcommunity
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Extcommunity.VpnDistinguisher.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "vpn-distinguisher"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lower_limit', (YLeaf(YType.str, 'lower-limit'), ['str'])),
                                    ('high_limit', (YLeaf(YType.str, 'high-limit'), ['str'])),
                                    ('additive', (YLeaf(YType.empty, 'additive'), ['Empty'])),
                                ])
                                self.lower_limit = None
                                self.high_limit = None
                                self.additive = None
                                self._segment_path = lambda: "range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Extcommunity.VpnDistinguisher.Range, ['lower_limit', 'high_limit', 'additive'], name, value)


                class Interface(Entity):
                    """
                    
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Interface.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Interface.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Interface.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Interface.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.RouteMap.RouteMapSeq.Set.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.RouteMap.RouteMapSeq.Set.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.RouteMap.RouteMapSeq.Set.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.RouteMap.RouteMapSeq.Set.Interface.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.RouteMap.RouteMapSeq.Set.Interface.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.RouteMap.RouteMapSeq.Set.Interface.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.RouteMap.RouteMapSeq.Set.Interface.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.RouteMap.RouteMapSeq.Set.Interface.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Interface.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Interface.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Interface.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Interface.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Interface.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Interface.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                class Ip(Entity):
                    """
                    IP specific information
                    
                    .. attribute:: address
                    
                    	Specify IP address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Address>`
                    
                    .. attribute:: default
                    
                    	Set default information
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Default>`
                    
                    .. attribute:: df
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..1
                    
                    .. attribute:: global_
                    
                    	global routing table
                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Global>`
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.NextHop>`
                    
                    .. attribute:: precedence
                    
                    	Set precedence field
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Precedence>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: qos_group
                    
                    	Set QOS Group ID
                    	**type**\:  :py:class:`QosGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.QosGroup>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: tos
                    
                    	Set type of service field
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Tos>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: vrf
                    
                    	VRF name
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.RouteMap.RouteMapSeq.Set.Ip.Address)), ("default", ("default", Native.RouteMap.RouteMapSeq.Set.Ip.Default)), ("global", ("global_", Native.RouteMap.RouteMapSeq.Set.Ip.Global)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Set.Ip.NextHop)), ("precedence", ("precedence", Native.RouteMap.RouteMapSeq.Set.Ip.Precedence)), ("qos-group", ("qos_group", Native.RouteMap.RouteMapSeq.Set.Ip.QosGroup)), ("tos", ("tos", Native.RouteMap.RouteMapSeq.Set.Ip.Tos)), ("vrf", ("vrf", Native.RouteMap.RouteMapSeq.Set.Ip.Vrf))])
                        self._leafs = OrderedDict([
                            ('df', (YLeaf(YType.uint8, 'df'), ['int'])),
                        ])
                        self.df = None

                        self.address = Native.RouteMap.RouteMapSeq.Set.Ip.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.default = Native.RouteMap.RouteMapSeq.Set.Ip.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.global_ = Native.RouteMap.RouteMapSeq.Set.Ip.Global()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"

                        self.next_hop = Native.RouteMap.RouteMapSeq.Set.Ip.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"

                        self.precedence = None
                        self._children_name_map["precedence"] = "precedence"

                        self.qos_group = None
                        self._children_name_map["qos_group"] = "qos-group"

                        self.tos = None
                        self._children_name_map["tos"] = "tos"

                        self.vrf = Native.RouteMap.RouteMapSeq.Set.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip, ['df'], name, value)


                    class Address(Entity):
                        """
                        Specify IP address
                        
                        .. attribute:: prefix_list
                        
                        	Specify prefix\-list
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ip.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.prefix_list = None
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Address, ['prefix_list'], name, value)


                    class Default(Entity):
                        """
                        Set default information
                        
                        .. attribute:: global_
                        
                        	global routing table
                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Default.Global>`
                        
                        .. attribute:: next_hop
                        
                        	Next hop along path
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Default.NextHop>`
                        
                        .. attribute:: vrf
                        
                        	VRF name
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ip.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("global", ("global_", Native.RouteMap.RouteMapSeq.Set.Ip.Default.Global)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Set.Ip.Default.NextHop)), ("vrf", ("vrf", Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf))])
                            self._leafs = OrderedDict()

                            self.global_ = Native.RouteMap.RouteMapSeq.Set.Ip.Default.Global()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"

                            self.next_hop = Native.RouteMap.RouteMapSeq.Set.Ip.Default.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"

                            self.vrf = Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Default, [], name, value)


                        class Global(Entity):
                            """
                            global routing table
                            
                            .. attribute:: next_hop
                            
                            	Next hop along path
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Default.Global.NextHop>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ip.Default.Global, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Set.Ip.Default.Global.NextHop))])
                                self._leafs = OrderedDict()

                                self.next_hop = Native.RouteMap.RouteMapSeq.Set.Ip.Default.Global.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._segment_path = lambda: "global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Default.Global, [], name, value)


                            class NextHop(Entity):
                                """
                                Next hop along path
                                
                                .. attribute:: address
                                
                                	
                                	**type**\: list of str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Ip.Default.Global.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                    ])
                                    self.address = []
                                    self._segment_path = lambda: "next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Default.Global.NextHop, ['address'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop along path
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: list of str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ip.Default.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                ])
                                self.address = []
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Default.NextHop, ['address'], name, value)


                        class Vrf(Entity):
                            """
                            VRF name
                            
                            .. attribute:: vrfs
                            
                            	
                            	**type**\: list of  		 :py:class:`Vrfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf.Vrfs>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrfs", ("vrfs", Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf.Vrfs))])
                                self._leafs = OrderedDict()

                                self.vrfs = YList(self)
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf, [], name, value)


                            class Vrfs(Entity):
                                """
                                
                                
                                .. attribute:: vrf  (key)
                                
                                	WORD;;VRF name
                                	**type**\: str
                                
                                .. attribute:: next_hop
                                
                                	Next hop along path
                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf.Vrfs.NextHop>`
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf.Vrfs, self).__init__()

                                    self.yang_name = "vrfs"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['vrf']
                                    self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf.Vrfs.NextHop))])
                                    self._leafs = OrderedDict([
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.vrf = None

                                    self.next_hop = Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf.Vrfs.NextHop()
                                    self.next_hop.parent = self
                                    self._children_name_map["next_hop"] = "next-hop"
                                    self._segment_path = lambda: "vrfs" + "[vrf='" + str(self.vrf) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf.Vrfs, ['vrf'], name, value)


                                class NextHop(Entity):
                                    """
                                    Next hop along path
                                    
                                    .. attribute:: address
                                    
                                    	
                                    	**type**\: list of str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-route-map'
                                    _revision = '2018-03-08'

                                    def __init__(self):
                                        super(Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf.Vrfs.NextHop, self).__init__()

                                        self.yang_name = "next-hop"
                                        self.yang_parent_name = "vrfs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                        ])
                                        self.address = []
                                        self._segment_path = lambda: "next-hop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Default.Vrf.Vrfs.NextHop, ['address'], name, value)


                    class Global(Entity):
                        """
                        global routing table
                        
                        .. attribute:: next_hop
                        
                        	Next hop along path
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Global.NextHop>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ip.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Set.Ip.Global.NextHop))])
                            self._leafs = OrderedDict()

                            self.next_hop = Native.RouteMap.RouteMapSeq.Set.Ip.Global.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._segment_path = lambda: "global"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Global, [], name, value)


                        class NextHop(Entity):
                            """
                            Next hop along path
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: list of str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ip.Global.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                ])
                                self.address = []
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Global.NextHop, ['address'], name, value)


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: dynamic
                        
                        	application dynamically sets next hop
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Dynamic>`
                        
                        .. attribute:: encapsulate
                        
                        	Encapsulation profile for VPN nexthop
                        	**type**\:  :py:class:`Encapsulate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Encapsulate>`
                        
                        .. attribute:: peer_address
                        
                        	Use peer address (for BGP only)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: recursive
                        
                        	Recursive next\-hop
                        	**type**\:  :py:class:`Recursive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive>`
                        
                        .. attribute:: self
                        
                        	Use self address (for BGP only)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: verify_availability
                        
                        	Verify if nexthop is reachable
                        	**type**\:  :py:class:`VerifyAvailability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.VerifyAvailability>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Dynamic)), ("encapsulate", ("encapsulate", Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Encapsulate)), ("recursive", ("recursive", Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive)), ("verify-availability", ("verify_availability", Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.VerifyAvailability))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('peer_address', (YLeaf(YType.empty, 'peer-address'), ['Empty'])),
                                ('self', (YLeaf(YType.empty, 'self'), ['Empty'])),
                            ])
                            self.address = None
                            self.peer_address = None
                            self.self = None

                            self.dynamic = Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Dynamic()
                            self.dynamic.parent = self
                            self._children_name_map["dynamic"] = "dynamic"

                            self.encapsulate = Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Encapsulate()
                            self.encapsulate.parent = self
                            self._children_name_map["encapsulate"] = "encapsulate"

                            self.recursive = Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive()
                            self.recursive.parent = self
                            self._children_name_map["recursive"] = "recursive"

                            self.verify_availability = None
                            self._children_name_map["verify_availability"] = "verify-availability"
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop, ['address', 'peer_address', 'self'], name, value)


                        class Dynamic(Entity):
                            """
                            application dynamically sets next hop
                            
                            .. attribute:: dhcp
                            
                            	DHCP learned next hop
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Dynamic, ['dhcp'], name, value)


                        class Encapsulate(Entity):
                            """
                            Encapsulation profile for VPN nexthop
                            
                            .. attribute:: l3vpn
                            
                            	L3VPN
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Encapsulate, self).__init__()

                                self.yang_name = "encapsulate"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('l3vpn', (YLeaf(YType.str, 'l3vpn'), ['str'])),
                                ])
                                self.l3vpn = None
                                self._segment_path = lambda: "encapsulate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Encapsulate, ['l3vpn'], name, value)


                        class Recursive(Entity):
                            """
                            Recursive next\-hop
                            
                            .. attribute:: ipv4
                            
                            	IP address of recursive next hop
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: global_
                            
                            	IP address of recursive next hop
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vrf
                            
                            	VRF name
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive.Vrf>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive, self).__init__()

                                self.yang_name = "recursive"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive.Vrf))])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('global_', (YLeaf(YType.str, 'global'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.global_ = None

                                self.vrf = Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._segment_path = lambda: "recursive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive, ['ipv4', 'global_'], name, value)


                            class Vrf(Entity):
                                """
                                VRF name
                                
                                .. attribute:: vrfs
                                
                                	
                                	**type**\: list of  		 :py:class:`Vrfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive.Vrf.Vrfs>`
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "recursive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrfs", ("vrfs", Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive.Vrf.Vrfs))])
                                    self._leafs = OrderedDict()

                                    self.vrfs = YList(self)
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive.Vrf, [], name, value)


                                class Vrfs(Entity):
                                    """
                                    
                                    
                                    .. attribute:: vrf  (key)
                                    
                                    	VRF name
                                    	**type**\: str
                                    
                                    .. attribute:: ipv4
                                    
                                    	IP address of recursive next hop
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-route-map'
                                    _revision = '2018-03-08'

                                    def __init__(self):
                                        super(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive.Vrf.Vrfs, self).__init__()

                                        self.yang_name = "vrfs"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['vrf']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ])
                                        self.vrf = None
                                        self.ipv4 = None
                                        self._segment_path = lambda: "vrfs" + "[vrf='" + str(self.vrf) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.Recursive.Vrf.Vrfs, ['vrf', 'ipv4'], name, value)


                        class VerifyAvailability(Entity):
                            """
                            Verify if nexthop is reachable
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.VerifyAvailability.Ipv4>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.VerifyAvailability, self).__init__()

                                self.yang_name = "verify-availability"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.VerifyAvailability.Ipv4))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.ipv4 = YList(self)
                                self._segment_path = lambda: "verify-availability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.VerifyAvailability, [], name, value)


                            class Ipv4(Entity):
                                """
                                
                                
                                .. attribute:: ipv4  (key)
                                
                                	IP address of next hop
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: range
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: track
                                
                                	set the next hop depending on the state\\ of a tracked object
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.VerifyAvailability.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "verify-availability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv4']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                        ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                    ])
                                    self.ipv4 = None
                                    self.range = None
                                    self.track = None
                                    self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.NextHop.VerifyAvailability.Ipv4, ['ipv4', 'range', 'track'], name, value)


                    class Precedence(Entity):
                        """
                        Set precedence field
                        
                        .. attribute:: precedence_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: precedence_fields
                        
                        	
                        	**type**\:  :py:class:`PrecedenceFields <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Precedence.PrecedenceFields>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ip.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('precedence_value', (YLeaf(YType.uint8, 'precedence-value'), ['int'])),
                                ('precedence_fields', (YLeaf(YType.enumeration, 'precedence-fields'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapSeq.Set.Ip.Precedence.PrecedenceFields')])),
                            ])
                            self.precedence_value = None
                            self.precedence_fields = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Precedence, ['precedence_value', 'precedence_fields'], name, value)

                        class PrecedenceFields(Enum):
                            """
                            PrecedenceFields (Enum Class)

                            .. data:: critical = 0

                            .. data:: flash = 1

                            .. data:: flash_override = 2

                            .. data:: immediate = 3

                            .. data:: internet = 4

                            .. data:: network = 5

                            .. data:: priority = 6

                            .. data:: routine = 7

                            """

                            critical = Enum.YLeaf(0, "critical")

                            flash = Enum.YLeaf(1, "flash")

                            flash_override = Enum.YLeaf(2, "flash-override")

                            immediate = Enum.YLeaf(3, "immediate")

                            internet = Enum.YLeaf(4, "internet")

                            network = Enum.YLeaf(5, "network")

                            priority = Enum.YLeaf(6, "priority")

                            routine = Enum.YLeaf(7, "routine")



                    class QosGroup(Entity):
                        """
                        Set QOS Group ID
                        
                        .. attribute:: qos_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..99
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ip.QosGroup, self).__init__()

                            self.yang_name = "qos-group"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('qos_id', (YLeaf(YType.uint8, 'qos-id'), ['int'])),
                            ])
                            self.qos_id = None
                            self._segment_path = lambda: "qos-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.QosGroup, ['qos_id'], name, value)


                    class Tos(Entity):
                        """
                        Set type of service field
                        
                        .. attribute:: service_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..15
                        
                        .. attribute:: tos_fields
                        
                        	
                        	**type**\:  :py:class:`TosFields <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Tos.TosFields>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ip.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('service_value', (YLeaf(YType.uint8, 'service-value'), ['int'])),
                                ('tos_fields', (YLeaf(YType.enumeration, 'tos-fields'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapSeq.Set.Ip.Tos.TosFields')])),
                            ])
                            self.service_value = None
                            self.tos_fields = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Tos, ['service_value', 'tos_fields'], name, value)

                        class TosFields(Enum):
                            """
                            TosFields (Enum Class)

                            .. data:: max_reliability = 0

                            .. data:: max_throughput = 1

                            .. data:: min_delay = 2

                            .. data:: min_monetary_cost = 3

                            .. data:: normal = 4

                            """

                            max_reliability = Enum.YLeaf(0, "max-reliability")

                            max_throughput = Enum.YLeaf(1, "max-throughput")

                            min_delay = Enum.YLeaf(2, "min-delay")

                            min_monetary_cost = Enum.YLeaf(3, "min-monetary-cost")

                            normal = Enum.YLeaf(4, "normal")



                    class Vrf(Entity):
                        """
                        VRF name
                        
                        .. attribute:: vrfs
                        
                        	
                        	**type**\: list of  		 :py:class:`Vrfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Vrf.Vrfs>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrfs", ("vrfs", Native.RouteMap.RouteMapSeq.Set.Ip.Vrf.Vrfs))])
                            self._leafs = OrderedDict()

                            self.vrfs = YList(self)
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Vrf, [], name, value)


                        class Vrfs(Entity):
                            """
                            
                            
                            .. attribute:: vrf  (key)
                            
                            	WORD;;VRF name
                            	**type**\: str
                            
                            .. attribute:: next_hop
                            
                            	Next hop along path
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ip.Vrf.Vrfs.NextHop>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ip.Vrf.Vrfs, self).__init__()

                                self.yang_name = "vrfs"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['vrf']
                                self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Set.Ip.Vrf.Vrfs.NextHop))])
                                self._leafs = OrderedDict([
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.vrf = None

                                self.next_hop = Native.RouteMap.RouteMapSeq.Set.Ip.Vrf.Vrfs.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._segment_path = lambda: "vrfs" + "[vrf='" + str(self.vrf) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Vrf.Vrfs, ['vrf'], name, value)


                            class NextHop(Entity):
                                """
                                Next hop along path
                                
                                .. attribute:: address
                                
                                	
                                	**type**\: list of str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Ip.Vrf.Vrfs.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "vrfs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                    ])
                                    self.address = []
                                    self._segment_path = lambda: "next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ip.Vrf.Vrfs.NextHop, ['address'], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 specific information
                    
                    .. attribute:: address
                    
                    	IPv6 address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Address>`
                    
                    .. attribute:: default
                    
                    	Set default information
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Default>`
                    
                    .. attribute:: global_
                    
                    	global routing table
                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Global>`
                    
                    .. attribute:: next_hop
                    
                    	IPv6 Next hop
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop>`
                    
                    .. attribute:: precedence
                    
                    	Precedence value
                    	**type**\: int
                    
                    	**range:** 0..7
                    
                    .. attribute:: bvrf
                    
                    	
                    	**type**\: list of  		 :py:class:`Bvrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.RouteMap.RouteMapSeq.Set.Ipv6.Address)), ("default", ("default", Native.RouteMap.RouteMapSeq.Set.Ipv6.Default)), ("global", ("global_", Native.RouteMap.RouteMapSeq.Set.Ipv6.Global)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop)), ("bvrf", ("bvrf", Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf))])
                        self._leafs = OrderedDict([
                            ('precedence', (YLeaf(YType.uint8, 'precedence'), ['int'])),
                        ])
                        self.precedence = None

                        self.address = Native.RouteMap.RouteMapSeq.Set.Ipv6.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.default = Native.RouteMap.RouteMapSeq.Set.Ipv6.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.global_ = Native.RouteMap.RouteMapSeq.Set.Ipv6.Global()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"

                        self.next_hop = Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"

                        self.bvrf = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6, ['precedence'], name, value)


                    class Address(Entity):
                        """
                        IPv6 address
                        
                        .. attribute:: prefix_list
                        
                        	IPv6 prefix\-list
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.prefix_list = []
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Address, ['prefix_list'], name, value)


                    class Default(Entity):
                        """
                        Set default information
                        
                        .. attribute:: global_
                        
                        	global routing table
                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Global>`
                        
                        .. attribute:: next_hop
                        
                        	Next hop along path
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.NextHop>`
                        
                        .. attribute:: dvrf
                        
                        	
                        	**type**\: list of  		 :py:class:`Dvrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Dvrf>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("global", ("global_", Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Global)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.NextHop)), ("dvrf", ("dvrf", Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Dvrf))])
                            self._leafs = OrderedDict()

                            self.global_ = Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Global()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"

                            self.next_hop = Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"

                            self.dvrf = YList(self)
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default, [], name, value)


                        class Global(Entity):
                            """
                            global routing table
                            
                            .. attribute:: next_hop
                            
                            	Next hop along path
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Global, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str'])),
                                ])
                                self.next_hop = None
                                self._segment_path = lambda: "global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Global, ['next_hop'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop along path
                            
                            .. attribute:: ipv6s
                            
                            	
                            	**type**\: list of  		 :py:class:`Ipv6s <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.NextHop.Ipv6s>`
                            
                            .. attribute:: next_hop_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv6s", ("ipv6s", Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.NextHop.Ipv6s))])
                                self._leafs = OrderedDict([
                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str'])),
                                ])
                                self.next_hop_address = None

                                self.ipv6s = YList(self)
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.NextHop, ['next_hop_address'], name, value)


                            class Ipv6s(Entity):
                                """
                                
                                
                                .. attribute:: ipv6  (key)
                                
                                	Default next hop IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.NextHop.Ipv6s, self).__init__()

                                    self.yang_name = "ipv6s"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv6']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.ipv6 = None
                                    self._segment_path = lambda: "ipv6s" + "[ipv6='" + str(self.ipv6) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.NextHop.Ipv6s, ['ipv6'], name, value)


                        class Dvrf(Entity):
                            """
                            
                            
                            .. attribute:: dvrf  (key)
                            
                            	VRF name
                            	**type**\: str
                            
                            .. attribute:: dvrf0
                            
                            	
                            	**type**\: list of  		 :py:class:`Dvrf0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Dvrf.Dvrf0>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Dvrf, self).__init__()

                                self.yang_name = "dvrf"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['dvrf']
                                self._child_classes = OrderedDict([("dvrf0", ("dvrf0", Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Dvrf.Dvrf0))])
                                self._leafs = OrderedDict([
                                    ('dvrf', (YLeaf(YType.str, 'dvrf'), ['str'])),
                                ])
                                self.dvrf = None

                                self.dvrf0 = YList(self)
                                self._segment_path = lambda: "dvrf" + "[dvrf='" + str(self.dvrf) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Dvrf, ['dvrf'], name, value)


                            class Dvrf0(Entity):
                                """
                                
                                
                                .. attribute:: dvrf0  (key)
                                
                                	VRF name
                                	**type**\: str
                                
                                .. attribute:: next_hop
                                
                                	Next hop along path
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Dvrf.Dvrf0, self).__init__()

                                    self.yang_name = "dvrf0"
                                    self.yang_parent_name = "dvrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['dvrf0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dvrf0', (YLeaf(YType.str, 'dvrf0'), ['str'])),
                                        ('next_hop', (YLeaf(YType.empty, 'next-hop'), ['Empty'])),
                                    ])
                                    self.dvrf0 = None
                                    self.next_hop = None
                                    self._segment_path = lambda: "dvrf0" + "[dvrf0='" + str(self.dvrf0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Default.Dvrf.Dvrf0, ['dvrf0', 'next_hop'], name, value)


                    class Global(Entity):
                        """
                        global routing table
                        
                        .. attribute:: next_hop
                        
                        	IPv6 Next hop
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Global.NextHop>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Set.Ipv6.Global.NextHop))])
                            self._leafs = OrderedDict()

                            self.next_hop = Native.RouteMap.RouteMapSeq.Set.Ipv6.Global.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._segment_path = lambda: "global"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Global, [], name, value)


                        class NextHop(Entity):
                            """
                            IPv6 Next hop
                            
                            .. attribute:: nh_ipv6
                            
                            	
                            	**type**\: list of  		 :py:class:`NhIpv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Global.NextHop.NhIpv6>`
                            
                            .. attribute:: verify_availability
                            
                            	Next hop address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Global.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("nh-ipv6", ("nh_ipv6", Native.RouteMap.RouteMapSeq.Set.Ipv6.Global.NextHop.NhIpv6))])
                                self._leafs = OrderedDict([
                                    ('verify_availability', (YLeaf(YType.str, 'verify-availability'), ['str'])),
                                ])
                                self.verify_availability = None

                                self.nh_ipv6 = YList(self)
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Global.NextHop, ['verify_availability'], name, value)


                            class NhIpv6(Entity):
                                """
                                
                                
                                .. attribute:: nh_ipv6  (key)
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: nh_ipv60
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Global.NextHop.NhIpv6, self).__init__()

                                    self.yang_name = "nh-ipv6"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['nh_ipv6']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nh_ipv6', (YLeaf(YType.str, 'nh-ipv6'), ['str'])),
                                        ('nh_ipv60', (YLeaf(YType.str, 'nh-ipv60'), ['str'])),
                                    ])
                                    self.nh_ipv6 = None
                                    self.nh_ipv60 = None
                                    self._segment_path = lambda: "nh-ipv6" + "[nh-ipv6='" + str(self.nh_ipv6) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Global.NextHop.NhIpv6, ['nh_ipv6', 'nh_ipv60'], name, value)


                    class NextHop(Entity):
                        """
                        IPv6 Next hop
                        
                        .. attribute:: nha_ipv6
                        
                        	
                        	**type**\: list of  		 :py:class:`NhaIpv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.NhaIpv6>`
                        
                        .. attribute:: encapsulate
                        
                        	Encapsulation profile for VPN nexthop
                        	**type**\:  :py:class:`Encapsulate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.Encapsulate>`
                        
                        .. attribute:: peer_address
                        
                        	Use peer address (for BGP only)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: recursive
                        
                        	IPv6 address of recursive next\-hop
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: verify_availability
                        
                        	Verify if nexthop is reachable
                        	**type**\:  :py:class:`VerifyAvailability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.VerifyAvailability>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nha-ipv6", ("nha_ipv6", Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.NhaIpv6)), ("encapsulate", ("encapsulate", Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.Encapsulate)), ("verify-availability", ("verify_availability", Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.VerifyAvailability))])
                            self._leafs = OrderedDict([
                                ('peer_address', (YLeaf(YType.empty, 'peer-address'), ['Empty'])),
                                ('recursive', (YLeaf(YType.str, 'recursive'), ['str'])),
                            ])
                            self.peer_address = None
                            self.recursive = None

                            self.encapsulate = Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.Encapsulate()
                            self.encapsulate.parent = self
                            self._children_name_map["encapsulate"] = "encapsulate"

                            self.verify_availability = Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.VerifyAvailability()
                            self.verify_availability.parent = self
                            self._children_name_map["verify_availability"] = "verify-availability"

                            self.nha_ipv6 = YList(self)
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop, ['peer_address', 'recursive'], name, value)


                        class NhaIpv6(Entity):
                            """
                            
                            
                            .. attribute:: nha_ipv6  (key)
                            
                            	Next hop address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: nha_ipv60
                            
                            	
                            	**type**\: list of  		 :py:class:`NhaIpv60 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.NhaIpv6.NhaIpv60>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.NhaIpv6, self).__init__()

                                self.yang_name = "nha-ipv6"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['nha_ipv6']
                                self._child_classes = OrderedDict([("nha-ipv60", ("nha_ipv60", Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.NhaIpv6.NhaIpv60))])
                                self._leafs = OrderedDict([
                                    ('nha_ipv6', (YLeaf(YType.str, 'nha-ipv6'), ['str'])),
                                ])
                                self.nha_ipv6 = None

                                self.nha_ipv60 = YList(self)
                                self._segment_path = lambda: "nha-ipv6" + "[nha-ipv6='" + str(self.nha_ipv6) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.NhaIpv6, ['nha_ipv6'], name, value)


                            class NhaIpv60(Entity):
                                """
                                
                                
                                .. attribute:: nha_ipv60  (key)
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: nh_ipv6
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.NhaIpv6.NhaIpv60, self).__init__()

                                    self.yang_name = "nha-ipv60"
                                    self.yang_parent_name = "nha-ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['nha_ipv60']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nha_ipv60', (YLeaf(YType.str, 'nha-ipv60'), ['str'])),
                                        ('nh_ipv6', (YLeaf(YType.str, 'nh-ipv6'), ['str'])),
                                    ])
                                    self.nha_ipv60 = None
                                    self.nh_ipv6 = None
                                    self._segment_path = lambda: "nha-ipv60" + "[nha-ipv60='" + str(self.nha_ipv60) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.NhaIpv6.NhaIpv60, ['nha_ipv60', 'nh_ipv6'], name, value)


                        class Encapsulate(Entity):
                            """
                            Encapsulation profile for VPN nexthop
                            
                            .. attribute:: l3vpn
                            
                            	Encapsulation profile name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.Encapsulate, self).__init__()

                                self.yang_name = "encapsulate"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('l3vpn', (YLeaf(YType.str, 'l3vpn'), ['str'])),
                                ])
                                self.l3vpn = None
                                self._segment_path = lambda: "encapsulate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.Encapsulate, ['l3vpn'], name, value)


                        class VerifyAvailability(Entity):
                            """
                            Verify if nexthop is reachable
                            
                            .. attribute:: va_ipv6
                            
                            	
                            	**type**\: list of  		 :py:class:`VaIpv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.VerifyAvailability.VaIpv6>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.VerifyAvailability, self).__init__()

                                self.yang_name = "verify-availability"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("va-ipv6", ("va_ipv6", Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.VerifyAvailability.VaIpv6))])
                                self._leafs = OrderedDict()

                                self.va_ipv6 = YList(self)
                                self._segment_path = lambda: "verify-availability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.VerifyAvailability, [], name, value)


                            class VaIpv6(Entity):
                                """
                                
                                
                                .. attribute:: va_ipv6  (key)
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: seq_nh
                                
                                	Sequence to insert into next\-hop list
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.VerifyAvailability.VaIpv6, self).__init__()

                                    self.yang_name = "va-ipv6"
                                    self.yang_parent_name = "verify-availability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['va_ipv6']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('va_ipv6', (YLeaf(YType.str, 'va-ipv6'), ['str'])),
                                        ('seq_nh', (YLeaf(YType.uint16, 'seq-nh'), ['int'])),
                                    ])
                                    self.va_ipv6 = None
                                    self.seq_nh = None
                                    self._segment_path = lambda: "va-ipv6" + "[va-ipv6='" + str(self.va_ipv6) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.NextHop.VerifyAvailability.VaIpv6, ['va_ipv6', 'seq_nh'], name, value)


                    class Bvrf(Entity):
                        """
                        
                        
                        .. attribute:: bvrf  (key)
                        
                        	VRF name
                        	**type**\: str
                        
                        .. attribute:: bvrf0
                        
                        	
                        	**type**\: list of  		 :py:class:`Bvrf0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf.Bvrf0>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf, self).__init__()

                            self.yang_name = "bvrf"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['bvrf']
                            self._child_classes = OrderedDict([("bvrf0", ("bvrf0", Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf.Bvrf0))])
                            self._leafs = OrderedDict([
                                ('bvrf', (YLeaf(YType.str, 'bvrf'), ['str'])),
                            ])
                            self.bvrf = None

                            self.bvrf0 = YList(self)
                            self._segment_path = lambda: "bvrf" + "[bvrf='" + str(self.bvrf) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf, ['bvrf'], name, value)


                        class Bvrf0(Entity):
                            """
                            
                            
                            .. attribute:: bvrf0  (key)
                            
                            	VRF name
                            	**type**\: str
                            
                            .. attribute:: next_hop
                            
                            	IPv6 Next hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf.Bvrf0.NextHop>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf.Bvrf0, self).__init__()

                                self.yang_name = "bvrf0"
                                self.yang_parent_name = "bvrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['bvrf0']
                                self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf.Bvrf0.NextHop))])
                                self._leafs = OrderedDict([
                                    ('bvrf0', (YLeaf(YType.str, 'bvrf0'), ['str'])),
                                ])
                                self.bvrf0 = None

                                self.next_hop = Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf.Bvrf0.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._segment_path = lambda: "bvrf0" + "[bvrf0='" + str(self.bvrf0) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf.Bvrf0, ['bvrf0'], name, value)


                            class NextHop(Entity):
                                """
                                IPv6 Next hop
                                
                                .. attribute:: bipv6
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: verify_availability
                                
                                	Verify if nexthop is reachable
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf.Bvrf0.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "bvrf0"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bipv6', (YLeaf(YType.str, 'bipv6'), ['str'])),
                                        ('verify_availability', (YLeaf(YType.empty, 'verify-availability'), ['Empty'])),
                                    ])
                                    self.bipv6 = None
                                    self.verify_availability = None
                                    self._segment_path = lambda: "next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Ipv6.Bvrf.Bvrf0.NextHop, ['bipv6', 'verify_availability'], name, value)


                class Level(Entity):
                    """
                    Where to import route
                    
                    .. attribute:: level_1
                    
                    	Import into a level\-1 area
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level_1_2
                    
                    	Import into level\-1 and level\-2
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level_2
                    
                    	Import into level\-2 sub\-domain
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nssa_only
                    
                    	Import only into OSPF NSSA areas and don't propagate
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                            ('level_1_2', (YLeaf(YType.empty, 'level-1-2'), ['Empty'])),
                            ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                        ])
                        self.level_1 = None
                        self.level_1_2 = None
                        self.level_2 = None
                        self.nssa_only = None
                        self._segment_path = lambda: "level"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Level, ['level_1', 'level_1_2', 'level_2', 'nssa_only'], name, value)


                class Lisp(Entity):
                    """
                    Locator ID Separation Protocol specific information
                    
                    .. attribute:: locator_set
                    
                    	The name of the locator set
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                        ])
                        self.locator_set = None
                        self._segment_path = lambda: "lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Lisp, ['locator_set'], name, value)


                class Metric(Entity):
                    """
                    Metric value for destination routing protocol
                    
                    .. attribute:: metric_change
                    
                    	+/\-<metric>;;Add or subtract metric
                    	**type**\: str
                    
                    	**pattern:** (\\+\|\-)\\d{1,10}
                    
                    .. attribute:: values
                    
                    	
                    	**type**\:  :py:class:`Values <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Metric.Values>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("values", ("values", Native.RouteMap.RouteMapSeq.Set.Metric.Values))])
                        self._leafs = OrderedDict([
                            ('metric_change', (YLeaf(YType.str, 'metric-change'), ['str'])),
                        ])
                        self.metric_change = None

                        self.values = Native.RouteMap.RouteMapSeq.Set.Metric.Values()
                        self.values.parent = self
                        self._children_name_map["values"] = "values"
                        self._segment_path = lambda: "metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Metric, ['metric_change'], name, value)


                    class Values(Entity):
                        """
                        
                        
                        .. attribute:: value
                        
                        	Metric value or Bandwidth in Kbits per second
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: delay
                        
                        	EIGRP delay metric, in 10 microsecond units
                        	**type**\: str
                        
                        	**pattern:** (\\+\|\-)?\\d{1,10}
                        
                        .. attribute:: reliability
                        
                        	EIGRP reliability metric where 255 is 100% reliable
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: loading
                        
                        	EIGRP Effective bandwidth metric (Loading) where 255 is 100% loaded
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: mtu
                        
                        	EIGRP MTU of the path
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Set.Metric.Values, self).__init__()

                            self.yang_name = "values"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ('delay', (YLeaf(YType.str, 'delay'), ['str'])),
                                ('reliability', (YLeaf(YType.uint8, 'reliability'), ['int'])),
                                ('loading', (YLeaf(YType.uint8, 'loading'), ['int'])),
                                ('mtu', (YLeaf(YType.uint32, 'MTU'), ['int'])),
                            ])
                            self.value = None
                            self.delay = None
                            self.reliability = None
                            self.loading = None
                            self.mtu = None
                            self._segment_path = lambda: "values"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Metric.Values, ['value', 'delay', 'reliability', 'loading', 'mtu'], name, value)


                class Origin(Entity):
                    """
                    BGP origin code
                    
                    .. attribute:: origin_value
                    
                    	
                    	**type**\:  :py:class:`OriginValue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Set.Origin.OriginValue>`
                    
                    .. attribute:: egp
                    
                    	remote EGP
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Origin, self).__init__()

                        self.yang_name = "origin"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('origin_value', (YLeaf(YType.enumeration, 'origin-value'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapSeq.Set.Origin.OriginValue')])),
                            ('egp', (YLeaf(YType.uint32, 'egp'), ['int'])),
                        ])
                        self.origin_value = None
                        self.egp = None
                        self._segment_path = lambda: "origin"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Origin, ['origin_value', 'egp'], name, value)

                    class OriginValue(Enum):
                        """
                        OriginValue (Enum Class)

                        .. data:: igp = 0

                        .. data:: incomplete = 1

                        """

                        igp = Enum.YLeaf(0, "igp")

                        incomplete = Enum.YLeaf(1, "incomplete")



                class Tag(Entity):
                    """
                    Tag value for destination routing protocol
                    
                    .. attribute:: tag_val
                    
                    	Tag value
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tag_ipv4
                    
                    	Tag value(dotted decimal format)
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Set.Tag, self).__init__()

                        self.yang_name = "tag"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag_val', (YLeaf(YType.uint32, 'tag-val'), ['int'])),
                            ('tag_ipv4', (YLeaf(YType.str, 'tag-ipv4'), ['str'])),
                        ])
                        self.tag_val = None
                        self.tag_ipv4 = None
                        self._segment_path = lambda: "tag"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Set.Tag, ['tag_val', 'tag_ipv4'], name, value)


            class Match(Entity):
                """
                Match values from routing table
                
                .. attribute:: additional_paths
                
                	BGP Add\-Path match policies
                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.AdditionalPaths>`
                
                .. attribute:: as_path
                
                	Match BGP AS path list
                	**type**\:  :py:class:`AsPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.AsPath>`
                
                .. attribute:: clns
                
                	CLNS information
                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Clns>`
                
                .. attribute:: community
                
                	Match BGP community list
                	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Community>`
                
                .. attribute:: extcommunity
                
                	Match BGP/VPN extended community list
                	**type**\:  :py:class:`Extcommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Extcommunity>`
                
                .. attribute:: interface
                
                	SPAN source interface
                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Interface>`
                
                .. attribute:: ip
                
                	IP specific information
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ip>`
                
                .. attribute:: ipv6
                
                	IPv6 specific information
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ipv6>`
                
                .. attribute:: length
                
                	Packet length
                	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Length>`
                
                .. attribute:: local_preference
                
                	Local preference for route
                	**type**\:  :py:class:`LocalPreference <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.LocalPreference>`
                
                .. attribute:: mdt_group
                
                	Match routes corresponding to MDT group
                	**type**\:  :py:class:`MdtGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.MdtGroup>`
                
                .. attribute:: metric
                
                	Match metric of route
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Metric>`
                
                .. attribute:: mpls_label
                
                	Match routes which have MPLS labels
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: policy_list
                
                	Match IP policy list
                	**type**\:  :py:class:`PolicyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.PolicyList>`
                
                .. attribute:: route_type
                
                	Match route\-type of route
                	**type**\:  :py:class:`RouteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.RouteType>`
                
                .. attribute:: rpki
                
                	Match RPKI state of route
                	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Rpki>`
                
                .. attribute:: source_protocol
                
                	Match source\-protocol of route
                	**type**\:  :py:class:`SourceProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.SourceProtocol>`
                
                	**presence node**\: True
                
                .. attribute:: tag
                
                	Match tag of route
                	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Tag>`
                
                .. attribute:: track
                
                	tracking object
                	**type**\: int
                
                	**range:** 1..1000
                
                

                """

                _prefix = 'ios-route-map'
                _revision = '2018-03-08'

                def __init__(self):
                    super(Native.RouteMap.RouteMapSeq.Match, self).__init__()

                    self.yang_name = "match"
                    self.yang_parent_name = "route-map-seq"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.RouteMap.RouteMapSeq.Match.AdditionalPaths)), ("as-path", ("as_path", Native.RouteMap.RouteMapSeq.Match.AsPath)), ("clns", ("clns", Native.RouteMap.RouteMapSeq.Match.Clns)), ("community", ("community", Native.RouteMap.RouteMapSeq.Match.Community)), ("extcommunity", ("extcommunity", Native.RouteMap.RouteMapSeq.Match.Extcommunity)), ("interface", ("interface", Native.RouteMap.RouteMapSeq.Match.Interface)), ("ip", ("ip", Native.RouteMap.RouteMapSeq.Match.Ip)), ("ipv6", ("ipv6", Native.RouteMap.RouteMapSeq.Match.Ipv6)), ("length", ("length", Native.RouteMap.RouteMapSeq.Match.Length)), ("local-preference", ("local_preference", Native.RouteMap.RouteMapSeq.Match.LocalPreference)), ("mdt-group", ("mdt_group", Native.RouteMap.RouteMapSeq.Match.MdtGroup)), ("metric", ("metric", Native.RouteMap.RouteMapSeq.Match.Metric)), ("policy-list", ("policy_list", Native.RouteMap.RouteMapSeq.Match.PolicyList)), ("route-type", ("route_type", Native.RouteMap.RouteMapSeq.Match.RouteType)), ("rpki", ("rpki", Native.RouteMap.RouteMapSeq.Match.Rpki)), ("source-protocol", ("source_protocol", Native.RouteMap.RouteMapSeq.Match.SourceProtocol)), ("tag", ("tag", Native.RouteMap.RouteMapSeq.Match.Tag))])
                    self._leafs = OrderedDict([
                        ('mpls_label', (YLeaf(YType.empty, 'mpls-label'), ['Empty'])),
                        ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                    ])
                    self.mpls_label = None
                    self.track = None

                    self.additional_paths = Native.RouteMap.RouteMapSeq.Match.AdditionalPaths()
                    self.additional_paths.parent = self
                    self._children_name_map["additional_paths"] = "additional-paths"

                    self.as_path = Native.RouteMap.RouteMapSeq.Match.AsPath()
                    self.as_path.parent = self
                    self._children_name_map["as_path"] = "as-path"

                    self.clns = Native.RouteMap.RouteMapSeq.Match.Clns()
                    self.clns.parent = self
                    self._children_name_map["clns"] = "clns"

                    self.community = Native.RouteMap.RouteMapSeq.Match.Community()
                    self.community.parent = self
                    self._children_name_map["community"] = "community"

                    self.extcommunity = Native.RouteMap.RouteMapSeq.Match.Extcommunity()
                    self.extcommunity.parent = self
                    self._children_name_map["extcommunity"] = "extcommunity"

                    self.interface = Native.RouteMap.RouteMapSeq.Match.Interface()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.ip = Native.RouteMap.RouteMapSeq.Match.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.ipv6 = Native.RouteMap.RouteMapSeq.Match.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.length = Native.RouteMap.RouteMapSeq.Match.Length()
                    self.length.parent = self
                    self._children_name_map["length"] = "length"

                    self.local_preference = Native.RouteMap.RouteMapSeq.Match.LocalPreference()
                    self.local_preference.parent = self
                    self._children_name_map["local_preference"] = "local-preference"

                    self.mdt_group = Native.RouteMap.RouteMapSeq.Match.MdtGroup()
                    self.mdt_group.parent = self
                    self._children_name_map["mdt_group"] = "mdt-group"

                    self.metric = Native.RouteMap.RouteMapSeq.Match.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "metric"

                    self.policy_list = Native.RouteMap.RouteMapSeq.Match.PolicyList()
                    self.policy_list.parent = self
                    self._children_name_map["policy_list"] = "policy-list"

                    self.route_type = Native.RouteMap.RouteMapSeq.Match.RouteType()
                    self.route_type.parent = self
                    self._children_name_map["route_type"] = "route-type"

                    self.rpki = Native.RouteMap.RouteMapSeq.Match.Rpki()
                    self.rpki.parent = self
                    self._children_name_map["rpki"] = "rpki"

                    self.source_protocol = None
                    self._children_name_map["source_protocol"] = "source-protocol"

                    self.tag = Native.RouteMap.RouteMapSeq.Match.Tag()
                    self.tag.parent = self
                    self._children_name_map["tag"] = "tag"
                    self._segment_path = lambda: "match"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Match, ['mpls_label', 'track'], name, value)


                class AdditionalPaths(Entity):
                    """
                    BGP Add\-Path match policies
                    
                    .. attribute:: advertise_set
                    
                    	BGP Add\-Path advertise\-set policy
                    	**type**\:  :py:class:`AdvertiseSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths, self).__init__()

                        self.yang_name = "additional-paths"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("advertise-set", ("advertise_set", Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet))])
                        self._leafs = OrderedDict()

                        self.advertise_set = Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet()
                        self.advertise_set.parent = self
                        self._children_name_map["advertise_set"] = "advertise-set"
                        self._segment_path = lambda: "additional-paths"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths, [], name, value)


                    class AdvertiseSet(Entity):
                        """
                        BGP Add\-Path advertise\-set policy
                        
                        .. attribute:: all
                        
                        	BGP Add\-Path advertise all paths
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.All>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: best
                        
                        	BGP Add\-Path advertise best n paths
                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.Best>`
                        
                        .. attribute:: best_range
                        
                        	BGP Add\-Path advertise best paths (range m to n)
                        	**type**\:  :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.BestRange>`
                        
                        .. attribute:: group_best
                        
                        	BGP Add\-Path advertise group\-best path
                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.GroupBest>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet, self).__init__()

                            self.yang_name = "advertise-set"
                            self.yang_parent_name = "additional-paths"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("all", ("all", Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.All)), ("best", ("best", Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.Best)), ("best-range", ("best_range", Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.BestRange)), ("group-best", ("group_best", Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.GroupBest))])
                            self._leafs = OrderedDict()

                            self.all = None
                            self._children_name_map["all"] = "all"

                            self.best = Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.Best()
                            self.best.parent = self
                            self._children_name_map["best"] = "best"

                            self.best_range = Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.BestRange()
                            self.best_range.parent = self
                            self._children_name_map["best_range"] = "best-range"

                            self.group_best = None
                            self._children_name_map["group_best"] = "group-best"
                            self._segment_path = lambda: "advertise-set"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet, [], name, value)


                        class All(Entity):
                            """
                            BGP Add\-Path advertise all paths
                            
                            .. attribute:: best
                            
                            	BGP Add\-Path best n paths to advertise
                            	**type**\: int
                            
                            	**range:** 1..3
                            
                            .. attribute:: best_range
                            
                            	BGP Add\-Path best paths to advertise (lower limit)
                            	**type**\: int
                            
                            	**range:** 1..3
                            
                            .. attribute:: group_best
                            
                            	BGP Add\-Path advertise group\-best path
                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.All.GroupBest>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.All, self).__init__()

                                self.yang_name = "all"
                                self.yang_parent_name = "advertise-set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.All.GroupBest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                    ('best_range', (YLeaf(YType.uint8, 'best-range'), ['int'])),
                                ])
                                self.best = None
                                self.best_range = None

                                self.group_best = None
                                self._children_name_map["group_best"] = "group-best"
                                self._segment_path = lambda: "all"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.All, ['best', 'best_range'], name, value)


                            class GroupBest(Entity):
                                """
                                BGP Add\-Path advertise group\-best path
                                
                                .. attribute:: best
                                
                                	BGP Add\-Path advertise best n paths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: best_range
                                
                                	BGP Add\-Path advertise best paths (range m to n)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.All.GroupBest, self).__init__()

                                    self.yang_name = "group-best"
                                    self.yang_parent_name = "all"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('best', (YLeaf(YType.empty, 'best'), ['Empty'])),
                                        ('best_range', (YLeaf(YType.empty, 'best-range'), ['Empty'])),
                                    ])
                                    self.best = None
                                    self.best_range = None
                                    self._segment_path = lambda: "group-best"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.All.GroupBest, ['best', 'best_range'], name, value)


                        class Best(Entity):
                            """
                            BGP Add\-Path advertise best n paths
                            
                            .. attribute:: best_range
                            
                            	
                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.Best.BestRange>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.Best, self).__init__()

                                self.yang_name = "best"
                                self.yang_parent_name = "advertise-set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.Best.BestRange))])
                                self._leafs = OrderedDict()

                                self.best_range = YList(self)
                                self._segment_path = lambda: "best"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.Best, [], name, value)


                            class BestRange(Entity):
                                """
                                
                                
                                .. attribute:: best_range  (key)
                                
                                	BGP Add\-Path best n paths to advertise
                                	**type**\: int
                                
                                	**range:** 1..3
                                
                                .. attribute:: all
                                
                                	BGP Add\-Path advertise all paths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: group_best
                                
                                	BGP Add\-Path advertise group\-best path
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.Best.BestRange, self).__init__()

                                    self.yang_name = "best-range"
                                    self.yang_parent_name = "best"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['best_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('best_range', (YLeaf(YType.uint8, 'best-range'), ['int'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                    ])
                                    self.best_range = None
                                    self.all = None
                                    self.group_best = None
                                    self._segment_path = lambda: "best-range" + "[best-range='" + str(self.best_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.Best.BestRange, ['best_range', 'all', 'group_best'], name, value)


                        class BestRange(Entity):
                            """
                            BGP Add\-Path advertise best paths (range m to n)
                            
                            .. attribute:: adv_path
                            
                            	
                            	**type**\: list of  		 :py:class:`AdvPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.BestRange.AdvPath>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.BestRange, self).__init__()

                                self.yang_name = "best-range"
                                self.yang_parent_name = "advertise-set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adv-path", ("adv_path", Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.BestRange.AdvPath))])
                                self._leafs = OrderedDict()

                                self.adv_path = YList(self)
                                self._segment_path = lambda: "best-range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.BestRange, [], name, value)


                            class AdvPath(Entity):
                                """
                                
                                
                                .. attribute:: adv_path  (key)
                                
                                	BGP Add\-Path best paths to advertise (lower limit)
                                	**type**\: int
                                
                                	**range:** 1..3
                                
                                .. attribute:: adv_path0
                                
                                	BGP Add\-Path best paths to advertise (upper limit)
                                	**type**\: int
                                
                                	**range:** 1..3
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.BestRange.AdvPath, self).__init__()

                                    self.yang_name = "adv-path"
                                    self.yang_parent_name = "best-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['adv_path']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('adv_path', (YLeaf(YType.uint8, 'adv-path'), ['int'])),
                                        ('adv_path0', (YLeaf(YType.uint8, 'adv-path0'), ['int'])),
                                    ])
                                    self.adv_path = None
                                    self.adv_path0 = None
                                    self._segment_path = lambda: "adv-path" + "[adv-path='" + str(self.adv_path) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.BestRange.AdvPath, ['adv_path', 'adv_path0'], name, value)


                        class GroupBest(Entity):
                            """
                            BGP Add\-Path advertise group\-best path
                            
                            .. attribute:: all
                            
                            	BGP Add\-Path advertise all paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best
                            
                            	BGP Add\-Path best n paths to advertise
                            	**type**\: int
                            
                            	**range:** 1..3
                            
                            .. attribute:: best_range
                            
                            	BGP Add\-Path best paths to advertise (lower limit)
                            	**type**\: int
                            
                            	**range:** 1..3
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.GroupBest, self).__init__()

                                self.yang_name = "group-best"
                                self.yang_parent_name = "advertise-set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                    ('best_range', (YLeaf(YType.uint8, 'best-range'), ['int'])),
                                ])
                                self.all = None
                                self.best = None
                                self.best_range = None
                                self._segment_path = lambda: "group-best"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.AdditionalPaths.AdvertiseSet.GroupBest, ['all', 'best', 'best_range'], name, value)


                class AsPath(Entity):
                    """
                    Match BGP AS path list
                    
                    .. attribute:: access_list
                    
                    	AS path access\-list
                    	**type**\: list of int
                    
                    	**range:** 1..500
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.AsPath, self).__init__()

                        self.yang_name = "as-path"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('access_list', (YLeafList(YType.uint16, 'access-list'), ['int'])),
                        ])
                        self.access_list = []
                        self._segment_path = lambda: "as-path"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.AsPath, ['access_list'], name, value)


                class Clns(Entity):
                    """
                    CLNS information
                    
                    .. attribute:: name
                    
                    	Named clna list
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.Clns, self).__init__()

                        self.yang_name = "clns"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeafList(YType.str, 'name'), ['str'])),
                        ])
                        self.name = []
                        self._segment_path = lambda: "clns"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Clns, ['name'], name, value)


                class Community(Entity):
                    """
                    Match BGP community list
                    
                    .. attribute:: name
                    
                    	Named Access List
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.Community, self).__init__()

                        self.yang_name = "community"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeafList(YType.str, 'name'), ['str'])),
                        ])
                        self.name = []
                        self._segment_path = lambda: "community"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Community, ['name'], name, value)


                class Extcommunity(Entity):
                    """
                    Match BGP/VPN extended community list
                    
                    .. attribute:: name
                    
                    	Named Access List
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.Extcommunity, self).__init__()

                        self.yang_name = "extcommunity"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeafList(YType.str, 'name'), ['str'])),
                        ])
                        self.name = []
                        self._segment_path = lambda: "extcommunity"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Extcommunity, ['name'], name, value)


                class Interface(Entity):
                    """
                    SPAN source interface
                    
                    .. attribute:: interface
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface', (YLeafList(YType.str, 'interface'), ['str'])),
                        ])
                        self.interface = []
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Interface, ['interface'], name, value)


                class Ip(Entity):
                    """
                    IP specific information
                    
                    .. attribute:: address
                    
                    	Match address of route or match packet
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ip.Address>`
                    
                    .. attribute:: flowspec
                    
                    	Match address of route
                    	**type**\:  :py:class:`Flowspec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec>`
                    
                    .. attribute:: next_hop
                    
                    	Match next\-hop address of route
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ip.NextHop>`
                    
                    .. attribute:: redistribution_source
                    
                    	route redistribution source (EIGRP only)
                    	**type**\:  :py:class:`RedistributionSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ip.RedistributionSource>`
                    
                    .. attribute:: route_source
                    
                    	Match advertising source address of route
                    	**type**\:  :py:class:`RouteSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ip.RouteSource>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.RouteMap.RouteMapSeq.Match.Ip.Address)), ("flowspec", ("flowspec", Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Match.Ip.NextHop)), ("redistribution-source", ("redistribution_source", Native.RouteMap.RouteMapSeq.Match.Ip.RedistributionSource)), ("route-source", ("route_source", Native.RouteMap.RouteMapSeq.Match.Ip.RouteSource))])
                        self._leafs = OrderedDict()

                        self.address = Native.RouteMap.RouteMapSeq.Match.Ip.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.flowspec = Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec()
                        self.flowspec.parent = self
                        self._children_name_map["flowspec"] = "flowspec"

                        self.next_hop = Native.RouteMap.RouteMapSeq.Match.Ip.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"

                        self.redistribution_source = Native.RouteMap.RouteMapSeq.Match.Ip.RedistributionSource()
                        self.redistribution_source.parent = self
                        self._children_name_map["redistribution_source"] = "redistribution-source"

                        self.route_source = Native.RouteMap.RouteMapSeq.Match.Ip.RouteSource()
                        self.route_source.parent = self
                        self._children_name_map["route_source"] = "route-source"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ip, [], name, value)


                    class Address(Entity):
                        """
                        Match address of route or match packet
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: list of str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	Match entries of prefix\-lists
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.Ip.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = []
                            self.prefix_list = []
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ip.Address, ['access_list', 'prefix_list'], name, value)


                    class Flowspec(Entity):
                        """
                        Match address of route
                        
                        .. attribute:: dest_pfx
                        
                        	Match dest prefix component of flowspec prefix
                        	**type**\:  :py:class:`DestPfx <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec.DestPfx>`
                        
                        .. attribute:: src_pfx
                        
                        	Match source prefix component of flowspec prefix
                        	**type**\:  :py:class:`SrcPfx <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec.SrcPfx>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec, self).__init__()

                            self.yang_name = "flowspec"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dest-pfx", ("dest_pfx", Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec.DestPfx)), ("src-pfx", ("src_pfx", Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec.SrcPfx))])
                            self._leafs = OrderedDict()

                            self.dest_pfx = Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec.DestPfx()
                            self.dest_pfx.parent = self
                            self._children_name_map["dest_pfx"] = "dest-pfx"

                            self.src_pfx = Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec.SrcPfx()
                            self.src_pfx.parent = self
                            self._children_name_map["src_pfx"] = "src-pfx"
                            self._segment_path = lambda: "flowspec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec, [], name, value)


                        class DestPfx(Entity):
                            """
                            Match dest prefix component of flowspec prefix
                            
                            .. attribute:: access_list
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: list of str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: prefix_list
                            
                            	Match entries of prefix\-lists
                            	**type**\: list of str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec.DestPfx, self).__init__()

                                self.yang_name = "dest-pfx"
                                self.yang_parent_name = "flowspec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                    ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.access_list = []
                                self.prefix_list = []
                                self._segment_path = lambda: "dest-pfx"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec.DestPfx, ['access_list', 'prefix_list'], name, value)


                        class SrcPfx(Entity):
                            """
                            Match source prefix component of flowspec prefix
                            
                            .. attribute:: access_list
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: list of str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: prefix_list
                            
                            	Match entries of prefix\-lists
                            	**type**\: list of str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec.SrcPfx, self).__init__()

                                self.yang_name = "src-pfx"
                                self.yang_parent_name = "flowspec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                    ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.access_list = []
                                self.prefix_list = []
                                self._segment_path = lambda: "src-pfx"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ip.Flowspec.SrcPfx, ['access_list', 'prefix_list'], name, value)


                    class NextHop(Entity):
                        """
                        Match next\-hop address of route
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: list of str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	Match entries of prefix\-lists
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.Ip.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = []
                            self.prefix_list = []
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ip.NextHop, ['access_list', 'prefix_list'], name, value)


                    class RedistributionSource(Entity):
                        """
                        route redistribution source (EIGRP only)
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: list of str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	Match entries of prefix\-lists
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.Ip.RedistributionSource, self).__init__()

                            self.yang_name = "redistribution-source"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = []
                            self.prefix_list = []
                            self._segment_path = lambda: "redistribution-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ip.RedistributionSource, ['access_list', 'prefix_list'], name, value)


                    class RouteSource(Entity):
                        """
                        Match advertising source address of route
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: list of str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	Match entries of prefix\-lists
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.Ip.RouteSource, self).__init__()

                            self.yang_name = "route-source"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = []
                            self.prefix_list = []
                            self._segment_path = lambda: "route-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ip.RouteSource, ['access_list', 'prefix_list'], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 specific information
                    
                    .. attribute:: address
                    
                    	Match address of route
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ipv6.Address>`
                    
                    .. attribute:: flowspec
                    
                    	Match address of route
                    	**type**\:  :py:class:`Flowspec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec>`
                    
                    .. attribute:: next_hop
                    
                    	Match next\-hop address of route
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ipv6.NextHop>`
                    
                    .. attribute:: route_source
                    
                    	Match advertising source address of route
                    	**type**\:  :py:class:`RouteSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ipv6.RouteSource>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.RouteMap.RouteMapSeq.Match.Ipv6.Address)), ("flowspec", ("flowspec", Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapSeq.Match.Ipv6.NextHop)), ("route-source", ("route_source", Native.RouteMap.RouteMapSeq.Match.Ipv6.RouteSource))])
                        self._leafs = OrderedDict()

                        self.address = Native.RouteMap.RouteMapSeq.Match.Ipv6.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.flowspec = Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec()
                        self.flowspec.parent = self
                        self._children_name_map["flowspec"] = "flowspec"

                        self.next_hop = Native.RouteMap.RouteMapSeq.Match.Ipv6.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"

                        self.route_source = Native.RouteMap.RouteMapSeq.Match.Ipv6.RouteSource()
                        self.route_source.parent = self
                        self._children_name_map["route_source"] = "route-source"
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ipv6, [], name, value)


                    class Address(Entity):
                        """
                        Match address of route
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	IPv6 prefix\-list
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.Ipv6.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = None
                            self.prefix_list = None
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ipv6.Address, ['access_list', 'prefix_list'], name, value)


                    class Flowspec(Entity):
                        """
                        Match address of route
                        
                        .. attribute:: dest_pfx
                        
                        	Match dest prefix component of flowspec prefix
                        	**type**\:  :py:class:`DestPfx <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec.DestPfx>`
                        
                        .. attribute:: src_pfx
                        
                        	Match source prefix component of flowspec prefix
                        	**type**\:  :py:class:`SrcPfx <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec.SrcPfx>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec, self).__init__()

                            self.yang_name = "flowspec"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dest-pfx", ("dest_pfx", Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec.DestPfx)), ("src-pfx", ("src_pfx", Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec.SrcPfx))])
                            self._leafs = OrderedDict()

                            self.dest_pfx = Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec.DestPfx()
                            self.dest_pfx.parent = self
                            self._children_name_map["dest_pfx"] = "dest-pfx"

                            self.src_pfx = Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec.SrcPfx()
                            self.src_pfx.parent = self
                            self._children_name_map["src_pfx"] = "src-pfx"
                            self._segment_path = lambda: "flowspec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec, [], name, value)


                        class DestPfx(Entity):
                            """
                            Match dest prefix component of flowspec prefix
                            
                            .. attribute:: access_list
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: prefix_list
                            
                            	IPv6 prefix\-list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec.DestPfx, self).__init__()

                                self.yang_name = "dest-pfx"
                                self.yang_parent_name = "flowspec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.access_list = None
                                self.prefix_list = None
                                self._segment_path = lambda: "dest-pfx"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec.DestPfx, ['access_list', 'prefix_list'], name, value)


                        class SrcPfx(Entity):
                            """
                            Match source prefix component of flowspec prefix
                            
                            .. attribute:: access_list
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: prefix_list
                            
                            	IPv6 prefix\-list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec.SrcPfx, self).__init__()

                                self.yang_name = "src-pfx"
                                self.yang_parent_name = "flowspec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.access_list = None
                                self.prefix_list = None
                                self._segment_path = lambda: "src-pfx"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ipv6.Flowspec.SrcPfx, ['access_list', 'prefix_list'], name, value)


                    class NextHop(Entity):
                        """
                        Match next\-hop address of route
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	IPv6 prefix\-list
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.Ipv6.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = None
                            self.prefix_list = None
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ipv6.NextHop, ['access_list', 'prefix_list'], name, value)


                    class RouteSource(Entity):
                        """
                        Match advertising source address of route
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	IPv6 prefix\-list
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.Ipv6.RouteSource, self).__init__()

                            self.yang_name = "route-source"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = None
                            self.prefix_list = None
                            self._segment_path = lambda: "route-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Ipv6.RouteSource, ['access_list', 'prefix_list'], name, value)


                class Length(Entity):
                    """
                    Packet length
                    
                    .. attribute:: lengths
                    
                    	
                    	**type**\: list of  		 :py:class:`Lengths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Length.Lengths>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.Length, self).__init__()

                        self.yang_name = "length"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("lengths", ("lengths", Native.RouteMap.RouteMapSeq.Match.Length.Lengths))])
                        self._leafs = OrderedDict()

                        self.lengths = YList(self)
                        self._segment_path = lambda: "length"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Length, [], name, value)


                    class Lengths(Entity):
                        """
                        
                        
                        .. attribute:: min_len  (key)
                        
                        	Minimum packet length
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        .. attribute:: max_len  (key)
                        
                        	Maximum packet length
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.Length.Lengths, self).__init__()

                            self.yang_name = "lengths"
                            self.yang_parent_name = "length"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['min_len','max_len']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('min_len', (YLeaf(YType.uint32, 'min-len'), ['int'])),
                                ('max_len', (YLeaf(YType.uint32, 'max-len'), ['int'])),
                            ])
                            self.min_len = None
                            self.max_len = None
                            self._segment_path = lambda: "lengths" + "[min-len='" + str(self.min_len) + "']" + "[max-len='" + str(self.max_len) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Length.Lengths, ['min_len', 'max_len'], name, value)


                class LocalPreference(Entity):
                    """
                    Local preference for route
                    
                    .. attribute:: values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.LocalPreference, self).__init__()

                        self.yang_name = "local-preference"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('values', (YLeafList(YType.uint32, 'values'), ['int'])),
                        ])
                        self.values = []
                        self._segment_path = lambda: "local-preference"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.LocalPreference, ['values'], name, value)


                class MdtGroup(Entity):
                    """
                    Match routes corresponding to MDT group
                    
                    .. attribute:: name
                    
                    	IP Access List
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.MdtGroup, self).__init__()

                        self.yang_name = "mdt-group"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeafList(YType.str, 'name'), ['str'])),
                        ])
                        self.name = []
                        self._segment_path = lambda: "mdt-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.MdtGroup, ['name'], name, value)


                class Metric(Entity):
                    """
                    Match metric of route
                    
                    .. attribute:: metric_value
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: external
                    
                    	match route using external protocol metric
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('metric_value', (YLeaf(YType.str, 'metric-value'), ['str'])),
                            ('external', (YLeaf(YType.str, 'external'), ['str'])),
                        ])
                        self.metric_value = None
                        self.external = None
                        self._segment_path = lambda: "metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Metric, ['metric_value', 'external'], name, value)


                class PolicyList(Entity):
                    """
                    Match IP policy list
                    
                    .. attribute:: policy_map_names
                    
                    	IP Policy map name
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.PolicyList, self).__init__()

                        self.yang_name = "policy-list"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_names', (YLeafList(YType.str, 'policy-map-names'), ['str'])),
                        ])
                        self.policy_map_names = []
                        self._segment_path = lambda: "policy-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.PolicyList, ['policy_map_names'], name, value)


                class RouteType(Entity):
                    """
                    Match route\-type of route
                    
                    .. attribute:: external
                    
                    	external route (BGP, EIGRP and OSPF type 1/2)
                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.RouteType.External>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: internal
                    
                    	internal route (including OSPF intra/inter area)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level_1
                    
                    	IS\-IS level\-1 route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level_2
                    
                    	IS\-IS level\-2 route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	locally generated route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nssa_external
                    
                    	nssa\-external route (OSPF type 1/2)
                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.RouteType.NssaExternal>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.RouteType, self).__init__()

                        self.yang_name = "route-type"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("external", ("external", Native.RouteMap.RouteMapSeq.Match.RouteType.External)), ("nssa-external", ("nssa_external", Native.RouteMap.RouteMapSeq.Match.RouteType.NssaExternal))])
                        self._leafs = OrderedDict([
                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                            ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                            ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ])
                        self.internal = None
                        self.level_1 = None
                        self.level_2 = None
                        self.local = None

                        self.external = None
                        self._children_name_map["external"] = "external"

                        self.nssa_external = None
                        self._children_name_map["nssa_external"] = "nssa-external"
                        self._segment_path = lambda: "route-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.RouteType, ['internal', 'level_1', 'level_2', 'local'], name, value)


                    class External(Entity):
                        """
                        external route (BGP, EIGRP and OSPF type 1/2)
                        
                        .. attribute:: type_1
                        
                        	OSPF external type 1 route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: type_2
                        
                        	OSPF external type 2 route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.RouteType.External, self).__init__()

                            self.yang_name = "external"
                            self.yang_parent_name = "route-type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('type_1', (YLeaf(YType.empty, 'type-1'), ['Empty'])),
                                ('type_2', (YLeaf(YType.empty, 'type-2'), ['Empty'])),
                            ])
                            self.type_1 = None
                            self.type_2 = None
                            self._segment_path = lambda: "external"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.RouteType.External, ['type_1', 'type_2'], name, value)


                    class NssaExternal(Entity):
                        """
                        nssa\-external route (OSPF type 1/2)
                        
                        .. attribute:: type_1
                        
                        	OSPF external type 1 route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: type_2
                        
                        	OSPF external type 2 route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.RouteType.NssaExternal, self).__init__()

                            self.yang_name = "nssa-external"
                            self.yang_parent_name = "route-type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('type_1', (YLeaf(YType.empty, 'type-1'), ['Empty'])),
                                ('type_2', (YLeaf(YType.empty, 'type-2'), ['Empty'])),
                            ])
                            self.type_1 = None
                            self.type_2 = None
                            self._segment_path = lambda: "nssa-external"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.RouteType.NssaExternal, ['type_1', 'type_2'], name, value)


                class Rpki(Entity):
                    """
                    Match RPKI state of route
                    
                    .. attribute:: invalid
                    
                    	RPKI Invalid State
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: not_found
                    
                    	RPKI Not Found State
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: valid
                    
                    	RPKI Valid State
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.Rpki, self).__init__()

                        self.yang_name = "rpki"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('invalid', (YLeaf(YType.empty, 'invalid'), ['Empty'])),
                            ('not_found', (YLeaf(YType.empty, 'not-found'), ['Empty'])),
                            ('valid', (YLeaf(YType.empty, 'valid'), ['Empty'])),
                        ])
                        self.invalid = None
                        self.not_found = None
                        self.valid = None
                        self._segment_path = lambda: "rpki"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Rpki, ['invalid', 'not_found', 'valid'], name, value)


                class SourceProtocol(Entity):
                    """
                    Match source\-protocol of route
                    
                    .. attribute:: bgp
                    
                    	Border Gateway Protocol (BGP)
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: list of str
                    
                    .. attribute:: connected
                    
                    	Connected
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: eigrp
                    
                    	Border Gateway Protocol (BGP)
                    	**type**\: list of str
                    
                    .. attribute:: isis
                    
                    	ISO IS\-IS
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: lisp
                    
                    	Locator ID Separation Protocol (LISP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mobile
                    
                    	Mobile routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ospf
                    
                    	Open Shortest Path First (OSPF)
                    	**type**\: list of str
                    
                    .. attribute:: ospfv3
                    
                    	OSPFv3
                    	**type**\: list of str
                    
                    .. attribute:: rip
                    
                    	Routing Information Protocol (RIP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: static
                    
                    	Static routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.SourceProtocol, self).__init__()

                        self.yang_name = "source-protocol"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('bgp', (YLeafList(YType.str, 'bgp'), ['int','str'])),
                            ('connected', (YLeaf(YType.empty, 'connected'), ['Empty'])),
                            ('eigrp', (YLeafList(YType.str, 'eigrp'), ['str'])),
                            ('isis', (YLeaf(YType.empty, 'isis'), ['Empty'])),
                            ('lisp', (YLeaf(YType.empty, 'lisp'), ['Empty'])),
                            ('mobile', (YLeaf(YType.empty, 'mobile'), ['Empty'])),
                            ('ospf', (YLeafList(YType.str, 'ospf'), ['str'])),
                            ('ospfv3', (YLeafList(YType.str, 'ospfv3'), ['str'])),
                            ('rip', (YLeaf(YType.empty, 'rip'), ['Empty'])),
                            ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                        ])
                        self.bgp = []
                        self.connected = None
                        self.eigrp = []
                        self.isis = None
                        self.lisp = None
                        self.mobile = None
                        self.ospf = []
                        self.ospfv3 = []
                        self.rip = None
                        self.static = None
                        self._segment_path = lambda: "source-protocol"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.SourceProtocol, ['bgp', 'connected', 'eigrp', 'isis', 'lisp', 'mobile', 'ospf', 'ospfv3', 'rip', 'static'], name, value)


                class Tag(Entity):
                    """
                    Match tag of route
                    
                    .. attribute:: tag_value
                    
                    	Tag value
                    	**type**\: list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv4_address
                    
                    	<A.B.C.D>;;Tag value(dotted decimal format)
                    	**type**\: list of str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: list
                    
                    	Route Tag List
                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapSeq.Match.Tag.List>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapSeq.Match.Tag, self).__init__()

                        self.yang_name = "tag"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("list", ("list", Native.RouteMap.RouteMapSeq.Match.Tag.List))])
                        self._leafs = OrderedDict([
                            ('tag_value', (YLeafList(YType.uint32, 'tag_value'), ['int'])),
                            ('ipv4_address', (YLeafList(YType.str, 'ipv4-address'), ['str'])),
                        ])
                        self.tag_value = []
                        self.ipv4_address = []

                        self.list = Native.RouteMap.RouteMapSeq.Match.Tag.List()
                        self.list.parent = self
                        self._children_name_map["list"] = "list"
                        self._segment_path = lambda: "tag"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Tag, ['tag_value', 'ipv4_address'], name, value)


                    class List(Entity):
                        """
                        Route Tag List
                        
                        .. attribute:: tag_names
                        
                        	Tag list name
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapSeq.Match.Tag.List, self).__init__()

                            self.yang_name = "list"
                            self.yang_parent_name = "tag"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tag_names', (YLeafList(YType.str, 'tag-names'), ['str'])),
                            ])
                            self.tag_names = []
                            self._segment_path = lambda: "list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapSeq.Match.Tag.List, ['tag_names'], name, value)


        class RouteMapWithoutOrderSeq(Entity):
            """
            
            
            .. attribute:: seq_no  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: operation_
            
            	
            	**type**\:  :py:class:`Operation_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Operation_>`
            
            .. attribute:: description
            
            	Route\-map comment
            	**type**\: str
            
            .. attribute:: set
            
            	Set values in destination routing protocol
            	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set>`
            
            .. attribute:: match
            
            	Match values from routing table
            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match>`
            
            

            """

            _prefix = 'ios-route-map'
            _revision = '2018-03-08'

            def __init__(self):
                super(Native.RouteMap.RouteMapWithoutOrderSeq, self).__init__()

                self.yang_name = "route-map-without-order-seq"
                self.yang_parent_name = "route-map"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = ['seq_no']
                self._child_classes = OrderedDict([("set", ("set", Native.RouteMap.RouteMapWithoutOrderSeq.Set)), ("match", ("match", Native.RouteMap.RouteMapWithoutOrderSeq.Match))])
                self._leafs = OrderedDict([
                    ('seq_no', (YLeaf(YType.uint16, 'seq_no'), ['int'])),
                    ('operation_', (YLeaf(YType.enumeration, 'operation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapWithoutOrderSeq.Operation_')])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                ])
                self.seq_no = None
                self.operation_ = None
                self.description = None

                self.set = Native.RouteMap.RouteMapWithoutOrderSeq.Set()
                self.set.parent = self
                self._children_name_map["set"] = "set"

                self.match = Native.RouteMap.RouteMapWithoutOrderSeq.Match()
                self.match.parent = self
                self._children_name_map["match"] = "match"
                self._segment_path = lambda: "Cisco-IOS-XE-route-map:route-map-without-order-seq" + "[seq_no='" + str(self.seq_no) + "']"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq, ['seq_no', 'operation_', 'description'], name, value)

            class Operation_(Enum):
                """
                Operation\_ (Enum Class)

                .. data:: deny = 0

                .. data:: permit = 1

                """

                deny = Enum.YLeaf(0, "deny")

                permit = Enum.YLeaf(1, "permit")



            class Set(Entity):
                """
                Set values in destination routing protocol
                
                .. attribute:: aigp_metric
                
                	accumulated metric value
                	**type**\:  :py:class:`AigpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.AigpMetric>`
                
                .. attribute:: as_path
                
                	Prepend string for a BGP AS\-path attribute
                	**type**\:  :py:class:`AsPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath>`
                
                .. attribute:: automatic_tag
                
                	Automatically compute TAG value
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: clns
                
                	OSI summary address
                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Clns>`
                
                .. attribute:: community
                
                	BGP community attribute
                	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Community>`
                
                .. attribute:: comm_list
                
                	set BGP community list (for deletion)
                	**type**\:  :py:class:`CommList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.CommList>`
                
                .. attribute:: dampening
                
                	Set BGP route flap dampening parameters
                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Dampening>`
                
                .. attribute:: default
                
                	
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default>`
                
                .. attribute:: extcomm_list
                
                	Set BGP/VPN extended community list (for deletion)
                	**type**\:  :py:class:`ExtcommList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList>`
                
                .. attribute:: extcommunity
                
                	BGP extended community attribute
                	**type**\:  :py:class:`Extcommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity>`
                
                .. attribute:: global_
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface
                
                	
                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface>`
                
                .. attribute:: ip
                
                	IP specific information
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip>`
                
                .. attribute:: ipv6
                
                	IPv6 specific information
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6>`
                
                .. attribute:: level
                
                	Where to import route
                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Level>`
                
                .. attribute:: lisp
                
                	Locator ID Separation Protocol specific information
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Lisp>`
                
                .. attribute:: local_preference
                
                	Preference value
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: metric
                
                	Metric value for destination routing protocol
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Metric>`
                
                .. attribute:: metric_type
                
                	Type of metric for destination routing protocol
                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.MetricType>`
                
                .. attribute:: mpls_label
                
                	Set MPLS label for prefix
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: weight
                
                	BGP weight for routing table
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: origin
                
                	BGP origin code
                	**type**\:  :py:class:`Origin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Origin>`
                
                .. attribute:: tag
                
                	Tag value for destination routing protocol
                	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Tag>`
                
                .. attribute:: traffic_index
                
                	Bucket number
                	**type**\: int
                
                	**range:** 1..64
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding instance name
                	**type**\: str
                
                

                """

                _prefix = 'ios-route-map'
                _revision = '2018-03-08'

                def __init__(self):
                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set, self).__init__()

                    self.yang_name = "set"
                    self.yang_parent_name = "route-map-without-order-seq"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("aigp-metric", ("aigp_metric", Native.RouteMap.RouteMapWithoutOrderSeq.Set.AigpMetric)), ("as-path", ("as_path", Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath)), ("clns", ("clns", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Clns)), ("community", ("community", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Community)), ("comm-list", ("comm_list", Native.RouteMap.RouteMapWithoutOrderSeq.Set.CommList)), ("dampening", ("dampening", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Dampening)), ("default", ("default", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default)), ("extcomm-list", ("extcomm_list", Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList)), ("extcommunity", ("extcommunity", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity)), ("interface", ("interface", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface)), ("ip", ("ip", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip)), ("ipv6", ("ipv6", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6)), ("level", ("level", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Level)), ("lisp", ("lisp", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Lisp)), ("metric", ("metric", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Metric)), ("origin", ("origin", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Origin)), ("tag", ("tag", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Tag))])
                    self._leafs = OrderedDict([
                        ('automatic_tag', (YLeaf(YType.empty, 'automatic-tag'), ['Empty'])),
                        ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapWithoutOrderSeq.Set.MetricType')])),
                        ('mpls_label', (YLeaf(YType.empty, 'mpls-label'), ['Empty'])),
                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                        ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ])
                    self.automatic_tag = None
                    self.global_ = None
                    self.local_preference = None
                    self.metric_type = None
                    self.mpls_label = None
                    self.weight = None
                    self.traffic_index = None
                    self.vrf = None

                    self.aigp_metric = Native.RouteMap.RouteMapWithoutOrderSeq.Set.AigpMetric()
                    self.aigp_metric.parent = self
                    self._children_name_map["aigp_metric"] = "aigp-metric"

                    self.as_path = Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath()
                    self.as_path.parent = self
                    self._children_name_map["as_path"] = "as-path"

                    self.clns = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Clns()
                    self.clns.parent = self
                    self._children_name_map["clns"] = "clns"

                    self.community = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Community()
                    self.community.parent = self
                    self._children_name_map["community"] = "community"

                    self.comm_list = Native.RouteMap.RouteMapWithoutOrderSeq.Set.CommList()
                    self.comm_list.parent = self
                    self._children_name_map["comm_list"] = "comm-list"

                    self.dampening = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Dampening()
                    self.dampening.parent = self
                    self._children_name_map["dampening"] = "dampening"

                    self.default = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.extcomm_list = Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList()
                    self.extcomm_list.parent = self
                    self._children_name_map["extcomm_list"] = "extcomm-list"

                    self.extcommunity = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity()
                    self.extcommunity.parent = self
                    self._children_name_map["extcommunity"] = "extcommunity"

                    self.interface = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.ip = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.ipv6 = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.level = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Level()
                    self.level.parent = self
                    self._children_name_map["level"] = "level"

                    self.lisp = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "lisp"

                    self.metric = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "metric"

                    self.origin = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Origin()
                    self.origin.parent = self
                    self._children_name_map["origin"] = "origin"

                    self.tag = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Tag()
                    self.tag.parent = self
                    self._children_name_map["tag"] = "tag"
                    self._segment_path = lambda: "set"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set, ['automatic_tag', 'global_', 'local_preference', 'metric_type', 'mpls_label', 'weight', 'traffic_index', 'vrf'], name, value)

                class MetricType(Enum):
                    """
                    MetricType (Enum Class)

                    Type of metric for destination routing protocol

                    .. data:: external = 0

                    .. data:: internal = 1

                    .. data:: type_1 = 2

                    .. data:: type_2 = 3

                    """

                    external = Enum.YLeaf(0, "external")

                    internal = Enum.YLeaf(1, "internal")

                    type_1 = Enum.YLeaf(2, "type-1")

                    type_2 = Enum.YLeaf(3, "type-2")



                class AigpMetric(Entity):
                    """
                    accumulated metric value
                    
                    .. attribute:: value
                    
                    	manual value
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: igp_metric
                    
                    	metric value from rib
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.AigpMetric, self).__init__()

                        self.yang_name = "aigp-metric"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                            ('igp_metric', (YLeaf(YType.empty, 'igp-metric'), ['Empty'])),
                        ])
                        self.value = None
                        self.igp_metric = None
                        self._segment_path = lambda: "aigp-metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.AigpMetric, ['value', 'igp_metric'], name, value)


                class AsPath(Entity):
                    """
                    Prepend string for a BGP AS\-path attribute
                    
                    .. attribute:: prepend
                    
                    	Prepend to the as\-path
                    	**type**\:  :py:class:`Prepend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend>`
                    
                    .. attribute:: tag
                    
                    	Set the tag as an AS\-path attribute
                    	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Tag>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath, self).__init__()

                        self.yang_name = "as-path"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prepend", ("prepend", Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend)), ("tag", ("tag", Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Tag))])
                        self._leafs = OrderedDict()

                        self.prepend = Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend()
                        self.prepend.parent = self
                        self._children_name_map["prepend"] = "prepend"

                        self.tag = None
                        self._children_name_map["tag"] = "tag"
                        self._segment_path = lambda: "as-path"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath, [], name, value)


                    class Prepend(Entity):
                        """
                        Prepend to the as\-path
                        
                        .. attribute:: as_container
                        
                        	
                        	**type**\:  :py:class:`AsContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend.AsContainer>`
                        
                        .. attribute:: last_as_cont
                        
                        	
                        	**type**\:  :py:class:`LastAsCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend.LastAsCont>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend, self).__init__()

                            self.yang_name = "prepend"
                            self.yang_parent_name = "as-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("as-container", ("as_container", Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend.AsContainer)), ("last-as-cont", ("last_as_cont", Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend.LastAsCont))])
                            self._leafs = OrderedDict()

                            self.as_container = Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend.AsContainer()
                            self.as_container.parent = self
                            self._children_name_map["as_container"] = "as-container"

                            self.last_as_cont = Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend.LastAsCont()
                            self.last_as_cont.parent = self
                            self._children_name_map["last_as_cont"] = "last-as-cont"
                            self._segment_path = lambda: "prepend"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend, [], name, value)


                        class AsContainer(Entity):
                            """
                            
                            
                            .. attribute:: as_number
                            
                            	<1\-65535>;;AS number
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend.AsContainer, self).__init__()

                                self.yang_name = "as-container"
                                self.yang_parent_name = "prepend"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('as_number', (YLeaf(YType.str, 'as-number'), ['str'])),
                                ])
                                self.as_number = None
                                self._segment_path = lambda: "as-container"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend.AsContainer, ['as_number'], name, value)


                        class LastAsCont(Entity):
                            """
                            
                            
                            .. attribute:: last_as
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..10
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend.LastAsCont, self).__init__()

                                self.yang_name = "last-as-cont"
                                self.yang_parent_name = "prepend"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('last_as', (YLeaf(YType.uint16, 'last-as'), ['int'])),
                                ])
                                self.last_as = None
                                self._segment_path = lambda: "last-as-cont"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Prepend.LastAsCont, ['last_as'], name, value)


                    class Tag(Entity):
                        """
                        Set the tag as an AS\-path attribute
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.AsPath.Tag, self).__init__()

                            self.yang_name = "tag"
                            self.yang_parent_name = "as-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "tag"
                            self._is_frozen = True


                class Clns(Entity):
                    """
                    OSI summary address
                    
                    .. attribute:: next_hop
                    
                    	Next hop along path
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Clns.NextHop>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Clns, self).__init__()

                        self.yang_name = "clns"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Clns.NextHop))])
                        self._leafs = OrderedDict()

                        self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Clns.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._segment_path = lambda: "clns"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Clns, [], name, value)


                    class NextHop(Entity):
                        """
                        Next hop along path
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: list of str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Clns.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "clns"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeafList(YType.str, 'address'), ['str'])),
                            ])
                            self.address = []
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Clns.NextHop, ['address'], name, value)


                class Community(Entity):
                    """
                    BGP community attribute
                    
                    .. attribute:: none
                    
                    	No community attribute
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: community_well_known
                    
                    	
                    	**type**\:  :py:class:`CommunityWellKnown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Community.CommunityWellKnown>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Community, self).__init__()

                        self.yang_name = "community"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("community-well-known", ("community_well_known", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Community.CommunityWellKnown))])
                        self._leafs = OrderedDict([
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ])
                        self.none = None

                        self.community_well_known = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Community.CommunityWellKnown()
                        self.community_well_known.parent = self
                        self._children_name_map["community_well_known"] = "community-well-known"
                        self._segment_path = lambda: "community"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Community, ['none'], name, value)


                    class CommunityWellKnown(Entity):
                        """
                        
                        
                        .. attribute:: community_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..4294967295
                        
                        		**type**\: list of str
                        
                        			**pattern:** (\\d+\:\\d+)
                        
                        		**type**\: list of   :py:class:`CommunityWellKnownAddType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.CommunityWellKnownAddType>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Community.CommunityWellKnown, self).__init__()

                            self.yang_name = "community-well-known"
                            self.yang_parent_name = "community"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('community_list', (YLeafList(YType.str, 'community-list'), ['int','str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'CommunityWellKnownAddType', '')])),
                            ])
                            self.community_list = []
                            self._segment_path = lambda: "community-well-known"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Community.CommunityWellKnown, ['community_list'], name, value)


                class CommList(Entity):
                    """
                    set BGP community list (for deletion)
                    
                    .. attribute:: comm_list_standard
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..99
                    
                    .. attribute:: comm_list_expanded
                    
                    	
                    	**type**\: int
                    
                    	**range:** 100..500
                    
                    .. attribute:: comm_list_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: delete
                    
                    	Delete matching communities
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.CommList, self).__init__()

                        self.yang_name = "comm-list"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('comm_list_standard', (YLeaf(YType.uint16, 'comm-list-standard'), ['int'])),
                            ('comm_list_expanded', (YLeaf(YType.uint16, 'comm-list-expanded'), ['int'])),
                            ('comm_list_name', (YLeaf(YType.str, 'comm-list-name'), ['str'])),
                            ('delete', (YLeaf(YType.empty, 'delete'), ['Empty'])),
                        ])
                        self.comm_list_standard = None
                        self.comm_list_expanded = None
                        self.comm_list_name = None
                        self.delete = None
                        self._segment_path = lambda: "comm-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.CommList, ['comm_list_standard', 'comm_list_expanded', 'comm_list_name', 'delete'], name, value)


                class Dampening(Entity):
                    """
                    Set BGP route flap dampening parameters
                    
                    .. attribute:: dampening_list
                    
                    	
                    	**type**\: list of  		 :py:class:`DampeningList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Dampening.DampeningList>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Dampening, self).__init__()

                        self.yang_name = "dampening"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dampening-list", ("dampening_list", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Dampening.DampeningList))])
                        self._leafs = OrderedDict()

                        self.dampening_list = YList(self)
                        self._segment_path = lambda: "dampening"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Dampening, [], name, value)


                    class DampeningList(Entity):
                        """
                        
                        
                        .. attribute:: half_life_penalty  (key)
                        
                        	half\-life time for the penalty
                        	**type**\: int
                        
                        	**range:** 1..45
                        
                        .. attribute:: restart_penalty  (key)
                        
                        	penalty to start reusing a route
                        	**type**\: int
                        
                        	**range:** 1..20000
                        
                        .. attribute:: suppress_penalty  (key)
                        
                        	penalty to start suppressing a route
                        	**type**\: int
                        
                        	**range:** 1..20000
                        
                        .. attribute:: max_suppress_penalty  (key)
                        
                        	Maximum duration to suppress a stable route
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Dampening.DampeningList, self).__init__()

                            self.yang_name = "dampening-list"
                            self.yang_parent_name = "dampening"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['half_life_penalty','restart_penalty','suppress_penalty','max_suppress_penalty']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('half_life_penalty', (YLeaf(YType.uint8, 'half-life-penalty'), ['int'])),
                                ('restart_penalty', (YLeaf(YType.uint16, 'restart-penalty'), ['int'])),
                                ('suppress_penalty', (YLeaf(YType.uint16, 'suppress-penalty'), ['int'])),
                                ('max_suppress_penalty', (YLeaf(YType.uint8, 'max-suppress-penalty'), ['int'])),
                            ])
                            self.half_life_penalty = None
                            self.restart_penalty = None
                            self.suppress_penalty = None
                            self.max_suppress_penalty = None
                            self._segment_path = lambda: "dampening-list" + "[half-life-penalty='" + str(self.half_life_penalty) + "']" + "[restart-penalty='" + str(self.restart_penalty) + "']" + "[suppress-penalty='" + str(self.suppress_penalty) + "']" + "[max-suppress-penalty='" + str(self.max_suppress_penalty) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Dampening.DampeningList, ['half_life_penalty', 'restart_penalty', 'suppress_penalty', 'max_suppress_penalty'], name, value)


                class Default(Entity):
                    """
                    
                    
                    .. attribute:: interface
                    
                    	SPAN source interface
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface))])
                        self._leafs = OrderedDict()

                        self.interface = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default, [], name, value)


                    class Interface(Entity):
                        """
                        SPAN source interface
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Default.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                class ExtcommList(Entity):
                    """
                    Set BGP/VPN extended community list (for deletion)
                    
                    .. attribute:: ext_range
                    
                    	
                    	**type**\: list of  		 :py:class:`ExtRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList.ExtRange>`
                    
                    .. attribute:: excomm_list_name
                    
                    	
                    	**type**\: list of  		 :py:class:`ExcommListName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList.ExcommListName>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList, self).__init__()

                        self.yang_name = "extcomm-list"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ext-range", ("ext_range", Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList.ExtRange)), ("excomm-list-name", ("excomm_list_name", Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList.ExcommListName))])
                        self._leafs = OrderedDict()

                        self.ext_range = YList(self)
                        self.excomm_list_name = YList(self)
                        self._segment_path = lambda: "extcomm-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList, [], name, value)


                    class ExtRange(Entity):
                        """
                        
                        
                        .. attribute:: comm_list_num  (key)
                        
                        	Extended community\-list number (expanded)
                        	**type**\: int
                        
                        	**range:** 1..500
                        
                        .. attribute:: delete
                        
                        	Delete matching extended communities
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList.ExtRange, self).__init__()

                            self.yang_name = "ext-range"
                            self.yang_parent_name = "extcomm-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['comm_list_num']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('comm_list_num', (YLeaf(YType.uint16, 'comm-list-num'), ['int'])),
                                ('delete', (YLeaf(YType.empty, 'delete'), ['Empty'])),
                            ])
                            self.comm_list_num = None
                            self.delete = None
                            self._segment_path = lambda: "ext-range" + "[comm-list-num='" + str(self.comm_list_num) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList.ExtRange, ['comm_list_num', 'delete'], name, value)


                    class ExcommListName(Entity):
                        """
                        
                        
                        .. attribute:: name  (key)
                        
                        	extcommunity\-list name
                        	**type**\: str
                        
                        .. attribute:: delete
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList.ExcommListName, self).__init__()

                            self.yang_name = "excomm-list-name"
                            self.yang_parent_name = "extcomm-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('delete', (YLeaf(YType.empty, 'delete'), ['Empty'])),
                            ])
                            self.name = None
                            self.delete = None
                            self._segment_path = lambda: "excomm-list-name" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.ExtcommList.ExcommListName, ['name', 'delete'], name, value)


                class Extcommunity(Entity):
                    """
                    BGP extended community attribute
                    
                    .. attribute:: cost
                    
                    	Cost extended community
                    	**type**\:  :py:class:`Cost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost>`
                    
                    .. attribute:: rt
                    
                    	Route Target extended community
                    	**type**\:  :py:class:`Rt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt>`
                    
                    .. attribute:: soo
                    
                    	Site\-of\-Origin extended community
                    	**type**\:  :py:class:`Soo <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Soo>`
                    
                    .. attribute:: vpn_distinguisher
                    
                    	VPN Distinguisher
                    	**type**\:  :py:class:`VpnDistinguisher <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.VpnDistinguisher>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity, self).__init__()

                        self.yang_name = "extcommunity"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("cost", ("cost", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost)), ("rt", ("rt", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt)), ("soo", ("soo", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Soo)), ("vpn-distinguisher", ("vpn_distinguisher", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.VpnDistinguisher))])
                        self._leafs = OrderedDict()

                        self.cost = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost()
                        self.cost.parent = self
                        self._children_name_map["cost"] = "cost"

                        self.rt = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt()
                        self.rt.parent = self
                        self._children_name_map["rt"] = "rt"

                        self.soo = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Soo()
                        self.soo.parent = self
                        self._children_name_map["soo"] = "soo"

                        self.vpn_distinguisher = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.VpnDistinguisher()
                        self.vpn_distinguisher.parent = self
                        self._children_name_map["vpn_distinguisher"] = "vpn-distinguisher"
                        self._segment_path = lambda: "extcommunity"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity, [], name, value)


                    class Cost(Entity):
                        """
                        Cost extended community
                        
                        .. attribute:: community_id
                        
                        	
                        	**type**\: list of  		 :py:class:`CommunityId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.CommunityId>`
                        
                        .. attribute:: igp
                        
                        	Compare following IGP cost comparison
                        	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.Igp>`
                        
                        .. attribute:: pre_bestpath
                        
                        	Compare before all other steps in bestpath calculation
                        	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.PreBestpath>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost, self).__init__()

                            self.yang_name = "cost"
                            self.yang_parent_name = "extcommunity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("community-id", ("community_id", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.CommunityId)), ("igp", ("igp", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.Igp)), ("pre-bestpath", ("pre_bestpath", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.PreBestpath))])
                            self._leafs = OrderedDict()

                            self.igp = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.Igp()
                            self.igp.parent = self
                            self._children_name_map["igp"] = "igp"

                            self.pre_bestpath = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.PreBestpath()
                            self.pre_bestpath.parent = self
                            self._children_name_map["pre_bestpath"] = "pre-bestpath"

                            self.community_id = YList(self)
                            self._segment_path = lambda: "cost"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost, [], name, value)


                        class CommunityId(Entity):
                            """
                            
                            
                            .. attribute:: community_id  (key)
                            
                            	Community ID
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: cost_value  (key)
                            
                            	Cost Value (No\-preference Cost = 2147483647)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.CommunityId, self).__init__()

                                self.yang_name = "community-id"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['community_id','cost_value']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('community_id', (YLeaf(YType.uint8, 'community-id'), ['int'])),
                                    ('cost_value', (YLeaf(YType.uint32, 'cost-value'), ['int'])),
                                ])
                                self.community_id = None
                                self.cost_value = None
                                self._segment_path = lambda: "community-id" + "[community-id='" + str(self.community_id) + "']" + "[cost-value='" + str(self.cost_value) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.CommunityId, ['community_id', 'cost_value'], name, value)


                        class Igp(Entity):
                            """
                            Compare following IGP cost comparison
                            
                            .. attribute:: community_id
                            
                            	
                            	**type**\: list of  		 :py:class:`CommunityId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.Igp.CommunityId>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.Igp, self).__init__()

                                self.yang_name = "igp"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("community-id", ("community_id", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.Igp.CommunityId))])
                                self._leafs = OrderedDict()

                                self.community_id = YList(self)
                                self._segment_path = lambda: "igp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.Igp, [], name, value)


                            class CommunityId(Entity):
                                """
                                
                                
                                .. attribute:: community_id  (key)
                                
                                	Community ID
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: cost_value  (key)
                                
                                	Cost Value (No\-preference Cost = 2147483647)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.Igp.CommunityId, self).__init__()

                                    self.yang_name = "community-id"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['community_id','cost_value']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('community_id', (YLeaf(YType.uint8, 'community-id'), ['int'])),
                                        ('cost_value', (YLeaf(YType.uint32, 'cost-value'), ['int'])),
                                    ])
                                    self.community_id = None
                                    self.cost_value = None
                                    self._segment_path = lambda: "community-id" + "[community-id='" + str(self.community_id) + "']" + "[cost-value='" + str(self.cost_value) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.Igp.CommunityId, ['community_id', 'cost_value'], name, value)


                        class PreBestpath(Entity):
                            """
                            Compare before all other steps in bestpath calculation
                            
                            .. attribute:: community_id
                            
                            	
                            	**type**\: list of  		 :py:class:`CommunityId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.PreBestpath.CommunityId>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.PreBestpath, self).__init__()

                                self.yang_name = "pre-bestpath"
                                self.yang_parent_name = "cost"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("community-id", ("community_id", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.PreBestpath.CommunityId))])
                                self._leafs = OrderedDict()

                                self.community_id = YList(self)
                                self._segment_path = lambda: "pre-bestpath"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.PreBestpath, [], name, value)


                            class CommunityId(Entity):
                                """
                                
                                
                                .. attribute:: community_id  (key)
                                
                                	Community ID
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: cost_value  (key)
                                
                                	Cost Value (No\-preference Cost = 2147483647)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.PreBestpath.CommunityId, self).__init__()

                                    self.yang_name = "community-id"
                                    self.yang_parent_name = "pre-bestpath"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['community_id','cost_value']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('community_id', (YLeaf(YType.uint8, 'community-id'), ['int'])),
                                        ('cost_value', (YLeaf(YType.uint32, 'cost-value'), ['int'])),
                                    ])
                                    self.community_id = None
                                    self.cost_value = None
                                    self._segment_path = lambda: "community-id" + "[community-id='" + str(self.community_id) + "']" + "[cost-value='" + str(self.cost_value) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Cost.PreBestpath.CommunityId, ['community_id', 'cost_value'], name, value)


                    class Rt(Entity):
                        """
                        Route Target extended community
                        
                        .. attribute:: asn_nn
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of str
                        
                        			**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                        
                        		**type**\: list of   :py:class:`AsnNn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt.AsnNn>`
                        
                        .. attribute:: range
                        
                        	Specify a range of extended community
                        	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt.Range>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt, self).__init__()

                            self.yang_name = "rt"
                            self.yang_parent_name = "extcommunity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt.Range))])
                            self._leafs = OrderedDict([
                                ('asn_nn', (YLeafList(YType.str, 'asn-nn'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt.AsnNn')])),
                            ])
                            self.asn_nn = []

                            self.range = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt.Range()
                            self.range.parent = self
                            self._children_name_map["range"] = "range"
                            self._segment_path = lambda: "rt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt, ['asn_nn'], name, value)

                        class AsnNn(Enum):
                            """
                            AsnNn (Enum Class)

                            .. data:: additive = 0

                            """

                            additive = Enum.YLeaf(0, "additive")



                        class Range(Entity):
                            """
                            Specify a range of extended community
                            
                            .. attribute:: lower_limit
                            
                            	VPN extended community lower limit
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: high_limit
                            
                            	VPN extended community high limit
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: additive
                            
                            	Add to the existing extcommunity
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lower_limit', (YLeaf(YType.str, 'lower-limit'), ['str'])),
                                    ('high_limit', (YLeaf(YType.str, 'high-limit'), ['str'])),
                                    ('additive', (YLeaf(YType.empty, 'additive'), ['Empty'])),
                                ])
                                self.lower_limit = None
                                self.high_limit = None
                                self.additive = None
                                self._segment_path = lambda: "range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Rt.Range, ['lower_limit', 'high_limit', 'additive'], name, value)


                    class Soo(Entity):
                        """
                        Site\-of\-Origin extended community
                        
                        .. attribute:: asn_nn
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Soo, self).__init__()

                            self.yang_name = "soo"
                            self.yang_parent_name = "extcommunity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('asn_nn', (YLeaf(YType.str, 'asn-nn'), ['str'])),
                            ])
                            self.asn_nn = None
                            self._segment_path = lambda: "soo"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.Soo, ['asn_nn'], name, value)


                    class VpnDistinguisher(Entity):
                        """
                        VPN Distinguisher
                        
                        .. attribute:: asn_nn
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                        
                        .. attribute:: range
                        
                        	Specify a range of extended community
                        	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.VpnDistinguisher.Range>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.VpnDistinguisher, self).__init__()

                            self.yang_name = "vpn-distinguisher"
                            self.yang_parent_name = "extcommunity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.VpnDistinguisher.Range))])
                            self._leafs = OrderedDict([
                                ('asn_nn', (YLeaf(YType.str, 'asn-nn'), ['str'])),
                            ])
                            self.asn_nn = None

                            self.range = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.VpnDistinguisher.Range()
                            self.range.parent = self
                            self._children_name_map["range"] = "range"
                            self._segment_path = lambda: "vpn-distinguisher"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.VpnDistinguisher, ['asn_nn'], name, value)


                        class Range(Entity):
                            """
                            Specify a range of extended community
                            
                            .. attribute:: lower_limit
                            
                            	VPN extended community lower limit
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: high_limit
                            
                            	VPN extended community high limit
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]+)\|((([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])))\:[0\-9]+
                            
                            .. attribute:: additive
                            
                            	Add to the existing extcommunity
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.VpnDistinguisher.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "vpn-distinguisher"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lower_limit', (YLeaf(YType.str, 'lower-limit'), ['str'])),
                                    ('high_limit', (YLeaf(YType.str, 'high-limit'), ['str'])),
                                    ('additive', (YLeaf(YType.empty, 'additive'), ['Empty'])),
                                ])
                                self.lower_limit = None
                                self.high_limit = None
                                self.additive = None
                                self._segment_path = lambda: "range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Extcommunity.VpnDistinguisher.Range, ['lower_limit', 'high_limit', 'additive'], name, value)


                class Interface(Entity):
                    """
                    
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                class Ip(Entity):
                    """
                    IP specific information
                    
                    .. attribute:: address
                    
                    	Specify IP address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Address>`
                    
                    .. attribute:: default
                    
                    	Set default information
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default>`
                    
                    .. attribute:: df
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..1
                    
                    .. attribute:: global_
                    
                    	global routing table
                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Global>`
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop>`
                    
                    .. attribute:: precedence
                    
                    	Set precedence field
                    	**type**\:  :py:class:`Precedence <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Precedence>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: qos_group
                    
                    	Set QOS Group ID
                    	**type**\:  :py:class:`QosGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.QosGroup>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: tos
                    
                    	Set type of service field
                    	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Tos>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: vrf
                    
                    	VRF name
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Address)), ("default", ("default", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default)), ("global", ("global_", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Global)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop)), ("precedence", ("precedence", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Precedence)), ("qos-group", ("qos_group", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.QosGroup)), ("tos", ("tos", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Tos)), ("vrf", ("vrf", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf))])
                        self._leafs = OrderedDict([
                            ('df', (YLeaf(YType.uint8, 'df'), ['int'])),
                        ])
                        self.df = None

                        self.address = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.default = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.global_ = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Global()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"

                        self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"

                        self.precedence = None
                        self._children_name_map["precedence"] = "precedence"

                        self.qos_group = None
                        self._children_name_map["qos_group"] = "qos-group"

                        self.tos = None
                        self._children_name_map["tos"] = "tos"

                        self.vrf = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip, ['df'], name, value)


                    class Address(Entity):
                        """
                        Specify IP address
                        
                        .. attribute:: prefix_list
                        
                        	Specify prefix\-list
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.prefix_list = None
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Address, ['prefix_list'], name, value)


                    class Default(Entity):
                        """
                        Set default information
                        
                        .. attribute:: global_
                        
                        	global routing table
                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Global>`
                        
                        .. attribute:: next_hop
                        
                        	Next hop along path
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.NextHop>`
                        
                        .. attribute:: vrf
                        
                        	VRF name
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("global", ("global_", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Global)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.NextHop)), ("vrf", ("vrf", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf))])
                            self._leafs = OrderedDict()

                            self.global_ = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Global()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"

                            self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"

                            self.vrf = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default, [], name, value)


                        class Global(Entity):
                            """
                            global routing table
                            
                            .. attribute:: next_hop
                            
                            	Next hop along path
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Global.NextHop>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Global, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Global.NextHop))])
                                self._leafs = OrderedDict()

                                self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Global.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._segment_path = lambda: "global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Global, [], name, value)


                            class NextHop(Entity):
                                """
                                Next hop along path
                                
                                .. attribute:: address
                                
                                	
                                	**type**\: list of str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Global.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                    ])
                                    self.address = []
                                    self._segment_path = lambda: "next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Global.NextHop, ['address'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop along path
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: list of str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                ])
                                self.address = []
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.NextHop, ['address'], name, value)


                        class Vrf(Entity):
                            """
                            VRF name
                            
                            .. attribute:: vrfs
                            
                            	
                            	**type**\: list of  		 :py:class:`Vrfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf.Vrfs>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrfs", ("vrfs", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf.Vrfs))])
                                self._leafs = OrderedDict()

                                self.vrfs = YList(self)
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf, [], name, value)


                            class Vrfs(Entity):
                                """
                                
                                
                                .. attribute:: vrf  (key)
                                
                                	WORD;;VRF name
                                	**type**\: str
                                
                                .. attribute:: next_hop
                                
                                	Next hop along path
                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf.Vrfs.NextHop>`
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf.Vrfs, self).__init__()

                                    self.yang_name = "vrfs"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['vrf']
                                    self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf.Vrfs.NextHop))])
                                    self._leafs = OrderedDict([
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.vrf = None

                                    self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf.Vrfs.NextHop()
                                    self.next_hop.parent = self
                                    self._children_name_map["next_hop"] = "next-hop"
                                    self._segment_path = lambda: "vrfs" + "[vrf='" + str(self.vrf) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf.Vrfs, ['vrf'], name, value)


                                class NextHop(Entity):
                                    """
                                    Next hop along path
                                    
                                    .. attribute:: address
                                    
                                    	
                                    	**type**\: list of str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-route-map'
                                    _revision = '2018-03-08'

                                    def __init__(self):
                                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf.Vrfs.NextHop, self).__init__()

                                        self.yang_name = "next-hop"
                                        self.yang_parent_name = "vrfs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                        ])
                                        self.address = []
                                        self._segment_path = lambda: "next-hop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Default.Vrf.Vrfs.NextHop, ['address'], name, value)


                    class Global(Entity):
                        """
                        global routing table
                        
                        .. attribute:: next_hop
                        
                        	Next hop along path
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Global.NextHop>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Global.NextHop))])
                            self._leafs = OrderedDict()

                            self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Global.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._segment_path = lambda: "global"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Global, [], name, value)


                        class NextHop(Entity):
                            """
                            Next hop along path
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: list of str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Global.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                ])
                                self.address = []
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Global.NextHop, ['address'], name, value)


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: dynamic
                        
                        	application dynamically sets next hop
                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Dynamic>`
                        
                        .. attribute:: encapsulate
                        
                        	Encapsulation profile for VPN nexthop
                        	**type**\:  :py:class:`Encapsulate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Encapsulate>`
                        
                        .. attribute:: peer_address
                        
                        	Use peer address (for BGP only)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: recursive
                        
                        	Recursive next\-hop
                        	**type**\:  :py:class:`Recursive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive>`
                        
                        .. attribute:: self
                        
                        	Use self address (for BGP only)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: verify_availability
                        
                        	Verify if nexthop is reachable
                        	**type**\:  :py:class:`VerifyAvailability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.VerifyAvailability>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Dynamic)), ("encapsulate", ("encapsulate", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Encapsulate)), ("recursive", ("recursive", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive)), ("verify-availability", ("verify_availability", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.VerifyAvailability))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('peer_address', (YLeaf(YType.empty, 'peer-address'), ['Empty'])),
                                ('self', (YLeaf(YType.empty, 'self'), ['Empty'])),
                            ])
                            self.address = None
                            self.peer_address = None
                            self.self = None

                            self.dynamic = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Dynamic()
                            self.dynamic.parent = self
                            self._children_name_map["dynamic"] = "dynamic"

                            self.encapsulate = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Encapsulate()
                            self.encapsulate.parent = self
                            self._children_name_map["encapsulate"] = "encapsulate"

                            self.recursive = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive()
                            self.recursive.parent = self
                            self._children_name_map["recursive"] = "recursive"

                            self.verify_availability = None
                            self._children_name_map["verify_availability"] = "verify-availability"
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop, ['address', 'peer_address', 'self'], name, value)


                        class Dynamic(Entity):
                            """
                            application dynamically sets next hop
                            
                            .. attribute:: dhcp
                            
                            	DHCP learned next hop
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Dynamic, self).__init__()

                                self.yang_name = "dynamic"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                                ])
                                self.dhcp = None
                                self._segment_path = lambda: "dynamic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Dynamic, ['dhcp'], name, value)


                        class Encapsulate(Entity):
                            """
                            Encapsulation profile for VPN nexthop
                            
                            .. attribute:: l3vpn
                            
                            	L3VPN
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Encapsulate, self).__init__()

                                self.yang_name = "encapsulate"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('l3vpn', (YLeaf(YType.str, 'l3vpn'), ['str'])),
                                ])
                                self.l3vpn = None
                                self._segment_path = lambda: "encapsulate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Encapsulate, ['l3vpn'], name, value)


                        class Recursive(Entity):
                            """
                            Recursive next\-hop
                            
                            .. attribute:: ipv4
                            
                            	IP address of recursive next hop
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: global_
                            
                            	IP address of recursive next hop
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vrf
                            
                            	VRF name
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive.Vrf>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive, self).__init__()

                                self.yang_name = "recursive"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive.Vrf))])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('global_', (YLeaf(YType.str, 'global'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.global_ = None

                                self.vrf = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._segment_path = lambda: "recursive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive, ['ipv4', 'global_'], name, value)


                            class Vrf(Entity):
                                """
                                VRF name
                                
                                .. attribute:: vrfs
                                
                                	
                                	**type**\: list of  		 :py:class:`Vrfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive.Vrf.Vrfs>`
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "recursive"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrfs", ("vrfs", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive.Vrf.Vrfs))])
                                    self._leafs = OrderedDict()

                                    self.vrfs = YList(self)
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive.Vrf, [], name, value)


                                class Vrfs(Entity):
                                    """
                                    
                                    
                                    .. attribute:: vrf  (key)
                                    
                                    	VRF name
                                    	**type**\: str
                                    
                                    .. attribute:: ipv4
                                    
                                    	IP address of recursive next hop
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-route-map'
                                    _revision = '2018-03-08'

                                    def __init__(self):
                                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive.Vrf.Vrfs, self).__init__()

                                        self.yang_name = "vrfs"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['vrf']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ])
                                        self.vrf = None
                                        self.ipv4 = None
                                        self._segment_path = lambda: "vrfs" + "[vrf='" + str(self.vrf) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.Recursive.Vrf.Vrfs, ['vrf', 'ipv4'], name, value)


                        class VerifyAvailability(Entity):
                            """
                            Verify if nexthop is reachable
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.VerifyAvailability.Ipv4>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.VerifyAvailability, self).__init__()

                                self.yang_name = "verify-availability"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.VerifyAvailability.Ipv4))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.ipv4 = YList(self)
                                self._segment_path = lambda: "verify-availability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.VerifyAvailability, [], name, value)


                            class Ipv4(Entity):
                                """
                                
                                
                                .. attribute:: ipv4  (key)
                                
                                	IP address of next hop
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: range
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: track
                                
                                	set the next hop depending on the state\\ of a tracked object
                                	**type**\: int
                                
                                	**range:** 1..1000
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.VerifyAvailability.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "verify-availability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv4']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                        ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                    ])
                                    self.ipv4 = None
                                    self.range = None
                                    self.track = None
                                    self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.NextHop.VerifyAvailability.Ipv4, ['ipv4', 'range', 'track'], name, value)


                    class Precedence(Entity):
                        """
                        Set precedence field
                        
                        .. attribute:: precedence_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: precedence_fields
                        
                        	
                        	**type**\:  :py:class:`PrecedenceFields <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Precedence.PrecedenceFields>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Precedence, self).__init__()

                            self.yang_name = "precedence"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('precedence_value', (YLeaf(YType.uint8, 'precedence-value'), ['int'])),
                                ('precedence_fields', (YLeaf(YType.enumeration, 'precedence-fields'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Precedence.PrecedenceFields')])),
                            ])
                            self.precedence_value = None
                            self.precedence_fields = None
                            self._segment_path = lambda: "precedence"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Precedence, ['precedence_value', 'precedence_fields'], name, value)

                        class PrecedenceFields(Enum):
                            """
                            PrecedenceFields (Enum Class)

                            .. data:: critical = 0

                            .. data:: flash = 1

                            .. data:: flash_override = 2

                            .. data:: immediate = 3

                            .. data:: internet = 4

                            .. data:: network = 5

                            .. data:: priority = 6

                            .. data:: routine = 7

                            """

                            critical = Enum.YLeaf(0, "critical")

                            flash = Enum.YLeaf(1, "flash")

                            flash_override = Enum.YLeaf(2, "flash-override")

                            immediate = Enum.YLeaf(3, "immediate")

                            internet = Enum.YLeaf(4, "internet")

                            network = Enum.YLeaf(5, "network")

                            priority = Enum.YLeaf(6, "priority")

                            routine = Enum.YLeaf(7, "routine")



                    class QosGroup(Entity):
                        """
                        Set QOS Group ID
                        
                        .. attribute:: qos_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..99
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.QosGroup, self).__init__()

                            self.yang_name = "qos-group"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('qos_id', (YLeaf(YType.uint8, 'qos-id'), ['int'])),
                            ])
                            self.qos_id = None
                            self._segment_path = lambda: "qos-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.QosGroup, ['qos_id'], name, value)


                    class Tos(Entity):
                        """
                        Set type of service field
                        
                        .. attribute:: service_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..15
                        
                        .. attribute:: tos_fields
                        
                        	
                        	**type**\:  :py:class:`TosFields <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Tos.TosFields>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Tos, self).__init__()

                            self.yang_name = "tos"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('service_value', (YLeaf(YType.uint8, 'service-value'), ['int'])),
                                ('tos_fields', (YLeaf(YType.enumeration, 'tos-fields'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Tos.TosFields')])),
                            ])
                            self.service_value = None
                            self.tos_fields = None
                            self._segment_path = lambda: "tos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Tos, ['service_value', 'tos_fields'], name, value)

                        class TosFields(Enum):
                            """
                            TosFields (Enum Class)

                            .. data:: max_reliability = 0

                            .. data:: max_throughput = 1

                            .. data:: min_delay = 2

                            .. data:: min_monetary_cost = 3

                            .. data:: normal = 4

                            """

                            max_reliability = Enum.YLeaf(0, "max-reliability")

                            max_throughput = Enum.YLeaf(1, "max-throughput")

                            min_delay = Enum.YLeaf(2, "min-delay")

                            min_monetary_cost = Enum.YLeaf(3, "min-monetary-cost")

                            normal = Enum.YLeaf(4, "normal")



                    class Vrf(Entity):
                        """
                        VRF name
                        
                        .. attribute:: vrfs
                        
                        	
                        	**type**\: list of  		 :py:class:`Vrfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf.Vrfs>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrfs", ("vrfs", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf.Vrfs))])
                            self._leafs = OrderedDict()

                            self.vrfs = YList(self)
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf, [], name, value)


                        class Vrfs(Entity):
                            """
                            
                            
                            .. attribute:: vrf  (key)
                            
                            	WORD;;VRF name
                            	**type**\: str
                            
                            .. attribute:: next_hop
                            
                            	Next hop along path
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf.Vrfs.NextHop>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf.Vrfs, self).__init__()

                                self.yang_name = "vrfs"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['vrf']
                                self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf.Vrfs.NextHop))])
                                self._leafs = OrderedDict([
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.vrf = None

                                self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf.Vrfs.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._segment_path = lambda: "vrfs" + "[vrf='" + str(self.vrf) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf.Vrfs, ['vrf'], name, value)


                            class NextHop(Entity):
                                """
                                Next hop along path
                                
                                .. attribute:: address
                                
                                	
                                	**type**\: list of str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf.Vrfs.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "vrfs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                    ])
                                    self.address = []
                                    self._segment_path = lambda: "next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ip.Vrf.Vrfs.NextHop, ['address'], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 specific information
                    
                    .. attribute:: address
                    
                    	IPv6 address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Address>`
                    
                    .. attribute:: default
                    
                    	Set default information
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default>`
                    
                    .. attribute:: global_
                    
                    	global routing table
                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global>`
                    
                    .. attribute:: next_hop
                    
                    	IPv6 Next hop
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop>`
                    
                    .. attribute:: precedence
                    
                    	Precedence value
                    	**type**\: int
                    
                    	**range:** 0..7
                    
                    .. attribute:: bvrf
                    
                    	
                    	**type**\: list of  		 :py:class:`Bvrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Address)), ("default", ("default", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default)), ("global", ("global_", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop)), ("bvrf", ("bvrf", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf))])
                        self._leafs = OrderedDict([
                            ('precedence', (YLeaf(YType.uint8, 'precedence'), ['int'])),
                        ])
                        self.precedence = None

                        self.address = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.default = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.global_ = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"

                        self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"

                        self.bvrf = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6, ['precedence'], name, value)


                    class Address(Entity):
                        """
                        IPv6 address
                        
                        .. attribute:: prefix_list
                        
                        	IPv6 prefix\-list
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.prefix_list = []
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Address, ['prefix_list'], name, value)


                    class Default(Entity):
                        """
                        Set default information
                        
                        .. attribute:: global_
                        
                        	global routing table
                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Global>`
                        
                        .. attribute:: next_hop
                        
                        	Next hop along path
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.NextHop>`
                        
                        .. attribute:: dvrf
                        
                        	
                        	**type**\: list of  		 :py:class:`Dvrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Dvrf>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("global", ("global_", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Global)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.NextHop)), ("dvrf", ("dvrf", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Dvrf))])
                            self._leafs = OrderedDict()

                            self.global_ = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Global()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"

                            self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"

                            self.dvrf = YList(self)
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default, [], name, value)


                        class Global(Entity):
                            """
                            global routing table
                            
                            .. attribute:: next_hop
                            
                            	Next hop along path
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Global, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str'])),
                                ])
                                self.next_hop = None
                                self._segment_path = lambda: "global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Global, ['next_hop'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop along path
                            
                            .. attribute:: ipv6s
                            
                            	
                            	**type**\: list of  		 :py:class:`Ipv6s <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.NextHop.Ipv6s>`
                            
                            .. attribute:: next_hop_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv6s", ("ipv6s", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.NextHop.Ipv6s))])
                                self._leafs = OrderedDict([
                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str'])),
                                ])
                                self.next_hop_address = None

                                self.ipv6s = YList(self)
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.NextHop, ['next_hop_address'], name, value)


                            class Ipv6s(Entity):
                                """
                                
                                
                                .. attribute:: ipv6  (key)
                                
                                	Default next hop IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.NextHop.Ipv6s, self).__init__()

                                    self.yang_name = "ipv6s"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv6']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.ipv6 = None
                                    self._segment_path = lambda: "ipv6s" + "[ipv6='" + str(self.ipv6) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.NextHop.Ipv6s, ['ipv6'], name, value)


                        class Dvrf(Entity):
                            """
                            
                            
                            .. attribute:: dvrf  (key)
                            
                            	VRF name
                            	**type**\: str
                            
                            .. attribute:: dvrf0
                            
                            	
                            	**type**\: list of  		 :py:class:`Dvrf0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Dvrf.Dvrf0>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Dvrf, self).__init__()

                                self.yang_name = "dvrf"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['dvrf']
                                self._child_classes = OrderedDict([("dvrf0", ("dvrf0", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Dvrf.Dvrf0))])
                                self._leafs = OrderedDict([
                                    ('dvrf', (YLeaf(YType.str, 'dvrf'), ['str'])),
                                ])
                                self.dvrf = None

                                self.dvrf0 = YList(self)
                                self._segment_path = lambda: "dvrf" + "[dvrf='" + str(self.dvrf) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Dvrf, ['dvrf'], name, value)


                            class Dvrf0(Entity):
                                """
                                
                                
                                .. attribute:: dvrf0  (key)
                                
                                	VRF name
                                	**type**\: str
                                
                                .. attribute:: next_hop
                                
                                	Next hop along path
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Dvrf.Dvrf0, self).__init__()

                                    self.yang_name = "dvrf0"
                                    self.yang_parent_name = "dvrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['dvrf0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dvrf0', (YLeaf(YType.str, 'dvrf0'), ['str'])),
                                        ('next_hop', (YLeaf(YType.empty, 'next-hop'), ['Empty'])),
                                    ])
                                    self.dvrf0 = None
                                    self.next_hop = None
                                    self._segment_path = lambda: "dvrf0" + "[dvrf0='" + str(self.dvrf0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Default.Dvrf.Dvrf0, ['dvrf0', 'next_hop'], name, value)


                    class Global(Entity):
                        """
                        global routing table
                        
                        .. attribute:: next_hop
                        
                        	IPv6 Next hop
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global.NextHop>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global.NextHop))])
                            self._leafs = OrderedDict()

                            self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._segment_path = lambda: "global"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global, [], name, value)


                        class NextHop(Entity):
                            """
                            IPv6 Next hop
                            
                            .. attribute:: nh_ipv6
                            
                            	
                            	**type**\: list of  		 :py:class:`NhIpv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global.NextHop.NhIpv6>`
                            
                            .. attribute:: verify_availability
                            
                            	Next hop address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("nh-ipv6", ("nh_ipv6", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global.NextHop.NhIpv6))])
                                self._leafs = OrderedDict([
                                    ('verify_availability', (YLeaf(YType.str, 'verify-availability'), ['str'])),
                                ])
                                self.verify_availability = None

                                self.nh_ipv6 = YList(self)
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global.NextHop, ['verify_availability'], name, value)


                            class NhIpv6(Entity):
                                """
                                
                                
                                .. attribute:: nh_ipv6  (key)
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: nh_ipv60
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global.NextHop.NhIpv6, self).__init__()

                                    self.yang_name = "nh-ipv6"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['nh_ipv6']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nh_ipv6', (YLeaf(YType.str, 'nh-ipv6'), ['str'])),
                                        ('nh_ipv60', (YLeaf(YType.str, 'nh-ipv60'), ['str'])),
                                    ])
                                    self.nh_ipv6 = None
                                    self.nh_ipv60 = None
                                    self._segment_path = lambda: "nh-ipv6" + "[nh-ipv6='" + str(self.nh_ipv6) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Global.NextHop.NhIpv6, ['nh_ipv6', 'nh_ipv60'], name, value)


                    class NextHop(Entity):
                        """
                        IPv6 Next hop
                        
                        .. attribute:: nha_ipv6
                        
                        	
                        	**type**\: list of  		 :py:class:`NhaIpv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.NhaIpv6>`
                        
                        .. attribute:: encapsulate
                        
                        	Encapsulation profile for VPN nexthop
                        	**type**\:  :py:class:`Encapsulate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.Encapsulate>`
                        
                        .. attribute:: peer_address
                        
                        	Use peer address (for BGP only)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: recursive
                        
                        	IPv6 address of recursive next\-hop
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: verify_availability
                        
                        	Verify if nexthop is reachable
                        	**type**\:  :py:class:`VerifyAvailability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.VerifyAvailability>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nha-ipv6", ("nha_ipv6", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.NhaIpv6)), ("encapsulate", ("encapsulate", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.Encapsulate)), ("verify-availability", ("verify_availability", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.VerifyAvailability))])
                            self._leafs = OrderedDict([
                                ('peer_address', (YLeaf(YType.empty, 'peer-address'), ['Empty'])),
                                ('recursive', (YLeaf(YType.str, 'recursive'), ['str'])),
                            ])
                            self.peer_address = None
                            self.recursive = None

                            self.encapsulate = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.Encapsulate()
                            self.encapsulate.parent = self
                            self._children_name_map["encapsulate"] = "encapsulate"

                            self.verify_availability = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.VerifyAvailability()
                            self.verify_availability.parent = self
                            self._children_name_map["verify_availability"] = "verify-availability"

                            self.nha_ipv6 = YList(self)
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop, ['peer_address', 'recursive'], name, value)


                        class NhaIpv6(Entity):
                            """
                            
                            
                            .. attribute:: nha_ipv6  (key)
                            
                            	Next hop address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: nha_ipv60
                            
                            	
                            	**type**\: list of  		 :py:class:`NhaIpv60 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.NhaIpv6.NhaIpv60>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.NhaIpv6, self).__init__()

                                self.yang_name = "nha-ipv6"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['nha_ipv6']
                                self._child_classes = OrderedDict([("nha-ipv60", ("nha_ipv60", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.NhaIpv6.NhaIpv60))])
                                self._leafs = OrderedDict([
                                    ('nha_ipv6', (YLeaf(YType.str, 'nha-ipv6'), ['str'])),
                                ])
                                self.nha_ipv6 = None

                                self.nha_ipv60 = YList(self)
                                self._segment_path = lambda: "nha-ipv6" + "[nha-ipv6='" + str(self.nha_ipv6) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.NhaIpv6, ['nha_ipv6'], name, value)


                            class NhaIpv60(Entity):
                                """
                                
                                
                                .. attribute:: nha_ipv60  (key)
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: nh_ipv6
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.NhaIpv6.NhaIpv60, self).__init__()

                                    self.yang_name = "nha-ipv60"
                                    self.yang_parent_name = "nha-ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['nha_ipv60']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nha_ipv60', (YLeaf(YType.str, 'nha-ipv60'), ['str'])),
                                        ('nh_ipv6', (YLeaf(YType.str, 'nh-ipv6'), ['str'])),
                                    ])
                                    self.nha_ipv60 = None
                                    self.nh_ipv6 = None
                                    self._segment_path = lambda: "nha-ipv60" + "[nha-ipv60='" + str(self.nha_ipv60) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.NhaIpv6.NhaIpv60, ['nha_ipv60', 'nh_ipv6'], name, value)


                        class Encapsulate(Entity):
                            """
                            Encapsulation profile for VPN nexthop
                            
                            .. attribute:: l3vpn
                            
                            	Encapsulation profile name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.Encapsulate, self).__init__()

                                self.yang_name = "encapsulate"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('l3vpn', (YLeaf(YType.str, 'l3vpn'), ['str'])),
                                ])
                                self.l3vpn = None
                                self._segment_path = lambda: "encapsulate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.Encapsulate, ['l3vpn'], name, value)


                        class VerifyAvailability(Entity):
                            """
                            Verify if nexthop is reachable
                            
                            .. attribute:: va_ipv6
                            
                            	
                            	**type**\: list of  		 :py:class:`VaIpv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.VerifyAvailability.VaIpv6>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.VerifyAvailability, self).__init__()

                                self.yang_name = "verify-availability"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("va-ipv6", ("va_ipv6", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.VerifyAvailability.VaIpv6))])
                                self._leafs = OrderedDict()

                                self.va_ipv6 = YList(self)
                                self._segment_path = lambda: "verify-availability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.VerifyAvailability, [], name, value)


                            class VaIpv6(Entity):
                                """
                                
                                
                                .. attribute:: va_ipv6  (key)
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: seq_nh
                                
                                	Sequence to insert into next\-hop list
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.VerifyAvailability.VaIpv6, self).__init__()

                                    self.yang_name = "va-ipv6"
                                    self.yang_parent_name = "verify-availability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['va_ipv6']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('va_ipv6', (YLeaf(YType.str, 'va-ipv6'), ['str'])),
                                        ('seq_nh', (YLeaf(YType.uint16, 'seq-nh'), ['int'])),
                                    ])
                                    self.va_ipv6 = None
                                    self.seq_nh = None
                                    self._segment_path = lambda: "va-ipv6" + "[va-ipv6='" + str(self.va_ipv6) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.NextHop.VerifyAvailability.VaIpv6, ['va_ipv6', 'seq_nh'], name, value)


                    class Bvrf(Entity):
                        """
                        
                        
                        .. attribute:: bvrf  (key)
                        
                        	VRF name
                        	**type**\: str
                        
                        .. attribute:: bvrf0
                        
                        	
                        	**type**\: list of  		 :py:class:`Bvrf0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf.Bvrf0>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf, self).__init__()

                            self.yang_name = "bvrf"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['bvrf']
                            self._child_classes = OrderedDict([("bvrf0", ("bvrf0", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf.Bvrf0))])
                            self._leafs = OrderedDict([
                                ('bvrf', (YLeaf(YType.str, 'bvrf'), ['str'])),
                            ])
                            self.bvrf = None

                            self.bvrf0 = YList(self)
                            self._segment_path = lambda: "bvrf" + "[bvrf='" + str(self.bvrf) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf, ['bvrf'], name, value)


                        class Bvrf0(Entity):
                            """
                            
                            
                            .. attribute:: bvrf0  (key)
                            
                            	VRF name
                            	**type**\: str
                            
                            .. attribute:: next_hop
                            
                            	IPv6 Next hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf.Bvrf0.NextHop>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf.Bvrf0, self).__init__()

                                self.yang_name = "bvrf0"
                                self.yang_parent_name = "bvrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['bvrf0']
                                self._child_classes = OrderedDict([("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf.Bvrf0.NextHop))])
                                self._leafs = OrderedDict([
                                    ('bvrf0', (YLeaf(YType.str, 'bvrf0'), ['str'])),
                                ])
                                self.bvrf0 = None

                                self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf.Bvrf0.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._segment_path = lambda: "bvrf0" + "[bvrf0='" + str(self.bvrf0) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf.Bvrf0, ['bvrf0'], name, value)


                            class NextHop(Entity):
                                """
                                IPv6 Next hop
                                
                                .. attribute:: bipv6
                                
                                	Next hop address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: verify_availability
                                
                                	Verify if nexthop is reachable
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf.Bvrf0.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "bvrf0"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bipv6', (YLeaf(YType.str, 'bipv6'), ['str'])),
                                        ('verify_availability', (YLeaf(YType.empty, 'verify-availability'), ['Empty'])),
                                    ])
                                    self.bipv6 = None
                                    self.verify_availability = None
                                    self._segment_path = lambda: "next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Ipv6.Bvrf.Bvrf0.NextHop, ['bipv6', 'verify_availability'], name, value)


                class Level(Entity):
                    """
                    Where to import route
                    
                    .. attribute:: level_1
                    
                    	Import into a level\-1 area
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level_1_2
                    
                    	Import into level\-1 and level\-2
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level_2
                    
                    	Import into level\-2 sub\-domain
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nssa_only
                    
                    	Import only into OSPF NSSA areas and don't propagate
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                            ('level_1_2', (YLeaf(YType.empty, 'level-1-2'), ['Empty'])),
                            ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                        ])
                        self.level_1 = None
                        self.level_1_2 = None
                        self.level_2 = None
                        self.nssa_only = None
                        self._segment_path = lambda: "level"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Level, ['level_1', 'level_1_2', 'level_2', 'nssa_only'], name, value)


                class Lisp(Entity):
                    """
                    Locator ID Separation Protocol specific information
                    
                    .. attribute:: locator_set
                    
                    	The name of the locator set
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                        ])
                        self.locator_set = None
                        self._segment_path = lambda: "lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Lisp, ['locator_set'], name, value)


                class Metric(Entity):
                    """
                    Metric value for destination routing protocol
                    
                    .. attribute:: metric_change
                    
                    	+/\-<metric>;;Add or subtract metric
                    	**type**\: str
                    
                    	**pattern:** (\\+\|\-)\\d{1,10}
                    
                    .. attribute:: values
                    
                    	
                    	**type**\:  :py:class:`Values <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Metric.Values>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("values", ("values", Native.RouteMap.RouteMapWithoutOrderSeq.Set.Metric.Values))])
                        self._leafs = OrderedDict([
                            ('metric_change', (YLeaf(YType.str, 'metric-change'), ['str'])),
                        ])
                        self.metric_change = None

                        self.values = Native.RouteMap.RouteMapWithoutOrderSeq.Set.Metric.Values()
                        self.values.parent = self
                        self._children_name_map["values"] = "values"
                        self._segment_path = lambda: "metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Metric, ['metric_change'], name, value)


                    class Values(Entity):
                        """
                        
                        
                        .. attribute:: value
                        
                        	Metric value or Bandwidth in Kbits per second
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: delay
                        
                        	EIGRP delay metric, in 10 microsecond units
                        	**type**\: str
                        
                        	**pattern:** (\\+\|\-)?\\d{1,10}
                        
                        .. attribute:: reliability
                        
                        	EIGRP reliability metric where 255 is 100% reliable
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: loading
                        
                        	EIGRP Effective bandwidth metric (Loading) where 255 is 100% loaded
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: mtu
                        
                        	EIGRP MTU of the path
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Metric.Values, self).__init__()

                            self.yang_name = "values"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                ('delay', (YLeaf(YType.str, 'delay'), ['str'])),
                                ('reliability', (YLeaf(YType.uint8, 'reliability'), ['int'])),
                                ('loading', (YLeaf(YType.uint8, 'loading'), ['int'])),
                                ('mtu', (YLeaf(YType.uint32, 'MTU'), ['int'])),
                            ])
                            self.value = None
                            self.delay = None
                            self.reliability = None
                            self.loading = None
                            self.mtu = None
                            self._segment_path = lambda: "values"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Metric.Values, ['value', 'delay', 'reliability', 'loading', 'mtu'], name, value)


                class Origin(Entity):
                    """
                    BGP origin code
                    
                    .. attribute:: origin_value
                    
                    	
                    	**type**\:  :py:class:`OriginValue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Set.Origin.OriginValue>`
                    
                    .. attribute:: egp
                    
                    	remote EGP
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Origin, self).__init__()

                        self.yang_name = "origin"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('origin_value', (YLeaf(YType.enumeration, 'origin-value'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RouteMap.RouteMapWithoutOrderSeq.Set.Origin.OriginValue')])),
                            ('egp', (YLeaf(YType.uint32, 'egp'), ['int'])),
                        ])
                        self.origin_value = None
                        self.egp = None
                        self._segment_path = lambda: "origin"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Origin, ['origin_value', 'egp'], name, value)

                    class OriginValue(Enum):
                        """
                        OriginValue (Enum Class)

                        .. data:: igp = 0

                        .. data:: incomplete = 1

                        """

                        igp = Enum.YLeaf(0, "igp")

                        incomplete = Enum.YLeaf(1, "incomplete")



                class Tag(Entity):
                    """
                    Tag value for destination routing protocol
                    
                    .. attribute:: tag_val
                    
                    	Tag value
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tag_ipv4
                    
                    	Tag value(dotted decimal format)
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Tag, self).__init__()

                        self.yang_name = "tag"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag_val', (YLeaf(YType.uint32, 'tag-val'), ['int'])),
                            ('tag_ipv4', (YLeaf(YType.str, 'tag-ipv4'), ['str'])),
                        ])
                        self.tag_val = None
                        self.tag_ipv4 = None
                        self._segment_path = lambda: "tag"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Set.Tag, ['tag_val', 'tag_ipv4'], name, value)


            class Match(Entity):
                """
                Match values from routing table
                
                .. attribute:: additional_paths
                
                	BGP Add\-Path match policies
                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths>`
                
                .. attribute:: as_path
                
                	Match BGP AS path list
                	**type**\:  :py:class:`AsPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.AsPath>`
                
                .. attribute:: clns
                
                	CLNS information
                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Clns>`
                
                .. attribute:: community
                
                	Match BGP community list
                	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Community>`
                
                .. attribute:: extcommunity
                
                	Match BGP/VPN extended community list
                	**type**\:  :py:class:`Extcommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Extcommunity>`
                
                .. attribute:: interface
                
                	SPAN source interface
                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Interface>`
                
                .. attribute:: ip
                
                	IP specific information
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip>`
                
                .. attribute:: ipv6
                
                	IPv6 specific information
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6>`
                
                .. attribute:: length
                
                	Packet length
                	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Length>`
                
                .. attribute:: local_preference
                
                	Local preference for route
                	**type**\:  :py:class:`LocalPreference <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.LocalPreference>`
                
                .. attribute:: mdt_group
                
                	Match routes corresponding to MDT group
                	**type**\:  :py:class:`MdtGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.MdtGroup>`
                
                .. attribute:: metric
                
                	Match metric of route
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Metric>`
                
                .. attribute:: mpls_label
                
                	Match routes which have MPLS labels
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: policy_list
                
                	Match IP policy list
                	**type**\:  :py:class:`PolicyList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.PolicyList>`
                
                .. attribute:: route_type
                
                	Match route\-type of route
                	**type**\:  :py:class:`RouteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType>`
                
                .. attribute:: rpki
                
                	Match RPKI state of route
                	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Rpki>`
                
                .. attribute:: source_protocol
                
                	Match source\-protocol of route
                	**type**\:  :py:class:`SourceProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.SourceProtocol>`
                
                	**presence node**\: True
                
                .. attribute:: tag
                
                	Match tag of route
                	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Tag>`
                
                .. attribute:: track
                
                	tracking object
                	**type**\: int
                
                	**range:** 1..1000
                
                

                """

                _prefix = 'ios-route-map'
                _revision = '2018-03-08'

                def __init__(self):
                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Match, self).__init__()

                    self.yang_name = "match"
                    self.yang_parent_name = "route-map-without-order-seq"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths)), ("as-path", ("as_path", Native.RouteMap.RouteMapWithoutOrderSeq.Match.AsPath)), ("clns", ("clns", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Clns)), ("community", ("community", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Community)), ("extcommunity", ("extcommunity", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Extcommunity)), ("interface", ("interface", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Interface)), ("ip", ("ip", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip)), ("ipv6", ("ipv6", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6)), ("length", ("length", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Length)), ("local-preference", ("local_preference", Native.RouteMap.RouteMapWithoutOrderSeq.Match.LocalPreference)), ("mdt-group", ("mdt_group", Native.RouteMap.RouteMapWithoutOrderSeq.Match.MdtGroup)), ("metric", ("metric", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Metric)), ("policy-list", ("policy_list", Native.RouteMap.RouteMapWithoutOrderSeq.Match.PolicyList)), ("route-type", ("route_type", Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType)), ("rpki", ("rpki", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Rpki)), ("source-protocol", ("source_protocol", Native.RouteMap.RouteMapWithoutOrderSeq.Match.SourceProtocol)), ("tag", ("tag", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Tag))])
                    self._leafs = OrderedDict([
                        ('mpls_label', (YLeaf(YType.empty, 'mpls-label'), ['Empty'])),
                        ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                    ])
                    self.mpls_label = None
                    self.track = None

                    self.additional_paths = Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths()
                    self.additional_paths.parent = self
                    self._children_name_map["additional_paths"] = "additional-paths"

                    self.as_path = Native.RouteMap.RouteMapWithoutOrderSeq.Match.AsPath()
                    self.as_path.parent = self
                    self._children_name_map["as_path"] = "as-path"

                    self.clns = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Clns()
                    self.clns.parent = self
                    self._children_name_map["clns"] = "clns"

                    self.community = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Community()
                    self.community.parent = self
                    self._children_name_map["community"] = "community"

                    self.extcommunity = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Extcommunity()
                    self.extcommunity.parent = self
                    self._children_name_map["extcommunity"] = "extcommunity"

                    self.interface = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Interface()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"

                    self.ip = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.ipv6 = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.length = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Length()
                    self.length.parent = self
                    self._children_name_map["length"] = "length"

                    self.local_preference = Native.RouteMap.RouteMapWithoutOrderSeq.Match.LocalPreference()
                    self.local_preference.parent = self
                    self._children_name_map["local_preference"] = "local-preference"

                    self.mdt_group = Native.RouteMap.RouteMapWithoutOrderSeq.Match.MdtGroup()
                    self.mdt_group.parent = self
                    self._children_name_map["mdt_group"] = "mdt-group"

                    self.metric = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "metric"

                    self.policy_list = Native.RouteMap.RouteMapWithoutOrderSeq.Match.PolicyList()
                    self.policy_list.parent = self
                    self._children_name_map["policy_list"] = "policy-list"

                    self.route_type = Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType()
                    self.route_type.parent = self
                    self._children_name_map["route_type"] = "route-type"

                    self.rpki = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Rpki()
                    self.rpki.parent = self
                    self._children_name_map["rpki"] = "rpki"

                    self.source_protocol = None
                    self._children_name_map["source_protocol"] = "source-protocol"

                    self.tag = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Tag()
                    self.tag.parent = self
                    self._children_name_map["tag"] = "tag"
                    self._segment_path = lambda: "match"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match, ['mpls_label', 'track'], name, value)


                class AdditionalPaths(Entity):
                    """
                    BGP Add\-Path match policies
                    
                    .. attribute:: advertise_set
                    
                    	BGP Add\-Path advertise\-set policy
                    	**type**\:  :py:class:`AdvertiseSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths, self).__init__()

                        self.yang_name = "additional-paths"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("advertise-set", ("advertise_set", Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet))])
                        self._leafs = OrderedDict()

                        self.advertise_set = Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet()
                        self.advertise_set.parent = self
                        self._children_name_map["advertise_set"] = "advertise-set"
                        self._segment_path = lambda: "additional-paths"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths, [], name, value)


                    class AdvertiseSet(Entity):
                        """
                        BGP Add\-Path advertise\-set policy
                        
                        .. attribute:: all
                        
                        	BGP Add\-Path advertise all paths
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.All>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: best
                        
                        	BGP Add\-Path advertise best n paths
                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.Best>`
                        
                        .. attribute:: best_range
                        
                        	BGP Add\-Path advertise best paths (range m to n)
                        	**type**\:  :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.BestRange>`
                        
                        .. attribute:: group_best
                        
                        	BGP Add\-Path advertise group\-best path
                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.GroupBest>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet, self).__init__()

                            self.yang_name = "advertise-set"
                            self.yang_parent_name = "additional-paths"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("all", ("all", Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.All)), ("best", ("best", Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.Best)), ("best-range", ("best_range", Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.BestRange)), ("group-best", ("group_best", Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.GroupBest))])
                            self._leafs = OrderedDict()

                            self.all = None
                            self._children_name_map["all"] = "all"

                            self.best = Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.Best()
                            self.best.parent = self
                            self._children_name_map["best"] = "best"

                            self.best_range = Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.BestRange()
                            self.best_range.parent = self
                            self._children_name_map["best_range"] = "best-range"

                            self.group_best = None
                            self._children_name_map["group_best"] = "group-best"
                            self._segment_path = lambda: "advertise-set"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet, [], name, value)


                        class All(Entity):
                            """
                            BGP Add\-Path advertise all paths
                            
                            .. attribute:: best
                            
                            	BGP Add\-Path best n paths to advertise
                            	**type**\: int
                            
                            	**range:** 1..3
                            
                            .. attribute:: best_range
                            
                            	BGP Add\-Path best paths to advertise (lower limit)
                            	**type**\: int
                            
                            	**range:** 1..3
                            
                            .. attribute:: group_best
                            
                            	BGP Add\-Path advertise group\-best path
                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.All.GroupBest>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.All, self).__init__()

                                self.yang_name = "all"
                                self.yang_parent_name = "advertise-set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.All.GroupBest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                    ('best_range', (YLeaf(YType.uint8, 'best-range'), ['int'])),
                                ])
                                self.best = None
                                self.best_range = None

                                self.group_best = None
                                self._children_name_map["group_best"] = "group-best"
                                self._segment_path = lambda: "all"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.All, ['best', 'best_range'], name, value)


                            class GroupBest(Entity):
                                """
                                BGP Add\-Path advertise group\-best path
                                
                                .. attribute:: best
                                
                                	BGP Add\-Path advertise best n paths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: best_range
                                
                                	BGP Add\-Path advertise best paths (range m to n)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.All.GroupBest, self).__init__()

                                    self.yang_name = "group-best"
                                    self.yang_parent_name = "all"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('best', (YLeaf(YType.empty, 'best'), ['Empty'])),
                                        ('best_range', (YLeaf(YType.empty, 'best-range'), ['Empty'])),
                                    ])
                                    self.best = None
                                    self.best_range = None
                                    self._segment_path = lambda: "group-best"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.All.GroupBest, ['best', 'best_range'], name, value)


                        class Best(Entity):
                            """
                            BGP Add\-Path advertise best n paths
                            
                            .. attribute:: best_range
                            
                            	
                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.Best.BestRange>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.Best, self).__init__()

                                self.yang_name = "best"
                                self.yang_parent_name = "advertise-set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.Best.BestRange))])
                                self._leafs = OrderedDict()

                                self.best_range = YList(self)
                                self._segment_path = lambda: "best"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.Best, [], name, value)


                            class BestRange(Entity):
                                """
                                
                                
                                .. attribute:: best_range  (key)
                                
                                	BGP Add\-Path best n paths to advertise
                                	**type**\: int
                                
                                	**range:** 1..3
                                
                                .. attribute:: all
                                
                                	BGP Add\-Path advertise all paths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: group_best
                                
                                	BGP Add\-Path advertise group\-best path
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.Best.BestRange, self).__init__()

                                    self.yang_name = "best-range"
                                    self.yang_parent_name = "best"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['best_range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('best_range', (YLeaf(YType.uint8, 'best-range'), ['int'])),
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                    ])
                                    self.best_range = None
                                    self.all = None
                                    self.group_best = None
                                    self._segment_path = lambda: "best-range" + "[best-range='" + str(self.best_range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.Best.BestRange, ['best_range', 'all', 'group_best'], name, value)


                        class BestRange(Entity):
                            """
                            BGP Add\-Path advertise best paths (range m to n)
                            
                            .. attribute:: adv_path
                            
                            	
                            	**type**\: list of  		 :py:class:`AdvPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.BestRange.AdvPath>`
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.BestRange, self).__init__()

                                self.yang_name = "best-range"
                                self.yang_parent_name = "advertise-set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adv-path", ("adv_path", Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.BestRange.AdvPath))])
                                self._leafs = OrderedDict()

                                self.adv_path = YList(self)
                                self._segment_path = lambda: "best-range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.BestRange, [], name, value)


                            class AdvPath(Entity):
                                """
                                
                                
                                .. attribute:: adv_path  (key)
                                
                                	BGP Add\-Path best paths to advertise (lower limit)
                                	**type**\: int
                                
                                	**range:** 1..3
                                
                                .. attribute:: adv_path0
                                
                                	BGP Add\-Path best paths to advertise (upper limit)
                                	**type**\: int
                                
                                	**range:** 1..3
                                
                                

                                """

                                _prefix = 'ios-route-map'
                                _revision = '2018-03-08'

                                def __init__(self):
                                    super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.BestRange.AdvPath, self).__init__()

                                    self.yang_name = "adv-path"
                                    self.yang_parent_name = "best-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['adv_path']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('adv_path', (YLeaf(YType.uint8, 'adv-path'), ['int'])),
                                        ('adv_path0', (YLeaf(YType.uint8, 'adv-path0'), ['int'])),
                                    ])
                                    self.adv_path = None
                                    self.adv_path0 = None
                                    self._segment_path = lambda: "adv-path" + "[adv-path='" + str(self.adv_path) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.BestRange.AdvPath, ['adv_path', 'adv_path0'], name, value)


                        class GroupBest(Entity):
                            """
                            BGP Add\-Path advertise group\-best path
                            
                            .. attribute:: all
                            
                            	BGP Add\-Path advertise all paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best
                            
                            	BGP Add\-Path best n paths to advertise
                            	**type**\: int
                            
                            	**range:** 1..3
                            
                            .. attribute:: best_range
                            
                            	BGP Add\-Path best paths to advertise (lower limit)
                            	**type**\: int
                            
                            	**range:** 1..3
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.GroupBest, self).__init__()

                                self.yang_name = "group-best"
                                self.yang_parent_name = "advertise-set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                    ('best_range', (YLeaf(YType.uint8, 'best-range'), ['int'])),
                                ])
                                self.all = None
                                self.best = None
                                self.best_range = None
                                self._segment_path = lambda: "group-best"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AdditionalPaths.AdvertiseSet.GroupBest, ['all', 'best', 'best_range'], name, value)


                class AsPath(Entity):
                    """
                    Match BGP AS path list
                    
                    .. attribute:: access_list
                    
                    	AS path access\-list
                    	**type**\: list of int
                    
                    	**range:** 1..500
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AsPath, self).__init__()

                        self.yang_name = "as-path"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('access_list', (YLeafList(YType.uint16, 'access-list'), ['int'])),
                        ])
                        self.access_list = []
                        self._segment_path = lambda: "as-path"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.AsPath, ['access_list'], name, value)


                class Clns(Entity):
                    """
                    CLNS information
                    
                    .. attribute:: name
                    
                    	Named clna list
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Clns, self).__init__()

                        self.yang_name = "clns"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeafList(YType.str, 'name'), ['str'])),
                        ])
                        self.name = []
                        self._segment_path = lambda: "clns"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Clns, ['name'], name, value)


                class Community(Entity):
                    """
                    Match BGP community list
                    
                    .. attribute:: name
                    
                    	Named Access List
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Community, self).__init__()

                        self.yang_name = "community"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeafList(YType.str, 'name'), ['str'])),
                        ])
                        self.name = []
                        self._segment_path = lambda: "community"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Community, ['name'], name, value)


                class Extcommunity(Entity):
                    """
                    Match BGP/VPN extended community list
                    
                    .. attribute:: name
                    
                    	Named Access List
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Extcommunity, self).__init__()

                        self.yang_name = "extcommunity"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeafList(YType.str, 'name'), ['str'])),
                        ])
                        self.name = []
                        self._segment_path = lambda: "extcommunity"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Extcommunity, ['name'], name, value)


                class Interface(Entity):
                    """
                    SPAN source interface
                    
                    .. attribute:: interface
                    
                    	
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface', (YLeafList(YType.str, 'interface'), ['str'])),
                        ])
                        self.interface = []
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Interface, ['interface'], name, value)


                class Ip(Entity):
                    """
                    IP specific information
                    
                    .. attribute:: address
                    
                    	Match address of route or match packet
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Address>`
                    
                    .. attribute:: flowspec
                    
                    	Match address of route
                    	**type**\:  :py:class:`Flowspec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec>`
                    
                    .. attribute:: next_hop
                    
                    	Match next\-hop address of route
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.NextHop>`
                    
                    .. attribute:: redistribution_source
                    
                    	route redistribution source (EIGRP only)
                    	**type**\:  :py:class:`RedistributionSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.RedistributionSource>`
                    
                    .. attribute:: route_source
                    
                    	Match advertising source address of route
                    	**type**\:  :py:class:`RouteSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.RouteSource>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Address)), ("flowspec", ("flowspec", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.NextHop)), ("redistribution-source", ("redistribution_source", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.RedistributionSource)), ("route-source", ("route_source", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.RouteSource))])
                        self._leafs = OrderedDict()

                        self.address = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.flowspec = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec()
                        self.flowspec.parent = self
                        self._children_name_map["flowspec"] = "flowspec"

                        self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"

                        self.redistribution_source = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.RedistributionSource()
                        self.redistribution_source.parent = self
                        self._children_name_map["redistribution_source"] = "redistribution-source"

                        self.route_source = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.RouteSource()
                        self.route_source.parent = self
                        self._children_name_map["route_source"] = "route-source"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip, [], name, value)


                    class Address(Entity):
                        """
                        Match address of route or match packet
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: list of str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	Match entries of prefix\-lists
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = []
                            self.prefix_list = []
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Address, ['access_list', 'prefix_list'], name, value)


                    class Flowspec(Entity):
                        """
                        Match address of route
                        
                        .. attribute:: dest_pfx
                        
                        	Match dest prefix component of flowspec prefix
                        	**type**\:  :py:class:`DestPfx <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec.DestPfx>`
                        
                        .. attribute:: src_pfx
                        
                        	Match source prefix component of flowspec prefix
                        	**type**\:  :py:class:`SrcPfx <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec.SrcPfx>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec, self).__init__()

                            self.yang_name = "flowspec"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dest-pfx", ("dest_pfx", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec.DestPfx)), ("src-pfx", ("src_pfx", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec.SrcPfx))])
                            self._leafs = OrderedDict()

                            self.dest_pfx = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec.DestPfx()
                            self.dest_pfx.parent = self
                            self._children_name_map["dest_pfx"] = "dest-pfx"

                            self.src_pfx = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec.SrcPfx()
                            self.src_pfx.parent = self
                            self._children_name_map["src_pfx"] = "src-pfx"
                            self._segment_path = lambda: "flowspec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec, [], name, value)


                        class DestPfx(Entity):
                            """
                            Match dest prefix component of flowspec prefix
                            
                            .. attribute:: access_list
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: list of str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: prefix_list
                            
                            	Match entries of prefix\-lists
                            	**type**\: list of str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec.DestPfx, self).__init__()

                                self.yang_name = "dest-pfx"
                                self.yang_parent_name = "flowspec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                    ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.access_list = []
                                self.prefix_list = []
                                self._segment_path = lambda: "dest-pfx"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec.DestPfx, ['access_list', 'prefix_list'], name, value)


                        class SrcPfx(Entity):
                            """
                            Match source prefix component of flowspec prefix
                            
                            .. attribute:: access_list
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: list of int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: list of str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: prefix_list
                            
                            	Match entries of prefix\-lists
                            	**type**\: list of str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec.SrcPfx, self).__init__()

                                self.yang_name = "src-pfx"
                                self.yang_parent_name = "flowspec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                    ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.access_list = []
                                self.prefix_list = []
                                self._segment_path = lambda: "src-pfx"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.Flowspec.SrcPfx, ['access_list', 'prefix_list'], name, value)


                    class NextHop(Entity):
                        """
                        Match next\-hop address of route
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: list of str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	Match entries of prefix\-lists
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = []
                            self.prefix_list = []
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.NextHop, ['access_list', 'prefix_list'], name, value)


                    class RedistributionSource(Entity):
                        """
                        route redistribution source (EIGRP only)
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: list of str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	Match entries of prefix\-lists
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.RedistributionSource, self).__init__()

                            self.yang_name = "redistribution-source"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = []
                            self.prefix_list = []
                            self._segment_path = lambda: "redistribution-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.RedistributionSource, ['access_list', 'prefix_list'], name, value)


                    class RouteSource(Entity):
                        """
                        Match advertising source address of route
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: list of int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: list of str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	Match entries of prefix\-lists
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.RouteSource, self).__init__()

                            self.yang_name = "route-source"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeafList(YType.str, 'access-list'), ['int','str'])),
                                ('prefix_list', (YLeafList(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = []
                            self.prefix_list = []
                            self._segment_path = lambda: "route-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ip.RouteSource, ['access_list', 'prefix_list'], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 specific information
                    
                    .. attribute:: address
                    
                    	Match address of route
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Address>`
                    
                    .. attribute:: flowspec
                    
                    	Match address of route
                    	**type**\:  :py:class:`Flowspec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec>`
                    
                    .. attribute:: next_hop
                    
                    	Match next\-hop address of route
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.NextHop>`
                    
                    .. attribute:: route_source
                    
                    	Match advertising source address of route
                    	**type**\:  :py:class:`RouteSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.RouteSource>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Address)), ("flowspec", ("flowspec", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec)), ("next-hop", ("next_hop", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.NextHop)), ("route-source", ("route_source", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.RouteSource))])
                        self._leafs = OrderedDict()

                        self.address = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.flowspec = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec()
                        self.flowspec.parent = self
                        self._children_name_map["flowspec"] = "flowspec"

                        self.next_hop = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"

                        self.route_source = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.RouteSource()
                        self.route_source.parent = self
                        self._children_name_map["route_source"] = "route-source"
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6, [], name, value)


                    class Address(Entity):
                        """
                        Match address of route
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	IPv6 prefix\-list
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = None
                            self.prefix_list = None
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Address, ['access_list', 'prefix_list'], name, value)


                    class Flowspec(Entity):
                        """
                        Match address of route
                        
                        .. attribute:: dest_pfx
                        
                        	Match dest prefix component of flowspec prefix
                        	**type**\:  :py:class:`DestPfx <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec.DestPfx>`
                        
                        .. attribute:: src_pfx
                        
                        	Match source prefix component of flowspec prefix
                        	**type**\:  :py:class:`SrcPfx <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec.SrcPfx>`
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec, self).__init__()

                            self.yang_name = "flowspec"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dest-pfx", ("dest_pfx", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec.DestPfx)), ("src-pfx", ("src_pfx", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec.SrcPfx))])
                            self._leafs = OrderedDict()

                            self.dest_pfx = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec.DestPfx()
                            self.dest_pfx.parent = self
                            self._children_name_map["dest_pfx"] = "dest-pfx"

                            self.src_pfx = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec.SrcPfx()
                            self.src_pfx.parent = self
                            self._children_name_map["src_pfx"] = "src-pfx"
                            self._segment_path = lambda: "flowspec"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec, [], name, value)


                        class DestPfx(Entity):
                            """
                            Match dest prefix component of flowspec prefix
                            
                            .. attribute:: access_list
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: prefix_list
                            
                            	IPv6 prefix\-list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec.DestPfx, self).__init__()

                                self.yang_name = "dest-pfx"
                                self.yang_parent_name = "flowspec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.access_list = None
                                self.prefix_list = None
                                self._segment_path = lambda: "dest-pfx"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec.DestPfx, ['access_list', 'prefix_list'], name, value)


                        class SrcPfx(Entity):
                            """
                            Match source prefix component of flowspec prefix
                            
                            .. attribute:: access_list
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: prefix_list
                            
                            	IPv6 prefix\-list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-route-map'
                            _revision = '2018-03-08'

                            def __init__(self):
                                super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec.SrcPfx, self).__init__()

                                self.yang_name = "src-pfx"
                                self.yang_parent_name = "flowspec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.access_list = None
                                self.prefix_list = None
                                self._segment_path = lambda: "src-pfx"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.Flowspec.SrcPfx, ['access_list', 'prefix_list'], name, value)


                    class NextHop(Entity):
                        """
                        Match next\-hop address of route
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	IPv6 prefix\-list
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = None
                            self.prefix_list = None
                            self._segment_path = lambda: "next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.NextHop, ['access_list', 'prefix_list'], name, value)


                    class RouteSource(Entity):
                        """
                        Match advertising source address of route
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: prefix_list
                        
                        	IPv6 prefix\-list
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.RouteSource, self).__init__()

                            self.yang_name = "route-source"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.access_list = None
                            self.prefix_list = None
                            self._segment_path = lambda: "route-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Ipv6.RouteSource, ['access_list', 'prefix_list'], name, value)


                class Length(Entity):
                    """
                    Packet length
                    
                    .. attribute:: lengths
                    
                    	
                    	**type**\: list of  		 :py:class:`Lengths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Length.Lengths>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Length, self).__init__()

                        self.yang_name = "length"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("lengths", ("lengths", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Length.Lengths))])
                        self._leafs = OrderedDict()

                        self.lengths = YList(self)
                        self._segment_path = lambda: "length"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Length, [], name, value)


                    class Lengths(Entity):
                        """
                        
                        
                        .. attribute:: min_len  (key)
                        
                        	Minimum packet length
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        .. attribute:: max_len  (key)
                        
                        	Maximum packet length
                        	**type**\: int
                        
                        	**range:** 0..2147483647
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Length.Lengths, self).__init__()

                            self.yang_name = "lengths"
                            self.yang_parent_name = "length"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['min_len','max_len']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('min_len', (YLeaf(YType.uint32, 'min-len'), ['int'])),
                                ('max_len', (YLeaf(YType.uint32, 'max-len'), ['int'])),
                            ])
                            self.min_len = None
                            self.max_len = None
                            self._segment_path = lambda: "lengths" + "[min-len='" + str(self.min_len) + "']" + "[max-len='" + str(self.max_len) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Length.Lengths, ['min_len', 'max_len'], name, value)


                class LocalPreference(Entity):
                    """
                    Local preference for route
                    
                    .. attribute:: values
                    
                    	
                    	**type**\: list of int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.LocalPreference, self).__init__()

                        self.yang_name = "local-preference"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('values', (YLeafList(YType.uint32, 'values'), ['int'])),
                        ])
                        self.values = []
                        self._segment_path = lambda: "local-preference"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.LocalPreference, ['values'], name, value)


                class MdtGroup(Entity):
                    """
                    Match routes corresponding to MDT group
                    
                    .. attribute:: name
                    
                    	IP Access List
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.MdtGroup, self).__init__()

                        self.yang_name = "mdt-group"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeafList(YType.str, 'name'), ['str'])),
                        ])
                        self.name = []
                        self._segment_path = lambda: "mdt-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.MdtGroup, ['name'], name, value)


                class Metric(Entity):
                    """
                    Match metric of route
                    
                    .. attribute:: metric_value
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: external
                    
                    	match route using external protocol metric
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('metric_value', (YLeaf(YType.str, 'metric-value'), ['str'])),
                            ('external', (YLeaf(YType.str, 'external'), ['str'])),
                        ])
                        self.metric_value = None
                        self.external = None
                        self._segment_path = lambda: "metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Metric, ['metric_value', 'external'], name, value)


                class PolicyList(Entity):
                    """
                    Match IP policy list
                    
                    .. attribute:: policy_map_names
                    
                    	IP Policy map name
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.PolicyList, self).__init__()

                        self.yang_name = "policy-list"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_names', (YLeafList(YType.str, 'policy-map-names'), ['str'])),
                        ])
                        self.policy_map_names = []
                        self._segment_path = lambda: "policy-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.PolicyList, ['policy_map_names'], name, value)


                class RouteType(Entity):
                    """
                    Match route\-type of route
                    
                    .. attribute:: external
                    
                    	external route (BGP, EIGRP and OSPF type 1/2)
                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType.External>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: internal
                    
                    	internal route (including OSPF intra/inter area)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level_1
                    
                    	IS\-IS level\-1 route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level_2
                    
                    	IS\-IS level\-2 route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	locally generated route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nssa_external
                    
                    	nssa\-external route (OSPF type 1/2)
                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType.NssaExternal>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType, self).__init__()

                        self.yang_name = "route-type"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("external", ("external", Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType.External)), ("nssa-external", ("nssa_external", Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType.NssaExternal))])
                        self._leafs = OrderedDict([
                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                            ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                            ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ])
                        self.internal = None
                        self.level_1 = None
                        self.level_2 = None
                        self.local = None

                        self.external = None
                        self._children_name_map["external"] = "external"

                        self.nssa_external = None
                        self._children_name_map["nssa_external"] = "nssa-external"
                        self._segment_path = lambda: "route-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType, ['internal', 'level_1', 'level_2', 'local'], name, value)


                    class External(Entity):
                        """
                        external route (BGP, EIGRP and OSPF type 1/2)
                        
                        .. attribute:: type_1
                        
                        	OSPF external type 1 route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: type_2
                        
                        	OSPF external type 2 route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType.External, self).__init__()

                            self.yang_name = "external"
                            self.yang_parent_name = "route-type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('type_1', (YLeaf(YType.empty, 'type-1'), ['Empty'])),
                                ('type_2', (YLeaf(YType.empty, 'type-2'), ['Empty'])),
                            ])
                            self.type_1 = None
                            self.type_2 = None
                            self._segment_path = lambda: "external"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType.External, ['type_1', 'type_2'], name, value)


                    class NssaExternal(Entity):
                        """
                        nssa\-external route (OSPF type 1/2)
                        
                        .. attribute:: type_1
                        
                        	OSPF external type 1 route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: type_2
                        
                        	OSPF external type 2 route
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType.NssaExternal, self).__init__()

                            self.yang_name = "nssa-external"
                            self.yang_parent_name = "route-type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('type_1', (YLeaf(YType.empty, 'type-1'), ['Empty'])),
                                ('type_2', (YLeaf(YType.empty, 'type-2'), ['Empty'])),
                            ])
                            self.type_1 = None
                            self.type_2 = None
                            self._segment_path = lambda: "nssa-external"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.RouteType.NssaExternal, ['type_1', 'type_2'], name, value)


                class Rpki(Entity):
                    """
                    Match RPKI state of route
                    
                    .. attribute:: invalid
                    
                    	RPKI Invalid State
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: not_found
                    
                    	RPKI Not Found State
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: valid
                    
                    	RPKI Valid State
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Rpki, self).__init__()

                        self.yang_name = "rpki"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('invalid', (YLeaf(YType.empty, 'invalid'), ['Empty'])),
                            ('not_found', (YLeaf(YType.empty, 'not-found'), ['Empty'])),
                            ('valid', (YLeaf(YType.empty, 'valid'), ['Empty'])),
                        ])
                        self.invalid = None
                        self.not_found = None
                        self.valid = None
                        self._segment_path = lambda: "rpki"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Rpki, ['invalid', 'not_found', 'valid'], name, value)


                class SourceProtocol(Entity):
                    """
                    Match source\-protocol of route
                    
                    .. attribute:: bgp
                    
                    	Border Gateway Protocol (BGP)
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: list of str
                    
                    .. attribute:: connected
                    
                    	Connected
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: eigrp
                    
                    	Border Gateway Protocol (BGP)
                    	**type**\: list of str
                    
                    .. attribute:: isis
                    
                    	ISO IS\-IS
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: lisp
                    
                    	Locator ID Separation Protocol (LISP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mobile
                    
                    	Mobile routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ospf
                    
                    	Open Shortest Path First (OSPF)
                    	**type**\: list of str
                    
                    .. attribute:: ospfv3
                    
                    	OSPFv3
                    	**type**\: list of str
                    
                    .. attribute:: rip
                    
                    	Routing Information Protocol (RIP)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: static
                    
                    	Static routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.SourceProtocol, self).__init__()

                        self.yang_name = "source-protocol"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('bgp', (YLeafList(YType.str, 'bgp'), ['int','str'])),
                            ('connected', (YLeaf(YType.empty, 'connected'), ['Empty'])),
                            ('eigrp', (YLeafList(YType.str, 'eigrp'), ['str'])),
                            ('isis', (YLeaf(YType.empty, 'isis'), ['Empty'])),
                            ('lisp', (YLeaf(YType.empty, 'lisp'), ['Empty'])),
                            ('mobile', (YLeaf(YType.empty, 'mobile'), ['Empty'])),
                            ('ospf', (YLeafList(YType.str, 'ospf'), ['str'])),
                            ('ospfv3', (YLeafList(YType.str, 'ospfv3'), ['str'])),
                            ('rip', (YLeaf(YType.empty, 'rip'), ['Empty'])),
                            ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                        ])
                        self.bgp = []
                        self.connected = None
                        self.eigrp = []
                        self.isis = None
                        self.lisp = None
                        self.mobile = None
                        self.ospf = []
                        self.ospfv3 = []
                        self.rip = None
                        self.static = None
                        self._segment_path = lambda: "source-protocol"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.SourceProtocol, ['bgp', 'connected', 'eigrp', 'isis', 'lisp', 'mobile', 'ospf', 'ospfv3', 'rip', 'static'], name, value)


                class Tag(Entity):
                    """
                    Match tag of route
                    
                    .. attribute:: tag_value
                    
                    	Tag value
                    	**type**\: list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv4_address
                    
                    	<A.B.C.D>;;Tag value(dotted decimal format)
                    	**type**\: list of str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: list
                    
                    	Route Tag List
                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteMap.RouteMapWithoutOrderSeq.Match.Tag.List>`
                    
                    

                    """

                    _prefix = 'ios-route-map'
                    _revision = '2018-03-08'

                    def __init__(self):
                        super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Tag, self).__init__()

                        self.yang_name = "tag"
                        self.yang_parent_name = "match"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("list", ("list", Native.RouteMap.RouteMapWithoutOrderSeq.Match.Tag.List))])
                        self._leafs = OrderedDict([
                            ('tag_value', (YLeafList(YType.uint32, 'tag_value'), ['int'])),
                            ('ipv4_address', (YLeafList(YType.str, 'ipv4-address'), ['str'])),
                        ])
                        self.tag_value = []
                        self.ipv4_address = []

                        self.list = Native.RouteMap.RouteMapWithoutOrderSeq.Match.Tag.List()
                        self.list.parent = self
                        self._children_name_map["list"] = "list"
                        self._segment_path = lambda: "tag"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Tag, ['tag_value', 'ipv4_address'], name, value)


                    class List(Entity):
                        """
                        Route Tag List
                        
                        .. attribute:: tag_names
                        
                        	Tag list name
                        	**type**\: list of str
                        
                        

                        """

                        _prefix = 'ios-route-map'
                        _revision = '2018-03-08'

                        def __init__(self):
                            super(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Tag.List, self).__init__()

                            self.yang_name = "list"
                            self.yang_parent_name = "tag"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tag_names', (YLeafList(YType.str, 'tag-names'), ['str'])),
                            ])
                            self.tag_names = []
                            self._segment_path = lambda: "list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteMap.RouteMapWithoutOrderSeq.Match.Tag.List, ['tag_names'], name, value)


    class RouteTag(Entity):
        """
        
        
        .. attribute:: list
        
        	
        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag.List>`
        
        .. attribute:: notation
        
        	
        	**type**\:  :py:class:`Notation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag.Notation>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.RouteTag, self).__init__()

            self.yang_name = "route-tag"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-eigrp:list", ("list", Native.RouteTag.List)), ("Cisco-IOS-XE-eigrp:notation", ("notation", Native.RouteTag.Notation))])
            self._leafs = OrderedDict()

            self.list = Native.RouteTag.List()
            self.list.parent = self
            self._children_name_map["list"] = "Cisco-IOS-XE-eigrp:list"

            self.notation = Native.RouteTag.Notation()
            self.notation.parent = self
            self._children_name_map["notation"] = "Cisco-IOS-XE-eigrp:notation"
            self._segment_path = lambda: "route-tag"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.RouteTag, [], name, value)


        class List(Entity):
            """
            
            
            .. attribute:: rt_name
            
            	
            	**type**\: list of  		 :py:class:`RtName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag.List.RtName>`
            
            

            """

            _prefix = 'ios-eigrp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.RouteTag.List, self).__init__()

                self.yang_name = "list"
                self.yang_parent_name = "route-tag"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("rt-name", ("rt_name", Native.RouteTag.List.RtName))])
                self._leafs = OrderedDict()

                self.rt_name = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-eigrp:list"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/route-tag/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.RouteTag.List, [], name, value)


            class RtName(Entity):
                """
                
                
                .. attribute:: rt_name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: deny
                
                	
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag.List.RtName.Deny>`
                
                .. attribute:: permit
                
                	
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag.List.RtName.Permit>`
                
                .. attribute:: seq
                
                	
                	**type**\:  :py:class:`Seq <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag.List.RtName.Seq>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.RouteTag.List.RtName, self).__init__()

                    self.yang_name = "rt-name"
                    self.yang_parent_name = "list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['rt_name']
                    self._child_classes = OrderedDict([("deny", ("deny", Native.RouteTag.List.RtName.Deny)), ("permit", ("permit", Native.RouteTag.List.RtName.Permit)), ("seq", ("seq", Native.RouteTag.List.RtName.Seq))])
                    self._leafs = OrderedDict([
                        ('rt_name', (YLeaf(YType.str, 'rt-name'), ['str'])),
                    ])
                    self.rt_name = None

                    self.deny = Native.RouteTag.List.RtName.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"

                    self.permit = Native.RouteTag.List.RtName.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"

                    self.seq = Native.RouteTag.List.RtName.Seq()
                    self.seq.parent = self
                    self._children_name_map["seq"] = "seq"
                    self._segment_path = lambda: "rt-name" + "[rt-name='" + str(self.rt_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/route-tag/Cisco-IOS-XE-eigrp:list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.RouteTag.List.RtName, ['rt_name'], name, value)


                class Deny(Entity):
                    """
                    
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag.List.RtName.Deny.Ipv4>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.RouteTag.List.RtName.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "rt-name"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.RouteTag.List.RtName.Deny.Ipv4))])
                        self._leafs = OrderedDict()

                        self.ipv4 = YList(self)
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteTag.List.RtName.Deny, [], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: ipv4  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.RouteTag.List.RtName.Deny.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv4']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.ipv4 = None
                            self.mask = None
                            self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteTag.List.RtName.Deny.Ipv4, ['ipv4', 'mask'], name, value)


                class Permit(Entity):
                    """
                    
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag.List.RtName.Permit.Ipv4>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.RouteTag.List.RtName.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "rt-name"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.RouteTag.List.RtName.Permit.Ipv4))])
                        self._leafs = OrderedDict()

                        self.ipv4 = YList(self)
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteTag.List.RtName.Permit, [], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: ipv4  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.RouteTag.List.RtName.Permit.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv4']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ])
                            self.ipv4 = None
                            self.mask = None
                            self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteTag.List.RtName.Permit.Ipv4, ['ipv4', 'mask'], name, value)


                class Seq(Entity):
                    """
                    
                    
                    .. attribute:: seq_num
                    
                    	
                    	**type**\: list of  		 :py:class:`SeqNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag.List.RtName.Seq.SeqNum>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.RouteTag.List.RtName.Seq, self).__init__()

                        self.yang_name = "seq"
                        self.yang_parent_name = "rt-name"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("seq-num", ("seq_num", Native.RouteTag.List.RtName.Seq.SeqNum))])
                        self._leafs = OrderedDict()

                        self.seq_num = YList(self)
                        self._segment_path = lambda: "seq"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RouteTag.List.RtName.Seq, [], name, value)


                    class SeqNum(Entity):
                        """
                        
                        
                        .. attribute:: seq_num  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967294
                        
                        .. attribute:: deny
                        
                        	
                        	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag.List.RtName.Seq.SeqNum.Deny>`
                        
                        .. attribute:: permit
                        
                        	
                        	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RouteTag.List.RtName.Seq.SeqNum.Permit>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.RouteTag.List.RtName.Seq.SeqNum, self).__init__()

                            self.yang_name = "seq-num"
                            self.yang_parent_name = "seq"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['seq_num']
                            self._child_classes = OrderedDict([("deny", ("deny", Native.RouteTag.List.RtName.Seq.SeqNum.Deny)), ("permit", ("permit", Native.RouteTag.List.RtName.Seq.SeqNum.Permit))])
                            self._leafs = OrderedDict([
                                ('seq_num', (YLeaf(YType.uint32, 'seq-num'), ['int'])),
                            ])
                            self.seq_num = None

                            self.deny = Native.RouteTag.List.RtName.Seq.SeqNum.Deny()
                            self.deny.parent = self
                            self._children_name_map["deny"] = "deny"

                            self.permit = Native.RouteTag.List.RtName.Seq.SeqNum.Permit()
                            self.permit.parent = self
                            self._children_name_map["permit"] = "permit"
                            self._segment_path = lambda: "seq-num" + "[seq-num='" + str(self.seq_num) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RouteTag.List.RtName.Seq.SeqNum, ['seq_num'], name, value)


                        class Deny(Entity):
                            """
                            
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.RouteTag.List.RtName.Seq.SeqNum.Deny, self).__init__()

                                self.yang_name = "deny"
                                self.yang_parent_name = "seq-num"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.mask = None
                                self._segment_path = lambda: "deny"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteTag.List.RtName.Seq.SeqNum.Deny, ['ipv4', 'mask'], name, value)


                        class Permit(Entity):
                            """
                            
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.RouteTag.List.RtName.Seq.SeqNum.Permit, self).__init__()

                                self.yang_name = "permit"
                                self.yang_parent_name = "seq-num"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.mask = None
                                self._segment_path = lambda: "permit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.RouteTag.List.RtName.Seq.SeqNum.Permit, ['ipv4', 'mask'], name, value)


        class Notation(Entity):
            """
            
            
            .. attribute:: dotted_decimal
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-eigrp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.RouteTag.Notation, self).__init__()

                self.yang_name = "notation"
                self.yang_parent_name = "route-tag"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('dotted_decimal', (YLeaf(YType.empty, 'dotted-decimal'), ['Empty'])),
                ])
                self.dotted_decimal = None
                self._segment_path = lambda: "Cisco-IOS-XE-eigrp:notation"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/route-tag/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.RouteTag.Notation, ['dotted_decimal'], name, value)


    class TableMap(Entity):
        """
        Configure Table Map
        
        .. attribute:: name  (key)
        
        	
        	**type**\: str
        
        .. attribute:: default
        
        	the default behavior for setting value not found in the table map
        	**type**\: union of the below types:
        
        		**type**\: int
        
        			**range:** 0..63
        
        		**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap.Default>`
        
        .. attribute:: map
        
        	map to\_value from from\_value
        	**type**\: list of  		 :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TableMap.Map>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.TableMap, self).__init__()

            self.yang_name = "table-map"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['name']
            self._child_classes = OrderedDict([("Cisco-IOS-XE-qos:map", ("map", Native.TableMap.Map))])
            self._leafs = OrderedDict([
                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ('default', (YLeaf(YType.str, 'Cisco-IOS-XE-qos:default'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'TableMap.Default')])),
            ])
            self.name = None
            self.default = None

            self.map = YList(self)
            self._segment_path = lambda: "table-map" + "[name='" + str(self.name) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.TableMap, [u'name', 'default'], name, value)

        class Default(Enum):
            """
            Default (Enum Class)

            the default behavior for setting value not found in the table map

            .. data:: copy = 0

            .. data:: ignore = 1

            """

            copy = Enum.YLeaf(0, "copy")

            ignore = Enum.YLeaf(1, "ignore")



        class Map(Entity):
            """
            map to\_value from from\_value
            
            .. attribute:: from_  (key)
            
            	map from value
            	**type**\: int
            
            	**range:** 0..63
            
            .. attribute:: to  (key)
            
            	map to value
            	**type**\: int
            
            	**range:** 0..63
            
            

            """

            _prefix = 'ios-qos'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.TableMap.Map, self).__init__()

                self.yang_name = "map"
                self.yang_parent_name = "table-map"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = ['from_','to']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('from_', (YLeaf(YType.uint8, 'from'), ['int'])),
                    ('to', (YLeaf(YType.uint8, 'to'), ['int'])),
                ])
                self.from_ = None
                self.to = None
                self._segment_path = lambda: "Cisco-IOS-XE-qos:map" + "[from='" + str(self.from_) + "']" + "[to='" + str(self.to) + "']"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.TableMap.Map, ['from_', 'to'], name, value)


    class Sdm(Entity):
        """
        Switch database management
        
        .. attribute:: prefer
        
        	Config TCAM and ASIC RAM size. Warning\: need to reset switch for configuration to take effect
        	**type**\:  :py:class:`Prefer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Sdm.Prefer>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Sdm, self).__init__()

            self.yang_name = "sdm"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:prefer", ("prefer", Native.Sdm.Prefer))])
            self._leafs = OrderedDict()

            self.prefer = None
            self._children_name_map["prefer"] = "Cisco-IOS-XE-switch:prefer"
            self._segment_path = lambda: "sdm"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Sdm, [], name, value)


        class Prefer(Entity):
            """
            Config TCAM and ASIC RAM size. Warning\: need to reset switch for configuration to take effect
            
            .. attribute:: default
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: qos
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.Sdm.Prefer, self).__init__()

                self.yang_name = "prefer"
                self.yang_parent_name = "sdm"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                    ('qos', (YLeaf(YType.empty, 'qos'), ['Empty'])),
                ])
                self.default = None
                self.qos = None
                self._segment_path = lambda: "Cisco-IOS-XE-switch:prefer"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/sdm/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Sdm.Prefer, [u'default', u'qos'], name, value)


    class Mls(Entity):
        """
        mls global commands
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Mls, self).__init__()

            self.yang_name = "mls"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict()
            self._segment_path = lambda: "mls"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True


    class ObjectGroup(Entity):
        """
        Configure Object group
        
        .. attribute:: network
        
        	network group
        	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Network>`
        
        .. attribute:: security
        
        	security group
        	**type**\: list of  		 :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Security>`
        
        .. attribute:: service
        
        	service group
        	**type**\: list of  		 :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Service>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.ObjectGroup, self).__init__()

            self.yang_name = "object-group"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-object-group:network", ("network", Native.ObjectGroup.Network)), ("Cisco-IOS-XE-object-group:security", ("security", Native.ObjectGroup.Security)), ("Cisco-IOS-XE-object-group:service", ("service", Native.ObjectGroup.Service))])
            self._leafs = OrderedDict()

            self.network = YList(self)
            self.security = YList(self)
            self.service = YList(self)
            self._segment_path = lambda: "object-group"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.ObjectGroup, [], name, value)


        class Network(Entity):
            """
            network group
            
            .. attribute:: name  (key)
            
            	WORD;;object\-group name
            	**type**\: str
            
            .. attribute:: obj_mode_config_network_group
            
            	
            	**type**\:  :py:class:`ObjModeConfigNetworkGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Network.ObjModeConfigNetworkGroup>`
            
            

            """

            _prefix = 'ios-og'
            _revision = '2017-07-31'

            def __init__(self):
                super(Native.ObjectGroup.Network, self).__init__()

                self.yang_name = "network"
                self.yang_parent_name = "object-group"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("obj-Mode-config-network-group", ("obj_mode_config_network_group", Native.ObjectGroup.Network.ObjModeConfigNetworkGroup))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.obj_mode_config_network_group = Native.ObjectGroup.Network.ObjModeConfigNetworkGroup()
                self.obj_mode_config_network_group.parent = self
                self._children_name_map["obj_mode_config_network_group"] = "obj-Mode-config-network-group"
                self._segment_path = lambda: "Cisco-IOS-XE-object-group:network" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/object-group/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ObjectGroup.Network, ['name'], name, value)


            class ObjModeConfigNetworkGroup(Entity):
                """
                
                
                .. attribute:: network_address
                
                	
                	**type**\: list of  		 :py:class:`NetworkAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.NetworkAddress>`
                
                .. attribute:: description
                
                	Network object group description
                	**type**\: str
                
                	**length:** 1..200
                
                .. attribute:: group_object
                
                	Nested object group
                	**type**\: str
                
                .. attribute:: host
                
                	Host address of the object\-group member
                	**type**\: list of  		 :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.Host>`
                
                .. attribute:: range
                
                	
                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.Range>`
                
                

                """

                _prefix = 'ios-og'
                _revision = '2017-07-31'

                def __init__(self):
                    super(Native.ObjectGroup.Network.ObjModeConfigNetworkGroup, self).__init__()

                    self.yang_name = "obj-Mode-config-network-group"
                    self.yang_parent_name = "network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("network_address", ("network_address", Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.NetworkAddress)), ("host", ("host", Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.Host)), ("range", ("range", Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.Range))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('group_object', (YLeaf(YType.str, 'group-object'), ['str'])),
                    ])
                    self.description = None
                    self.group_object = None

                    self.range = Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.Range()
                    self.range.parent = self
                    self._children_name_map["range"] = "range"

                    self.network_address = YList(self)
                    self.host = YList(self)
                    self._segment_path = lambda: "obj-Mode-config-network-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ObjectGroup.Network.ObjModeConfigNetworkGroup, ['description', 'group_object'], name, value)


                class NetworkAddress(Entity):
                    """
                    
                    
                    .. attribute:: ipv4_addr  (key)
                    
                    	A.B.C.D;;Network address of the group members
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv4_mask  (key)
                    
                    	A.B.C.D;;Network mask
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-og'
                    _revision = '2017-07-31'

                    def __init__(self):
                        super(Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.NetworkAddress, self).__init__()

                        self.yang_name = "network_address"
                        self.yang_parent_name = "obj-Mode-config-network-group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['ipv4_addr','ipv4_mask']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4_addr'), ['str'])),
                            ('ipv4_mask', (YLeaf(YType.str, 'ipv4_mask'), ['str'])),
                        ])
                        self.ipv4_addr = None
                        self.ipv4_mask = None
                        self._segment_path = lambda: "network_address" + "[ipv4_addr='" + str(self.ipv4_addr) + "']" + "[ipv4_mask='" + str(self.ipv4_mask) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.NetworkAddress, ['ipv4_addr', 'ipv4_mask'], name, value)


                class Host(Entity):
                    """
                    Host address of the object\-group member
                    
                    .. attribute:: ipv4_host  (key)
                    
                    	Host address of the object\-group member
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                    
                    

                    """

                    _prefix = 'ios-og'
                    _revision = '2017-07-31'

                    def __init__(self):
                        super(Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.Host, self).__init__()

                        self.yang_name = "host"
                        self.yang_parent_name = "obj-Mode-config-network-group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['ipv4_host']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ipv4_host', (YLeaf(YType.str, 'ipv4-host'), ['str','str','str'])),
                        ])
                        self.ipv4_host = None
                        self._segment_path = lambda: "host" + "[ipv4-host='" + str(self.ipv4_host) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.Host, ['ipv4_host'], name, value)


                class Range(Entity):
                    """
                    
                    
                    .. attribute:: ip_addr_min
                    
                    	Starting IPv4 Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ip_addr_max
                    
                    	Ending IPv4 Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-og'
                    _revision = '2017-07-31'

                    def __init__(self):
                        super(Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "obj-Mode-config-network-group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip_addr_min', (YLeaf(YType.str, 'ip-addr-min'), ['str'])),
                            ('ip_addr_max', (YLeaf(YType.str, 'ip-addr-max'), ['str'])),
                        ])
                        self.ip_addr_min = None
                        self.ip_addr_max = None
                        self._segment_path = lambda: "range"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ObjectGroup.Network.ObjModeConfigNetworkGroup.Range, ['ip_addr_min', 'ip_addr_max'], name, value)


        class Security(Entity):
            """
            security group
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: security_group
            
            	
            	**type**\:  :py:class:`SecurityGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Security.SecurityGroup>`
            
            

            """

            _prefix = 'ios-og'
            _revision = '2017-07-31'

            def __init__(self):
                super(Native.ObjectGroup.Security, self).__init__()

                self.yang_name = "security"
                self.yang_parent_name = "object-group"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("security-group", ("security_group", Native.ObjectGroup.Security.SecurityGroup))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.security_group = Native.ObjectGroup.Security.SecurityGroup()
                self.security_group.parent = self
                self._children_name_map["security_group"] = "security-group"
                self._segment_path = lambda: "Cisco-IOS-XE-object-group:security" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/object-group/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ObjectGroup.Security, ['name'], name, value)


            class SecurityGroup(Entity):
                """
                
                
                .. attribute:: description
                
                	Network object group description
                	**type**\: str
                
                	**length:** 1..200
                
                .. attribute:: group_object
                
                	Nested object group
                	**type**\: str
                
                .. attribute:: security_group
                
                	Security Group Tag
                	**type**\:  :py:class:`SecurityGroup_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Security.SecurityGroup.SecurityGroup_>`
                
                

                """

                _prefix = 'ios-og'
                _revision = '2017-07-31'

                def __init__(self):
                    super(Native.ObjectGroup.Security.SecurityGroup, self).__init__()

                    self.yang_name = "security-group"
                    self.yang_parent_name = "security"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("security-group", ("security_group", Native.ObjectGroup.Security.SecurityGroup.SecurityGroup_))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('group_object', (YLeaf(YType.str, 'group-object'), ['str'])),
                    ])
                    self.description = None
                    self.group_object = None

                    self.security_group = Native.ObjectGroup.Security.SecurityGroup.SecurityGroup_()
                    self.security_group.parent = self
                    self._children_name_map["security_group"] = "security-group"
                    self._segment_path = lambda: "security-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ObjectGroup.Security.SecurityGroup, ['description', 'group_object'], name, value)


                class SecurityGroup_(Entity):
                    """
                    Security Group Tag
                    
                    .. attribute:: tag
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-og'
                    _revision = '2017-07-31'

                    def __init__(self):
                        super(Native.ObjectGroup.Security.SecurityGroup.SecurityGroup_, self).__init__()

                        self.yang_name = "security-group"
                        self.yang_parent_name = "security-group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.uint16, 'tag'), ['int'])),
                        ])
                        self.tag = None
                        self._segment_path = lambda: "security-group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ObjectGroup.Security.SecurityGroup.SecurityGroup_, ['tag'], name, value)


        class Service(Entity):
            """
            service group
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: description
            
            	Service object group description
            	**type**\: str
            
            .. attribute:: group_object
            
            	Nested object group
            	**type**\: str
            
            .. attribute:: protocal_number
            
            	
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: ahp
            
            	Authentication Header Protocol
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: eigrp
            
            	Cisco's EIGRP routing protocol
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: esp
            
            	Encapsulation Security Payload
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: gre
            
            	Cisco's GRE tunneling
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: icmp
            
            	Internet Control Message Protocol
            	**type**\:  :py:class:`Icmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Service.Icmp>`
            
            	**presence node**\: True
            
            .. attribute:: igmp
            
            	Internet Gateway Message Protocol
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ip
            
            	Any Internet Protocol
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ipinip
            
            	IP in IP tunneling
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: nos
            
            	KA9Q NOS compatible IP over IP tunneling
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ospf
            
            	OSPF routing protocol
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: pcp
            
            	Payload Compression Protocol
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: pim
            
            	Protocol Independent Multicast
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: tcp
            
            	Transmission Control Protocol
            	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Service.Tcp>`
            
            	**presence node**\: True
            
            .. attribute:: tcp_udp
            
            	TCP or UDP protocol
            	**type**\:  :py:class:`TcpUdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Service.TcpUdp>`
            
            	**presence node**\: True
            
            .. attribute:: udp
            
            	User Datagram Protocol
            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Service.Udp>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios-og'
            _revision = '2017-07-31'

            def __init__(self):
                super(Native.ObjectGroup.Service, self).__init__()

                self.yang_name = "service"
                self.yang_parent_name = "object-group"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("icmp", ("icmp", Native.ObjectGroup.Service.Icmp)), ("tcp", ("tcp", Native.ObjectGroup.Service.Tcp)), ("tcp-udp", ("tcp_udp", Native.ObjectGroup.Service.TcpUdp)), ("udp", ("udp", Native.ObjectGroup.Service.Udp))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('group_object', (YLeaf(YType.str, 'group-object'), ['str'])),
                    ('protocal_number', (YLeaf(YType.uint8, 'protocal-number'), ['int'])),
                    ('ahp', (YLeaf(YType.empty, 'ahp'), ['Empty'])),
                    ('eigrp', (YLeaf(YType.empty, 'eigrp'), ['Empty'])),
                    ('esp', (YLeaf(YType.empty, 'esp'), ['Empty'])),
                    ('gre', (YLeaf(YType.empty, 'gre'), ['Empty'])),
                    ('igmp', (YLeaf(YType.empty, 'igmp'), ['Empty'])),
                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                    ('ipinip', (YLeaf(YType.empty, 'ipinip'), ['Empty'])),
                    ('nos', (YLeaf(YType.empty, 'nos'), ['Empty'])),
                    ('ospf', (YLeaf(YType.empty, 'ospf'), ['Empty'])),
                    ('pcp', (YLeaf(YType.empty, 'pcp'), ['Empty'])),
                    ('pim', (YLeaf(YType.empty, 'pim'), ['Empty'])),
                ])
                self.name = None
                self.description = None
                self.group_object = None
                self.protocal_number = None
                self.ahp = None
                self.eigrp = None
                self.esp = None
                self.gre = None
                self.igmp = None
                self.ip = None
                self.ipinip = None
                self.nos = None
                self.ospf = None
                self.pcp = None
                self.pim = None

                self.icmp = None
                self._children_name_map["icmp"] = "icmp"

                self.tcp = None
                self._children_name_map["tcp"] = "tcp"

                self.tcp_udp = None
                self._children_name_map["tcp_udp"] = "tcp-udp"

                self.udp = None
                self._children_name_map["udp"] = "udp"
                self._segment_path = lambda: "Cisco-IOS-XE-object-group:service" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/object-group/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ObjectGroup.Service, ['name', 'description', 'group_object', 'protocal_number', 'ahp', 'eigrp', 'esp', 'gre', 'igmp', 'ip', 'ipinip', 'nos', 'ospf', 'pcp', 'pim'], name, value)


            class Icmp(Entity):
                """
                Internet Control Message Protocol
                
                .. attribute:: port_number
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: alternate_address
                
                	Alternate address
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: conversion_error
                
                	Datagram conversion
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: echo
                
                	Echo (ping)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: echo_reply
                
                	Echo reply
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: information_reply
                
                	Information replies
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: information_request
                
                	Information requests
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mask_reply
                
                	Mask replies
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mask_request
                
                	Mask requests
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mobile_redirect
                
                	Mobile host redirect
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: parameter_problem
                
                	All parameter problems
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: redirect
                
                	All redirects
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: router_advertisement
                
                	Router discovery advertisements
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: router_solicitation
                
                	Router discovery solicitations
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: source_quench
                
                	Source quenches
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: time_exceeded
                
                	All time exceededs
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timestamp_reply
                
                	Timestamp replies
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timestamp_request
                
                	Timestamp requests
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: traceroute
                
                	Traceroute
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: unreachable
                
                	All unreachables
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-og'
                _revision = '2017-07-31'

                def __init__(self):
                    super(Native.ObjectGroup.Service.Icmp, self).__init__()

                    self.yang_name = "icmp"
                    self.yang_parent_name = "service"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('port_number', (YLeaf(YType.uint8, 'port-number'), ['int'])),
                        ('alternate_address', (YLeaf(YType.empty, 'alternate-address'), ['Empty'])),
                        ('conversion_error', (YLeaf(YType.empty, 'conversion-error'), ['Empty'])),
                        ('echo', (YLeaf(YType.empty, 'echo'), ['Empty'])),
                        ('echo_reply', (YLeaf(YType.empty, 'echo-reply'), ['Empty'])),
                        ('information_reply', (YLeaf(YType.empty, 'information-reply'), ['Empty'])),
                        ('information_request', (YLeaf(YType.empty, 'information-request'), ['Empty'])),
                        ('mask_reply', (YLeaf(YType.empty, 'mask-reply'), ['Empty'])),
                        ('mask_request', (YLeaf(YType.empty, 'mask-request'), ['Empty'])),
                        ('mobile_redirect', (YLeaf(YType.empty, 'mobile-redirect'), ['Empty'])),
                        ('parameter_problem', (YLeaf(YType.empty, 'parameter-problem'), ['Empty'])),
                        ('redirect', (YLeaf(YType.empty, 'redirect'), ['Empty'])),
                        ('router_advertisement', (YLeaf(YType.empty, 'router-advertisement'), ['Empty'])),
                        ('router_solicitation', (YLeaf(YType.empty, 'router-solicitation'), ['Empty'])),
                        ('source_quench', (YLeaf(YType.empty, 'source-quench'), ['Empty'])),
                        ('time_exceeded', (YLeaf(YType.empty, 'time-exceeded'), ['Empty'])),
                        ('timestamp_reply', (YLeaf(YType.empty, 'timestamp-reply'), ['Empty'])),
                        ('timestamp_request', (YLeaf(YType.empty, 'timestamp-request'), ['Empty'])),
                        ('traceroute', (YLeaf(YType.empty, 'traceroute'), ['Empty'])),
                        ('unreachable', (YLeaf(YType.empty, 'unreachable'), ['Empty'])),
                    ])
                    self.port_number = None
                    self.alternate_address = None
                    self.conversion_error = None
                    self.echo = None
                    self.echo_reply = None
                    self.information_reply = None
                    self.information_request = None
                    self.mask_reply = None
                    self.mask_request = None
                    self.mobile_redirect = None
                    self.parameter_problem = None
                    self.redirect = None
                    self.router_advertisement = None
                    self.router_solicitation = None
                    self.source_quench = None
                    self.time_exceeded = None
                    self.timestamp_reply = None
                    self.timestamp_request = None
                    self.traceroute = None
                    self.unreachable = None
                    self._segment_path = lambda: "icmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ObjectGroup.Service.Icmp, ['port_number', 'alternate_address', 'conversion_error', 'echo', 'echo_reply', 'information_reply', 'information_request', 'mask_reply', 'mask_request', 'mobile_redirect', 'parameter_problem', 'redirect', 'router_advertisement', 'router_solicitation', 'source_quench', 'time_exceeded', 'timestamp_reply', 'timestamp_request', 'traceroute', 'unreachable'], name, value)


            class Tcp(Entity):
                """
                Transmission Control Protocol
                
                .. attribute:: tcp_port_list
                
                	
                	**type**\: list of  		 :py:class:`TcpPortList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Service.Tcp.TcpPortList>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-og'
                _revision = '2017-07-31'

                def __init__(self):
                    super(Native.ObjectGroup.Service.Tcp, self).__init__()

                    self.yang_name = "tcp"
                    self.yang_parent_name = "service"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tcp-port-list", ("tcp_port_list", Native.ObjectGroup.Service.Tcp.TcpPortList))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.tcp_port_list = YList(self)
                    self._segment_path = lambda: "tcp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ObjectGroup.Service.Tcp, [], name, value)


                class TcpPortList(Entity):
                    """
                    
                    
                    .. attribute:: tcp_port  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..65535
                    
                    		**type**\:  :py:class:`AclTcpPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AclTcpPortType>`
                    
                    .. attribute:: operator
                    
                    	
                    	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Service.Tcp.TcpPortList.Operator>`
                    
                    .. attribute:: max_tcp_port
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..65535
                    
                    		**type**\:  :py:class:`AclTcpPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AclTcpPortType>`
                    
                    

                    """

                    _prefix = 'ios-og'
                    _revision = '2017-07-31'

                    def __init__(self):
                        super(Native.ObjectGroup.Service.Tcp.TcpPortList, self).__init__()

                        self.yang_name = "tcp-port-list"
                        self.yang_parent_name = "tcp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['tcp_port']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tcp_port', (YLeaf(YType.str, 'tcp-port'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AclTcpPortType', '')])),
                            ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'ObjectGroup.Service.Tcp.TcpPortList.Operator')])),
                            ('max_tcp_port', (YLeaf(YType.str, 'max-tcp-port'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AclTcpPortType', '')])),
                        ])
                        self.tcp_port = None
                        self.operator = None
                        self.max_tcp_port = None
                        self._segment_path = lambda: "tcp-port-list" + "[tcp-port='" + str(self.tcp_port) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ObjectGroup.Service.Tcp.TcpPortList, ['tcp_port', 'operator', 'max_tcp_port'], name, value)

                    class Operator(Enum):
                        """
                        Operator (Enum Class)

                        .. data:: eq = 0

                        .. data:: gt = 1

                        .. data:: lt = 2

                        .. data:: range = 3

                        """

                        eq = Enum.YLeaf(0, "eq")

                        gt = Enum.YLeaf(1, "gt")

                        lt = Enum.YLeaf(2, "lt")

                        range = Enum.YLeaf(3, "range")



            class TcpUdp(Entity):
                """
                TCP or UDP protocol
                
                .. attribute:: udp_port_list
                
                	
                	**type**\: list of  		 :py:class:`UdpPortList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Service.TcpUdp.UdpPortList>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-og'
                _revision = '2017-07-31'

                def __init__(self):
                    super(Native.ObjectGroup.Service.TcpUdp, self).__init__()

                    self.yang_name = "tcp-udp"
                    self.yang_parent_name = "service"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("udp-port-list", ("udp_port_list", Native.ObjectGroup.Service.TcpUdp.UdpPortList))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.udp_port_list = YList(self)
                    self._segment_path = lambda: "tcp-udp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ObjectGroup.Service.TcpUdp, [], name, value)


                class UdpPortList(Entity):
                    """
                    
                    
                    .. attribute:: udp_port  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..65535
                    
                    		**type**\:  :py:class:`AclUdpPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AclUdpPortType>`
                    
                    .. attribute:: operator
                    
                    	
                    	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Service.TcpUdp.UdpPortList.Operator>`
                    
                    .. attribute:: max_udp_port
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..65535
                    
                    		**type**\:  :py:class:`AclUdpPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AclUdpPortType>`
                    
                    

                    """

                    _prefix = 'ios-og'
                    _revision = '2017-07-31'

                    def __init__(self):
                        super(Native.ObjectGroup.Service.TcpUdp.UdpPortList, self).__init__()

                        self.yang_name = "udp-port-list"
                        self.yang_parent_name = "tcp-udp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['udp_port']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('udp_port', (YLeaf(YType.str, 'udp-port'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AclUdpPortType', '')])),
                            ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'ObjectGroup.Service.TcpUdp.UdpPortList.Operator')])),
                            ('max_udp_port', (YLeaf(YType.str, 'max-udp-port'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AclUdpPortType', '')])),
                        ])
                        self.udp_port = None
                        self.operator = None
                        self.max_udp_port = None
                        self._segment_path = lambda: "udp-port-list" + "[udp-port='" + str(self.udp_port) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ObjectGroup.Service.TcpUdp.UdpPortList, ['udp_port', 'operator', 'max_udp_port'], name, value)

                    class Operator(Enum):
                        """
                        Operator (Enum Class)

                        .. data:: eq = 0

                        .. data:: gt = 1

                        .. data:: lt = 2

                        .. data:: range = 3

                        """

                        eq = Enum.YLeaf(0, "eq")

                        gt = Enum.YLeaf(1, "gt")

                        lt = Enum.YLeaf(2, "lt")

                        range = Enum.YLeaf(3, "range")



            class Udp(Entity):
                """
                User Datagram Protocol
                
                .. attribute:: udp_port_list
                
                	
                	**type**\: list of  		 :py:class:`UdpPortList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Service.Udp.UdpPortList>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-og'
                _revision = '2017-07-31'

                def __init__(self):
                    super(Native.ObjectGroup.Service.Udp, self).__init__()

                    self.yang_name = "udp"
                    self.yang_parent_name = "service"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("udp-port-list", ("udp_port_list", Native.ObjectGroup.Service.Udp.UdpPortList))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.udp_port_list = YList(self)
                    self._segment_path = lambda: "udp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ObjectGroup.Service.Udp, [], name, value)


                class UdpPortList(Entity):
                    """
                    
                    
                    .. attribute:: udp_port  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..65535
                    
                    		**type**\:  :py:class:`AclUdpPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AclUdpPortType>`
                    
                    .. attribute:: operator
                    
                    	
                    	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ObjectGroup.Service.Udp.UdpPortList.Operator>`
                    
                    .. attribute:: max_udp_port
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..65535
                    
                    		**type**\:  :py:class:`AclUdpPortType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AclUdpPortType>`
                    
                    

                    """

                    _prefix = 'ios-og'
                    _revision = '2017-07-31'

                    def __init__(self):
                        super(Native.ObjectGroup.Service.Udp.UdpPortList, self).__init__()

                        self.yang_name = "udp-port-list"
                        self.yang_parent_name = "udp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['udp_port']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('udp_port', (YLeaf(YType.str, 'udp-port'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AclUdpPortType', '')])),
                            ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'ObjectGroup.Service.Udp.UdpPortList.Operator')])),
                            ('max_udp_port', (YLeaf(YType.str, 'max-udp-port'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AclUdpPortType', '')])),
                        ])
                        self.udp_port = None
                        self.operator = None
                        self.max_udp_port = None
                        self._segment_path = lambda: "udp-port-list" + "[udp-port='" + str(self.udp_port) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ObjectGroup.Service.Udp.UdpPortList, ['udp_port', 'operator', 'max_udp_port'], name, value)

                    class Operator(Enum):
                        """
                        Operator (Enum Class)

                        .. data:: eq = 0

                        .. data:: gt = 1

                        .. data:: lt = 2

                        .. data:: range = 3

                        """

                        eq = Enum.YLeaf(0, "eq")

                        gt = Enum.YLeaf(1, "gt")

                        lt = Enum.YLeaf(2, "lt")

                        range = Enum.YLeaf(3, "range")



    class PseudowireClass(Entity):
        """
        Pseudowire\-class configuration
        
        .. attribute:: name  (key)
        
        	
        	**type**\: str
        
        .. attribute:: encapsulation
        
        	Data encapsulation method
        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Encapsulation>`
        
        .. attribute:: ip
        
        	Specify IP parameters
        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Ip>`
        
        .. attribute:: control_word
        
        	Include control\-word in pseudowire packets
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: interworking
        
        	Interworking options for pseudowire
        	**type**\:  :py:class:`Interworking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Interworking>`
        
        .. attribute:: load_balance
        
        	Loadbalancing for pseudowire
        	**type**\:  :py:class:`LoadBalance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.LoadBalance>`
        
        .. attribute:: monitor
        
        	Active monitoring of xconnect peer
        	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Monitor>`
        
        .. attribute:: preferred_path
        
        	Preferred path
        	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.PreferredPath>`
        
        .. attribute:: protocol_mpls
        
        	
        	**type**\:  :py:class:`ProtocolMpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.ProtocolMpls>`
        
        .. attribute:: protocol_l2tpv2
        
        	
        	**type**\:  :py:class:`ProtocolL2tpv2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.ProtocolL2tpv2>`
        
        .. attribute:: protocol_l2tpv3
        
        	
        	**type**\:  :py:class:`ProtocolL2tpv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.ProtocolL2tpv3>`
        
        .. attribute:: sequencing
        
        	Sequencing options for pseudowire
        	**type**\:  :py:class:`Sequencing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Sequencing>`
        
        .. attribute:: status
        
        	Pseudowire status capabilities
        	**type**\:  :py:class:`Status <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Status>`
        
        	**presence node**\: True
        
        .. attribute:: switching
        
        	Switching TLV on/off for pseudowire
        	**type**\:  :py:class:`Switching <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Switching>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.PseudowireClass, self).__init__()

            self.yang_name = "pseudowire-class"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['name']
            self._child_classes = OrderedDict([("Cisco-IOS-XE-l2vpn:ip", ("ip", Native.PseudowireClass.Ip)), ("Cisco-IOS-XE-l2vpn:load-balance", ("load_balance", Native.PseudowireClass.LoadBalance)), ("Cisco-IOS-XE-l2vpn:monitor", ("monitor", Native.PseudowireClass.Monitor)), ("Cisco-IOS-XE-l2vpn:preferred-path", ("preferred_path", Native.PseudowireClass.PreferredPath)), ("Cisco-IOS-XE-l2vpn:protocol-mpls", ("protocol_mpls", Native.PseudowireClass.ProtocolMpls)), ("Cisco-IOS-XE-l2vpn:protocol-l2tpv2", ("protocol_l2tpv2", Native.PseudowireClass.ProtocolL2tpv2)), ("Cisco-IOS-XE-l2vpn:protocol-l2tpv3", ("protocol_l2tpv3", Native.PseudowireClass.ProtocolL2tpv3)), ("Cisco-IOS-XE-l2vpn:status", ("status", Native.PseudowireClass.Status)), ("Cisco-IOS-XE-l2vpn:switching", ("switching", Native.PseudowireClass.Switching))])
            self._leafs = OrderedDict([
                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ('encapsulation', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-l2vpn:encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'PseudowireClass.Encapsulation')])),
                ('control_word', (YLeaf(YType.empty, 'Cisco-IOS-XE-l2vpn:control-word'), ['Empty'])),
                ('interworking', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-l2vpn:interworking'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'PseudowireClass.Interworking')])),
                ('sequencing', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-l2vpn:sequencing'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'PseudowireClass.Sequencing')])),
            ])
            self.name = None
            self.encapsulation = None
            self.control_word = None
            self.interworking = None
            self.sequencing = None

            self.ip = Native.PseudowireClass.Ip()
            self.ip.parent = self
            self._children_name_map["ip"] = "Cisco-IOS-XE-l2vpn:ip"

            self.load_balance = Native.PseudowireClass.LoadBalance()
            self.load_balance.parent = self
            self._children_name_map["load_balance"] = "Cisco-IOS-XE-l2vpn:load-balance"

            self.monitor = Native.PseudowireClass.Monitor()
            self.monitor.parent = self
            self._children_name_map["monitor"] = "Cisco-IOS-XE-l2vpn:monitor"

            self.preferred_path = Native.PseudowireClass.PreferredPath()
            self.preferred_path.parent = self
            self._children_name_map["preferred_path"] = "Cisco-IOS-XE-l2vpn:preferred-path"

            self.protocol_mpls = Native.PseudowireClass.ProtocolMpls()
            self.protocol_mpls.parent = self
            self._children_name_map["protocol_mpls"] = "Cisco-IOS-XE-l2vpn:protocol-mpls"

            self.protocol_l2tpv2 = Native.PseudowireClass.ProtocolL2tpv2()
            self.protocol_l2tpv2.parent = self
            self._children_name_map["protocol_l2tpv2"] = "Cisco-IOS-XE-l2vpn:protocol-l2tpv2"

            self.protocol_l2tpv3 = Native.PseudowireClass.ProtocolL2tpv3()
            self.protocol_l2tpv3.parent = self
            self._children_name_map["protocol_l2tpv3"] = "Cisco-IOS-XE-l2vpn:protocol-l2tpv3"

            self.status = None
            self._children_name_map["status"] = "Cisco-IOS-XE-l2vpn:status"

            self.switching = Native.PseudowireClass.Switching()
            self.switching.parent = self
            self._children_name_map["switching"] = "Cisco-IOS-XE-l2vpn:switching"
            self._segment_path = lambda: "pseudowire-class" + "[name='" + str(self.name) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.PseudowireClass, [u'name', 'encapsulation', 'control_word', 'interworking', 'sequencing'], name, value)

        class Encapsulation(Enum):
            """
            Encapsulation (Enum Class)

            Data encapsulation method

            .. data:: l2tpv2 = 0

            .. data:: l2tpv3 = 1

            .. data:: mpls = 2

            .. data:: udp = 3

            """

            l2tpv2 = Enum.YLeaf(0, "l2tpv2")

            l2tpv3 = Enum.YLeaf(1, "l2tpv3")

            mpls = Enum.YLeaf(2, "mpls")

            udp = Enum.YLeaf(3, "udp")


        class Interworking(Enum):
            """
            Interworking (Enum Class)

            Interworking options for pseudowire

            .. data:: ethernet = 0

            .. data:: ip = 1

            .. data:: vlan = 2

            """

            ethernet = Enum.YLeaf(0, "ethernet")

            ip = Enum.YLeaf(1, "ip")

            vlan = Enum.YLeaf(2, "vlan")


        class Sequencing(Enum):
            """
            Sequencing (Enum Class)

            Sequencing options for pseudowire

            .. data:: both = 0

            .. data:: receive = 1

            .. data:: resync = 2

            .. data:: transmit = 3

            """

            both = Enum.YLeaf(0, "both")

            receive = Enum.YLeaf(1, "receive")

            resync = Enum.YLeaf(2, "resync")

            transmit = Enum.YLeaf(3, "transmit")



        class Ip(Entity):
            """
            Specify IP parameters
            
            .. attribute:: dfbit
            
            	DF bit options for tunnel
            	**type**\:  :py:class:`Dfbit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Ip.Dfbit>`
            
            .. attribute:: local
            
            	Specify local information
            	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Ip.Local>`
            
            .. attribute:: pmtu
            
            	Enable Path MTU for tunnel
            	**type**\:  :py:class:`Pmtu <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Ip.Pmtu>`
            
            	**presence node**\: True
            
            .. attribute:: protocol
            
            	Specific IP protocol number to use
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Ip.Protocol>`
            
            .. attribute:: tos
            
            	Specify ToS options for IP tunnel header
            	**type**\:  :py:class:`Tos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Ip.Tos>`
            
            .. attribute:: ttl
            
            	Specify TTL value for IP tunnel header
            	**type**\: int
            
            	**range:** 0..255
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.PseudowireClass.Ip, self).__init__()

                self.yang_name = "ip"
                self.yang_parent_name = "pseudowire-class"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("dfbit", ("dfbit", Native.PseudowireClass.Ip.Dfbit)), ("local", ("local", Native.PseudowireClass.Ip.Local)), ("pmtu", ("pmtu", Native.PseudowireClass.Ip.Pmtu)), ("tos", ("tos", Native.PseudowireClass.Ip.Tos))])
                self._leafs = OrderedDict([
                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'PseudowireClass.Ip.Protocol')])),
                    ('ttl', (YLeaf(YType.uint8, 'ttl'), ['int'])),
                ])
                self.protocol = None
                self.ttl = None

                self.dfbit = Native.PseudowireClass.Ip.Dfbit()
                self.dfbit.parent = self
                self._children_name_map["dfbit"] = "dfbit"

                self.local = Native.PseudowireClass.Ip.Local()
                self.local.parent = self
                self._children_name_map["local"] = "local"

                self.pmtu = None
                self._children_name_map["pmtu"] = "pmtu"

                self.tos = Native.PseudowireClass.Ip.Tos()
                self.tos.parent = self
                self._children_name_map["tos"] = "tos"
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:ip"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PseudowireClass.Ip, ['protocol', 'ttl'], name, value)

            class Protocol(Enum):
                """
                Protocol (Enum Class)

                Specific IP protocol number to use

                .. data:: l2tp = 0

                .. data:: uti = 1

                """

                l2tp = Enum.YLeaf(0, "l2tp")

                uti = Enum.YLeaf(1, "uti")



            class Dfbit(Entity):
                """
                DF bit options for tunnel
                
                .. attribute:: set
                
                	Set the DF bit in the tunnel header
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.Ip.Dfbit, self).__init__()

                    self.yang_name = "dfbit"
                    self.yang_parent_name = "ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('set', (YLeaf(YType.empty, 'set'), ['Empty'])),
                    ])
                    self.set = None
                    self._segment_path = lambda: "dfbit"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.Ip.Dfbit, ['set'], name, value)


            class Local(Entity):
                """
                Specify local information
                
                .. attribute:: interface
                
                	Source interface for pseudowire
                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Ip.Local.Interface>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.Ip.Local, self).__init__()

                    self.yang_name = "local"
                    self.yang_parent_name = "ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Native.PseudowireClass.Ip.Local.Interface))])
                    self._leafs = OrderedDict()

                    self.interface = Native.PseudowireClass.Ip.Local.Interface()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"
                    self._segment_path = lambda: "local"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.Ip.Local, [], name, value)


                class Interface(Entity):
                    """
                    Source interface for pseudowire
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Ip.Local.Interface.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Ip.Local.Interface.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Ip.Local.Interface.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Ip.Local.Interface.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.PseudowireClass.Ip.Local.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "local"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.PseudowireClass.Ip.Local.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.PseudowireClass.Ip.Local.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.PseudowireClass.Ip.Local.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.PseudowireClass.Ip.Local.Interface.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.PseudowireClass.Ip.Local.Interface.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.PseudowireClass.Ip.Local.Interface.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.PseudowireClass.Ip.Local.Interface.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.PseudowireClass.Ip.Local.Interface.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PseudowireClass.Ip.Local.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.PseudowireClass.Ip.Local.Interface.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PseudowireClass.Ip.Local.Interface.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.PseudowireClass.Ip.Local.Interface.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PseudowireClass.Ip.Local.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.PseudowireClass.Ip.Local.Interface.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PseudowireClass.Ip.Local.Interface.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.PseudowireClass.Ip.Local.Interface.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PseudowireClass.Ip.Local.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


            class Pmtu(Entity):
                """
                Enable Path MTU for tunnel
                
                .. attribute:: max
                
                	Maximum Path MTU for session
                	**type**\: int
                
                	**range:** 68..65535
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.Ip.Pmtu, self).__init__()

                    self.yang_name = "pmtu"
                    self.yang_parent_name = "ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                    ])
                    self.max = None
                    self._segment_path = lambda: "pmtu"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.Ip.Pmtu, ['max'], name, value)


            class Tos(Entity):
                """
                Specify ToS options for IP tunnel header
                
                .. attribute:: reflect
                
                	Reflect IP payload ToS on tunnel
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value
                
                	IP ToS value
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.Ip.Tos, self).__init__()

                    self.yang_name = "tos"
                    self.yang_parent_name = "ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('reflect', (YLeaf(YType.empty, 'reflect'), ['Empty'])),
                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                    ])
                    self.reflect = None
                    self.value = None
                    self._segment_path = lambda: "tos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.Ip.Tos, ['reflect', 'value'], name, value)


        class LoadBalance(Entity):
            """
            Loadbalancing for pseudowire
            
            .. attribute:: flow
            
            	Enable flow based load balancing for pseudowire
            	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.LoadBalance.Flow>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.PseudowireClass.LoadBalance, self).__init__()

                self.yang_name = "load-balance"
                self.yang_parent_name = "pseudowire-class"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("flow", ("flow", Native.PseudowireClass.LoadBalance.Flow))])
                self._leafs = OrderedDict()

                self.flow = None
                self._children_name_map["flow"] = "flow"
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:load-balance"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PseudowireClass.LoadBalance, [], name, value)


            class Flow(Entity):
                """
                Enable flow based load balancing for pseudowire
                
                .. attribute:: ethernet
                
                	Ethernet pseudowire flow classification
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.LoadBalance.Flow.Ethernet>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.LoadBalance.Flow, self).__init__()

                    self.yang_name = "flow"
                    self.yang_parent_name = "load-balance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('ethernet', (YLeaf(YType.enumeration, 'ethernet'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'PseudowireClass.LoadBalance.Flow.Ethernet')])),
                    ])
                    self.ethernet = None
                    self._segment_path = lambda: "flow"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.LoadBalance.Flow, ['ethernet'], name, value)

                class Ethernet(Enum):
                    """
                    Ethernet (Enum Class)

                    Ethernet pseudowire flow classification

                    .. data:: dst_mac = 0

                    .. data:: src_dst_mac = 1

                    .. data:: src_mac = 2

                    """

                    dst_mac = Enum.YLeaf(0, "dst-mac")

                    src_dst_mac = Enum.YLeaf(1, "src-dst-mac")

                    src_mac = Enum.YLeaf(2, "src-mac")



        class Monitor(Entity):
            """
            Active monitoring of xconnect peer
            
            .. attribute:: peer
            
            	Active monitoring of xconnect peer
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Monitor.Peer>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.PseudowireClass.Monitor, self).__init__()

                self.yang_name = "monitor"
                self.yang_parent_name = "pseudowire-class"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("peer", ("peer", Native.PseudowireClass.Monitor.Peer))])
                self._leafs = OrderedDict()

                self.peer = Native.PseudowireClass.Monitor.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:monitor"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PseudowireClass.Monitor, [], name, value)


            class Peer(Entity):
                """
                Active monitoring of xconnect peer
                
                .. attribute:: bfd
                
                	BFD active monitoring for the xconnect peer
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Monitor.Peer.Bfd>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.Monitor.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bfd", ("bfd", Native.PseudowireClass.Monitor.Peer.Bfd))])
                    self._leafs = OrderedDict()

                    self.bfd = None
                    self._children_name_map["bfd"] = "bfd"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.Monitor.Peer, [], name, value)


                class Bfd(Entity):
                    """
                    BFD active monitoring for the xconnect peer
                    
                    .. attribute:: local
                    
                    	Specify local endpoint information to map to a BFD session
                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Monitor.Peer.Bfd.Local>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.PseudowireClass.Monitor.Peer.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("local", ("local", Native.PseudowireClass.Monitor.Peer.Bfd.Local))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.local = Native.PseudowireClass.Monitor.Peer.Bfd.Local()
                        self.local.parent = self
                        self._children_name_map["local"] = "local"
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PseudowireClass.Monitor.Peer.Bfd, [], name, value)


                    class Local(Entity):
                        """
                        Specify local endpoint information to map to a BFD session
                        
                        .. attribute:: interface
                        
                        	Source interface for pseudowire
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.PseudowireClass.Monitor.Peer.Bfd.Local, self).__init__()

                            self.yang_name = "local"
                            self.yang_parent_name = "bfd"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface))])
                            self._leafs = OrderedDict()

                            self.interface = Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._segment_path = lambda: "local"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PseudowireClass.Monitor.Peer.Bfd.Local, [], name, value)


                        class Interface(Entity):
                            """
                            Source interface for pseudowire
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.PseudowireClass.Monitor.Peer.Bfd.Local.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


        class PreferredPath(Entity):
            """
            Preferred path
            
            .. attribute:: interface
            
            	Output Interface
            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.PreferredPath.Interface>`
            
            .. attribute:: peer_container
            
            	
            	**type**\:  :py:class:`PeerContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.PreferredPath.PeerContainer>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.PseudowireClass.PreferredPath, self).__init__()

                self.yang_name = "preferred-path"
                self.yang_parent_name = "pseudowire-class"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("interface", ("interface", Native.PseudowireClass.PreferredPath.Interface)), ("peer-container", ("peer_container", Native.PseudowireClass.PreferredPath.PeerContainer))])
                self._leafs = OrderedDict()

                self.interface = Native.PseudowireClass.PreferredPath.Interface()
                self.interface.parent = self
                self._children_name_map["interface"] = "interface"

                self.peer_container = Native.PseudowireClass.PreferredPath.PeerContainer()
                self.peer_container.parent = self
                self._children_name_map["peer_container"] = "peer-container"
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:preferred-path"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PseudowireClass.PreferredPath, [], name, value)


            class Interface(Entity):
                """
                Output Interface
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..2147483647
                
                .. attribute:: tunnel_tp
                
                	MPLS Transport Profile interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: disable_fallback
                
                	disable fall back to alternative route
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.PreferredPath.Interface, self).__init__()

                    self.yang_name = "interface"
                    self.yang_parent_name = "preferred-path"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('tunnel', (YLeaf(YType.uint64, 'Tunnel'), ['int'])),
                        ('tunnel_tp', (YLeaf(YType.uint16, 'Tunnel-tp'), ['int'])),
                        ('disable_fallback', (YLeaf(YType.empty, 'disable-fallback'), ['Empty'])),
                    ])
                    self.tunnel = None
                    self.tunnel_tp = None
                    self.disable_fallback = None
                    self._segment_path = lambda: "interface"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.PreferredPath.Interface, ['tunnel', 'tunnel_tp', 'disable_fallback'], name, value)


            class PeerContainer(Entity):
                """
                
                
                .. attribute:: peer
                
                	Peer Address
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: disable_fallback
                
                	disable fall back to alternative route
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.PreferredPath.PeerContainer, self).__init__()

                    self.yang_name = "peer-container"
                    self.yang_parent_name = "preferred-path"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('peer', (YLeaf(YType.str, 'peer'), ['str','str'])),
                        ('disable_fallback', (YLeaf(YType.empty, 'disable-fallback'), ['Empty'])),
                    ])
                    self.peer = None
                    self.disable_fallback = None
                    self._segment_path = lambda: "peer-container"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.PreferredPath.PeerContainer, ['peer', 'disable_fallback'], name, value)


        class ProtocolMpls(Entity):
            """
            
            
            .. attribute:: protocol
            
            	Signaling protocol to use
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.ProtocolMpls.Protocol>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.PseudowireClass.ProtocolMpls, self).__init__()

                self.yang_name = "protocol-mpls"
                self.yang_parent_name = "pseudowire-class"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'PseudowireClass.ProtocolMpls.Protocol')])),
                ])
                self.protocol = None
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:protocol-mpls"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PseudowireClass.ProtocolMpls, ['protocol'], name, value)

            class Protocol(Enum):
                """
                Protocol (Enum Class)

                Signaling protocol to use

                .. data:: ldp = 0

                .. data:: none = 1

                """

                ldp = Enum.YLeaf(0, "ldp")

                none = Enum.YLeaf(1, "none")



        class ProtocolL2tpv2(Entity):
            """
            
            
            .. attribute:: protocol
            
            	Signaling protocol to use
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.ProtocolL2tpv2.Protocol>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.PseudowireClass.ProtocolL2tpv2, self).__init__()

                self.yang_name = "protocol-l2tpv2"
                self.yang_parent_name = "pseudowire-class"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'PseudowireClass.ProtocolL2tpv2.Protocol')])),
                ])
                self.protocol = None
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:protocol-l2tpv2"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PseudowireClass.ProtocolL2tpv2, ['protocol'], name, value)

            class Protocol(Enum):
                """
                Protocol (Enum Class)

                Signaling protocol to use

                .. data:: l2tpv2 = 0

                .. data:: none = 1

                """

                l2tpv2 = Enum.YLeaf(0, "l2tpv2")

                none = Enum.YLeaf(1, "none")



        class ProtocolL2tpv3(Entity):
            """
            
            
            .. attribute:: protocol
            
            	Signaling protocol to use
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.ProtocolL2tpv3.Protocol>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.PseudowireClass.ProtocolL2tpv3, self).__init__()

                self.yang_name = "protocol-l2tpv3"
                self.yang_parent_name = "pseudowire-class"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'PseudowireClass.ProtocolL2tpv3.Protocol')])),
                ])
                self.protocol = None
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:protocol-l2tpv3"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PseudowireClass.ProtocolL2tpv3, ['protocol'], name, value)

            class Protocol(Enum):
                """
                Protocol (Enum Class)

                Signaling protocol to use

                .. data:: l2tpv3 = 0

                .. data:: l2tpv3ietf = 1

                .. data:: none = 2

                """

                l2tpv3 = Enum.YLeaf(0, "l2tpv3")

                l2tpv3ietf = Enum.YLeaf(1, "l2tpv3ietf")

                none = Enum.YLeaf(2, "none")



        class Status(Entity):
            """
            Pseudowire status capabilities
            
            .. attribute:: admin_down
            
            	Admin down of Attachment Circuit
            	**type**\:  :py:class:`AdminDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Status.AdminDown>`
            
            .. attribute:: control_plane
            
            	control plane status events
            	**type**\:  :py:class:`ControlPlane <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Status.ControlPlane>`
            
            .. attribute:: decoupled
            
            	Reflect standby status of the attachment circuit as up on the pseudowire
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: peer
            
            	peer status configuration
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Status.Peer>`
            
            .. attribute:: redundancy
            
            	Xconnect redundancy configuration
            	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Status.Redundancy>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.PseudowireClass.Status, self).__init__()

                self.yang_name = "status"
                self.yang_parent_name = "pseudowire-class"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("admin-down", ("admin_down", Native.PseudowireClass.Status.AdminDown)), ("control-plane", ("control_plane", Native.PseudowireClass.Status.ControlPlane)), ("peer", ("peer", Native.PseudowireClass.Status.Peer)), ("redundancy", ("redundancy", Native.PseudowireClass.Status.Redundancy))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('decoupled', (YLeaf(YType.empty, 'decoupled'), ['Empty'])),
                ])
                self.decoupled = None

                self.admin_down = Native.PseudowireClass.Status.AdminDown()
                self.admin_down.parent = self
                self._children_name_map["admin_down"] = "admin-down"

                self.control_plane = Native.PseudowireClass.Status.ControlPlane()
                self.control_plane.parent = self
                self._children_name_map["control_plane"] = "control-plane"

                self.peer = Native.PseudowireClass.Status.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.redundancy = Native.PseudowireClass.Status.Redundancy()
                self.redundancy.parent = self
                self._children_name_map["redundancy"] = "redundancy"
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:status"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PseudowireClass.Status, ['decoupled'], name, value)


            class AdminDown(Entity):
                """
                Admin down of Attachment Circuit
                
                .. attribute:: disconnect
                
                	Disconnect the session
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.Status.AdminDown, self).__init__()

                    self.yang_name = "admin-down"
                    self.yang_parent_name = "status"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('disconnect', (YLeaf(YType.empty, 'disconnect'), ['Empty'])),
                    ])
                    self.disconnect = None
                    self._segment_path = lambda: "admin-down"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.Status.AdminDown, ['disconnect'], name, value)


            class ControlPlane(Entity):
                """
                control plane status events
                
                .. attribute:: route_watch
                
                	listen on the control plane to route\-watch events
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.Status.ControlPlane, self).__init__()

                    self.yang_name = "control-plane"
                    self.yang_parent_name = "status"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('route_watch', (YLeaf(YType.empty, 'route-watch'), ['Empty'])),
                    ])
                    self.route_watch = None
                    self._segment_path = lambda: "control-plane"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.Status.ControlPlane, ['route_watch'], name, value)


            class Peer(Entity):
                """
                peer status configuration
                
                .. attribute:: topology
                
                	change status behaviour based on peer topology
                	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PseudowireClass.Status.Peer.Topology>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.Status.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "status"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology", ("topology", Native.PseudowireClass.Status.Peer.Topology))])
                    self._leafs = OrderedDict()

                    self.topology = Native.PseudowireClass.Status.Peer.Topology()
                    self.topology.parent = self
                    self._children_name_map["topology"] = "topology"
                    self._segment_path = lambda: "peer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.Status.Peer, [], name, value)


                class Topology(Entity):
                    """
                    change status behaviour based on peer topology
                    
                    .. attribute:: dual_homed
                    
                    	Our peer(s) are participating in a redundant solution with some form of redundancyprotocol running between the peer routers, Only one of the remote peers will advertise astatus of UP at a time. The other will advertise standby. Change our configuration so wecan send a status of UP on both active and redundant pseudowires
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.PseudowireClass.Status.Peer.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dual_homed', (YLeaf(YType.empty, 'dual-homed'), ['Empty'])),
                        ])
                        self.dual_homed = None
                        self._segment_path = lambda: "topology"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PseudowireClass.Status.Peer.Topology, ['dual_homed'], name, value)


            class Redundancy(Entity):
                """
                Xconnect redundancy configuration
                
                .. attribute:: master
                
                	Put the xconnect redundancy group on this node in master mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.PseudowireClass.Status.Redundancy, self).__init__()

                    self.yang_name = "redundancy"
                    self.yang_parent_name = "status"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('master', (YLeaf(YType.empty, 'master'), ['Empty'])),
                    ])
                    self.master = None
                    self._segment_path = lambda: "redundancy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PseudowireClass.Status.Redundancy, ['master'], name, value)


        class Switching(Entity):
            """
            Switching TLV on/off for pseudowire
            
            .. attribute:: tlv
            
            	Switching TLV on/off for pseudowire
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.PseudowireClass.Switching, self).__init__()

                self.yang_name = "switching"
                self.yang_parent_name = "pseudowire-class"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('tlv', (YLeaf(YType.empty, 'tlv'), ['Empty'])),
                ])
                self.tlv = None
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:switching"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PseudowireClass.Switching, ['tlv'], name, value)


    class ControlPlane(Entity):
        """
        Configure control plane services
        
        .. attribute:: service_policy
        
        	
        	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ControlPlane.ServicePolicy>`
        
        

        This class is a :ref:`presence class<presence-class>`

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.ControlPlane, self).__init__()

            self.yang_name = "control-plane"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-policy:service-policy", ("service_policy", Native.ControlPlane.ServicePolicy))])
            self.is_presence_container = True
            self._leafs = OrderedDict()

            self.service_policy = Native.ControlPlane.ServicePolicy()
            self.service_policy.parent = self
            self._children_name_map["service_policy"] = "Cisco-IOS-XE-policy:service-policy"
            self._segment_path = lambda: "control-plane"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.ControlPlane, [], name, value)


        class ServicePolicy(Entity):
            """
            
            
            .. attribute:: input
            
            	Assign policy\-map to the input of an interface
            	**type**\: str
            
            .. attribute:: output
            
            	Assign policy\-map to the output of an interface
            	**type**\: str
            
            

            """

            _prefix = 'ios-policy'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.ControlPlane.ServicePolicy, self).__init__()

                self.yang_name = "service-policy"
                self.yang_parent_name = "control-plane"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('input', (YLeaf(YType.str, 'input'), ['str'])),
                    ('output', (YLeaf(YType.str, 'output'), ['str'])),
                ])
                self.input = None
                self.output = None
                self._segment_path = lambda: "Cisco-IOS-XE-policy:service-policy"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/control-plane/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ControlPlane.ServicePolicy, ['input', 'output'], name, value)


    class ControlPlaneHost(Entity):
        """
        
        
        .. attribute:: control_plane
        
        	Configure control plane services
        	**type**\:  :py:class:`ControlPlane <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ControlPlaneHost.ControlPlane>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.ControlPlaneHost, self).__init__()

            self.yang_name = "control-plane-host"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("control-plane", ("control_plane", Native.ControlPlaneHost.ControlPlane))])
            self._leafs = OrderedDict()

            self.control_plane = Native.ControlPlaneHost.ControlPlane()
            self.control_plane.parent = self
            self._children_name_map["control_plane"] = "control-plane"
            self._segment_path = lambda: "control-plane-host"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.ControlPlaneHost, [], name, value)


        class ControlPlane(Entity):
            """
            Configure control plane services
            
            .. attribute:: host
            
            	
            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ControlPlaneHost.ControlPlane.Host>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.ControlPlaneHost.ControlPlane, self).__init__()

                self.yang_name = "control-plane"
                self.yang_parent_name = "control-plane-host"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("host", ("host", Native.ControlPlaneHost.ControlPlane.Host))])
                self._leafs = OrderedDict()

                self.host = None
                self._children_name_map["host"] = "host"
                self._segment_path = lambda: "control-plane"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/control-plane-host/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ControlPlaneHost.ControlPlane, [], name, value)


            class Host(Entity):
                """
                
                
                .. attribute:: management_interface
                
                	Configure interface for receiving network management traffic
                	**type**\: list of  		 :py:class:`ManagementInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ControlPlaneHost.ControlPlane.Host.ManagementInterface>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.ControlPlaneHost.ControlPlane.Host, self).__init__()

                    self.yang_name = "host"
                    self.yang_parent_name = "control-plane"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("management-interface", ("management_interface", Native.ControlPlaneHost.ControlPlane.Host.ManagementInterface))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.management_interface = YList(self)
                    self._segment_path = lambda: "host"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/control-plane-host/control-plane/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ControlPlaneHost.ControlPlane.Host, [], name, value)


                class ManagementInterface(Entity):
                    """
                    Configure interface for receiving network management traffic
                    
                    .. attribute:: interface_name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: allow
                    
                    	Allowed network management protocols on selected interface
                    	**type**\:  :py:class:`Allow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ControlPlaneHost.ControlPlane.Host.ManagementInterface.Allow>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.ControlPlaneHost.ControlPlane.Host.ManagementInterface, self).__init__()

                        self.yang_name = "management-interface"
                        self.yang_parent_name = "host"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("allow", ("allow", Native.ControlPlaneHost.ControlPlane.Host.ManagementInterface.Allow))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None

                        self.allow = Native.ControlPlaneHost.ControlPlane.Host.ManagementInterface.Allow()
                        self.allow.parent = self
                        self._children_name_map["allow"] = "allow"
                        self._segment_path = lambda: "management-interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/control-plane-host/control-plane/host/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ControlPlaneHost.ControlPlane.Host.ManagementInterface, [u'interface_name'], name, value)


                    class Allow(Entity):
                        """
                        Allowed network management protocols on selected interface
                        
                        .. attribute:: beep
                        
                        	Beep Protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ftp
                        
                        	File Transfer Protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: http
                        
                        	HTTP Protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: https
                        
                        	HTTPS Protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: snmp
                        
                        	Simple Network Management Protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ssh
                        
                        	Secure Shell Protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: telnet
                        
                        	Telnet Protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tftp
                        
                        	Trivial File Transfer Protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tl1
                        
                        	Transaction Language Session Protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.ControlPlaneHost.ControlPlane.Host.ManagementInterface.Allow, self).__init__()

                            self.yang_name = "allow"
                            self.yang_parent_name = "management-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('beep', (YLeaf(YType.empty, 'beep'), ['Empty'])),
                                ('ftp', (YLeaf(YType.empty, 'ftp'), ['Empty'])),
                                ('http', (YLeaf(YType.empty, 'http'), ['Empty'])),
                                ('https', (YLeaf(YType.empty, 'https'), ['Empty'])),
                                ('snmp', (YLeaf(YType.empty, 'snmp'), ['Empty'])),
                                ('ssh', (YLeaf(YType.empty, 'ssh'), ['Empty'])),
                                ('telnet', (YLeaf(YType.empty, 'telnet'), ['Empty'])),
                                ('tftp', (YLeaf(YType.empty, 'tftp'), ['Empty'])),
                                ('tl1', (YLeaf(YType.empty, 'tl1'), ['Empty'])),
                            ])
                            self.beep = None
                            self.ftp = None
                            self.http = None
                            self.https = None
                            self.snmp = None
                            self.ssh = None
                            self.telnet = None
                            self.tftp = None
                            self.tl1 = None
                            self._segment_path = lambda: "allow"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ControlPlaneHost.ControlPlane.Host.ManagementInterface.Allow, [u'beep', u'ftp', u'http', u'https', u'snmp', u'ssh', u'telnet', u'tftp', u'tl1'], name, value)


    class Clock(Entity):
        """
        Configure time\-of\-day clock
        
        .. attribute:: calendar_valid
        
        	Calendar time is authoritative
        	**type**\:  :py:class:`CalendarValid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Clock.CalendarValid>`
        
        	**presence node**\: True
        
        .. attribute:: summer_time
        
        	Configure summer (daylight savings) time
        	**type**\:  :py:class:`SummerTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Clock.SummerTime>`
        
        .. attribute:: timezone
        
        	Configure time zone
        	**type**\:  :py:class:`Timezone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Clock.Timezone>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Clock, self).__init__()

            self.yang_name = "clock"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("calendar-valid", ("calendar_valid", Native.Clock.CalendarValid)), ("summer-time", ("summer_time", Native.Clock.SummerTime)), ("timezone", ("timezone", Native.Clock.Timezone))])
            self._leafs = OrderedDict()

            self.calendar_valid = None
            self._children_name_map["calendar_valid"] = "calendar-valid"

            self.summer_time = Native.Clock.SummerTime()
            self.summer_time.parent = self
            self._children_name_map["summer_time"] = "summer-time"

            self.timezone = Native.Clock.Timezone()
            self.timezone.parent = self
            self._children_name_map["timezone"] = "timezone"
            self._segment_path = lambda: "clock"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Clock, [], name, value)


        class CalendarValid(Entity):
            """
            Calendar time is authoritative
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Clock.CalendarValid, self).__init__()

                self.yang_name = "calendar-valid"
                self.yang_parent_name = "clock"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict()
                self._segment_path = lambda: "calendar-valid"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/clock/%s" % self._segment_path()
                self._is_frozen = True


        class SummerTime(Entity):
            """
            Configure summer (daylight savings) time
            
            .. attribute:: zone
            
            	
            	**type**\: str
            
            .. attribute:: date
            
            	Configure absolute summer time
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: start_day
            
            	
            	**type**\: int
            
            	**range:** 1..31
            
            .. attribute:: start_month
            
            	
            	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
            
            .. attribute:: start_year
            
            	
            	**type**\: int
            
            	**range:** 1993..2035
            
            .. attribute:: start_time
            
            	
            	**type**\: str
            
            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
            
            .. attribute:: date_end_day
            
            	
            	**type**\: int
            
            	**range:** 1..31
            
            .. attribute:: date_end_month
            
            	
            	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
            
            .. attribute:: date_end_year
            
            	
            	**type**\: int
            
            	**range:** 1993..2035
            
            .. attribute:: date_end_time
            
            	
            	**type**\: str
            
            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
            
            .. attribute:: offset
            
            	
            	**type**\: int
            
            	**range:** 1..1440
            
            .. attribute:: recurring
            
            	Configure recurring summer time
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: recurring_start
            
            	
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 1..4
            
            		**type**\:  :py:class:`RecurringStart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Clock.SummerTime.RecurringStart>`
            
            .. attribute:: recurring_start_day
            
            	
            	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
            
            .. attribute:: recurring_start_month
            
            	
            	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
            
            .. attribute:: recurring_start_time
            
            	
            	**type**\: str
            
            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
            
            .. attribute:: recurring_end
            
            	
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 1..4
            
            		**type**\:  :py:class:`RecurringEnd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Clock.SummerTime.RecurringEnd>`
            
            .. attribute:: recurring_end_day
            
            	
            	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
            
            .. attribute:: recurring_end_month
            
            	
            	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
            
            .. attribute:: recurring_end_time
            
            	
            	**type**\: str
            
            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
            
            .. attribute:: recurring_offset
            
            	
            	**type**\: int
            
            	**range:** 1..1440
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Clock.SummerTime, self).__init__()

                self.yang_name = "summer-time"
                self.yang_parent_name = "clock"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('zone', (YLeaf(YType.str, 'zone'), ['str'])),
                    ('date', (YLeaf(YType.empty, 'date'), ['Empty'])),
                    ('start_day', (YLeaf(YType.uint8, 'start-day'), ['int'])),
                    ('start_month', (YLeaf(YType.enumeration, 'start-month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                    ('start_year', (YLeaf(YType.uint32, 'start-year'), ['int'])),
                    ('start_time', (YLeaf(YType.str, 'start-time'), ['str'])),
                    ('date_end_day', (YLeaf(YType.uint8, 'date-end-day'), ['int'])),
                    ('date_end_month', (YLeaf(YType.enumeration, 'date-end-month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                    ('date_end_year', (YLeaf(YType.uint32, 'date-end-year'), ['int'])),
                    ('date_end_time', (YLeaf(YType.str, 'date-end-time'), ['str'])),
                    ('offset', (YLeaf(YType.uint16, 'offset'), ['int'])),
                    ('recurring', (YLeaf(YType.empty, 'recurring'), ['Empty'])),
                    ('recurring_start', (YLeaf(YType.str, 'recurring-start'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Clock.SummerTime.RecurringStart')])),
                    ('recurring_start_day', (YLeaf(YType.enumeration, 'recurring-start-day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                    ('recurring_start_month', (YLeaf(YType.enumeration, 'recurring-start-month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                    ('recurring_start_time', (YLeaf(YType.str, 'recurring-start-time'), ['str'])),
                    ('recurring_end', (YLeaf(YType.str, 'recurring-end'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Clock.SummerTime.RecurringEnd')])),
                    ('recurring_end_day', (YLeaf(YType.enumeration, 'recurring-end-day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                    ('recurring_end_month', (YLeaf(YType.enumeration, 'recurring-end-month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                    ('recurring_end_time', (YLeaf(YType.str, 'recurring-end-time'), ['str'])),
                    ('recurring_offset', (YLeaf(YType.uint16, 'recurring-offset'), ['int'])),
                ])
                self.zone = None
                self.date = None
                self.start_day = None
                self.start_month = None
                self.start_year = None
                self.start_time = None
                self.date_end_day = None
                self.date_end_month = None
                self.date_end_year = None
                self.date_end_time = None
                self.offset = None
                self.recurring = None
                self.recurring_start = None
                self.recurring_start_day = None
                self.recurring_start_month = None
                self.recurring_start_time = None
                self.recurring_end = None
                self.recurring_end_day = None
                self.recurring_end_month = None
                self.recurring_end_time = None
                self.recurring_offset = None
                self._segment_path = lambda: "summer-time"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/clock/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Clock.SummerTime, [u'zone', u'date', u'start_day', u'start_month', u'start_year', u'start_time', u'date_end_day', u'date_end_month', u'date_end_year', u'date_end_time', u'offset', u'recurring', u'recurring_start', u'recurring_start_day', u'recurring_start_month', u'recurring_start_time', u'recurring_end', u'recurring_end_day', u'recurring_end_month', u'recurring_end_time', u'recurring_offset'], name, value)

            class RecurringEnd(Enum):
                """
                RecurringEnd (Enum Class)

                .. data:: first = 0

                .. data:: last = 1

                """

                first = Enum.YLeaf(0, "first")

                last = Enum.YLeaf(1, "last")


            class RecurringStart(Enum):
                """
                RecurringStart (Enum Class)

                .. data:: first = 0

                .. data:: last = 1

                """

                first = Enum.YLeaf(0, "first")

                last = Enum.YLeaf(1, "last")



        class Timezone(Entity):
            """
            Configure time zone
            
            .. attribute:: zone
            
            	
            	**type**\: str
            
            .. attribute:: offset
            
            	
            	**type**\:  :py:class:`Offset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Clock.Timezone.Offset>`
            
            .. attribute:: hours
            
            	
            	**type**\: int
            
            	**range:** \-23..23
            
            .. attribute:: minutes
            
            	
            	**type**\: int
            
            	**range:** 0..59
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Clock.Timezone, self).__init__()

                self.yang_name = "timezone"
                self.yang_parent_name = "clock"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('zone', (YLeaf(YType.str, 'zone'), ['str'])),
                    ('offset', (YLeaf(YType.enumeration, 'offset'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Clock.Timezone.Offset')])),
                    ('hours', (YLeaf(YType.int8, 'hours'), ['int'])),
                    ('minutes', (YLeaf(YType.int8, 'minutes'), ['int'])),
                ])
                self.zone = None
                self.offset = None
                self.hours = None
                self.minutes = None
                self._segment_path = lambda: "timezone"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/clock/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Clock.Timezone, [u'zone', u'offset', u'hours', u'minutes'], name, value)

            class Offset(Enum):
                """
                Offset (Enum Class)

                .. data:: Y__PLUS__ = 0

                .. data:: Y_ = 1

                """

                Y__PLUS__ = Enum.YLeaf(0, "+")

                Y_ = Enum.YLeaf(1, "-")



    class Logging(Entity):
        """
        Modify message logging facilities
        
        .. attribute:: discriminator
        
        	Create or modify a message discriminator
        	**type**\: list of  		 :py:class:`Discriminator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Discriminator>`
        
        .. attribute:: persistent
        
        	Set persistent logging parameters
        	**type**\:  :py:class:`Persistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Persistent>`
        
        	**presence node**\: True
        
        .. attribute:: monitor_conf
        
        	
        	**type**\:  :py:class:`MonitorConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.MonitorConf>`
        
        .. attribute:: monitor
        
        	Set terminal line (monitor) logging parameters
        	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Monitor>`
        
        	**presence node**\: True
        
        .. attribute:: alarm
        
        	Configure syslog for alarms
        	**type**\: union of the below types:
        
        		**type**\: int
        
        			**range:** 1..4
        
        		**type**\:  :py:class:`Alarm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Alarm>`
        
        .. attribute:: buffered
        
        	Set buffered logging parameters
        	**type**\:  :py:class:`Buffered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Buffered>`
        
        	**presence node**\: True
        
        .. attribute:: console_conf
        
        	
        	**type**\:  :py:class:`ConsoleConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.ConsoleConf>`
        
        .. attribute:: console
        
        	Set console logging parameters
        	**type**\:  :py:class:`Console <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Console>`
        
        	**presence node**\: True
        
        .. attribute:: event
        
        	Global interface events
        	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Event>`
        
        .. attribute:: esm
        
        	Set ESM filter restrictions
        	**type**\:  :py:class:`Esm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Esm>`
        
        .. attribute:: facility
        
        	Facility parameter for syslog messages
        	**type**\:  :py:class:`Facility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Facility>`
        
        .. attribute:: history
        
        	Configure syslog history table
        	**type**\:  :py:class:`History <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.History>`
        
        .. attribute:: host
        
        	Set syslog server IP address and parameters
        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host>`
        
        .. attribute:: origin_id
        
        	Add origin ID to syslog messages
        	**type**\:  :py:class:`OriginId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.OriginId>`
        
        .. attribute:: rate_limit_conf
        
        	
        	**type**\:  :py:class:`RateLimitConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimitConf>`
        
        .. attribute:: rate_limit
        
        	Set messages per second limit
        	**type**\:  :py:class:`RateLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit>`
        
        	**presence node**\: True
        
        .. attribute:: source_interface
        
        	Specify interface for source address in logging transactions
        	**type**\: list of  		 :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.SourceInterface>`
        
        .. attribute:: snmp_trap
        
        	Set SNMP trap logging level
        	**type**\:  :py:class:`SnmpTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.SnmpTrap>`
        
        .. attribute:: trap
        
        	Set trap server logging level
        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Trap>`
        
        	**presence node**\: True
        
        .. attribute:: hostip
        
        	
        	**type**\: union of the below types:
        
        		**type**\: str
        
        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
        
        		**type**\: str
        
        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
        
        		**type**\: str
        
        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
        
        .. attribute:: file
        
        	Set logging file parameters
        	**type**\:  :py:class:`File <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.File>`
        
        .. attribute:: snmp_authfail
        
        	
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: buginf
        
        	Enable buginf logging for debugging
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: userinfo
        
        	Enable logging of user info on privileged mode enabling
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Logging, self).__init__()

            self.yang_name = "logging"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("discriminator", ("discriminator", Native.Logging.Discriminator)), ("persistent", ("persistent", Native.Logging.Persistent)), ("monitor-conf", ("monitor_conf", Native.Logging.MonitorConf)), ("monitor", ("monitor", Native.Logging.Monitor)), ("buffered", ("buffered", Native.Logging.Buffered)), ("console-conf", ("console_conf", Native.Logging.ConsoleConf)), ("console", ("console", Native.Logging.Console)), ("event", ("event", Native.Logging.Event)), ("esm", ("esm", Native.Logging.Esm)), ("history", ("history", Native.Logging.History)), ("host", ("host", Native.Logging.Host)), ("origin-id", ("origin_id", Native.Logging.OriginId)), ("rate-limit-conf", ("rate_limit_conf", Native.Logging.RateLimitConf)), ("rate-limit", ("rate_limit", Native.Logging.RateLimit)), ("source-interface", ("source_interface", Native.Logging.SourceInterface)), ("snmp-trap", ("snmp_trap", Native.Logging.SnmpTrap)), ("trap", ("trap", Native.Logging.Trap)), ("file", ("file", Native.Logging.File))])
            self._leafs = OrderedDict([
                ('alarm', (YLeaf(YType.str, 'alarm'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Logging.Alarm')])),
                ('facility', (YLeaf(YType.enumeration, 'facility'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Logging.Facility')])),
                ('hostip', (YLeaf(YType.str, 'hostip'), ['str','str','str'])),
                ('snmp_authfail', (YLeaf(YType.empty, 'snmp-authfail'), ['Empty'])),
                ('buginf', (YLeaf(YType.empty, 'buginf'), ['Empty'])),
                ('userinfo', (YLeaf(YType.empty, 'userinfo'), ['Empty'])),
            ])
            self.alarm = None
            self.facility = None
            self.hostip = None
            self.snmp_authfail = None
            self.buginf = None
            self.userinfo = None

            self.persistent = None
            self._children_name_map["persistent"] = "persistent"

            self.monitor_conf = Native.Logging.MonitorConf()
            self.monitor_conf.parent = self
            self._children_name_map["monitor_conf"] = "monitor-conf"

            self.monitor = None
            self._children_name_map["monitor"] = "monitor"

            self.buffered = None
            self._children_name_map["buffered"] = "buffered"

            self.console_conf = Native.Logging.ConsoleConf()
            self.console_conf.parent = self
            self._children_name_map["console_conf"] = "console-conf"

            self.console = None
            self._children_name_map["console"] = "console"

            self.event = Native.Logging.Event()
            self.event.parent = self
            self._children_name_map["event"] = "event"

            self.esm = Native.Logging.Esm()
            self.esm.parent = self
            self._children_name_map["esm"] = "esm"

            self.history = Native.Logging.History()
            self.history.parent = self
            self._children_name_map["history"] = "history"

            self.host = Native.Logging.Host()
            self.host.parent = self
            self._children_name_map["host"] = "host"

            self.origin_id = Native.Logging.OriginId()
            self.origin_id.parent = self
            self._children_name_map["origin_id"] = "origin-id"

            self.rate_limit_conf = Native.Logging.RateLimitConf()
            self.rate_limit_conf.parent = self
            self._children_name_map["rate_limit_conf"] = "rate-limit-conf"

            self.rate_limit = None
            self._children_name_map["rate_limit"] = "rate-limit"

            self.snmp_trap = Native.Logging.SnmpTrap()
            self.snmp_trap.parent = self
            self._children_name_map["snmp_trap"] = "snmp-trap"

            self.trap = None
            self._children_name_map["trap"] = "trap"

            self.file = Native.Logging.File()
            self.file.parent = self
            self._children_name_map["file"] = "file"

            self.discriminator = YList(self)
            self.source_interface = YList(self)
            self._segment_path = lambda: "logging"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Logging, [u'alarm', u'facility', u'hostip', u'snmp_authfail', u'buginf', u'userinfo'], name, value)

        class Alarm(Enum):
            """
            Alarm (Enum Class)

            Configure syslog for alarms

            .. data:: critical = 0

            .. data:: informational = 1

            .. data:: major = 2

            .. data:: minor = 3

            """

            critical = Enum.YLeaf(0, "critical")

            informational = Enum.YLeaf(1, "informational")

            major = Enum.YLeaf(2, "major")

            minor = Enum.YLeaf(3, "minor")


        class Facility(Enum):
            """
            Facility (Enum Class)

            Facility parameter for syslog messages

            .. data:: auth = 0

            .. data:: cron = 1

            .. data:: daemon = 2

            .. data:: kern = 3

            .. data:: local0 = 4

            .. data:: local1 = 5

            .. data:: local2 = 6

            .. data:: local3 = 7

            .. data:: local4 = 8

            .. data:: local5 = 9

            .. data:: local6 = 10

            .. data:: local7 = 11

            .. data:: lpr = 12

            .. data:: mail = 13

            .. data:: news = 14

            .. data:: sys10 = 15

            .. data:: sys11 = 16

            .. data:: sys12 = 17

            .. data:: sys13 = 18

            .. data:: sys14 = 19

            .. data:: sys9 = 20

            .. data:: syslog = 21

            .. data:: user = 22

            .. data:: uucp = 23

            """

            auth = Enum.YLeaf(0, "auth")

            cron = Enum.YLeaf(1, "cron")

            daemon = Enum.YLeaf(2, "daemon")

            kern = Enum.YLeaf(3, "kern")

            local0 = Enum.YLeaf(4, "local0")

            local1 = Enum.YLeaf(5, "local1")

            local2 = Enum.YLeaf(6, "local2")

            local3 = Enum.YLeaf(7, "local3")

            local4 = Enum.YLeaf(8, "local4")

            local5 = Enum.YLeaf(9, "local5")

            local6 = Enum.YLeaf(10, "local6")

            local7 = Enum.YLeaf(11, "local7")

            lpr = Enum.YLeaf(12, "lpr")

            mail = Enum.YLeaf(13, "mail")

            news = Enum.YLeaf(14, "news")

            sys10 = Enum.YLeaf(15, "sys10")

            sys11 = Enum.YLeaf(16, "sys11")

            sys12 = Enum.YLeaf(17, "sys12")

            sys13 = Enum.YLeaf(18, "sys13")

            sys14 = Enum.YLeaf(19, "sys14")

            sys9 = Enum.YLeaf(20, "sys9")

            syslog = Enum.YLeaf(21, "syslog")

            user = Enum.YLeaf(22, "user")

            uucp = Enum.YLeaf(23, "uucp")



        class Discriminator(Entity):
            """
            Create or modify a message discriminator
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: severity
            
            	Msg\-body pattern for messsage filtering
            	**type**\:  :py:class:`Severity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Discriminator.Severity>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.Discriminator, self).__init__()

                self.yang_name = "discriminator"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("severity", ("severity", Native.Logging.Discriminator.Severity))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.severity = Native.Logging.Discriminator.Severity()
                self.severity.parent = self
                self._children_name_map["severity"] = "severity"
                self._segment_path = lambda: "discriminator" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.Discriminator, [u'name'], name, value)


            class Severity(Entity):
                """
                Msg\-body pattern for messsage filtering
                
                .. attribute:: drops
                
                	To drop messages including the specified regular expression string
                	**type**\: str
                
                .. attribute:: includes
                
                	To deliver messages including the specified regular expression string
                	**type**\: str
                
                .. attribute:: facility
                
                	Msg\-body pattern for messsage filtering
                	**type**\:  :py:class:`Facility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Discriminator.Severity.Facility>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.Discriminator.Severity, self).__init__()

                    self.yang_name = "severity"
                    self.yang_parent_name = "discriminator"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("facility", ("facility", Native.Logging.Discriminator.Severity.Facility))])
                    self._leafs = OrderedDict([
                        ('drops', (YLeaf(YType.str, 'drops'), ['str'])),
                        ('includes', (YLeaf(YType.str, 'includes'), ['str'])),
                    ])
                    self.drops = None
                    self.includes = None

                    self.facility = Native.Logging.Discriminator.Severity.Facility()
                    self.facility.parent = self
                    self._children_name_map["facility"] = "facility"
                    self._segment_path = lambda: "severity"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.Discriminator.Severity, [u'drops', u'includes'], name, value)


                class Facility(Entity):
                    """
                    Msg\-body pattern for messsage filtering
                    
                    .. attribute:: drops
                    
                    	To drop messages including the specified regular expression string
                    	**type**\: str
                    
                    .. attribute:: includes
                    
                    	To deliver messages including the specified regular expression string
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Logging.Discriminator.Severity.Facility, self).__init__()

                        self.yang_name = "facility"
                        self.yang_parent_name = "severity"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('drops', (YLeaf(YType.str, 'drops'), ['str'])),
                            ('includes', (YLeaf(YType.str, 'includes'), ['str'])),
                        ])
                        self.drops = None
                        self.includes = None
                        self._segment_path = lambda: "facility"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Logging.Discriminator.Severity.Facility, [u'drops', u'includes'], name, value)


        class Persistent(Entity):
            """
            Set persistent logging parameters
            
            .. attribute:: url
            
            	URL to store logging messages
            	**type**\: str
            
            .. attribute:: size
            
            	Set disk space for writing log messages
            	**type**\: int
            
            	**range:** 16384..2147483647
            
            .. attribute:: filesize
            
            	Set size of individual log files
            	**type**\: int
            
            	**range:** 8192..2147483647
            
            .. attribute:: batch
            
            	Batch size for writing to persistent storage
            	**type**\: int
            
            	**range:** 4096..2147483647
            
            .. attribute:: threshold
            
            	Setting threshold capacity. When setting circular logging is disabled
            	**type**\: int
            
            	**range:** 1..99
            
            .. attribute:: immediate
            
            	Write log entry to storage immediately (no buffering)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: notify
            
            	Notify when show logging [persistent] is activated
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: protected
            
            	Eliminates manipulation on logging\-persistent files
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.Persistent, self).__init__()

                self.yang_name = "persistent"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('url', (YLeaf(YType.str, 'url'), ['str'])),
                    ('size', (YLeaf(YType.uint32, 'size'), ['int'])),
                    ('filesize', (YLeaf(YType.uint32, 'filesize'), ['int'])),
                    ('batch', (YLeaf(YType.uint32, 'batch'), ['int'])),
                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                    ('immediate', (YLeaf(YType.empty, 'immediate'), ['Empty'])),
                    ('notify', (YLeaf(YType.empty, 'notify'), ['Empty'])),
                    ('protected', (YLeaf(YType.empty, 'protected'), ['Empty'])),
                ])
                self.url = None
                self.size = None
                self.filesize = None
                self.batch = None
                self.threshold = None
                self.immediate = None
                self.notify = None
                self.protected = None
                self._segment_path = lambda: "persistent"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.Persistent, [u'url', u'size', u'filesize', u'batch', u'threshold', u'immediate', u'notify', u'protected'], name, value)


        class MonitorConf(Entity):
            """
            
            
            .. attribute:: monitor
            
            	
            	**type**\: bool
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.MonitorConf, self).__init__()

                self.yang_name = "monitor-conf"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('monitor', (YLeaf(YType.boolean, 'monitor'), ['bool'])),
                ])
                self.monitor = None
                self._segment_path = lambda: "monitor-conf"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.MonitorConf, [u'monitor'], name, value)


        class Monitor(Entity):
            """
            Set terminal line (monitor) logging parameters
            
            .. attribute:: severity
            
            	
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..7
            
            		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
            
            .. attribute:: discriminator
            
            	Establish MD\-Console association
            	**type**\: list of  		 :py:class:`Discriminator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Monitor.Discriminator>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.Monitor, self).__init__()

                self.yang_name = "monitor"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("discriminator", ("discriminator", Native.Logging.Monitor.Discriminator))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('severity', (YLeaf(YType.str, 'severity'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                ])
                self.severity = None

                self.discriminator = YList(self)
                self._segment_path = lambda: "monitor"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.Monitor, [u'severity'], name, value)


            class Discriminator(Entity):
                """
                Establish MD\-Console association
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: severity
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..7
                
                		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.Monitor.Discriminator, self).__init__()

                    self.yang_name = "discriminator"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('severity', (YLeaf(YType.str, 'severity'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                    ])
                    self.name = None
                    self.severity = None
                    self._segment_path = lambda: "discriminator" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/monitor/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.Monitor.Discriminator, [u'name', u'severity'], name, value)


        class Buffered(Entity):
            """
            Set buffered logging parameters
            
            .. attribute:: discriminator
            
            	
            	**type**\: list of  		 :py:class:`Discriminator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Buffered.Discriminator>`
            
            .. attribute:: size
            
            	
            	**type**\:  :py:class:`Size <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Buffered.Size>`
            
            .. attribute:: severity
            
            	
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..7
            
            		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
            
            .. attribute:: xxml
            
            	Enable logging in XML to XML logging buffer
            	**type**\: int
            
            	**range:** 4096..2147483647
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.Buffered, self).__init__()

                self.yang_name = "buffered"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("discriminator", ("discriminator", Native.Logging.Buffered.Discriminator)), ("size", ("size", Native.Logging.Buffered.Size))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('severity', (YLeaf(YType.str, 'severity'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                    ('xxml', (YLeaf(YType.uint32, 'xxml'), ['int'])),
                ])
                self.severity = None
                self.xxml = None

                self.size = Native.Logging.Buffered.Size()
                self.size.parent = self
                self._children_name_map["size"] = "size"

                self.discriminator = YList(self)
                self._segment_path = lambda: "buffered"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.Buffered, [u'severity', u'xxml'], name, value)


            class Discriminator(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: size_value
                
                	
                	**type**\: int
                
                	**range:** 4096..2147483647
                
                .. attribute:: severity
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..7
                
                		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.Buffered.Discriminator, self).__init__()

                    self.yang_name = "discriminator"
                    self.yang_parent_name = "buffered"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('size_value', (YLeaf(YType.uint32, 'size-value'), ['int'])),
                        ('severity', (YLeaf(YType.str, 'severity'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                    ])
                    self.name = None
                    self.size_value = None
                    self.severity = None
                    self._segment_path = lambda: "discriminator" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/buffered/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.Buffered.Discriminator, [u'name', u'size_value', u'severity'], name, value)


            class Size(Entity):
                """
                
                
                .. attribute:: size_value
                
                	
                	**type**\: int
                
                	**range:** 4096..2147483647
                
                .. attribute:: severity
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..7
                
                		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
                
                	**default value**\: debugging
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.Buffered.Size, self).__init__()

                    self.yang_name = "size"
                    self.yang_parent_name = "buffered"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('size_value', (YLeaf(YType.uint32, 'size-value'), ['int'])),
                        ('severity', (YLeaf(YType.str, 'severity'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                    ])
                    self.size_value = None
                    self.severity = None
                    self._segment_path = lambda: "size"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/buffered/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.Buffered.Size, [u'size_value', u'severity'], name, value)


        class ConsoleConf(Entity):
            """
            
            
            .. attribute:: console
            
            	Set console logging parameters
            	**type**\: bool
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.ConsoleConf, self).__init__()

                self.yang_name = "console-conf"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('console', (YLeaf(YType.boolean, 'console'), ['bool'])),
                ])
                self.console = None
                self._segment_path = lambda: "console-conf"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.ConsoleConf, [u'console'], name, value)


        class Console(Entity):
            """
            Set console logging parameters
            
            .. attribute:: discriminator
            
            	Establish MD\-Console association
            	**type**\: list of  		 :py:class:`Discriminator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Console.Discriminator>`
            
            .. attribute:: filtered
            
            	Enable filtered logging
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: guaranteed
            
            	Guarantee console messages
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: xxml
            
            	Enable logging in XML
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..7
            
            		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
            
            .. attribute:: severity
            
            	
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..7
            
            		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.Console, self).__init__()

                self.yang_name = "console"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("discriminator", ("discriminator", Native.Logging.Console.Discriminator))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('filtered', (YLeaf(YType.empty, 'filtered'), ['Empty'])),
                    ('guaranteed', (YLeaf(YType.empty, 'guaranteed'), ['Empty'])),
                    ('xxml', (YLeaf(YType.str, 'xxml'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                    ('severity', (YLeaf(YType.str, 'severity'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                ])
                self.filtered = None
                self.guaranteed = None
                self.xxml = None
                self.severity = None

                self.discriminator = YList(self)
                self._segment_path = lambda: "console"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.Console, [u'filtered', u'guaranteed', u'xxml', u'severity'], name, value)


            class Discriminator(Entity):
                """
                Establish MD\-Console association
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: severity
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..7
                
                		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.Console.Discriminator, self).__init__()

                    self.yang_name = "discriminator"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('severity', (YLeaf(YType.str, 'severity'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                    ])
                    self.name = None
                    self.severity = None
                    self._segment_path = lambda: "discriminator" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/console/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.Console.Discriminator, [u'name', u'severity'], name, value)


        class Event(Entity):
            """
            Global interface events
            
            .. attribute:: link_status
            
            	Globally enable/disable link UPDOWN message
            	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Event.LinkStatus>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.Event, self).__init__()

                self.yang_name = "event"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("link-status", ("link_status", Native.Logging.Event.LinkStatus))])
                self._leafs = OrderedDict()

                self.link_status = Native.Logging.Event.LinkStatus()
                self.link_status.parent = self
                self._children_name_map["link_status"] = "link-status"
                self._segment_path = lambda: "event"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.Event, [], name, value)


            class LinkStatus(Entity):
                """
                Globally enable/disable link UPDOWN message
                
                .. attribute:: boot
                
                	Supress/Allow link UPDOWN messages during boot
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: global_
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: default
                
                	Link UPDOWN messages for all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.Event.LinkStatus, self).__init__()

                    self.yang_name = "link-status"
                    self.yang_parent_name = "event"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('boot', (YLeaf(YType.empty, 'boot'), ['Empty'])),
                        ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                    ])
                    self.boot = None
                    self.global_ = None
                    self.default = None
                    self._segment_path = lambda: "link-status"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/event/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.Event.LinkStatus, [u'boot', u'global_', u'default'], name, value)


        class Esm(Entity):
            """
            Set ESM filter restrictions
            
            .. attribute:: config
            
            	Permit/Deny configuration changes from ESM filters
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.Esm, self).__init__()

                self.yang_name = "esm"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('config', (YLeaf(YType.empty, 'config'), ['Empty'])),
                ])
                self.config = None
                self._segment_path = lambda: "esm"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.Esm, [u'config'], name, value)


        class History(Entity):
            """
            Configure syslog history table
            
            .. attribute:: size
            
            	Set history table size
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: severity_level
            
            	
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..7
            
            		**type**\:  :py:class:`SeverityLevel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.History.SeverityLevel>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.History, self).__init__()

                self.yang_name = "history"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                    ('severity_level', (YLeaf(YType.str, 'severity-level'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Logging.History.SeverityLevel')])),
                ])
                self.size = None
                self.severity_level = None
                self._segment_path = lambda: "history"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.History, [u'size', u'severity_level'], name, value)

            class SeverityLevel(Enum):
                """
                SeverityLevel (Enum Class)

                .. data:: emergencies = 0

                .. data:: alerts = 1

                .. data:: critical = 2

                .. data:: errors = 3

                .. data:: warnings = 4

                .. data:: notifications = 5

                .. data:: informational = 6

                .. data:: debugging = 7

                """

                emergencies = Enum.YLeaf(0, "emergencies")

                alerts = Enum.YLeaf(1, "alerts")

                critical = Enum.YLeaf(2, "critical")

                errors = Enum.YLeaf(3, "errors")

                warnings = Enum.YLeaf(4, "warnings")

                notifications = Enum.YLeaf(5, "notifications")

                informational = Enum.YLeaf(6, "informational")

                debugging = Enum.YLeaf(7, "debugging")



        class Host(Entity):
            """
            Set syslog server IP address and parameters
            
            .. attribute:: ipv4_host_list
            
            	
            	**type**\: list of  		 :py:class:`Ipv4HostList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv4HostList>`
            
            .. attribute:: ipv4_host_transport_list
            
            	
            	**type**\: list of  		 :py:class:`Ipv4HostTransportList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv4HostTransportList>`
            
            .. attribute:: ipv4_host_vrf_list
            
            	
            	**type**\: list of  		 :py:class:`Ipv4HostVrfList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv4HostVrfList>`
            
            .. attribute:: ipv4_host_vrf_transport_list
            
            	
            	**type**\: list of  		 :py:class:`Ipv4HostVrfTransportList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv4HostVrfTransportList>`
            
            .. attribute:: ipv6
            
            	Set syslog server IPv6 address
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv6>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.Host, self).__init__()

                self.yang_name = "host"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ipv4-host-list", ("ipv4_host_list", Native.Logging.Host.Ipv4HostList)), ("ipv4-host-transport-list", ("ipv4_host_transport_list", Native.Logging.Host.Ipv4HostTransportList)), ("ipv4-host-vrf-list", ("ipv4_host_vrf_list", Native.Logging.Host.Ipv4HostVrfList)), ("ipv4-host-vrf-transport-list", ("ipv4_host_vrf_transport_list", Native.Logging.Host.Ipv4HostVrfTransportList)), ("ipv6", ("ipv6", Native.Logging.Host.Ipv6))])
                self._leafs = OrderedDict()

                self.ipv6 = Native.Logging.Host.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.ipv4_host_list = YList(self)
                self.ipv4_host_transport_list = YList(self)
                self.ipv4_host_vrf_list = YList(self)
                self.ipv4_host_vrf_transport_list = YList(self)
                self._segment_path = lambda: "host"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.Host, [], name, value)


            class Ipv4HostList(Entity):
                """
                
                
                .. attribute:: ipv4_host  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.Host.Ipv4HostList, self).__init__()

                    self.yang_name = "ipv4-host-list"
                    self.yang_parent_name = "host"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['ipv4_host']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ipv4_host', (YLeaf(YType.str, 'ipv4-host'), ['str','str','str'])),
                    ])
                    self.ipv4_host = None
                    self._segment_path = lambda: "ipv4-host-list" + "[ipv4-host='" + str(self.ipv4_host) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/host/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.Host.Ipv4HostList, [u'ipv4_host'], name, value)


            class Ipv4HostTransportList(Entity):
                """
                
                
                .. attribute:: ipv4_host  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                
                .. attribute:: transport
                
                	
                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv4HostTransportList.Transport>`
                
                .. attribute:: discriminator
                
                	Specify a message discriminator identifier for this logging session
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.Host.Ipv4HostTransportList, self).__init__()

                    self.yang_name = "ipv4-host-transport-list"
                    self.yang_parent_name = "host"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['ipv4_host']
                    self._child_classes = OrderedDict([("transport", ("transport", Native.Logging.Host.Ipv4HostTransportList.Transport))])
                    self._leafs = OrderedDict([
                        ('ipv4_host', (YLeaf(YType.str, 'ipv4-host'), ['str','str','str'])),
                        ('discriminator', (YLeaf(YType.str, 'discriminator'), ['str'])),
                    ])
                    self.ipv4_host = None
                    self.discriminator = None

                    self.transport = Native.Logging.Host.Ipv4HostTransportList.Transport()
                    self.transport.parent = self
                    self._children_name_map["transport"] = "transport"
                    self._segment_path = lambda: "ipv4-host-transport-list" + "[ipv4-host='" + str(self.ipv4_host) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/host/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.Host.Ipv4HostTransportList, [u'ipv4_host', u'discriminator'], name, value)


                class Transport(Entity):
                    """
                    
                    
                    .. attribute:: udp
                    
                    	
                    	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv4HostTransportList.Transport.Udp>`
                    
                    .. attribute:: tcp
                    
                    	
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv4HostTransportList.Transport.Tcp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Logging.Host.Ipv4HostTransportList.Transport, self).__init__()

                        self.yang_name = "transport"
                        self.yang_parent_name = "ipv4-host-transport-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("udp", ("udp", Native.Logging.Host.Ipv4HostTransportList.Transport.Udp)), ("tcp", ("tcp", Native.Logging.Host.Ipv4HostTransportList.Transport.Tcp))])
                        self._leafs = OrderedDict()

                        self.udp = Native.Logging.Host.Ipv4HostTransportList.Transport.Udp()
                        self.udp.parent = self
                        self._children_name_map["udp"] = "udp"

                        self.tcp = Native.Logging.Host.Ipv4HostTransportList.Transport.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"
                        self._segment_path = lambda: "transport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Logging.Host.Ipv4HostTransportList.Transport, [], name, value)


                    class Udp(Entity):
                        """
                        
                        
                        .. attribute:: port
                        
                        	
                        	**type**\: list of int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Logging.Host.Ipv4HostTransportList.Transport.Udp, self).__init__()

                            self.yang_name = "udp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port', (YLeafList(YType.uint16, 'port'), ['int'])),
                            ])
                            self.port = []
                            self._segment_path = lambda: "udp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Logging.Host.Ipv4HostTransportList.Transport.Udp, [u'port'], name, value)


                    class Tcp(Entity):
                        """
                        
                        
                        .. attribute:: port
                        
                        	
                        	**type**\: list of int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Logging.Host.Ipv4HostTransportList.Transport.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port', (YLeafList(YType.uint16, 'port'), ['int'])),
                            ])
                            self.port = []
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Logging.Host.Ipv4HostTransportList.Transport.Tcp, [u'port'], name, value)


            class Ipv4HostVrfList(Entity):
                """
                
                
                .. attribute:: ipv4_host  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                
                .. attribute:: vrf  (key)
                
                	Set VRF option
                	**type**\: str
                
                .. attribute:: discriminator
                
                	Specify a message discriminator identifier for this logging session
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.Host.Ipv4HostVrfList, self).__init__()

                    self.yang_name = "ipv4-host-vrf-list"
                    self.yang_parent_name = "host"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['ipv4_host','vrf']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ipv4_host', (YLeaf(YType.str, 'ipv4-host'), ['str','str','str'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ('discriminator', (YLeaf(YType.str, 'discriminator'), ['str'])),
                    ])
                    self.ipv4_host = None
                    self.vrf = None
                    self.discriminator = None
                    self._segment_path = lambda: "ipv4-host-vrf-list" + "[ipv4-host='" + str(self.ipv4_host) + "']" + "[vrf='" + str(self.vrf) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/host/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.Host.Ipv4HostVrfList, [u'ipv4_host', u'vrf', u'discriminator'], name, value)


            class Ipv4HostVrfTransportList(Entity):
                """
                
                
                .. attribute:: ipv4_host  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                
                .. attribute:: vrf  (key)
                
                	Set VRF option
                	**type**\: str
                
                .. attribute:: transport
                
                	
                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv4HostVrfTransportList.Transport>`
                
                .. attribute:: discriminator
                
                	Specify a message discriminator identifier for this logging session
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.Host.Ipv4HostVrfTransportList, self).__init__()

                    self.yang_name = "ipv4-host-vrf-transport-list"
                    self.yang_parent_name = "host"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['ipv4_host','vrf']
                    self._child_classes = OrderedDict([("transport", ("transport", Native.Logging.Host.Ipv4HostVrfTransportList.Transport))])
                    self._leafs = OrderedDict([
                        ('ipv4_host', (YLeaf(YType.str, 'ipv4-host'), ['str','str','str'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ('discriminator', (YLeaf(YType.str, 'discriminator'), ['str'])),
                    ])
                    self.ipv4_host = None
                    self.vrf = None
                    self.discriminator = None

                    self.transport = Native.Logging.Host.Ipv4HostVrfTransportList.Transport()
                    self.transport.parent = self
                    self._children_name_map["transport"] = "transport"
                    self._segment_path = lambda: "ipv4-host-vrf-transport-list" + "[ipv4-host='" + str(self.ipv4_host) + "']" + "[vrf='" + str(self.vrf) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/host/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.Host.Ipv4HostVrfTransportList, [u'ipv4_host', u'vrf', u'discriminator'], name, value)


                class Transport(Entity):
                    """
                    
                    
                    .. attribute:: udp
                    
                    	
                    	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv4HostVrfTransportList.Transport.Udp>`
                    
                    .. attribute:: tcp
                    
                    	
                    	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv4HostVrfTransportList.Transport.Tcp>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Logging.Host.Ipv4HostVrfTransportList.Transport, self).__init__()

                        self.yang_name = "transport"
                        self.yang_parent_name = "ipv4-host-vrf-transport-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("udp", ("udp", Native.Logging.Host.Ipv4HostVrfTransportList.Transport.Udp)), ("tcp", ("tcp", Native.Logging.Host.Ipv4HostVrfTransportList.Transport.Tcp))])
                        self._leafs = OrderedDict()

                        self.udp = Native.Logging.Host.Ipv4HostVrfTransportList.Transport.Udp()
                        self.udp.parent = self
                        self._children_name_map["udp"] = "udp"

                        self.tcp = Native.Logging.Host.Ipv4HostVrfTransportList.Transport.Tcp()
                        self.tcp.parent = self
                        self._children_name_map["tcp"] = "tcp"
                        self._segment_path = lambda: "transport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Logging.Host.Ipv4HostVrfTransportList.Transport, [], name, value)


                    class Udp(Entity):
                        """
                        
                        
                        .. attribute:: port
                        
                        	
                        	**type**\: list of int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Logging.Host.Ipv4HostVrfTransportList.Transport.Udp, self).__init__()

                            self.yang_name = "udp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port', (YLeafList(YType.uint16, 'port'), ['int'])),
                            ])
                            self.port = []
                            self._segment_path = lambda: "udp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Logging.Host.Ipv4HostVrfTransportList.Transport.Udp, [u'port'], name, value)


                    class Tcp(Entity):
                        """
                        
                        
                        .. attribute:: port
                        
                        	
                        	**type**\: list of int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Logging.Host.Ipv4HostVrfTransportList.Transport.Tcp, self).__init__()

                            self.yang_name = "tcp"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port', (YLeafList(YType.uint16, 'port'), ['int'])),
                            ])
                            self.port = []
                            self._segment_path = lambda: "tcp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Logging.Host.Ipv4HostVrfTransportList.Transport.Tcp, [u'port'], name, value)


            class Ipv6(Entity):
                """
                Set syslog server IPv6 address
                
                .. attribute:: ipv6_host_list
                
                	
                	**type**\: list of  		 :py:class:`Ipv6HostList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv6.Ipv6HostList>`
                
                .. attribute:: ipv6_host_transport_list
                
                	
                	**type**\: list of  		 :py:class:`Ipv6HostTransportList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv6.Ipv6HostTransportList>`
                
                .. attribute:: ipv6_host_vrf_list
                
                	
                	**type**\: list of  		 :py:class:`Ipv6HostVrfList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv6.Ipv6HostVrfList>`
                
                .. attribute:: ipv6_host_vrf_transport_list
                
                	
                	**type**\: list of  		 :py:class:`Ipv6HostVrfTransportList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.Host.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "host"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv6-host-list", ("ipv6_host_list", Native.Logging.Host.Ipv6.Ipv6HostList)), ("ipv6-host-transport-list", ("ipv6_host_transport_list", Native.Logging.Host.Ipv6.Ipv6HostTransportList)), ("ipv6-host-vrf-list", ("ipv6_host_vrf_list", Native.Logging.Host.Ipv6.Ipv6HostVrfList)), ("ipv6-host-vrf-transport-list", ("ipv6_host_vrf_transport_list", Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList))])
                    self._leafs = OrderedDict()

                    self.ipv6_host_list = YList(self)
                    self.ipv6_host_transport_list = YList(self)
                    self.ipv6_host_vrf_list = YList(self)
                    self.ipv6_host_vrf_transport_list = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/host/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.Host.Ipv6, [], name, value)


                class Ipv6HostList(Entity):
                    """
                    
                    
                    .. attribute:: ipv6_host  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Logging.Host.Ipv6.Ipv6HostList, self).__init__()

                        self.yang_name = "ipv6-host-list"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['ipv6_host']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ipv6_host', (YLeaf(YType.str, 'ipv6-host'), ['str','str'])),
                        ])
                        self.ipv6_host = None
                        self._segment_path = lambda: "ipv6-host-list" + "[ipv6-host='" + str(self.ipv6_host) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/host/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Logging.Host.Ipv6.Ipv6HostList, [u'ipv6_host'], name, value)


                class Ipv6HostTransportList(Entity):
                    """
                    
                    
                    .. attribute:: ipv6_host  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                    
                    .. attribute:: transport
                    
                    	
                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport>`
                    
                    .. attribute:: discriminator
                    
                    	Specify a message discriminator identifier for this logging session
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Logging.Host.Ipv6.Ipv6HostTransportList, self).__init__()

                        self.yang_name = "ipv6-host-transport-list"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['ipv6_host']
                        self._child_classes = OrderedDict([("transport", ("transport", Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport))])
                        self._leafs = OrderedDict([
                            ('ipv6_host', (YLeaf(YType.str, 'ipv6-host'), ['str','str'])),
                            ('discriminator', (YLeaf(YType.str, 'discriminator'), ['str'])),
                        ])
                        self.ipv6_host = None
                        self.discriminator = None

                        self.transport = Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport()
                        self.transport.parent = self
                        self._children_name_map["transport"] = "transport"
                        self._segment_path = lambda: "ipv6-host-transport-list" + "[ipv6-host='" + str(self.ipv6_host) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/host/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Logging.Host.Ipv6.Ipv6HostTransportList, [u'ipv6_host', u'discriminator'], name, value)


                    class Transport(Entity):
                        """
                        
                        
                        .. attribute:: udp
                        
                        	
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport.Udp>`
                        
                        .. attribute:: tcp
                        
                        	
                        	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport.Tcp>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport, self).__init__()

                            self.yang_name = "transport"
                            self.yang_parent_name = "ipv6-host-transport-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("udp", ("udp", Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport.Udp)), ("tcp", ("tcp", Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport.Tcp))])
                            self._leafs = OrderedDict()

                            self.udp = Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"

                            self.tcp = Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport.Tcp()
                            self.tcp.parent = self
                            self._children_name_map["tcp"] = "tcp"
                            self._segment_path = lambda: "transport"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport, [], name, value)


                        class Udp(Entity):
                            """
                            
                            
                            .. attribute:: port
                            
                            	
                            	**type**\: list of int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port', (YLeafList(YType.uint16, 'port'), ['int'])),
                                ])
                                self.port = []
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport.Udp, [u'port'], name, value)


                        class Tcp(Entity):
                            """
                            
                            
                            .. attribute:: port
                            
                            	
                            	**type**\: list of int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport.Tcp, self).__init__()

                                self.yang_name = "tcp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port', (YLeafList(YType.uint16, 'port'), ['int'])),
                                ])
                                self.port = []
                                self._segment_path = lambda: "tcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Logging.Host.Ipv6.Ipv6HostTransportList.Transport.Tcp, [u'port'], name, value)


                class Ipv6HostVrfList(Entity):
                    """
                    
                    
                    .. attribute:: ipv6_host  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                    
                    .. attribute:: vrf  (key)
                    
                    	Set VRF option
                    	**type**\: str
                    
                    .. attribute:: discriminator
                    
                    	Specify a message discriminator identifier for this logging session
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Logging.Host.Ipv6.Ipv6HostVrfList, self).__init__()

                        self.yang_name = "ipv6-host-vrf-list"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['ipv6_host','vrf']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ipv6_host', (YLeaf(YType.str, 'ipv6-host'), ['str','str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ('discriminator', (YLeaf(YType.str, 'discriminator'), ['str'])),
                        ])
                        self.ipv6_host = None
                        self.vrf = None
                        self.discriminator = None
                        self._segment_path = lambda: "ipv6-host-vrf-list" + "[ipv6-host='" + str(self.ipv6_host) + "']" + "[vrf='" + str(self.vrf) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/host/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Logging.Host.Ipv6.Ipv6HostVrfList, [u'ipv6_host', u'vrf', u'discriminator'], name, value)


                class Ipv6HostVrfTransportList(Entity):
                    """
                    
                    
                    .. attribute:: ipv6_host  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                    
                    .. attribute:: vrf  (key)
                    
                    	Set VRF option
                    	**type**\: str
                    
                    .. attribute:: transport
                    
                    	
                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport>`
                    
                    .. attribute:: discriminator
                    
                    	Specify a message discriminator identifier for this logging session
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList, self).__init__()

                        self.yang_name = "ipv6-host-vrf-transport-list"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['ipv6_host','vrf']
                        self._child_classes = OrderedDict([("transport", ("transport", Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport))])
                        self._leafs = OrderedDict([
                            ('ipv6_host', (YLeaf(YType.str, 'ipv6-host'), ['str','str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ('discriminator', (YLeaf(YType.str, 'discriminator'), ['str'])),
                        ])
                        self.ipv6_host = None
                        self.vrf = None
                        self.discriminator = None

                        self.transport = Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport()
                        self.transport.parent = self
                        self._children_name_map["transport"] = "transport"
                        self._segment_path = lambda: "ipv6-host-vrf-transport-list" + "[ipv6-host='" + str(self.ipv6_host) + "']" + "[vrf='" + str(self.vrf) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/host/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList, [u'ipv6_host', u'vrf', u'discriminator'], name, value)


                    class Transport(Entity):
                        """
                        
                        
                        .. attribute:: udp
                        
                        	
                        	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport.Udp>`
                        
                        .. attribute:: tcp
                        
                        	
                        	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport.Tcp>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport, self).__init__()

                            self.yang_name = "transport"
                            self.yang_parent_name = "ipv6-host-vrf-transport-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("udp", ("udp", Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport.Udp)), ("tcp", ("tcp", Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport.Tcp))])
                            self._leafs = OrderedDict()

                            self.udp = Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport.Udp()
                            self.udp.parent = self
                            self._children_name_map["udp"] = "udp"

                            self.tcp = Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport.Tcp()
                            self.tcp.parent = self
                            self._children_name_map["tcp"] = "tcp"
                            self._segment_path = lambda: "transport"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport, [], name, value)


                        class Udp(Entity):
                            """
                            
                            
                            .. attribute:: port
                            
                            	
                            	**type**\: list of int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport.Udp, self).__init__()

                                self.yang_name = "udp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port', (YLeafList(YType.uint16, 'port'), ['int'])),
                                ])
                                self.port = []
                                self._segment_path = lambda: "udp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport.Udp, [u'port'], name, value)


                        class Tcp(Entity):
                            """
                            
                            
                            .. attribute:: port
                            
                            	
                            	**type**\: list of int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport.Tcp, self).__init__()

                                self.yang_name = "tcp"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port', (YLeafList(YType.uint16, 'port'), ['int'])),
                                ])
                                self.port = []
                                self._segment_path = lambda: "tcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Logging.Host.Ipv6.Ipv6HostVrfTransportList.Transport.Tcp, [u'port'], name, value)


        class OriginId(Entity):
            """
            Add origin ID to syslog messages
            
            .. attribute:: type_value
            
            	Use origin hostname/ip/ipv6 as ID
            	**type**\:  :py:class:`TypeValue <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.OriginId.TypeValue>`
            
            .. attribute:: string
            
            	Define a unique text string as ID
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.OriginId, self).__init__()

                self.yang_name = "origin-id"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('type_value', (YLeaf(YType.enumeration, 'type-value'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Logging.OriginId.TypeValue')])),
                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                ])
                self.type_value = None
                self.string = None
                self._segment_path = lambda: "origin-id"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.OriginId, [u'type_value', u'string'], name, value)

            class TypeValue(Enum):
                """
                TypeValue (Enum Class)

                Use origin hostname/ip/ipv6 as ID

                .. data:: hostname = 0

                .. data:: ip = 1

                .. data:: ipv6 = 2

                """

                hostname = Enum.YLeaf(0, "hostname")

                ip = Enum.YLeaf(1, "ip")

                ipv6 = Enum.YLeaf(2, "ipv6")



        class RateLimitConf(Entity):
            """
            
            
            .. attribute:: rate_limit
            
            	
            	**type**\: bool
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.RateLimitConf, self).__init__()

                self.yang_name = "rate-limit-conf"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                ])
                self.rate_limit = None
                self._segment_path = lambda: "rate-limit-conf"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.RateLimitConf, [u'rate_limit'], name, value)


        class RateLimit(Entity):
            """
            Set messages per second limit
            
            .. attribute:: ranges
            
            	
            	**type**\: list of  		 :py:class:`Ranges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit.Ranges>`
            
            .. attribute:: console
            
            	Rate limit only console messages
            	**type**\:  :py:class:`Console <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit.Console>`
            
            .. attribute:: all
            
            	Rate limit only console messages
            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit.All>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.RateLimit, self).__init__()

                self.yang_name = "rate-limit"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ranges", ("ranges", Native.Logging.RateLimit.Ranges)), ("console", ("console", Native.Logging.RateLimit.Console)), ("all", ("all", Native.Logging.RateLimit.All))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.console = Native.Logging.RateLimit.Console()
                self.console.parent = self
                self._children_name_map["console"] = "console"

                self.all = Native.Logging.RateLimit.All()
                self.all.parent = self
                self._children_name_map["all"] = "all"

                self.ranges = YList(self)
                self._segment_path = lambda: "rate-limit"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.RateLimit, [], name, value)


            class Ranges(Entity):
                """
                
                
                .. attribute:: range  (key)
                
                	Messages per second
                	**type**\: int
                
                	**range:** 1..10000
                
                .. attribute:: except_
                
                	Messages of this severity or higher
                	**type**\:  :py:class:`Except <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit.Ranges.Except>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.RateLimit.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "rate-limit"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['range']
                    self._child_classes = OrderedDict([("except", ("except_", Native.Logging.RateLimit.Ranges.Except))])
                    self._leafs = OrderedDict([
                        ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                    ])
                    self.range = None

                    self.except_ = None
                    self._children_name_map["except_"] = "except"
                    self._segment_path = lambda: "ranges" + "[range='" + str(self.range) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/rate-limit/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.RateLimit.Ranges, [u'range'], name, value)


                class Except(Entity):
                    """
                    Messages of this severity or higher
                    
                    .. attribute:: range
                    
                    	Logging severity level
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..7
                    
                    		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Logging.RateLimit.Ranges.Except, self).__init__()

                        self.yang_name = "except"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.str, 'range'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                        ])
                        self.range = None
                        self._segment_path = lambda: "except"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Logging.RateLimit.Ranges.Except, [u'range'], name, value)


            class Console(Entity):
                """
                Rate limit only console messages
                
                .. attribute:: ranges
                
                	
                	**type**\: list of  		 :py:class:`Ranges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit.Console.Ranges>`
                
                .. attribute:: all
                
                	all
                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit.Console.All>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.RateLimit.Console, self).__init__()

                    self.yang_name = "console"
                    self.yang_parent_name = "rate-limit"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ranges", ("ranges", Native.Logging.RateLimit.Console.Ranges)), ("all", ("all", Native.Logging.RateLimit.Console.All))])
                    self._leafs = OrderedDict()

                    self.all = Native.Logging.RateLimit.Console.All()
                    self.all.parent = self
                    self._children_name_map["all"] = "all"

                    self.ranges = YList(self)
                    self._segment_path = lambda: "console"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/rate-limit/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.RateLimit.Console, [], name, value)


                class Ranges(Entity):
                    """
                    
                    
                    .. attribute:: range  (key)
                    
                    	Messages per second
                    	**type**\: int
                    
                    	**range:** 1..10000
                    
                    .. attribute:: except_
                    
                    	Messages of this severity or higher
                    	**type**\:  :py:class:`Except <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit.Console.Ranges.Except>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Logging.RateLimit.Console.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "console"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("except", ("except_", Native.Logging.RateLimit.Console.Ranges.Except))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                        ])
                        self.range = None

                        self.except_ = None
                        self._children_name_map["except_"] = "except"
                        self._segment_path = lambda: "ranges" + "[range='" + str(self.range) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/rate-limit/console/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Logging.RateLimit.Console.Ranges, [u'range'], name, value)


                    class Except(Entity):
                        """
                        Messages of this severity or higher
                        
                        .. attribute:: range
                        
                        	Logging severity level
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..7
                        
                        		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Logging.RateLimit.Console.Ranges.Except, self).__init__()

                            self.yang_name = "except"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('range', (YLeaf(YType.str, 'range'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                            ])
                            self.range = None
                            self._segment_path = lambda: "except"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Logging.RateLimit.Console.Ranges.Except, [u'range'], name, value)


                class All(Entity):
                    """
                    all
                    
                    .. attribute:: ranges
                    
                    	
                    	**type**\: list of  		 :py:class:`Ranges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit.Console.All.Ranges>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Logging.RateLimit.Console.All, self).__init__()

                        self.yang_name = "all"
                        self.yang_parent_name = "console"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ranges", ("ranges", Native.Logging.RateLimit.Console.All.Ranges))])
                        self._leafs = OrderedDict()

                        self.ranges = YList(self)
                        self._segment_path = lambda: "all"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/rate-limit/console/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Logging.RateLimit.Console.All, [], name, value)


                    class Ranges(Entity):
                        """
                        
                        
                        .. attribute:: range  (key)
                        
                        	Messages per second
                        	**type**\: int
                        
                        	**range:** 1..10000
                        
                        .. attribute:: except_
                        
                        	Messages of this severity or higher
                        	**type**\:  :py:class:`Except <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit.Console.All.Ranges.Except>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Logging.RateLimit.Console.All.Ranges, self).__init__()

                            self.yang_name = "ranges"
                            self.yang_parent_name = "all"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['range']
                            self._child_classes = OrderedDict([("except", ("except_", Native.Logging.RateLimit.Console.All.Ranges.Except))])
                            self._leafs = OrderedDict([
                                ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                            ])
                            self.range = None

                            self.except_ = None
                            self._children_name_map["except_"] = "except"
                            self._segment_path = lambda: "ranges" + "[range='" + str(self.range) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/rate-limit/console/all/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Logging.RateLimit.Console.All.Ranges, [u'range'], name, value)


                        class Except(Entity):
                            """
                            Messages of this severity or higher
                            
                            .. attribute:: range
                            
                            	Logging severity level
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..7
                            
                            		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Logging.RateLimit.Console.All.Ranges.Except, self).__init__()

                                self.yang_name = "except"
                                self.yang_parent_name = "ranges"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.str, 'range'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                                ])
                                self.range = None
                                self._segment_path = lambda: "except"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Logging.RateLimit.Console.All.Ranges.Except, [u'range'], name, value)


            class All(Entity):
                """
                Rate limit only console messages
                
                .. attribute:: ranges
                
                	
                	**type**\: list of  		 :py:class:`Ranges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit.All.Ranges>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Logging.RateLimit.All, self).__init__()

                    self.yang_name = "all"
                    self.yang_parent_name = "rate-limit"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ranges", ("ranges", Native.Logging.RateLimit.All.Ranges))])
                    self._leafs = OrderedDict()

                    self.ranges = YList(self)
                    self._segment_path = lambda: "all"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/rate-limit/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Logging.RateLimit.All, [], name, value)


                class Ranges(Entity):
                    """
                    
                    
                    .. attribute:: range  (key)
                    
                    	Messages per second
                    	**type**\: int
                    
                    	**range:** 1..10000
                    
                    .. attribute:: except_
                    
                    	Messages of this severity or higher
                    	**type**\:  :py:class:`Except <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.RateLimit.All.Ranges.Except>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Logging.RateLimit.All.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['range']
                        self._child_classes = OrderedDict([("except", ("except_", Native.Logging.RateLimit.All.Ranges.Except))])
                        self._leafs = OrderedDict([
                            ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                        ])
                        self.range = None

                        self.except_ = None
                        self._children_name_map["except_"] = "except"
                        self._segment_path = lambda: "ranges" + "[range='" + str(self.range) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/rate-limit/all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Logging.RateLimit.All.Ranges, [u'range'], name, value)


                    class Except(Entity):
                        """
                        Messages of this severity or higher
                        
                        .. attribute:: range
                        
                        	Logging severity level
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..7
                        
                        		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Logging.RateLimit.All.Ranges.Except, self).__init__()

                            self.yang_name = "except"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('range', (YLeaf(YType.str, 'range'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                            ])
                            self.range = None
                            self._segment_path = lambda: "except"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Logging.RateLimit.All.Ranges.Except, [u'range'], name, value)


        class SourceInterface(Entity):
            """
            Specify interface for source address in logging transactions
            
            .. attribute:: interface_name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: vrf
            
            	Specify the vrf of source interface for logging transactions
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.SourceInterface, self).__init__()

                self.yang_name = "source-interface"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['interface_name']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                ])
                self.interface_name = None
                self.vrf = None
                self._segment_path = lambda: "source-interface" + "[interface-name='" + str(self.interface_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.SourceInterface, [u'interface_name', u'vrf'], name, value)


        class SnmpTrap(Entity):
            """
            Set SNMP trap logging level
            
            .. attribute:: alerts
            
            	Immediate action needed           (severity=1)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: critical
            
            	Critical conditions               (severity=2)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: debugging
            
            	Debugging messages                (severity=7)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: emergencies
            
            	System is unusable                (severity=0)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: errors
            
            	Error conditions                  (severity=3)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: informational
            
            	Informational messages            (severity=6)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: notifications
            
            	Normal but significant conditions (severity=5)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: warnings
            
            	Warning conditions                (severity=4)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.SnmpTrap, self).__init__()

                self.yang_name = "snmp-trap"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('alerts', (YLeaf(YType.empty, 'alerts'), ['Empty'])),
                    ('critical', (YLeaf(YType.empty, 'critical'), ['Empty'])),
                    ('debugging', (YLeaf(YType.empty, 'debugging'), ['Empty'])),
                    ('emergencies', (YLeaf(YType.empty, 'emergencies'), ['Empty'])),
                    ('errors', (YLeaf(YType.empty, 'errors'), ['Empty'])),
                    ('informational', (YLeaf(YType.empty, 'informational'), ['Empty'])),
                    ('notifications', (YLeaf(YType.empty, 'notifications'), ['Empty'])),
                    ('warnings', (YLeaf(YType.empty, 'warnings'), ['Empty'])),
                ])
                self.alerts = None
                self.critical = None
                self.debugging = None
                self.emergencies = None
                self.errors = None
                self.informational = None
                self.notifications = None
                self.warnings = None
                self._segment_path = lambda: "snmp-trap"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.SnmpTrap, [u'alerts', u'critical', u'debugging', u'emergencies', u'errors', u'informational', u'notifications', u'warnings'], name, value)


        class Trap(Entity):
            """
            Set trap server logging level
            
            .. attribute:: trap_default
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: severity
            
            	
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..7
            
            		**type**\:  :py:class:`Severity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Logging.Trap.Severity>`
            
            	**default value**\: informational
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.Trap, self).__init__()

                self.yang_name = "trap"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('trap_default', (YLeaf(YType.empty, 'trap-default'), ['Empty'])),
                    ('severity', (YLeaf(YType.str, 'severity'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Logging.Trap.Severity')])),
                ])
                self.trap_default = None
                self.severity = None
                self._segment_path = lambda: "trap"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.Trap, [u'trap_default', u'severity'], name, value)

            class Severity(Enum):
                """
                Severity (Enum Class)

                .. data:: alerts = 0

                .. data:: critical = 1

                .. data:: debugging = 2

                .. data:: emergencies = 3

                .. data:: errors = 4

                .. data:: informational = 5

                .. data:: notifications = 6

                .. data:: warnings = 7

                """

                alerts = Enum.YLeaf(0, "alerts")

                critical = Enum.YLeaf(1, "critical")

                debugging = Enum.YLeaf(2, "debugging")

                emergencies = Enum.YLeaf(3, "emergencies")

                errors = Enum.YLeaf(4, "errors")

                informational = Enum.YLeaf(5, "informational")

                notifications = Enum.YLeaf(6, "notifications")

                warnings = Enum.YLeaf(7, "warnings")



        class File(Entity):
            """
            Set logging file parameters
            
            .. attribute:: name
            
            	
            	**type**\: str
            
            .. attribute:: max_size
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: min_size
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: severity
            
            	
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..7
            
            		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Logging.File, self).__init__()

                self.yang_name = "file"
                self.yang_parent_name = "logging"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('max_size', (YLeaf(YType.uint32, 'max-size'), ['int'])),
                    ('min_size', (YLeaf(YType.uint32, 'min-size'), ['int'])),
                    ('severity', (YLeaf(YType.str, 'severity'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                ])
                self.name = None
                self.max_size = None
                self.min_size = None
                self.severity = None
                self._segment_path = lambda: "file"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/logging/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Logging.File, [u'name', u'max_size', u'min_size', u'severity'], name, value)


    class Aaa(Entity):
        """
        Authentication, Authorization and Accounting.
        
        .. attribute:: new_model
        
        	Enable NEW access control commands and functions.(Disables OLD commands.)
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: group
        
        	AAA group definitions
        	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group>`
        
        .. attribute:: attribute
        
        	AAA attribute definitions
        	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Attribute>`
        
        .. attribute:: authentication
        
        	Authentication configurations parameters
        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication>`
        
        .. attribute:: local
        
        	AAA Local method options
        	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Local>`
        
        .. attribute:: authorization
        
        	Authorization configurations parameters
        	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization>`
        
        .. attribute:: accounting
        
        	Accounting configurations parameters
        	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting>`
        
        .. attribute:: server
        
        	Local AAA server
        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server>`
        
        .. attribute:: session_id
        
        	AAA Session ID
        	**type**\:  :py:class:`SessionId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.SessionId>`
        
        .. attribute:: login
        
        	AAA login enable display
        	**type**\:  :py:class:`Login <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Login>`
        
        .. attribute:: max_sessions
        
        	Adjust initial hash size for estimated max sessions
        	**type**\: int
        
        	**range:** 1024..64000
        
        .. attribute:: memory
        
        	AAA memory parameters
        	**type**\:  :py:class:`Memory <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Memory>`
        
        .. attribute:: password
        
        	Configure password/secret related settings
        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Password>`
        
        .. attribute:: policy
        
        	AAA policy parameters
        	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Policy>`
        
        .. attribute:: route
        
        	Static route downloading
        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Route>`
        
        .. attribute:: traceback
        
        	Traceback recording
        	**type**\:  :py:class:`Traceback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Traceback>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Aaa, self).__init__()

            self.yang_name = "aaa"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-aaa:group", ("group", Native.Aaa.Group)), ("Cisco-IOS-XE-aaa:attribute", ("attribute", Native.Aaa.Attribute)), ("Cisco-IOS-XE-aaa:authentication", ("authentication", Native.Aaa.Authentication)), ("Cisco-IOS-XE-aaa:local", ("local", Native.Aaa.Local)), ("Cisco-IOS-XE-aaa:authorization", ("authorization", Native.Aaa.Authorization)), ("Cisco-IOS-XE-aaa:accounting", ("accounting", Native.Aaa.Accounting)), ("Cisco-IOS-XE-aaa:server", ("server", Native.Aaa.Server)), ("Cisco-IOS-XE-aaa:login", ("login", Native.Aaa.Login)), ("Cisco-IOS-XE-aaa:memory", ("memory", Native.Aaa.Memory)), ("Cisco-IOS-XE-aaa:policy", ("policy", Native.Aaa.Policy)), ("Cisco-IOS-XE-aaa:route", ("route", Native.Aaa.Route))])
            self._leafs = OrderedDict([
                ('new_model', (YLeaf(YType.empty, 'Cisco-IOS-XE-aaa:new-model'), ['Empty'])),
                ('session_id', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-aaa:session-id'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.SessionId')])),
                ('max_sessions', (YLeaf(YType.uint16, 'Cisco-IOS-XE-aaa:max-sessions'), ['int'])),
                ('password', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-aaa:password'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Password')])),
                ('traceback', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-aaa:traceback'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Traceback')])),
            ])
            self.new_model = None
            self.session_id = None
            self.max_sessions = None
            self.password = None
            self.traceback = None

            self.group = Native.Aaa.Group()
            self.group.parent = self
            self._children_name_map["group"] = "Cisco-IOS-XE-aaa:group"

            self.attribute = Native.Aaa.Attribute()
            self.attribute.parent = self
            self._children_name_map["attribute"] = "Cisco-IOS-XE-aaa:attribute"

            self.authentication = Native.Aaa.Authentication()
            self.authentication.parent = self
            self._children_name_map["authentication"] = "Cisco-IOS-XE-aaa:authentication"

            self.local = Native.Aaa.Local()
            self.local.parent = self
            self._children_name_map["local"] = "Cisco-IOS-XE-aaa:local"

            self.authorization = Native.Aaa.Authorization()
            self.authorization.parent = self
            self._children_name_map["authorization"] = "Cisco-IOS-XE-aaa:authorization"

            self.accounting = Native.Aaa.Accounting()
            self.accounting.parent = self
            self._children_name_map["accounting"] = "Cisco-IOS-XE-aaa:accounting"

            self.server = Native.Aaa.Server()
            self.server.parent = self
            self._children_name_map["server"] = "Cisco-IOS-XE-aaa:server"

            self.login = Native.Aaa.Login()
            self.login.parent = self
            self._children_name_map["login"] = "Cisco-IOS-XE-aaa:login"

            self.memory = Native.Aaa.Memory()
            self.memory.parent = self
            self._children_name_map["memory"] = "Cisco-IOS-XE-aaa:memory"

            self.policy = Native.Aaa.Policy()
            self.policy.parent = self
            self._children_name_map["policy"] = "Cisco-IOS-XE-aaa:policy"

            self.route = Native.Aaa.Route()
            self.route.parent = self
            self._children_name_map["route"] = "Cisco-IOS-XE-aaa:route"
            self._segment_path = lambda: "aaa"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Aaa, ['new_model', 'session_id', 'max_sessions', 'password', 'traceback'], name, value)

        class Password(Enum):
            """
            Password (Enum Class)

            Configure password/secret related settings

            .. data:: restriction = 0

            """

            restriction = Enum.YLeaf(0, "restriction")


        class SessionId(Enum):
            """
            SessionId (Enum Class)

            AAA Session ID

            .. data:: common = 0

            .. data:: unique = 1

            """

            common = Enum.YLeaf(0, "common")

            unique = Enum.YLeaf(1, "unique")


        class Traceback(Enum):
            """
            Traceback (Enum Class)

            Traceback recording

            .. data:: recording = 0

            """

            recording = Enum.YLeaf(0, "recording")



        class Group(Entity):
            """
            AAA group definitions
            
            .. attribute:: server
            
            	AAA Server group definitions
            	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Aaa.Group, self).__init__()

                self.yang_name = "group"
                self.yang_parent_name = "aaa"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("server", ("server", Native.Aaa.Group.Server))])
                self._leafs = OrderedDict()

                self.server = Native.Aaa.Group.Server()
                self.server.parent = self
                self._children_name_map["server"] = "server"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:group"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Aaa.Group, [], name, value)


            class Server(Entity):
                """
                AAA Server group definitions
                
                .. attribute:: tacacsplus
                
                	Tacacs+ server\-group definition
                	**type**\: list of  		 :py:class:`Tacacsplus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus>`
                
                .. attribute:: tacacs
                
                	Tacacs+ server\-group definition
                	**type**\: list of  		 :py:class:`Tacacs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacs>`
                
                .. attribute:: radius
                
                	Radius server\-group definition
                	**type**\: list of  		 :py:class:`Radius <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Group.Server, self).__init__()

                    self.yang_name = "server"
                    self.yang_parent_name = "group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tacacsplus", ("tacacsplus", Native.Aaa.Group.Server.Tacacsplus)), ("tacacs", ("tacacs", Native.Aaa.Group.Server.Tacacs)), ("radius", ("radius", Native.Aaa.Group.Server.Radius))])
                    self._leafs = OrderedDict()

                    self.tacacsplus = YList(self)
                    self.tacacs = YList(self)
                    self.radius = YList(self)
                    self._segment_path = lambda: "server"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:group/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Group.Server, [], name, value)


                class Tacacsplus(Entity):
                    """
                    Tacacs+ server\-group definition
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: server
                    
                    	Specify a TACACS server
                    	**type**\:  :py:class:`Server_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.Server_>`
                    
                    .. attribute:: server_private
                    
                    	Define a private TACACS server (per group)
                    	**type**\: list of  		 :py:class:`ServerPrivate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.ServerPrivate>`
                    
                    .. attribute:: ip
                    
                    	Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.Ip>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Group.Server.Tacacsplus, self).__init__()

                        self.yang_name = "tacacsplus"
                        self.yang_parent_name = "server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("server", ("server", Native.Aaa.Group.Server.Tacacsplus.Server_)), ("server-private", ("server_private", Native.Aaa.Group.Server.Tacacsplus.ServerPrivate)), ("ip", ("ip", Native.Aaa.Group.Server.Tacacsplus.Ip))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.server = Native.Aaa.Group.Server.Tacacsplus.Server_()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.ip = Native.Aaa.Group.Server.Tacacsplus.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.server_private = YList(self)
                        self._segment_path = lambda: "tacacsplus" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:group/server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus, ['name'], name, value)


                    class Server_(Entity):
                        """
                        Specify a TACACS server
                        
                        .. attribute:: name
                        
                        	Name of tacacs server
                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.Server_.Name>`
                        
                        .. attribute:: direct
                        
                        	
                        	**type**\: list of  		 :py:class:`Direct <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.Server_.Direct>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Group.Server.Tacacsplus.Server_, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "tacacsplus"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("name", ("name", Native.Aaa.Group.Server.Tacacsplus.Server_.Name)), ("direct", ("direct", Native.Aaa.Group.Server.Tacacsplus.Server_.Direct))])
                            self._leafs = OrderedDict()

                            self.name = YList(self)
                            self.direct = YList(self)
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.Server_, [], name, value)


                        class Name(Entity):
                            """
                            Name of tacacs server
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Tacacsplus.Server_.Name, self).__init__()

                                self.yang_name = "name"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.Server_.Name, ['name'], name, value)


                        class Direct(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Tacacsplus.Server_.Direct, self).__init__()

                                self.yang_name = "direct"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str','str','str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "direct" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.Server_.Direct, ['name'], name, value)


                    class ServerPrivate(Entity):
                        """
                        Define a private TACACS server (per group)
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: port
                        
                        	TCP port for TACACS+ server (default is 49)
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: timeout
                        
                        	Time to wait for this TACACS server to reply (overrides default)
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: key
                        
                        	per\-server encryption key (overrides default)
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.ServerPrivate.Key>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Group.Server.Tacacsplus.ServerPrivate, self).__init__()

                            self.yang_name = "server-private"
                            self.yang_parent_name = "tacacsplus"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("key", ("key", Native.Aaa.Group.Server.Tacacsplus.ServerPrivate.Key))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str','str','str'])),
                                ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                            ])
                            self.name = None
                            self.port = None
                            self.timeout = None

                            self.key = Native.Aaa.Group.Server.Tacacsplus.ServerPrivate.Key()
                            self.key.parent = self
                            self._children_name_map["key"] = "key"
                            self._segment_path = lambda: "server-private" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.ServerPrivate, ['name', 'port', 'timeout'], name, value)


                        class Key(Entity):
                            """
                            per\-server encryption key (overrides default)
                            
                            .. attribute:: encryption
                            
                            	
                            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.ServerPrivate.Key.Encryption>`
                            
                            .. attribute:: key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Tacacsplus.ServerPrivate.Key, self).__init__()

                                self.yang_name = "key"
                                self.yang_parent_name = "server-private"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Group.Server.Tacacsplus.ServerPrivate.Key.Encryption')])),
                                    ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ])
                                self.encryption = None
                                self.key = None
                                self._segment_path = lambda: "key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.ServerPrivate.Key, ['encryption', 'key'], name, value)

                            class Encryption(Enum):
                                """
                                Encryption (Enum Class)

                                .. data:: Y_0 = 0

                                .. data:: Y_7 = 1

                                """

                                Y_0 = Enum.YLeaf(0, "0")

                                Y_7 = Enum.YLeaf(1, "7")



                    class Ip(Entity):
                        """
                        Internet Protocol config commands
                        
                        .. attribute:: tacacs
                        
                        	TACACS configuration commands
                        	**type**\:  :py:class:`Tacacs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs>`
                        
                        .. attribute:: vrf
                        
                        	Set VPN Routing Forwarding to use with the servers
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.Ip.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Group.Server.Tacacsplus.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "tacacsplus"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("tacacs", ("tacacs", Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs)), ("vrf", ("vrf", Native.Aaa.Group.Server.Tacacsplus.Ip.Vrf))])
                            self._leafs = OrderedDict()

                            self.tacacs = Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs()
                            self.tacacs.parent = self
                            self._children_name_map["tacacs"] = "tacacs"

                            self.vrf = Native.Aaa.Group.Server.Tacacsplus.Ip.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.Ip, [], name, value)


                        class Tacacs(Entity):
                            """
                            TACACS configuration commands
                            
                            .. attribute:: source_interface
                            
                            	Specify interface for source address in TACACS packets
                            	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs, self).__init__()

                                self.yang_name = "tacacs"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source-interface", ("source_interface", Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface))])
                                self._leafs = OrderedDict()

                                self.source_interface = Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface()
                                self.source_interface.parent = self
                                self._children_name_map["source_interface"] = "source-interface"
                                self._segment_path = lambda: "tacacs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs, [], name, value)


                            class SourceInterface(Entity):
                                """
                                Specify interface for source address in TACACS packets
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface, self).__init__()

                                    self.yang_name = "source-interface"
                                    self.yang_parent_name = "tacacs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "source-interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "source-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "source-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "source-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "source-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.Ip.Tacacs.SourceInterface.PortChannelSubinterface, [u'port_channel'], name, value)


                        class Vrf(Entity):
                            """
                            Set VPN Routing Forwarding to use with the servers
                            
                            .. attribute:: forwarding
                            
                            	Configure forwarding table
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Tacacsplus.Ip.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                                ])
                                self.forwarding = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Tacacsplus.Ip.Vrf, ['forwarding'], name, value)


                class Tacacs(Entity):
                    """
                    Tacacs+ server\-group definition
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Group.Server.Tacacs, self).__init__()

                        self.yang_name = "tacacs"
                        self.yang_parent_name = "server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "tacacs" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:group/server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Group.Server.Tacacs, ['name'], name, value)


                class Radius(Entity):
                    """
                    Radius server\-group definition
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: server
                    
                    	Specify a RADIUS server
                    	**type**\:  :py:class:`Server_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Server_>`
                    
                    .. attribute:: subscriber
                    
                    	Configures MAC Filtering RADIUS Compatibility mode
                    	**type**\:  :py:class:`Subscriber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Subscriber>`
                    
                    .. attribute:: mac_delimiter
                    
                    	MAC Delimiter for Radius Compatibility Mode
                    	**type**\:  :py:class:`MacDelimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.MacDelimiter>`
                    
                    .. attribute:: server_private
                    
                    	Define a private RADIUS server (per group)
                    	**type**\: list of  		 :py:class:`ServerPrivate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.ServerPrivate>`
                    
                    .. attribute:: deadtime
                    
                    	Specify time in minutes to ignore an unresponsive server
                    	**type**\: int
                    
                    	**range:** 0..1440
                    
                    .. attribute:: ip
                    
                    	Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Ip>`
                    
                    .. attribute:: load_balance
                    
                    	Server group load\-balancing options
                    	**type**\:  :py:class:`LoadBalance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.LoadBalance>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Group.Server.Radius, self).__init__()

                        self.yang_name = "radius"
                        self.yang_parent_name = "server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("server", ("server", Native.Aaa.Group.Server.Radius.Server_)), ("subscriber", ("subscriber", Native.Aaa.Group.Server.Radius.Subscriber)), ("server-private", ("server_private", Native.Aaa.Group.Server.Radius.ServerPrivate)), ("ip", ("ip", Native.Aaa.Group.Server.Radius.Ip)), ("load-balance", ("load_balance", Native.Aaa.Group.Server.Radius.LoadBalance))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('mac_delimiter', (YLeaf(YType.enumeration, 'mac-delimiter'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Group.Server.Radius.MacDelimiter')])),
                            ('deadtime', (YLeaf(YType.uint16, 'deadtime'), ['int'])),
                        ])
                        self.name = None
                        self.mac_delimiter = None
                        self.deadtime = None

                        self.server = Native.Aaa.Group.Server.Radius.Server_()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"

                        self.subscriber = Native.Aaa.Group.Server.Radius.Subscriber()
                        self.subscriber.parent = self
                        self._children_name_map["subscriber"] = "subscriber"

                        self.ip = Native.Aaa.Group.Server.Radius.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.load_balance = Native.Aaa.Group.Server.Radius.LoadBalance()
                        self.load_balance.parent = self
                        self._children_name_map["load_balance"] = "load-balance"

                        self.server_private = YList(self)
                        self._segment_path = lambda: "radius" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:group/server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Group.Server.Radius, ['name', 'mac_delimiter', 'deadtime'], name, value)

                    class MacDelimiter(Enum):
                        """
                        MacDelimiter (Enum Class)

                        MAC Delimiter for Radius Compatibility Mode

                        .. data:: colon = 0

                        .. data:: hyphen = 1

                        .. data:: none = 2

                        .. data:: single_hyphen = 3

                        """

                        colon = Enum.YLeaf(0, "colon")

                        hyphen = Enum.YLeaf(1, "hyphen")

                        none = Enum.YLeaf(2, "none")

                        single_hyphen = Enum.YLeaf(3, "single-hyphen")



                    class Server_(Entity):
                        """
                        Specify a RADIUS server
                        
                        .. attribute:: name
                        
                        	Name of radius server
                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Server_.Name>`
                        
                        .. attribute:: direct
                        
                        	
                        	**type**\: list of  		 :py:class:`Direct <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Server_.Direct>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Group.Server.Radius.Server_, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "radius"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("name", ("name", Native.Aaa.Group.Server.Radius.Server_.Name)), ("direct", ("direct", Native.Aaa.Group.Server.Radius.Server_.Direct))])
                            self._leafs = OrderedDict()

                            self.name = YList(self)
                            self.direct = YList(self)
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Group.Server.Radius.Server_, [], name, value)


                        class Name(Entity):
                            """
                            Name of radius server
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Radius.Server_.Name, self).__init__()

                                self.yang_name = "name"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Radius.Server_.Name, ['name'], name, value)


                        class Direct(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: auth_port
                            
                            	UDP port for RADIUS authentication server (default is 1645)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: acct_port
                            
                            	UDP port for RADIUS accounting server (default is 1646)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Radius.Server_.Direct, self).__init__()

                                self.yang_name = "direct"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str','str','str'])),
                                    ('auth_port', (YLeaf(YType.uint16, 'auth-port'), ['int'])),
                                    ('acct_port', (YLeaf(YType.uint16, 'acct-port'), ['int'])),
                                ])
                                self.name = None
                                self.auth_port = None
                                self.acct_port = None
                                self._segment_path = lambda: "direct" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Radius.Server_.Direct, ['name', 'auth_port', 'acct_port'], name, value)


                    class Subscriber(Entity):
                        """
                        Configures MAC Filtering RADIUS Compatibility mode
                        
                        .. attribute:: mac_filtering
                        
                        	MAC Filtering
                        	**type**\:  :py:class:`MacFiltering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Subscriber.MacFiltering>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Group.Server.Radius.Subscriber, self).__init__()

                            self.yang_name = "subscriber"
                            self.yang_parent_name = "radius"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mac-filtering", ("mac_filtering", Native.Aaa.Group.Server.Radius.Subscriber.MacFiltering))])
                            self._leafs = OrderedDict()

                            self.mac_filtering = Native.Aaa.Group.Server.Radius.Subscriber.MacFiltering()
                            self.mac_filtering.parent = self
                            self._children_name_map["mac_filtering"] = "mac-filtering"
                            self._segment_path = lambda: "subscriber"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Group.Server.Radius.Subscriber, [], name, value)


                        class MacFiltering(Entity):
                            """
                            MAC Filtering
                            
                            .. attribute:: security_mode
                            
                            	Security Mode
                            	**type**\:  :py:class:`SecurityMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Subscriber.MacFiltering.SecurityMode>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Radius.Subscriber.MacFiltering, self).__init__()

                                self.yang_name = "mac-filtering"
                                self.yang_parent_name = "subscriber"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('security_mode', (YLeaf(YType.enumeration, 'security-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Group.Server.Radius.Subscriber.MacFiltering.SecurityMode')])),
                                ])
                                self.security_mode = None
                                self._segment_path = lambda: "mac-filtering"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Radius.Subscriber.MacFiltering, ['security_mode'], name, value)

                            class SecurityMode(Enum):
                                """
                                SecurityMode (Enum Class)

                                Security Mode

                                .. data:: mac = 0

                                .. data:: none = 1

                                .. data:: shared_secret = 2

                                """

                                mac = Enum.YLeaf(0, "mac")

                                none = Enum.YLeaf(1, "none")

                                shared_secret = Enum.YLeaf(2, "shared-secret")



                    class ServerPrivate(Entity):
                        """
                        Define a private RADIUS server (per group)
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: auth_port
                        
                        	UDP port for RADIUS authentication server (default is 1645)
                        	**type**\: int
                        
                        	**range:** 0..65534
                        
                        .. attribute:: acct_port
                        
                        	UDP port for RADIUS accounting server (default is 1646)
                        	**type**\: int
                        
                        	**range:** 0..65534
                        
                        .. attribute:: timeout
                        
                        	Time to wait for this RADIUS server to reply (overrides default)
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: retransmit
                        
                        	Number of retries to active server (overrides default)
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        .. attribute:: key
                        
                        	per\-server encryption key (overrides default)
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.ServerPrivate.Key>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Group.Server.Radius.ServerPrivate, self).__init__()

                            self.yang_name = "server-private"
                            self.yang_parent_name = "radius"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("key", ("key", Native.Aaa.Group.Server.Radius.ServerPrivate.Key))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str','str','str'])),
                                ('auth_port', (YLeaf(YType.uint16, 'auth-port'), ['int'])),
                                ('acct_port', (YLeaf(YType.uint16, 'acct-port'), ['int'])),
                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                                ('retransmit', (YLeaf(YType.uint8, 'retransmit'), ['int'])),
                            ])
                            self.name = None
                            self.auth_port = None
                            self.acct_port = None
                            self.timeout = None
                            self.retransmit = None

                            self.key = Native.Aaa.Group.Server.Radius.ServerPrivate.Key()
                            self.key.parent = self
                            self._children_name_map["key"] = "key"
                            self._segment_path = lambda: "server-private" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Group.Server.Radius.ServerPrivate, ['name', 'auth_port', 'acct_port', 'timeout', 'retransmit'], name, value)


                        class Key(Entity):
                            """
                            per\-server encryption key (overrides default)
                            
                            .. attribute:: encryption
                            
                            	
                            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.ServerPrivate.Key.Encryption>`
                            
                            .. attribute:: key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Radius.ServerPrivate.Key, self).__init__()

                                self.yang_name = "key"
                                self.yang_parent_name = "server-private"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Group.Server.Radius.ServerPrivate.Key.Encryption')])),
                                    ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ])
                                self.encryption = None
                                self.key = None
                                self._segment_path = lambda: "key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Radius.ServerPrivate.Key, ['encryption', 'key'], name, value)

                            class Encryption(Enum):
                                """
                                Encryption (Enum Class)

                                .. data:: Y_0 = 0

                                .. data:: Y_6 = 1

                                .. data:: Y_7 = 2

                                """

                                Y_0 = Enum.YLeaf(0, "0")

                                Y_6 = Enum.YLeaf(1, "6")

                                Y_7 = Enum.YLeaf(2, "7")



                    class Ip(Entity):
                        """
                        Internet Protocol config commands
                        
                        .. attribute:: radius
                        
                        	RADIUS configuration commands
                        	**type**\:  :py:class:`Radius_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Ip.Radius_>`
                        
                        .. attribute:: vrf
                        
                        	Set VPN Routing Forwarding to use with the servers
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Ip.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Group.Server.Radius.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "radius"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("radius", ("radius", Native.Aaa.Group.Server.Radius.Ip.Radius_)), ("vrf", ("vrf", Native.Aaa.Group.Server.Radius.Ip.Vrf))])
                            self._leafs = OrderedDict()

                            self.radius = Native.Aaa.Group.Server.Radius.Ip.Radius_()
                            self.radius.parent = self
                            self._children_name_map["radius"] = "radius"

                            self.vrf = Native.Aaa.Group.Server.Radius.Ip.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Group.Server.Radius.Ip, [], name, value)


                        class Radius_(Entity):
                            """
                            RADIUS configuration commands
                            
                            .. attribute:: source_interface
                            
                            	Specify interface for source address in RADIUS packets
                            	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Radius.Ip.Radius_, self).__init__()

                                self.yang_name = "radius"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source-interface", ("source_interface", Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface))])
                                self._leafs = OrderedDict()

                                self.source_interface = Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface()
                                self.source_interface.parent = self
                                self._children_name_map["source_interface"] = "source-interface"
                                self._segment_path = lambda: "radius"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Radius.Ip.Radius_, [], name, value)


                            class SourceInterface(Entity):
                                """
                                Specify interface for source address in RADIUS packets
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface, self).__init__()

                                    self.yang_name = "source-interface"
                                    self.yang_parent_name = "radius"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "source-interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "source-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "source-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "source-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "source-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Group.Server.Radius.Ip.Radius_.SourceInterface.PortChannelSubinterface, [u'port_channel'], name, value)


                        class Vrf(Entity):
                            """
                            Set VPN Routing Forwarding to use with the servers
                            
                            .. attribute:: forwarding
                            
                            	Configure forwarding table
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Radius.Ip.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('forwarding', (YLeaf(YType.str, 'forwarding'), ['str'])),
                                ])
                                self.forwarding = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Radius.Ip.Vrf, ['forwarding'], name, value)


                    class LoadBalance(Entity):
                        """
                        Server group load\-balancing options.
                        
                        .. attribute:: method
                        
                        	Method by which the next host will be picked
                        	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.LoadBalance.Method>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Group.Server.Radius.LoadBalance, self).__init__()

                            self.yang_name = "load-balance"
                            self.yang_parent_name = "radius"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("method", ("method", Native.Aaa.Group.Server.Radius.LoadBalance.Method))])
                            self._leafs = OrderedDict()

                            self.method = Native.Aaa.Group.Server.Radius.LoadBalance.Method()
                            self.method.parent = self
                            self._children_name_map["method"] = "method"
                            self._segment_path = lambda: "load-balance"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Group.Server.Radius.LoadBalance, [], name, value)


                        class Method(Entity):
                            """
                            Method by which the next host will be picked.
                            
                            .. attribute:: least_outstanding
                            
                            	Pick the server with the least transactions outstanding
                            	**type**\:  :py:class:`LeastOutstanding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Group.Server.Radius.LoadBalance.Method.LeastOutstanding>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Group.Server.Radius.LoadBalance.Method, self).__init__()

                                self.yang_name = "method"
                                self.yang_parent_name = "load-balance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("least-outstanding", ("least_outstanding", Native.Aaa.Group.Server.Radius.LoadBalance.Method.LeastOutstanding))])
                                self._leafs = OrderedDict()

                                self.least_outstanding = None
                                self._children_name_map["least_outstanding"] = "least-outstanding"
                                self._segment_path = lambda: "method"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Group.Server.Radius.LoadBalance.Method, [], name, value)


                            class LeastOutstanding(Entity):
                                """
                                Pick the server with the least transactions outstanding.
                                
                                .. attribute:: batch_size
                                
                                	Size of the transaction batch that should be load\-balanced
                                	**type**\: int
                                
                                	**range:** 1..2147483647
                                
                                .. attribute:: ignore_preferred_server
                                
                                	Should the preferred\-server be ignored
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Group.Server.Radius.LoadBalance.Method.LeastOutstanding, self).__init__()

                                    self.yang_name = "least-outstanding"
                                    self.yang_parent_name = "method"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('batch_size', (YLeaf(YType.uint32, 'batch-size'), ['int'])),
                                        ('ignore_preferred_server', (YLeaf(YType.empty, 'ignore-preferred-server'), ['Empty'])),
                                    ])
                                    self.batch_size = None
                                    self.ignore_preferred_server = None
                                    self._segment_path = lambda: "least-outstanding"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Group.Server.Radius.LoadBalance.Method.LeastOutstanding, ['batch_size', 'ignore_preferred_server'], name, value)


        class Attribute(Entity):
            """
            AAA attribute definitions
            
            .. attribute:: list
            
            	AAA attribute list definition
            	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Attribute.List>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Aaa.Attribute, self).__init__()

                self.yang_name = "attribute"
                self.yang_parent_name = "aaa"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("list", ("list", Native.Aaa.Attribute.List))])
                self._leafs = OrderedDict()

                self.list = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:attribute"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Aaa.Attribute, [], name, value)


            class List(Entity):
                """
                AAA attribute list definition
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: attribute
                
                	Specify an AAA attribute
                	**type**\:  :py:class:`Attribute_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Attribute.List.Attribute_>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Attribute.List, self).__init__()

                    self.yang_name = "list"
                    self.yang_parent_name = "attribute"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("attribute", ("attribute", Native.Aaa.Attribute.List.Attribute_))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.attribute = Native.Aaa.Attribute.List.Attribute_()
                    self.attribute.parent = self
                    self._children_name_map["attribute"] = "attribute"
                    self._segment_path = lambda: "list" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:attribute/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Attribute.List, ['name'], name, value)


                class Attribute_(Entity):
                    """
                    Specify an AAA attribute
                    
                    .. attribute:: type
                    
                    	Specify an AAA attribute type
                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Attribute.List.Attribute_.Type>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Attribute.List.Attribute_, self).__init__()

                        self.yang_name = "attribute"
                        self.yang_parent_name = "list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("type", ("type", Native.Aaa.Attribute.List.Attribute_.Type))])
                        self._leafs = OrderedDict()

                        self.type = Native.Aaa.Attribute.List.Attribute_.Type()
                        self.type.parent = self
                        self._children_name_map["type"] = "type"
                        self._segment_path = lambda: "attribute"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Attribute.List.Attribute_, [], name, value)


                    class Type(Entity):
                        """
                        Specify an AAA attribute type
                        
                        .. attribute:: password
                        
                        	The password of the user to be authenticated \\ string of hex characters
                        	**type**\: str
                        
                        .. attribute:: mandatory
                        
                        	Specify an AAA attribute as mandatory
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tag
                        
                        	Specify an AAA attribute tag
                        	**type**\: int
                        
                        	**range:** 1..31
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Attribute.List.Attribute_.Type, self).__init__()

                            self.yang_name = "type"
                            self.yang_parent_name = "attribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                ('mandatory', (YLeaf(YType.empty, 'mandatory'), ['Empty'])),
                                ('tag', (YLeaf(YType.uint8, 'tag'), ['int'])),
                            ])
                            self.password = None
                            self.mandatory = None
                            self.tag = None
                            self._segment_path = lambda: "type"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Attribute.List.Attribute_.Type, ['password', 'mandatory', 'tag'], name, value)


        class Authentication(Entity):
            """
            Authentication configurations parameters.
            
            .. attribute:: attempts
            
            	Set the maximum number of authentication attempts
            	**type**\:  :py:class:`Attempts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Attempts>`
            
            .. attribute:: dot1x
            
            	Set authentication lists for IEEE 802.1x
            	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Dot1x>`
            
            .. attribute:: enable
            
            	Set authentication list for enable
            	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Enable>`
            
            .. attribute:: eou
            
            	Set authentication lists for EAPoUDP
            	**type**\:  :py:class:`Eou <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Eou>`
            
            .. attribute:: login
            
            	Set authentication lists for logins
            	**type**\: list of  		 :py:class:`Login <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login>`
            
            .. attribute:: onep
            
            	Set authentication lists for ONEP
            	**type**\:  :py:class:`Onep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Onep>`
            
            .. attribute:: ppp
            
            	Set authentication lists for ppp
            	**type**\: list of  		 :py:class:`Ppp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Aaa.Authentication, self).__init__()

                self.yang_name = "authentication"
                self.yang_parent_name = "aaa"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("attempts", ("attempts", Native.Aaa.Authentication.Attempts)), ("dot1x", ("dot1x", Native.Aaa.Authentication.Dot1x)), ("enable", ("enable", Native.Aaa.Authentication.Enable)), ("eou", ("eou", Native.Aaa.Authentication.Eou)), ("login", ("login", Native.Aaa.Authentication.Login)), ("onep", ("onep", Native.Aaa.Authentication.Onep)), ("ppp", ("ppp", Native.Aaa.Authentication.Ppp))])
                self._leafs = OrderedDict()

                self.attempts = Native.Aaa.Authentication.Attempts()
                self.attempts.parent = self
                self._children_name_map["attempts"] = "attempts"

                self.dot1x = Native.Aaa.Authentication.Dot1x()
                self.dot1x.parent = self
                self._children_name_map["dot1x"] = "dot1x"

                self.enable = Native.Aaa.Authentication.Enable()
                self.enable.parent = self
                self._children_name_map["enable"] = "enable"

                self.eou = Native.Aaa.Authentication.Eou()
                self.eou.parent = self
                self._children_name_map["eou"] = "eou"

                self.onep = Native.Aaa.Authentication.Onep()
                self.onep.parent = self
                self._children_name_map["onep"] = "onep"

                self.login = YList(self)
                self.ppp = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:authentication"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Aaa.Authentication, [], name, value)


            class Attempts(Entity):
                """
                Set the maximum number of authentication attempts
                
                .. attribute:: login
                
                	Set the max. number of attempts for login service
                	**type**\: int
                
                	**range:** 1..25
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authentication.Attempts, self).__init__()

                    self.yang_name = "attempts"
                    self.yang_parent_name = "authentication"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('login', (YLeaf(YType.uint8, 'login'), ['int'])),
                    ])
                    self.login = None
                    self._segment_path = lambda: "attempts"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authentication.Attempts, ['login'], name, value)


            class Dot1x(Entity):
                """
                Set authentication lists for IEEE 802.1x.
                
                .. attribute:: dot1x_list
                
                	
                	**type**\: list of  		 :py:class:`Dot1xList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Dot1x.Dot1xList>`
                
                .. attribute:: default
                
                	The default authentication list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Dot1x.Default>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authentication.Dot1x, self).__init__()

                    self.yang_name = "dot1x"
                    self.yang_parent_name = "authentication"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dot1x-list", ("dot1x_list", Native.Aaa.Authentication.Dot1x.Dot1xList)), ("default", ("default", Native.Aaa.Authentication.Dot1x.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Authentication.Dot1x.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.dot1x_list = YList(self)
                    self._segment_path = lambda: "dot1x"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authentication.Dot1x, [], name, value)


                class Dot1xList(Entity):
                    """
                    
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Dot1x.Default.Group>`
                    
                    .. attribute:: local
                    
                    	Use local username authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cache
                    
                    	Use Cased\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Dot1x.Default.Cache>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Dot1x.Dot1xList, self).__init__()

                        self.yang_name = "dot1x-list"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Dot1x.Default.Group')])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Dot1x.Default.Cache')])),
                        ])
                        self.name = None
                        self.group = None
                        self.local = None
                        self.cache = None
                        self._segment_path = lambda: "dot1x-list" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/dot1x/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Dot1x.Dot1xList, ['name', 'group', 'local', 'cache'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cased\-group

                        .. data:: radius = 0

                        .. data:: ldap = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        ldap = Enum.YLeaf(1, "ldap")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: ldap = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        ldap = Enum.YLeaf(1, "ldap")



                class Default(Entity):
                    """
                    The default authentication list.
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Dot1x.Default.Group>`
                    
                    .. attribute:: local
                    
                    	Use local username authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cache
                    
                    	Use Cased\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Dot1x.Default.Cache>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Dot1x.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Dot1x.Default.Group')])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Dot1x.Default.Cache')])),
                        ])
                        self.group = None
                        self.local = None
                        self.cache = None
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/dot1x/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Dot1x.Default, ['group', 'local', 'cache'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cased\-group

                        .. data:: radius = 0

                        .. data:: ldap = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        ldap = Enum.YLeaf(1, "ldap")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: ldap = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        ldap = Enum.YLeaf(1, "ldap")



            class Enable(Entity):
                """
                Set authentication list for enable.
                
                .. attribute:: default
                
                	The default authentication list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Enable.Default>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authentication.Enable, self).__init__()

                    self.yang_name = "enable"
                    self.yang_parent_name = "authentication"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Authentication.Enable.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Authentication.Enable.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "enable"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authentication.Enable, [], name, value)


                class Default(Entity):
                    """
                    The default authentication list.
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Enable.Default.Group>`
                    
                    .. attribute:: enable
                    
                    	Use enable password for authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: line
                    
                    	Use line password for authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: none
                    
                    	No authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Enable.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "enable"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Enable.Default.Group')])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('line', (YLeaf(YType.empty, 'line'), ['Empty'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ])
                        self.group = None
                        self.enable = None
                        self.line = None
                        self.none = None
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/enable/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Enable.Default, ['group', 'enable', 'line', 'none'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



            class Eou(Entity):
                """
                Set authentication lists for EAPoUDP
                
                .. attribute:: default
                
                	The default authentication list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Eou.Default>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authentication.Eou, self).__init__()

                    self.yang_name = "eou"
                    self.yang_parent_name = "authentication"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Authentication.Eou.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Authentication.Eou.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "eou"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authentication.Eou, [], name, value)


                class Default(Entity):
                    """
                    The default authentication list
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Eou.Default.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Eou.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "eou"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group", ("group", Native.Aaa.Authentication.Eou.Default.Group))])
                        self._leafs = OrderedDict()

                        self.group = Native.Aaa.Authentication.Eou.Default.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/eou/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Eou.Default, [], name, value)


                    class Group(Entity):
                        """
                        Use Server\-group
                        
                        .. attribute:: radius
                        
                        	Use list of all Radius hosts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Authentication.Eou.Default.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('radius', (YLeaf(YType.empty, 'radius'), ['Empty'])),
                            ])
                            self.radius = None
                            self._segment_path = lambda: "group"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/eou/default/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Authentication.Eou.Default.Group, ['radius'], name, value)


            class Login(Entity):
                """
                Set authentication lists for logins.
                
                .. attribute:: name  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.Name>`
                
                		**type**\: str
                
                			**length:** 1..31
                
                .. attribute:: a1
                
                	
                	**type**\:  :py:class:`A1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A1>`
                
                .. attribute:: a2
                
                	
                	**type**\:  :py:class:`A2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A2>`
                
                .. attribute:: a3
                
                	
                	**type**\:  :py:class:`A3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A3>`
                
                .. attribute:: a4
                
                	
                	**type**\:  :py:class:`A4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A4>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authentication.Login, self).__init__()

                    self.yang_name = "login"
                    self.yang_parent_name = "authentication"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("a1", ("a1", Native.Aaa.Authentication.Login.A1)), ("a2", ("a2", Native.Aaa.Authentication.Login.A2)), ("a3", ("a3", Native.Aaa.Authentication.Login.A3)), ("a4", ("a4", Native.Aaa.Authentication.Login.A4))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Login.Name'),'str'])),
                    ])
                    self.name = None

                    self.a1 = Native.Aaa.Authentication.Login.A1()
                    self.a1.parent = self
                    self._children_name_map["a1"] = "a1"

                    self.a2 = Native.Aaa.Authentication.Login.A2()
                    self.a2.parent = self
                    self._children_name_map["a2"] = "a2"

                    self.a3 = Native.Aaa.Authentication.Login.A3()
                    self.a3.parent = self
                    self._children_name_map["a3"] = "a3"

                    self.a4 = Native.Aaa.Authentication.Login.A4()
                    self.a4.parent = self
                    self._children_name_map["a4"] = "a4"
                    self._segment_path = lambda: "login" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authentication.Login, ['name'], name, value)

                class Name(Enum):
                    """
                    Name (Enum Class)

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")



                class A1(Entity):
                    """
                    
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5
                    
                    	Use Kerberos 5 authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5_telnet
                    
                    	Allow logins only if already authenticated via Kerbero
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: line
                    
                    	Use line password for authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Use enable password for authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	Use local username authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local_case
                    
                    	Use case\-sensitive local username authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A1.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A1.Cache>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Login.A1, self).__init__()

                        self.yang_name = "a1"
                        self.yang_parent_name = "login"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('krb5', (YLeaf(YType.empty, 'krb5'), ['Empty'])),
                            ('krb5_telnet', (YLeaf(YType.empty, 'krb5-telnet'), ['Empty'])),
                            ('line', (YLeaf(YType.empty, 'line'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('local_case', (YLeaf(YType.empty, 'local-case'), ['Empty'])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Login.A1.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Login.A1.Cache')])),
                        ])
                        self.none = None
                        self.krb5 = None
                        self.krb5_telnet = None
                        self.line = None
                        self.enable = None
                        self.local = None
                        self.local_case = None
                        self.group = None
                        self.cache = None
                        self._segment_path = lambda: "a1"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Login.A1, ['none', 'krb5', 'krb5_telnet', 'line', 'enable', 'local', 'local_case', 'group', 'cache'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")



                class A2(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A2.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A2.Cache>`
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5_telnet
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: line
                    
                    	Use line password for authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Use enable password for authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local_case
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Login.A2, self).__init__()

                        self.yang_name = "a2"
                        self.yang_parent_name = "login"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Login.A2.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Login.A2.Cache')])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('krb5', (YLeaf(YType.empty, 'krb5'), ['Empty'])),
                            ('krb5_telnet', (YLeaf(YType.empty, 'krb5-telnet'), ['Empty'])),
                            ('line', (YLeaf(YType.empty, 'line'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('local_case', (YLeaf(YType.empty, 'local-case'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.none = None
                        self.krb5 = None
                        self.krb5_telnet = None
                        self.line = None
                        self.enable = None
                        self.local = None
                        self.local_case = None
                        self._segment_path = lambda: "a2"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Login.A2, ['group', 'cache', 'none', 'krb5', 'krb5_telnet', 'line', 'enable', 'local', 'local_case'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")



                class A3(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A3.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A3.Cache>`
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5_telnet
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: line
                    
                    	Use line password for authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Use enable password for authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local_case
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Login.A3, self).__init__()

                        self.yang_name = "a3"
                        self.yang_parent_name = "login"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Login.A3.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Login.A3.Cache')])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('krb5', (YLeaf(YType.empty, 'krb5'), ['Empty'])),
                            ('krb5_telnet', (YLeaf(YType.empty, 'krb5-telnet'), ['Empty'])),
                            ('line', (YLeaf(YType.empty, 'line'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('local_case', (YLeaf(YType.empty, 'local-case'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.none = None
                        self.krb5 = None
                        self.krb5_telnet = None
                        self.line = None
                        self.enable = None
                        self.local = None
                        self.local_case = None
                        self._segment_path = lambda: "a3"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Login.A3, ['group', 'cache', 'none', 'krb5', 'krb5_telnet', 'line', 'enable', 'local', 'local_case'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")



                class A4(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A4.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Login.A4.Cache>`
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5_telnet
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: line
                    
                    	Use line password for authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Use enable password for authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local_case
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Login.A4, self).__init__()

                        self.yang_name = "a4"
                        self.yang_parent_name = "login"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Login.A4.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Login.A4.Cache')])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('krb5', (YLeaf(YType.empty, 'krb5'), ['Empty'])),
                            ('krb5_telnet', (YLeaf(YType.empty, 'krb5-telnet'), ['Empty'])),
                            ('line', (YLeaf(YType.empty, 'line'), ['Empty'])),
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('local_case', (YLeaf(YType.empty, 'local-case'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.none = None
                        self.krb5 = None
                        self.krb5_telnet = None
                        self.line = None
                        self.enable = None
                        self.local = None
                        self.local_case = None
                        self._segment_path = lambda: "a4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Login.A4, ['group', 'cache', 'none', 'krb5', 'krb5_telnet', 'line', 'enable', 'local', 'local_case'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")



            class Onep(Entity):
                """
                Set authentication lists for ONEP
                
                .. attribute:: default
                
                	The default authentication list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Onep.Default>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authentication.Onep, self).__init__()

                    self.yang_name = "onep"
                    self.yang_parent_name = "authentication"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Authentication.Onep.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Authentication.Onep.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "onep"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authentication.Onep, [], name, value)


                class Default(Entity):
                    """
                    The default authentication list.
                    
                    .. attribute:: local
                    
                    	Use local username authentication
                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Onep.Default.Local>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Onep.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "onep"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("local", ("local", Native.Aaa.Authentication.Onep.Default.Local))])
                        self._leafs = OrderedDict()

                        self.local = None
                        self._children_name_map["local"] = "local"
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/onep/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Onep.Default, [], name, value)


                    class Local(Entity):
                        """
                        Use local username authentication.
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Authentication.Onep.Default.Local, self).__init__()

                            self.yang_name = "local"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "local"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/onep/default/%s" % self._segment_path()
                            self._is_frozen = True


            class Ppp(Entity):
                """
                Set authentication lists for ppp.
                
                .. attribute:: id  (key)
                
                	
                	**type**\: str
                
                	**length:** 1..31
                
                .. attribute:: a1
                
                	
                	**type**\:  :py:class:`A1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A1>`
                
                .. attribute:: a2
                
                	
                	**type**\:  :py:class:`A2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A2>`
                
                .. attribute:: a3
                
                	
                	**type**\:  :py:class:`A3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A3>`
                
                .. attribute:: a4
                
                	
                	**type**\:  :py:class:`A4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A4>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authentication.Ppp, self).__init__()

                    self.yang_name = "ppp"
                    self.yang_parent_name = "authentication"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("a1", ("a1", Native.Aaa.Authentication.Ppp.A1)), ("a2", ("a2", Native.Aaa.Authentication.Ppp.A2)), ("a3", ("a3", Native.Aaa.Authentication.Ppp.A3)), ("a4", ("a4", Native.Aaa.Authentication.Ppp.A4))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                    ])
                    self.id = None

                    self.a1 = Native.Aaa.Authentication.Ppp.A1()
                    self.a1.parent = self
                    self._children_name_map["a1"] = "a1"

                    self.a2 = Native.Aaa.Authentication.Ppp.A2()
                    self.a2.parent = self
                    self._children_name_map["a2"] = "a2"

                    self.a3 = Native.Aaa.Authentication.Ppp.A3()
                    self.a3.parent = self
                    self._children_name_map["a3"] = "a3"

                    self.a4 = Native.Aaa.Authentication.Ppp.A4()
                    self.a4.parent = self
                    self._children_name_map["a4"] = "a4"
                    self._segment_path = lambda: "ppp" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authentication/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authentication.Ppp, ['id'], name, value)


                class A1(Entity):
                    """
                    
                    
                    .. attribute:: if_needed
                    
                    	Only authenticate if needed
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5
                    
                    	Use Kerberos 5 authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	Use local username authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local_case
                    
                    	Use case\-sensitive local username authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A1.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A1.Cache>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Ppp.A1, self).__init__()

                        self.yang_name = "a1"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('if_needed', (YLeaf(YType.empty, 'if-needed'), ['Empty'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('krb5', (YLeaf(YType.empty, 'krb5'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('local_case', (YLeaf(YType.empty, 'local-case'), ['Empty'])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Ppp.A1.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Ppp.A1.Cache')])),
                        ])
                        self.if_needed = None
                        self.none = None
                        self.krb5 = None
                        self.local = None
                        self.local_case = None
                        self.group = None
                        self.cache = None
                        self._segment_path = lambda: "a1"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Ppp.A1, ['if_needed', 'none', 'krb5', 'local', 'local_case', 'group', 'cache'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



                class A2(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A2.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A2.Cache>`
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local_case
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Ppp.A2, self).__init__()

                        self.yang_name = "a2"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Ppp.A2.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Ppp.A2.Cache')])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('krb5', (YLeaf(YType.empty, 'krb5'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('local_case', (YLeaf(YType.empty, 'local-case'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.none = None
                        self.krb5 = None
                        self.local = None
                        self.local_case = None
                        self._segment_path = lambda: "a2"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Ppp.A2, ['group', 'cache', 'none', 'krb5', 'local', 'local_case'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



                class A3(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A3.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A3.Cache>`
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local_case
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Ppp.A3, self).__init__()

                        self.yang_name = "a3"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Ppp.A3.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Ppp.A3.Cache')])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('krb5', (YLeaf(YType.empty, 'krb5'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('local_case', (YLeaf(YType.empty, 'local-case'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.none = None
                        self.krb5 = None
                        self.local = None
                        self.local_case = None
                        self._segment_path = lambda: "a3"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Ppp.A3, ['group', 'cache', 'none', 'krb5', 'local', 'local_case'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



                class A4(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A4.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authentication.Ppp.A4.Cache>`
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local_case
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authentication.Ppp.A4, self).__init__()

                        self.yang_name = "a4"
                        self.yang_parent_name = "ppp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Ppp.A4.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authentication.Ppp.A4.Cache')])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('krb5', (YLeaf(YType.empty, 'krb5'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('local_case', (YLeaf(YType.empty, 'local-case'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.none = None
                        self.krb5 = None
                        self.local = None
                        self.local_case = None
                        self._segment_path = lambda: "a4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authentication.Ppp.A4, ['group', 'cache', 'none', 'krb5', 'local', 'local_case'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



        class Local(Entity):
            """
            AAA Local method options
            
            .. attribute:: authentication
            
            	Local authentication options
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Local.Authentication>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Aaa.Local, self).__init__()

                self.yang_name = "local"
                self.yang_parent_name = "aaa"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Aaa.Local.Authentication))])
                self._leafs = OrderedDict()

                self.authentication = Native.Aaa.Local.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "authentication"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:local"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Aaa.Local, [], name, value)


            class Authentication(Entity):
                """
                Local authentication options
                
                .. attribute:: authorization
                
                	
                	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Local.Authentication.Authorization>`
                
                .. attribute:: attempts
                
                	Local authentication attempts
                	**type**\:  :py:class:`Attempts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Local.Authentication.Attempts>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Local.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "local"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authorization", ("authorization", Native.Aaa.Local.Authentication.Authorization)), ("attempts", ("attempts", Native.Aaa.Local.Authentication.Attempts))])
                    self._leafs = OrderedDict()

                    self.authorization = Native.Aaa.Local.Authentication.Authorization()
                    self.authorization.parent = self
                    self._children_name_map["authorization"] = "authorization"

                    self.attempts = Native.Aaa.Local.Authentication.Attempts()
                    self.attempts.parent = self
                    self._children_name_map["attempts"] = "attempts"
                    self._segment_path = lambda: "authentication"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:local/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Local.Authentication, [], name, value)


                class Authorization(Entity):
                    """
                    
                    
                    .. attribute:: authen_type
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\:  :py:class:`AuthenType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Local.Authentication.Authorization.AuthenType>`
                    
                    		**type**\: str
                    
                    .. attribute:: authorization
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\:  :py:class:`Authorization_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Local.Authentication.Authorization.Authorization_>`
                    
                    		**type**\: str
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Local.Authentication.Authorization, self).__init__()

                        self.yang_name = "authorization"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('authen_type', (YLeaf(YType.str, 'authen-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Local.Authentication.Authorization.AuthenType'),'str'])),
                            ('authorization', (YLeaf(YType.str, 'authorization'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Local.Authentication.Authorization.Authorization_'),'str'])),
                        ])
                        self.authen_type = None
                        self.authorization = None
                        self._segment_path = lambda: "authorization"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:local/authentication/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Local.Authentication.Authorization, ['authen_type', 'authorization'], name, value)

                    class AuthenType(Enum):
                        """
                        AuthenType (Enum Class)

                        .. data:: default = 0

                        """

                        default = Enum.YLeaf(0, "default")


                    class Authorization_(Enum):
                        """
                        Authorization\_ (Enum Class)

                        .. data:: default = 0

                        """

                        default = Enum.YLeaf(0, "default")



                class Attempts(Entity):
                    """
                    Local authentication attempts
                    
                    .. attribute:: max_fail
                    
                    	Max failed attempts to lock the user
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Local.Authentication.Attempts, self).__init__()

                        self.yang_name = "attempts"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_fail', (YLeaf(YType.uint16, 'max-fail'), ['int'])),
                        ])
                        self.max_fail = None
                        self._segment_path = lambda: "attempts"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:local/authentication/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Local.Authentication.Attempts, ['max_fail'], name, value)


        class Authorization(Entity):
            """
            Authorization configurations parameters.
            
            .. attribute:: auth_type
            
            	For Authentication Proxy Services
            	**type**\:  :py:class:`AuthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.AuthType>`
            
            .. attribute:: commands
            
            	For exec (shell) commands
            	**type**\: list of  		 :py:class:`Commands <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Commands>`
            
            .. attribute:: console
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: config_commands
            
            	For configuration mode commands
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: configuration
            
            	For downloading configurations from AAA server
            	**type**\:  :py:class:`Configuration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Configuration>`
            
            .. attribute:: credential_download
            
            	For downloading EAP credential from Local/RADIUS/LDAP
            	**type**\:  :py:class:`CredentialDownload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.CredentialDownload>`
            
            .. attribute:: exec_
            
            	For starting an exec (shell)
            	**type**\: list of  		 :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec>`
            
            .. attribute:: eventmanager
            
            	For starting an exec (shell)
            	**type**\: list of  		 :py:class:`Eventmanager <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Eventmanager>`
            
            .. attribute:: network
            
            	For network services. (PPP, SLIP, ARAP)
            	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network>`
            
            .. attribute:: auth_proxy
            
            	For Authentication Proxy Services
            	**type**\:  :py:class:`AuthProxy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.AuthProxy>`
            
            .. attribute:: onep
            
            	Set authorization lists for ONEP
            	**type**\:  :py:class:`Onep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Onep>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Aaa.Authorization, self).__init__()

                self.yang_name = "authorization"
                self.yang_parent_name = "aaa"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("auth-type", ("auth_type", Native.Aaa.Authorization.AuthType)), ("commands", ("commands", Native.Aaa.Authorization.Commands)), ("configuration", ("configuration", Native.Aaa.Authorization.Configuration)), ("credential-download", ("credential_download", Native.Aaa.Authorization.CredentialDownload)), ("exec", ("exec_", Native.Aaa.Authorization.Exec)), ("eventmanager", ("eventmanager", Native.Aaa.Authorization.Eventmanager)), ("network", ("network", Native.Aaa.Authorization.Network)), ("auth-proxy", ("auth_proxy", Native.Aaa.Authorization.AuthProxy)), ("onep", ("onep", Native.Aaa.Authorization.Onep))])
                self._leafs = OrderedDict([
                    ('console', (YLeaf(YType.empty, 'console'), ['Empty'])),
                    ('config_commands', (YLeaf(YType.empty, 'config-commands'), ['Empty'])),
                ])
                self.console = None
                self.config_commands = None

                self.auth_type = Native.Aaa.Authorization.AuthType()
                self.auth_type.parent = self
                self._children_name_map["auth_type"] = "auth-type"

                self.configuration = Native.Aaa.Authorization.Configuration()
                self.configuration.parent = self
                self._children_name_map["configuration"] = "configuration"

                self.credential_download = Native.Aaa.Authorization.CredentialDownload()
                self.credential_download.parent = self
                self._children_name_map["credential_download"] = "credential-download"

                self.auth_proxy = Native.Aaa.Authorization.AuthProxy()
                self.auth_proxy.parent = self
                self._children_name_map["auth_proxy"] = "auth-proxy"

                self.onep = Native.Aaa.Authorization.Onep()
                self.onep.parent = self
                self._children_name_map["onep"] = "onep"

                self.commands = YList(self)
                self.exec_ = YList(self)
                self.eventmanager = YList(self)
                self.network = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:authorization"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Aaa.Authorization, ['console', 'config_commands'], name, value)


            class AuthType(Entity):
                """
                For Authentication Proxy Services
                
                .. attribute:: default
                
                	The default authorization list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.AuthType.Default>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authorization.AuthType, self).__init__()

                    self.yang_name = "auth-type"
                    self.yang_parent_name = "authorization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Authorization.AuthType.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Authorization.AuthType.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "auth-type"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authorization.AuthType, [], name, value)


                class Default(Entity):
                    """
                    The default authorization list.
                    
                    .. attribute:: group
                    
                    	Use server\-group
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.AuthType.Default.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.AuthType.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "auth-type"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.enumeration, 'group'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.AuthType.Default.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/auth-type/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.AuthType.Default, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use server\-group.

                        .. data:: radius = 0

                        """

                        radius = Enum.YLeaf(0, "radius")



            class Commands(Entity):
                """
                For exec (shell) commands.
                
                .. attribute:: level  (key)
                
                	Enable level
                	**type**\: int
                
                	**range:** 0..15
                
                .. attribute:: list_name  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\:  :py:class:`ListName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Commands.ListName>`
                
                		**type**\: str
                
                .. attribute:: group
                
                	Use server\-group
                	**type**\: union of the below types:
                
                		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Commands.Group>`
                
                		**type**\: str
                
                .. attribute:: if_authenticated
                
                	Succeed if user has authenticated
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: local
                
                	Use local database
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: none
                
                	No authorization (always succeeds)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authorization.Commands, self).__init__()

                    self.yang_name = "commands"
                    self.yang_parent_name = "authorization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['level','list_name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                        ('list_name', (YLeaf(YType.str, 'list-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Commands.ListName'),'str'])),
                        ('group', (YLeaf(YType.str, 'group'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Commands.Group'),'str'])),
                        ('if_authenticated', (YLeaf(YType.empty, 'if-authenticated'), ['Empty'])),
                        ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                    ])
                    self.level = None
                    self.list_name = None
                    self.group = None
                    self.if_authenticated = None
                    self.local = None
                    self.none = None
                    self._segment_path = lambda: "commands" + "[level='" + str(self.level) + "']" + "[list-name='" + str(self.list_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authorization.Commands, ['level', 'list_name', 'group', 'if_authenticated', 'local', 'none'], name, value)

                class Group(Enum):
                    """
                    Group (Enum Class)

                    Use server\-group.

                    .. data:: tacacs__PLUS__ = 0

                    """

                    tacacs__PLUS__ = Enum.YLeaf(0, "tacacs+")


                class ListName(Enum):
                    """
                    ListName (Enum Class)

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")



            class Configuration(Entity):
                """
                For downloading configurations from AAA server
                
                .. attribute:: default
                
                	The default authorization list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Configuration.Default>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authorization.Configuration, self).__init__()

                    self.yang_name = "configuration"
                    self.yang_parent_name = "authorization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Authorization.Configuration.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Authorization.Configuration.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "configuration"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authorization.Configuration, [], name, value)


                class Default(Entity):
                    """
                    The default authorization list.
                    
                    .. attribute:: group
                    
                    	Use server\-group
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Configuration.Default.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.Configuration.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "configuration"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group", ("group", Native.Aaa.Authorization.Configuration.Default.Group))])
                        self._leafs = OrderedDict()

                        self.group = Native.Aaa.Authorization.Configuration.Default.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/configuration/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.Configuration.Default, [], name, value)


                    class Group(Entity):
                        """
                        Use server\-group.
                        
                        .. attribute:: group_name
                        
                        	
                        	**type**\: list of  		 :py:class:`GroupName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Configuration.Default.Group.GroupName>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Authorization.Configuration.Default.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group-name", ("group_name", Native.Aaa.Authorization.Configuration.Default.Group.GroupName))])
                            self._leafs = OrderedDict()

                            self.group_name = YList(self)
                            self._segment_path = lambda: "group"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/configuration/default/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Authorization.Configuration.Default.Group, [], name, value)


                        class GroupName(Entity):
                            """
                            
                            
                            .. attribute:: group_name  (key)
                            
                            	Server\-group name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Authorization.Configuration.Default.Group.GroupName, self).__init__()

                                self.yang_name = "group-name"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['group_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                ])
                                self.group_name = None
                                self._segment_path = lambda: "group-name" + "[group-name='" + str(self.group_name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/configuration/default/group/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Authorization.Configuration.Default.Group.GroupName, ['group_name'], name, value)


            class CredentialDownload(Entity):
                """
                For downloading EAP credential from Local/RADIUS/LDAP
                
                .. attribute:: default
                
                	The default authorization list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.CredentialDownload.Default>`
                
                .. attribute:: authorization_list
                
                	Named authorization list (max 31 characters, \\ longer will be rejected)
                	**type**\: list of  		 :py:class:`AuthorizationList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.CredentialDownload.AuthorizationList>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authorization.CredentialDownload, self).__init__()

                    self.yang_name = "credential-download"
                    self.yang_parent_name = "authorization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Authorization.CredentialDownload.Default)), ("authorization-list", ("authorization_list", Native.Aaa.Authorization.CredentialDownload.AuthorizationList))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Authorization.CredentialDownload.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.authorization_list = YList(self)
                    self._segment_path = lambda: "credential-download"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authorization.CredentialDownload, [], name, value)


                class Default(Entity):
                    """
                    The default authorization list
                    
                    .. attribute:: local
                    
                    	Use local database
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.CredentialDownload.AuthorizationList.Cache>`
                    
                    .. attribute:: group
                    
                    	Use server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.CredentialDownload.AuthorizationList.Group>`
                    
                    .. attribute:: if_authenticated
                    
                    	Succeed if user has authenticated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: none
                    
                    	No authorization (always succeeds)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.CredentialDownload.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "credential-download"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.CredentialDownload.AuthorizationList.Cache')])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.CredentialDownload.AuthorizationList.Group')])),
                            ('if_authenticated', (YLeaf(YType.empty, 'if-authenticated'), ['Empty'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ])
                        self.local = None
                        self.cache = None
                        self.group = None
                        self.if_authenticated = None
                        self.none = None
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/credential-download/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.CredentialDownload.Default, ['local', 'cache', 'group', 'if_authenticated', 'none'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use server\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")



                class AuthorizationList(Entity):
                    """
                    Named authorization list (max 31 characters, \\
                    longer will be rejected)
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: local
                    
                    	Use local database
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.CredentialDownload.AuthorizationList.Cache>`
                    
                    .. attribute:: group
                    
                    	Use server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.CredentialDownload.AuthorizationList.Group>`
                    
                    .. attribute:: if_authenticated
                    
                    	Succeed if user has authenticated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: none
                    
                    	No authorization (always succeeds)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.CredentialDownload.AuthorizationList, self).__init__()

                        self.yang_name = "authorization-list"
                        self.yang_parent_name = "credential-download"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.CredentialDownload.AuthorizationList.Cache')])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.CredentialDownload.AuthorizationList.Group')])),
                            ('if_authenticated', (YLeaf(YType.empty, 'if-authenticated'), ['Empty'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ])
                        self.name = None
                        self.local = None
                        self.cache = None
                        self.group = None
                        self.if_authenticated = None
                        self.none = None
                        self._segment_path = lambda: "authorization-list" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/credential-download/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.CredentialDownload.AuthorizationList, ['name', 'local', 'cache', 'group', 'if_authenticated', 'none'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use server\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")



            class Exec(Entity):
                """
                For starting an exec (shell).
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: a1
                
                	
                	**type**\:  :py:class:`A1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A1>`
                
                .. attribute:: a2
                
                	
                	**type**\:  :py:class:`A2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A2>`
                
                .. attribute:: a3
                
                	
                	**type**\:  :py:class:`A3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A3>`
                
                .. attribute:: a4
                
                	
                	**type**\:  :py:class:`A4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A4>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authorization.Exec, self).__init__()

                    self.yang_name = "exec"
                    self.yang_parent_name = "authorization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("a1", ("a1", Native.Aaa.Authorization.Exec.A1)), ("a2", ("a2", Native.Aaa.Authorization.Exec.A2)), ("a3", ("a3", Native.Aaa.Authorization.Exec.A3)), ("a4", ("a4", Native.Aaa.Authorization.Exec.A4))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.a1 = Native.Aaa.Authorization.Exec.A1()
                    self.a1.parent = self
                    self._children_name_map["a1"] = "a1"

                    self.a2 = Native.Aaa.Authorization.Exec.A2()
                    self.a2.parent = self
                    self._children_name_map["a2"] = "a2"

                    self.a3 = Native.Aaa.Authorization.Exec.A3()
                    self.a3.parent = self
                    self._children_name_map["a3"] = "a3"

                    self.a4 = Native.Aaa.Authorization.Exec.A4()
                    self.a4.parent = self
                    self._children_name_map["a4"] = "a4"
                    self._segment_path = lambda: "exec" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authorization.Exec, ['name'], name, value)


                class A1(Entity):
                    """
                    
                    
                    .. attribute:: if_authenticated
                    
                    	Succeed if user has authenticated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: none
                    
                    	No authorization (always succeeds)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5_instance
                    
                    	Use Kerberos instance privilege maps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	Use local database
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A1.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A1.Cache>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.Exec.A1, self).__init__()

                        self.yang_name = "a1"
                        self.yang_parent_name = "exec"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('if_authenticated', (YLeaf(YType.empty, 'if-authenticated'), ['Empty'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('krb5_instance', (YLeaf(YType.empty, 'krb5-instance'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Exec.A1.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Exec.A1.Cache')])),
                        ])
                        self.if_authenticated = None
                        self.none = None
                        self.krb5_instance = None
                        self.local = None
                        self.group = None
                        self.cache = None
                        self._segment_path = lambda: "a1"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.Exec.A1, ['if_authenticated', 'none', 'krb5_instance', 'local', 'group', 'cache'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")



                class A2(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A2.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A2.Cache>`
                    
                    .. attribute:: if_authenticated
                    
                    	Succeed if user has authenticated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: none
                    
                    	No authorization (always succeeds)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5_instance
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.Exec.A2, self).__init__()

                        self.yang_name = "a2"
                        self.yang_parent_name = "exec"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Exec.A2.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Exec.A2.Cache')])),
                            ('if_authenticated', (YLeaf(YType.empty, 'if-authenticated'), ['Empty'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('krb5_instance', (YLeaf(YType.empty, 'krb5-instance'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.if_authenticated = None
                        self.none = None
                        self.krb5_instance = None
                        self.local = None
                        self._segment_path = lambda: "a2"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.Exec.A2, ['group', 'cache', 'if_authenticated', 'none', 'krb5_instance', 'local'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")



                class A3(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A3.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A3.Cache>`
                    
                    .. attribute:: none
                    
                    	No authorization (always succeeds)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: if_authenticated
                    
                    	Succeed if user has authenticated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5_instance
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.Exec.A3, self).__init__()

                        self.yang_name = "a3"
                        self.yang_parent_name = "exec"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Exec.A3.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Exec.A3.Cache')])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('if_authenticated', (YLeaf(YType.empty, 'if-authenticated'), ['Empty'])),
                            ('krb5_instance', (YLeaf(YType.empty, 'krb5-instance'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.none = None
                        self.if_authenticated = None
                        self.krb5_instance = None
                        self.local = None
                        self._segment_path = lambda: "a3"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.Exec.A3, ['group', 'cache', 'none', 'if_authenticated', 'krb5_instance', 'local'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")



                class A4(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A4.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Exec.A4.Cache>`
                    
                    .. attribute:: none
                    
                    	No authorization (always succeeds)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: if_authenticated
                    
                    	Succeed if user has authenticated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: krb5_instance
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.Exec.A4, self).__init__()

                        self.yang_name = "a4"
                        self.yang_parent_name = "exec"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Exec.A4.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Exec.A4.Cache')])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('if_authenticated', (YLeaf(YType.empty, 'if-authenticated'), ['Empty'])),
                            ('krb5_instance', (YLeaf(YType.empty, 'krb5-instance'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.none = None
                        self.if_authenticated = None
                        self.krb5_instance = None
                        self.local = None
                        self._segment_path = lambda: "a4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.Exec.A4, ['group', 'cache', 'none', 'if_authenticated', 'krb5_instance', 'local'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs__PLUS__ = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(2, "tacacs+")



            class Eventmanager(Entity):
                """
                For starting an exec (shell).
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: group
                
                	Use server\-group
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Eventmanager.Group>`
                
                .. attribute:: local
                
                	Use local database
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: none
                
                	No authorization (always succeeds)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authorization.Eventmanager, self).__init__()

                    self.yang_name = "eventmanager"
                    self.yang_parent_name = "authorization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Eventmanager.Group')])),
                        ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                    ])
                    self.name = None
                    self.group = None
                    self.local = None
                    self.none = None
                    self._segment_path = lambda: "eventmanager" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authorization.Eventmanager, ['name', 'group', 'local', 'none'], name, value)

                class Group(Enum):
                    """
                    Group (Enum Class)

                    Use server\-group.

                    .. data:: ldap = 0

                    .. data:: radius = 1

                    .. data:: tacacs = 2

                    """

                    ldap = Enum.YLeaf(0, "ldap")

                    radius = Enum.YLeaf(1, "radius")

                    tacacs = Enum.YLeaf(2, "tacacs")



            class Network(Entity):
                """
                For network services. (PPP, SLIP, ARAP)
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.Id>`
                
                		**type**\: str
                
                			**length:** 1..31
                
                .. attribute:: a1
                
                	
                	**type**\:  :py:class:`A1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A1>`
                
                .. attribute:: a2
                
                	
                	**type**\:  :py:class:`A2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A2>`
                
                .. attribute:: a3
                
                	
                	**type**\:  :py:class:`A3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A3>`
                
                .. attribute:: a4
                
                	
                	**type**\:  :py:class:`A4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A4>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authorization.Network, self).__init__()

                    self.yang_name = "network"
                    self.yang_parent_name = "authorization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("a1", ("a1", Native.Aaa.Authorization.Network.A1)), ("a2", ("a2", Native.Aaa.Authorization.Network.A2)), ("a3", ("a3", Native.Aaa.Authorization.Network.A3)), ("a4", ("a4", Native.Aaa.Authorization.Network.A4))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Network.Id'),'str'])),
                    ])
                    self.id = None

                    self.a1 = Native.Aaa.Authorization.Network.A1()
                    self.a1.parent = self
                    self._children_name_map["a1"] = "a1"

                    self.a2 = Native.Aaa.Authorization.Network.A2()
                    self.a2.parent = self
                    self._children_name_map["a2"] = "a2"

                    self.a3 = Native.Aaa.Authorization.Network.A3()
                    self.a3.parent = self
                    self._children_name_map["a3"] = "a3"

                    self.a4 = Native.Aaa.Authorization.Network.A4()
                    self.a4.parent = self
                    self._children_name_map["a4"] = "a4"
                    self._segment_path = lambda: "network" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authorization.Network, ['id'], name, value)

                class Id(Enum):
                    """
                    Id (Enum Class)

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")



                class A1(Entity):
                    """
                    
                    
                    .. attribute:: if_authenticated
                    
                    	Succeed if user has authenticated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	Use local username authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A1.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A1.Cache>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.Network.A1, self).__init__()

                        self.yang_name = "a1"
                        self.yang_parent_name = "network"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('if_authenticated', (YLeaf(YType.empty, 'if-authenticated'), ['Empty'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Network.A1.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Network.A1.Cache')])),
                        ])
                        self.if_authenticated = None
                        self.none = None
                        self.local = None
                        self.group = None
                        self.cache = None
                        self._segment_path = lambda: "a1"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.Network.A1, ['if_authenticated', 'none', 'local', 'group', 'cache'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



                class A2(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A2.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A2.Cache>`
                    
                    .. attribute:: if_authenticated
                    
                    	Succeed if user has authenticated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.Network.A2, self).__init__()

                        self.yang_name = "a2"
                        self.yang_parent_name = "network"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Network.A2.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Network.A2.Cache')])),
                            ('if_authenticated', (YLeaf(YType.empty, 'if-authenticated'), ['Empty'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.if_authenticated = None
                        self.none = None
                        self.local = None
                        self._segment_path = lambda: "a2"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.Network.A2, ['group', 'cache', 'if_authenticated', 'none', 'local'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



                class A3(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A3.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A3.Cache>`
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: if_authenticated
                    
                    	Succeed if user has authenticated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.Network.A3, self).__init__()

                        self.yang_name = "a3"
                        self.yang_parent_name = "network"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Network.A3.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Network.A3.Cache')])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('if_authenticated', (YLeaf(YType.empty, 'if-authenticated'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.none = None
                        self.if_authenticated = None
                        self.local = None
                        self._segment_path = lambda: "a3"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.Network.A3, ['group', 'cache', 'none', 'if_authenticated', 'local'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



                class A4(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A4.Group>`
                    
                    .. attribute:: cache
                    
                    	Use Cached\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Network.A4.Cache>`
                    
                    .. attribute:: none
                    
                    	NO authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: if_authenticated
                    
                    	Succeed if user has authenticated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: local
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.Network.A4, self).__init__()

                        self.yang_name = "a4"
                        self.yang_parent_name = "network"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Network.A4.Group')])),
                            ('cache', (YLeaf(YType.str, 'cache'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.Network.A4.Cache')])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('if_authenticated', (YLeaf(YType.empty, 'if-authenticated'), ['Empty'])),
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ])
                        self.group = None
                        self.cache = None
                        self.none = None
                        self.if_authenticated = None
                        self.local = None
                        self._segment_path = lambda: "a4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.Network.A4, ['group', 'cache', 'none', 'if_authenticated', 'local'], name, value)

                    class Cache(Enum):
                        """
                        Cache (Enum Class)

                        Use Cached\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



            class AuthProxy(Entity):
                """
                For Authentication Proxy Services
                
                .. attribute:: default
                
                	The default authorization list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.AuthProxy.Default>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authorization.AuthProxy, self).__init__()

                    self.yang_name = "auth-proxy"
                    self.yang_parent_name = "authorization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Authorization.AuthProxy.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Authorization.AuthProxy.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "auth-proxy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authorization.AuthProxy, [], name, value)


                class Default(Entity):
                    """
                    The default authorization list.
                    
                    .. attribute:: local
                    
                    	Local authorization
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.AuthProxy.Default.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.AuthProxy.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "auth-proxy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Authorization.AuthProxy.Default.Group')])),
                        ])
                        self.local = None
                        self.group = None
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/auth-proxy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.AuthProxy.Default, ['local', 'group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        """

                        radius = Enum.YLeaf(0, "radius")



            class Onep(Entity):
                """
                Set authorization lists for ONEP
                
                .. attribute:: default
                
                	The default authorization list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Onep.Default>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Authorization.Onep, self).__init__()

                    self.yang_name = "onep"
                    self.yang_parent_name = "authorization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Authorization.Onep.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Authorization.Onep.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "onep"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Authorization.Onep, [], name, value)


                class Default(Entity):
                    """
                    The default authorization list.
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Onep.Default.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Authorization.Onep.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "onep"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group", ("group", Native.Aaa.Authorization.Onep.Default.Group))])
                        self._leafs = OrderedDict()

                        self.group = Native.Aaa.Authorization.Onep.Default.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/onep/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Authorization.Onep.Default, [], name, value)


                    class Group(Entity):
                        """
                        Use Server\-group
                        
                        .. attribute:: group_word
                        
                        	
                        	**type**\: list of  		 :py:class:`GroupWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Authorization.Onep.Default.Group.GroupWord>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Authorization.Onep.Default.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group-word", ("group_word", Native.Aaa.Authorization.Onep.Default.Group.GroupWord))])
                            self._leafs = OrderedDict()

                            self.group_word = YList(self)
                            self._segment_path = lambda: "group"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/onep/default/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Authorization.Onep.Default.Group, [], name, value)


                        class GroupWord(Entity):
                            """
                            
                            
                            .. attribute:: group_word  (key)
                            
                            	Server\-group name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Authorization.Onep.Default.Group.GroupWord, self).__init__()

                                self.yang_name = "group-word"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['group_word']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group_word', (YLeaf(YType.str, 'group-word'), ['str'])),
                                ])
                                self.group_word = None
                                self._segment_path = lambda: "group-word" + "[group-word='" + str(self.group_word) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:authorization/onep/default/group/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Authorization.Onep.Default.Group.GroupWord, ['group_word'], name, value)


        class Accounting(Entity):
            """
            Accounting configurations parameters.
            
            .. attribute:: commands
            
            	For exec (shell) commands
            	**type**\: list of  		 :py:class:`Commands <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Commands>`
            
            .. attribute:: connection
            
            	For outbound connections. (telnet, rlogin)
            	**type**\: list of  		 :py:class:`Connection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Connection>`
            
            .. attribute:: delay_start
            
            	Delay PPP Network start record until peer IP address is known
            	**type**\:  :py:class:`DelayStart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.DelayStart>`
            
            .. attribute:: dot1x
            
            	For dot1x sessions
            	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Dot1x>`
            
            .. attribute:: identity
            
            	For identity sessions
            	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Identity>`
            
            .. attribute:: exec_
            
            	For starting an exec (shell)
            	**type**\: list of  		 :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Exec>`
            
            .. attribute:: exec_submode
            
            	
            	**type**\:  :py:class:`ExecSubmode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.ExecSubmode>`
            
            .. attribute:: network
            
            	For network services. (PPP, SLIP, ARAP)
            	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network>`
            
            .. attribute:: send
            
            	Send records to accounting server
            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Send>`
            
            .. attribute:: suppress
            
            	Do not generate accounting records for a specific type of user
            	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Suppress>`
            
            .. attribute:: system
            
            	For system events
            	**type**\:  :py:class:`System <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.System>`
            
            .. attribute:: update
            
            	Enable accounting update records
            	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Update>`
            
            .. attribute:: auth_proxy
            
            	For Authentication Proxy Services
            	**type**\:  :py:class:`AuthProxy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.AuthProxy>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Aaa.Accounting, self).__init__()

                self.yang_name = "accounting"
                self.yang_parent_name = "aaa"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("commands", ("commands", Native.Aaa.Accounting.Commands)), ("connection", ("connection", Native.Aaa.Accounting.Connection)), ("delay-start", ("delay_start", Native.Aaa.Accounting.DelayStart)), ("dot1x", ("dot1x", Native.Aaa.Accounting.Dot1x)), ("identity", ("identity", Native.Aaa.Accounting.Identity)), ("exec", ("exec_", Native.Aaa.Accounting.Exec)), ("exec-submode", ("exec_submode", Native.Aaa.Accounting.ExecSubmode)), ("network", ("network", Native.Aaa.Accounting.Network)), ("send", ("send", Native.Aaa.Accounting.Send)), ("suppress", ("suppress", Native.Aaa.Accounting.Suppress)), ("system", ("system", Native.Aaa.Accounting.System)), ("update", ("update", Native.Aaa.Accounting.Update)), ("auth-proxy", ("auth_proxy", Native.Aaa.Accounting.AuthProxy))])
                self._leafs = OrderedDict()

                self.delay_start = Native.Aaa.Accounting.DelayStart()
                self.delay_start.parent = self
                self._children_name_map["delay_start"] = "delay-start"

                self.dot1x = Native.Aaa.Accounting.Dot1x()
                self.dot1x.parent = self
                self._children_name_map["dot1x"] = "dot1x"

                self.identity = Native.Aaa.Accounting.Identity()
                self.identity.parent = self
                self._children_name_map["identity"] = "identity"

                self.exec_submode = Native.Aaa.Accounting.ExecSubmode()
                self.exec_submode.parent = self
                self._children_name_map["exec_submode"] = "exec-submode"

                self.send = Native.Aaa.Accounting.Send()
                self.send.parent = self
                self._children_name_map["send"] = "send"

                self.suppress = Native.Aaa.Accounting.Suppress()
                self.suppress.parent = self
                self._children_name_map["suppress"] = "suppress"

                self.system = Native.Aaa.Accounting.System()
                self.system.parent = self
                self._children_name_map["system"] = "system"

                self.update = Native.Aaa.Accounting.Update()
                self.update.parent = self
                self._children_name_map["update"] = "update"

                self.auth_proxy = Native.Aaa.Accounting.AuthProxy()
                self.auth_proxy.parent = self
                self._children_name_map["auth_proxy"] = "auth-proxy"

                self.commands = YList(self)
                self.connection = YList(self)
                self.exec_ = YList(self)
                self.network = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:accounting"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Aaa.Accounting, [], name, value)


            class Commands(Entity):
                """
                For exec (shell) commands.
                
                .. attribute:: level  (key)
                
                	Enable level
                	**type**\: int
                
                	**range:** 0..15
                
                .. attribute:: list_name  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\:  :py:class:`ListName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Commands.ListName>`
                
                		**type**\: str
                
                			**length:** 1..31
                
                .. attribute:: action_type
                
                	
                	**type**\:  :py:class:`ActionType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Commands.ActionType>`
                
                .. attribute:: broadcast
                
                	Use Broadcast for Accounting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: group
                
                	Use Server\-group
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Commands.Group>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.Commands, self).__init__()

                    self.yang_name = "commands"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['level','list_name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                        ('list_name', (YLeaf(YType.str, 'list-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Commands.ListName'),'str'])),
                        ('action_type', (YLeaf(YType.enumeration, 'action-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Commands.ActionType')])),
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                        ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Commands.Group')])),
                    ])
                    self.level = None
                    self.list_name = None
                    self.action_type = None
                    self.broadcast = None
                    self.group = None
                    self._segment_path = lambda: "commands" + "[level='" + str(self.level) + "']" + "[list-name='" + str(self.list_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.Commands, ['level', 'list_name', 'action_type', 'broadcast', 'group'], name, value)

                class ActionType(Enum):
                    """
                    ActionType (Enum Class)

                    .. data:: none = 0

                    .. data:: start_stop = 1

                    .. data:: stop_only = 2

                    """

                    none = Enum.YLeaf(0, "none")

                    start_stop = Enum.YLeaf(1, "start-stop")

                    stop_only = Enum.YLeaf(2, "stop-only")


                class Group(Enum):
                    """
                    Group (Enum Class)

                    Use Server\-group

                    .. data:: tacacs__PLUS__ = 0

                    """

                    tacacs__PLUS__ = Enum.YLeaf(0, "tacacs+")


                class ListName(Enum):
                    """
                    ListName (Enum Class)

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")



            class Connection(Entity):
                """
                For outbound connections. (telnet, rlogin)
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: none
                
                	No accounting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: start_stop
                
                	Record start and stop without waiting
                	**type**\:  :py:class:`StartStop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Connection.StartStop>`
                
                .. attribute:: stop_only
                
                	Record stop when service terminates
                	**type**\:  :py:class:`StopOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Connection.StopOnly>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.Connection, self).__init__()

                    self.yang_name = "connection"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("start-stop", ("start_stop", Native.Aaa.Accounting.Connection.StartStop)), ("stop-only", ("stop_only", Native.Aaa.Accounting.Connection.StopOnly))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                    ])
                    self.name = None
                    self.none = None

                    self.start_stop = Native.Aaa.Accounting.Connection.StartStop()
                    self.start_stop.parent = self
                    self._children_name_map["start_stop"] = "start-stop"

                    self.stop_only = Native.Aaa.Accounting.Connection.StopOnly()
                    self.stop_only.parent = self
                    self._children_name_map["stop_only"] = "stop-only"
                    self._segment_path = lambda: "connection" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.Connection, ['name', 'none'], name, value)


                class StartStop(Entity):
                    """
                    Record start and stop without waiting
                    
                    .. attribute:: broadcast
                    
                    	Use Broadcast for Accounting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StartStop.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Connection.StartStop, self).__init__()

                        self.yang_name = "start-stop"
                        self.yang_parent_name = "connection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.ExecSubmode.Exec.ActionType.StartStop.Group')])),
                        ])
                        self.broadcast = None
                        self.group = None
                        self._segment_path = lambda: "start-stop"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Connection.StartStop, ['broadcast', 'group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



                class StopOnly(Entity):
                    """
                    Record stop when service terminates.
                    
                    .. attribute:: broadcast
                    
                    	Use Broadcast for Accounting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StopOnly.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Connection.StopOnly, self).__init__()

                        self.yang_name = "stop-only"
                        self.yang_parent_name = "connection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.ExecSubmode.Exec.ActionType.StopOnly.Group')])),
                        ])
                        self.broadcast = None
                        self.group = None
                        self._segment_path = lambda: "stop-only"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Connection.StopOnly, ['broadcast', 'group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



            class DelayStart(Entity):
                """
                Delay PPP Network start record until peer IP address is known.
                
                .. attribute:: extended_delay
                
                	
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: all
                
                	Delay start records for all vrf and non\-vrf users
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.DelayStart, self).__init__()

                    self.yang_name = "delay-start"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('extended_delay', (YLeaf(YType.uint8, 'extended-delay'), ['int'])),
                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                    ])
                    self.extended_delay = None
                    self.all = None
                    self._segment_path = lambda: "delay-start"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.DelayStart, ['extended_delay', 'all'], name, value)


            class Dot1x(Entity):
                """
                For dot1x sessions.
                
                .. attribute:: default
                
                	The default authorization list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Dot1x.Default>`
                
                .. attribute:: accounting_list
                
                	Named authorization list (max 31 characters, \\ longer will be rejected)
                	**type**\: list of  		 :py:class:`AccountingList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Dot1x.AccountingList>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.Dot1x, self).__init__()

                    self.yang_name = "dot1x"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Accounting.Dot1x.Default)), ("accounting-list", ("accounting_list", Native.Aaa.Accounting.Dot1x.AccountingList))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Accounting.Dot1x.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.accounting_list = YList(self)
                    self._segment_path = lambda: "dot1x"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.Dot1x, [], name, value)


                class Default(Entity):
                    """
                    The default authorization list
                    
                    .. attribute:: start_stop
                    
                    	Record start and stop without waiting
                    	**type**\:  :py:class:`StartStop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Dot1x.Default.StartStop>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Dot1x.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("start-stop", ("start_stop", Native.Aaa.Accounting.Dot1x.Default.StartStop))])
                        self._leafs = OrderedDict()

                        self.start_stop = Native.Aaa.Accounting.Dot1x.Default.StartStop()
                        self.start_stop.parent = self
                        self._children_name_map["start_stop"] = "start-stop"
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/dot1x/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Dot1x.Default, [], name, value)


                    class StartStop(Entity):
                        """
                        Record start and stop without waiting
                        
                        .. attribute:: broadcast
                        
                        	Use Broadcast for Accounting
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: group
                        
                        	Use Server\-group
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Dot1x.AccountingList.StartStop.Group>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Accounting.Dot1x.Default.StartStop, self).__init__()

                            self.yang_name = "start-stop"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Dot1x.AccountingList.StartStop.Group')])),
                            ])
                            self.broadcast = None
                            self.group = None
                            self._segment_path = lambda: "start-stop"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/dot1x/default/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Accounting.Dot1x.Default.StartStop, ['broadcast', 'group'], name, value)

                        class Group(Enum):
                            """
                            Group (Enum Class)

                            Use Server\-group

                            .. data:: radius = 0

                            .. data:: tacacs__PLUS__ = 1

                            """

                            radius = Enum.YLeaf(0, "radius")

                            tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



                class AccountingList(Entity):
                    """
                    Named authorization list (max 31 characters, \\
                    longer will be rejected)
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: start_stop
                    
                    	Record start and stop without waiting
                    	**type**\:  :py:class:`StartStop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Dot1x.AccountingList.StartStop>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Dot1x.AccountingList, self).__init__()

                        self.yang_name = "accounting-list"
                        self.yang_parent_name = "dot1x"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("start-stop", ("start_stop", Native.Aaa.Accounting.Dot1x.AccountingList.StartStop))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.start_stop = Native.Aaa.Accounting.Dot1x.AccountingList.StartStop()
                        self.start_stop.parent = self
                        self._children_name_map["start_stop"] = "start-stop"
                        self._segment_path = lambda: "accounting-list" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/dot1x/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Dot1x.AccountingList, ['name'], name, value)


                    class StartStop(Entity):
                        """
                        Record start and stop without waiting
                        
                        .. attribute:: broadcast
                        
                        	Use Broadcast for Accounting
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: group
                        
                        	Use Server\-group
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Dot1x.AccountingList.StartStop.Group>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Accounting.Dot1x.AccountingList.StartStop, self).__init__()

                            self.yang_name = "start-stop"
                            self.yang_parent_name = "accounting-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Dot1x.AccountingList.StartStop.Group')])),
                            ])
                            self.broadcast = None
                            self.group = None
                            self._segment_path = lambda: "start-stop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Accounting.Dot1x.AccountingList.StartStop, ['broadcast', 'group'], name, value)

                        class Group(Enum):
                            """
                            Group (Enum Class)

                            Use Server\-group

                            .. data:: radius = 0

                            .. data:: tacacs__PLUS__ = 1

                            """

                            radius = Enum.YLeaf(0, "radius")

                            tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



            class Identity(Entity):
                """
                For identity sessions.
                
                .. attribute:: default
                
                	The default authorization list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Identity.Default>`
                
                .. attribute:: accounting_list
                
                	Named authorization list (max 31 characters, \\ longer will be rejected)
                	**type**\: list of  		 :py:class:`AccountingList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Identity.AccountingList>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.Identity, self).__init__()

                    self.yang_name = "identity"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Accounting.Identity.Default)), ("accounting-list", ("accounting_list", Native.Aaa.Accounting.Identity.AccountingList))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Accounting.Identity.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.accounting_list = YList(self)
                    self._segment_path = lambda: "identity"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.Identity, [], name, value)


                class Default(Entity):
                    """
                    The default authorization list
                    
                    .. attribute:: start_stop
                    
                    	Record start and stop without waiting
                    	**type**\:  :py:class:`StartStop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Identity.Default.StartStop>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Identity.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "identity"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("start-stop", ("start_stop", Native.Aaa.Accounting.Identity.Default.StartStop))])
                        self._leafs = OrderedDict()

                        self.start_stop = Native.Aaa.Accounting.Identity.Default.StartStop()
                        self.start_stop.parent = self
                        self._children_name_map["start_stop"] = "start-stop"
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/identity/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Identity.Default, [], name, value)


                    class StartStop(Entity):
                        """
                        Record start and stop without waiting
                        
                        .. attribute:: broadcast
                        
                        	Use Broadcast for Accounting
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: group
                        
                        	Use Server\-group
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Identity.AccountingList.StartStop.Group>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Accounting.Identity.Default.StartStop, self).__init__()

                            self.yang_name = "start-stop"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Identity.AccountingList.StartStop.Group')])),
                            ])
                            self.broadcast = None
                            self.group = None
                            self._segment_path = lambda: "start-stop"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/identity/default/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Accounting.Identity.Default.StartStop, ['broadcast', 'group'], name, value)

                        class Group(Enum):
                            """
                            Group (Enum Class)

                            Use Server\-group

                            .. data:: radius = 0

                            .. data:: tacacs__PLUS__ = 1

                            """

                            radius = Enum.YLeaf(0, "radius")

                            tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



                class AccountingList(Entity):
                    """
                    Named authorization list (max 31 characters, \\
                    longer will be rejected)
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: start_stop
                    
                    	Record start and stop without waiting
                    	**type**\:  :py:class:`StartStop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Identity.AccountingList.StartStop>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Identity.AccountingList, self).__init__()

                        self.yang_name = "accounting-list"
                        self.yang_parent_name = "identity"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("start-stop", ("start_stop", Native.Aaa.Accounting.Identity.AccountingList.StartStop))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.start_stop = Native.Aaa.Accounting.Identity.AccountingList.StartStop()
                        self.start_stop.parent = self
                        self._children_name_map["start_stop"] = "start-stop"
                        self._segment_path = lambda: "accounting-list" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/identity/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Identity.AccountingList, ['name'], name, value)


                    class StartStop(Entity):
                        """
                        Record start and stop without waiting
                        
                        .. attribute:: broadcast
                        
                        	Use Broadcast for Accounting
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: group
                        
                        	Use Server\-group
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Identity.AccountingList.StartStop.Group>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Accounting.Identity.AccountingList.StartStop, self).__init__()

                            self.yang_name = "start-stop"
                            self.yang_parent_name = "accounting-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Identity.AccountingList.StartStop.Group')])),
                            ])
                            self.broadcast = None
                            self.group = None
                            self._segment_path = lambda: "start-stop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Accounting.Identity.AccountingList.StartStop, ['broadcast', 'group'], name, value)

                        class Group(Enum):
                            """
                            Group (Enum Class)

                            Use Server\-group

                            .. data:: radius = 0

                            .. data:: tacacs__PLUS__ = 1

                            """

                            radius = Enum.YLeaf(0, "radius")

                            tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



            class Exec(Entity):
                """
                For starting an exec (shell).
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: none
                
                	No accounting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: start_stop
                
                	Record start and stop without waiting
                	**type**\:  :py:class:`StartStop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Exec.StartStop>`
                
                .. attribute:: stop_only
                
                	Record stop when service terminates
                	**type**\:  :py:class:`StopOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Exec.StopOnly>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.Exec, self).__init__()

                    self.yang_name = "exec"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("start-stop", ("start_stop", Native.Aaa.Accounting.Exec.StartStop)), ("stop-only", ("stop_only", Native.Aaa.Accounting.Exec.StopOnly))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                    ])
                    self.name = None
                    self.none = None

                    self.start_stop = Native.Aaa.Accounting.Exec.StartStop()
                    self.start_stop.parent = self
                    self._children_name_map["start_stop"] = "start-stop"

                    self.stop_only = Native.Aaa.Accounting.Exec.StopOnly()
                    self.stop_only.parent = self
                    self._children_name_map["stop_only"] = "stop-only"
                    self._segment_path = lambda: "exec" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.Exec, ['name', 'none'], name, value)


                class StartStop(Entity):
                    """
                    Record start and stop without waiting
                    
                    .. attribute:: broadcast
                    
                    	Use Broadcast for Accounting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StartStop.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Exec.StartStop, self).__init__()

                        self.yang_name = "start-stop"
                        self.yang_parent_name = "exec"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.ExecSubmode.Exec.ActionType.StartStop.Group')])),
                        ])
                        self.broadcast = None
                        self.group = None
                        self._segment_path = lambda: "start-stop"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Exec.StartStop, ['broadcast', 'group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



                class StopOnly(Entity):
                    """
                    Record stop when service terminates.
                    
                    .. attribute:: broadcast
                    
                    	Use Broadcast for Accounting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StopOnly.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Exec.StopOnly, self).__init__()

                        self.yang_name = "stop-only"
                        self.yang_parent_name = "exec"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.ExecSubmode.Exec.ActionType.StopOnly.Group')])),
                        ])
                        self.broadcast = None
                        self.group = None
                        self._segment_path = lambda: "stop-only"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Exec.StopOnly, ['broadcast', 'group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        .. data:: tacacs__PLUS__ = 1

                        """

                        radius = Enum.YLeaf(0, "radius")

                        tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



            class ExecSubmode(Entity):
                """
                
                
                .. attribute:: exec_
                
                	For starting an exec (shell)
                	**type**\: list of  		 :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.ExecSubmode.Exec>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.ExecSubmode, self).__init__()

                    self.yang_name = "exec-submode"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("exec", ("exec_", Native.Aaa.Accounting.ExecSubmode.Exec))])
                    self._leafs = OrderedDict()

                    self.exec_ = YList(self)
                    self._segment_path = lambda: "exec-submode"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.ExecSubmode, [], name, value)


                class Exec(Entity):
                    """
                    For starting an exec (shell).
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: action_type
                    
                    	Type of action to be performed on accounting records
                    	**type**\:  :py:class:`ActionType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.ExecSubmode.Exec.ActionType>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.ExecSubmode.Exec, self).__init__()

                        self.yang_name = "exec"
                        self.yang_parent_name = "exec-submode"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("action-type", ("action_type", Native.Aaa.Accounting.ExecSubmode.Exec.ActionType))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.action_type = Native.Aaa.Accounting.ExecSubmode.Exec.ActionType()
                        self.action_type.parent = self
                        self._children_name_map["action_type"] = "action-type"
                        self._segment_path = lambda: "exec" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/exec-submode/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.ExecSubmode.Exec, ['name'], name, value)


                    class ActionType(Entity):
                        """
                        Type of action to be performed on accounting records
                        
                        .. attribute:: none
                        
                        	No accounting
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: start_stop
                        
                        	Record start and stop without waiting
                        	**type**\:  :py:class:`StartStop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StartStop>`
                        
                        .. attribute:: stop_only
                        
                        	Record stop when service terminates
                        	**type**\:  :py:class:`StopOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StopOnly>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Accounting.ExecSubmode.Exec.ActionType, self).__init__()

                            self.yang_name = "action-type"
                            self.yang_parent_name = "exec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("start-stop", ("start_stop", Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StartStop)), ("stop-only", ("stop_only", Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StopOnly))])
                            self._leafs = OrderedDict([
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.none = None

                            self.start_stop = Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StartStop()
                            self.start_stop.parent = self
                            self._children_name_map["start_stop"] = "start-stop"

                            self.stop_only = Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StopOnly()
                            self.stop_only.parent = self
                            self._children_name_map["stop_only"] = "stop-only"
                            self._segment_path = lambda: "action-type"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Accounting.ExecSubmode.Exec.ActionType, ['none'], name, value)


                        class StartStop(Entity):
                            """
                            Record start and stop without waiting
                            
                            .. attribute:: broadcast
                            
                            	Use Broadcast for Accounting
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: group
                            
                            	Use Server\-group
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StartStop.Group>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StartStop, self).__init__()

                                self.yang_name = "start-stop"
                                self.yang_parent_name = "action-type"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.ExecSubmode.Exec.ActionType.StartStop.Group')])),
                                ])
                                self.broadcast = None
                                self.group = None
                                self._segment_path = lambda: "start-stop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StartStop, ['broadcast', 'group'], name, value)

                            class Group(Enum):
                                """
                                Group (Enum Class)

                                Use Server\-group

                                .. data:: radius = 0

                                .. data:: tacacs__PLUS__ = 1

                                """

                                radius = Enum.YLeaf(0, "radius")

                                tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



                        class StopOnly(Entity):
                            """
                            Record stop when service terminates.
                            
                            .. attribute:: broadcast
                            
                            	Use Broadcast for Accounting
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: group
                            
                            	Use Server\-group
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StopOnly.Group>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StopOnly, self).__init__()

                                self.yang_name = "stop-only"
                                self.yang_parent_name = "action-type"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                    ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.ExecSubmode.Exec.ActionType.StopOnly.Group')])),
                                ])
                                self.broadcast = None
                                self.group = None
                                self._segment_path = lambda: "stop-only"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Accounting.ExecSubmode.Exec.ActionType.StopOnly, ['broadcast', 'group'], name, value)

                            class Group(Enum):
                                """
                                Group (Enum Class)

                                Use Server\-group

                                .. data:: radius = 0

                                .. data:: tacacs__PLUS__ = 1

                                """

                                radius = Enum.YLeaf(0, "radius")

                                tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



            class Network(Entity):
                """
                For network services. (PPP, SLIP, ARAP)
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.Id>`
                
                		**type**\: str
                
                			**length:** 1..31
                
                .. attribute:: start_stop
                
                	Record start and stop without waiting
                	**type**\:  :py:class:`StartStop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.StartStop>`
                
                .. attribute:: none
                
                	No accounting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mode
                
                	
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.Mode>`
                
                .. attribute:: broadcast
                
                	Use Broadcast for Accounting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: a1
                
                	
                	**type**\:  :py:class:`A1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.A1>`
                
                .. attribute:: a2
                
                	
                	**type**\:  :py:class:`A2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.A2>`
                
                .. attribute:: a3
                
                	
                	**type**\:  :py:class:`A3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.A3>`
                
                .. attribute:: a4
                
                	
                	**type**\:  :py:class:`A4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.A4>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.Network, self).__init__()

                    self.yang_name = "network"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("start-stop", ("start_stop", Native.Aaa.Accounting.Network.StartStop)), ("a1", ("a1", Native.Aaa.Accounting.Network.A1)), ("a2", ("a2", Native.Aaa.Accounting.Network.A2)), ("a3", ("a3", Native.Aaa.Accounting.Network.A3)), ("a4", ("a4", Native.Aaa.Accounting.Network.A4))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Network.Id'),'str'])),
                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Network.Mode')])),
                        ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                    ])
                    self.id = None
                    self.none = None
                    self.mode = None
                    self.broadcast = None

                    self.start_stop = Native.Aaa.Accounting.Network.StartStop()
                    self.start_stop.parent = self
                    self._children_name_map["start_stop"] = "start-stop"

                    self.a1 = Native.Aaa.Accounting.Network.A1()
                    self.a1.parent = self
                    self._children_name_map["a1"] = "a1"

                    self.a2 = Native.Aaa.Accounting.Network.A2()
                    self.a2.parent = self
                    self._children_name_map["a2"] = "a2"

                    self.a3 = Native.Aaa.Accounting.Network.A3()
                    self.a3.parent = self
                    self._children_name_map["a3"] = "a3"

                    self.a4 = Native.Aaa.Accounting.Network.A4()
                    self.a4.parent = self
                    self._children_name_map["a4"] = "a4"
                    self._segment_path = lambda: "network" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.Network, ['id', 'none', 'mode', 'broadcast'], name, value)

                class Id(Enum):
                    """
                    Id (Enum Class)

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")


                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    .. data:: start_stop = 0

                    .. data:: stop_only = 1

                    """

                    start_stop = Enum.YLeaf(0, "start-stop")

                    stop_only = Enum.YLeaf(1, "stop-only")



                class StartStop(Entity):
                    """
                    Record start and stop without waiting
                    
                    .. attribute:: group
                    
                    	Use Server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.StartStop.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Network.StartStop, self).__init__()

                        self.yang_name = "start-stop"
                        self.yang_parent_name = "network"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Network.StartStop.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "start-stop"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Network.StartStop, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use Server\-group

                        .. data:: radius = 0

                        """

                        radius = Enum.YLeaf(0, "radius")



                class A1(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.A1.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Network.A1, self).__init__()

                        self.yang_name = "a1"
                        self.yang_parent_name = "network"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Network.A1.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "a1"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Network.A1, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use server\-group.

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs = Enum.YLeaf(2, "tacacs")



                class A2(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.A2.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Network.A2, self).__init__()

                        self.yang_name = "a2"
                        self.yang_parent_name = "network"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Network.A2.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "a2"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Network.A2, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use server\-group.

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs = Enum.YLeaf(2, "tacacs")



                class A3(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.A3.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Network.A3, self).__init__()

                        self.yang_name = "a3"
                        self.yang_parent_name = "network"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Network.A3.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "a3"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Network.A3, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use server\-group.

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs = Enum.YLeaf(2, "tacacs")



                class A4(Entity):
                    """
                    
                    
                    .. attribute:: group
                    
                    	Use server\-group
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Network.A4.Group>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Network.A4, self).__init__()

                        self.yang_name = "a4"
                        self.yang_parent_name = "network"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.Network.A4.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "a4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Network.A4, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Use server\-group.

                        .. data:: ldap = 0

                        .. data:: radius = 1

                        .. data:: tacacs = 2

                        """

                        ldap = Enum.YLeaf(0, "ldap")

                        radius = Enum.YLeaf(1, "radius")

                        tacacs = Enum.YLeaf(2, "tacacs")



            class Send(Entity):
                """
                Send records to accounting server
                
                .. attribute:: counters
                
                	Enable specific counters in the Stop record
                	**type**\:  :py:class:`Counters <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Send.Counters>`
                
                .. attribute:: stop_record
                
                	Generate STOP records for a specified event
                	**type**\:  :py:class:`StopRecord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Send.StopRecord>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.Send, self).__init__()

                    self.yang_name = "send"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("counters", ("counters", Native.Aaa.Accounting.Send.Counters)), ("stop-record", ("stop_record", Native.Aaa.Accounting.Send.StopRecord))])
                    self._leafs = OrderedDict()

                    self.counters = Native.Aaa.Accounting.Send.Counters()
                    self.counters.parent = self
                    self._children_name_map["counters"] = "counters"

                    self.stop_record = Native.Aaa.Accounting.Send.StopRecord()
                    self.stop_record.parent = self
                    self._children_name_map["stop_record"] = "stop-record"
                    self._segment_path = lambda: "send"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.Send, [], name, value)


                class Counters(Entity):
                    """
                    Enable specific counters in the Stop record
                    
                    .. attribute:: ipv6
                    
                    	Send IPv6 counters in the Stop Record
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Send.Counters, self).__init__()

                        self.yang_name = "counters"
                        self.yang_parent_name = "send"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                        ])
                        self.ipv6 = None
                        self._segment_path = lambda: "counters"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/send/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Send.Counters, ['ipv6'], name, value)


                class StopRecord(Entity):
                    """
                    Generate STOP records for a specified event
                    
                    .. attribute:: always
                    
                    	Generate STOP records always, even if the START record is not sent
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: authentication
                    
                    	Generate STOP records for authentication failures
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Send.StopRecord.Authentication>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.Send.StopRecord, self).__init__()

                        self.yang_name = "stop-record"
                        self.yang_parent_name = "send"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Aaa.Accounting.Send.StopRecord.Authentication))])
                        self._leafs = OrderedDict([
                            ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                        ])
                        self.always = None

                        self.authentication = Native.Aaa.Accounting.Send.StopRecord.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._segment_path = lambda: "stop-record"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/send/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.Send.StopRecord, ['always'], name, value)


                    class Authentication(Entity):
                        """
                        Generate STOP records for authentication failures
                        
                        .. attribute:: failure
                        
                        	Generate STOP records for authentication failures
                        	**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Send.StopRecord.Authentication.Failure>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: success
                        
                        	Generate STOP records for authenticated users
                        	**type**\:  :py:class:`Success <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Send.StopRecord.Authentication.Success>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Accounting.Send.StopRecord.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "stop-record"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("failure", ("failure", Native.Aaa.Accounting.Send.StopRecord.Authentication.Failure)), ("success", ("success", Native.Aaa.Accounting.Send.StopRecord.Authentication.Success))])
                            self._leafs = OrderedDict()

                            self.failure = None
                            self._children_name_map["failure"] = "failure"

                            self.success = Native.Aaa.Accounting.Send.StopRecord.Authentication.Success()
                            self.success.parent = self
                            self._children_name_map["success"] = "success"
                            self._segment_path = lambda: "authentication"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/send/stop-record/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Accounting.Send.StopRecord.Authentication, [], name, value)


                        class Failure(Entity):
                            """
                            Generate STOP records for authentication failures
                            
                            .. attribute:: vrf
                            
                            	VPN Routing/Forwarding parameters
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Accounting.Send.StopRecord.Authentication.Failure, self).__init__()

                                self.yang_name = "failure"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.vrf = None
                                self._segment_path = lambda: "failure"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/send/stop-record/authentication/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Accounting.Send.StopRecord.Authentication.Failure, ['vrf'], name, value)


                        class Success(Entity):
                            """
                            Generate STOP records for authenticated users
                            
                            .. attribute:: remote_server
                            
                            	Successfully authenticated, through access\-accept, by a remote AAA server
                            	**type**\:  :py:class:`RemoteServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.Send.StopRecord.Authentication.Success.RemoteServer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Accounting.Send.StopRecord.Authentication.Success, self).__init__()

                                self.yang_name = "success"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("remote-server", ("remote_server", Native.Aaa.Accounting.Send.StopRecord.Authentication.Success.RemoteServer))])
                                self._leafs = OrderedDict()

                                self.remote_server = None
                                self._children_name_map["remote_server"] = "remote-server"
                                self._segment_path = lambda: "success"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/send/stop-record/authentication/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Accounting.Send.StopRecord.Authentication.Success, [], name, value)


                            class RemoteServer(Entity):
                                """
                                Successfully authenticated, through access\-accept, by a remote AAA server
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding parameters
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Accounting.Send.StopRecord.Authentication.Success.RemoteServer, self).__init__()

                                    self.yang_name = "remote-server"
                                    self.yang_parent_name = "success"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.vrf = None
                                    self._segment_path = lambda: "remote-server"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/send/stop-record/authentication/success/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Accounting.Send.StopRecord.Authentication.Success.RemoteServer, ['vrf'], name, value)


            class Suppress(Entity):
                """
                Do not generate accounting records for a specific type of user
                
                .. attribute:: null_username
                
                	Do not generate accounting records for users with a null\-username
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.Suppress, self).__init__()

                    self.yang_name = "suppress"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('null_username', (YLeaf(YType.empty, 'null-username'), ['Empty'])),
                    ])
                    self.null_username = None
                    self._segment_path = lambda: "suppress"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.Suppress, ['null_username'], name, value)


            class System(Entity):
                """
                For system events.
                
                .. attribute:: default
                
                	The default accounting list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.System.Default>`
                
                	**presence node**\: True
                
                .. attribute:: guarantee_first
                
                	Guarantee system accounting as first record
                	**type**\: bool
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.System, self).__init__()

                    self.yang_name = "system"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Accounting.System.Default))])
                    self._leafs = OrderedDict([
                        ('guarantee_first', (YLeaf(YType.boolean, 'guarantee-first'), ['bool'])),
                    ])
                    self.guarantee_first = None

                    self.default = None
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "system"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.System, ['guarantee_first'], name, value)


                class Default(Entity):
                    """
                    The default accounting list.
                    
                    .. attribute:: none
                    
                    	No accounting
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: start_stop
                    
                    	Record start and stop without waiting
                    	**type**\:  :py:class:`StartStop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.System.Default.StartStop>`
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding parameters
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.System.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "system"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("start-stop", ("start_stop", Native.Aaa.Accounting.System.Default.StartStop))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.none = None
                        self.vrf = None

                        self.start_stop = Native.Aaa.Accounting.System.Default.StartStop()
                        self.start_stop.parent = self
                        self._children_name_map["start_stop"] = "start-stop"
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/system/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.System.Default, ['none', 'vrf'], name, value)


                    class StartStop(Entity):
                        """
                        Record start and stop without waiting
                        
                        .. attribute:: broadcast
                        
                        	Use Broadcast for Accounting
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: group
                        
                        	Use Server\-group
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.System.Default.StartStop.Group>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Accounting.System.Default.StartStop, self).__init__()

                            self.yang_name = "start-stop"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('broadcast', (YLeaf(YType.empty, 'broadcast'), ['Empty'])),
                                ('group', (YLeaf(YType.str, 'group'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Accounting.System.Default.StartStop.Group')])),
                            ])
                            self.broadcast = None
                            self.group = None
                            self._segment_path = lambda: "start-stop"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/system/default/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Accounting.System.Default.StartStop, ['broadcast', 'group'], name, value)

                        class Group(Enum):
                            """
                            Group (Enum Class)

                            Use Server\-group

                            .. data:: radius = 0

                            .. data:: tacacs__PLUS__ = 1

                            """

                            radius = Enum.YLeaf(0, "radius")

                            tacacs__PLUS__ = Enum.YLeaf(1, "tacacs+")



            class Update(Entity):
                """
                Enable accounting update records
                
                .. attribute:: periodic
                
                	Periodic intervals to send accounting update records(in minutes)
                	**type**\: int
                
                	**range:** 1..71582
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.Update, self).__init__()

                    self.yang_name = "update"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('periodic', (YLeaf(YType.uint32, 'periodic'), ['int'])),
                    ])
                    self.periodic = None
                    self._segment_path = lambda: "update"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.Update, ['periodic'], name, value)


            class AuthProxy(Entity):
                """
                For Authentication Proxy Services
                
                .. attribute:: default
                
                	The default authorization list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.AuthProxy.Default>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Accounting.AuthProxy, self).__init__()

                    self.yang_name = "auth-proxy"
                    self.yang_parent_name = "accounting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Accounting.AuthProxy.Default))])
                    self._leafs = OrderedDict()

                    self.default = Native.Aaa.Accounting.AuthProxy.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "auth-proxy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Accounting.AuthProxy, [], name, value)


                class Default(Entity):
                    """
                    The default authorization list.
                    
                    .. attribute:: start_stop
                    
                    	Record start and stop without waiting
                    	**type**\:  :py:class:`StartStop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Accounting.AuthProxy.Default.StartStop>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Accounting.AuthProxy.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "auth-proxy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("start-stop", ("start_stop", Native.Aaa.Accounting.AuthProxy.Default.StartStop))])
                        self._leafs = OrderedDict()

                        self.start_stop = Native.Aaa.Accounting.AuthProxy.Default.StartStop()
                        self.start_stop.parent = self
                        self._children_name_map["start_stop"] = "start-stop"
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/auth-proxy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Accounting.AuthProxy.Default, [], name, value)


                    class StartStop(Entity):
                        """
                        Record start and stop without waiting
                        
                        .. attribute:: group
                        
                        	Use server\-group
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Accounting.AuthProxy.Default.StartStop, self).__init__()

                            self.yang_name = "start-stop"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('group', (YLeaf(YType.str, 'group'), ['str'])),
                            ])
                            self.group = None
                            self._segment_path = lambda: "start-stop"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:accounting/auth-proxy/default/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Accounting.AuthProxy.Default.StartStop, ['group'], name, value)


        class Server(Entity):
            """
            Local AAA server
            
            .. attribute:: radius
            
            	Profile for local radius server
            	**type**\:  :py:class:`Radius <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Aaa.Server, self).__init__()

                self.yang_name = "server"
                self.yang_parent_name = "aaa"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("radius", ("radius", Native.Aaa.Server.Radius))])
                self._leafs = OrderedDict()

                self.radius = Native.Aaa.Server.Radius()
                self.radius.parent = self
                self._children_name_map["radius"] = "radius"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:server"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Aaa.Server, [], name, value)


            class Radius(Entity):
                """
                Profile for local radius server
                
                .. attribute:: dynamic_author
                
                	Local server profile for RFC 3576 support
                	**type**\:  :py:class:`DynamicAuthor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor>`
                
                	**presence node**\: True
                
                .. attribute:: policy_device
                
                	Local server profile for RADIUS External Policy Delegation client
                	**type**\:  :py:class:`PolicyDevice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice>`
                
                	**presence node**\: True
                
                .. attribute:: proxy
                
                	Local server profile for RADIUS proxy clients
                	**type**\:  :py:class:`Proxy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy>`
                
                	**presence node**\: True
                
                .. attribute:: sesm
                
                	Local server profile for a SESM client
                	**type**\:  :py:class:`Sesm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Sesm>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Server.Radius, self).__init__()

                    self.yang_name = "radius"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dynamic-author", ("dynamic_author", Native.Aaa.Server.Radius.DynamicAuthor)), ("policy-device", ("policy_device", Native.Aaa.Server.Radius.PolicyDevice)), ("proxy", ("proxy", Native.Aaa.Server.Radius.Proxy)), ("sesm", ("sesm", Native.Aaa.Server.Radius.Sesm))])
                    self._leafs = OrderedDict()

                    self.dynamic_author = None
                    self._children_name_map["dynamic_author"] = "dynamic-author"

                    self.policy_device = None
                    self._children_name_map["policy_device"] = "policy-device"

                    self.proxy = None
                    self._children_name_map["proxy"] = "proxy"

                    self.sesm = None
                    self._children_name_map["sesm"] = "sesm"
                    self._segment_path = lambda: "radius"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Server.Radius, [], name, value)


                class DynamicAuthor(Entity):
                    """
                    Local server profile for RFC 3576 support
                    
                    .. attribute:: port
                    
                    	Radius server port
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: client
                    
                    	Specify a RADIUS client
                    	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.Client>`
                    
                    .. attribute:: server_key
                    
                    	Specify a RADIUS client server\-key
                    	**type**\:  :py:class:`ServerKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.ServerKey>`
                    
                    .. attribute:: domain
                    
                    	Username domain options
                    	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.Domain>`
                    
                    .. attribute:: auth_type
                    
                    	Specify the server authorization type
                    	**type**\:  :py:class:`AuthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.AuthType>`
                    
                    .. attribute:: ignore
                    
                    	Override behaviour to ignore certain parameters
                    	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.Ignore>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Server.Radius.DynamicAuthor, self).__init__()

                        self.yang_name = "dynamic-author"
                        self.yang_parent_name = "radius"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("client", ("client", Native.Aaa.Server.Radius.DynamicAuthor.Client)), ("server-key", ("server_key", Native.Aaa.Server.Radius.DynamicAuthor.ServerKey)), ("domain", ("domain", Native.Aaa.Server.Radius.DynamicAuthor.Domain)), ("ignore", ("ignore", Native.Aaa.Server.Radius.DynamicAuthor.Ignore))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                            ('auth_type', (YLeaf(YType.enumeration, 'auth-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.DynamicAuthor.AuthType')])),
                        ])
                        self.port = None
                        self.auth_type = None

                        self.server_key = Native.Aaa.Server.Radius.DynamicAuthor.ServerKey()
                        self.server_key.parent = self
                        self._children_name_map["server_key"] = "server-key"

                        self.domain = Native.Aaa.Server.Radius.DynamicAuthor.Domain()
                        self.domain.parent = self
                        self._children_name_map["domain"] = "domain"

                        self.ignore = Native.Aaa.Server.Radius.DynamicAuthor.Ignore()
                        self.ignore.parent = self
                        self._children_name_map["ignore"] = "ignore"

                        self.client = YList(self)
                        self._segment_path = lambda: "dynamic-author"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Server.Radius.DynamicAuthor, ['port', 'auth_type'], name, value)

                    class AuthType(Enum):
                        """
                        AuthType (Enum Class)

                        Specify the server authorization type

                        .. data:: all = 0

                        .. data:: any = 1

                        .. data:: session_key = 2

                        """

                        all = Enum.YLeaf(0, "all")

                        any = Enum.YLeaf(1, "any")

                        session_key = Enum.YLeaf(2, "session-key")



                    class Client(Entity):
                        """
                        Specify a RADIUS client
                        
                        .. attribute:: ip  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        .. attribute:: dtls
                        
                        	Enable DTLS for the client
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vrf
                        
                        	 Virtual Routing/Forwarding parameters
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.Client.Vrf>`
                        
                        .. attribute:: server_key
                        
                        	Specify a RADIUS client server\-key
                        	**type**\:  :py:class:`ServerKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.Client.ServerKey>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.DynamicAuthor.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "dynamic-author"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ip']
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Aaa.Server.Radius.DynamicAuthor.Client.Vrf)), ("server-key", ("server_key", Native.Aaa.Server.Radius.DynamicAuthor.Client.ServerKey))])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str','str','str'])),
                                ('dtls', (YLeaf(YType.empty, 'dtls'), ['Empty'])),
                            ])
                            self.ip = None
                            self.dtls = None

                            self.server_key = Native.Aaa.Server.Radius.DynamicAuthor.Client.ServerKey()
                            self.server_key.parent = self
                            self._children_name_map["server_key"] = "server-key"

                            self.vrf = YList(self)
                            self._segment_path = lambda: "client" + "[ip='" + str(self.ip) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/dynamic-author/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.DynamicAuthor.Client, ['ip', 'dtls'], name, value)


                        class Vrf(Entity):
                            """
                             Virtual Routing/Forwarding parameters
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: dtls
                            
                            	Enable DTLS for the client
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: server_key
                            
                            	Specify a RADIUS client server\-key
                            	**type**\:  :py:class:`ServerKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.Client.Vrf.ServerKey>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.DynamicAuthor.Client.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("server-key", ("server_key", Native.Aaa.Server.Radius.DynamicAuthor.Client.Vrf.ServerKey))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('dtls', (YLeaf(YType.empty, 'dtls'), ['Empty'])),
                                ])
                                self.name = None
                                self.dtls = None

                                self.server_key = Native.Aaa.Server.Radius.DynamicAuthor.Client.Vrf.ServerKey()
                                self.server_key.parent = self
                                self._children_name_map["server_key"] = "server-key"
                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.DynamicAuthor.Client.Vrf, ['name', 'dtls'], name, value)


                            class ServerKey(Entity):
                                """
                                Specify a RADIUS client server\-key
                                
                                .. attribute:: key
                                
                                	
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.Client.Vrf.ServerKey.Key>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.DynamicAuthor.Client.Vrf.ServerKey, self).__init__()

                                    self.yang_name = "server-key"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.DynamicAuthor.Client.Vrf.ServerKey.Key')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.key = None
                                    self.string = None
                                    self._segment_path = lambda: "server-key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.DynamicAuthor.Client.Vrf.ServerKey, ['key', 'string'], name, value)

                                class Key(Enum):
                                    """
                                    Key (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_6 = 1

                                    .. data:: Y_7 = 2

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_6 = Enum.YLeaf(1, "6")

                                    Y_7 = Enum.YLeaf(2, "7")



                        class ServerKey(Entity):
                            """
                            Specify a RADIUS client server\-key
                            
                            .. attribute:: key
                            
                            	
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.Client.ServerKey.Key>`
                            
                            .. attribute:: string
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.DynamicAuthor.Client.ServerKey, self).__init__()

                                self.yang_name = "server-key"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.DynamicAuthor.Client.ServerKey.Key')])),
                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                ])
                                self.key = None
                                self.string = None
                                self._segment_path = lambda: "server-key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.DynamicAuthor.Client.ServerKey, ['key', 'string'], name, value)

                            class Key(Enum):
                                """
                                Key (Enum Class)

                                .. data:: Y_0 = 0

                                .. data:: Y_6 = 1

                                .. data:: Y_7 = 2

                                """

                                Y_0 = Enum.YLeaf(0, "0")

                                Y_6 = Enum.YLeaf(1, "6")

                                Y_7 = Enum.YLeaf(2, "7")



                    class ServerKey(Entity):
                        """
                        Specify a RADIUS client server\-key
                        
                        .. attribute:: key
                        
                        	
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.ServerKey.Key>`
                        
                        .. attribute:: string
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.DynamicAuthor.ServerKey, self).__init__()

                            self.yang_name = "server-key"
                            self.yang_parent_name = "dynamic-author"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.DynamicAuthor.ServerKey.Key')])),
                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                            ])
                            self.key = None
                            self.string = None
                            self._segment_path = lambda: "server-key"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/dynamic-author/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.DynamicAuthor.ServerKey, ['key', 'string'], name, value)

                        class Key(Enum):
                            """
                            Key (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: Y_6 = 1

                            .. data:: Y_7 = 2

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_6 = Enum.YLeaf(1, "6")

                            Y_7 = Enum.YLeaf(2, "7")



                    class Domain(Entity):
                        """
                        Username domain options
                        
                        .. attribute:: delimiter
                        
                        	Domain delimiter, Choose from {@, /, $, %, \\, #, \-}
                        	**type**\: str
                        
                        .. attribute:: stripping
                        
                        	Match incoming username left oriented of the @ domain delimiter
                        	**type**\:  :py:class:`Stripping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.DynamicAuthor.Domain.Stripping>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.DynamicAuthor.Domain, self).__init__()

                            self.yang_name = "domain"
                            self.yang_parent_name = "dynamic-author"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("stripping", ("stripping", Native.Aaa.Server.Radius.DynamicAuthor.Domain.Stripping))])
                            self._leafs = OrderedDict([
                                ('delimiter', (YLeaf(YType.str, 'delimiter'), ['str'])),
                            ])
                            self.delimiter = None

                            self.stripping = None
                            self._children_name_map["stripping"] = "stripping"
                            self._segment_path = lambda: "domain"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/dynamic-author/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.DynamicAuthor.Domain, ['delimiter'], name, value)


                        class Stripping(Entity):
                            """
                            Match incoming username left oriented of the @ domain delimiter
                            
                            .. attribute:: right_to_left
                            
                            	Terminate the string at the first delimiter going from right to left
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.DynamicAuthor.Domain.Stripping, self).__init__()

                                self.yang_name = "stripping"
                                self.yang_parent_name = "domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('right_to_left', (YLeaf(YType.empty, 'right-to-left'), ['Empty'])),
                                ])
                                self.right_to_left = None
                                self._segment_path = lambda: "stripping"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/dynamic-author/domain/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.DynamicAuthor.Domain.Stripping, ['right_to_left'], name, value)


                    class Ignore(Entity):
                        """
                        Override behaviour to ignore certain parameters
                        
                        .. attribute:: retransmission
                        
                        	Drop packets using same radius id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: server_key
                        
                        	Ignore shared secret
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: session_key
                        
                        	Ignore attr 151
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.DynamicAuthor.Ignore, self).__init__()

                            self.yang_name = "ignore"
                            self.yang_parent_name = "dynamic-author"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('retransmission', (YLeaf(YType.empty, 'retransmission'), ['Empty'])),
                                ('server_key', (YLeaf(YType.empty, 'server-key'), ['Empty'])),
                                ('session_key', (YLeaf(YType.empty, 'session-key'), ['Empty'])),
                            ])
                            self.retransmission = None
                            self.server_key = None
                            self.session_key = None
                            self._segment_path = lambda: "ignore"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/dynamic-author/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.DynamicAuthor.Ignore, ['retransmission', 'server_key', 'session_key'], name, value)


                class PolicyDevice(Entity):
                    """
                    Local server profile for RADIUS External Policy Delegation client
                    
                    .. attribute:: accounting
                    
                    	Specify accounting details
                    	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice.Accounting>`
                    
                    .. attribute:: authentication
                    
                    	Specify authentication details
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice.Authentication>`
                    
                    .. attribute:: client
                    
                    	Specify a RADIUS client
                    	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice.Client>`
                    
                    .. attribute:: key
                    
                    	Specify a RADIUS client
                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice.Key>`
                    
                    .. attribute:: message_authenticator
                    
                    	Message Authenticator attribute from Clients
                    	**type**\:  :py:class:`MessageAuthenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice.MessageAuthenticator>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Server.Radius.PolicyDevice, self).__init__()

                        self.yang_name = "policy-device"
                        self.yang_parent_name = "radius"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("accounting", ("accounting", Native.Aaa.Server.Radius.PolicyDevice.Accounting)), ("authentication", ("authentication", Native.Aaa.Server.Radius.PolicyDevice.Authentication)), ("client", ("client", Native.Aaa.Server.Radius.PolicyDevice.Client)), ("key", ("key", Native.Aaa.Server.Radius.PolicyDevice.Key)), ("message-authenticator", ("message_authenticator", Native.Aaa.Server.Radius.PolicyDevice.MessageAuthenticator))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.accounting = Native.Aaa.Server.Radius.PolicyDevice.Accounting()
                        self.accounting.parent = self
                        self._children_name_map["accounting"] = "accounting"

                        self.authentication = Native.Aaa.Server.Radius.PolicyDevice.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.key = Native.Aaa.Server.Radius.PolicyDevice.Key()
                        self.key.parent = self
                        self._children_name_map["key"] = "key"

                        self.message_authenticator = Native.Aaa.Server.Radius.PolicyDevice.MessageAuthenticator()
                        self.message_authenticator.parent = self
                        self._children_name_map["message_authenticator"] = "message-authenticator"

                        self.client = YList(self)
                        self._segment_path = lambda: "policy-device"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Server.Radius.PolicyDevice, [], name, value)


                    class Accounting(Entity):
                        """
                        Specify accounting details
                        
                        .. attribute:: port
                        
                        	Radius server port
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.PolicyDevice.Accounting, self).__init__()

                            self.yang_name = "accounting"
                            self.yang_parent_name = "policy-device"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                            ])
                            self.port = None
                            self._segment_path = lambda: "accounting"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/policy-device/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.PolicyDevice.Accounting, ['port'], name, value)


                    class Authentication(Entity):
                        """
                        Specify authentication details
                        
                        .. attribute:: port
                        
                        	Radius server port
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.PolicyDevice.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "policy-device"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                            ])
                            self.port = None
                            self._segment_path = lambda: "authentication"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/policy-device/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.PolicyDevice.Authentication, ['port'], name, value)


                    class Client(Entity):
                        """
                        Specify a RADIUS client
                        
                        .. attribute:: ip  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        .. attribute:: port
                        
                        	Port on which radius client listens for CoA messages (default is 3799)
                        	**type**\: int
                        
                        	**range:** 0..65534
                        
                        .. attribute:: vrf
                        
                        	 Virtual Routing/Forwarding parameters
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice.Client.Vrf>`
                        
                        .. attribute:: key
                        
                        	Specify a RADIUS client
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice.Client.Key>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.PolicyDevice.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "policy-device"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ip']
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Aaa.Server.Radius.PolicyDevice.Client.Vrf)), ("key", ("key", Native.Aaa.Server.Radius.PolicyDevice.Client.Key))])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str','str','str'])),
                                ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                            ])
                            self.ip = None
                            self.port = None

                            self.key = Native.Aaa.Server.Radius.PolicyDevice.Client.Key()
                            self.key.parent = self
                            self._children_name_map["key"] = "key"

                            self.vrf = YList(self)
                            self._segment_path = lambda: "client" + "[ip='" + str(self.ip) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/policy-device/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.PolicyDevice.Client, ['ip', 'port'], name, value)


                        class Vrf(Entity):
                            """
                             Virtual Routing/Forwarding parameters
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: port
                            
                            	Port on which radius client listens for CoA messages (default is 3799)
                            	**type**\: int
                            
                            	**range:** 0..65534
                            
                            .. attribute:: key
                            
                            	Specify a RADIUS client
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice.Client.Vrf.Key>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.PolicyDevice.Client.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("key", ("key", Native.Aaa.Server.Radius.PolicyDevice.Client.Vrf.Key))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                ])
                                self.name = None
                                self.port = None

                                self.key = Native.Aaa.Server.Radius.PolicyDevice.Client.Vrf.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.PolicyDevice.Client.Vrf, ['name', 'port'], name, value)


                            class Key(Entity):
                                """
                                Specify a RADIUS client
                                
                                .. attribute:: key
                                
                                	
                                	**type**\:  :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice.Client.Vrf.Key.Key_>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.PolicyDevice.Client.Vrf.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.PolicyDevice.Client.Vrf.Key.Key_')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.key = None
                                    self.string = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.PolicyDevice.Client.Vrf.Key, ['key', 'string'], name, value)

                                class Key_(Enum):
                                    """
                                    Key\_ (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_6 = 1

                                    .. data:: Y_7 = 2

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_6 = Enum.YLeaf(1, "6")

                                    Y_7 = Enum.YLeaf(2, "7")



                        class Key(Entity):
                            """
                            Specify a RADIUS client
                            
                            .. attribute:: key
                            
                            	
                            	**type**\:  :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice.Client.Key.Key_>`
                            
                            .. attribute:: string
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.PolicyDevice.Client.Key, self).__init__()

                                self.yang_name = "key"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.PolicyDevice.Client.Key.Key_')])),
                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                ])
                                self.key = None
                                self.string = None
                                self._segment_path = lambda: "key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.PolicyDevice.Client.Key, ['key', 'string'], name, value)

                            class Key_(Enum):
                                """
                                Key\_ (Enum Class)

                                .. data:: Y_0 = 0

                                .. data:: Y_6 = 1

                                .. data:: Y_7 = 2

                                """

                                Y_0 = Enum.YLeaf(0, "0")

                                Y_6 = Enum.YLeaf(1, "6")

                                Y_7 = Enum.YLeaf(2, "7")



                    class Key(Entity):
                        """
                        Specify a RADIUS client
                        
                        .. attribute:: key
                        
                        	
                        	**type**\:  :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.PolicyDevice.Key.Key_>`
                        
                        .. attribute:: string
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.PolicyDevice.Key, self).__init__()

                            self.yang_name = "key"
                            self.yang_parent_name = "policy-device"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.PolicyDevice.Key.Key_')])),
                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                            ])
                            self.key = None
                            self.string = None
                            self._segment_path = lambda: "key"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/policy-device/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.PolicyDevice.Key, ['key', 'string'], name, value)

                        class Key_(Enum):
                            """
                            Key\_ (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: Y_6 = 1

                            .. data:: Y_7 = 2

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_6 = Enum.YLeaf(1, "6")

                            Y_7 = Enum.YLeaf(2, "7")



                    class MessageAuthenticator(Entity):
                        """
                        Message Authenticator attribute from Clients
                        
                        .. attribute:: ignore
                        
                        	Ignore checking of Message Authenticator attribute from\\ Clients
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.PolicyDevice.MessageAuthenticator, self).__init__()

                            self.yang_name = "message-authenticator"
                            self.yang_parent_name = "policy-device"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "message-authenticator"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/policy-device/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.PolicyDevice.MessageAuthenticator, ['ignore'], name, value)


                class Proxy(Entity):
                    """
                    Local server profile for RADIUS proxy clients
                    
                    .. attribute:: accounting
                    
                    	Specify accounting details
                    	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Accounting>`
                    
                    .. attribute:: authentication
                    
                    	Specify authentication details
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Authentication>`
                    
                    .. attribute:: calling_station_id
                    
                    	Specify format of Calling\-Station\-Id, attribute\\ 31.Default format is to expect mac\-address in\\ calling\-station\-id
                    	**type**\:  :py:class:`CallingStationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId>`
                    
                    .. attribute:: eap_user
                    
                    	EAP users
                    	**type**\:  :py:class:`EapUser <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.EapUser>`
                    
                    .. attribute:: filter
                    
                    	Configure filter
                    	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Filter>`
                    
                    .. attribute:: key
                    
                    	Specify a RADIUS client
                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Key>`
                    
                    .. attribute:: message_authenticator
                    
                    	Message Authenticator attribute from Clients
                    	**type**\:  :py:class:`MessageAuthenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.MessageAuthenticator>`
                    
                    .. attribute:: mode
                    
                    	Radius Proxy Pass thru mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Mode>`
                    
                    .. attribute:: pwlan_session
                    
                    	PWLAN Reconnect feature
                    	**type**\:  :py:class:`PwlanSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.PwlanSession>`
                    
                    .. attribute:: re_authentication
                    
                    	Specify re\-authentication details
                    	**type**\:  :py:class:`ReAuthentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ReAuthentication>`
                    
                    .. attribute:: session_identifier
                    
                    	This attribute will be used to correlate Radius \\ requests of a session and to identify sessions within \\ radius\-proxy
                    	**type**\:  :py:class:`SessionIdentifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.SessionIdentifier>`
                    
                    .. attribute:: timer
                    
                    	Configure RADIUS proxy timer values
                    	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Timer>`
                    
                    .. attribute:: client_ip
                    
                    	
                    	**type**\:  :py:class:`ClientIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp>`
                    
                    .. attribute:: client_ip_mask
                    
                    	
                    	**type**\:  :py:class:`ClientIpMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask>`
                    
                    .. attribute:: client_ip_vrf
                    
                    	
                    	**type**\:  :py:class:`ClientIpVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf>`
                    
                    .. attribute:: client_ip_mask_vrf
                    
                    	
                    	**type**\:  :py:class:`ClientIpMaskVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf>`
                    
                    .. attribute:: send
                    
                    	Send attributes in Radius requests
                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Send>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Server.Radius.Proxy, self).__init__()

                        self.yang_name = "proxy"
                        self.yang_parent_name = "radius"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("accounting", ("accounting", Native.Aaa.Server.Radius.Proxy.Accounting)), ("authentication", ("authentication", Native.Aaa.Server.Radius.Proxy.Authentication)), ("calling-station-id", ("calling_station_id", Native.Aaa.Server.Radius.Proxy.CallingStationId)), ("eap-user", ("eap_user", Native.Aaa.Server.Radius.Proxy.EapUser)), ("filter", ("filter", Native.Aaa.Server.Radius.Proxy.Filter)), ("key", ("key", Native.Aaa.Server.Radius.Proxy.Key)), ("message-authenticator", ("message_authenticator", Native.Aaa.Server.Radius.Proxy.MessageAuthenticator)), ("mode", ("mode", Native.Aaa.Server.Radius.Proxy.Mode)), ("pwlan-session", ("pwlan_session", Native.Aaa.Server.Radius.Proxy.PwlanSession)), ("re-authentication", ("re_authentication", Native.Aaa.Server.Radius.Proxy.ReAuthentication)), ("session-identifier", ("session_identifier", Native.Aaa.Server.Radius.Proxy.SessionIdentifier)), ("timer", ("timer", Native.Aaa.Server.Radius.Proxy.Timer)), ("client-ip", ("client_ip", Native.Aaa.Server.Radius.Proxy.ClientIp)), ("client-ip-mask", ("client_ip_mask", Native.Aaa.Server.Radius.Proxy.ClientIpMask)), ("client-ip-vrf", ("client_ip_vrf", Native.Aaa.Server.Radius.Proxy.ClientIpVrf)), ("client-ip-mask-vrf", ("client_ip_mask_vrf", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf)), ("send", ("send", Native.Aaa.Server.Radius.Proxy.Send))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.accounting = Native.Aaa.Server.Radius.Proxy.Accounting()
                        self.accounting.parent = self
                        self._children_name_map["accounting"] = "accounting"

                        self.authentication = Native.Aaa.Server.Radius.Proxy.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.calling_station_id = Native.Aaa.Server.Radius.Proxy.CallingStationId()
                        self.calling_station_id.parent = self
                        self._children_name_map["calling_station_id"] = "calling-station-id"

                        self.eap_user = Native.Aaa.Server.Radius.Proxy.EapUser()
                        self.eap_user.parent = self
                        self._children_name_map["eap_user"] = "eap-user"

                        self.filter = Native.Aaa.Server.Radius.Proxy.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"

                        self.key = Native.Aaa.Server.Radius.Proxy.Key()
                        self.key.parent = self
                        self._children_name_map["key"] = "key"

                        self.message_authenticator = Native.Aaa.Server.Radius.Proxy.MessageAuthenticator()
                        self.message_authenticator.parent = self
                        self._children_name_map["message_authenticator"] = "message-authenticator"

                        self.mode = Native.Aaa.Server.Radius.Proxy.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.pwlan_session = Native.Aaa.Server.Radius.Proxy.PwlanSession()
                        self.pwlan_session.parent = self
                        self._children_name_map["pwlan_session"] = "pwlan-session"

                        self.re_authentication = Native.Aaa.Server.Radius.Proxy.ReAuthentication()
                        self.re_authentication.parent = self
                        self._children_name_map["re_authentication"] = "re-authentication"

                        self.session_identifier = Native.Aaa.Server.Radius.Proxy.SessionIdentifier()
                        self.session_identifier.parent = self
                        self._children_name_map["session_identifier"] = "session-identifier"

                        self.timer = Native.Aaa.Server.Radius.Proxy.Timer()
                        self.timer.parent = self
                        self._children_name_map["timer"] = "timer"

                        self.client_ip = Native.Aaa.Server.Radius.Proxy.ClientIp()
                        self.client_ip.parent = self
                        self._children_name_map["client_ip"] = "client-ip"

                        self.client_ip_mask = Native.Aaa.Server.Radius.Proxy.ClientIpMask()
                        self.client_ip_mask.parent = self
                        self._children_name_map["client_ip_mask"] = "client-ip-mask"

                        self.client_ip_vrf = Native.Aaa.Server.Radius.Proxy.ClientIpVrf()
                        self.client_ip_vrf.parent = self
                        self._children_name_map["client_ip_vrf"] = "client-ip-vrf"

                        self.client_ip_mask_vrf = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf()
                        self.client_ip_mask_vrf.parent = self
                        self._children_name_map["client_ip_mask_vrf"] = "client-ip-mask-vrf"

                        self.send = Native.Aaa.Server.Radius.Proxy.Send()
                        self.send.parent = self
                        self._children_name_map["send"] = "send"
                        self._segment_path = lambda: "proxy"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy, [], name, value)


                    class Accounting(Entity):
                        """
                        Specify accounting details
                        
                        .. attribute:: method_list
                        
                        	Authentication method list details
                        	**type**\:  :py:class:`MethodList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Accounting.MethodList>`
                        
                        .. attribute:: port
                        
                        	Radius server port
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.Accounting, self).__init__()

                            self.yang_name = "accounting"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("method-list", ("method_list", Native.Aaa.Server.Radius.Proxy.Accounting.MethodList))])
                            self._leafs = OrderedDict([
                                ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                            ])
                            self.port = None

                            self.method_list = Native.Aaa.Server.Radius.Proxy.Accounting.MethodList()
                            self.method_list.parent = self
                            self._children_name_map["method_list"] = "method-list"
                            self._segment_path = lambda: "accounting"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Accounting, ['port'], name, value)


                        class MethodList(Entity):
                            """
                            Authentication method list details
                            
                            .. attribute:: method_name
                            
                            	Method list name
                            	**type**\: str
                            
                            .. attribute:: default
                            
                            	The default authentication list
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.Accounting.MethodList, self).__init__()

                                self.yang_name = "method-list"
                                self.yang_parent_name = "accounting"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('method_name', (YLeaf(YType.str, 'method-name'), ['str'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ])
                                self.method_name = None
                                self.default = None
                                self._segment_path = lambda: "method-list"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/accounting/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Accounting.MethodList, ['method_name', 'default'], name, value)


                    class Authentication(Entity):
                        """
                        Specify authentication details
                        
                        .. attribute:: method_list
                        
                        	Authentication method list details
                        	**type**\:  :py:class:`MethodList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Authentication.MethodList>`
                        
                        .. attribute:: port
                        
                        	Radius server port
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("method-list", ("method_list", Native.Aaa.Server.Radius.Proxy.Authentication.MethodList))])
                            self._leafs = OrderedDict([
                                ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                            ])
                            self.port = None

                            self.method_list = Native.Aaa.Server.Radius.Proxy.Authentication.MethodList()
                            self.method_list.parent = self
                            self._children_name_map["method_list"] = "method-list"
                            self._segment_path = lambda: "authentication"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Authentication, ['port'], name, value)


                        class MethodList(Entity):
                            """
                            Authentication method list details
                            
                            .. attribute:: method_name
                            
                            	Method list name
                            	**type**\: str
                            
                            .. attribute:: default
                            
                            	The default authentication list
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.Authentication.MethodList, self).__init__()

                                self.yang_name = "method-list"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('method_name', (YLeaf(YType.str, 'method-name'), ['str'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ])
                                self.method_name = None
                                self.default = None
                                self._segment_path = lambda: "method-list"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/authentication/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Authentication.MethodList, ['method_name', 'default'], name, value)


                    class CallingStationId(Entity):
                        """
                        Specify format of Calling\-Station\-Id, attribute\\
                        31.Default format is to expect mac\-address in\\
                        calling\-station\-id
                        
                        .. attribute:: format
                        
                        	Specify the format as MAC or MSISDN
                        	**type**\:  :py:class:`Format <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.CallingStationId, self).__init__()

                            self.yang_name = "calling-station-id"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("format", ("format", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format))])
                            self._leafs = OrderedDict()

                            self.format = Native.Aaa.Server.Radius.Proxy.CallingStationId.Format()
                            self.format.parent = self
                            self._children_name_map["format"] = "format"
                            self._segment_path = lambda: "calling-station-id"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId, [], name, value)


                        class Format(Entity):
                            """
                            Specify the format as MAC or MSISDN
                            
                            .. attribute:: mac_address
                            
                            	Expect MAC address to be present in CLID
                            	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress>`
                            
                            .. attribute:: msisdn
                            
                            	Expect MSISDN value to be present in CLID
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format, self).__init__()

                                self.yang_name = "format"
                                self.yang_parent_name = "calling-station-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mac-address", ("mac_address", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress))])
                                self._leafs = OrderedDict([
                                    ('msisdn', (YLeaf(YType.empty, 'msisdn'), ['Empty'])),
                                ])
                                self.msisdn = None

                                self.mac_address = Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress()
                                self.mac_address.parent = self
                                self._children_name_map["mac_address"] = "mac-address"
                                self._segment_path = lambda: "format"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format, ['msisdn'], name, value)


                            class MacAddress(Entity):
                                """
                                Expect MAC address to be present in CLID
                                
                                .. attribute:: default
                                
                                	format ex\: 0000.4096.3e4a
                                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Default>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ietf
                                
                                	format ex\: 00\-00\-40\-96\-3E\-4A
                                	**type**\:  :py:class:`Ietf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Ietf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: none
                                
                                	format unspecified
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: one_byte
                                
                                	format ex\: 00.00.40.96.3e.4a
                                	**type**\:  :py:class:`OneByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte>`
                                
                                .. attribute:: three_byte
                                
                                	format ex\: 000040.963e4a
                                	**type**\:  :py:class:`ThreeByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte>`
                                
                                .. attribute:: two_byte
                                
                                	format ex\: 0000.4096.3e4a
                                	**type**\:  :py:class:`TwoByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte>`
                                
                                .. attribute:: unformatted
                                
                                	format ex\: 000040963e4a
                                	**type**\:  :py:class:`Unformatted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Unformatted>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress, self).__init__()

                                    self.yang_name = "mac-address"
                                    self.yang_parent_name = "format"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Default)), ("ietf", ("ietf", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Ietf)), ("one-byte", ("one_byte", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte)), ("three-byte", ("three_byte", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte)), ("two-byte", ("two_byte", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte)), ("unformatted", ("unformatted", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Unformatted))])
                                    self._leafs = OrderedDict([
                                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                    ])
                                    self.none = None

                                    self.default = None
                                    self._children_name_map["default"] = "default"

                                    self.ietf = None
                                    self._children_name_map["ietf"] = "ietf"

                                    self.one_byte = Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte()
                                    self.one_byte.parent = self
                                    self._children_name_map["one_byte"] = "one-byte"

                                    self.three_byte = Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte()
                                    self.three_byte.parent = self
                                    self._children_name_map["three_byte"] = "three-byte"

                                    self.two_byte = Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte()
                                    self.two_byte.parent = self
                                    self._children_name_map["two_byte"] = "two-byte"

                                    self.unformatted = None
                                    self._children_name_map["unformatted"] = "unformatted"
                                    self._segment_path = lambda: "mac-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress, ['none'], name, value)


                                class Default(Entity):
                                    """
                                    format ex\: 0000.4096.3e4a
                                    
                                    .. attribute:: type
                                    
                                    	
                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Default.Type>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Default, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "mac-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Default.Type')])),
                                        ])
                                        self.type = None
                                        self._segment_path = lambda: "default"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Default, ['type'], name, value)

                                    class Type(Enum):
                                        """
                                        Type (Enum Class)

                                        .. data:: lower_case = 0

                                        .. data:: upper_case = 1

                                        """

                                        lower_case = Enum.YLeaf(0, "lower-case")

                                        upper_case = Enum.YLeaf(1, "upper-case")



                                class Ietf(Entity):
                                    """
                                    format ex\: 00\-00\-40\-96\-3E\-4A
                                    
                                    .. attribute:: type
                                    
                                    	
                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Ietf.Type>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Ietf, self).__init__()

                                        self.yang_name = "ietf"
                                        self.yang_parent_name = "mac-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Ietf.Type')])),
                                        ])
                                        self.type = None
                                        self._segment_path = lambda: "ietf"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Ietf, ['type'], name, value)

                                    class Type(Enum):
                                        """
                                        Type (Enum Class)

                                        .. data:: lower_case = 0

                                        .. data:: upper_case = 1

                                        """

                                        lower_case = Enum.YLeaf(0, "lower-case")

                                        upper_case = Enum.YLeaf(1, "upper-case")



                                class OneByte(Entity):
                                    """
                                    format ex\: 00.00.40.96.3e.4a
                                    
                                    .. attribute:: delimiter
                                    
                                    	
                                    	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte, self).__init__()

                                        self.yang_name = "one-byte"
                                        self.yang_parent_name = "mac-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter))])
                                        self._leafs = OrderedDict()

                                        self.delimiter = Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter()
                                        self.delimiter.parent = self
                                        self._children_name_map["delimiter"] = "delimiter"
                                        self._segment_path = lambda: "one-byte"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte, [], name, value)


                                    class Delimiter(Entity):
                                        """
                                        
                                        
                                        .. attribute:: colon
                                        
                                        	
                                        	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dot
                                        
                                        	
                                        	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: hyphen
                                        
                                        	
                                        	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter, self).__init__()

                                            self.yang_name = "delimiter"
                                            self.yang_parent_name = "one-byte"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen))])
                                            self._leafs = OrderedDict()

                                            self.colon = None
                                            self._children_name_map["colon"] = "colon"

                                            self.dot = None
                                            self._children_name_map["dot"] = "dot"

                                            self.hyphen = None
                                            self._children_name_map["hyphen"] = "hyphen"
                                            self._segment_path = lambda: "delimiter"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/one-byte/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter, [], name, value)


                                        class Colon(Entity):
                                            """
                                            
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon, self).__init__()

                                                self.yang_name = "colon"
                                                self.yang_parent_name = "delimiter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "colon"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/one-byte/delimiter/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class Dot(Entity):
                                            """
                                            
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot, self).__init__()

                                                self.yang_name = "dot"
                                                self.yang_parent_name = "delimiter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "dot"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/one-byte/delimiter/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class Hyphen(Entity):
                                            """
                                            
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen, self).__init__()

                                                self.yang_name = "hyphen"
                                                self.yang_parent_name = "delimiter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "hyphen"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/one-byte/delimiter/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                class ThreeByte(Entity):
                                    """
                                    format ex\: 000040.963e4a
                                    
                                    .. attribute:: delimiter
                                    
                                    	
                                    	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte, self).__init__()

                                        self.yang_name = "three-byte"
                                        self.yang_parent_name = "mac-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter))])
                                        self._leafs = OrderedDict()

                                        self.delimiter = Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter()
                                        self.delimiter.parent = self
                                        self._children_name_map["delimiter"] = "delimiter"
                                        self._segment_path = lambda: "three-byte"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte, [], name, value)


                                    class Delimiter(Entity):
                                        """
                                        
                                        
                                        .. attribute:: colon
                                        
                                        	
                                        	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dot
                                        
                                        	
                                        	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: hyphen
                                        
                                        	
                                        	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter, self).__init__()

                                            self.yang_name = "delimiter"
                                            self.yang_parent_name = "three-byte"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen))])
                                            self._leafs = OrderedDict()

                                            self.colon = None
                                            self._children_name_map["colon"] = "colon"

                                            self.dot = None
                                            self._children_name_map["dot"] = "dot"

                                            self.hyphen = None
                                            self._children_name_map["hyphen"] = "hyphen"
                                            self._segment_path = lambda: "delimiter"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/three-byte/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter, [], name, value)


                                        class Colon(Entity):
                                            """
                                            
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon, self).__init__()

                                                self.yang_name = "colon"
                                                self.yang_parent_name = "delimiter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "colon"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/three-byte/delimiter/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class Dot(Entity):
                                            """
                                            
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot, self).__init__()

                                                self.yang_name = "dot"
                                                self.yang_parent_name = "delimiter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "dot"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/three-byte/delimiter/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class Hyphen(Entity):
                                            """
                                            
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen, self).__init__()

                                                self.yang_name = "hyphen"
                                                self.yang_parent_name = "delimiter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "hyphen"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/three-byte/delimiter/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                class TwoByte(Entity):
                                    """
                                    format ex\: 0000.4096.3e4a
                                    
                                    .. attribute:: delimiter
                                    
                                    	
                                    	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte, self).__init__()

                                        self.yang_name = "two-byte"
                                        self.yang_parent_name = "mac-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter))])
                                        self._leafs = OrderedDict()

                                        self.delimiter = Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter()
                                        self.delimiter.parent = self
                                        self._children_name_map["delimiter"] = "delimiter"
                                        self._segment_path = lambda: "two-byte"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte, [], name, value)


                                    class Delimiter(Entity):
                                        """
                                        
                                        
                                        .. attribute:: colon
                                        
                                        	
                                        	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dot
                                        
                                        	
                                        	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: hyphen
                                        
                                        	
                                        	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter, self).__init__()

                                            self.yang_name = "delimiter"
                                            self.yang_parent_name = "two-byte"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen))])
                                            self._leafs = OrderedDict()

                                            self.colon = None
                                            self._children_name_map["colon"] = "colon"

                                            self.dot = None
                                            self._children_name_map["dot"] = "dot"

                                            self.hyphen = None
                                            self._children_name_map["hyphen"] = "hyphen"
                                            self._segment_path = lambda: "delimiter"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/two-byte/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter, [], name, value)


                                        class Colon(Entity):
                                            """
                                            
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon, self).__init__()

                                                self.yang_name = "colon"
                                                self.yang_parent_name = "delimiter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "colon"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/two-byte/delimiter/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class Dot(Entity):
                                            """
                                            
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot, self).__init__()

                                                self.yang_name = "dot"
                                                self.yang_parent_name = "delimiter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "dot"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/two-byte/delimiter/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class Hyphen(Entity):
                                            """
                                            
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen, self).__init__()

                                                self.yang_name = "hyphen"
                                                self.yang_parent_name = "delimiter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "hyphen"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/two-byte/delimiter/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                class Unformatted(Entity):
                                    """
                                    format ex\: 000040963e4a
                                    
                                    .. attribute:: type
                                    
                                    	
                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Unformatted.Type>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Unformatted, self).__init__()

                                        self.yang_name = "unformatted"
                                        self.yang_parent_name = "mac-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Unformatted.Type')])),
                                        ])
                                        self.type = None
                                        self._segment_path = lambda: "unformatted"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/calling-station-id/format/mac-address/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.CallingStationId.Format.MacAddress.Unformatted, ['type'], name, value)

                                    class Type(Enum):
                                        """
                                        Type (Enum Class)

                                        .. data:: lower_case = 0

                                        .. data:: upper_case = 1

                                        """

                                        lower_case = Enum.YLeaf(0, "lower-case")

                                        upper_case = Enum.YLeaf(1, "upper-case")



                    class EapUser(Entity):
                        """
                        EAP users
                        
                        .. attribute:: ignore_open_session
                        
                        	for EAP authenticated users, open\-session is not supported
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.EapUser, self).__init__()

                            self.yang_name = "eap-user"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore_open_session', (YLeaf(YType.empty, 'ignore-open-session'), ['Empty'])),
                            ])
                            self.ignore_open_session = None
                            self._segment_path = lambda: "eap-user"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.EapUser, ['ignore_open_session'], name, value)


                    class Filter(Entity):
                        """
                        Configure filter
                        
                        .. attribute:: access
                        
                        	For access requests
                        	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Filter.Access>`
                        
                        .. attribute:: accounting
                        
                        	For accounting requests
                        	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Filter.Accounting>`
                        
                        .. attribute:: attribute
                        
                        	Filter attributes in packets sent to clients
                        	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Filter.Attribute>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.Filter, self).__init__()

                            self.yang_name = "filter"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("access", ("access", Native.Aaa.Server.Radius.Proxy.Filter.Access)), ("accounting", ("accounting", Native.Aaa.Server.Radius.Proxy.Filter.Accounting)), ("attribute", ("attribute", Native.Aaa.Server.Radius.Proxy.Filter.Attribute))])
                            self._leafs = OrderedDict()

                            self.access = Native.Aaa.Server.Radius.Proxy.Filter.Access()
                            self.access.parent = self
                            self._children_name_map["access"] = "access"

                            self.accounting = Native.Aaa.Server.Radius.Proxy.Filter.Accounting()
                            self.accounting.parent = self
                            self._children_name_map["accounting"] = "accounting"

                            self.attribute = Native.Aaa.Server.Radius.Proxy.Filter.Attribute()
                            self.attribute.parent = self
                            self._children_name_map["attribute"] = "attribute"
                            self._segment_path = lambda: "filter"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Filter, [], name, value)


                        class Access(Entity):
                            """
                            For access requests
                            
                            .. attribute:: ack
                            
                            	Acknowledge the packet
                            	**type**\:  :py:class:`Ack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Filter.Access.Ack>`
                            
                            .. attribute:: drop
                            
                            	Drop the packet
                            	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Filter.Access.Drop>`
                            
                            .. attribute:: ignore
                            
                            	Ignore the packet for applying ISG features
                            	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Filter.Access.Ignore>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.Filter.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "filter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ack", ("ack", Native.Aaa.Server.Radius.Proxy.Filter.Access.Ack)), ("drop", ("drop", Native.Aaa.Server.Radius.Proxy.Filter.Access.Drop)), ("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.Filter.Access.Ignore))])
                                self._leafs = OrderedDict()

                                self.ack = Native.Aaa.Server.Radius.Proxy.Filter.Access.Ack()
                                self.ack.parent = self
                                self._children_name_map["ack"] = "ack"

                                self.drop = Native.Aaa.Server.Radius.Proxy.Filter.Access.Drop()
                                self.drop.parent = self
                                self._children_name_map["drop"] = "drop"

                                self.ignore = Native.Aaa.Server.Radius.Proxy.Filter.Access.Ignore()
                                self.ignore.parent = self
                                self._children_name_map["ignore"] = "ignore"
                                self._segment_path = lambda: "access"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/filter/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Filter.Access, [], name, value)


                            class Ack(Entity):
                                """
                                Acknowledge the packet
                                
                                .. attribute:: word1
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word2
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word3
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word4
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.Filter.Access.Ack, self).__init__()

                                    self.yang_name = "ack"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                        ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                        ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                        ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                    ])
                                    self.word1 = None
                                    self.word2 = None
                                    self.word3 = None
                                    self.word4 = None
                                    self._segment_path = lambda: "ack"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/filter/access/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Filter.Access.Ack, ['word1', 'word2', 'word3', 'word4'], name, value)


                            class Drop(Entity):
                                """
                                Drop the packet
                                
                                .. attribute:: word1
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word2
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word3
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word4
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.Filter.Access.Drop, self).__init__()

                                    self.yang_name = "drop"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                        ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                        ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                        ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                    ])
                                    self.word1 = None
                                    self.word2 = None
                                    self.word3 = None
                                    self.word4 = None
                                    self._segment_path = lambda: "drop"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/filter/access/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Filter.Access.Drop, ['word1', 'word2', 'word3', 'word4'], name, value)


                            class Ignore(Entity):
                                """
                                Ignore the packet for applying ISG features
                                
                                .. attribute:: word1
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word2
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word3
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word4
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.Filter.Access.Ignore, self).__init__()

                                    self.yang_name = "ignore"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                        ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                        ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                        ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                    ])
                                    self.word1 = None
                                    self.word2 = None
                                    self.word3 = None
                                    self.word4 = None
                                    self._segment_path = lambda: "ignore"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/filter/access/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Filter.Access.Ignore, ['word1', 'word2', 'word3', 'word4'], name, value)


                        class Accounting(Entity):
                            """
                            For accounting requests
                            
                            .. attribute:: ack
                            
                            	Acknowledge the packet
                            	**type**\:  :py:class:`Ack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Ack>`
                            
                            .. attribute:: drop
                            
                            	Drop the packet
                            	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Drop>`
                            
                            .. attribute:: ignore
                            
                            	Ignore the packet for applying ISG features
                            	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Ignore>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.Filter.Accounting, self).__init__()

                                self.yang_name = "accounting"
                                self.yang_parent_name = "filter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ack", ("ack", Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Ack)), ("drop", ("drop", Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Drop)), ("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Ignore))])
                                self._leafs = OrderedDict()

                                self.ack = Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Ack()
                                self.ack.parent = self
                                self._children_name_map["ack"] = "ack"

                                self.drop = Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Drop()
                                self.drop.parent = self
                                self._children_name_map["drop"] = "drop"

                                self.ignore = Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Ignore()
                                self.ignore.parent = self
                                self._children_name_map["ignore"] = "ignore"
                                self._segment_path = lambda: "accounting"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/filter/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Filter.Accounting, [], name, value)


                            class Ack(Entity):
                                """
                                Acknowledge the packet
                                
                                .. attribute:: word1
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word2
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word3
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word4
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Ack, self).__init__()

                                    self.yang_name = "ack"
                                    self.yang_parent_name = "accounting"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                        ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                        ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                        ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                    ])
                                    self.word1 = None
                                    self.word2 = None
                                    self.word3 = None
                                    self.word4 = None
                                    self._segment_path = lambda: "ack"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/filter/accounting/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Ack, ['word1', 'word2', 'word3', 'word4'], name, value)


                            class Drop(Entity):
                                """
                                Drop the packet
                                
                                .. attribute:: word1
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word2
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word3
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word4
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Drop, self).__init__()

                                    self.yang_name = "drop"
                                    self.yang_parent_name = "accounting"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                        ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                        ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                        ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                    ])
                                    self.word1 = None
                                    self.word2 = None
                                    self.word3 = None
                                    self.word4 = None
                                    self._segment_path = lambda: "drop"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/filter/accounting/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Drop, ['word1', 'word2', 'word3', 'word4'], name, value)


                            class Ignore(Entity):
                                """
                                Ignore the packet for applying ISG features
                                
                                .. attribute:: word1
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word2
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word3
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                .. attribute:: word4
                                
                                	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Ignore, self).__init__()

                                    self.yang_name = "ignore"
                                    self.yang_parent_name = "accounting"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                        ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                        ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                        ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                    ])
                                    self.word1 = None
                                    self.word2 = None
                                    self.word3 = None
                                    self.word4 = None
                                    self._segment_path = lambda: "ignore"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/filter/accounting/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Filter.Accounting.Ignore, ['word1', 'word2', 'word3', 'word4'], name, value)


                        class Attribute(Entity):
                            """
                            Filter attributes in packets sent to clients
                            
                            .. attribute:: allow
                            
                            	Allow only the attributes specified in the list
                            	**type**\: str
                            
                            .. attribute:: block
                            
                            	Block the attributes specified in the list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.Filter.Attribute, self).__init__()

                                self.yang_name = "attribute"
                                self.yang_parent_name = "filter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('allow', (YLeaf(YType.str, 'allow'), ['str'])),
                                    ('block', (YLeaf(YType.str, 'block'), ['str'])),
                                ])
                                self.allow = None
                                self.block = None
                                self._segment_path = lambda: "attribute"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/filter/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Filter.Attribute, ['allow', 'block'], name, value)


                    class Key(Entity):
                        """
                        Specify a RADIUS client
                        
                        .. attribute:: key
                        
                        	
                        	**type**\:  :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Key.Key_>`
                        
                        .. attribute:: string
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.Key, self).__init__()

                            self.yang_name = "key"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.Key.Key_')])),
                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                            ])
                            self.key = None
                            self.string = None
                            self._segment_path = lambda: "key"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Key, ['key', 'string'], name, value)

                        class Key_(Enum):
                            """
                            Key\_ (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: Y_6 = 1

                            .. data:: Y_7 = 2

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_6 = Enum.YLeaf(1, "6")

                            Y_7 = Enum.YLeaf(2, "7")



                    class MessageAuthenticator(Entity):
                        """
                        Message Authenticator attribute from Clients
                        
                        .. attribute:: ignore
                        
                        	Ignore checking of Message Authenticator attribute from\\ Clients
                        	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.MessageAuthenticator.Ignore>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.MessageAuthenticator, self).__init__()

                            self.yang_name = "message-authenticator"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.MessageAuthenticator.Ignore))])
                            self._leafs = OrderedDict()

                            self.ignore = None
                            self._children_name_map["ignore"] = "ignore"
                            self._segment_path = lambda: "message-authenticator"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.MessageAuthenticator, [], name, value)


                        class Ignore(Entity):
                            """
                            Ignore checking of Message Authenticator attribute from\\
                            Clients
                            
                            .. attribute:: accounting
                            
                            	Ignore checking of Message Authenticator attribute from\\ accounting packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.MessageAuthenticator.Ignore, self).__init__()

                                self.yang_name = "ignore"
                                self.yang_parent_name = "message-authenticator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('accounting', (YLeaf(YType.empty, 'accounting'), ['Empty'])),
                                ])
                                self.accounting = None
                                self._segment_path = lambda: "ignore"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/message-authenticator/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.MessageAuthenticator.Ignore, ['accounting'], name, value)


                    class Mode(Entity):
                        """
                        Radius Proxy Pass thru mode
                        
                        .. attribute:: pass_through
                        
                        	Enable the pass\-through mode for Radius Proxy
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('pass_through', (YLeaf(YType.empty, 'pass-through'), ['Empty'])),
                            ])
                            self.pass_through = None
                            self._segment_path = lambda: "mode"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Mode, ['pass_through'], name, value)


                    class PwlanSession(Entity):
                        """
                        PWLAN Reconnect feature
                        
                        .. attribute:: reconnect
                        
                        	Enable the reconnect feature for PWLAN RP sessions
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.PwlanSession, self).__init__()

                            self.yang_name = "pwlan-session"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('reconnect', (YLeaf(YType.empty, 'reconnect'), ['Empty'])),
                            ])
                            self.reconnect = None
                            self._segment_path = lambda: "pwlan-session"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.PwlanSession, ['reconnect'], name, value)


                    class ReAuthentication(Entity):
                        """
                        Specify re\-authentication details
                        
                        .. attribute:: do_not_apply
                        
                        	Do not apply new data during re\-authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.ReAuthentication, self).__init__()

                            self.yang_name = "re-authentication"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('do_not_apply', (YLeaf(YType.empty, 'do-not-apply'), ['Empty'])),
                            ])
                            self.do_not_apply = None
                            self._segment_path = lambda: "re-authentication"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ReAuthentication, ['do_not_apply'], name, value)


                    class SessionIdentifier(Entity):
                        """
                        This attribute will be used to correlate Radius \\
                        requests of a session and to identify sessions within \\
                        radius\-proxy
                        
                        .. attribute:: attribute
                        
                        	Specify an IETF Radius attribute
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: vsa
                        
                        	Specify Vendor\-Specific Attribute
                        	**type**\:  :py:class:`Vsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.SessionIdentifier.Vsa>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.SessionIdentifier, self).__init__()

                            self.yang_name = "session-identifier"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vsa", ("vsa", Native.Aaa.Server.Radius.Proxy.SessionIdentifier.Vsa))])
                            self._leafs = OrderedDict([
                                ('attribute', (YLeaf(YType.uint8, 'attribute'), ['int'])),
                            ])
                            self.attribute = None

                            self.vsa = Native.Aaa.Server.Radius.Proxy.SessionIdentifier.Vsa()
                            self.vsa.parent = self
                            self._children_name_map["vsa"] = "vsa"
                            self._segment_path = lambda: "session-identifier"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.SessionIdentifier, ['attribute'], name, value)


                        class Vsa(Entity):
                            """
                            Specify Vendor\-Specific Attribute
                            
                            .. attribute:: vendor
                            
                            	Specify the vendor type
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: type
                            
                            	Give attribute type for vsa
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.SessionIdentifier.Vsa, self).__init__()

                                self.yang_name = "vsa"
                                self.yang_parent_name = "session-identifier"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vendor', (YLeaf(YType.uint16, 'vendor'), ['int'])),
                                    ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                ])
                                self.vendor = None
                                self.type = None
                                self._segment_path = lambda: "vsa"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/session-identifier/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.SessionIdentifier.Vsa, ['vendor', 'type'], name, value)


                    class Timer(Entity):
                        """
                        Configure RADIUS proxy timer values
                        
                        .. attribute:: disconnect
                        
                        	Specify disconnect timer
                        	**type**\:  :py:class:`Disconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Timer.Disconnect>`
                        
                        .. attribute:: ip_address
                        
                        	Specify value of wait for IP timer
                        	**type**\: int
                        
                        	**range:** 0..43200
                        
                        .. attribute:: reconnect
                        
                        	Specify value of wait for reconnect timer
                        	**type**\: int
                        
                        	**range:** 0..43200
                        
                        .. attribute:: request
                        
                        	Specify value of wait for Access\-Request timer
                        	**type**\: int
                        
                        	**range:** 0..43200
                        
                        .. attribute:: roaming
                        
                        	Specify value of wait for roaming timer
                        	**type**\: int
                        
                        	**range:** 0..43200
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.Timer, self).__init__()

                            self.yang_name = "timer"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("disconnect", ("disconnect", Native.Aaa.Server.Radius.Proxy.Timer.Disconnect))])
                            self._leafs = OrderedDict([
                                ('ip_address', (YLeaf(YType.uint16, 'ip-address'), ['int'])),
                                ('reconnect', (YLeaf(YType.uint16, 'reconnect'), ['int'])),
                                ('request', (YLeaf(YType.uint16, 'request'), ['int'])),
                                ('roaming', (YLeaf(YType.uint16, 'roaming'), ['int'])),
                            ])
                            self.ip_address = None
                            self.reconnect = None
                            self.request = None
                            self.roaming = None

                            self.disconnect = Native.Aaa.Server.Radius.Proxy.Timer.Disconnect()
                            self.disconnect.parent = self
                            self._children_name_map["disconnect"] = "disconnect"
                            self._segment_path = lambda: "timer"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Timer, ['ip_address', 'reconnect', 'request', 'roaming'], name, value)


                        class Disconnect(Entity):
                            """
                            Specify disconnect timer
                            
                            .. attribute:: acct_stop
                            
                            	Specify disconnect delay timer for accounting stop
                            	**type**\: int
                            
                            	**range:** 0..43200
                            
                            .. attribute:: reauth_fail
                            
                            	Specify disconnect delay timer for reauthentication failure
                            	**type**\: int
                            
                            	**range:** 0..43200
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.Timer.Disconnect, self).__init__()

                                self.yang_name = "disconnect"
                                self.yang_parent_name = "timer"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acct_stop', (YLeaf(YType.uint16, 'acct-stop'), ['int'])),
                                    ('reauth_fail', (YLeaf(YType.uint16, 'reauth-fail'), ['int'])),
                                ])
                                self.acct_stop = None
                                self.reauth_fail = None
                                self._segment_path = lambda: "disconnect"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/timer/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Timer.Disconnect, ['acct_stop', 'reauth_fail'], name, value)


                    class ClientIp(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Specify a RADIUS client
                        	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.ClientIp, self).__init__()

                            self.yang_name = "client-ip"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client", ("client", Native.Aaa.Server.Radius.Proxy.ClientIp.Client))])
                            self._leafs = OrderedDict()

                            self.client = YList(self)
                            self._segment_path = lambda: "client-ip"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp, [], name, value)


                        class Client(Entity):
                            """
                            Specify a RADIUS client
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            .. attribute:: accounting
                            
                            	Specify accounting details
                            	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Accounting>`
                            
                            .. attribute:: authentication
                            
                            	Specify authentication details
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Authentication>`
                            
                            .. attribute:: calling_station_id
                            
                            	Specify format of Calling\-Station\-Id, attribute\\ 31.Default format is to expect mac\-address in\\ calling\-station\-id
                            	**type**\:  :py:class:`CallingStationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId>`
                            
                            .. attribute:: eap_user
                            
                            	EAP users
                            	**type**\:  :py:class:`EapUser <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.EapUser>`
                            
                            .. attribute:: filter
                            
                            	Configure filter
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter>`
                            
                            .. attribute:: key
                            
                            	Specify a RADIUS client
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Key>`
                            
                            .. attribute:: message_authenticator
                            
                            	Message Authenticator attribute from Clients
                            	**type**\:  :py:class:`MessageAuthenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.MessageAuthenticator>`
                            
                            .. attribute:: mode
                            
                            	Radius Proxy Pass thru mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Mode>`
                            
                            .. attribute:: pwlan_session
                            
                            	PWLAN Reconnect feature
                            	**type**\:  :py:class:`PwlanSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.PwlanSession>`
                            
                            .. attribute:: re_authentication
                            
                            	Specify re\-authentication details
                            	**type**\:  :py:class:`ReAuthentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.ReAuthentication>`
                            
                            .. attribute:: session_identifier
                            
                            	This attribute will be used to correlate Radius \\ requests of a session and to identify sessions within \\ radius\-proxy
                            	**type**\:  :py:class:`SessionIdentifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.SessionIdentifier>`
                            
                            .. attribute:: timer
                            
                            	Configure RADIUS proxy timer values
                            	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Timer>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client, self).__init__()

                                self.yang_name = "client"
                                self.yang_parent_name = "client-ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip']
                                self._child_classes = OrderedDict([("accounting", ("accounting", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Accounting)), ("authentication", ("authentication", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Authentication)), ("calling-station-id", ("calling_station_id", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId)), ("eap-user", ("eap_user", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.EapUser)), ("filter", ("filter", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter)), ("key", ("key", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Key)), ("message-authenticator", ("message_authenticator", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.MessageAuthenticator)), ("mode", ("mode", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Mode)), ("pwlan-session", ("pwlan_session", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.PwlanSession)), ("re-authentication", ("re_authentication", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.ReAuthentication)), ("session-identifier", ("session_identifier", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.SessionIdentifier)), ("timer", ("timer", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Timer))])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str','str','str'])),
                                ])
                                self.ip = None

                                self.accounting = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Accounting()
                                self.accounting.parent = self
                                self._children_name_map["accounting"] = "accounting"

                                self.authentication = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"

                                self.calling_station_id = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId()
                                self.calling_station_id.parent = self
                                self._children_name_map["calling_station_id"] = "calling-station-id"

                                self.eap_user = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.EapUser()
                                self.eap_user.parent = self
                                self._children_name_map["eap_user"] = "eap-user"

                                self.filter = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"

                                self.key = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"

                                self.message_authenticator = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.MessageAuthenticator()
                                self.message_authenticator.parent = self
                                self._children_name_map["message_authenticator"] = "message-authenticator"

                                self.mode = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Mode()
                                self.mode.parent = self
                                self._children_name_map["mode"] = "mode"

                                self.pwlan_session = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.PwlanSession()
                                self.pwlan_session.parent = self
                                self._children_name_map["pwlan_session"] = "pwlan-session"

                                self.re_authentication = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.ReAuthentication()
                                self.re_authentication.parent = self
                                self._children_name_map["re_authentication"] = "re-authentication"

                                self.session_identifier = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.SessionIdentifier()
                                self.session_identifier.parent = self
                                self._children_name_map["session_identifier"] = "session-identifier"

                                self.timer = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Timer()
                                self.timer.parent = self
                                self._children_name_map["timer"] = "timer"
                                self._segment_path = lambda: "client" + "[ip='" + str(self.ip) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/client-ip/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client, ['ip'], name, value)


                            class Accounting(Entity):
                                """
                                Specify accounting details
                                
                                .. attribute:: method_list
                                
                                	Authentication method list details
                                	**type**\:  :py:class:`MethodList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Accounting.MethodList>`
                                
                                .. attribute:: port
                                
                                	Radius server port
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Accounting, self).__init__()

                                    self.yang_name = "accounting"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("method-list", ("method_list", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Accounting.MethodList))])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                    ])
                                    self.port = None

                                    self.method_list = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Accounting.MethodList()
                                    self.method_list.parent = self
                                    self._children_name_map["method_list"] = "method-list"
                                    self._segment_path = lambda: "accounting"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Accounting, ['port'], name, value)


                                class MethodList(Entity):
                                    """
                                    Authentication method list details
                                    
                                    .. attribute:: method_name
                                    
                                    	Method list name
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	The default authentication list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Accounting.MethodList, self).__init__()

                                        self.yang_name = "method-list"
                                        self.yang_parent_name = "accounting"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('method_name', (YLeaf(YType.str, 'method-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ])
                                        self.method_name = None
                                        self.default = None
                                        self._segment_path = lambda: "method-list"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Accounting.MethodList, ['method_name', 'default'], name, value)


                            class Authentication(Entity):
                                """
                                Specify authentication details
                                
                                .. attribute:: method_list
                                
                                	Authentication method list details
                                	**type**\:  :py:class:`MethodList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Authentication.MethodList>`
                                
                                .. attribute:: port
                                
                                	Radius server port
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("method-list", ("method_list", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Authentication.MethodList))])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                    ])
                                    self.port = None

                                    self.method_list = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Authentication.MethodList()
                                    self.method_list.parent = self
                                    self._children_name_map["method_list"] = "method-list"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Authentication, ['port'], name, value)


                                class MethodList(Entity):
                                    """
                                    Authentication method list details
                                    
                                    .. attribute:: method_name
                                    
                                    	Method list name
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	The default authentication list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Authentication.MethodList, self).__init__()

                                        self.yang_name = "method-list"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('method_name', (YLeaf(YType.str, 'method-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ])
                                        self.method_name = None
                                        self.default = None
                                        self._segment_path = lambda: "method-list"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Authentication.MethodList, ['method_name', 'default'], name, value)


                            class CallingStationId(Entity):
                                """
                                Specify format of Calling\-Station\-Id, attribute\\
                                31.Default format is to expect mac\-address in\\
                                calling\-station\-id
                                
                                .. attribute:: format
                                
                                	Specify the format as MAC or MSISDN
                                	**type**\:  :py:class:`Format <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId, self).__init__()

                                    self.yang_name = "calling-station-id"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("format", ("format", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format))])
                                    self._leafs = OrderedDict()

                                    self.format = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format()
                                    self.format.parent = self
                                    self._children_name_map["format"] = "format"
                                    self._segment_path = lambda: "calling-station-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId, [], name, value)


                                class Format(Entity):
                                    """
                                    Specify the format as MAC or MSISDN
                                    
                                    .. attribute:: mac_address
                                    
                                    	Expect MAC address to be present in CLID
                                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress>`
                                    
                                    .. attribute:: msisdn
                                    
                                    	Expect MSISDN value to be present in CLID
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format, self).__init__()

                                        self.yang_name = "format"
                                        self.yang_parent_name = "calling-station-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("mac-address", ("mac_address", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress))])
                                        self._leafs = OrderedDict([
                                            ('msisdn', (YLeaf(YType.empty, 'msisdn'), ['Empty'])),
                                        ])
                                        self.msisdn = None

                                        self.mac_address = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress()
                                        self.mac_address.parent = self
                                        self._children_name_map["mac_address"] = "mac-address"
                                        self._segment_path = lambda: "format"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format, ['msisdn'], name, value)


                                    class MacAddress(Entity):
                                        """
                                        Expect MAC address to be present in CLID
                                        
                                        .. attribute:: default
                                        
                                        	format ex\: 0000.4096.3e4a
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Default>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ietf
                                        
                                        	format ex\: 00\-00\-40\-96\-3E\-4A
                                        	**type**\:  :py:class:`Ietf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Ietf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: none
                                        
                                        	format unspecified
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: one_byte
                                        
                                        	format ex\: 00.00.40.96.3e.4a
                                        	**type**\:  :py:class:`OneByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte>`
                                        
                                        .. attribute:: three_byte
                                        
                                        	format ex\: 000040.963e4a
                                        	**type**\:  :py:class:`ThreeByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte>`
                                        
                                        .. attribute:: two_byte
                                        
                                        	format ex\: 0000.4096.3e4a
                                        	**type**\:  :py:class:`TwoByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte>`
                                        
                                        .. attribute:: unformatted
                                        
                                        	format ex\: 000040963e4a
                                        	**type**\:  :py:class:`Unformatted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Unformatted>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress, self).__init__()

                                            self.yang_name = "mac-address"
                                            self.yang_parent_name = "format"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Default)), ("ietf", ("ietf", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Ietf)), ("one-byte", ("one_byte", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte)), ("three-byte", ("three_byte", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte)), ("two-byte", ("two_byte", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte)), ("unformatted", ("unformatted", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Unformatted))])
                                            self._leafs = OrderedDict([
                                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                            ])
                                            self.none = None

                                            self.default = None
                                            self._children_name_map["default"] = "default"

                                            self.ietf = None
                                            self._children_name_map["ietf"] = "ietf"

                                            self.one_byte = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte()
                                            self.one_byte.parent = self
                                            self._children_name_map["one_byte"] = "one-byte"

                                            self.three_byte = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte()
                                            self.three_byte.parent = self
                                            self._children_name_map["three_byte"] = "three-byte"

                                            self.two_byte = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte()
                                            self.two_byte.parent = self
                                            self._children_name_map["two_byte"] = "two-byte"

                                            self.unformatted = None
                                            self._children_name_map["unformatted"] = "unformatted"
                                            self._segment_path = lambda: "mac-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress, ['none'], name, value)


                                        class Default(Entity):
                                            """
                                            format ex\: 0000.4096.3e4a
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Default.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Default.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Default, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class Ietf(Entity):
                                            """
                                            format ex\: 00\-00\-40\-96\-3E\-4A
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Ietf.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Ietf, self).__init__()

                                                self.yang_name = "ietf"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Ietf.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "ietf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Ietf, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class OneByte(Entity):
                                            """
                                            format ex\: 00.00.40.96.3e.4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte, self).__init__()

                                                self.yang_name = "one-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "one-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "one-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class ThreeByte(Entity):
                                            """
                                            format ex\: 000040.963e4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte, self).__init__()

                                                self.yang_name = "three-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "three-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "three-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class TwoByte(Entity):
                                            """
                                            format ex\: 0000.4096.3e4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte, self).__init__()

                                                self.yang_name = "two-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "two-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "two-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class Unformatted(Entity):
                                            """
                                            format ex\: 000040963e4a
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Unformatted.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Unformatted, self).__init__()

                                                self.yang_name = "unformatted"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Unformatted.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "unformatted"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.CallingStationId.Format.MacAddress.Unformatted, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                            class EapUser(Entity):
                                """
                                EAP users
                                
                                .. attribute:: ignore_open_session
                                
                                	for EAP authenticated users, open\-session is not supported
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.EapUser, self).__init__()

                                    self.yang_name = "eap-user"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore_open_session', (YLeaf(YType.empty, 'ignore-open-session'), ['Empty'])),
                                    ])
                                    self.ignore_open_session = None
                                    self._segment_path = lambda: "eap-user"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.EapUser, ['ignore_open_session'], name, value)


                            class Filter(Entity):
                                """
                                Configure filter
                                
                                .. attribute:: access
                                
                                	For access requests
                                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access>`
                                
                                .. attribute:: accounting
                                
                                	For accounting requests
                                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting>`
                                
                                .. attribute:: attribute
                                
                                	Filter attributes in packets sent to clients
                                	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Attribute>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("access", ("access", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access)), ("accounting", ("accounting", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting)), ("attribute", ("attribute", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Attribute))])
                                    self._leafs = OrderedDict()

                                    self.access = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access()
                                    self.access.parent = self
                                    self._children_name_map["access"] = "access"

                                    self.accounting = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting()
                                    self.accounting.parent = self
                                    self._children_name_map["accounting"] = "accounting"

                                    self.attribute = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Attribute()
                                    self.attribute.parent = self
                                    self._children_name_map["attribute"] = "attribute"
                                    self._segment_path = lambda: "filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter, [], name, value)


                                class Access(Entity):
                                    """
                                    For access requests
                                    
                                    .. attribute:: ack
                                    
                                    	Acknowledge the packet
                                    	**type**\:  :py:class:`Ack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Ack>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop the packet
                                    	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Drop>`
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore the packet for applying ISG features
                                    	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Ignore>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access, self).__init__()

                                        self.yang_name = "access"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ack", ("ack", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Ack)), ("drop", ("drop", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Drop)), ("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Ignore))])
                                        self._leafs = OrderedDict()

                                        self.ack = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Ack()
                                        self.ack.parent = self
                                        self._children_name_map["ack"] = "ack"

                                        self.drop = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Drop()
                                        self.drop.parent = self
                                        self._children_name_map["drop"] = "drop"

                                        self.ignore = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Ignore()
                                        self.ignore.parent = self
                                        self._children_name_map["ignore"] = "ignore"
                                        self._segment_path = lambda: "access"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access, [], name, value)


                                    class Ack(Entity):
                                        """
                                        Acknowledge the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Ack, self).__init__()

                                            self.yang_name = "ack"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Ack, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Drop(Entity):
                                        """
                                        Drop the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Drop, self).__init__()

                                            self.yang_name = "drop"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Drop, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Ignore(Entity):
                                        """
                                        Ignore the packet for applying ISG features
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Ignore, self).__init__()

                                            self.yang_name = "ignore"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ignore"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Access.Ignore, ['word1', 'word2', 'word3', 'word4'], name, value)


                                class Accounting(Entity):
                                    """
                                    For accounting requests
                                    
                                    .. attribute:: ack
                                    
                                    	Acknowledge the packet
                                    	**type**\:  :py:class:`Ack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Ack>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop the packet
                                    	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Drop>`
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore the packet for applying ISG features
                                    	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Ignore>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting, self).__init__()

                                        self.yang_name = "accounting"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ack", ("ack", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Ack)), ("drop", ("drop", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Drop)), ("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Ignore))])
                                        self._leafs = OrderedDict()

                                        self.ack = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Ack()
                                        self.ack.parent = self
                                        self._children_name_map["ack"] = "ack"

                                        self.drop = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Drop()
                                        self.drop.parent = self
                                        self._children_name_map["drop"] = "drop"

                                        self.ignore = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Ignore()
                                        self.ignore.parent = self
                                        self._children_name_map["ignore"] = "ignore"
                                        self._segment_path = lambda: "accounting"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting, [], name, value)


                                    class Ack(Entity):
                                        """
                                        Acknowledge the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Ack, self).__init__()

                                            self.yang_name = "ack"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Ack, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Drop(Entity):
                                        """
                                        Drop the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Drop, self).__init__()

                                            self.yang_name = "drop"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Drop, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Ignore(Entity):
                                        """
                                        Ignore the packet for applying ISG features
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Ignore, self).__init__()

                                            self.yang_name = "ignore"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ignore"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Accounting.Ignore, ['word1', 'word2', 'word3', 'word4'], name, value)


                                class Attribute(Entity):
                                    """
                                    Filter attributes in packets sent to clients
                                    
                                    .. attribute:: allow
                                    
                                    	Allow only the attributes specified in the list
                                    	**type**\: str
                                    
                                    .. attribute:: block
                                    
                                    	Block the attributes specified in the list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Attribute, self).__init__()

                                        self.yang_name = "attribute"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow', (YLeaf(YType.str, 'allow'), ['str'])),
                                            ('block', (YLeaf(YType.str, 'block'), ['str'])),
                                        ])
                                        self.allow = None
                                        self.block = None
                                        self._segment_path = lambda: "attribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Filter.Attribute, ['allow', 'block'], name, value)


                            class Key(Entity):
                                """
                                Specify a RADIUS client
                                
                                .. attribute:: key
                                
                                	
                                	**type**\:  :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Key.Key_>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIp.Client.Key.Key_')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.key = None
                                    self.string = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Key, ['key', 'string'], name, value)

                                class Key_(Enum):
                                    """
                                    Key\_ (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_6 = 1

                                    .. data:: Y_7 = 2

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_6 = Enum.YLeaf(1, "6")

                                    Y_7 = Enum.YLeaf(2, "7")



                            class MessageAuthenticator(Entity):
                                """
                                Message Authenticator attribute from Clients
                                
                                .. attribute:: ignore
                                
                                	Ignore checking of Message Authenticator attribute from\\ Clients
                                	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.MessageAuthenticator.Ignore>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.MessageAuthenticator, self).__init__()

                                    self.yang_name = "message-authenticator"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.MessageAuthenticator.Ignore))])
                                    self._leafs = OrderedDict()

                                    self.ignore = None
                                    self._children_name_map["ignore"] = "ignore"
                                    self._segment_path = lambda: "message-authenticator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.MessageAuthenticator, [], name, value)


                                class Ignore(Entity):
                                    """
                                    Ignore checking of Message Authenticator attribute from\\
                                    Clients
                                    
                                    .. attribute:: accounting
                                    
                                    	Ignore checking of Message Authenticator attribute from\\ accounting packets
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.MessageAuthenticator.Ignore, self).__init__()

                                        self.yang_name = "ignore"
                                        self.yang_parent_name = "message-authenticator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('accounting', (YLeaf(YType.empty, 'accounting'), ['Empty'])),
                                        ])
                                        self.accounting = None
                                        self._segment_path = lambda: "ignore"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.MessageAuthenticator.Ignore, ['accounting'], name, value)


                            class Mode(Entity):
                                """
                                Radius Proxy Pass thru mode
                                
                                .. attribute:: pass_through
                                
                                	Enable the pass\-through mode for Radius Proxy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Mode, self).__init__()

                                    self.yang_name = "mode"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pass_through', (YLeaf(YType.empty, 'pass-through'), ['Empty'])),
                                    ])
                                    self.pass_through = None
                                    self._segment_path = lambda: "mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Mode, ['pass_through'], name, value)


                            class PwlanSession(Entity):
                                """
                                PWLAN Reconnect feature
                                
                                .. attribute:: reconnect
                                
                                	Enable the reconnect feature for PWLAN RP sessions
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.PwlanSession, self).__init__()

                                    self.yang_name = "pwlan-session"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reconnect', (YLeaf(YType.empty, 'reconnect'), ['Empty'])),
                                    ])
                                    self.reconnect = None
                                    self._segment_path = lambda: "pwlan-session"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.PwlanSession, ['reconnect'], name, value)


                            class ReAuthentication(Entity):
                                """
                                Specify re\-authentication details
                                
                                .. attribute:: do_not_apply
                                
                                	Do not apply new data during re\-authentication
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.ReAuthentication, self).__init__()

                                    self.yang_name = "re-authentication"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('do_not_apply', (YLeaf(YType.empty, 'do-not-apply'), ['Empty'])),
                                    ])
                                    self.do_not_apply = None
                                    self._segment_path = lambda: "re-authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.ReAuthentication, ['do_not_apply'], name, value)


                            class SessionIdentifier(Entity):
                                """
                                This attribute will be used to correlate Radius \\
                                requests of a session and to identify sessions within \\
                                radius\-proxy
                                
                                .. attribute:: attribute
                                
                                	Specify an IETF Radius attribute
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: vsa
                                
                                	Specify Vendor\-Specific Attribute
                                	**type**\:  :py:class:`Vsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.SessionIdentifier.Vsa>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.SessionIdentifier, self).__init__()

                                    self.yang_name = "session-identifier"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vsa", ("vsa", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.SessionIdentifier.Vsa))])
                                    self._leafs = OrderedDict([
                                        ('attribute', (YLeaf(YType.uint8, 'attribute'), ['int'])),
                                    ])
                                    self.attribute = None

                                    self.vsa = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.SessionIdentifier.Vsa()
                                    self.vsa.parent = self
                                    self._children_name_map["vsa"] = "vsa"
                                    self._segment_path = lambda: "session-identifier"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.SessionIdentifier, ['attribute'], name, value)


                                class Vsa(Entity):
                                    """
                                    Specify Vendor\-Specific Attribute
                                    
                                    .. attribute:: vendor
                                    
                                    	Specify the vendor type
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: type
                                    
                                    	Give attribute type for vsa
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.SessionIdentifier.Vsa, self).__init__()

                                        self.yang_name = "vsa"
                                        self.yang_parent_name = "session-identifier"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vendor', (YLeaf(YType.uint16, 'vendor'), ['int'])),
                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                        ])
                                        self.vendor = None
                                        self.type = None
                                        self._segment_path = lambda: "vsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.SessionIdentifier.Vsa, ['vendor', 'type'], name, value)


                            class Timer(Entity):
                                """
                                Configure RADIUS proxy timer values
                                
                                .. attribute:: disconnect
                                
                                	Specify disconnect timer
                                	**type**\:  :py:class:`Disconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Timer.Disconnect>`
                                
                                .. attribute:: ip_address
                                
                                	Specify value of wait for IP timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: reconnect
                                
                                	Specify value of wait for reconnect timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: request
                                
                                	Specify value of wait for Access\-Request timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: roaming
                                
                                	Specify value of wait for roaming timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Timer, self).__init__()

                                    self.yang_name = "timer"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disconnect", ("disconnect", Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Timer.Disconnect))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.uint16, 'ip-address'), ['int'])),
                                        ('reconnect', (YLeaf(YType.uint16, 'reconnect'), ['int'])),
                                        ('request', (YLeaf(YType.uint16, 'request'), ['int'])),
                                        ('roaming', (YLeaf(YType.uint16, 'roaming'), ['int'])),
                                    ])
                                    self.ip_address = None
                                    self.reconnect = None
                                    self.request = None
                                    self.roaming = None

                                    self.disconnect = Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Timer.Disconnect()
                                    self.disconnect.parent = self
                                    self._children_name_map["disconnect"] = "disconnect"
                                    self._segment_path = lambda: "timer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Timer, ['ip_address', 'reconnect', 'request', 'roaming'], name, value)


                                class Disconnect(Entity):
                                    """
                                    Specify disconnect timer
                                    
                                    .. attribute:: acct_stop
                                    
                                    	Specify disconnect delay timer for accounting stop
                                    	**type**\: int
                                    
                                    	**range:** 0..43200
                                    
                                    .. attribute:: reauth_fail
                                    
                                    	Specify disconnect delay timer for reauthentication failure
                                    	**type**\: int
                                    
                                    	**range:** 0..43200
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Timer.Disconnect, self).__init__()

                                        self.yang_name = "disconnect"
                                        self.yang_parent_name = "timer"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('acct_stop', (YLeaf(YType.uint16, 'acct-stop'), ['int'])),
                                            ('reauth_fail', (YLeaf(YType.uint16, 'reauth-fail'), ['int'])),
                                        ])
                                        self.acct_stop = None
                                        self.reauth_fail = None
                                        self._segment_path = lambda: "disconnect"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIp.Client.Timer.Disconnect, ['acct_stop', 'reauth_fail'], name, value)


                    class ClientIpMask(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Specify a RADIUS client
                        	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMask, self).__init__()

                            self.yang_name = "client-ip-mask"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client", ("client", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client))])
                            self._leafs = OrderedDict()

                            self.client = YList(self)
                            self._segment_path = lambda: "client-ip-mask"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask, [], name, value)


                        class Client(Entity):
                            """
                            Specify a RADIUS client
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            .. attribute:: mask  (key)
                            
                            	Network mask or prefix length
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** /(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: accounting
                            
                            	Specify accounting details
                            	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Accounting>`
                            
                            .. attribute:: authentication
                            
                            	Specify authentication details
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Authentication>`
                            
                            .. attribute:: calling_station_id
                            
                            	Specify format of Calling\-Station\-Id, attribute\\ 31.Default format is to expect mac\-address in\\ calling\-station\-id
                            	**type**\:  :py:class:`CallingStationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId>`
                            
                            .. attribute:: eap_user
                            
                            	EAP users
                            	**type**\:  :py:class:`EapUser <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.EapUser>`
                            
                            .. attribute:: filter
                            
                            	Configure filter
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter>`
                            
                            .. attribute:: key
                            
                            	Specify a RADIUS client
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Key>`
                            
                            .. attribute:: message_authenticator
                            
                            	Message Authenticator attribute from Clients
                            	**type**\:  :py:class:`MessageAuthenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.MessageAuthenticator>`
                            
                            .. attribute:: mode
                            
                            	Radius Proxy Pass thru mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Mode>`
                            
                            .. attribute:: pwlan_session
                            
                            	PWLAN Reconnect feature
                            	**type**\:  :py:class:`PwlanSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.PwlanSession>`
                            
                            .. attribute:: re_authentication
                            
                            	Specify re\-authentication details
                            	**type**\:  :py:class:`ReAuthentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.ReAuthentication>`
                            
                            .. attribute:: session_identifier
                            
                            	This attribute will be used to correlate Radius \\ requests of a session and to identify sessions within \\ radius\-proxy
                            	**type**\:  :py:class:`SessionIdentifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.SessionIdentifier>`
                            
                            .. attribute:: timer
                            
                            	Configure RADIUS proxy timer values
                            	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Timer>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client, self).__init__()

                                self.yang_name = "client"
                                self.yang_parent_name = "client-ip-mask"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip','mask']
                                self._child_classes = OrderedDict([("accounting", ("accounting", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Accounting)), ("authentication", ("authentication", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Authentication)), ("calling-station-id", ("calling_station_id", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId)), ("eap-user", ("eap_user", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.EapUser)), ("filter", ("filter", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter)), ("key", ("key", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Key)), ("message-authenticator", ("message_authenticator", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.MessageAuthenticator)), ("mode", ("mode", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Mode)), ("pwlan-session", ("pwlan_session", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.PwlanSession)), ("re-authentication", ("re_authentication", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.ReAuthentication)), ("session-identifier", ("session_identifier", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.SessionIdentifier)), ("timer", ("timer", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Timer))])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str','str','str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str','str'])),
                                ])
                                self.ip = None
                                self.mask = None

                                self.accounting = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Accounting()
                                self.accounting.parent = self
                                self._children_name_map["accounting"] = "accounting"

                                self.authentication = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"

                                self.calling_station_id = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId()
                                self.calling_station_id.parent = self
                                self._children_name_map["calling_station_id"] = "calling-station-id"

                                self.eap_user = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.EapUser()
                                self.eap_user.parent = self
                                self._children_name_map["eap_user"] = "eap-user"

                                self.filter = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"

                                self.key = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"

                                self.message_authenticator = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.MessageAuthenticator()
                                self.message_authenticator.parent = self
                                self._children_name_map["message_authenticator"] = "message-authenticator"

                                self.mode = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Mode()
                                self.mode.parent = self
                                self._children_name_map["mode"] = "mode"

                                self.pwlan_session = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.PwlanSession()
                                self.pwlan_session.parent = self
                                self._children_name_map["pwlan_session"] = "pwlan-session"

                                self.re_authentication = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.ReAuthentication()
                                self.re_authentication.parent = self
                                self._children_name_map["re_authentication"] = "re-authentication"

                                self.session_identifier = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.SessionIdentifier()
                                self.session_identifier.parent = self
                                self._children_name_map["session_identifier"] = "session-identifier"

                                self.timer = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Timer()
                                self.timer.parent = self
                                self._children_name_map["timer"] = "timer"
                                self._segment_path = lambda: "client" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/client-ip-mask/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client, ['ip', 'mask'], name, value)


                            class Accounting(Entity):
                                """
                                Specify accounting details
                                
                                .. attribute:: method_list
                                
                                	Authentication method list details
                                	**type**\:  :py:class:`MethodList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Accounting.MethodList>`
                                
                                .. attribute:: port
                                
                                	Radius server port
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Accounting, self).__init__()

                                    self.yang_name = "accounting"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("method-list", ("method_list", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Accounting.MethodList))])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                    ])
                                    self.port = None

                                    self.method_list = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Accounting.MethodList()
                                    self.method_list.parent = self
                                    self._children_name_map["method_list"] = "method-list"
                                    self._segment_path = lambda: "accounting"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Accounting, ['port'], name, value)


                                class MethodList(Entity):
                                    """
                                    Authentication method list details
                                    
                                    .. attribute:: method_name
                                    
                                    	Method list name
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	The default authentication list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Accounting.MethodList, self).__init__()

                                        self.yang_name = "method-list"
                                        self.yang_parent_name = "accounting"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('method_name', (YLeaf(YType.str, 'method-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ])
                                        self.method_name = None
                                        self.default = None
                                        self._segment_path = lambda: "method-list"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Accounting.MethodList, ['method_name', 'default'], name, value)


                            class Authentication(Entity):
                                """
                                Specify authentication details
                                
                                .. attribute:: method_list
                                
                                	Authentication method list details
                                	**type**\:  :py:class:`MethodList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Authentication.MethodList>`
                                
                                .. attribute:: port
                                
                                	Radius server port
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("method-list", ("method_list", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Authentication.MethodList))])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                    ])
                                    self.port = None

                                    self.method_list = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Authentication.MethodList()
                                    self.method_list.parent = self
                                    self._children_name_map["method_list"] = "method-list"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Authentication, ['port'], name, value)


                                class MethodList(Entity):
                                    """
                                    Authentication method list details
                                    
                                    .. attribute:: method_name
                                    
                                    	Method list name
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	The default authentication list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Authentication.MethodList, self).__init__()

                                        self.yang_name = "method-list"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('method_name', (YLeaf(YType.str, 'method-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ])
                                        self.method_name = None
                                        self.default = None
                                        self._segment_path = lambda: "method-list"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Authentication.MethodList, ['method_name', 'default'], name, value)


                            class CallingStationId(Entity):
                                """
                                Specify format of Calling\-Station\-Id, attribute\\
                                31.Default format is to expect mac\-address in\\
                                calling\-station\-id
                                
                                .. attribute:: format
                                
                                	Specify the format as MAC or MSISDN
                                	**type**\:  :py:class:`Format <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId, self).__init__()

                                    self.yang_name = "calling-station-id"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("format", ("format", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format))])
                                    self._leafs = OrderedDict()

                                    self.format = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format()
                                    self.format.parent = self
                                    self._children_name_map["format"] = "format"
                                    self._segment_path = lambda: "calling-station-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId, [], name, value)


                                class Format(Entity):
                                    """
                                    Specify the format as MAC or MSISDN
                                    
                                    .. attribute:: mac_address
                                    
                                    	Expect MAC address to be present in CLID
                                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress>`
                                    
                                    .. attribute:: msisdn
                                    
                                    	Expect MSISDN value to be present in CLID
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format, self).__init__()

                                        self.yang_name = "format"
                                        self.yang_parent_name = "calling-station-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("mac-address", ("mac_address", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress))])
                                        self._leafs = OrderedDict([
                                            ('msisdn', (YLeaf(YType.empty, 'msisdn'), ['Empty'])),
                                        ])
                                        self.msisdn = None

                                        self.mac_address = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress()
                                        self.mac_address.parent = self
                                        self._children_name_map["mac_address"] = "mac-address"
                                        self._segment_path = lambda: "format"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format, ['msisdn'], name, value)


                                    class MacAddress(Entity):
                                        """
                                        Expect MAC address to be present in CLID
                                        
                                        .. attribute:: default
                                        
                                        	format ex\: 0000.4096.3e4a
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Default>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ietf
                                        
                                        	format ex\: 00\-00\-40\-96\-3E\-4A
                                        	**type**\:  :py:class:`Ietf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Ietf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: none
                                        
                                        	format unspecified
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: one_byte
                                        
                                        	format ex\: 00.00.40.96.3e.4a
                                        	**type**\:  :py:class:`OneByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte>`
                                        
                                        .. attribute:: three_byte
                                        
                                        	format ex\: 000040.963e4a
                                        	**type**\:  :py:class:`ThreeByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte>`
                                        
                                        .. attribute:: two_byte
                                        
                                        	format ex\: 0000.4096.3e4a
                                        	**type**\:  :py:class:`TwoByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte>`
                                        
                                        .. attribute:: unformatted
                                        
                                        	format ex\: 000040963e4a
                                        	**type**\:  :py:class:`Unformatted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Unformatted>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress, self).__init__()

                                            self.yang_name = "mac-address"
                                            self.yang_parent_name = "format"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Default)), ("ietf", ("ietf", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Ietf)), ("one-byte", ("one_byte", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte)), ("three-byte", ("three_byte", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte)), ("two-byte", ("two_byte", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte)), ("unformatted", ("unformatted", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Unformatted))])
                                            self._leafs = OrderedDict([
                                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                            ])
                                            self.none = None

                                            self.default = None
                                            self._children_name_map["default"] = "default"

                                            self.ietf = None
                                            self._children_name_map["ietf"] = "ietf"

                                            self.one_byte = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte()
                                            self.one_byte.parent = self
                                            self._children_name_map["one_byte"] = "one-byte"

                                            self.three_byte = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte()
                                            self.three_byte.parent = self
                                            self._children_name_map["three_byte"] = "three-byte"

                                            self.two_byte = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte()
                                            self.two_byte.parent = self
                                            self._children_name_map["two_byte"] = "two-byte"

                                            self.unformatted = None
                                            self._children_name_map["unformatted"] = "unformatted"
                                            self._segment_path = lambda: "mac-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress, ['none'], name, value)


                                        class Default(Entity):
                                            """
                                            format ex\: 0000.4096.3e4a
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Default.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Default.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Default, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class Ietf(Entity):
                                            """
                                            format ex\: 00\-00\-40\-96\-3E\-4A
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Ietf.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Ietf, self).__init__()

                                                self.yang_name = "ietf"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Ietf.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "ietf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Ietf, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class OneByte(Entity):
                                            """
                                            format ex\: 00.00.40.96.3e.4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte, self).__init__()

                                                self.yang_name = "one-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "one-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "one-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class ThreeByte(Entity):
                                            """
                                            format ex\: 000040.963e4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte, self).__init__()

                                                self.yang_name = "three-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "three-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "three-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class TwoByte(Entity):
                                            """
                                            format ex\: 0000.4096.3e4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte, self).__init__()

                                                self.yang_name = "two-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "two-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "two-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class Unformatted(Entity):
                                            """
                                            format ex\: 000040963e4a
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Unformatted.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Unformatted, self).__init__()

                                                self.yang_name = "unformatted"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Unformatted.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "unformatted"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.CallingStationId.Format.MacAddress.Unformatted, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                            class EapUser(Entity):
                                """
                                EAP users
                                
                                .. attribute:: ignore_open_session
                                
                                	for EAP authenticated users, open\-session is not supported
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.EapUser, self).__init__()

                                    self.yang_name = "eap-user"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore_open_session', (YLeaf(YType.empty, 'ignore-open-session'), ['Empty'])),
                                    ])
                                    self.ignore_open_session = None
                                    self._segment_path = lambda: "eap-user"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.EapUser, ['ignore_open_session'], name, value)


                            class Filter(Entity):
                                """
                                Configure filter
                                
                                .. attribute:: access
                                
                                	For access requests
                                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access>`
                                
                                .. attribute:: accounting
                                
                                	For accounting requests
                                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting>`
                                
                                .. attribute:: attribute
                                
                                	Filter attributes in packets sent to clients
                                	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Attribute>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("access", ("access", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access)), ("accounting", ("accounting", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting)), ("attribute", ("attribute", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Attribute))])
                                    self._leafs = OrderedDict()

                                    self.access = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access()
                                    self.access.parent = self
                                    self._children_name_map["access"] = "access"

                                    self.accounting = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting()
                                    self.accounting.parent = self
                                    self._children_name_map["accounting"] = "accounting"

                                    self.attribute = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Attribute()
                                    self.attribute.parent = self
                                    self._children_name_map["attribute"] = "attribute"
                                    self._segment_path = lambda: "filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter, [], name, value)


                                class Access(Entity):
                                    """
                                    For access requests
                                    
                                    .. attribute:: ack
                                    
                                    	Acknowledge the packet
                                    	**type**\:  :py:class:`Ack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Ack>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop the packet
                                    	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Drop>`
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore the packet for applying ISG features
                                    	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Ignore>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access, self).__init__()

                                        self.yang_name = "access"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ack", ("ack", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Ack)), ("drop", ("drop", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Drop)), ("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Ignore))])
                                        self._leafs = OrderedDict()

                                        self.ack = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Ack()
                                        self.ack.parent = self
                                        self._children_name_map["ack"] = "ack"

                                        self.drop = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Drop()
                                        self.drop.parent = self
                                        self._children_name_map["drop"] = "drop"

                                        self.ignore = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Ignore()
                                        self.ignore.parent = self
                                        self._children_name_map["ignore"] = "ignore"
                                        self._segment_path = lambda: "access"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access, [], name, value)


                                    class Ack(Entity):
                                        """
                                        Acknowledge the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Ack, self).__init__()

                                            self.yang_name = "ack"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Ack, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Drop(Entity):
                                        """
                                        Drop the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Drop, self).__init__()

                                            self.yang_name = "drop"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Drop, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Ignore(Entity):
                                        """
                                        Ignore the packet for applying ISG features
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Ignore, self).__init__()

                                            self.yang_name = "ignore"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ignore"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Access.Ignore, ['word1', 'word2', 'word3', 'word4'], name, value)


                                class Accounting(Entity):
                                    """
                                    For accounting requests
                                    
                                    .. attribute:: ack
                                    
                                    	Acknowledge the packet
                                    	**type**\:  :py:class:`Ack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Ack>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop the packet
                                    	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Drop>`
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore the packet for applying ISG features
                                    	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Ignore>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting, self).__init__()

                                        self.yang_name = "accounting"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ack", ("ack", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Ack)), ("drop", ("drop", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Drop)), ("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Ignore))])
                                        self._leafs = OrderedDict()

                                        self.ack = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Ack()
                                        self.ack.parent = self
                                        self._children_name_map["ack"] = "ack"

                                        self.drop = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Drop()
                                        self.drop.parent = self
                                        self._children_name_map["drop"] = "drop"

                                        self.ignore = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Ignore()
                                        self.ignore.parent = self
                                        self._children_name_map["ignore"] = "ignore"
                                        self._segment_path = lambda: "accounting"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting, [], name, value)


                                    class Ack(Entity):
                                        """
                                        Acknowledge the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Ack, self).__init__()

                                            self.yang_name = "ack"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Ack, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Drop(Entity):
                                        """
                                        Drop the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Drop, self).__init__()

                                            self.yang_name = "drop"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Drop, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Ignore(Entity):
                                        """
                                        Ignore the packet for applying ISG features
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Ignore, self).__init__()

                                            self.yang_name = "ignore"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ignore"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Accounting.Ignore, ['word1', 'word2', 'word3', 'word4'], name, value)


                                class Attribute(Entity):
                                    """
                                    Filter attributes in packets sent to clients
                                    
                                    .. attribute:: allow
                                    
                                    	Allow only the attributes specified in the list
                                    	**type**\: str
                                    
                                    .. attribute:: block
                                    
                                    	Block the attributes specified in the list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Attribute, self).__init__()

                                        self.yang_name = "attribute"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow', (YLeaf(YType.str, 'allow'), ['str'])),
                                            ('block', (YLeaf(YType.str, 'block'), ['str'])),
                                        ])
                                        self.allow = None
                                        self.block = None
                                        self._segment_path = lambda: "attribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Filter.Attribute, ['allow', 'block'], name, value)


                            class Key(Entity):
                                """
                                Specify a RADIUS client
                                
                                .. attribute:: key
                                
                                	
                                	**type**\:  :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Key.Key_>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMask.Client.Key.Key_')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.key = None
                                    self.string = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Key, ['key', 'string'], name, value)

                                class Key_(Enum):
                                    """
                                    Key\_ (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_6 = 1

                                    .. data:: Y_7 = 2

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_6 = Enum.YLeaf(1, "6")

                                    Y_7 = Enum.YLeaf(2, "7")



                            class MessageAuthenticator(Entity):
                                """
                                Message Authenticator attribute from Clients
                                
                                .. attribute:: ignore
                                
                                	Ignore checking of Message Authenticator attribute from\\ Clients
                                	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.MessageAuthenticator.Ignore>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.MessageAuthenticator, self).__init__()

                                    self.yang_name = "message-authenticator"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.MessageAuthenticator.Ignore))])
                                    self._leafs = OrderedDict()

                                    self.ignore = None
                                    self._children_name_map["ignore"] = "ignore"
                                    self._segment_path = lambda: "message-authenticator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.MessageAuthenticator, [], name, value)


                                class Ignore(Entity):
                                    """
                                    Ignore checking of Message Authenticator attribute from\\
                                    Clients
                                    
                                    .. attribute:: accounting
                                    
                                    	Ignore checking of Message Authenticator attribute from\\ accounting packets
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.MessageAuthenticator.Ignore, self).__init__()

                                        self.yang_name = "ignore"
                                        self.yang_parent_name = "message-authenticator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('accounting', (YLeaf(YType.empty, 'accounting'), ['Empty'])),
                                        ])
                                        self.accounting = None
                                        self._segment_path = lambda: "ignore"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.MessageAuthenticator.Ignore, ['accounting'], name, value)


                            class Mode(Entity):
                                """
                                Radius Proxy Pass thru mode
                                
                                .. attribute:: pass_through
                                
                                	Enable the pass\-through mode for Radius Proxy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Mode, self).__init__()

                                    self.yang_name = "mode"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pass_through', (YLeaf(YType.empty, 'pass-through'), ['Empty'])),
                                    ])
                                    self.pass_through = None
                                    self._segment_path = lambda: "mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Mode, ['pass_through'], name, value)


                            class PwlanSession(Entity):
                                """
                                PWLAN Reconnect feature
                                
                                .. attribute:: reconnect
                                
                                	Enable the reconnect feature for PWLAN RP sessions
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.PwlanSession, self).__init__()

                                    self.yang_name = "pwlan-session"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reconnect', (YLeaf(YType.empty, 'reconnect'), ['Empty'])),
                                    ])
                                    self.reconnect = None
                                    self._segment_path = lambda: "pwlan-session"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.PwlanSession, ['reconnect'], name, value)


                            class ReAuthentication(Entity):
                                """
                                Specify re\-authentication details
                                
                                .. attribute:: do_not_apply
                                
                                	Do not apply new data during re\-authentication
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.ReAuthentication, self).__init__()

                                    self.yang_name = "re-authentication"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('do_not_apply', (YLeaf(YType.empty, 'do-not-apply'), ['Empty'])),
                                    ])
                                    self.do_not_apply = None
                                    self._segment_path = lambda: "re-authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.ReAuthentication, ['do_not_apply'], name, value)


                            class SessionIdentifier(Entity):
                                """
                                This attribute will be used to correlate Radius \\
                                requests of a session and to identify sessions within \\
                                radius\-proxy
                                
                                .. attribute:: attribute
                                
                                	Specify an IETF Radius attribute
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: vsa
                                
                                	Specify Vendor\-Specific Attribute
                                	**type**\:  :py:class:`Vsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.SessionIdentifier.Vsa>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.SessionIdentifier, self).__init__()

                                    self.yang_name = "session-identifier"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vsa", ("vsa", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.SessionIdentifier.Vsa))])
                                    self._leafs = OrderedDict([
                                        ('attribute', (YLeaf(YType.uint8, 'attribute'), ['int'])),
                                    ])
                                    self.attribute = None

                                    self.vsa = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.SessionIdentifier.Vsa()
                                    self.vsa.parent = self
                                    self._children_name_map["vsa"] = "vsa"
                                    self._segment_path = lambda: "session-identifier"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.SessionIdentifier, ['attribute'], name, value)


                                class Vsa(Entity):
                                    """
                                    Specify Vendor\-Specific Attribute
                                    
                                    .. attribute:: vendor
                                    
                                    	Specify the vendor type
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: type
                                    
                                    	Give attribute type for vsa
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.SessionIdentifier.Vsa, self).__init__()

                                        self.yang_name = "vsa"
                                        self.yang_parent_name = "session-identifier"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vendor', (YLeaf(YType.uint16, 'vendor'), ['int'])),
                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                        ])
                                        self.vendor = None
                                        self.type = None
                                        self._segment_path = lambda: "vsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.SessionIdentifier.Vsa, ['vendor', 'type'], name, value)


                            class Timer(Entity):
                                """
                                Configure RADIUS proxy timer values
                                
                                .. attribute:: disconnect
                                
                                	Specify disconnect timer
                                	**type**\:  :py:class:`Disconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Timer.Disconnect>`
                                
                                .. attribute:: ip_address
                                
                                	Specify value of wait for IP timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: reconnect
                                
                                	Specify value of wait for reconnect timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: request
                                
                                	Specify value of wait for Access\-Request timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: roaming
                                
                                	Specify value of wait for roaming timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Timer, self).__init__()

                                    self.yang_name = "timer"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disconnect", ("disconnect", Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Timer.Disconnect))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.uint16, 'ip-address'), ['int'])),
                                        ('reconnect', (YLeaf(YType.uint16, 'reconnect'), ['int'])),
                                        ('request', (YLeaf(YType.uint16, 'request'), ['int'])),
                                        ('roaming', (YLeaf(YType.uint16, 'roaming'), ['int'])),
                                    ])
                                    self.ip_address = None
                                    self.reconnect = None
                                    self.request = None
                                    self.roaming = None

                                    self.disconnect = Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Timer.Disconnect()
                                    self.disconnect.parent = self
                                    self._children_name_map["disconnect"] = "disconnect"
                                    self._segment_path = lambda: "timer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Timer, ['ip_address', 'reconnect', 'request', 'roaming'], name, value)


                                class Disconnect(Entity):
                                    """
                                    Specify disconnect timer
                                    
                                    .. attribute:: acct_stop
                                    
                                    	Specify disconnect delay timer for accounting stop
                                    	**type**\: int
                                    
                                    	**range:** 0..43200
                                    
                                    .. attribute:: reauth_fail
                                    
                                    	Specify disconnect delay timer for reauthentication failure
                                    	**type**\: int
                                    
                                    	**range:** 0..43200
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Timer.Disconnect, self).__init__()

                                        self.yang_name = "disconnect"
                                        self.yang_parent_name = "timer"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('acct_stop', (YLeaf(YType.uint16, 'acct-stop'), ['int'])),
                                            ('reauth_fail', (YLeaf(YType.uint16, 'reauth-fail'), ['int'])),
                                        ])
                                        self.acct_stop = None
                                        self.reauth_fail = None
                                        self._segment_path = lambda: "disconnect"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMask.Client.Timer.Disconnect, ['acct_stop', 'reauth_fail'], name, value)


                    class ClientIpVrf(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Specify a RADIUS client
                        	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf, self).__init__()

                            self.yang_name = "client-ip-vrf"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client", ("client", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client))])
                            self._leafs = OrderedDict()

                            self.client = YList(self)
                            self._segment_path = lambda: "client-ip-vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf, [], name, value)


                        class Client(Entity):
                            """
                            Specify a RADIUS client
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            .. attribute:: vrf  (key)
                            
                            	Virtual Routing/Forwarding parameters
                            	**type**\: str
                            
                            .. attribute:: accounting
                            
                            	Specify accounting details
                            	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Accounting>`
                            
                            .. attribute:: authentication
                            
                            	Specify authentication details
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Authentication>`
                            
                            .. attribute:: calling_station_id
                            
                            	Specify format of Calling\-Station\-Id, attribute\\ 31.Default format is to expect mac\-address in\\ calling\-station\-id
                            	**type**\:  :py:class:`CallingStationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId>`
                            
                            .. attribute:: eap_user
                            
                            	EAP users
                            	**type**\:  :py:class:`EapUser <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.EapUser>`
                            
                            .. attribute:: filter
                            
                            	Configure filter
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter>`
                            
                            .. attribute:: key
                            
                            	Specify a RADIUS client
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Key>`
                            
                            .. attribute:: message_authenticator
                            
                            	Message Authenticator attribute from Clients
                            	**type**\:  :py:class:`MessageAuthenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.MessageAuthenticator>`
                            
                            .. attribute:: mode
                            
                            	Radius Proxy Pass thru mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Mode>`
                            
                            .. attribute:: pwlan_session
                            
                            	PWLAN Reconnect feature
                            	**type**\:  :py:class:`PwlanSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.PwlanSession>`
                            
                            .. attribute:: re_authentication
                            
                            	Specify re\-authentication details
                            	**type**\:  :py:class:`ReAuthentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.ReAuthentication>`
                            
                            .. attribute:: session_identifier
                            
                            	This attribute will be used to correlate Radius \\ requests of a session and to identify sessions within \\ radius\-proxy
                            	**type**\:  :py:class:`SessionIdentifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.SessionIdentifier>`
                            
                            .. attribute:: timer
                            
                            	Configure RADIUS proxy timer values
                            	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Timer>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client, self).__init__()

                                self.yang_name = "client"
                                self.yang_parent_name = "client-ip-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip','vrf']
                                self._child_classes = OrderedDict([("accounting", ("accounting", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Accounting)), ("authentication", ("authentication", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Authentication)), ("calling-station-id", ("calling_station_id", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId)), ("eap-user", ("eap_user", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.EapUser)), ("filter", ("filter", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter)), ("key", ("key", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Key)), ("message-authenticator", ("message_authenticator", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.MessageAuthenticator)), ("mode", ("mode", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Mode)), ("pwlan-session", ("pwlan_session", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.PwlanSession)), ("re-authentication", ("re_authentication", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.ReAuthentication)), ("session-identifier", ("session_identifier", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.SessionIdentifier)), ("timer", ("timer", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Timer))])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str','str','str'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.ip = None
                                self.vrf = None

                                self.accounting = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Accounting()
                                self.accounting.parent = self
                                self._children_name_map["accounting"] = "accounting"

                                self.authentication = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"

                                self.calling_station_id = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId()
                                self.calling_station_id.parent = self
                                self._children_name_map["calling_station_id"] = "calling-station-id"

                                self.eap_user = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.EapUser()
                                self.eap_user.parent = self
                                self._children_name_map["eap_user"] = "eap-user"

                                self.filter = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"

                                self.key = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"

                                self.message_authenticator = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.MessageAuthenticator()
                                self.message_authenticator.parent = self
                                self._children_name_map["message_authenticator"] = "message-authenticator"

                                self.mode = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Mode()
                                self.mode.parent = self
                                self._children_name_map["mode"] = "mode"

                                self.pwlan_session = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.PwlanSession()
                                self.pwlan_session.parent = self
                                self._children_name_map["pwlan_session"] = "pwlan-session"

                                self.re_authentication = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.ReAuthentication()
                                self.re_authentication.parent = self
                                self._children_name_map["re_authentication"] = "re-authentication"

                                self.session_identifier = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.SessionIdentifier()
                                self.session_identifier.parent = self
                                self._children_name_map["session_identifier"] = "session-identifier"

                                self.timer = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Timer()
                                self.timer.parent = self
                                self._children_name_map["timer"] = "timer"
                                self._segment_path = lambda: "client" + "[ip='" + str(self.ip) + "']" + "[vrf='" + str(self.vrf) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/client-ip-vrf/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client, ['ip', 'vrf'], name, value)


                            class Accounting(Entity):
                                """
                                Specify accounting details
                                
                                .. attribute:: method_list
                                
                                	Authentication method list details
                                	**type**\:  :py:class:`MethodList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Accounting.MethodList>`
                                
                                .. attribute:: port
                                
                                	Radius server port
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Accounting, self).__init__()

                                    self.yang_name = "accounting"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("method-list", ("method_list", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Accounting.MethodList))])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                    ])
                                    self.port = None

                                    self.method_list = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Accounting.MethodList()
                                    self.method_list.parent = self
                                    self._children_name_map["method_list"] = "method-list"
                                    self._segment_path = lambda: "accounting"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Accounting, ['port'], name, value)


                                class MethodList(Entity):
                                    """
                                    Authentication method list details
                                    
                                    .. attribute:: method_name
                                    
                                    	Method list name
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	The default authentication list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Accounting.MethodList, self).__init__()

                                        self.yang_name = "method-list"
                                        self.yang_parent_name = "accounting"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('method_name', (YLeaf(YType.str, 'method-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ])
                                        self.method_name = None
                                        self.default = None
                                        self._segment_path = lambda: "method-list"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Accounting.MethodList, ['method_name', 'default'], name, value)


                            class Authentication(Entity):
                                """
                                Specify authentication details
                                
                                .. attribute:: method_list
                                
                                	Authentication method list details
                                	**type**\:  :py:class:`MethodList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Authentication.MethodList>`
                                
                                .. attribute:: port
                                
                                	Radius server port
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("method-list", ("method_list", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Authentication.MethodList))])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                    ])
                                    self.port = None

                                    self.method_list = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Authentication.MethodList()
                                    self.method_list.parent = self
                                    self._children_name_map["method_list"] = "method-list"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Authentication, ['port'], name, value)


                                class MethodList(Entity):
                                    """
                                    Authentication method list details
                                    
                                    .. attribute:: method_name
                                    
                                    	Method list name
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	The default authentication list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Authentication.MethodList, self).__init__()

                                        self.yang_name = "method-list"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('method_name', (YLeaf(YType.str, 'method-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ])
                                        self.method_name = None
                                        self.default = None
                                        self._segment_path = lambda: "method-list"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Authentication.MethodList, ['method_name', 'default'], name, value)


                            class CallingStationId(Entity):
                                """
                                Specify format of Calling\-Station\-Id, attribute\\
                                31.Default format is to expect mac\-address in\\
                                calling\-station\-id
                                
                                .. attribute:: format
                                
                                	Specify the format as MAC or MSISDN
                                	**type**\:  :py:class:`Format <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId, self).__init__()

                                    self.yang_name = "calling-station-id"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("format", ("format", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format))])
                                    self._leafs = OrderedDict()

                                    self.format = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format()
                                    self.format.parent = self
                                    self._children_name_map["format"] = "format"
                                    self._segment_path = lambda: "calling-station-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId, [], name, value)


                                class Format(Entity):
                                    """
                                    Specify the format as MAC or MSISDN
                                    
                                    .. attribute:: mac_address
                                    
                                    	Expect MAC address to be present in CLID
                                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress>`
                                    
                                    .. attribute:: msisdn
                                    
                                    	Expect MSISDN value to be present in CLID
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format, self).__init__()

                                        self.yang_name = "format"
                                        self.yang_parent_name = "calling-station-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("mac-address", ("mac_address", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress))])
                                        self._leafs = OrderedDict([
                                            ('msisdn', (YLeaf(YType.empty, 'msisdn'), ['Empty'])),
                                        ])
                                        self.msisdn = None

                                        self.mac_address = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress()
                                        self.mac_address.parent = self
                                        self._children_name_map["mac_address"] = "mac-address"
                                        self._segment_path = lambda: "format"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format, ['msisdn'], name, value)


                                    class MacAddress(Entity):
                                        """
                                        Expect MAC address to be present in CLID
                                        
                                        .. attribute:: default
                                        
                                        	format ex\: 0000.4096.3e4a
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Default>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ietf
                                        
                                        	format ex\: 00\-00\-40\-96\-3E\-4A
                                        	**type**\:  :py:class:`Ietf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Ietf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: none
                                        
                                        	format unspecified
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: one_byte
                                        
                                        	format ex\: 00.00.40.96.3e.4a
                                        	**type**\:  :py:class:`OneByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte>`
                                        
                                        .. attribute:: three_byte
                                        
                                        	format ex\: 000040.963e4a
                                        	**type**\:  :py:class:`ThreeByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte>`
                                        
                                        .. attribute:: two_byte
                                        
                                        	format ex\: 0000.4096.3e4a
                                        	**type**\:  :py:class:`TwoByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte>`
                                        
                                        .. attribute:: unformatted
                                        
                                        	format ex\: 000040963e4a
                                        	**type**\:  :py:class:`Unformatted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Unformatted>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress, self).__init__()

                                            self.yang_name = "mac-address"
                                            self.yang_parent_name = "format"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Default)), ("ietf", ("ietf", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Ietf)), ("one-byte", ("one_byte", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte)), ("three-byte", ("three_byte", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte)), ("two-byte", ("two_byte", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte)), ("unformatted", ("unformatted", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Unformatted))])
                                            self._leafs = OrderedDict([
                                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                            ])
                                            self.none = None

                                            self.default = None
                                            self._children_name_map["default"] = "default"

                                            self.ietf = None
                                            self._children_name_map["ietf"] = "ietf"

                                            self.one_byte = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte()
                                            self.one_byte.parent = self
                                            self._children_name_map["one_byte"] = "one-byte"

                                            self.three_byte = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte()
                                            self.three_byte.parent = self
                                            self._children_name_map["three_byte"] = "three-byte"

                                            self.two_byte = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte()
                                            self.two_byte.parent = self
                                            self._children_name_map["two_byte"] = "two-byte"

                                            self.unformatted = None
                                            self._children_name_map["unformatted"] = "unformatted"
                                            self._segment_path = lambda: "mac-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress, ['none'], name, value)


                                        class Default(Entity):
                                            """
                                            format ex\: 0000.4096.3e4a
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Default.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Default.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Default, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class Ietf(Entity):
                                            """
                                            format ex\: 00\-00\-40\-96\-3E\-4A
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Ietf.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Ietf, self).__init__()

                                                self.yang_name = "ietf"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Ietf.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "ietf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Ietf, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class OneByte(Entity):
                                            """
                                            format ex\: 00.00.40.96.3e.4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte, self).__init__()

                                                self.yang_name = "one-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "one-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "one-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class ThreeByte(Entity):
                                            """
                                            format ex\: 000040.963e4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte, self).__init__()

                                                self.yang_name = "three-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "three-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "three-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class TwoByte(Entity):
                                            """
                                            format ex\: 0000.4096.3e4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte, self).__init__()

                                                self.yang_name = "two-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "two-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "two-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class Unformatted(Entity):
                                            """
                                            format ex\: 000040963e4a
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Unformatted.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Unformatted, self).__init__()

                                                self.yang_name = "unformatted"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Unformatted.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "unformatted"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.CallingStationId.Format.MacAddress.Unformatted, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                            class EapUser(Entity):
                                """
                                EAP users
                                
                                .. attribute:: ignore_open_session
                                
                                	for EAP authenticated users, open\-session is not supported
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.EapUser, self).__init__()

                                    self.yang_name = "eap-user"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore_open_session', (YLeaf(YType.empty, 'ignore-open-session'), ['Empty'])),
                                    ])
                                    self.ignore_open_session = None
                                    self._segment_path = lambda: "eap-user"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.EapUser, ['ignore_open_session'], name, value)


                            class Filter(Entity):
                                """
                                Configure filter
                                
                                .. attribute:: access
                                
                                	For access requests
                                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access>`
                                
                                .. attribute:: accounting
                                
                                	For accounting requests
                                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting>`
                                
                                .. attribute:: attribute
                                
                                	Filter attributes in packets sent to clients
                                	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Attribute>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("access", ("access", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access)), ("accounting", ("accounting", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting)), ("attribute", ("attribute", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Attribute))])
                                    self._leafs = OrderedDict()

                                    self.access = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access()
                                    self.access.parent = self
                                    self._children_name_map["access"] = "access"

                                    self.accounting = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting()
                                    self.accounting.parent = self
                                    self._children_name_map["accounting"] = "accounting"

                                    self.attribute = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Attribute()
                                    self.attribute.parent = self
                                    self._children_name_map["attribute"] = "attribute"
                                    self._segment_path = lambda: "filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter, [], name, value)


                                class Access(Entity):
                                    """
                                    For access requests
                                    
                                    .. attribute:: ack
                                    
                                    	Acknowledge the packet
                                    	**type**\:  :py:class:`Ack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Ack>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop the packet
                                    	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Drop>`
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore the packet for applying ISG features
                                    	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Ignore>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access, self).__init__()

                                        self.yang_name = "access"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ack", ("ack", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Ack)), ("drop", ("drop", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Drop)), ("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Ignore))])
                                        self._leafs = OrderedDict()

                                        self.ack = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Ack()
                                        self.ack.parent = self
                                        self._children_name_map["ack"] = "ack"

                                        self.drop = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Drop()
                                        self.drop.parent = self
                                        self._children_name_map["drop"] = "drop"

                                        self.ignore = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Ignore()
                                        self.ignore.parent = self
                                        self._children_name_map["ignore"] = "ignore"
                                        self._segment_path = lambda: "access"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access, [], name, value)


                                    class Ack(Entity):
                                        """
                                        Acknowledge the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Ack, self).__init__()

                                            self.yang_name = "ack"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Ack, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Drop(Entity):
                                        """
                                        Drop the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Drop, self).__init__()

                                            self.yang_name = "drop"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Drop, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Ignore(Entity):
                                        """
                                        Ignore the packet for applying ISG features
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Ignore, self).__init__()

                                            self.yang_name = "ignore"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ignore"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Access.Ignore, ['word1', 'word2', 'word3', 'word4'], name, value)


                                class Accounting(Entity):
                                    """
                                    For accounting requests
                                    
                                    .. attribute:: ack
                                    
                                    	Acknowledge the packet
                                    	**type**\:  :py:class:`Ack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Ack>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop the packet
                                    	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Drop>`
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore the packet for applying ISG features
                                    	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Ignore>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting, self).__init__()

                                        self.yang_name = "accounting"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ack", ("ack", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Ack)), ("drop", ("drop", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Drop)), ("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Ignore))])
                                        self._leafs = OrderedDict()

                                        self.ack = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Ack()
                                        self.ack.parent = self
                                        self._children_name_map["ack"] = "ack"

                                        self.drop = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Drop()
                                        self.drop.parent = self
                                        self._children_name_map["drop"] = "drop"

                                        self.ignore = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Ignore()
                                        self.ignore.parent = self
                                        self._children_name_map["ignore"] = "ignore"
                                        self._segment_path = lambda: "accounting"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting, [], name, value)


                                    class Ack(Entity):
                                        """
                                        Acknowledge the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Ack, self).__init__()

                                            self.yang_name = "ack"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Ack, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Drop(Entity):
                                        """
                                        Drop the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Drop, self).__init__()

                                            self.yang_name = "drop"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Drop, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Ignore(Entity):
                                        """
                                        Ignore the packet for applying ISG features
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Ignore, self).__init__()

                                            self.yang_name = "ignore"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ignore"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Accounting.Ignore, ['word1', 'word2', 'word3', 'word4'], name, value)


                                class Attribute(Entity):
                                    """
                                    Filter attributes in packets sent to clients
                                    
                                    .. attribute:: allow
                                    
                                    	Allow only the attributes specified in the list
                                    	**type**\: str
                                    
                                    .. attribute:: block
                                    
                                    	Block the attributes specified in the list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Attribute, self).__init__()

                                        self.yang_name = "attribute"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow', (YLeaf(YType.str, 'allow'), ['str'])),
                                            ('block', (YLeaf(YType.str, 'block'), ['str'])),
                                        ])
                                        self.allow = None
                                        self.block = None
                                        self._segment_path = lambda: "attribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Filter.Attribute, ['allow', 'block'], name, value)


                            class Key(Entity):
                                """
                                Specify a RADIUS client
                                
                                .. attribute:: key
                                
                                	
                                	**type**\:  :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Key.Key_>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Key.Key_')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.key = None
                                    self.string = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Key, ['key', 'string'], name, value)

                                class Key_(Enum):
                                    """
                                    Key\_ (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_6 = 1

                                    .. data:: Y_7 = 2

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_6 = Enum.YLeaf(1, "6")

                                    Y_7 = Enum.YLeaf(2, "7")



                            class MessageAuthenticator(Entity):
                                """
                                Message Authenticator attribute from Clients
                                
                                .. attribute:: ignore
                                
                                	Ignore checking of Message Authenticator attribute from\\ Clients
                                	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.MessageAuthenticator.Ignore>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.MessageAuthenticator, self).__init__()

                                    self.yang_name = "message-authenticator"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.MessageAuthenticator.Ignore))])
                                    self._leafs = OrderedDict()

                                    self.ignore = None
                                    self._children_name_map["ignore"] = "ignore"
                                    self._segment_path = lambda: "message-authenticator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.MessageAuthenticator, [], name, value)


                                class Ignore(Entity):
                                    """
                                    Ignore checking of Message Authenticator attribute from\\
                                    Clients
                                    
                                    .. attribute:: accounting
                                    
                                    	Ignore checking of Message Authenticator attribute from\\ accounting packets
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.MessageAuthenticator.Ignore, self).__init__()

                                        self.yang_name = "ignore"
                                        self.yang_parent_name = "message-authenticator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('accounting', (YLeaf(YType.empty, 'accounting'), ['Empty'])),
                                        ])
                                        self.accounting = None
                                        self._segment_path = lambda: "ignore"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.MessageAuthenticator.Ignore, ['accounting'], name, value)


                            class Mode(Entity):
                                """
                                Radius Proxy Pass thru mode
                                
                                .. attribute:: pass_through
                                
                                	Enable the pass\-through mode for Radius Proxy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Mode, self).__init__()

                                    self.yang_name = "mode"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pass_through', (YLeaf(YType.empty, 'pass-through'), ['Empty'])),
                                    ])
                                    self.pass_through = None
                                    self._segment_path = lambda: "mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Mode, ['pass_through'], name, value)


                            class PwlanSession(Entity):
                                """
                                PWLAN Reconnect feature
                                
                                .. attribute:: reconnect
                                
                                	Enable the reconnect feature for PWLAN RP sessions
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.PwlanSession, self).__init__()

                                    self.yang_name = "pwlan-session"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reconnect', (YLeaf(YType.empty, 'reconnect'), ['Empty'])),
                                    ])
                                    self.reconnect = None
                                    self._segment_path = lambda: "pwlan-session"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.PwlanSession, ['reconnect'], name, value)


                            class ReAuthentication(Entity):
                                """
                                Specify re\-authentication details
                                
                                .. attribute:: do_not_apply
                                
                                	Do not apply new data during re\-authentication
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.ReAuthentication, self).__init__()

                                    self.yang_name = "re-authentication"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('do_not_apply', (YLeaf(YType.empty, 'do-not-apply'), ['Empty'])),
                                    ])
                                    self.do_not_apply = None
                                    self._segment_path = lambda: "re-authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.ReAuthentication, ['do_not_apply'], name, value)


                            class SessionIdentifier(Entity):
                                """
                                This attribute will be used to correlate Radius \\
                                requests of a session and to identify sessions within \\
                                radius\-proxy
                                
                                .. attribute:: attribute
                                
                                	Specify an IETF Radius attribute
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: vsa
                                
                                	Specify Vendor\-Specific Attribute
                                	**type**\:  :py:class:`Vsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.SessionIdentifier.Vsa>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.SessionIdentifier, self).__init__()

                                    self.yang_name = "session-identifier"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vsa", ("vsa", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.SessionIdentifier.Vsa))])
                                    self._leafs = OrderedDict([
                                        ('attribute', (YLeaf(YType.uint8, 'attribute'), ['int'])),
                                    ])
                                    self.attribute = None

                                    self.vsa = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.SessionIdentifier.Vsa()
                                    self.vsa.parent = self
                                    self._children_name_map["vsa"] = "vsa"
                                    self._segment_path = lambda: "session-identifier"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.SessionIdentifier, ['attribute'], name, value)


                                class Vsa(Entity):
                                    """
                                    Specify Vendor\-Specific Attribute
                                    
                                    .. attribute:: vendor
                                    
                                    	Specify the vendor type
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: type
                                    
                                    	Give attribute type for vsa
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.SessionIdentifier.Vsa, self).__init__()

                                        self.yang_name = "vsa"
                                        self.yang_parent_name = "session-identifier"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vendor', (YLeaf(YType.uint16, 'vendor'), ['int'])),
                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                        ])
                                        self.vendor = None
                                        self.type = None
                                        self._segment_path = lambda: "vsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.SessionIdentifier.Vsa, ['vendor', 'type'], name, value)


                            class Timer(Entity):
                                """
                                Configure RADIUS proxy timer values
                                
                                .. attribute:: disconnect
                                
                                	Specify disconnect timer
                                	**type**\:  :py:class:`Disconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Timer.Disconnect>`
                                
                                .. attribute:: ip_address
                                
                                	Specify value of wait for IP timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: reconnect
                                
                                	Specify value of wait for reconnect timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: request
                                
                                	Specify value of wait for Access\-Request timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: roaming
                                
                                	Specify value of wait for roaming timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Timer, self).__init__()

                                    self.yang_name = "timer"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disconnect", ("disconnect", Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Timer.Disconnect))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.uint16, 'ip-address'), ['int'])),
                                        ('reconnect', (YLeaf(YType.uint16, 'reconnect'), ['int'])),
                                        ('request', (YLeaf(YType.uint16, 'request'), ['int'])),
                                        ('roaming', (YLeaf(YType.uint16, 'roaming'), ['int'])),
                                    ])
                                    self.ip_address = None
                                    self.reconnect = None
                                    self.request = None
                                    self.roaming = None

                                    self.disconnect = Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Timer.Disconnect()
                                    self.disconnect.parent = self
                                    self._children_name_map["disconnect"] = "disconnect"
                                    self._segment_path = lambda: "timer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Timer, ['ip_address', 'reconnect', 'request', 'roaming'], name, value)


                                class Disconnect(Entity):
                                    """
                                    Specify disconnect timer
                                    
                                    .. attribute:: acct_stop
                                    
                                    	Specify disconnect delay timer for accounting stop
                                    	**type**\: int
                                    
                                    	**range:** 0..43200
                                    
                                    .. attribute:: reauth_fail
                                    
                                    	Specify disconnect delay timer for reauthentication failure
                                    	**type**\: int
                                    
                                    	**range:** 0..43200
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Timer.Disconnect, self).__init__()

                                        self.yang_name = "disconnect"
                                        self.yang_parent_name = "timer"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('acct_stop', (YLeaf(YType.uint16, 'acct-stop'), ['int'])),
                                            ('reauth_fail', (YLeaf(YType.uint16, 'reauth-fail'), ['int'])),
                                        ])
                                        self.acct_stop = None
                                        self.reauth_fail = None
                                        self._segment_path = lambda: "disconnect"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpVrf.Client.Timer.Disconnect, ['acct_stop', 'reauth_fail'], name, value)


                    class ClientIpMaskVrf(Entity):
                        """
                        
                        
                        .. attribute:: client
                        
                        	Specify a RADIUS client
                        	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf, self).__init__()

                            self.yang_name = "client-ip-mask-vrf"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("client", ("client", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client))])
                            self._leafs = OrderedDict()

                            self.client = YList(self)
                            self._segment_path = lambda: "client-ip-mask-vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf, [], name, value)


                        class Client(Entity):
                            """
                            Specify a RADIUS client
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            .. attribute:: mask  (key)
                            
                            	Network mask or prefix length
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** /(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vrf  (key)
                            
                            	Virtual Routing/Forwarding parameters
                            	**type**\: str
                            
                            .. attribute:: accounting
                            
                            	Specify accounting details
                            	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Accounting>`
                            
                            .. attribute:: authentication
                            
                            	Specify authentication details
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Authentication>`
                            
                            .. attribute:: calling_station_id
                            
                            	Specify format of Calling\-Station\-Id, attribute\\ 31.Default format is to expect mac\-address in\\ calling\-station\-id
                            	**type**\:  :py:class:`CallingStationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId>`
                            
                            .. attribute:: eap_user
                            
                            	EAP users
                            	**type**\:  :py:class:`EapUser <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.EapUser>`
                            
                            .. attribute:: filter
                            
                            	Configure filter
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter>`
                            
                            .. attribute:: key
                            
                            	Specify a RADIUS client
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Key>`
                            
                            .. attribute:: message_authenticator
                            
                            	Message Authenticator attribute from Clients
                            	**type**\:  :py:class:`MessageAuthenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.MessageAuthenticator>`
                            
                            .. attribute:: mode
                            
                            	Radius Proxy Pass thru mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Mode>`
                            
                            .. attribute:: pwlan_session
                            
                            	PWLAN Reconnect feature
                            	**type**\:  :py:class:`PwlanSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.PwlanSession>`
                            
                            .. attribute:: re_authentication
                            
                            	Specify re\-authentication details
                            	**type**\:  :py:class:`ReAuthentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.ReAuthentication>`
                            
                            .. attribute:: session_identifier
                            
                            	This attribute will be used to correlate Radius \\ requests of a session and to identify sessions within \\ radius\-proxy
                            	**type**\:  :py:class:`SessionIdentifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.SessionIdentifier>`
                            
                            .. attribute:: timer
                            
                            	Configure RADIUS proxy timer values
                            	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Timer>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client, self).__init__()

                                self.yang_name = "client"
                                self.yang_parent_name = "client-ip-mask-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip','mask','vrf']
                                self._child_classes = OrderedDict([("accounting", ("accounting", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Accounting)), ("authentication", ("authentication", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Authentication)), ("calling-station-id", ("calling_station_id", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId)), ("eap-user", ("eap_user", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.EapUser)), ("filter", ("filter", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter)), ("key", ("key", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Key)), ("message-authenticator", ("message_authenticator", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.MessageAuthenticator)), ("mode", ("mode", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Mode)), ("pwlan-session", ("pwlan_session", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.PwlanSession)), ("re-authentication", ("re_authentication", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.ReAuthentication)), ("session-identifier", ("session_identifier", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.SessionIdentifier)), ("timer", ("timer", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Timer))])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str','str','str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str','str'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.ip = None
                                self.mask = None
                                self.vrf = None

                                self.accounting = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Accounting()
                                self.accounting.parent = self
                                self._children_name_map["accounting"] = "accounting"

                                self.authentication = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"

                                self.calling_station_id = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId()
                                self.calling_station_id.parent = self
                                self._children_name_map["calling_station_id"] = "calling-station-id"

                                self.eap_user = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.EapUser()
                                self.eap_user.parent = self
                                self._children_name_map["eap_user"] = "eap-user"

                                self.filter = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"

                                self.key = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"

                                self.message_authenticator = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.MessageAuthenticator()
                                self.message_authenticator.parent = self
                                self._children_name_map["message_authenticator"] = "message-authenticator"

                                self.mode = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Mode()
                                self.mode.parent = self
                                self._children_name_map["mode"] = "mode"

                                self.pwlan_session = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.PwlanSession()
                                self.pwlan_session.parent = self
                                self._children_name_map["pwlan_session"] = "pwlan-session"

                                self.re_authentication = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.ReAuthentication()
                                self.re_authentication.parent = self
                                self._children_name_map["re_authentication"] = "re-authentication"

                                self.session_identifier = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.SessionIdentifier()
                                self.session_identifier.parent = self
                                self._children_name_map["session_identifier"] = "session-identifier"

                                self.timer = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Timer()
                                self.timer.parent = self
                                self._children_name_map["timer"] = "timer"
                                self._segment_path = lambda: "client" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']" + "[vrf='" + str(self.vrf) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/client-ip-mask-vrf/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client, ['ip', 'mask', 'vrf'], name, value)


                            class Accounting(Entity):
                                """
                                Specify accounting details
                                
                                .. attribute:: method_list
                                
                                	Authentication method list details
                                	**type**\:  :py:class:`MethodList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Accounting.MethodList>`
                                
                                .. attribute:: port
                                
                                	Radius server port
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Accounting, self).__init__()

                                    self.yang_name = "accounting"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("method-list", ("method_list", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Accounting.MethodList))])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                    ])
                                    self.port = None

                                    self.method_list = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Accounting.MethodList()
                                    self.method_list.parent = self
                                    self._children_name_map["method_list"] = "method-list"
                                    self._segment_path = lambda: "accounting"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Accounting, ['port'], name, value)


                                class MethodList(Entity):
                                    """
                                    Authentication method list details
                                    
                                    .. attribute:: method_name
                                    
                                    	Method list name
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	The default authentication list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Accounting.MethodList, self).__init__()

                                        self.yang_name = "method-list"
                                        self.yang_parent_name = "accounting"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('method_name', (YLeaf(YType.str, 'method-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ])
                                        self.method_name = None
                                        self.default = None
                                        self._segment_path = lambda: "method-list"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Accounting.MethodList, ['method_name', 'default'], name, value)


                            class Authentication(Entity):
                                """
                                Specify authentication details
                                
                                .. attribute:: method_list
                                
                                	Authentication method list details
                                	**type**\:  :py:class:`MethodList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Authentication.MethodList>`
                                
                                .. attribute:: port
                                
                                	Radius server port
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("method-list", ("method_list", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Authentication.MethodList))])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                    ])
                                    self.port = None

                                    self.method_list = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Authentication.MethodList()
                                    self.method_list.parent = self
                                    self._children_name_map["method_list"] = "method-list"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Authentication, ['port'], name, value)


                                class MethodList(Entity):
                                    """
                                    Authentication method list details
                                    
                                    .. attribute:: method_name
                                    
                                    	Method list name
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	The default authentication list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Authentication.MethodList, self).__init__()

                                        self.yang_name = "method-list"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('method_name', (YLeaf(YType.str, 'method-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ])
                                        self.method_name = None
                                        self.default = None
                                        self._segment_path = lambda: "method-list"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Authentication.MethodList, ['method_name', 'default'], name, value)


                            class CallingStationId(Entity):
                                """
                                Specify format of Calling\-Station\-Id, attribute\\
                                31.Default format is to expect mac\-address in\\
                                calling\-station\-id
                                
                                .. attribute:: format
                                
                                	Specify the format as MAC or MSISDN
                                	**type**\:  :py:class:`Format <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId, self).__init__()

                                    self.yang_name = "calling-station-id"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("format", ("format", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format))])
                                    self._leafs = OrderedDict()

                                    self.format = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format()
                                    self.format.parent = self
                                    self._children_name_map["format"] = "format"
                                    self._segment_path = lambda: "calling-station-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId, [], name, value)


                                class Format(Entity):
                                    """
                                    Specify the format as MAC or MSISDN
                                    
                                    .. attribute:: mac_address
                                    
                                    	Expect MAC address to be present in CLID
                                    	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress>`
                                    
                                    .. attribute:: msisdn
                                    
                                    	Expect MSISDN value to be present in CLID
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format, self).__init__()

                                        self.yang_name = "format"
                                        self.yang_parent_name = "calling-station-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("mac-address", ("mac_address", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress))])
                                        self._leafs = OrderedDict([
                                            ('msisdn', (YLeaf(YType.empty, 'msisdn'), ['Empty'])),
                                        ])
                                        self.msisdn = None

                                        self.mac_address = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress()
                                        self.mac_address.parent = self
                                        self._children_name_map["mac_address"] = "mac-address"
                                        self._segment_path = lambda: "format"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format, ['msisdn'], name, value)


                                    class MacAddress(Entity):
                                        """
                                        Expect MAC address to be present in CLID
                                        
                                        .. attribute:: default
                                        
                                        	format ex\: 0000.4096.3e4a
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Default>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ietf
                                        
                                        	format ex\: 00\-00\-40\-96\-3E\-4A
                                        	**type**\:  :py:class:`Ietf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Ietf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: none
                                        
                                        	format unspecified
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: one_byte
                                        
                                        	format ex\: 00.00.40.96.3e.4a
                                        	**type**\:  :py:class:`OneByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte>`
                                        
                                        .. attribute:: three_byte
                                        
                                        	format ex\: 000040.963e4a
                                        	**type**\:  :py:class:`ThreeByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte>`
                                        
                                        .. attribute:: two_byte
                                        
                                        	format ex\: 0000.4096.3e4a
                                        	**type**\:  :py:class:`TwoByte <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte>`
                                        
                                        .. attribute:: unformatted
                                        
                                        	format ex\: 000040963e4a
                                        	**type**\:  :py:class:`Unformatted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Unformatted>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress, self).__init__()

                                            self.yang_name = "mac-address"
                                            self.yang_parent_name = "format"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("default", ("default", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Default)), ("ietf", ("ietf", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Ietf)), ("one-byte", ("one_byte", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte)), ("three-byte", ("three_byte", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte)), ("two-byte", ("two_byte", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte)), ("unformatted", ("unformatted", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Unformatted))])
                                            self._leafs = OrderedDict([
                                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                            ])
                                            self.none = None

                                            self.default = None
                                            self._children_name_map["default"] = "default"

                                            self.ietf = None
                                            self._children_name_map["ietf"] = "ietf"

                                            self.one_byte = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte()
                                            self.one_byte.parent = self
                                            self._children_name_map["one_byte"] = "one-byte"

                                            self.three_byte = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte()
                                            self.three_byte.parent = self
                                            self._children_name_map["three_byte"] = "three-byte"

                                            self.two_byte = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte()
                                            self.two_byte.parent = self
                                            self._children_name_map["two_byte"] = "two-byte"

                                            self.unformatted = None
                                            self._children_name_map["unformatted"] = "unformatted"
                                            self._segment_path = lambda: "mac-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress, ['none'], name, value)


                                        class Default(Entity):
                                            """
                                            format ex\: 0000.4096.3e4a
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Default.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Default.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Default, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class Ietf(Entity):
                                            """
                                            format ex\: 00\-00\-40\-96\-3E\-4A
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Ietf.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Ietf, self).__init__()

                                                self.yang_name = "ietf"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Ietf.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "ietf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Ietf, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                                        class OneByte(Entity):
                                            """
                                            format ex\: 00.00.40.96.3e.4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte, self).__init__()

                                                self.yang_name = "one-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "one-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "one-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.OneByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class ThreeByte(Entity):
                                            """
                                            format ex\: 000040.963e4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte, self).__init__()

                                                self.yang_name = "three-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "three-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "three-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.ThreeByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class TwoByte(Entity):
                                            """
                                            format ex\: 0000.4096.3e4a
                                            
                                            .. attribute:: delimiter
                                            
                                            	
                                            	**type**\:  :py:class:`Delimiter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter>`
                                            
                                            

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte, self).__init__()

                                                self.yang_name = "two-byte"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("delimiter", ("delimiter", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter))])
                                                self._leafs = OrderedDict()

                                                self.delimiter = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter()
                                                self.delimiter.parent = self
                                                self._children_name_map["delimiter"] = "delimiter"
                                                self._segment_path = lambda: "two-byte"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte, [], name, value)


                                            class Delimiter(Entity):
                                                """
                                                
                                                
                                                .. attribute:: colon
                                                
                                                	
                                                	**type**\:  :py:class:`Colon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: dot
                                                
                                                	
                                                	**type**\:  :py:class:`Dot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: hyphen
                                                
                                                	
                                                	**type**\:  :py:class:`Hyphen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-aaa'
                                                _revision = '2018-01-15'

                                                def __init__(self):
                                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter, self).__init__()

                                                    self.yang_name = "delimiter"
                                                    self.yang_parent_name = "two-byte"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("colon", ("colon", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon)), ("dot", ("dot", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot)), ("hyphen", ("hyphen", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen))])
                                                    self._leafs = OrderedDict()

                                                    self.colon = None
                                                    self._children_name_map["colon"] = "colon"

                                                    self.dot = None
                                                    self._children_name_map["dot"] = "dot"

                                                    self.hyphen = None
                                                    self._children_name_map["hyphen"] = "hyphen"
                                                    self._segment_path = lambda: "delimiter"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter, [], name, value)


                                                class Colon(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon, self).__init__()

                                                        self.yang_name = "colon"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "colon"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Colon, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Dot(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot, self).__init__()

                                                        self.yang_name = "dot"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "dot"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Dot, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                                class Hyphen(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen.Type>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-aaa'
                                                    _revision = '2018-01-15'

                                                    def __init__(self):
                                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen, self).__init__()

                                                        self.yang_name = "hyphen"
                                                        self.yang_parent_name = "delimiter"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen.Type')])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "hyphen"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.TwoByte.Delimiter.Hyphen, ['type'], name, value)

                                                    class Type(Enum):
                                                        """
                                                        Type (Enum Class)

                                                        .. data:: lower_case = 0

                                                        .. data:: upper_case = 1

                                                        """

                                                        lower_case = Enum.YLeaf(0, "lower-case")

                                                        upper_case = Enum.YLeaf(1, "upper-case")



                                        class Unformatted(Entity):
                                            """
                                            format ex\: 000040963e4a
                                            
                                            .. attribute:: type
                                            
                                            	
                                            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Unformatted.Type>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-aaa'
                                            _revision = '2018-01-15'

                                            def __init__(self):
                                                super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Unformatted, self).__init__()

                                                self.yang_name = "unformatted"
                                                self.yang_parent_name = "mac-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Unformatted.Type')])),
                                                ])
                                                self.type = None
                                                self._segment_path = lambda: "unformatted"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.CallingStationId.Format.MacAddress.Unformatted, ['type'], name, value)

                                            class Type(Enum):
                                                """
                                                Type (Enum Class)

                                                .. data:: lower_case = 0

                                                .. data:: upper_case = 1

                                                """

                                                lower_case = Enum.YLeaf(0, "lower-case")

                                                upper_case = Enum.YLeaf(1, "upper-case")



                            class EapUser(Entity):
                                """
                                EAP users
                                
                                .. attribute:: ignore_open_session
                                
                                	for EAP authenticated users, open\-session is not supported
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.EapUser, self).__init__()

                                    self.yang_name = "eap-user"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore_open_session', (YLeaf(YType.empty, 'ignore-open-session'), ['Empty'])),
                                    ])
                                    self.ignore_open_session = None
                                    self._segment_path = lambda: "eap-user"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.EapUser, ['ignore_open_session'], name, value)


                            class Filter(Entity):
                                """
                                Configure filter
                                
                                .. attribute:: access
                                
                                	For access requests
                                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access>`
                                
                                .. attribute:: accounting
                                
                                	For accounting requests
                                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting>`
                                
                                .. attribute:: attribute
                                
                                	Filter attributes in packets sent to clients
                                	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Attribute>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("access", ("access", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access)), ("accounting", ("accounting", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting)), ("attribute", ("attribute", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Attribute))])
                                    self._leafs = OrderedDict()

                                    self.access = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access()
                                    self.access.parent = self
                                    self._children_name_map["access"] = "access"

                                    self.accounting = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting()
                                    self.accounting.parent = self
                                    self._children_name_map["accounting"] = "accounting"

                                    self.attribute = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Attribute()
                                    self.attribute.parent = self
                                    self._children_name_map["attribute"] = "attribute"
                                    self._segment_path = lambda: "filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter, [], name, value)


                                class Access(Entity):
                                    """
                                    For access requests
                                    
                                    .. attribute:: ack
                                    
                                    	Acknowledge the packet
                                    	**type**\:  :py:class:`Ack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Ack>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop the packet
                                    	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Drop>`
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore the packet for applying ISG features
                                    	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Ignore>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access, self).__init__()

                                        self.yang_name = "access"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ack", ("ack", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Ack)), ("drop", ("drop", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Drop)), ("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Ignore))])
                                        self._leafs = OrderedDict()

                                        self.ack = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Ack()
                                        self.ack.parent = self
                                        self._children_name_map["ack"] = "ack"

                                        self.drop = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Drop()
                                        self.drop.parent = self
                                        self._children_name_map["drop"] = "drop"

                                        self.ignore = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Ignore()
                                        self.ignore.parent = self
                                        self._children_name_map["ignore"] = "ignore"
                                        self._segment_path = lambda: "access"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access, [], name, value)


                                    class Ack(Entity):
                                        """
                                        Acknowledge the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Ack, self).__init__()

                                            self.yang_name = "ack"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Ack, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Drop(Entity):
                                        """
                                        Drop the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Drop, self).__init__()

                                            self.yang_name = "drop"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Drop, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Ignore(Entity):
                                        """
                                        Ignore the packet for applying ISG features
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Ignore, self).__init__()

                                            self.yang_name = "ignore"
                                            self.yang_parent_name = "access"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ignore"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Access.Ignore, ['word1', 'word2', 'word3', 'word4'], name, value)


                                class Accounting(Entity):
                                    """
                                    For accounting requests
                                    
                                    .. attribute:: ack
                                    
                                    	Acknowledge the packet
                                    	**type**\:  :py:class:`Ack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Ack>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop the packet
                                    	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Drop>`
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore the packet for applying ISG features
                                    	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Ignore>`
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting, self).__init__()

                                        self.yang_name = "accounting"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ack", ("ack", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Ack)), ("drop", ("drop", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Drop)), ("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Ignore))])
                                        self._leafs = OrderedDict()

                                        self.ack = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Ack()
                                        self.ack.parent = self
                                        self._children_name_map["ack"] = "ack"

                                        self.drop = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Drop()
                                        self.drop.parent = self
                                        self._children_name_map["drop"] = "drop"

                                        self.ignore = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Ignore()
                                        self.ignore.parent = self
                                        self._children_name_map["ignore"] = "ignore"
                                        self._segment_path = lambda: "accounting"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting, [], name, value)


                                    class Ack(Entity):
                                        """
                                        Acknowledge the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Ack, self).__init__()

                                            self.yang_name = "ack"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Ack, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Drop(Entity):
                                        """
                                        Drop the packet
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Drop, self).__init__()

                                            self.yang_name = "drop"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "drop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Drop, ['word1', 'word2', 'word3', 'word4'], name, value)


                                    class Ignore(Entity):
                                        """
                                        Ignore the packet for applying ISG features
                                        
                                        .. attribute:: word1
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word2
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word3
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        .. attribute:: word4
                                        
                                        	Name of the filter to be applied (max 31 chars. \\ (max 31 chars. longer will be ignored)
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-aaa'
                                        _revision = '2018-01-15'

                                        def __init__(self):
                                            super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Ignore, self).__init__()

                                            self.yang_name = "ignore"
                                            self.yang_parent_name = "accounting"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word1', (YLeaf(YType.str, 'word1'), ['str'])),
                                                ('word2', (YLeaf(YType.str, 'word2'), ['str'])),
                                                ('word3', (YLeaf(YType.str, 'word3'), ['str'])),
                                                ('word4', (YLeaf(YType.str, 'word4'), ['str'])),
                                            ])
                                            self.word1 = None
                                            self.word2 = None
                                            self.word3 = None
                                            self.word4 = None
                                            self._segment_path = lambda: "ignore"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Accounting.Ignore, ['word1', 'word2', 'word3', 'word4'], name, value)


                                class Attribute(Entity):
                                    """
                                    Filter attributes in packets sent to clients
                                    
                                    .. attribute:: allow
                                    
                                    	Allow only the attributes specified in the list
                                    	**type**\: str
                                    
                                    .. attribute:: block
                                    
                                    	Block the attributes specified in the list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Attribute, self).__init__()

                                        self.yang_name = "attribute"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow', (YLeaf(YType.str, 'allow'), ['str'])),
                                            ('block', (YLeaf(YType.str, 'block'), ['str'])),
                                        ])
                                        self.allow = None
                                        self.block = None
                                        self._segment_path = lambda: "attribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Filter.Attribute, ['allow', 'block'], name, value)


                            class Key(Entity):
                                """
                                Specify a RADIUS client
                                
                                .. attribute:: key
                                
                                	
                                	**type**\:  :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Key.Key_>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Key.Key_')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.key = None
                                    self.string = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Key, ['key', 'string'], name, value)

                                class Key_(Enum):
                                    """
                                    Key\_ (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_6 = 1

                                    .. data:: Y_7 = 2

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_6 = Enum.YLeaf(1, "6")

                                    Y_7 = Enum.YLeaf(2, "7")



                            class MessageAuthenticator(Entity):
                                """
                                Message Authenticator attribute from Clients
                                
                                .. attribute:: ignore
                                
                                	Ignore checking of Message Authenticator attribute from\\ Clients
                                	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.MessageAuthenticator.Ignore>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.MessageAuthenticator, self).__init__()

                                    self.yang_name = "message-authenticator"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ignore", ("ignore", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.MessageAuthenticator.Ignore))])
                                    self._leafs = OrderedDict()

                                    self.ignore = None
                                    self._children_name_map["ignore"] = "ignore"
                                    self._segment_path = lambda: "message-authenticator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.MessageAuthenticator, [], name, value)


                                class Ignore(Entity):
                                    """
                                    Ignore checking of Message Authenticator attribute from\\
                                    Clients
                                    
                                    .. attribute:: accounting
                                    
                                    	Ignore checking of Message Authenticator attribute from\\ accounting packets
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.MessageAuthenticator.Ignore, self).__init__()

                                        self.yang_name = "ignore"
                                        self.yang_parent_name = "message-authenticator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('accounting', (YLeaf(YType.empty, 'accounting'), ['Empty'])),
                                        ])
                                        self.accounting = None
                                        self._segment_path = lambda: "ignore"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.MessageAuthenticator.Ignore, ['accounting'], name, value)


                            class Mode(Entity):
                                """
                                Radius Proxy Pass thru mode
                                
                                .. attribute:: pass_through
                                
                                	Enable the pass\-through mode for Radius Proxy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Mode, self).__init__()

                                    self.yang_name = "mode"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pass_through', (YLeaf(YType.empty, 'pass-through'), ['Empty'])),
                                    ])
                                    self.pass_through = None
                                    self._segment_path = lambda: "mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Mode, ['pass_through'], name, value)


                            class PwlanSession(Entity):
                                """
                                PWLAN Reconnect feature
                                
                                .. attribute:: reconnect
                                
                                	Enable the reconnect feature for PWLAN RP sessions
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.PwlanSession, self).__init__()

                                    self.yang_name = "pwlan-session"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reconnect', (YLeaf(YType.empty, 'reconnect'), ['Empty'])),
                                    ])
                                    self.reconnect = None
                                    self._segment_path = lambda: "pwlan-session"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.PwlanSession, ['reconnect'], name, value)


                            class ReAuthentication(Entity):
                                """
                                Specify re\-authentication details
                                
                                .. attribute:: do_not_apply
                                
                                	Do not apply new data during re\-authentication
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.ReAuthentication, self).__init__()

                                    self.yang_name = "re-authentication"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('do_not_apply', (YLeaf(YType.empty, 'do-not-apply'), ['Empty'])),
                                    ])
                                    self.do_not_apply = None
                                    self._segment_path = lambda: "re-authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.ReAuthentication, ['do_not_apply'], name, value)


                            class SessionIdentifier(Entity):
                                """
                                This attribute will be used to correlate Radius \\
                                requests of a session and to identify sessions within \\
                                radius\-proxy
                                
                                .. attribute:: attribute
                                
                                	Specify an IETF Radius attribute
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: vsa
                                
                                	Specify Vendor\-Specific Attribute
                                	**type**\:  :py:class:`Vsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.SessionIdentifier.Vsa>`
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.SessionIdentifier, self).__init__()

                                    self.yang_name = "session-identifier"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vsa", ("vsa", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.SessionIdentifier.Vsa))])
                                    self._leafs = OrderedDict([
                                        ('attribute', (YLeaf(YType.uint8, 'attribute'), ['int'])),
                                    ])
                                    self.attribute = None

                                    self.vsa = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.SessionIdentifier.Vsa()
                                    self.vsa.parent = self
                                    self._children_name_map["vsa"] = "vsa"
                                    self._segment_path = lambda: "session-identifier"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.SessionIdentifier, ['attribute'], name, value)


                                class Vsa(Entity):
                                    """
                                    Specify Vendor\-Specific Attribute
                                    
                                    .. attribute:: vendor
                                    
                                    	Specify the vendor type
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: type
                                    
                                    	Give attribute type for vsa
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.SessionIdentifier.Vsa, self).__init__()

                                        self.yang_name = "vsa"
                                        self.yang_parent_name = "session-identifier"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vendor', (YLeaf(YType.uint16, 'vendor'), ['int'])),
                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                        ])
                                        self.vendor = None
                                        self.type = None
                                        self._segment_path = lambda: "vsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.SessionIdentifier.Vsa, ['vendor', 'type'], name, value)


                            class Timer(Entity):
                                """
                                Configure RADIUS proxy timer values
                                
                                .. attribute:: disconnect
                                
                                	Specify disconnect timer
                                	**type**\:  :py:class:`Disconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Timer.Disconnect>`
                                
                                .. attribute:: ip_address
                                
                                	Specify value of wait for IP timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: reconnect
                                
                                	Specify value of wait for reconnect timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: request
                                
                                	Specify value of wait for Access\-Request timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                .. attribute:: roaming
                                
                                	Specify value of wait for roaming timer
                                	**type**\: int
                                
                                	**range:** 0..43200
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Timer, self).__init__()

                                    self.yang_name = "timer"
                                    self.yang_parent_name = "client"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disconnect", ("disconnect", Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Timer.Disconnect))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.uint16, 'ip-address'), ['int'])),
                                        ('reconnect', (YLeaf(YType.uint16, 'reconnect'), ['int'])),
                                        ('request', (YLeaf(YType.uint16, 'request'), ['int'])),
                                        ('roaming', (YLeaf(YType.uint16, 'roaming'), ['int'])),
                                    ])
                                    self.ip_address = None
                                    self.reconnect = None
                                    self.request = None
                                    self.roaming = None

                                    self.disconnect = Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Timer.Disconnect()
                                    self.disconnect.parent = self
                                    self._children_name_map["disconnect"] = "disconnect"
                                    self._segment_path = lambda: "timer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Timer, ['ip_address', 'reconnect', 'request', 'roaming'], name, value)


                                class Disconnect(Entity):
                                    """
                                    Specify disconnect timer
                                    
                                    .. attribute:: acct_stop
                                    
                                    	Specify disconnect delay timer for accounting stop
                                    	**type**\: int
                                    
                                    	**range:** 0..43200
                                    
                                    .. attribute:: reauth_fail
                                    
                                    	Specify disconnect delay timer for reauthentication failure
                                    	**type**\: int
                                    
                                    	**range:** 0..43200
                                    
                                    

                                    """

                                    _prefix = 'ios-aaa'
                                    _revision = '2018-01-15'

                                    def __init__(self):
                                        super(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Timer.Disconnect, self).__init__()

                                        self.yang_name = "disconnect"
                                        self.yang_parent_name = "timer"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('acct_stop', (YLeaf(YType.uint16, 'acct-stop'), ['int'])),
                                            ('reauth_fail', (YLeaf(YType.uint16, 'reauth-fail'), ['int'])),
                                        ])
                                        self.acct_stop = None
                                        self.reauth_fail = None
                                        self._segment_path = lambda: "disconnect"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Aaa.Server.Radius.Proxy.ClientIpMaskVrf.Client.Timer.Disconnect, ['acct_stop', 'reauth_fail'], name, value)


                    class Send(Entity):
                        """
                        Send attributes in Radius requests
                        
                        .. attribute:: vsa
                        
                        	Vendor specific attribute configuration
                        	**type**\:  :py:class:`Vsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Send.Vsa>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Proxy.Send, self).__init__()

                            self.yang_name = "send"
                            self.yang_parent_name = "proxy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vsa", ("vsa", Native.Aaa.Server.Radius.Proxy.Send.Vsa))])
                            self._leafs = OrderedDict()

                            self.vsa = Native.Aaa.Server.Radius.Proxy.Send.Vsa()
                            self.vsa.parent = self
                            self._children_name_map["vsa"] = "vsa"
                            self._segment_path = lambda: "send"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Send, [], name, value)


                        class Vsa(Entity):
                            """
                            Vendor specific attribute configuration
                            
                            .. attribute:: rpclient_source_address
                            
                            	AP Source Address
                            	**type**\:  :py:class:`RpclientSourceAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Proxy.Send.Vsa.RpclientSourceAddress>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Proxy.Send.Vsa, self).__init__()

                                self.yang_name = "vsa"
                                self.yang_parent_name = "send"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpclient-source-address", ("rpclient_source_address", Native.Aaa.Server.Radius.Proxy.Send.Vsa.RpclientSourceAddress))])
                                self._leafs = OrderedDict()

                                self.rpclient_source_address = None
                                self._children_name_map["rpclient_source_address"] = "rpclient-source-address"
                                self._segment_path = lambda: "vsa"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/send/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Send.Vsa, [], name, value)


                            class RpclientSourceAddress(Entity):
                                """
                                AP Source Address
                                
                                .. attribute:: accounting
                                
                                	send in accounting requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: authentication
                                
                                	send in access requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Proxy.Send.Vsa.RpclientSourceAddress, self).__init__()

                                    self.yang_name = "rpclient-source-address"
                                    self.yang_parent_name = "vsa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('accounting', (YLeaf(YType.empty, 'accounting'), ['Empty'])),
                                        ('authentication', (YLeaf(YType.empty, 'authentication'), ['Empty'])),
                                    ])
                                    self.accounting = None
                                    self.authentication = None
                                    self._segment_path = lambda: "rpclient-source-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/proxy/send/vsa/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Proxy.Send.Vsa.RpclientSourceAddress, ['accounting', 'authentication'], name, value)


                class Sesm(Entity):
                    """
                    Local server profile for a SESM client
                    
                    .. attribute:: client
                    
                    	Specify a RADIUS client
                    	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Sesm.Client>`
                    
                    .. attribute:: key
                    
                    	Specify a RADIUS client
                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Sesm.Key>`
                    
                    .. attribute:: message_authenticator
                    
                    	Message Authenticator attribute from Clients
                    	**type**\:  :py:class:`MessageAuthenticator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Sesm.MessageAuthenticator>`
                    
                    .. attribute:: port
                    
                    	Radius server port
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Server.Radius.Sesm, self).__init__()

                        self.yang_name = "sesm"
                        self.yang_parent_name = "radius"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("client", ("client", Native.Aaa.Server.Radius.Sesm.Client)), ("key", ("key", Native.Aaa.Server.Radius.Sesm.Key)), ("message-authenticator", ("message_authenticator", Native.Aaa.Server.Radius.Sesm.MessageAuthenticator))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                        ])
                        self.port = None

                        self.key = Native.Aaa.Server.Radius.Sesm.Key()
                        self.key.parent = self
                        self._children_name_map["key"] = "key"

                        self.message_authenticator = Native.Aaa.Server.Radius.Sesm.MessageAuthenticator()
                        self.message_authenticator.parent = self
                        self._children_name_map["message_authenticator"] = "message-authenticator"

                        self.client = YList(self)
                        self._segment_path = lambda: "sesm"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Server.Radius.Sesm, ['port'], name, value)


                    class Client(Entity):
                        """
                        Specify a RADIUS client
                        
                        .. attribute:: ip  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        .. attribute:: vrf
                        
                        	 Virtual Routing/Forwarding parameters
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Sesm.Client.Vrf>`
                        
                        .. attribute:: key
                        
                        	Specify a RADIUS client
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Sesm.Client.Key>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Sesm.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "sesm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ip']
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Aaa.Server.Radius.Sesm.Client.Vrf)), ("key", ("key", Native.Aaa.Server.Radius.Sesm.Client.Key))])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str','str','str'])),
                            ])
                            self.ip = None

                            self.key = Native.Aaa.Server.Radius.Sesm.Client.Key()
                            self.key.parent = self
                            self._children_name_map["key"] = "key"

                            self.vrf = YList(self)
                            self._segment_path = lambda: "client" + "[ip='" + str(self.ip) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/sesm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Sesm.Client, ['ip'], name, value)


                        class Vrf(Entity):
                            """
                             Virtual Routing/Forwarding parameters
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: key
                            
                            	Specify a RADIUS client
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Sesm.Client.Vrf.Key>`
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Sesm.Client.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("key", ("key", Native.Aaa.Server.Radius.Sesm.Client.Vrf.Key))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.key = Native.Aaa.Server.Radius.Sesm.Client.Vrf.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Sesm.Client.Vrf, ['name'], name, value)


                            class Key(Entity):
                                """
                                Specify a RADIUS client
                                
                                .. attribute:: key
                                
                                	
                                	**type**\:  :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Sesm.Client.Vrf.Key.Key_>`
                                
                                .. attribute:: string
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-aaa'
                                _revision = '2018-01-15'

                                def __init__(self):
                                    super(Native.Aaa.Server.Radius.Sesm.Client.Vrf.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Sesm.Client.Vrf.Key.Key_')])),
                                        ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                    ])
                                    self.key = None
                                    self.string = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Aaa.Server.Radius.Sesm.Client.Vrf.Key, ['key', 'string'], name, value)

                                class Key_(Enum):
                                    """
                                    Key\_ (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_6 = 1

                                    .. data:: Y_7 = 2

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_6 = Enum.YLeaf(1, "6")

                                    Y_7 = Enum.YLeaf(2, "7")



                        class Key(Entity):
                            """
                            Specify a RADIUS client
                            
                            .. attribute:: key
                            
                            	
                            	**type**\:  :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Sesm.Client.Key.Key_>`
                            
                            .. attribute:: string
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-aaa'
                            _revision = '2018-01-15'

                            def __init__(self):
                                super(Native.Aaa.Server.Radius.Sesm.Client.Key, self).__init__()

                                self.yang_name = "key"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Sesm.Client.Key.Key_')])),
                                    ('string', (YLeaf(YType.str, 'string'), ['str'])),
                                ])
                                self.key = None
                                self.string = None
                                self._segment_path = lambda: "key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Aaa.Server.Radius.Sesm.Client.Key, ['key', 'string'], name, value)

                            class Key_(Enum):
                                """
                                Key\_ (Enum Class)

                                .. data:: Y_0 = 0

                                .. data:: Y_6 = 1

                                .. data:: Y_7 = 2

                                """

                                Y_0 = Enum.YLeaf(0, "0")

                                Y_6 = Enum.YLeaf(1, "6")

                                Y_7 = Enum.YLeaf(2, "7")



                    class Key(Entity):
                        """
                        Specify a RADIUS client
                        
                        .. attribute:: key
                        
                        	
                        	**type**\:  :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Server.Radius.Sesm.Key.Key_>`
                        
                        .. attribute:: string
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Sesm.Key, self).__init__()

                            self.yang_name = "key"
                            self.yang_parent_name = "sesm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Server.Radius.Sesm.Key.Key_')])),
                                ('string', (YLeaf(YType.str, 'string'), ['str'])),
                            ])
                            self.key = None
                            self.string = None
                            self._segment_path = lambda: "key"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/sesm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Sesm.Key, ['key', 'string'], name, value)

                        class Key_(Enum):
                            """
                            Key\_ (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: Y_6 = 1

                            .. data:: Y_7 = 2

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_6 = Enum.YLeaf(1, "6")

                            Y_7 = Enum.YLeaf(2, "7")



                    class MessageAuthenticator(Entity):
                        """
                        Message Authenticator attribute from Clients
                        
                        .. attribute:: ignore
                        
                        	Ignore checking of Message Authenticator attribute from\\ Clients
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.Aaa.Server.Radius.Sesm.MessageAuthenticator, self).__init__()

                            self.yang_name = "message-authenticator"
                            self.yang_parent_name = "sesm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "message-authenticator"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:server/radius/sesm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Aaa.Server.Radius.Sesm.MessageAuthenticator, ['ignore'], name, value)


        class Login(Entity):
            """
            AAA login enable display
            
            .. attribute:: display
            
            	Display options for login info
            	**type**\:  :py:class:`Display <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Login.Display>`
            
            .. attribute:: success_track_conf_time
            
            	Track Successful login attempts occurring during configured time\-period
            	**type**\: int
            
            	**range:** 1..24
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Aaa.Login, self).__init__()

                self.yang_name = "login"
                self.yang_parent_name = "aaa"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('display', (YLeaf(YType.enumeration, 'display'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Login.Display')])),
                    ('success_track_conf_time', (YLeaf(YType.uint8, 'success-track-conf-time'), ['int'])),
                ])
                self.display = None
                self.success_track_conf_time = None
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:login"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Aaa.Login, ['display', 'success_track_conf_time'], name, value)

            class Display(Enum):
                """
                Display (Enum Class)

                Display options for login info

                .. data:: last_failure = 0

                .. data:: last_success = 1

                .. data:: number_failures = 2

                """

                last_failure = Enum.YLeaf(0, "last-failure")

                last_success = Enum.YLeaf(1, "last-success")

                number_failures = Enum.YLeaf(2, "number-failures")



        class Memory(Entity):
            """
            AAA memory parameters
            
            .. attribute:: threshold
            
            	set appropriate thresholds for the AAA process
            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Memory.Threshold>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Aaa.Memory, self).__init__()

                self.yang_name = "memory"
                self.yang_parent_name = "aaa"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Aaa.Memory.Threshold))])
                self._leafs = OrderedDict()

                self.threshold = Native.Aaa.Memory.Threshold()
                self.threshold.parent = self
                self._children_name_map["threshold"] = "threshold"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:memory"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Aaa.Memory, [], name, value)


            class Threshold(Entity):
                """
                set appropriate thresholds for the AAA process
                
                .. attribute:: accounting
                
                	AAA accounting low\-memory threshold
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Memory.Threshold.Accounting>`
                
                .. attribute:: authentication
                
                	AAA authentication low\-memory threshold
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Memory.Threshold.Authentication>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Memory.Threshold, self).__init__()

                    self.yang_name = "threshold"
                    self.yang_parent_name = "memory"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("accounting", ("accounting", Native.Aaa.Memory.Threshold.Accounting)), ("authentication", ("authentication", Native.Aaa.Memory.Threshold.Authentication))])
                    self._leafs = OrderedDict()

                    self.accounting = Native.Aaa.Memory.Threshold.Accounting()
                    self.accounting.parent = self
                    self._children_name_map["accounting"] = "accounting"

                    self.authentication = Native.Aaa.Memory.Threshold.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"
                    self._segment_path = lambda: "threshold"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:memory/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Memory.Threshold, [], name, value)


                class Accounting(Entity):
                    """
                    AAA accounting low\-memory threshold
                    
                    .. attribute:: disable
                    
                    	accounting may be disabled, if available memory falls below\\ this percentage
                    	**type**\: int
                    
                    	**range:** 1..15
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Memory.Threshold.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "threshold"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.uint8, 'disable'), ['int'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "accounting"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:memory/threshold/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Memory.Threshold.Accounting, ['disable'], name, value)


                class Authentication(Entity):
                    """
                    AAA authentication low\-memory threshold
                    
                    .. attribute:: reject
                    
                    	requests will be rejected, if available memory falls below\\ this percentage
                    	**type**\: int
                    
                    	**range:** 2..15
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Aaa.Memory.Threshold.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "threshold"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('reject', (YLeaf(YType.uint8, 'reject'), ['int'])),
                        ])
                        self.reject = None
                        self._segment_path = lambda: "authentication"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:memory/threshold/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Aaa.Memory.Threshold.Authentication, ['reject'], name, value)


        class Policy(Entity):
            """
            AAA policy parameters
            
            .. attribute:: interface_config
            
            	LCP interface config policy parameters
            	**type**\:  :py:class:`InterfaceConfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Policy.InterfaceConfig>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Aaa.Policy, self).__init__()

                self.yang_name = "policy"
                self.yang_parent_name = "aaa"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('interface_config', (YLeaf(YType.enumeration, 'interface-config'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Aaa.Policy.InterfaceConfig')])),
                ])
                self.interface_config = None
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:policy"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Aaa.Policy, ['interface_config'], name, value)

            class InterfaceConfig(Enum):
                """
                InterfaceConfig (Enum Class)

                LCP interface config policy parameters

                .. data:: allow_subinterface = 0

                """

                allow_subinterface = Enum.YLeaf(0, "allow-subinterface")



        class Route(Entity):
            """
            Static route downloading
            
            .. attribute:: download
            
            	Download from AAA server
            	**type**\:  :py:class:`Download <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Aaa.Route.Download>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Aaa.Route, self).__init__()

                self.yang_name = "route"
                self.yang_parent_name = "aaa"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("download", ("download", Native.Aaa.Route.Download))])
                self._leafs = OrderedDict()

                self.download = Native.Aaa.Route.Download()
                self.download.parent = self
                self._children_name_map["download"] = "download"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:route"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Aaa.Route, [], name, value)


            class Download(Entity):
                """
                Download from AAA server
                
                .. attribute:: update_period
                
                	Route update period in minutes
                	**type**\: int
                
                	**range:** 1..1440
                
                .. attribute:: authorization
                
                	Method list to use for authorization
                	**type**\: str
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Aaa.Route.Download, self).__init__()

                    self.yang_name = "download"
                    self.yang_parent_name = "route"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('update_period', (YLeaf(YType.uint16, 'update-period'), ['int'])),
                        ('authorization', (YLeaf(YType.str, 'authorization'), ['str'])),
                    ])
                    self.update_period = None
                    self.authorization = None
                    self._segment_path = lambda: "download"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/aaa/Cisco-IOS-XE-aaa:route/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Aaa.Route.Download, ['update_period', 'authorization'], name, value)


    class Privilege(Entity):
        """
        Command privilege parameters
        
        .. attribute:: mode
        
        	
        	**type**\: list of  		 :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Privilege.Mode>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Privilege, self).__init__()

            self.yang_name = "privilege"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("mode", ("mode", Native.Privilege.Mode))])
            self._leafs = OrderedDict()

            self.mode = YList(self)
            self._segment_path = lambda: "privilege"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Privilege, [], name, value)


        class Mode(Entity):
            """
            
            
            .. attribute:: name  (key)
            
            	
            	**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Privilege.Mode.Name>`
            
            .. attribute:: all
            
            	
            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Privilege.Mode.All>`
            
            .. attribute:: level
            
            	Set privilege level of command
            	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Privilege.Mode.Level>`
            
            .. attribute:: reset
            
            	
            	**type**\: list of  		 :py:class:`Reset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Privilege.Mode.Reset>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Privilege.Mode, self).__init__()

                self.yang_name = "mode"
                self.yang_parent_name = "privilege"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("all", ("all", Native.Privilege.Mode.All)), ("level", ("level", Native.Privilege.Mode.Level)), ("reset", ("reset", Native.Privilege.Mode.Reset))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.enumeration, 'name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Privilege.Mode.Name')])),
                ])
                self.name = None

                self.all = Native.Privilege.Mode.All()
                self.all.parent = self
                self._children_name_map["all"] = "all"

                self.level = YList(self)
                self.reset = YList(self)
                self._segment_path = lambda: "mode" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/privilege/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Privilege.Mode, [u'name'], name, value)

            class Name(Enum):
                """
                Name (Enum Class)

                .. data:: configure = 0

                .. data:: exec_ = 1

                .. data:: interface = 2

                .. data:: router = 3

                """

                configure = Enum.YLeaf(0, "configure")

                exec_ = Enum.YLeaf(1, "exec")

                interface = Enum.YLeaf(2, "interface")

                router = Enum.YLeaf(3, "router")



            class All(Entity):
                """
                
                
                .. attribute:: level
                
                	Set privilege level of command
                	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Privilege.Mode.All.Level>`
                
                .. attribute:: reset
                
                	
                	**type**\: list of  		 :py:class:`Reset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Privilege.Mode.All.Reset>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Privilege.Mode.All, self).__init__()

                    self.yang_name = "all"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Privilege.Mode.All.Level)), ("reset", ("reset", Native.Privilege.Mode.All.Reset))])
                    self._leafs = OrderedDict()

                    self.level = YList(self)
                    self.reset = YList(self)
                    self._segment_path = lambda: "all"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Privilege.Mode.All, [], name, value)


                class Level(Entity):
                    """
                    Set privilege level of command
                    
                    .. attribute:: privilege  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: command_list
                    
                    	
                    	**type**\: list of  		 :py:class:`CommandList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Privilege.Mode.All.Level.CommandList>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Privilege.Mode.All.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['privilege']
                        self._child_classes = OrderedDict([("command-list", ("command_list", Native.Privilege.Mode.All.Level.CommandList))])
                        self._leafs = OrderedDict([
                            ('privilege', (YLeaf(YType.uint8, 'privilege'), ['int'])),
                        ])
                        self.privilege = None

                        self.command_list = YList(self)
                        self._segment_path = lambda: "level" + "[privilege='" + str(self.privilege) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Privilege.Mode.All.Level, [u'privilege'], name, value)


                    class CommandList(Entity):
                        """
                        
                        
                        .. attribute:: command  (key)
                        
                        	There are side effects
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Privilege.Mode.All.Level.CommandList, self).__init__()

                            self.yang_name = "command-list"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['command']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('command', (YLeaf(YType.str, 'command'), ['str'])),
                            ])
                            self.command = None
                            self._segment_path = lambda: "command-list" + "[command='" + str(self.command) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Privilege.Mode.All.Level.CommandList, [u'command'], name, value)


                class Reset(Entity):
                    """
                    
                    
                    .. attribute:: command  (key)
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Privilege.Mode.All.Reset, self).__init__()

                        self.yang_name = "reset"
                        self.yang_parent_name = "all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['command']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('command', (YLeaf(YType.str, 'command'), ['str'])),
                        ])
                        self.command = None
                        self._segment_path = lambda: "reset" + "[command='" + str(self.command) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Privilege.Mode.All.Reset, [u'command'], name, value)


            class Level(Entity):
                """
                Set privilege level of command
                
                .. attribute:: privilege  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: command_list
                
                	
                	**type**\: list of  		 :py:class:`CommandList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Privilege.Mode.Level.CommandList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Privilege.Mode.Level, self).__init__()

                    self.yang_name = "level"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['privilege']
                    self._child_classes = OrderedDict([("command-list", ("command_list", Native.Privilege.Mode.Level.CommandList))])
                    self._leafs = OrderedDict([
                        ('privilege', (YLeaf(YType.uint8, 'privilege'), ['int'])),
                    ])
                    self.privilege = None

                    self.command_list = YList(self)
                    self._segment_path = lambda: "level" + "[privilege='" + str(self.privilege) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Privilege.Mode.Level, [u'privilege'], name, value)


                class CommandList(Entity):
                    """
                    
                    
                    .. attribute:: command  (key)
                    
                    	There are side effects
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Privilege.Mode.Level.CommandList, self).__init__()

                        self.yang_name = "command-list"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['command']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('command', (YLeaf(YType.str, 'command'), ['str'])),
                        ])
                        self.command = None
                        self._segment_path = lambda: "command-list" + "[command='" + str(self.command) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Privilege.Mode.Level.CommandList, [u'command'], name, value)


            class Reset(Entity):
                """
                
                
                .. attribute:: command  (key)
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Privilege.Mode.Reset, self).__init__()

                    self.yang_name = "reset"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['command']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('command', (YLeaf(YType.str, 'command'), ['str'])),
                    ])
                    self.command = None
                    self._segment_path = lambda: "reset" + "[command='" + str(self.command) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Privilege.Mode.Reset, [u'command'], name, value)


    class Login(Entity):
        """
        Enable secure login checking
        
        .. attribute:: delay
        
        	Set delay between successive fail login
        	**type**\: int
        
        	**range:** 1..10
        
        .. attribute:: on_failure
        
        	Set options for failed login attempt
        	**type**\:  :py:class:`OnFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Login.OnFailure>`
        
        	**presence node**\: True
        
        .. attribute:: on_success
        
        	Set options for successful login attempt
        	**type**\:  :py:class:`OnSuccess <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Login.OnSuccess>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Login, self).__init__()

            self.yang_name = "login"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("on-failure", ("on_failure", Native.Login.OnFailure)), ("on-success", ("on_success", Native.Login.OnSuccess))])
            self._leafs = OrderedDict([
                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
            ])
            self.delay = None

            self.on_failure = None
            self._children_name_map["on_failure"] = "on-failure"

            self.on_success = None
            self._children_name_map["on_success"] = "on-success"
            self._segment_path = lambda: "login"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Login, [u'delay'], name, value)


        class OnFailure(Entity):
            """
            Set options for failed login attempt
            
            .. attribute:: log
            
            	Generate syslogs on failure logins
            	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Login.OnFailure.Log>`
            
            	**presence node**\: True
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Login.OnFailure, self).__init__()

                self.yang_name = "on-failure"
                self.yang_parent_name = "login"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("log", ("log", Native.Login.OnFailure.Log))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.log = None
                self._children_name_map["log"] = "log"
                self._segment_path = lambda: "on-failure"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/login/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Login.OnFailure, [], name, value)


            class Log(Entity):
                """
                Generate syslogs on failure logins
                
                .. attribute:: every
                
                	Periodicity for logs generated
                	**type**\: int
                
                	**range:** 1..65535
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Login.OnFailure.Log, self).__init__()

                    self.yang_name = "log"
                    self.yang_parent_name = "on-failure"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('every', (YLeaf(YType.uint16, 'every'), ['int'])),
                    ])
                    self.every = None
                    self._segment_path = lambda: "log"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/login/on-failure/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Login.OnFailure.Log, [u'every'], name, value)


        class OnSuccess(Entity):
            """
            Set options for successful login attempt
            
            .. attribute:: log
            
            	Generate syslogs on successful logins
            	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Login.OnSuccess.Log>`
            
            	**presence node**\: True
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Login.OnSuccess, self).__init__()

                self.yang_name = "on-success"
                self.yang_parent_name = "login"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("log", ("log", Native.Login.OnSuccess.Log))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.log = None
                self._children_name_map["log"] = "log"
                self._segment_path = lambda: "on-success"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/login/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Login.OnSuccess, [], name, value)


            class Log(Entity):
                """
                Generate syslogs on successful logins
                
                .. attribute:: every
                
                	Periodicity for logs generated
                	**type**\: int
                
                	**range:** 1..65535
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Login.OnSuccess.Log, self).__init__()

                    self.yang_name = "log"
                    self.yang_parent_name = "on-success"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('every', (YLeaf(YType.uint16, 'every'), ['int'])),
                    ])
                    self.every = None
                    self._segment_path = lambda: "log"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/login/on-success/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Login.OnSuccess.Log, [u'every'], name, value)


    class Multilink(Entity):
        """
        PPP multilink global configuration
        
        .. attribute:: bundle_name
        
        	Select method for naming multilink bundles
        	**type**\:  :py:class:`BundleName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Multilink.BundleName>`
        
        .. attribute:: virtual_template
        
        	virtual\-template interface
        	**type**\: int
        
        	**range:** 1..4095
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Multilink, self).__init__()

            self.yang_name = "multilink"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('bundle_name', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-ppp:bundle-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Multilink.BundleName')])),
                ('virtual_template', (YLeaf(YType.uint16, 'Cisco-IOS-XE-ppp:virtual-template'), ['int'])),
            ])
            self.bundle_name = None
            self.virtual_template = None
            self._segment_path = lambda: "multilink"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Multilink, ['bundle_name', 'virtual_template'], name, value)

        class BundleName(Enum):
            """
            BundleName (Enum Class)

            Select method for naming multilink bundles

            .. data:: authenticated = 0

            .. data:: both = 1

            .. data:: endpoint = 2

            .. data:: rfc = 3

            """

            authenticated = Enum.YLeaf(0, "authenticated")

            both = Enum.YLeaf(1, "both")

            endpoint = Enum.YLeaf(2, "endpoint")

            rfc = Enum.YLeaf(3, "rfc")



    class MacAddressTable(Entity):
        """
        Configure the MAC address table
        
        .. attribute:: evc_xconnect
        
        	All ethernet virtual connections xconnect
        	**type**\:  :py:class:`EvcXconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MacAddressTable.EvcXconnect>`
        
        .. attribute:: limit
        
        	Enter parameters for mac limit feature
        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MacAddressTable.Limit>`
        
        .. attribute:: learning
        
        	Enable a MAC table learning feature
        	**type**\:  :py:class:`Learning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MacAddressTable.Learning>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.MacAddressTable, self).__init__()

            self.yang_name = "mac-address-table"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("evc-xconnect", ("evc_xconnect", Native.MacAddressTable.EvcXconnect)), ("limit", ("limit", Native.MacAddressTable.Limit)), ("learning", ("learning", Native.MacAddressTable.Learning))])
            self._leafs = OrderedDict()

            self.evc_xconnect = Native.MacAddressTable.EvcXconnect()
            self.evc_xconnect.parent = self
            self._children_name_map["evc_xconnect"] = "evc-xconnect"

            self.limit = Native.MacAddressTable.Limit()
            self.limit.parent = self
            self._children_name_map["limit"] = "limit"

            self.learning = Native.MacAddressTable.Learning()
            self.learning.parent = self
            self._children_name_map["learning"] = "learning"
            self._segment_path = lambda: "mac-address-table"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.MacAddressTable, [], name, value)


        class EvcXconnect(Entity):
            """
            All ethernet virtual connections xconnect
            
            .. attribute:: l2pt_forward_all
            
            	Layer 2 Protocol Forward All
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.MacAddressTable.EvcXconnect, self).__init__()

                self.yang_name = "evc-xconnect"
                self.yang_parent_name = "mac-address-table"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('l2pt_forward_all', (YLeaf(YType.empty, 'l2pt-forward-all'), ['Empty'])),
                ])
                self.l2pt_forward_all = None
                self._segment_path = lambda: "evc-xconnect"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac-address-table/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.MacAddressTable.EvcXconnect, [u'l2pt_forward_all'], name, value)


        class Limit(Entity):
            """
            Enter parameters for mac limit feature
            
            .. attribute:: bdomain
            
            	bdomain number for  mac limit feature
            	**type**\: list of  		 :py:class:`Bdomain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MacAddressTable.Limit.Bdomain>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.MacAddressTable.Limit, self).__init__()

                self.yang_name = "limit"
                self.yang_parent_name = "mac-address-table"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("bdomain", ("bdomain", Native.MacAddressTable.Limit.Bdomain))])
                self._leafs = OrderedDict()

                self.bdomain = YList(self)
                self._segment_path = lambda: "limit"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac-address-table/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.MacAddressTable.Limit, [], name, value)


            class Bdomain(Entity):
                """
                bdomain number for  mac limit feature
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 1..4095
                
                .. attribute:: action
                
                	Enter action
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MacAddressTable.Limit.Bdomain.Action>`
                
                .. attribute:: maximum
                
                	Enter max allowed entries
                	**type**\: int
                
                	**range:** 0..16000
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.MacAddressTable.Limit.Bdomain, self).__init__()

                    self.yang_name = "bdomain"
                    self.yang_parent_name = "limit"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'MacAddressTable.Limit.Bdomain.Action')])),
                        ('maximum', (YLeaf(YType.uint32, 'maximum'), ['int'])),
                    ])
                    self.number = None
                    self.action = None
                    self.maximum = None
                    self._segment_path = lambda: "bdomain" + "[number='" + str(self.number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac-address-table/limit/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.MacAddressTable.Limit.Bdomain, [u'number', u'action', u'maximum'], name, value)

                class Action(Enum):
                    """
                    Action (Enum Class)

                    Enter action

                    .. data:: warning = 0

                    .. data:: limit = 1

                    .. data:: shutdown = 2

                    """

                    warning = Enum.YLeaf(0, "warning")

                    limit = Enum.YLeaf(1, "limit")

                    shutdown = Enum.YLeaf(2, "shutdown")



        class Learning(Entity):
            """
            Enable a MAC table learning feature
            
            .. attribute:: vlan
            
            	Layer 2 table learning per VLAN
            	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MacAddressTable.Learning.Vlan>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.MacAddressTable.Learning, self).__init__()

                self.yang_name = "learning"
                self.yang_parent_name = "mac-address-table"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vlan", ("vlan", Native.MacAddressTable.Learning.Vlan))])
                self._leafs = OrderedDict()

                self.vlan = YList(self)
                self._segment_path = lambda: "learning"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac-address-table/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.MacAddressTable.Learning, [], name, value)


            class Vlan(Entity):
                """
                Layer 2 table learning per VLAN
                
                .. attribute:: id  (key)
                
                	
                	**type**\: int
                
                	**range:** 1..4094
                
                .. attribute:: module
                
                	Layer 2 table learning per VLAN per module
                	**type**\: int
                
                	**range:** 1..9
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.MacAddressTable.Learning.Vlan, self).__init__()

                    self.yang_name = "vlan"
                    self.yang_parent_name = "learning"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                        ('module', (YLeaf(YType.uint8, 'module'), ['int'])),
                    ])
                    self.id = None
                    self.module = None
                    self._segment_path = lambda: "vlan" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac-address-table/learning/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.MacAddressTable.Learning.Vlan, [u'id', u'module'], name, value)


    class Redundancy(Entity):
        """
        Enter redundancy mode
        
        .. attribute:: maintenance_mode
        
        	Enable/Disable maintenance mode 
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: main_cpu
        
        	Enter main\-cpu mode
        	**type**\:  :py:class:`MainCpu <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.MainCpu>`
        
        	**presence node**\: True
        
        .. attribute:: mode
        
        	redundancy mode for this chassis
        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Mode>`
        
        .. attribute:: policy
        
        	redundancy policy enforcement
        	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Policy>`
        
        .. attribute:: timer
        
        	Select a timer to configure
        	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Timer>`
        
        .. attribute:: interchassis
        
        	Enter interchassis mode
        	**type**\:  :py:class:`Interchassis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Interchassis>`
        
        

        This class is a :ref:`presence class<presence-class>`

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Redundancy, self).__init__()

            self.yang_name = "redundancy"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("main-cpu", ("main_cpu", Native.Redundancy.MainCpu)), ("policy", ("policy", Native.Redundancy.Policy)), ("timer", ("timer", Native.Redundancy.Timer)), ("interchassis", ("interchassis", Native.Redundancy.Interchassis))])
            self.is_presence_container = True
            self._leafs = OrderedDict([
                ('maintenance_mode', (YLeaf(YType.empty, 'maintenance-mode'), ['Empty'])),
                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Redundancy.Mode')])),
            ])
            self.maintenance_mode = None
            self.mode = None

            self.main_cpu = None
            self._children_name_map["main_cpu"] = "main-cpu"

            self.policy = Native.Redundancy.Policy()
            self.policy.parent = self
            self._children_name_map["policy"] = "policy"

            self.timer = Native.Redundancy.Timer()
            self.timer.parent = self
            self._children_name_map["timer"] = "timer"

            self.interchassis = Native.Redundancy.Interchassis()
            self.interchassis.parent = self
            self._children_name_map["interchassis"] = "interchassis"
            self._segment_path = lambda: "redundancy"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Redundancy, [u'maintenance_mode', u'mode'], name, value)

        class Mode(Enum):
            """
            Mode (Enum Class)

            redundancy mode for this chassis

            .. data:: rpr = 0

            .. data:: rpr_plus = 1

            .. data:: sso = 2

            .. data:: none = 3

            """

            rpr = Enum.YLeaf(0, "rpr")

            rpr_plus = Enum.YLeaf(1, "rpr-plus")

            sso = Enum.YLeaf(2, "sso")

            none = Enum.YLeaf(3, "none")



        class MainCpu(Entity):
            """
            Enter main\-cpu mode
            
            .. attribute:: auto_sync
            
            	
            	**type**\:  :py:class:`AutoSync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.MainCpu.AutoSync>`
            
            .. attribute:: standby
            
            	Standby
            	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.MainCpu.Standby>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Redundancy.MainCpu, self).__init__()

                self.yang_name = "main-cpu"
                self.yang_parent_name = "redundancy"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("auto-sync", ("auto_sync", Native.Redundancy.MainCpu.AutoSync)), ("standby", ("standby", Native.Redundancy.MainCpu.Standby))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.auto_sync = Native.Redundancy.MainCpu.AutoSync()
                self.auto_sync.parent = self
                self._children_name_map["auto_sync"] = "auto-sync"

                self.standby = Native.Redundancy.MainCpu.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"
                self._segment_path = lambda: "main-cpu"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Redundancy.MainCpu, [], name, value)


            class AutoSync(Entity):
                """
                
                
                .. attribute:: running_config
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: config_register
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bootvar
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: standard
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Redundancy.MainCpu.AutoSync, self).__init__()

                    self.yang_name = "auto-sync"
                    self.yang_parent_name = "main-cpu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('running_config', (YLeaf(YType.empty, 'running-config'), ['Empty'])),
                        ('config_register', (YLeaf(YType.empty, 'config-register'), ['Empty'])),
                        ('bootvar', (YLeaf(YType.empty, 'bootvar'), ['Empty'])),
                        ('standard', (YLeaf(YType.empty, 'standard'), ['Empty'])),
                    ])
                    self.running_config = None
                    self.config_register = None
                    self.bootvar = None
                    self.standard = None
                    self._segment_path = lambda: "auto-sync"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/main-cpu/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Redundancy.MainCpu.AutoSync, [u'running_config', u'config_register', u'bootvar', u'standard'], name, value)


            class Standby(Entity):
                """
                Standby
                
                .. attribute:: console
                
                	Console
                	**type**\:  :py:class:`Console <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.MainCpu.Standby.Console>`
                
                .. attribute:: initialization
                
                	Initialization
                	**type**\:  :py:class:`Initialization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.MainCpu.Standby.Initialization>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Redundancy.MainCpu.Standby, self).__init__()

                    self.yang_name = "standby"
                    self.yang_parent_name = "main-cpu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("console", ("console", Native.Redundancy.MainCpu.Standby.Console)), ("initialization", ("initialization", Native.Redundancy.MainCpu.Standby.Initialization))])
                    self._leafs = OrderedDict()

                    self.console = Native.Redundancy.MainCpu.Standby.Console()
                    self.console.parent = self
                    self._children_name_map["console"] = "console"

                    self.initialization = Native.Redundancy.MainCpu.Standby.Initialization()
                    self.initialization.parent = self
                    self._children_name_map["initialization"] = "initialization"
                    self._segment_path = lambda: "standby"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/main-cpu/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Redundancy.MainCpu.Standby, [], name, value)


                class Console(Entity):
                    """
                    Console
                    
                    .. attribute:: enable
                    
                    	Enable
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Redundancy.MainCpu.Standby.Console, self).__init__()

                        self.yang_name = "console"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "console"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/main-cpu/standby/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Redundancy.MainCpu.Standby.Console, [u'enable'], name, value)


                class Initialization(Entity):
                    """
                    Initialization
                    
                    .. attribute:: delay
                    
                    	Delay
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.MainCpu.Standby.Initialization.Delay>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Redundancy.MainCpu.Standby.Initialization, self).__init__()

                        self.yang_name = "initialization"
                        self.yang_parent_name = "standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("delay", ("delay", Native.Redundancy.MainCpu.Standby.Initialization.Delay))])
                        self._leafs = OrderedDict()

                        self.delay = Native.Redundancy.MainCpu.Standby.Initialization.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"
                        self._segment_path = lambda: "initialization"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/main-cpu/standby/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Redundancy.MainCpu.Standby.Initialization, [], name, value)


                    class Delay(Entity):
                        """
                        Delay
                        
                        .. attribute:: second
                        
                        	Delay value in seconds
                        	**type**\: int
                        
                        	**range:** 30..1800
                        
                        .. attribute:: boot_only
                        
                        	Delay effective only on system boot
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Redundancy.MainCpu.Standby.Initialization.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "initialization"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('second', (YLeaf(YType.uint16, 'second'), ['int'])),
                                ('boot_only', (YLeaf(YType.empty, 'boot-only'), ['Empty'])),
                            ])
                            self.second = None
                            self.boot_only = None
                            self._segment_path = lambda: "delay"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/main-cpu/standby/initialization/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Redundancy.MainCpu.Standby.Initialization.Delay, [u'second', u'boot_only'], name, value)


        class Policy(Entity):
            """
            redundancy policy enforcement
            
            .. attribute:: config_sync
            
            	config sync parameters
            	**type**\:  :py:class:`ConfigSync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Policy.ConfigSync>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Redundancy.Policy, self).__init__()

                self.yang_name = "policy"
                self.yang_parent_name = "redundancy"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("config-sync", ("config_sync", Native.Redundancy.Policy.ConfigSync))])
                self._leafs = OrderedDict()

                self.config_sync = Native.Redundancy.Policy.ConfigSync()
                self.config_sync.parent = self
                self._children_name_map["config_sync"] = "config-sync"
                self._segment_path = lambda: "policy"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Redundancy.Policy, [], name, value)


            class ConfigSync(Entity):
                """
                config sync parameters
                
                .. attribute:: bulk
                
                	bulk configuration mode
                	**type**\:  :py:class:`Bulk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Policy.ConfigSync.Bulk>`
                
                .. attribute:: lbl
                
                	line\-by\-line configuration mode
                	**type**\:  :py:class:`Lbl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Policy.ConfigSync.Lbl>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Redundancy.Policy.ConfigSync, self).__init__()

                    self.yang_name = "config-sync"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bulk", ("bulk", Native.Redundancy.Policy.ConfigSync.Bulk)), ("lbl", ("lbl", Native.Redundancy.Policy.ConfigSync.Lbl))])
                    self._leafs = OrderedDict()

                    self.bulk = Native.Redundancy.Policy.ConfigSync.Bulk()
                    self.bulk.parent = self
                    self._children_name_map["bulk"] = "bulk"

                    self.lbl = Native.Redundancy.Policy.ConfigSync.Lbl()
                    self.lbl.parent = self
                    self._children_name_map["lbl"] = "lbl"
                    self._segment_path = lambda: "config-sync"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/policy/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Redundancy.Policy.ConfigSync, [], name, value)


                class Bulk(Entity):
                    """
                    bulk configuration mode
                    
                    .. attribute:: prc
                    
                    	prc policy enforcement
                    	**type**\:  :py:class:`Prc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Policy.ConfigSync.Bulk.Prc>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Redundancy.Policy.ConfigSync.Bulk, self).__init__()

                        self.yang_name = "bulk"
                        self.yang_parent_name = "config-sync"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prc", ("prc", Native.Redundancy.Policy.ConfigSync.Bulk.Prc))])
                        self._leafs = OrderedDict()

                        self.prc = Native.Redundancy.Policy.ConfigSync.Bulk.Prc()
                        self.prc.parent = self
                        self._children_name_map["prc"] = "prc"
                        self._segment_path = lambda: "bulk"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/policy/config-sync/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Redundancy.Policy.ConfigSync.Bulk, [], name, value)


                    class Prc(Entity):
                        """
                        prc policy enforcement
                        
                        .. attribute:: reload
                        
                        	reload standby
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Redundancy.Policy.ConfigSync.Bulk.Prc, self).__init__()

                            self.yang_name = "prc"
                            self.yang_parent_name = "bulk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('reload', (YLeaf(YType.boolean, 'reload'), ['bool'])),
                            ])
                            self.reload = None
                            self._segment_path = lambda: "prc"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/policy/config-sync/bulk/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Redundancy.Policy.ConfigSync.Bulk.Prc, [u'reload'], name, value)


                class Lbl(Entity):
                    """
                    line\-by\-line configuration mode
                    
                    .. attribute:: prc
                    
                    	prc policy enforcement
                    	**type**\:  :py:class:`Prc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Policy.ConfigSync.Lbl.Prc>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Redundancy.Policy.ConfigSync.Lbl, self).__init__()

                        self.yang_name = "lbl"
                        self.yang_parent_name = "config-sync"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prc", ("prc", Native.Redundancy.Policy.ConfigSync.Lbl.Prc))])
                        self._leafs = OrderedDict()

                        self.prc = Native.Redundancy.Policy.ConfigSync.Lbl.Prc()
                        self.prc.parent = self
                        self._children_name_map["prc"] = "prc"
                        self._segment_path = lambda: "lbl"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/policy/config-sync/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Redundancy.Policy.ConfigSync.Lbl, [], name, value)


                    class Prc(Entity):
                        """
                        prc policy enforcement
                        
                        .. attribute:: reload
                        
                        	reload standby
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Redundancy.Policy.ConfigSync.Lbl.Prc, self).__init__()

                            self.yang_name = "prc"
                            self.yang_parent_name = "lbl"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('reload', (YLeaf(YType.boolean, 'reload'), ['bool'])),
                            ])
                            self.reload = None
                            self._segment_path = lambda: "prc"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/policy/config-sync/lbl/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Redundancy.Policy.ConfigSync.Lbl.Prc, [u'reload'], name, value)


        class Timer(Entity):
            """
            Select a timer to configure
            
            .. attribute:: rpso
            
            	Delay value in seconds
            	**type**\: int
            
            	**range:** 120..1200
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Redundancy.Timer, self).__init__()

                self.yang_name = "timer"
                self.yang_parent_name = "redundancy"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('rpso', (YLeaf(YType.uint16, 'rpso'), ['int'])),
                ])
                self.rpso = None
                self._segment_path = lambda: "timer"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Redundancy.Timer, [u'rpso'], name, value)


        class Interchassis(Entity):
            """
            Enter interchassis mode
            
            .. attribute:: group
            
            	Enter the redundancy group number
            	**type**\: list of  		 :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Interchassis.Group>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Redundancy.Interchassis, self).__init__()

                self.yang_name = "interchassis"
                self.yang_parent_name = "redundancy"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("group", ("group", Native.Redundancy.Interchassis.Group))])
                self._leafs = OrderedDict()

                self.group = YList(self)
                self._segment_path = lambda: "interchassis"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Redundancy.Interchassis, [], name, value)


            class Group(Entity):
                """
                Enter the redundancy group number
                
                .. attribute:: group_number  (key)
                
                	
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: monitor
                
                	define the peer monitoring method
                	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Interchassis.Group.Monitor>`
                
                .. attribute:: member
                
                	specify a redundancy group member
                	**type**\:  :py:class:`Member <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Interchassis.Group.Member>`
                
                .. attribute:: backbone
                
                	specify a redundancy group member
                	**type**\:  :py:class:`Backbone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Interchassis.Group.Backbone>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Redundancy.Interchassis.Group, self).__init__()

                    self.yang_name = "group"
                    self.yang_parent_name = "interchassis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['group_number']
                    self._child_classes = OrderedDict([("monitor", ("monitor", Native.Redundancy.Interchassis.Group.Monitor)), ("member", ("member", Native.Redundancy.Interchassis.Group.Member)), ("backbone", ("backbone", Native.Redundancy.Interchassis.Group.Backbone))])
                    self._leafs = OrderedDict([
                        ('group_number', (YLeaf(YType.uint64, 'group-number'), ['int'])),
                    ])
                    self.group_number = None

                    self.monitor = Native.Redundancy.Interchassis.Group.Monitor()
                    self.monitor.parent = self
                    self._children_name_map["monitor"] = "monitor"

                    self.member = Native.Redundancy.Interchassis.Group.Member()
                    self.member.parent = self
                    self._children_name_map["member"] = "member"

                    self.backbone = Native.Redundancy.Interchassis.Group.Backbone()
                    self.backbone.parent = self
                    self._children_name_map["backbone"] = "backbone"
                    self._segment_path = lambda: "group" + "[group-number='" + str(self.group_number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/redundancy/interchassis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Redundancy.Interchassis.Group, [u'group_number'], name, value)


                class Monitor(Entity):
                    """
                    define the peer monitoring method
                    
                    .. attribute:: peer
                    
                    	the peer method
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bfd
                    
                    	set peer monitoring method to bfd
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Redundancy.Interchassis.Group.Monitor, self).__init__()

                        self.yang_name = "monitor"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('peer', (YLeaf(YType.empty, 'peer'), ['Empty'])),
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ])
                        self.peer = None
                        self.bfd = None
                        self._segment_path = lambda: "monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Redundancy.Interchassis.Group.Monitor, [u'peer', u'bfd'], name, value)


                class Member(Entity):
                    """
                    specify a redundancy group member
                    
                    .. attribute:: ip
                    
                    	specify the redundancy group member using an ip address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Redundancy.Interchassis.Group.Member, self).__init__()

                        self.yang_name = "member"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                        ])
                        self.ip = None
                        self._segment_path = lambda: "member"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Redundancy.Interchassis.Group.Member, [u'ip'], name, value)


                class Backbone(Entity):
                    """
                    specify a redundancy group member
                    
                    .. attribute:: interface
                    
                    	
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Interchassis.Group.Backbone.Interface>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Redundancy.Interchassis.Group.Backbone, self).__init__()

                        self.yang_name = "backbone"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Native.Redundancy.Interchassis.Group.Backbone.Interface))])
                        self._leafs = OrderedDict()

                        self.interface = Native.Redundancy.Interchassis.Group.Backbone.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._segment_path = lambda: "backbone"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Redundancy.Interchassis.Group.Backbone, [], name, value)


                    class Interface(Entity):
                        """
                        
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Interchassis.Group.Backbone.Interface.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Interchassis.Group.Backbone.Interface.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Interchassis.Group.Backbone.Interface.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Redundancy.Interchassis.Group.Backbone.Interface.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Redundancy.Interchassis.Group.Backbone.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "backbone"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Redundancy.Interchassis.Group.Backbone.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Redundancy.Interchassis.Group.Backbone.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Redundancy.Interchassis.Group.Backbone.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Redundancy.Interchassis.Group.Backbone.Interface.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Redundancy.Interchassis.Group.Backbone.Interface.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Redundancy.Interchassis.Group.Backbone.Interface.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Redundancy.Interchassis.Group.Backbone.Interface.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Redundancy.Interchassis.Group.Backbone.Interface.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Redundancy.Interchassis.Group.Backbone.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Redundancy.Interchassis.Group.Backbone.Interface.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Redundancy.Interchassis.Group.Backbone.Interface.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Redundancy.Interchassis.Group.Backbone.Interface.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Redundancy.Interchassis.Group.Backbone.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Redundancy.Interchassis.Group.Backbone.Interface.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Redundancy.Interchassis.Group.Backbone.Interface.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Redundancy.Interchassis.Group.Backbone.Interface.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Redundancy.Interchassis.Group.Backbone.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


    class Scheduler(Entity):
        """
        Scheduler parameters
        
        .. attribute:: runtime
        
        	Process runtime controls
        	**type**\:  :py:class:`Runtime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Scheduler.Runtime>`
        
        .. attribute:: allocate
        
        	Guarantee CPU time for processes
        	**type**\:  :py:class:`Allocate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Scheduler.Allocate>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Scheduler, self).__init__()

            self.yang_name = "scheduler"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("runtime", ("runtime", Native.Scheduler.Runtime)), ("allocate", ("allocate", Native.Scheduler.Allocate))])
            self._leafs = OrderedDict()

            self.runtime = Native.Scheduler.Runtime()
            self.runtime.parent = self
            self._children_name_map["runtime"] = "runtime"

            self.allocate = Native.Scheduler.Allocate()
            self.allocate.parent = self
            self._children_name_map["allocate"] = "allocate"
            self._segment_path = lambda: "scheduler"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Scheduler, [], name, value)


        class Runtime(Entity):
            """
            Process runtime controls
            
            .. attribute:: netinput
            
            	Process\-switching run time (in milliseconds)
            	**type**\: int
            
            	**range:** 100..40000
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Scheduler.Runtime, self).__init__()

                self.yang_name = "runtime"
                self.yang_parent_name = "scheduler"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('netinput', (YLeaf(YType.uint16, 'netinput'), ['int'])),
                ])
                self.netinput = None
                self._segment_path = lambda: "runtime"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/scheduler/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Scheduler.Runtime, [u'netinput'], name, value)


        class Allocate(Entity):
            """
            Guarantee CPU time for processes
            
            .. attribute:: interrupt_time
            
            	
            	**type**\: int
            
            	**range:** 400..60000
            
            .. attribute:: process_time
            
            	
            	**type**\: int
            
            	**range:** 100..4000
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Scheduler.Allocate, self).__init__()

                self.yang_name = "allocate"
                self.yang_parent_name = "scheduler"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('interrupt_time', (YLeaf(YType.uint16, 'interrupt-time'), ['int'])),
                    ('process_time', (YLeaf(YType.uint16, 'process-time'), ['int'])),
                ])
                self.interrupt_time = None
                self.process_time = None
                self._segment_path = lambda: "allocate"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/scheduler/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Scheduler.Allocate, [u'interrupt_time', u'process_time'], name, value)


    class Epm(Entity):
        """
        EPM Global Configuration Commands
        
        .. attribute:: logging
        
        	Enable EPM logging
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Epm, self).__init__()

            self.yang_name = "epm"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('logging', (YLeaf(YType.empty, 'logging'), ['Empty'])),
            ])
            self.logging = None
            self._segment_path = lambda: "epm"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Epm, [u'logging'], name, value)


    class SpanningTree(Entity):
        """
        Spanning Tree Subsystem
        
        .. attribute:: backbonefast
        
        	Enable BackboneFast Feature
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: bridge
        
        	
        	**type**\:  :py:class:`Bridge <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Bridge>`
        
        .. attribute:: etherchannel
        
        	Spanning tree etherchannel specific configuration
        	**type**\:  :py:class:`Etherchannel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Etherchannel>`
        
        .. attribute:: extend
        
        	Spanning Tree 802.1t extensions
        	**type**\:  :py:class:`Extend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Extend>`
        
        .. attribute:: logging
        
        	Enable Spanning tree logging
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: loopguard
        
        	Spanning tree loopguard options
        	**type**\:  :py:class:`Loopguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Loopguard>`
        
        .. attribute:: mst
        
        	Multiple spanning tree configuration
        	**type**\:  :py:class:`Mst <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Mst>`
        
        .. attribute:: optimize
        
        	
        	**type**\:  :py:class:`Optimize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Optimize>`
        
        .. attribute:: pathcost
        
        	Spanning tree pathcost options
        	**type**\:  :py:class:`Pathcost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Pathcost>`
        
        .. attribute:: portfast
        
        	Spanning tree portfast options
        	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Portfast>`
        
        .. attribute:: transmit
        
        	STP transmit parameters
        	**type**\:  :py:class:`Transmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Transmit>`
        
        .. attribute:: uplinkfast
        
        	Enable UplinkFast Feature
        	**type**\:  :py:class:`Uplinkfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Uplinkfast>`
        
        	**presence node**\: True
        
        .. attribute:: mode
        
        	Spanning tree operating mode
        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Mode>`
        
        	**default value**\: rapid-pvst
        
        .. attribute:: vlan
        
        	VLAN Switch Spanning Tree
        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Vlan>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.SpanningTree, self).__init__()

            self.yang_name = "spanning-tree"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-spanning-tree:bridge", ("bridge", Native.SpanningTree.Bridge)), ("Cisco-IOS-XE-spanning-tree:etherchannel", ("etherchannel", Native.SpanningTree.Etherchannel)), ("Cisco-IOS-XE-spanning-tree:extend", ("extend", Native.SpanningTree.Extend)), ("Cisco-IOS-XE-spanning-tree:loopguard", ("loopguard", Native.SpanningTree.Loopguard)), ("Cisco-IOS-XE-spanning-tree:mst", ("mst", Native.SpanningTree.Mst)), ("Cisco-IOS-XE-spanning-tree:optimize", ("optimize", Native.SpanningTree.Optimize)), ("Cisco-IOS-XE-spanning-tree:pathcost", ("pathcost", Native.SpanningTree.Pathcost)), ("Cisco-IOS-XE-spanning-tree:portfast", ("portfast", Native.SpanningTree.Portfast)), ("Cisco-IOS-XE-spanning-tree:transmit", ("transmit", Native.SpanningTree.Transmit)), ("Cisco-IOS-XE-spanning-tree:uplinkfast", ("uplinkfast", Native.SpanningTree.Uplinkfast)), ("Cisco-IOS-XE-spanning-tree:vlan", ("vlan", Native.SpanningTree.Vlan))])
            self._leafs = OrderedDict([
                ('backbonefast', (YLeaf(YType.empty, 'Cisco-IOS-XE-spanning-tree:backbonefast'), ['Empty'])),
                ('logging', (YLeaf(YType.empty, 'Cisco-IOS-XE-spanning-tree:logging'), ['Empty'])),
                ('mode', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-spanning-tree:mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'SpanningTree.Mode')])),
            ])
            self.backbonefast = None
            self.logging = None
            self.mode = None

            self.bridge = Native.SpanningTree.Bridge()
            self.bridge.parent = self
            self._children_name_map["bridge"] = "Cisco-IOS-XE-spanning-tree:bridge"

            self.etherchannel = Native.SpanningTree.Etherchannel()
            self.etherchannel.parent = self
            self._children_name_map["etherchannel"] = "Cisco-IOS-XE-spanning-tree:etherchannel"

            self.extend = Native.SpanningTree.Extend()
            self.extend.parent = self
            self._children_name_map["extend"] = "Cisco-IOS-XE-spanning-tree:extend"

            self.loopguard = Native.SpanningTree.Loopguard()
            self.loopguard.parent = self
            self._children_name_map["loopguard"] = "Cisco-IOS-XE-spanning-tree:loopguard"

            self.mst = Native.SpanningTree.Mst()
            self.mst.parent = self
            self._children_name_map["mst"] = "Cisco-IOS-XE-spanning-tree:mst"

            self.optimize = Native.SpanningTree.Optimize()
            self.optimize.parent = self
            self._children_name_map["optimize"] = "Cisco-IOS-XE-spanning-tree:optimize"

            self.pathcost = Native.SpanningTree.Pathcost()
            self.pathcost.parent = self
            self._children_name_map["pathcost"] = "Cisco-IOS-XE-spanning-tree:pathcost"

            self.portfast = Native.SpanningTree.Portfast()
            self.portfast.parent = self
            self._children_name_map["portfast"] = "Cisco-IOS-XE-spanning-tree:portfast"

            self.transmit = Native.SpanningTree.Transmit()
            self.transmit.parent = self
            self._children_name_map["transmit"] = "Cisco-IOS-XE-spanning-tree:transmit"

            self.uplinkfast = None
            self._children_name_map["uplinkfast"] = "Cisco-IOS-XE-spanning-tree:uplinkfast"

            self.vlan = YList(self)
            self._segment_path = lambda: "spanning-tree"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.SpanningTree, ['backbonefast', 'logging', 'mode'], name, value)

        class Mode(Enum):
            """
            Mode (Enum Class)

            Spanning tree operating mode

            .. data:: mst = 0

            .. data:: pvst = 1

            .. data:: rapid_pvst = 2

            """

            mst = Enum.YLeaf(0, "mst")

            pvst = Enum.YLeaf(1, "pvst")

            rapid_pvst = Enum.YLeaf(2, "rapid-pvst")



        class Bridge(Entity):
            """
            
            
            .. attribute:: priority
            
            	
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: id
            
            	
            	**type**\: str
            
            .. attribute:: assurance
            
            	Enable STP Bridge Assurance feature
            	**type**\: bool
            
            	**default value**\: true
            
            

            """

            _prefix = 'ios-stp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.SpanningTree.Bridge, self).__init__()

                self.yang_name = "bridge"
                self.yang_parent_name = "spanning-tree"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                    ('id', (YLeaf(YType.str, 'ID'), ['str'])),
                    ('assurance', (YLeaf(YType.boolean, 'assurance'), ['bool'])),
                ])
                self.priority = None
                self.id = None
                self.assurance = None
                self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:bridge"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SpanningTree.Bridge, ['priority', 'id', 'assurance'], name, value)


        class Etherchannel(Entity):
            """
            Spanning tree etherchannel specific configuration
            
            .. attribute:: guard
            
            	Configure guard features for etherchannel
            	**type**\:  :py:class:`Guard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Etherchannel.Guard>`
            
            

            """

            _prefix = 'ios-stp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.SpanningTree.Etherchannel, self).__init__()

                self.yang_name = "etherchannel"
                self.yang_parent_name = "spanning-tree"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("guard", ("guard", Native.SpanningTree.Etherchannel.Guard))])
                self._leafs = OrderedDict()

                self.guard = Native.SpanningTree.Etherchannel.Guard()
                self.guard.parent = self
                self._children_name_map["guard"] = "guard"
                self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:etherchannel"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SpanningTree.Etherchannel, [], name, value)


            class Guard(Entity):
                """
                Configure guard features for etherchannel
                
                .. attribute:: misconfig
                
                	Enable guard to protect against etherchannel misconfiguration
                	**type**\: bool
                
                	**default value**\: true
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.SpanningTree.Etherchannel.Guard, self).__init__()

                    self.yang_name = "guard"
                    self.yang_parent_name = "etherchannel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('misconfig', (YLeaf(YType.boolean, 'misconfig'), ['bool'])),
                    ])
                    self.misconfig = None
                    self._segment_path = lambda: "guard"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/Cisco-IOS-XE-spanning-tree:etherchannel/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SpanningTree.Etherchannel.Guard, ['misconfig'], name, value)


        class Extend(Entity):
            """
            Spanning Tree 802.1t extensions
            
            .. attribute:: system_id
            
            	Extend system\-id into priority portion of the bridge id (PVST & Rapid PVST only)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-stp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.SpanningTree.Extend, self).__init__()

                self.yang_name = "extend"
                self.yang_parent_name = "spanning-tree"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('system_id', (YLeaf(YType.empty, 'system-id'), ['Empty'])),
                ])
                self.system_id = None
                self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:extend"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SpanningTree.Extend, ['system_id'], name, value)


        class Loopguard(Entity):
            """
            Spanning tree loopguard options
            
            .. attribute:: default
            
            	Enable loopguard by default on all ports
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-stp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.SpanningTree.Loopguard, self).__init__()

                self.yang_name = "loopguard"
                self.yang_parent_name = "spanning-tree"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                ])
                self.default = None
                self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:loopguard"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SpanningTree.Loopguard, ['default'], name, value)


        class Mst(Entity):
            """
            Multiple spanning tree configuration
            
            .. attribute:: instance_range
            
            	
            	**type**\: list of  		 :py:class:`InstanceRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Mst.InstanceRange>`
            
            .. attribute:: configuration
            
            	Enter MST configuration submode
            	**type**\:  :py:class:`Configuration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Mst.Configuration>`
            
            .. attribute:: forward_time
            
            	number of seconds for the forward delay timer
            	**type**\: int
            
            	**range:** 4..30
            
            .. attribute:: hello_time
            
            	number of seconds between generation of config BPDUs
            	**type**\: int
            
            	**range:** 1..10
            
            .. attribute:: max_age
            
            	maximum number of seconds the information in a BPDU is valid
            	**type**\: int
            
            	**range:** 6..40
            
            .. attribute:: max_hops
            
            	maximum number of hops a BPDU is valid
            	**type**\: int
            
            	**range:** 1..255
            
            

            """

            _prefix = 'ios-stp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.SpanningTree.Mst, self).__init__()

                self.yang_name = "mst"
                self.yang_parent_name = "spanning-tree"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("instance-range", ("instance_range", Native.SpanningTree.Mst.InstanceRange)), ("configuration", ("configuration", Native.SpanningTree.Mst.Configuration))])
                self._leafs = OrderedDict([
                    ('forward_time', (YLeaf(YType.uint8, 'forward-time'), ['int'])),
                    ('hello_time', (YLeaf(YType.uint8, 'hello-time'), ['int'])),
                    ('max_age', (YLeaf(YType.uint8, 'max-age'), ['int'])),
                    ('max_hops', (YLeaf(YType.uint8, 'max-hops'), ['int'])),
                ])
                self.forward_time = None
                self.hello_time = None
                self.max_age = None
                self.max_hops = None

                self.configuration = Native.SpanningTree.Mst.Configuration()
                self.configuration.parent = self
                self._children_name_map["configuration"] = "configuration"

                self.instance_range = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:mst"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SpanningTree.Mst, ['forward_time', 'hello_time', 'max_age', 'max_hops'], name, value)


            class InstanceRange(Entity):
                """
                
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..65535
                
                		**type**\: str
                
                .. attribute:: priority
                
                	Set the bridge priority for the spanning tree
                	**type**\: int
                
                	**range:** 0..61440
                
                .. attribute:: root
                
                	Configure switch as root
                	**type**\:  :py:class:`Root <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Mst.InstanceRange.Root>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.SpanningTree.Mst.InstanceRange, self).__init__()

                    self.yang_name = "instance-range"
                    self.yang_parent_name = "mst"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                        ('priority', (YLeaf(YType.uint16, 'priority'), ['int'])),
                        ('root', (YLeaf(YType.enumeration, 'root'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'SpanningTree.Mst.InstanceRange.Root')])),
                    ])
                    self.id = None
                    self.priority = None
                    self.root = None
                    self._segment_path = lambda: "instance-range" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/Cisco-IOS-XE-spanning-tree:mst/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SpanningTree.Mst.InstanceRange, ['id', 'priority', 'root'], name, value)

                class Root(Enum):
                    """
                    Root (Enum Class)

                    Configure switch as root

                    .. data:: primary = 0

                    .. data:: secondary = 1

                    """

                    primary = Enum.YLeaf(0, "primary")

                    secondary = Enum.YLeaf(1, "secondary")



            class Configuration(Entity):
                """
                Enter MST configuration submode
                
                .. attribute:: name
                
                	Set configuration name
                	**type**\: str
                
                .. attribute:: instance
                
                	Map vlans to an MST instance
                	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Mst.Configuration.Instance>`
                
                .. attribute:: private_vlan
                
                	Set private\-vlan synchronization
                	**type**\:  :py:class:`PrivateVlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Mst.Configuration.PrivateVlan>`
                
                .. attribute:: revision
                
                	Set configuration revision number
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.SpanningTree.Mst.Configuration, self).__init__()

                    self.yang_name = "configuration"
                    self.yang_parent_name = "mst"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance", ("instance", Native.SpanningTree.Mst.Configuration.Instance)), ("private-vlan", ("private_vlan", Native.SpanningTree.Mst.Configuration.PrivateVlan))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('revision', (YLeaf(YType.uint16, 'revision'), ['int'])),
                    ])
                    self.name = None
                    self.revision = None

                    self.private_vlan = Native.SpanningTree.Mst.Configuration.PrivateVlan()
                    self.private_vlan.parent = self
                    self._children_name_map["private_vlan"] = "private-vlan"

                    self.instance = YList(self)
                    self._segment_path = lambda: "configuration"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/Cisco-IOS-XE-spanning-tree:mst/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SpanningTree.Mst.Configuration, ['name', 'revision'], name, value)


                class Instance(Entity):
                    """
                    Map vlans to an MST instance
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4094
                    
                    .. attribute:: vlan
                    
                    	Range of vlans to add to the instance mapping
                    	**type**\: union of the below types:
                    
                    		**type**\: list of int
                    
                    			**range:** 0..65535
                    
                    		**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.SpanningTree.Mst.Configuration.Instance, self).__init__()

                        self.yang_name = "instance"
                        self.yang_parent_name = "configuration"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                            ('vlan', (YLeafList(YType.str, 'vlan'), ['int','str'])),
                        ])
                        self.id = None
                        self.vlan = []
                        self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/Cisco-IOS-XE-spanning-tree:mst/configuration/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SpanningTree.Mst.Configuration.Instance, ['id', 'vlan'], name, value)


                class PrivateVlan(Entity):
                    """
                    Set private\-vlan synchronization
                    
                    .. attribute:: synchronize
                    
                    	Synchronize vlans
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.SpanningTree.Mst.Configuration.PrivateVlan, self).__init__()

                        self.yang_name = "private-vlan"
                        self.yang_parent_name = "configuration"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('synchronize', (YLeaf(YType.empty, 'synchronize'), ['Empty'])),
                        ])
                        self.synchronize = None
                        self._segment_path = lambda: "private-vlan"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/Cisco-IOS-XE-spanning-tree:mst/configuration/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SpanningTree.Mst.Configuration.PrivateVlan, ['synchronize'], name, value)


        class Optimize(Entity):
            """
            
            
            .. attribute:: bpdu
            
            	
            	**type**\:  :py:class:`Bpdu <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Optimize.Bpdu>`
            
            

            """

            _prefix = 'ios-stp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.SpanningTree.Optimize, self).__init__()

                self.yang_name = "optimize"
                self.yang_parent_name = "spanning-tree"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("bpdu", ("bpdu", Native.SpanningTree.Optimize.Bpdu))])
                self._leafs = OrderedDict()

                self.bpdu = Native.SpanningTree.Optimize.Bpdu()
                self.bpdu.parent = self
                self._children_name_map["bpdu"] = "bpdu"
                self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:optimize"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SpanningTree.Optimize, [], name, value)


            class Bpdu(Entity):
                """
                
                
                .. attribute:: transmission
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.SpanningTree.Optimize.Bpdu, self).__init__()

                    self.yang_name = "bpdu"
                    self.yang_parent_name = "optimize"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('transmission', (YLeaf(YType.boolean, 'transmission'), ['bool'])),
                    ])
                    self.transmission = None
                    self._segment_path = lambda: "bpdu"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/Cisco-IOS-XE-spanning-tree:optimize/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SpanningTree.Optimize.Bpdu, ['transmission'], name, value)


        class Pathcost(Entity):
            """
            Spanning tree pathcost options
            
            .. attribute:: method
            
            	Method to calculate default port path cost
            	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Pathcost.Method>`
            
            

            """

            _prefix = 'ios-stp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.SpanningTree.Pathcost, self).__init__()

                self.yang_name = "pathcost"
                self.yang_parent_name = "spanning-tree"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("method", ("method", Native.SpanningTree.Pathcost.Method))])
                self._leafs = OrderedDict()

                self.method = Native.SpanningTree.Pathcost.Method()
                self.method.parent = self
                self._children_name_map["method"] = "method"
                self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:pathcost"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SpanningTree.Pathcost, [], name, value)


            class Method(Entity):
                """
                Method to calculate default port path cost
                
                .. attribute:: long
                
                	Use 32 bit based values for default port path costs
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: short
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.SpanningTree.Pathcost.Method, self).__init__()

                    self.yang_name = "method"
                    self.yang_parent_name = "pathcost"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                        ('short', (YLeaf(YType.empty, 'short'), ['Empty'])),
                    ])
                    self.long = None
                    self.short = None
                    self._segment_path = lambda: "method"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/Cisco-IOS-XE-spanning-tree:pathcost/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SpanningTree.Pathcost.Method, ['long', 'short'], name, value)


        class Portfast(Entity):
            """
            Spanning tree portfast options
            
            .. attribute:: bpdufilter
            
            	Enable portfast edge bpdu filter on this switch
            	**type**\:  :py:class:`Bpdufilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Portfast.Bpdufilter>`
            
            .. attribute:: bpduguard
            
            	Enable portfast edge bpdu guard on this switch
            	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Portfast.Bpduguard>`
            
            .. attribute:: default
            
            	Enable portfast by default on all access ports
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-stp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.SpanningTree.Portfast, self).__init__()

                self.yang_name = "portfast"
                self.yang_parent_name = "spanning-tree"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("bpdufilter", ("bpdufilter", Native.SpanningTree.Portfast.Bpdufilter)), ("bpduguard", ("bpduguard", Native.SpanningTree.Portfast.Bpduguard))])
                self._leafs = OrderedDict([
                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                ])
                self.default = None

                self.bpdufilter = Native.SpanningTree.Portfast.Bpdufilter()
                self.bpdufilter.parent = self
                self._children_name_map["bpdufilter"] = "bpdufilter"

                self.bpduguard = Native.SpanningTree.Portfast.Bpduguard()
                self.bpduguard.parent = self
                self._children_name_map["bpduguard"] = "bpduguard"
                self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:portfast"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SpanningTree.Portfast, ['default'], name, value)


            class Bpdufilter(Entity):
                """
                Enable portfast edge bpdu filter on this switch
                
                .. attribute:: default
                
                	Enable bpdu filter by default on all portfast edge ports
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.SpanningTree.Portfast.Bpdufilter, self).__init__()

                    self.yang_name = "bpdufilter"
                    self.yang_parent_name = "portfast"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                    ])
                    self.default = None
                    self._segment_path = lambda: "bpdufilter"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/Cisco-IOS-XE-spanning-tree:portfast/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SpanningTree.Portfast.Bpdufilter, ['default'], name, value)


            class Bpduguard(Entity):
                """
                Enable portfast edge bpdu guard on this switch
                
                .. attribute:: default
                
                	Enable bpdu guard by default on all portfast edge ports
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.SpanningTree.Portfast.Bpduguard, self).__init__()

                    self.yang_name = "bpduguard"
                    self.yang_parent_name = "portfast"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                    ])
                    self.default = None
                    self._segment_path = lambda: "bpduguard"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/Cisco-IOS-XE-spanning-tree:portfast/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SpanningTree.Portfast.Bpduguard, ['default'], name, value)


        class Transmit(Entity):
            """
            STP transmit parameters
            
            .. attribute:: hold_count
            
            	Value for txholdcount parameter
            	**type**\: int
            
            	**range:** 1..20
            
            

            """

            _prefix = 'ios-stp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.SpanningTree.Transmit, self).__init__()

                self.yang_name = "transmit"
                self.yang_parent_name = "spanning-tree"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('hold_count', (YLeaf(YType.uint8, 'hold-count'), ['int'])),
                ])
                self.hold_count = None
                self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:transmit"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SpanningTree.Transmit, ['hold_count'], name, value)


        class Uplinkfast(Entity):
            """
            Enable UplinkFast Feature
            
            .. attribute:: max_update_rate
            
            	Rate at which station address updates are sent
            	**type**\: int
            
            	**range:** 0..32000
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-stp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.SpanningTree.Uplinkfast, self).__init__()

                self.yang_name = "uplinkfast"
                self.yang_parent_name = "spanning-tree"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('max_update_rate', (YLeaf(YType.uint32, 'max-update-rate'), ['int'])),
                ])
                self.max_update_rate = None
                self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:uplinkfast"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SpanningTree.Uplinkfast, ['max_update_rate'], name, value)


        class Vlan(Entity):
            """
            VLAN Switch Spanning Tree
            
            .. attribute:: id  (key)
            
            	
            	**type**\: str
            
            .. attribute:: max_age
            
            	Set the max age interval for the spanning tree
            	**type**\: int
            
            	**range:** 6..40
            
            .. attribute:: forward_time
            
            	Set the forward delay for the spanning tree
            	**type**\: int
            
            	**range:** 4..30
            
            .. attribute:: hello_time
            
            	Set the hello interval for the spanning tree
            	**type**\: int
            
            	**range:** 1..10
            
            .. attribute:: priority
            
            	Set the bridge priority for the spanning tree
            	**type**\: int
            
            	**range:** 0..61440
            
            .. attribute:: root
            
            	Configure switch as root
            	**type**\:  :py:class:`Root <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Vlan.Root>`
            
            

            """

            _prefix = 'ios-stp'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.SpanningTree.Vlan, self).__init__()

                self.yang_name = "vlan"
                self.yang_parent_name = "spanning-tree"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("root", ("root", Native.SpanningTree.Vlan.Root))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                    ('max_age', (YLeaf(YType.uint8, 'max-age'), ['int'])),
                    ('forward_time', (YLeaf(YType.uint8, 'forward-time'), ['int'])),
                    ('hello_time', (YLeaf(YType.uint8, 'hello-time'), ['int'])),
                    ('priority', (YLeaf(YType.uint16, 'priority'), ['int'])),
                ])
                self.id = None
                self.max_age = None
                self.forward_time = None
                self.hello_time = None
                self.priority = None

                self.root = Native.SpanningTree.Vlan.Root()
                self.root.parent = self
                self._children_name_map["root"] = "root"
                self._segment_path = lambda: "Cisco-IOS-XE-spanning-tree:vlan" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/spanning-tree/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SpanningTree.Vlan, ['id', 'max_age', 'forward_time', 'hello_time', 'priority'], name, value)


            class Root(Entity):
                """
                Configure switch as root
                
                .. attribute:: primary
                
                	Configure this switch as primary root for this spanning tree
                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Vlan.Root.Primary>`
                
                .. attribute:: secondary
                
                	Configure switch as secondary root
                	**type**\:  :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SpanningTree.Vlan.Root.Secondary>`
                
                

                """

                _prefix = 'ios-stp'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.SpanningTree.Vlan.Root, self).__init__()

                    self.yang_name = "root"
                    self.yang_parent_name = "vlan"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("primary", ("primary", Native.SpanningTree.Vlan.Root.Primary)), ("secondary", ("secondary", Native.SpanningTree.Vlan.Root.Secondary))])
                    self._leafs = OrderedDict()

                    self.primary = Native.SpanningTree.Vlan.Root.Primary()
                    self.primary.parent = self
                    self._children_name_map["primary"] = "primary"

                    self.secondary = Native.SpanningTree.Vlan.Root.Secondary()
                    self.secondary.parent = self
                    self._children_name_map["secondary"] = "secondary"
                    self._segment_path = lambda: "root"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SpanningTree.Vlan.Root, [], name, value)


                class Primary(Entity):
                    """
                    Configure this switch as primary root for this spanning tree
                    
                    .. attribute:: diameter
                    
                    	Network diameter of this spanning tree
                    	**type**\: int
                    
                    	**range:** 2..7
                    
                    .. attribute:: hello_time
                    
                    	Hello interval for this spanning tree
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.SpanningTree.Vlan.Root.Primary, self).__init__()

                        self.yang_name = "primary"
                        self.yang_parent_name = "root"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('diameter', (YLeaf(YType.uint8, 'diameter'), ['int'])),
                            ('hello_time', (YLeaf(YType.uint8, 'hello-time'), ['int'])),
                        ])
                        self.diameter = None
                        self.hello_time = None
                        self._segment_path = lambda: "primary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SpanningTree.Vlan.Root.Primary, ['diameter', 'hello_time'], name, value)


                class Secondary(Entity):
                    """
                    Configure switch as secondary root
                    
                    .. attribute:: diameter
                    
                    	Network diameter of this spanning tree
                    	**type**\: int
                    
                    	**range:** 2..7
                    
                    .. attribute:: hello_time
                    
                    	Hello interval for this spanning tree
                    	**type**\: int
                    
                    	**range:** 1..10
                    
                    

                    """

                    _prefix = 'ios-stp'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.SpanningTree.Vlan.Root.Secondary, self).__init__()

                        self.yang_name = "secondary"
                        self.yang_parent_name = "root"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('diameter', (YLeaf(YType.uint8, 'diameter'), ['int'])),
                            ('hello_time', (YLeaf(YType.uint8, 'hello-time'), ['int'])),
                        ])
                        self.diameter = None
                        self.hello_time = None
                        self._segment_path = lambda: "secondary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SpanningTree.Vlan.Root.Secondary, ['diameter', 'hello_time'], name, value)


    class Subscriber(Entity):
        """
        Subscriber configuration
        
        .. attribute:: templating
        
        	Configure subscriber templating
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Subscriber, self).__init__()

            self.yang_name = "subscriber"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('templating', (YLeaf(YType.empty, 'templating'), ['Empty'])),
            ])
            self.templating = None
            self._segment_path = lambda: "subscriber"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Subscriber, [u'templating'], name, value)


    class Track(Entity):
        """
        Object tracking configuration commands
        
        .. attribute:: tracked_object
        
        	
        	**type**\: list of  		 :py:class:`TrackedObject <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject>`
        
        .. attribute:: resolution
        
        	Tracking resolution parameters
        	**type**\:  :py:class:`Resolution <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Resolution>`
        
        .. attribute:: timer
        
        	Polling interval timers
        	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Timer>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Track, self).__init__()

            self.yang_name = "track"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-track:tracked-object", ("tracked_object", Native.Track.TrackedObject)), ("Cisco-IOS-XE-track:resolution", ("resolution", Native.Track.Resolution)), ("Cisco-IOS-XE-track:timer", ("timer", Native.Track.Timer))])
            self._leafs = OrderedDict()

            self.resolution = Native.Track.Resolution()
            self.resolution.parent = self
            self._children_name_map["resolution"] = "Cisco-IOS-XE-track:resolution"

            self.timer = Native.Track.Timer()
            self.timer.parent = self
            self._children_name_map["timer"] = "Cisco-IOS-XE-track:timer"

            self.tracked_object = YList(self)
            self._segment_path = lambda: "track"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Track, [], name, value)


        class TrackedObject(Entity):
            """
            
            
            .. attribute:: object_number  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..1000
            
            .. attribute:: interface
            
            	Select an interface to track
            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Interface>`
            
            .. attribute:: ip
            
            	IP protocol
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 protocol
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Ipv6>`
            
            .. attribute:: list
            
            	Group objects in a list
            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.List>`
            
            .. attribute:: stub_object
            
            	Stub tracking object
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: default
            
            	Set a command to its defaults
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Default>`
            
            .. attribute:: delay
            
            	Tracking delay
            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Delay>`
            
            .. attribute:: default_state
            
            	default object state
            	**type**\:  :py:class:`DefaultState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.DefaultState>`
            
            .. attribute:: object
            
            	Add a tracked object to list
            	**type**\: list of  		 :py:class:`Object <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Object>`
            
            .. attribute:: ipv6_object
            
            	Tracking IPv6 object configuration
            	**type**\:  :py:class:`Ipv6Object <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Ipv6Object>`
            
            .. attribute:: ip_object
            
            	Tracking IP object configuration
            	**type**\:  :py:class:`IpObject <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.IpObject>`
            
            

            """

            _prefix = 'ios-track'
            _revision = '2017-04-28'

            def __init__(self):
                super(Native.Track.TrackedObject, self).__init__()

                self.yang_name = "tracked-object"
                self.yang_parent_name = "track"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['object_number']
                self._child_classes = OrderedDict([("interface", ("interface", Native.Track.TrackedObject.Interface)), ("ip", ("ip", Native.Track.TrackedObject.Ip)), ("ipv6", ("ipv6", Native.Track.TrackedObject.Ipv6)), ("list", ("list", Native.Track.TrackedObject.List)), ("default", ("default", Native.Track.TrackedObject.Default)), ("delay", ("delay", Native.Track.TrackedObject.Delay)), ("object", ("object", Native.Track.TrackedObject.Object)), ("ipv6-object", ("ipv6_object", Native.Track.TrackedObject.Ipv6Object)), ("ip-object", ("ip_object", Native.Track.TrackedObject.IpObject))])
                self._leafs = OrderedDict([
                    ('object_number', (YLeaf(YType.uint32, 'object-number'), ['int'])),
                    ('stub_object', (YLeaf(YType.empty, 'stub-object'), ['Empty'])),
                    ('default_state', (YLeaf(YType.enumeration, 'default-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Track.TrackedObject.DefaultState')])),
                ])
                self.object_number = None
                self.stub_object = None
                self.default_state = None

                self.interface = Native.Track.TrackedObject.Interface()
                self.interface.parent = self
                self._children_name_map["interface"] = "interface"

                self.ip = Native.Track.TrackedObject.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Track.TrackedObject.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.list = Native.Track.TrackedObject.List()
                self.list.parent = self
                self._children_name_map["list"] = "list"

                self.default = Native.Track.TrackedObject.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.delay = Native.Track.TrackedObject.Delay()
                self.delay.parent = self
                self._children_name_map["delay"] = "delay"

                self.ipv6_object = Native.Track.TrackedObject.Ipv6Object()
                self.ipv6_object.parent = self
                self._children_name_map["ipv6_object"] = "ipv6-object"

                self.ip_object = Native.Track.TrackedObject.IpObject()
                self.ip_object.parent = self
                self._children_name_map["ip_object"] = "ip-object"

                self.object = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-track:tracked-object" + "[object-number='" + str(self.object_number) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Track.TrackedObject, ['object_number', 'stub_object', 'default_state'], name, value)

            class DefaultState(Enum):
                """
                DefaultState (Enum Class)

                default object state

                .. data:: down = 0

                .. data:: up = 1

                """

                down = Enum.YLeaf(0, "down")

                up = Enum.YLeaf(1, "up")



            class Interface(Entity):
                """
                Select an interface to track
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: protocol
                
                	
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Interface.Protocol>`
                
                .. attribute:: routing
                
                	Track interface IPv6 routing capability
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.TrackedObject.Interface, self).__init__()

                    self.yang_name = "interface"
                    self.yang_parent_name = "tracked-object"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Track.TrackedObject.Interface.Protocol')])),
                        ('routing', (YLeaf(YType.empty, 'routing'), ['Empty'])),
                    ])
                    self.name = None
                    self.protocol = None
                    self.routing = None
                    self._segment_path = lambda: "interface"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.TrackedObject.Interface, ['name', 'protocol', 'routing'], name, value)

                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    .. data:: ip = 0

                    .. data:: ipv6 = 1

                    .. data:: line_protocol = 2

                    """

                    ip = Enum.YLeaf(0, "ip")

                    ipv6 = Enum.YLeaf(1, "ipv6")

                    line_protocol = Enum.YLeaf(2, "line-protocol")



            class Ip(Entity):
                """
                IP protocol
                
                .. attribute:: route
                
                	
                	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Ip.Route>`
                
                .. attribute:: sla
                
                	IP Service Level Agreement
                	**type**\:  :py:class:`Sla <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Ip.Sla>`
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.TrackedObject.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "tracked-object"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("route", ("route", Native.Track.TrackedObject.Ip.Route)), ("sla", ("sla", Native.Track.TrackedObject.Ip.Sla))])
                    self._leafs = OrderedDict()

                    self.route = Native.Track.TrackedObject.Ip.Route()
                    self.route.parent = self
                    self._children_name_map["route"] = "route"

                    self.sla = Native.Track.TrackedObject.Ip.Sla()
                    self.sla.parent = self
                    self._children_name_map["sla"] = "sla"
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.TrackedObject.Ip, [], name, value)


                class Route(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mask
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: reachability
                    
                    	Route reachability state
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: metric
                    
                    	Route metric
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Ip.Route.Metric>`
                    
                    

                    """

                    _prefix = 'ios-track'
                    _revision = '2017-04-28'

                    def __init__(self):
                        super(Native.Track.TrackedObject.Ip.Route, self).__init__()

                        self.yang_name = "route"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ('reachability', (YLeaf(YType.empty, 'reachability'), ['Empty'])),
                            ('metric', (YLeaf(YType.enumeration, 'metric'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Track.TrackedObject.Ip.Route.Metric')])),
                        ])
                        self.address = None
                        self.mask = None
                        self.reachability = None
                        self.metric = None
                        self._segment_path = lambda: "route"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Track.TrackedObject.Ip.Route, ['address', 'mask', 'reachability', 'metric'], name, value)

                    class Metric(Enum):
                        """
                        Metric (Enum Class)

                        Route metric

                        .. data:: threshold = 0

                        """

                        threshold = Enum.YLeaf(0, "threshold")



                class Sla(Entity):
                    """
                    IP Service Level Agreement
                    
                    .. attribute:: number
                    
                    	Entry number
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reachability
                    
                    	Reachability
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: state
                    
                    	Return code state
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-track'
                    _revision = '2017-04-28'

                    def __init__(self):
                        super(Native.Track.TrackedObject.Ip.Sla, self).__init__()

                        self.yang_name = "sla"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                            ('reachability', (YLeaf(YType.empty, 'reachability'), ['Empty'])),
                            ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                        ])
                        self.number = None
                        self.reachability = None
                        self.state = None
                        self._segment_path = lambda: "sla"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Track.TrackedObject.Ip.Sla, ['number', 'reachability', 'state'], name, value)


            class Ipv6(Entity):
                """
                IPv6 protocol
                
                .. attribute:: route
                
                	IPv6 route
                	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Ipv6.Route>`
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.TrackedObject.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "tracked-object"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("route", ("route", Native.Track.TrackedObject.Ipv6.Route))])
                    self._leafs = OrderedDict()

                    self.route = Native.Track.TrackedObject.Ipv6.Route()
                    self.route.parent = self
                    self._children_name_map["route"] = "route"
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.TrackedObject.Ipv6, [], name, value)


                class Route(Entity):
                    """
                    IPv6 route
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    .. attribute:: reachability
                    
                    	Route reachability state
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: metric
                    
                    	Route metric
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Ipv6.Route.Metric>`
                    
                    

                    """

                    _prefix = 'ios-track'
                    _revision = '2017-04-28'

                    def __init__(self):
                        super(Native.Track.TrackedObject.Ipv6.Route, self).__init__()

                        self.yang_name = "route"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('reachability', (YLeaf(YType.empty, 'reachability'), ['Empty'])),
                            ('metric', (YLeaf(YType.enumeration, 'metric'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Track.TrackedObject.Ipv6.Route.Metric')])),
                        ])
                        self.address = None
                        self.reachability = None
                        self.metric = None
                        self._segment_path = lambda: "route"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Track.TrackedObject.Ipv6.Route, ['address', 'reachability', 'metric'], name, value)

                    class Metric(Enum):
                        """
                        Metric (Enum Class)

                        Route metric

                        .. data:: threshold = 0

                        """

                        threshold = Enum.YLeaf(0, "threshold")



            class List(Entity):
                """
                Group objects in a list
                
                .. attribute:: boolean
                
                	List state based on a boolean calculation on objects
                	**type**\:  :py:class:`Boolean <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.List.Boolean>`
                
                .. attribute:: threshold
                
                	List state based on a threshold of UP and DOWN objects
                	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.List.Threshold>`
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.TrackedObject.List, self).__init__()

                    self.yang_name = "list"
                    self.yang_parent_name = "tracked-object"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('boolean', (YLeaf(YType.enumeration, 'boolean'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Track.TrackedObject.List.Boolean')])),
                        ('threshold', (YLeaf(YType.enumeration, 'threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Track.TrackedObject.List.Threshold')])),
                    ])
                    self.boolean = None
                    self.threshold = None
                    self._segment_path = lambda: "list"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.TrackedObject.List, ['boolean', 'threshold'], name, value)

                class Boolean(Enum):
                    """
                    Boolean (Enum Class)

                    List state based on a boolean calculation on objects

                    .. data:: and_ = 0

                    .. data:: or_ = 1

                    """

                    and_ = Enum.YLeaf(0, "and")

                    or_ = Enum.YLeaf(1, "or")


                class Threshold(Enum):
                    """
                    Threshold (Enum Class)

                    List state based on a threshold of UP and DOWN objects

                    .. data:: percentage = 0

                    .. data:: weight = 1

                    """

                    percentage = Enum.YLeaf(0, "percentage")

                    weight = Enum.YLeaf(1, "weight")



            class Default(Entity):
                """
                Set a command to its defaults
                
                .. attribute:: delay
                
                	Tracking delay
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Default.Delay>`
                
                	**presence node**\: True
                
                .. attribute:: default_state
                
                	default object state
                	**type**\:  :py:class:`DefaultState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Default.DefaultState>`
                
                .. attribute:: ip
                
                	Tracking IP object configuration
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Default.Ip>`
                
                .. attribute:: ipv6
                
                	Tracking IPv6 object configuration
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.TrackedObject.Default.Ipv6>`
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.TrackedObject.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "tracked-object"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("delay", ("delay", Native.Track.TrackedObject.Default.Delay)), ("ip", ("ip", Native.Track.TrackedObject.Default.Ip)), ("ipv6", ("ipv6", Native.Track.TrackedObject.Default.Ipv6))])
                    self._leafs = OrderedDict([
                        ('default_state', (YLeaf(YType.enumeration, 'default-state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Track.TrackedObject.Default.DefaultState')])),
                    ])
                    self.default_state = None

                    self.delay = None
                    self._children_name_map["delay"] = "delay"

                    self.ip = Native.Track.TrackedObject.Default.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.ipv6 = Native.Track.TrackedObject.Default.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._segment_path = lambda: "default"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.TrackedObject.Default, ['default_state'], name, value)

                class DefaultState(Enum):
                    """
                    DefaultState (Enum Class)

                    default object state

                    .. data:: down = 0

                    .. data:: up = 1

                    """

                    down = Enum.YLeaf(0, "down")

                    up = Enum.YLeaf(1, "up")



                class Delay(Entity):
                    """
                    Tracking delay
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-track'
                    _revision = '2017-04-28'

                    def __init__(self):
                        super(Native.Track.TrackedObject.Default.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True


                class Ip(Entity):
                    """
                    Tracking IP object configuration
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding table
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-track'
                    _revision = '2017-04-28'

                    def __init__(self):
                        super(Native.Track.TrackedObject.Default.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vrf', (YLeaf(YType.empty, 'vrf'), ['Empty'])),
                        ])
                        self.vrf = None
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Track.TrackedObject.Default.Ip, ['vrf'], name, value)


                class Ipv6(Entity):
                    """
                    Tracking IPv6 object configuration
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding table
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-track'
                    _revision = '2017-04-28'

                    def __init__(self):
                        super(Native.Track.TrackedObject.Default.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vrf', (YLeaf(YType.empty, 'vrf'), ['Empty'])),
                        ])
                        self.vrf = None
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Track.TrackedObject.Default.Ipv6, ['vrf'], name, value)


            class Delay(Entity):
                """
                Tracking delay
                
                .. attribute:: down
                
                	Delay down change notification
                	**type**\: int
                
                	**range:** 0..180
                
                .. attribute:: up
                
                	Delay up change notification
                	**type**\: int
                
                	**range:** 0..180
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.TrackedObject.Delay, self).__init__()

                    self.yang_name = "delay"
                    self.yang_parent_name = "tracked-object"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('down', (YLeaf(YType.uint32, 'down'), ['int'])),
                        ('up', (YLeaf(YType.uint32, 'up'), ['int'])),
                    ])
                    self.down = None
                    self.up = None
                    self._segment_path = lambda: "delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.TrackedObject.Delay, ['down', 'up'], name, value)


            class Object(Entity):
                """
                Add a tracked object to list
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 1..1000
                
                .. attribute:: not_
                
                	Negate the state of object
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.TrackedObject.Object, self).__init__()

                    self.yang_name = "object"
                    self.yang_parent_name = "tracked-object"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                        ('not_', (YLeaf(YType.empty, 'not'), ['Empty'])),
                    ])
                    self.number = None
                    self.not_ = None
                    self._segment_path = lambda: "object" + "[number='" + str(self.number) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.TrackedObject.Object, ['number', 'not_'], name, value)


            class Ipv6Object(Entity):
                """
                Tracking IPv6 object configuration
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding table name
                	**type**\: str
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.TrackedObject.Ipv6Object, self).__init__()

                    self.yang_name = "ipv6-object"
                    self.yang_parent_name = "tracked-object"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ])
                    self.vrf = None
                    self._segment_path = lambda: "ipv6-object"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.TrackedObject.Ipv6Object, ['vrf'], name, value)


            class IpObject(Entity):
                """
                Tracking IP object configuration
                
                .. attribute:: vrf
                
                	VPN Routing/Forwarding table name
                	**type**\: str
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.TrackedObject.IpObject, self).__init__()

                    self.yang_name = "ip-object"
                    self.yang_parent_name = "tracked-object"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ])
                    self.vrf = None
                    self._segment_path = lambda: "ip-object"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.TrackedObject.IpObject, ['vrf'], name, value)


        class Resolution(Entity):
            """
            Tracking resolution parameters
            
            .. attribute:: ip
            
            	IP protocol
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Resolution.Ip>`
            
            

            """

            _prefix = 'ios-track'
            _revision = '2017-04-28'

            def __init__(self):
                super(Native.Track.Resolution, self).__init__()

                self.yang_name = "resolution"
                self.yang_parent_name = "track"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ip", ("ip", Native.Track.Resolution.Ip))])
                self._leafs = OrderedDict()

                self.ip = Native.Track.Resolution.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-track:resolution"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Track.Resolution, [], name, value)


            class Ip(Entity):
                """
                IP protocol
                
                .. attribute:: route
                
                	Route metric resolution
                	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Resolution.Ip.Route>`
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.Resolution.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "resolution"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("route", ("route", Native.Track.Resolution.Ip.Route))])
                    self._leafs = OrderedDict()

                    self.route = Native.Track.Resolution.Ip.Route()
                    self.route.parent = self
                    self._children_name_map["route"] = "route"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/Cisco-IOS-XE-track:resolution/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.Resolution.Ip, [], name, value)


                class Route(Entity):
                    """
                    Route metric resolution
                    
                    .. attribute:: bgp
                    
                    	BGP route metric resolution
                    	**type**\: int
                    
                    	**range:** 256..40000000
                    
                    .. attribute:: eigrp
                    
                    	EIGRP route metric resolution
                    	**type**\: int
                    
                    	**range:** 256..40000000
                    
                    .. attribute:: isis
                    
                    	ISIS route metric resolution
                    	**type**\: int
                    
                    	**range:** 1..1000
                    
                    .. attribute:: ospf
                    
                    	OSPF route metric resolution
                    	**type**\: int
                    
                    	**range:** 1..1562
                    
                    .. attribute:: static
                    
                    	Static route metric resolution
                    	**type**\: int
                    
                    	**range:** 1..100000
                    
                    

                    """

                    _prefix = 'ios-track'
                    _revision = '2017-04-28'

                    def __init__(self):
                        super(Native.Track.Resolution.Ip.Route, self).__init__()

                        self.yang_name = "route"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('bgp', (YLeaf(YType.uint32, 'bgp'), ['int'])),
                            ('eigrp', (YLeaf(YType.uint32, 'eigrp'), ['int'])),
                            ('isis', (YLeaf(YType.uint32, 'isis'), ['int'])),
                            ('ospf', (YLeaf(YType.uint32, 'ospf'), ['int'])),
                            ('static', (YLeaf(YType.uint32, 'static'), ['int'])),
                        ])
                        self.bgp = None
                        self.eigrp = None
                        self.isis = None
                        self.ospf = None
                        self.static = None
                        self._segment_path = lambda: "route"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/Cisco-IOS-XE-track:resolution/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Track.Resolution.Ip.Route, ['bgp', 'eigrp', 'isis', 'ospf', 'static'], name, value)


        class Timer(Entity):
            """
            Polling interval timers
            
            .. attribute:: interface
            
            	Interface polling timer
            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Timer.Interface>`
            
            .. attribute:: ip
            
            	IP protocol
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Timer.Ip>`
            
            .. attribute:: ipv6
            
            	IPv6 protocol
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Timer.Ipv6>`
            
            .. attribute:: list
            
            	Boolean list polling timer
            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Timer.List>`
            
            .. attribute:: stub_object
            
            	EEM stub polling timer
            	**type**\:  :py:class:`StubObject <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Timer.StubObject>`
            
            

            """

            _prefix = 'ios-track'
            _revision = '2017-04-28'

            def __init__(self):
                super(Native.Track.Timer, self).__init__()

                self.yang_name = "timer"
                self.yang_parent_name = "track"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("interface", ("interface", Native.Track.Timer.Interface)), ("ip", ("ip", Native.Track.Timer.Ip)), ("ipv6", ("ipv6", Native.Track.Timer.Ipv6)), ("list", ("list", Native.Track.Timer.List)), ("stub-object", ("stub_object", Native.Track.Timer.StubObject))])
                self._leafs = OrderedDict()

                self.interface = Native.Track.Timer.Interface()
                self.interface.parent = self
                self._children_name_map["interface"] = "interface"

                self.ip = Native.Track.Timer.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Track.Timer.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.list = Native.Track.Timer.List()
                self.list.parent = self
                self._children_name_map["list"] = "list"

                self.stub_object = Native.Track.Timer.StubObject()
                self.stub_object.parent = self
                self._children_name_map["stub_object"] = "stub-object"
                self._segment_path = lambda: "Cisco-IOS-XE-track:timer"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Track.Timer, [], name, value)


            class Interface(Entity):
                """
                Interface polling timer
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 1..3000
                
                .. attribute:: ms
                
                	Specify polling interval in milliseconds
                	**type**\: int
                
                	**range:** 500..5000
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.Timer.Interface, self).__init__()

                    self.yang_name = "interface"
                    self.yang_parent_name = "timer"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                        ('ms', (YLeaf(YType.uint32, 'ms'), ['int'])),
                    ])
                    self.seconds = None
                    self.ms = None
                    self._segment_path = lambda: "interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/Cisco-IOS-XE-track:timer/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.Timer.Interface, ['seconds', 'ms'], name, value)


            class Ip(Entity):
                """
                IP protocol
                
                .. attribute:: route
                
                	IP route polling timer
                	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Timer.Ip.Route>`
                
                .. attribute:: sla
                
                	IP SLA polling timer
                	**type**\:  :py:class:`Sla <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Timer.Ip.Sla>`
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.Timer.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "timer"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("route", ("route", Native.Track.Timer.Ip.Route)), ("sla", ("sla", Native.Track.Timer.Ip.Sla))])
                    self._leafs = OrderedDict()

                    self.route = Native.Track.Timer.Ip.Route()
                    self.route.parent = self
                    self._children_name_map["route"] = "route"

                    self.sla = Native.Track.Timer.Ip.Sla()
                    self.sla.parent = self
                    self._children_name_map["sla"] = "sla"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/Cisco-IOS-XE-track:timer/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.Timer.Ip, [], name, value)


                class Route(Entity):
                    """
                    IP route polling timer
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3000
                    
                    .. attribute:: ms
                    
                    	Specify polling interval in milliseconds
                    	**type**\: int
                    
                    	**range:** 500..5000
                    
                    

                    """

                    _prefix = 'ios-track'
                    _revision = '2017-04-28'

                    def __init__(self):
                        super(Native.Track.Timer.Ip.Route, self).__init__()

                        self.yang_name = "route"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                            ('ms', (YLeaf(YType.uint32, 'ms'), ['int'])),
                        ])
                        self.seconds = None
                        self.ms = None
                        self._segment_path = lambda: "route"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/Cisco-IOS-XE-track:timer/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Track.Timer.Ip.Route, ['seconds', 'ms'], name, value)


                class Sla(Entity):
                    """
                    IP SLA polling timer
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3000
                    
                    .. attribute:: ms
                    
                    	Specify polling interval in milliseconds
                    	**type**\: int
                    
                    	**range:** 500..5000
                    
                    

                    """

                    _prefix = 'ios-track'
                    _revision = '2017-04-28'

                    def __init__(self):
                        super(Native.Track.Timer.Ip.Sla, self).__init__()

                        self.yang_name = "sla"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                            ('ms', (YLeaf(YType.uint32, 'ms'), ['int'])),
                        ])
                        self.seconds = None
                        self.ms = None
                        self._segment_path = lambda: "sla"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/Cisco-IOS-XE-track:timer/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Track.Timer.Ip.Sla, ['seconds', 'ms'], name, value)


            class Ipv6(Entity):
                """
                IPv6 protocol
                
                .. attribute:: route
                
                	IPv6 route polling timer
                	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Track.Timer.Ipv6.Route>`
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.Timer.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "timer"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("route", ("route", Native.Track.Timer.Ipv6.Route))])
                    self._leafs = OrderedDict()

                    self.route = Native.Track.Timer.Ipv6.Route()
                    self.route.parent = self
                    self._children_name_map["route"] = "route"
                    self._segment_path = lambda: "ipv6"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/Cisco-IOS-XE-track:timer/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.Timer.Ipv6, [], name, value)


                class Route(Entity):
                    """
                    IPv6 route polling timer
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..3000
                    
                    .. attribute:: ms
                    
                    	Specify polling interval in milliseconds
                    	**type**\: int
                    
                    	**range:** 500..5000
                    
                    

                    """

                    _prefix = 'ios-track'
                    _revision = '2017-04-28'

                    def __init__(self):
                        super(Native.Track.Timer.Ipv6.Route, self).__init__()

                        self.yang_name = "route"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                            ('ms', (YLeaf(YType.uint32, 'ms'), ['int'])),
                        ])
                        self.seconds = None
                        self.ms = None
                        self._segment_path = lambda: "route"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/Cisco-IOS-XE-track:timer/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Track.Timer.Ipv6.Route, ['seconds', 'ms'], name, value)


            class List(Entity):
                """
                Boolean list polling timer
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 1..3000
                
                .. attribute:: ms
                
                	Specify polling interval in milliseconds
                	**type**\: int
                
                	**range:** 500..5000
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.Timer.List, self).__init__()

                    self.yang_name = "list"
                    self.yang_parent_name = "timer"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                        ('ms', (YLeaf(YType.uint32, 'ms'), ['int'])),
                    ])
                    self.seconds = None
                    self.ms = None
                    self._segment_path = lambda: "list"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/Cisco-IOS-XE-track:timer/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.Timer.List, ['seconds', 'ms'], name, value)


            class StubObject(Entity):
                """
                EEM stub polling timer
                
                .. attribute:: seconds
                
                	
                	**type**\: int
                
                	**range:** 1..3000
                
                .. attribute:: ms
                
                	Specify polling interval in milliseconds
                	**type**\: int
                
                	**range:** 500..5000
                
                

                """

                _prefix = 'ios-track'
                _revision = '2017-04-28'

                def __init__(self):
                    super(Native.Track.Timer.StubObject, self).__init__()

                    self.yang_name = "stub-object"
                    self.yang_parent_name = "timer"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                        ('ms', (YLeaf(YType.uint32, 'ms'), ['int'])),
                    ])
                    self.seconds = None
                    self.ms = None
                    self._segment_path = lambda: "stub-object"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/track/Cisco-IOS-XE-track:timer/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Track.Timer.StubObject, ['seconds', 'ms'], name, value)


    class Dot1x(Entity):
        """
        IEEE 802.1X Global Configuration Commands
        
        .. attribute:: credentials
        
        	Configure 802.1X credentials profiles
        	**type**\: list of  		 :py:class:`Credentials <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dot1x.Credentials>`
        
        .. attribute:: critical
        
        	Set 802.1x Critical Authentication parameters
        	**type**\:  :py:class:`Critical <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dot1x.Critical>`
        
        .. attribute:: test
        
        	Configure dot1x test related parameters
        	**type**\:  :py:class:`Test <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dot1x.Test>`
        
        .. attribute:: logging
        
        	Set logging parameters
        	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dot1x.Logging>`
        
        .. attribute:: supplicant
        
        	802.1X supplicant configuration
        	**type**\:  :py:class:`Supplicant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dot1x.Supplicant>`
        
        .. attribute:: system_auth_control
        
        	Enable or Disable SysAuthControl
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Dot1x, self).__init__()

            self.yang_name = "dot1x"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-dot1x:credentials", ("credentials", Native.Dot1x.Credentials)), ("Cisco-IOS-XE-dot1x:critical", ("critical", Native.Dot1x.Critical)), ("Cisco-IOS-XE-dot1x:test", ("test", Native.Dot1x.Test)), ("Cisco-IOS-XE-dot1x:logging", ("logging", Native.Dot1x.Logging)), ("Cisco-IOS-XE-dot1x:supplicant", ("supplicant", Native.Dot1x.Supplicant))])
            self._leafs = OrderedDict([
                ('system_auth_control', (YLeaf(YType.empty, 'Cisco-IOS-XE-dot1x:system-auth-control'), ['Empty'])),
            ])
            self.system_auth_control = None

            self.critical = Native.Dot1x.Critical()
            self.critical.parent = self
            self._children_name_map["critical"] = "Cisco-IOS-XE-dot1x:critical"

            self.test = Native.Dot1x.Test()
            self.test.parent = self
            self._children_name_map["test"] = "Cisco-IOS-XE-dot1x:test"

            self.logging = Native.Dot1x.Logging()
            self.logging.parent = self
            self._children_name_map["logging"] = "Cisco-IOS-XE-dot1x:logging"

            self.supplicant = Native.Dot1x.Supplicant()
            self.supplicant.parent = self
            self._children_name_map["supplicant"] = "Cisco-IOS-XE-dot1x:supplicant"

            self.credentials = YList(self)
            self._segment_path = lambda: "dot1x"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Dot1x, ['system_auth_control'], name, value)


        class Credentials(Entity):
            """
            Configure 802.1X credentials profiles
            
            .. attribute:: profile_name  (key)
            
            	Specify a profile name
            	**type**\: str
            
            .. attribute:: username
            
            	Set the authentication userid
            	**type**\: str
            
            .. attribute:: password
            
            	Set the authentication password
            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dot1x.Credentials.Password>`
            
            .. attribute:: pki_trustpoint
            
            	Set the default pki trustpoint
            	**type**\: str
            
            

            """

            _prefix = 'ios-dot1x'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Dot1x.Credentials, self).__init__()

                self.yang_name = "credentials"
                self.yang_parent_name = "dot1x"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['profile_name']
                self._child_classes = OrderedDict([("password", ("password", Native.Dot1x.Credentials.Password))])
                self._leafs = OrderedDict([
                    ('profile_name', (YLeaf(YType.str, 'profile-name'), ['str'])),
                    ('username', (YLeaf(YType.str, 'username'), ['str'])),
                    ('pki_trustpoint', (YLeaf(YType.str, 'pki-trustpoint'), ['str'])),
                ])
                self.profile_name = None
                self.username = None
                self.pki_trustpoint = None

                self.password = Native.Dot1x.Credentials.Password()
                self.password.parent = self
                self._children_name_map["password"] = "password"
                self._segment_path = lambda: "Cisco-IOS-XE-dot1x:credentials" + "[profile-name='" + str(self.profile_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/dot1x/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Dot1x.Credentials, ['profile_name', 'username', 'pki_trustpoint'], name, value)


            class Password(Entity):
                """
                Set the authentication password
                
                .. attribute:: type
                
                	
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dot1x.Credentials.Password.Type>`
                
                .. attribute:: secret
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Dot1x.Credentials.Password, self).__init__()

                    self.yang_name = "password"
                    self.yang_parent_name = "credentials"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Dot1x.Credentials.Password.Type')])),
                        ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                    ])
                    self.type = None
                    self.secret = None
                    self._segment_path = lambda: "password"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Dot1x.Credentials.Password, ['type', 'secret'], name, value)

                class Type(Enum):
                    """
                    Type (Enum Class)

                    .. data:: Y_0 = 0

                    .. data:: Y_7 = 1

                    """

                    Y_0 = Enum.YLeaf(0, "0")

                    Y_7 = Enum.YLeaf(1, "7")



        class Critical(Entity):
            """
            Set 802.1x Critical Authentication parameters
            
            .. attribute:: eapol
            
            	Send EAPOL\-Success on successful Critical Authentication
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: recovery
            
            	Set 802.1x Critical Authentication Recovery parameters
            	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dot1x.Critical.Recovery>`
            
            

            """

            _prefix = 'ios-dot1x'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Dot1x.Critical, self).__init__()

                self.yang_name = "critical"
                self.yang_parent_name = "dot1x"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("recovery", ("recovery", Native.Dot1x.Critical.Recovery))])
                self._leafs = OrderedDict([
                    ('eapol', (YLeaf(YType.empty, 'eapol'), ['Empty'])),
                ])
                self.eapol = None

                self.recovery = Native.Dot1x.Critical.Recovery()
                self.recovery.parent = self
                self._children_name_map["recovery"] = "recovery"
                self._segment_path = lambda: "Cisco-IOS-XE-dot1x:critical"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/dot1x/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Dot1x.Critical, ['eapol'], name, value)


            class Recovery(Entity):
                """
                Set 802.1x Critical Authentication Recovery parameters
                
                .. attribute:: delay
                
                	Set 802.1x Critical Authentication Recovery Delay period
                	**type**\: int
                
                	**range:** 1..10000
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Dot1x.Critical.Recovery, self).__init__()

                    self.yang_name = "recovery"
                    self.yang_parent_name = "critical"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('delay', (YLeaf(YType.uint16, 'delay'), ['int'])),
                    ])
                    self.delay = None
                    self._segment_path = lambda: "recovery"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/dot1x/Cisco-IOS-XE-dot1x:critical/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Dot1x.Critical.Recovery, ['delay'], name, value)


        class Test(Entity):
            """
            Configure dot1x test related parameters
            
            .. attribute:: timeout
            
            	Seconds
            	**type**\: int
            
            	**range:** 1..65535
            
            

            """

            _prefix = 'ios-dot1x'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Dot1x.Test, self).__init__()

                self.yang_name = "test"
                self.yang_parent_name = "dot1x"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                ])
                self.timeout = None
                self._segment_path = lambda: "Cisco-IOS-XE-dot1x:test"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/dot1x/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Dot1x.Test, ['timeout'], name, value)


        class Logging(Entity):
            """
            Set logging parameters
            
            .. attribute:: verbose
            
            	Show verbose messages in system logs
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-dot1x'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Dot1x.Logging, self).__init__()

                self.yang_name = "logging"
                self.yang_parent_name = "dot1x"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('verbose', (YLeaf(YType.empty, 'verbose'), ['Empty'])),
                ])
                self.verbose = None
                self._segment_path = lambda: "Cisco-IOS-XE-dot1x:logging"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/dot1x/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Dot1x.Logging, ['verbose'], name, value)


        class Supplicant(Entity):
            """
            802.1X supplicant configuration
            
            .. attribute:: force_multicast
            
            	Force 802.1X supplicant to send multicast packets
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-dot1x'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Dot1x.Supplicant, self).__init__()

                self.yang_name = "supplicant"
                self.yang_parent_name = "dot1x"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('force_multicast', (YLeaf(YType.empty, 'force-multicast'), ['Empty'])),
                ])
                self.force_multicast = None
                self._segment_path = lambda: "Cisco-IOS-XE-dot1x:supplicant"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/dot1x/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Dot1x.Supplicant, ['force_multicast'], name, value)


    class Mab(Entity):
        """
        mab Configuration Commands
        
        .. attribute:: logging
        
        	Set logging parameters
        	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mab.Logging>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Mab, self).__init__()

            self.yang_name = "mab"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("logging", ("logging", Native.Mab.Logging))])
            self._leafs = OrderedDict()

            self.logging = Native.Mab.Logging()
            self.logging.parent = self
            self._children_name_map["logging"] = "logging"
            self._segment_path = lambda: "mab"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Mab, [], name, value)


        class Logging(Entity):
            """
            Set logging parameters
            
            .. attribute:: verbose
            
            	Show verbose messages in system logs
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Mab.Logging, self).__init__()

                self.yang_name = "logging"
                self.yang_parent_name = "mab"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('verbose', (YLeaf(YType.empty, 'verbose'), ['Empty'])),
                ])
                self.verbose = None
                self._segment_path = lambda: "logging"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mab/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mab.Logging, [u'verbose'], name, value)


    class Fallback(Entity):
        """
        Fallback configuration commands
        
        .. attribute:: profile
        
        	Create a Fallback profile
        	**type**\:  :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fallback.Profile>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Fallback, self).__init__()

            self.yang_name = "fallback"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-dot1x:profile", ("profile", Native.Fallback.Profile))])
            self._leafs = OrderedDict()

            self.profile = Native.Fallback.Profile()
            self.profile.parent = self
            self._children_name_map["profile"] = "Cisco-IOS-XE-dot1x:profile"
            self._segment_path = lambda: "fallback"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Fallback, [], name, value)


        class Profile(Entity):
            """
            Create a Fallback profile
            
            .. attribute:: fallback_list
            
            	Specify a policy name
            	**type**\: list of  		 :py:class:`FallbackList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fallback.Profile.FallbackList>`
            
            

            """

            _prefix = 'ios-dot1x'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Fallback.Profile, self).__init__()

                self.yang_name = "profile"
                self.yang_parent_name = "fallback"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("fallback-list", ("fallback_list", Native.Fallback.Profile.FallbackList))])
                self._leafs = OrderedDict()

                self.fallback_list = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-dot1x:profile"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/fallback/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Fallback.Profile, [], name, value)


            class FallbackList(Entity):
                """
                Specify a policy name
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: description
                
                	Any textual description
                	**type**\: str
                
                .. attribute:: ip
                
                	Internet Protocol configuration commands
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fallback.Profile.FallbackList.Ip>`
                
                

                """

                _prefix = 'ios-dot1x'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Fallback.Profile.FallbackList, self).__init__()

                    self.yang_name = "fallback-list"
                    self.yang_parent_name = "profile"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Fallback.Profile.FallbackList.Ip))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.name = None
                    self.description = None

                    self.ip = Native.Fallback.Profile.FallbackList.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "fallback-list" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/fallback/Cisco-IOS-XE-dot1x:profile/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Fallback.Profile.FallbackList, ['name', 'description'], name, value)


                class Ip(Entity):
                    """
                    Internet Protocol configuration commands
                    
                    .. attribute:: access_group
                    
                    	Specify access control for packets
                    	**type**\: list of  		 :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fallback.Profile.FallbackList.Ip.AccessGroup>`
                    
                    .. attribute:: admission
                    
                    	Name of IP admission rule
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-dot1x'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Fallback.Profile.FallbackList.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "fallback-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-group", ("access_group", Native.Fallback.Profile.FallbackList.Ip.AccessGroup))])
                        self._leafs = OrderedDict([
                            ('admission', (YLeaf(YType.str, 'admission'), ['str'])),
                        ])
                        self.admission = None

                        self.access_group = YList(self)
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Fallback.Profile.FallbackList.Ip, ['admission'], name, value)


                    class AccessGroup(Entity):
                        """
                        Specify access control for packets
                        
                        .. attribute:: name  (key)
                        
                        	IP expanded access list (standard or extended)
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1300..2699
                        
                        		**type**\: str
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-dot1x'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Fallback.Profile.FallbackList.Ip.AccessGroup, self).__init__()

                            self.yang_name = "access-group"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['int','str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                            ])
                            self.name = None
                            self.in_ = None
                            self._segment_path = lambda: "access-group" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Fallback.Profile.FallbackList.Ip.AccessGroup, ['name', 'in_'], name, value)


    class ParameterMap(Entity):
        """
        parameter map
        
        .. attribute:: type
        
        	parameter map type
        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.ParameterMap, self).__init__()

            self.yang_name = "parameter-map"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("type", ("type", Native.ParameterMap.Type))])
            self._leafs = OrderedDict()

            self.type = Native.ParameterMap.Type()
            self.type.parent = self
            self._children_name_map["type"] = "type"
            self._segment_path = lambda: "parameter-map"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.ParameterMap, [], name, value)


        class Type(Entity):
            """
            parameter map type
            
            .. attribute:: cws_tunnel
            
            	Cloud Web Security tunnel mode
            	**type**\:  :py:class:`CwsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel>`
            
            .. attribute:: inspect
            
            	inspect parameter\-map
            	**type**\: list of  		 :py:class:`Inspect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect>`
            
            .. attribute:: inspect_global_deprecate
            
            	
            	**type**\:  :py:class:`InspectGlobalDeprecate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate>`
            
            .. attribute:: inspect_global
            
            	inspect global parameter\-map
            	**type**\:  :py:class:`InspectGlobal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal>`
            
            	**presence node**\: True
            
            .. attribute:: inspect_vrf
            
            	inspect vrf parameter\-map
            	**type**\: list of  		 :py:class:`InspectVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectVrf>`
            
            .. attribute:: inspect_zone
            
            	inspect zone parameter\-map
            	**type**\: list of  		 :py:class:`InspectZone <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectZone>`
            
            .. attribute:: regex
            
            	regex parameter\-map
            	**type**\: list of  		 :py:class:`Regex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Regex>`
            
            .. attribute:: webauth
            
            	WEBAUTH parameters
            	**type**\: list of  		 :py:class:`Webauth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth>`
            
            .. attribute:: webauth_global
            
            	
            	**type**\:  :py:class:`WebauthGlobal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal>`
            
            .. attribute:: umbrella
            
            	Umbrella mode
            	**type**\:  :py:class:`Umbrella <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Umbrella>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.ParameterMap.Type, self).__init__()

                self.yang_name = "type"
                self.yang_parent_name = "parameter-map"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Cisco-IOS-XE-policy:cws-tunnel", ("cws_tunnel", Native.ParameterMap.Type.CwsTunnel)), ("Cisco-IOS-XE-policy:inspect", ("inspect", Native.ParameterMap.Type.Inspect)), ("Cisco-IOS-XE-policy:inspect-global-deprecate", ("inspect_global_deprecate", Native.ParameterMap.Type.InspectGlobalDeprecate)), ("Cisco-IOS-XE-policy:inspect-global", ("inspect_global", Native.ParameterMap.Type.InspectGlobal)), ("Cisco-IOS-XE-policy:inspect-vrf", ("inspect_vrf", Native.ParameterMap.Type.InspectVrf)), ("Cisco-IOS-XE-policy:inspect-zone", ("inspect_zone", Native.ParameterMap.Type.InspectZone)), ("Cisco-IOS-XE-policy:regex", ("regex", Native.ParameterMap.Type.Regex)), ("Cisco-IOS-XE-policy:webauth", ("webauth", Native.ParameterMap.Type.Webauth)), ("Cisco-IOS-XE-policy:webauth-global", ("webauth_global", Native.ParameterMap.Type.WebauthGlobal)), ("Cisco-IOS-XE-umbrella:umbrella", ("umbrella", Native.ParameterMap.Type.Umbrella))])
                self._leafs = OrderedDict()

                self.cws_tunnel = Native.ParameterMap.Type.CwsTunnel()
                self.cws_tunnel.parent = self
                self._children_name_map["cws_tunnel"] = "Cisco-IOS-XE-policy:cws-tunnel"

                self.inspect_global_deprecate = Native.ParameterMap.Type.InspectGlobalDeprecate()
                self.inspect_global_deprecate.parent = self
                self._children_name_map["inspect_global_deprecate"] = "Cisco-IOS-XE-policy:inspect-global-deprecate"

                self.inspect_global = None
                self._children_name_map["inspect_global"] = "Cisco-IOS-XE-policy:inspect-global"

                self.webauth_global = Native.ParameterMap.Type.WebauthGlobal()
                self.webauth_global.parent = self
                self._children_name_map["webauth_global"] = "Cisco-IOS-XE-policy:webauth-global"

                self.umbrella = Native.ParameterMap.Type.Umbrella()
                self.umbrella.parent = self
                self._children_name_map["umbrella"] = "Cisco-IOS-XE-umbrella:umbrella"

                self.inspect = YList(self)
                self.inspect_vrf = YList(self)
                self.inspect_zone = YList(self)
                self.regex = YList(self)
                self.webauth = YList(self)
                self._segment_path = lambda: "type"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ParameterMap.Type, [], name, value)


            class CwsTunnel(Entity):
                """
                Cloud Web Security tunnel mode
                
                .. attribute:: global_
                
                	cws\_tunnel global parameter\-map
                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.ParameterMap.Type.CwsTunnel, self).__init__()

                    self.yang_name = "cws-tunnel"
                    self.yang_parent_name = "type"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("global", ("global_", Native.ParameterMap.Type.CwsTunnel.Global))])
                    self._leafs = OrderedDict()

                    self.global_ = None
                    self._children_name_map["global_"] = "global"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:cws-tunnel"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ParameterMap.Type.CwsTunnel, [], name, value)


                class Global(Entity):
                    """
                    cws\_tunnel global parameter\-map
                    
                    .. attribute:: fail_open
                    
                    	Allow traffic to go in clear if CWS Towers are unreachable
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: license
                    
                    	License Key
                    	**type**\:  :py:class:`License <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global.License>`
                    
                    .. attribute:: logging
                    
                    	CWS syslogs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: primary
                    
                    	Primary tower
                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global.Primary>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: redirect_list
                    
                    	Set access\-list for reverse route from CWS Tower Standard IP access\-list number <1\-199> Standard IP access\-list number (expanded range) <1300\-2699>
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199
                    
                    		**type**\: int
                    
                    			**range:** 1300..2699
                    
                    .. attribute:: secondary
                    
                    	Secondary tower
                    	**type**\:  :py:class:`Secondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global.Secondary>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: whitelist
                    
                    	Disable redirection to CWS Access list (standard) <1\-199> Access list (extended) <1300\-2699> Access list name
                    	**type**\:  :py:class:`Whitelist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global.Whitelist>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.CwsTunnel.Global, self).__init__()

                        self.yang_name = "global"
                        self.yang_parent_name = "cws-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("license", ("license", Native.ParameterMap.Type.CwsTunnel.Global.License)), ("primary", ("primary", Native.ParameterMap.Type.CwsTunnel.Global.Primary)), ("secondary", ("secondary", Native.ParameterMap.Type.CwsTunnel.Global.Secondary)), ("whitelist", ("whitelist", Native.ParameterMap.Type.CwsTunnel.Global.Whitelist))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('fail_open', (YLeaf(YType.empty, 'fail-open'), ['Empty'])),
                            ('logging', (YLeaf(YType.empty, 'logging'), ['Empty'])),
                            ('redirect_list', (YLeaf(YType.str, 'redirect-list'), ['int','int'])),
                        ])
                        self.fail_open = None
                        self.logging = None
                        self.redirect_list = None

                        self.license = Native.ParameterMap.Type.CwsTunnel.Global.License()
                        self.license.parent = self
                        self._children_name_map["license"] = "license"

                        self.primary = None
                        self._children_name_map["primary"] = "primary"

                        self.secondary = None
                        self._children_name_map["secondary"] = "secondary"

                        self.whitelist = None
                        self._children_name_map["whitelist"] = "whitelist"
                        self._segment_path = lambda: "global"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global, ['fail_open', 'logging', 'redirect_list'], name, value)


                    class License(Entity):
                        """
                        License Key
                        
                        .. attribute:: unencypted
                        
                        	Unencrypted License
                        	**type**\:  :py:class:`Unencypted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global.License.Unencypted>`
                        
                        .. attribute:: encrypted
                        
                        	Encrypted License
                        	**type**\:  :py:class:`Encrypted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global.License.Encrypted>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.CwsTunnel.Global.License, self).__init__()

                            self.yang_name = "license"
                            self.yang_parent_name = "global"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("unencypted", ("unencypted", Native.ParameterMap.Type.CwsTunnel.Global.License.Unencypted)), ("encrypted", ("encrypted", Native.ParameterMap.Type.CwsTunnel.Global.License.Encrypted))])
                            self._leafs = OrderedDict()

                            self.unencypted = Native.ParameterMap.Type.CwsTunnel.Global.License.Unencypted()
                            self.unencypted.parent = self
                            self._children_name_map["unencypted"] = "unencypted"

                            self.encrypted = Native.ParameterMap.Type.CwsTunnel.Global.License.Encrypted()
                            self.encrypted.parent = self
                            self._children_name_map["encrypted"] = "encrypted"
                            self._segment_path = lambda: "license"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/global/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global.License, [], name, value)


                        class Unencypted(Entity):
                            """
                            Unencrypted License
                            
                            .. attribute:: hex_string
                            
                            	32 char non encrypted hex key
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.CwsTunnel.Global.License.Unencypted, self).__init__()

                                self.yang_name = "unencypted"
                                self.yang_parent_name = "license"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hex_string', (YLeaf(YType.str, 'hex-string'), ['str'])),
                                ])
                                self.hex_string = None
                                self._segment_path = lambda: "unencypted"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/global/license/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global.License.Unencypted, ['hex_string'], name, value)


                        class Encrypted(Entity):
                            """
                            Encrypted License
                            
                            .. attribute:: hex_string
                            
                            	66 char encrypted hex key
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.CwsTunnel.Global.License.Encrypted, self).__init__()

                                self.yang_name = "encrypted"
                                self.yang_parent_name = "license"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hex_string', (YLeaf(YType.str, 'hex-string'), ['str'])),
                                ])
                                self.hex_string = None
                                self._segment_path = lambda: "encrypted"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/global/license/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global.License.Encrypted, ['hex_string'], name, value)


                    class Primary(Entity):
                        """
                        Primary tower
                        
                        .. attribute:: tower
                        
                        	Tower configuration for CWS
                        	**type**\:  :py:class:`Tower <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global.Primary.Tower>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.CwsTunnel.Global.Primary, self).__init__()

                            self.yang_name = "primary"
                            self.yang_parent_name = "global"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("tower", ("tower", Native.ParameterMap.Type.CwsTunnel.Global.Primary.Tower))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.tower = Native.ParameterMap.Type.CwsTunnel.Global.Primary.Tower()
                            self.tower.parent = self
                            self._children_name_map["tower"] = "tower"
                            self._segment_path = lambda: "primary"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/global/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global.Primary, [], name, value)


                        class Tower(Entity):
                            """
                            Tower configuration for CWS
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address of the tower
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: name
                            
                            	Fully Qualified Domain Name of tower
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.CwsTunnel.Global.Primary.Tower, self).__init__()

                                self.yang_name = "tower"
                                self.yang_parent_name = "primary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.name = None
                                self._segment_path = lambda: "tower"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/global/primary/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global.Primary.Tower, ['ipv4', 'name'], name, value)


                    class Secondary(Entity):
                        """
                        Secondary tower
                        
                        .. attribute:: tower
                        
                        	Tower configuration for CWS
                        	**type**\:  :py:class:`Tower <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global.Secondary.Tower>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.CwsTunnel.Global.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "global"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("tower", ("tower", Native.ParameterMap.Type.CwsTunnel.Global.Secondary.Tower))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.tower = Native.ParameterMap.Type.CwsTunnel.Global.Secondary.Tower()
                            self.tower.parent = self
                            self._children_name_map["tower"] = "tower"
                            self._segment_path = lambda: "secondary"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/global/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global.Secondary, [], name, value)


                        class Tower(Entity):
                            """
                            Tower configuration for CWS
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address of the tower
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: name
                            
                            	Fully Qualified Domain Name of tower
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.CwsTunnel.Global.Secondary.Tower, self).__init__()

                                self.yang_name = "tower"
                                self.yang_parent_name = "secondary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.name = None
                                self._segment_path = lambda: "tower"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/global/secondary/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global.Secondary.Tower, ['ipv4', 'name'], name, value)


                    class Whitelist(Entity):
                        """
                        Disable redirection to CWS
                        Access list (standard) <1\-199>
                        Access list (extended) <1300\-2699>
                        Access list name
                        
                        .. attribute:: acl
                        
                        	Access list
                        	**type**\:  :py:class:`Acl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.Acl>`
                        
                        .. attribute:: domain_name
                        
                        	Domain name based Whitelist
                        	**type**\:  :py:class:`DomainName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.DomainName>`
                        
                        .. attribute:: download
                        
                        	whitelist download command
                        	**type**\:  :py:class:`Download <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.Download>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.CwsTunnel.Global.Whitelist, self).__init__()

                            self.yang_name = "whitelist"
                            self.yang_parent_name = "global"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("acl", ("acl", Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.Acl)), ("domain-name", ("domain_name", Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.DomainName)), ("download", ("download", Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.Download))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.acl = Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.Acl()
                            self.acl.parent = self
                            self._children_name_map["acl"] = "acl"

                            self.domain_name = Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.DomainName()
                            self.domain_name.parent = self
                            self._children_name_map["domain_name"] = "domain-name"

                            self.download = None
                            self._children_name_map["download"] = "download"
                            self._segment_path = lambda: "whitelist"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/global/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global.Whitelist, [], name, value)


                        class Acl(Entity):
                            """
                            Access list
                            
                            .. attribute:: acl_number
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199
                            
                            		**type**\: int
                            
                            			**range:** 1300..2699
                            
                            .. attribute:: name
                            
                            	Access list name
                            	**type**\: str
                            
                            	**length:** 1..64
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.Acl, self).__init__()

                                self.yang_name = "acl"
                                self.yang_parent_name = "whitelist"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('acl_number', (YLeaf(YType.str, 'acl-number'), ['int','int'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.acl_number = None
                                self.name = None
                                self._segment_path = lambda: "acl"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/global/whitelist/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.Acl, ['acl_number', 'name'], name, value)


                        class DomainName(Entity):
                            """
                            Domain name based Whitelist
                            
                            .. attribute:: regex
                            
                            	Domain name regex parameter map
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.DomainName, self).__init__()

                                self.yang_name = "domain-name"
                                self.yang_parent_name = "whitelist"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('regex', (YLeaf(YType.str, 'regex'), ['str'])),
                                ])
                                self.regex = None
                                self._segment_path = lambda: "domain-name"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/global/whitelist/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.DomainName, ['regex'], name, value)


                        class Download(Entity):
                            """
                            whitelist download command
                            
                            .. attribute:: interval
                            
                            	Download interval in minutes
                            	**type**\: int
                            
                            	**range:** 5..10080
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.Download, self).__init__()

                                self.yang_name = "download"
                                self.yang_parent_name = "whitelist"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "download"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:cws-tunnel/global/whitelist/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.CwsTunnel.Global.Whitelist.Download, ['interval'], name, value)


            class Inspect(Entity):
                """
                inspect parameter\-map
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                	**length:** 1..256
                
                .. attribute:: alert
                
                	Turn on/off alert
                	**type**\:  :py:class:`Alert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Alert>`
                
                .. attribute:: application_inspect
                
                	Turn on application inspection
                	**type**\:  :py:class:`ApplicationInspect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.ApplicationInspect>`
                
                .. attribute:: audit_trail
                
                	Turn on/off audit trail
                	**type**\:  :py:class:`AuditTrail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.AuditTrail>`
                
                .. attribute:: dns_timeout
                
                	Timeout in seconds
                	**type**\: int
                
                	**range:** 1..2147483
                
                .. attribute:: icmp
                
                	Config timeout values for icmp
                	**type**\:  :py:class:`Icmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Icmp>`
                
                .. attribute:: icmp_unreachable_allow
                
                	ICMP unreachable packets are allowed
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: log
                
                	Configure inspect logging parameters
                	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Log>`
                
                .. attribute:: max_incomplete
                
                	Specify maximum number of incomplete connections before clamping
                	**type**\:  :py:class:`MaxIncomplete <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.MaxIncomplete>`
                
                .. attribute:: one_minute
                
                	Specify one\-minute\-sample watermarks for clamping
                	**type**\:  :py:class:`OneMinute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.OneMinute>`
                
                .. attribute:: sessions
                
                	Configure sessions related parameters
                	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Sessions>`
                
                .. attribute:: tcp
                
                	Config timeout values for tcp connections
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp>`
                
                .. attribute:: udp
                
                	Config timeout values for udp flows
                	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Udp>`
                
                .. attribute:: zone_mismatch
                
                	Config zone\-mismatch option
                	**type**\:  :py:class:`ZoneMismatch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.ZoneMismatch>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.ParameterMap.Type.Inspect, self).__init__()

                    self.yang_name = "inspect"
                    self.yang_parent_name = "type"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("alert", ("alert", Native.ParameterMap.Type.Inspect.Alert)), ("application-inspect", ("application_inspect", Native.ParameterMap.Type.Inspect.ApplicationInspect)), ("audit-trail", ("audit_trail", Native.ParameterMap.Type.Inspect.AuditTrail)), ("icmp", ("icmp", Native.ParameterMap.Type.Inspect.Icmp)), ("log", ("log", Native.ParameterMap.Type.Inspect.Log)), ("max-incomplete", ("max_incomplete", Native.ParameterMap.Type.Inspect.MaxIncomplete)), ("one-minute", ("one_minute", Native.ParameterMap.Type.Inspect.OneMinute)), ("sessions", ("sessions", Native.ParameterMap.Type.Inspect.Sessions)), ("tcp", ("tcp", Native.ParameterMap.Type.Inspect.Tcp)), ("udp", ("udp", Native.ParameterMap.Type.Inspect.Udp)), ("zone-mismatch", ("zone_mismatch", Native.ParameterMap.Type.Inspect.ZoneMismatch))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('dns_timeout', (YLeaf(YType.uint32, 'dns-timeout'), ['int'])),
                        ('icmp_unreachable_allow', (YLeaf(YType.empty, 'icmp-unreachable-allow'), ['Empty'])),
                    ])
                    self.name = None
                    self.dns_timeout = None
                    self.icmp_unreachable_allow = None

                    self.alert = Native.ParameterMap.Type.Inspect.Alert()
                    self.alert.parent = self
                    self._children_name_map["alert"] = "alert"

                    self.application_inspect = Native.ParameterMap.Type.Inspect.ApplicationInspect()
                    self.application_inspect.parent = self
                    self._children_name_map["application_inspect"] = "application-inspect"

                    self.audit_trail = Native.ParameterMap.Type.Inspect.AuditTrail()
                    self.audit_trail.parent = self
                    self._children_name_map["audit_trail"] = "audit-trail"

                    self.icmp = Native.ParameterMap.Type.Inspect.Icmp()
                    self.icmp.parent = self
                    self._children_name_map["icmp"] = "icmp"

                    self.log = Native.ParameterMap.Type.Inspect.Log()
                    self.log.parent = self
                    self._children_name_map["log"] = "log"

                    self.max_incomplete = Native.ParameterMap.Type.Inspect.MaxIncomplete()
                    self.max_incomplete.parent = self
                    self._children_name_map["max_incomplete"] = "max-incomplete"

                    self.one_minute = Native.ParameterMap.Type.Inspect.OneMinute()
                    self.one_minute.parent = self
                    self._children_name_map["one_minute"] = "one-minute"

                    self.sessions = Native.ParameterMap.Type.Inspect.Sessions()
                    self.sessions.parent = self
                    self._children_name_map["sessions"] = "sessions"

                    self.tcp = Native.ParameterMap.Type.Inspect.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.udp = Native.ParameterMap.Type.Inspect.Udp()
                    self.udp.parent = self
                    self._children_name_map["udp"] = "udp"

                    self.zone_mismatch = Native.ParameterMap.Type.Inspect.ZoneMismatch()
                    self.zone_mismatch.parent = self
                    self._children_name_map["zone_mismatch"] = "zone-mismatch"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:inspect" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ParameterMap.Type.Inspect, ['name', 'dns_timeout', 'icmp_unreachable_allow'], name, value)


                class Alert(Entity):
                    """
                    Turn on/off alert
                    
                    .. attribute:: on
                    
                    	Turn on alert
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Inspect.Alert, self).__init__()

                        self.yang_name = "alert"
                        self.yang_parent_name = "inspect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                        ])
                        self.on = None
                        self._segment_path = lambda: "alert"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Inspect.Alert, ['on'], name, value)


                class ApplicationInspect(Entity):
                    """
                    Turn on application inspection
                    
                    .. attribute:: dns
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: exec_
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: ftp
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: gtp
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: h323
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: http
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: imap
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: login
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: msrpc
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: netbios
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: pop3
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: rtsp
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: shell
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: sip
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: skinny
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: smtp
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: sunrpc
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: tftp
                    
                    	
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Inspect.ApplicationInspect, self).__init__()

                        self.yang_name = "application-inspect"
                        self.yang_parent_name = "inspect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dns', (YLeaf(YType.boolean, 'dns'), ['bool'])),
                            ('exec_', (YLeaf(YType.boolean, 'exec'), ['bool'])),
                            ('ftp', (YLeaf(YType.boolean, 'ftp'), ['bool'])),
                            ('gtp', (YLeaf(YType.boolean, 'gtp'), ['bool'])),
                            ('h323', (YLeaf(YType.boolean, 'h323'), ['bool'])),
                            ('http', (YLeaf(YType.boolean, 'http'), ['bool'])),
                            ('imap', (YLeaf(YType.boolean, 'imap'), ['bool'])),
                            ('login', (YLeaf(YType.boolean, 'login'), ['bool'])),
                            ('msrpc', (YLeaf(YType.boolean, 'msrpc'), ['bool'])),
                            ('netbios', (YLeaf(YType.boolean, 'netbios'), ['bool'])),
                            ('pop3', (YLeaf(YType.boolean, 'pop3'), ['bool'])),
                            ('rtsp', (YLeaf(YType.boolean, 'rtsp'), ['bool'])),
                            ('shell', (YLeaf(YType.boolean, 'shell'), ['bool'])),
                            ('sip', (YLeaf(YType.boolean, 'sip'), ['bool'])),
                            ('skinny', (YLeaf(YType.boolean, 'skinny'), ['bool'])),
                            ('smtp', (YLeaf(YType.boolean, 'smtp'), ['bool'])),
                            ('sunrpc', (YLeaf(YType.boolean, 'sunrpc'), ['bool'])),
                            ('tftp', (YLeaf(YType.boolean, 'tftp'), ['bool'])),
                        ])
                        self.dns = None
                        self.exec_ = None
                        self.ftp = None
                        self.gtp = None
                        self.h323 = None
                        self.http = None
                        self.imap = None
                        self.login = None
                        self.msrpc = None
                        self.netbios = None
                        self.pop3 = None
                        self.rtsp = None
                        self.shell = None
                        self.sip = None
                        self.skinny = None
                        self.smtp = None
                        self.sunrpc = None
                        self.tftp = None
                        self._segment_path = lambda: "application-inspect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Inspect.ApplicationInspect, ['dns', 'exec_', 'ftp', 'gtp', 'h323', 'http', 'imap', 'login', 'msrpc', 'netbios', 'pop3', 'rtsp', 'shell', 'sip', 'skinny', 'smtp', 'sunrpc', 'tftp'], name, value)


                class AuditTrail(Entity):
                    """
                    Turn on/off audit trail
                    
                    .. attribute:: on
                    
                    	Turn on audit trail
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Inspect.AuditTrail, self).__init__()

                        self.yang_name = "audit-trail"
                        self.yang_parent_name = "inspect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                        ])
                        self.on = None
                        self._segment_path = lambda: "audit-trail"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Inspect.AuditTrail, ['on'], name, value)


                class Icmp(Entity):
                    """
                    Config timeout values for icmp
                    
                    .. attribute:: idle_time
                    
                    	Specify idle timeout for icmp
                    	**type**\:  :py:class:`IdleTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Icmp.IdleTime>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Inspect.Icmp, self).__init__()

                        self.yang_name = "icmp"
                        self.yang_parent_name = "inspect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("idle-time", ("idle_time", Native.ParameterMap.Type.Inspect.Icmp.IdleTime))])
                        self._leafs = OrderedDict()

                        self.idle_time = Native.ParameterMap.Type.Inspect.Icmp.IdleTime()
                        self.idle_time.parent = self
                        self._children_name_map["idle_time"] = "idle-time"
                        self._segment_path = lambda: "icmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Inspect.Icmp, [], name, value)


                    class IdleTime(Entity):
                        """
                        Specify idle timeout for icmp
                        
                        .. attribute:: timeout
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..2147483
                        
                        .. attribute:: ageout_time
                        
                        	Specify aggressive age\-out time for icmp
                        	**type**\: int
                        
                        	**range:** 1..2147483
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Icmp.IdleTime, self).__init__()

                            self.yang_name = "idle-time"
                            self.yang_parent_name = "icmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                                ('ageout_time', (YLeaf(YType.uint32, 'ageout-time'), ['int'])),
                            ])
                            self.timeout = None
                            self.ageout_time = None
                            self._segment_path = lambda: "idle-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Icmp.IdleTime, ['timeout', 'ageout_time'], name, value)


                class Log(Entity):
                    """
                    Configure inspect logging parameters
                    
                    .. attribute:: dropped_packets
                    
                    	Log dropped packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Inspect.Log, self).__init__()

                        self.yang_name = "log"
                        self.yang_parent_name = "inspect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dropped_packets', (YLeaf(YType.empty, 'dropped-packets'), ['Empty'])),
                        ])
                        self.dropped_packets = None
                        self._segment_path = lambda: "log"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Inspect.Log, ['dropped_packets'], name, value)


                class MaxIncomplete(Entity):
                    """
                    Specify maximum number of incomplete connections before clamping
                    
                    .. attribute:: high
                    
                    	Specify high\-watermark for clamping
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: low
                    
                    	Specify low\-watermark for clamping
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Inspect.MaxIncomplete, self).__init__()

                        self.yang_name = "max-incomplete"
                        self.yang_parent_name = "inspect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                            ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                        ])
                        self.high = None
                        self.low = None
                        self._segment_path = lambda: "max-incomplete"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Inspect.MaxIncomplete, ['high', 'low'], name, value)


                class OneMinute(Entity):
                    """
                    Specify one\-minute\-sample watermarks for clamping
                    
                    .. attribute:: high
                    
                    	Specify high\-watermark for clamping
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: low
                    
                    	Specify low\-watermark for clamping
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Inspect.OneMinute, self).__init__()

                        self.yang_name = "one-minute"
                        self.yang_parent_name = "inspect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                            ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                        ])
                        self.high = None
                        self.low = None
                        self._segment_path = lambda: "one-minute"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Inspect.OneMinute, ['high', 'low'], name, value)


                class Sessions(Entity):
                    """
                    Configure sessions related parameters
                    
                    .. attribute:: maximum
                    
                    	Maximum sessions
                    	**type**\: int
                    
                    	**range:** 1..2147483647
                    
                    .. attribute:: packet
                    
                    	Simultaneous packets per session
                    	**type**\: int
                    
                    	**range:** 25..100
                    
                    .. attribute:: rate
                    
                    	Specify watermarks for clamping
                    	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Sessions.Rate>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Inspect.Sessions, self).__init__()

                        self.yang_name = "sessions"
                        self.yang_parent_name = "inspect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rate", ("rate", Native.ParameterMap.Type.Inspect.Sessions.Rate))])
                        self._leafs = OrderedDict([
                            ('maximum', (YLeaf(YType.uint32, 'maximum'), ['int'])),
                            ('packet', (YLeaf(YType.uint8, 'packet'), ['int'])),
                        ])
                        self.maximum = None
                        self.packet = None

                        self.rate = Native.ParameterMap.Type.Inspect.Sessions.Rate()
                        self.rate.parent = self
                        self._children_name_map["rate"] = "rate"
                        self._segment_path = lambda: "sessions"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Inspect.Sessions, ['maximum', 'packet'], name, value)


                    class Rate(Entity):
                        """
                        Specify watermarks for clamping
                        
                        .. attribute:: high
                        
                        	Specify high\-watermark for clamping
                        	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Sessions.Rate.High>`
                        
                        .. attribute:: low
                        
                        	Specify low\-watermark for clamping
                        	**type**\:  :py:class:`Low <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Sessions.Rate.Low>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Sessions.Rate, self).__init__()

                            self.yang_name = "rate"
                            self.yang_parent_name = "sessions"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("high", ("high", Native.ParameterMap.Type.Inspect.Sessions.Rate.High)), ("low", ("low", Native.ParameterMap.Type.Inspect.Sessions.Rate.Low))])
                            self._leafs = OrderedDict()

                            self.high = Native.ParameterMap.Type.Inspect.Sessions.Rate.High()
                            self.high.parent = self
                            self._children_name_map["high"] = "high"

                            self.low = Native.ParameterMap.Type.Inspect.Sessions.Rate.Low()
                            self.low.parent = self
                            self._children_name_map["low"] = "low"
                            self._segment_path = lambda: "rate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Sessions.Rate, [], name, value)


                        class High(Entity):
                            """
                            Specify high\-watermark for clamping
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..2147483647
                            
                            .. attribute:: time
                            
                            	Specify the time for which session rate limit is applied
                            	**type**\: int
                            
                            	**range:** 1..2147483647
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Inspect.Sessions.Rate.High, self).__init__()

                                self.yang_name = "high"
                                self.yang_parent_name = "rate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                ])
                                self.value = None
                                self.time = None
                                self._segment_path = lambda: "high"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Inspect.Sessions.Rate.High, ['value', 'time'], name, value)


                        class Low(Entity):
                            """
                            Specify low\-watermark for clamping
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..2147483647
                            
                            .. attribute:: time
                            
                            	Specify the time for which session rate limit is applied
                            	**type**\: int
                            
                            	**range:** 1..2147483647
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Inspect.Sessions.Rate.Low, self).__init__()

                                self.yang_name = "low"
                                self.yang_parent_name = "rate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                ])
                                self.value = None
                                self.time = None
                                self._segment_path = lambda: "low"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Inspect.Sessions.Rate.Low, ['value', 'time'], name, value)


                class Tcp(Entity):
                    """
                    Config timeout values for tcp connections
                    
                    .. attribute:: finwait_time
                    
                    	Specify timeout for TCP connections after a FIN
                    	**type**\:  :py:class:`FinwaitTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.FinwaitTime>`
                    
                    .. attribute:: half_close
                    
                    	Specify tcp halfclose reset RST transmission on/off
                    	**type**\:  :py:class:`HalfClose <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.HalfClose>`
                    
                    .. attribute:: half_open
                    
                    	Specify tcp halfopen reset RST transmission on/off
                    	**type**\:  :py:class:`HalfOpen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.HalfOpen>`
                    
                    .. attribute:: idle
                    
                    	Specify tcp idle reset RST transmission on/off
                    	**type**\:  :py:class:`Idle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.Idle>`
                    
                    .. attribute:: idle_time
                    
                    	Specify idle timeout for tcp connections
                    	**type**\:  :py:class:`IdleTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.IdleTime>`
                    
                    .. attribute:: max_incomplete
                    
                    	Specify max half\-open connection per host
                    	**type**\:  :py:class:`MaxIncomplete <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.MaxIncomplete>`
                    
                    .. attribute:: synwait_time
                    
                    	Specify timeout for TCP connections after a SYN and no further data
                    	**type**\:  :py:class:`SynwaitTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.SynwaitTime>`
                    
                    .. attribute:: window_scale_enforcement
                    
                    	Specify tcp window scaling enforcement
                    	**type**\:  :py:class:`WindowScaleEnforcement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.WindowScaleEnforcement>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Inspect.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "inspect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("finwait-time", ("finwait_time", Native.ParameterMap.Type.Inspect.Tcp.FinwaitTime)), ("half-close", ("half_close", Native.ParameterMap.Type.Inspect.Tcp.HalfClose)), ("half-open", ("half_open", Native.ParameterMap.Type.Inspect.Tcp.HalfOpen)), ("idle", ("idle", Native.ParameterMap.Type.Inspect.Tcp.Idle)), ("idle-time", ("idle_time", Native.ParameterMap.Type.Inspect.Tcp.IdleTime)), ("max-incomplete", ("max_incomplete", Native.ParameterMap.Type.Inspect.Tcp.MaxIncomplete)), ("synwait-time", ("synwait_time", Native.ParameterMap.Type.Inspect.Tcp.SynwaitTime)), ("window-scale-enforcement", ("window_scale_enforcement", Native.ParameterMap.Type.Inspect.Tcp.WindowScaleEnforcement))])
                        self._leafs = OrderedDict()

                        self.finwait_time = Native.ParameterMap.Type.Inspect.Tcp.FinwaitTime()
                        self.finwait_time.parent = self
                        self._children_name_map["finwait_time"] = "finwait-time"

                        self.half_close = Native.ParameterMap.Type.Inspect.Tcp.HalfClose()
                        self.half_close.parent = self
                        self._children_name_map["half_close"] = "half-close"

                        self.half_open = Native.ParameterMap.Type.Inspect.Tcp.HalfOpen()
                        self.half_open.parent = self
                        self._children_name_map["half_open"] = "half-open"

                        self.idle = Native.ParameterMap.Type.Inspect.Tcp.Idle()
                        self.idle.parent = self
                        self._children_name_map["idle"] = "idle"

                        self.idle_time = Native.ParameterMap.Type.Inspect.Tcp.IdleTime()
                        self.idle_time.parent = self
                        self._children_name_map["idle_time"] = "idle-time"

                        self.max_incomplete = Native.ParameterMap.Type.Inspect.Tcp.MaxIncomplete()
                        self.max_incomplete.parent = self
                        self._children_name_map["max_incomplete"] = "max-incomplete"

                        self.synwait_time = Native.ParameterMap.Type.Inspect.Tcp.SynwaitTime()
                        self.synwait_time.parent = self
                        self._children_name_map["synwait_time"] = "synwait-time"

                        self.window_scale_enforcement = Native.ParameterMap.Type.Inspect.Tcp.WindowScaleEnforcement()
                        self.window_scale_enforcement.parent = self
                        self._children_name_map["window_scale_enforcement"] = "window-scale-enforcement"
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp, [], name, value)


                    class FinwaitTime(Entity):
                        """
                        Specify timeout for TCP connections after a FIN
                        
                        .. attribute:: timeout
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..2147483
                        
                        .. attribute:: ageout_time
                        
                        	Specify aggressive age\-out time for tcp
                        	**type**\: int
                        
                        	**range:** 1..2147483
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Tcp.FinwaitTime, self).__init__()

                            self.yang_name = "finwait-time"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                                ('ageout_time', (YLeaf(YType.uint32, 'ageout-time'), ['int'])),
                            ])
                            self.timeout = None
                            self.ageout_time = None
                            self._segment_path = lambda: "finwait-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.FinwaitTime, ['timeout', 'ageout_time'], name, value)


                    class HalfClose(Entity):
                        """
                        Specify tcp halfclose reset RST transmission on/off
                        
                        .. attribute:: reset
                        
                        	Specify tcp halfclose reset RST transmission on/off
                        	**type**\:  :py:class:`Reset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.HalfClose.Reset>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Tcp.HalfClose, self).__init__()

                            self.yang_name = "half-close"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reset", ("reset", Native.ParameterMap.Type.Inspect.Tcp.HalfClose.Reset))])
                            self._leafs = OrderedDict()

                            self.reset = Native.ParameterMap.Type.Inspect.Tcp.HalfClose.Reset()
                            self.reset.parent = self
                            self._children_name_map["reset"] = "reset"
                            self._segment_path = lambda: "half-close"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.HalfClose, [], name, value)


                        class Reset(Entity):
                            """
                            Specify tcp halfclose reset RST transmission on/off
                            
                            .. attribute:: off
                            
                            	Turn off tcp halfclose reset RST transmission
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Inspect.Tcp.HalfClose.Reset, self).__init__()

                                self.yang_name = "reset"
                                self.yang_parent_name = "half-close"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('off', (YLeaf(YType.empty, 'off'), ['Empty'])),
                                ])
                                self.off = None
                                self._segment_path = lambda: "reset"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.HalfClose.Reset, ['off'], name, value)


                    class HalfOpen(Entity):
                        """
                        Specify tcp halfopen reset RST transmission on/off
                        
                        .. attribute:: reset
                        
                        	Specify tcp halfopen reset RST transmission on/off
                        	**type**\:  :py:class:`Reset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.HalfOpen.Reset>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Tcp.HalfOpen, self).__init__()

                            self.yang_name = "half-open"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reset", ("reset", Native.ParameterMap.Type.Inspect.Tcp.HalfOpen.Reset))])
                            self._leafs = OrderedDict()

                            self.reset = Native.ParameterMap.Type.Inspect.Tcp.HalfOpen.Reset()
                            self.reset.parent = self
                            self._children_name_map["reset"] = "reset"
                            self._segment_path = lambda: "half-open"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.HalfOpen, [], name, value)


                        class Reset(Entity):
                            """
                            Specify tcp halfopen reset RST transmission on/off
                            
                            .. attribute:: off
                            
                            	Turn off tcp halfopen reset RST transmission
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Inspect.Tcp.HalfOpen.Reset, self).__init__()

                                self.yang_name = "reset"
                                self.yang_parent_name = "half-open"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('off', (YLeaf(YType.empty, 'off'), ['Empty'])),
                                ])
                                self.off = None
                                self._segment_path = lambda: "reset"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.HalfOpen.Reset, ['off'], name, value)


                    class Idle(Entity):
                        """
                        Specify tcp idle reset RST transmission on/off
                        
                        .. attribute:: reset
                        
                        	Specify tcp idle reset RST transmission on/off
                        	**type**\:  :py:class:`Reset <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.Idle.Reset>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Tcp.Idle, self).__init__()

                            self.yang_name = "idle"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reset", ("reset", Native.ParameterMap.Type.Inspect.Tcp.Idle.Reset))])
                            self._leafs = OrderedDict()

                            self.reset = Native.ParameterMap.Type.Inspect.Tcp.Idle.Reset()
                            self.reset.parent = self
                            self._children_name_map["reset"] = "reset"
                            self._segment_path = lambda: "idle"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.Idle, [], name, value)


                        class Reset(Entity):
                            """
                            Specify tcp idle reset RST transmission on/off
                            
                            .. attribute:: off
                            
                            	Turn off tcp idle reset RST transmission
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Inspect.Tcp.Idle.Reset, self).__init__()

                                self.yang_name = "reset"
                                self.yang_parent_name = "idle"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('off', (YLeaf(YType.empty, 'off'), ['Empty'])),
                                ])
                                self.off = None
                                self._segment_path = lambda: "reset"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.Idle.Reset, ['off'], name, value)


                    class IdleTime(Entity):
                        """
                        Specify idle timeout for tcp connections
                        
                        .. attribute:: timeout
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..2147483
                        
                        .. attribute:: ageout_time
                        
                        	Specify aggressive age\-out time for tcp
                        	**type**\: int
                        
                        	**range:** 1..2147483
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Tcp.IdleTime, self).__init__()

                            self.yang_name = "idle-time"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                                ('ageout_time', (YLeaf(YType.uint32, 'ageout-time'), ['int'])),
                            ])
                            self.timeout = None
                            self.ageout_time = None
                            self._segment_path = lambda: "idle-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.IdleTime, ['timeout', 'ageout_time'], name, value)


                    class MaxIncomplete(Entity):
                        """
                        Specify max half\-open connection per host
                        
                        .. attribute:: host
                        
                        	Specify max half\-open connection per host
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Tcp.MaxIncomplete.Host>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Tcp.MaxIncomplete, self).__init__()

                            self.yang_name = "max-incomplete"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.ParameterMap.Type.Inspect.Tcp.MaxIncomplete.Host))])
                            self._leafs = OrderedDict()

                            self.host = Native.ParameterMap.Type.Inspect.Tcp.MaxIncomplete.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"
                            self._segment_path = lambda: "max-incomplete"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.MaxIncomplete, [], name, value)


                        class Host(Entity):
                            """
                            Specify max half\-open connection per host
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: block_time
                            
                            	Specify the maximum time to block new connection attempts to host
                            	**type**\: int
                            
                            	**range:** 0..35791
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Inspect.Tcp.MaxIncomplete.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "max-incomplete"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('block_time', (YLeaf(YType.uint16, 'block-time'), ['int'])),
                                ])
                                self.value = None
                                self.block_time = None
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.MaxIncomplete.Host, ['value', 'block_time'], name, value)


                    class SynwaitTime(Entity):
                        """
                        Specify timeout for TCP connections after a SYN and no further data
                        
                        .. attribute:: timeout
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..2147483
                        
                        .. attribute:: ageout_time
                        
                        	Specify aggressive age\-out time for syn wait\-time
                        	**type**\: int
                        
                        	**range:** 1..2147483
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Tcp.SynwaitTime, self).__init__()

                            self.yang_name = "synwait-time"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                                ('ageout_time', (YLeaf(YType.uint32, 'ageout-time'), ['int'])),
                            ])
                            self.timeout = None
                            self.ageout_time = None
                            self._segment_path = lambda: "synwait-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.SynwaitTime, ['timeout', 'ageout_time'], name, value)


                    class WindowScaleEnforcement(Entity):
                        """
                        Specify tcp window scaling enforcement
                        
                        .. attribute:: loose
                        
                        	Loose enforcement
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Tcp.WindowScaleEnforcement, self).__init__()

                            self.yang_name = "window-scale-enforcement"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('loose', (YLeaf(YType.empty, 'loose'), ['Empty'])),
                            ])
                            self.loose = None
                            self._segment_path = lambda: "window-scale-enforcement"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Tcp.WindowScaleEnforcement, ['loose'], name, value)


                class Udp(Entity):
                    """
                    Config timeout values for udp flows
                    
                    .. attribute:: half_open
                    
                    	Config timeout values for udp half open flows
                    	**type**\:  :py:class:`HalfOpen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Udp.HalfOpen>`
                    
                    .. attribute:: idle_time
                    
                    	Specify idle timeout for udp
                    	**type**\:  :py:class:`IdleTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Udp.IdleTime>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Inspect.Udp, self).__init__()

                        self.yang_name = "udp"
                        self.yang_parent_name = "inspect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("half-open", ("half_open", Native.ParameterMap.Type.Inspect.Udp.HalfOpen)), ("idle-time", ("idle_time", Native.ParameterMap.Type.Inspect.Udp.IdleTime))])
                        self._leafs = OrderedDict()

                        self.half_open = Native.ParameterMap.Type.Inspect.Udp.HalfOpen()
                        self.half_open.parent = self
                        self._children_name_map["half_open"] = "half-open"

                        self.idle_time = Native.ParameterMap.Type.Inspect.Udp.IdleTime()
                        self.idle_time.parent = self
                        self._children_name_map["idle_time"] = "idle-time"
                        self._segment_path = lambda: "udp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Inspect.Udp, [], name, value)


                    class HalfOpen(Entity):
                        """
                        Config timeout values for udp half open flows
                        
                        .. attribute:: idle_time
                        
                        	Specify idle timeout for udp half open
                        	**type**\:  :py:class:`IdleTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Inspect.Udp.HalfOpen.IdleTime>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Udp.HalfOpen, self).__init__()

                            self.yang_name = "half-open"
                            self.yang_parent_name = "udp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("idle-time", ("idle_time", Native.ParameterMap.Type.Inspect.Udp.HalfOpen.IdleTime))])
                            self._leafs = OrderedDict()

                            self.idle_time = Native.ParameterMap.Type.Inspect.Udp.HalfOpen.IdleTime()
                            self.idle_time.parent = self
                            self._children_name_map["idle_time"] = "idle-time"
                            self._segment_path = lambda: "half-open"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Udp.HalfOpen, [], name, value)


                        class IdleTime(Entity):
                            """
                            Specify idle timeout for udp half open
                            
                            .. attribute:: timeout
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..2147483
                            
                            .. attribute:: ageout_time
                            
                            	Specify aggressive age\-out time for udp half open
                            	**type**\: int
                            
                            	**range:** 1..2147483
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Inspect.Udp.HalfOpen.IdleTime, self).__init__()

                                self.yang_name = "idle-time"
                                self.yang_parent_name = "half-open"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                                    ('ageout_time', (YLeaf(YType.uint32, 'ageout-time'), ['int'])),
                                ])
                                self.timeout = None
                                self.ageout_time = None
                                self._segment_path = lambda: "idle-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Inspect.Udp.HalfOpen.IdleTime, ['timeout', 'ageout_time'], name, value)


                    class IdleTime(Entity):
                        """
                        Specify idle timeout for udp
                        
                        .. attribute:: timeout
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..2147483
                        
                        .. attribute:: ageout_time
                        
                        	Specify aggressive age\-out time for udp
                        	**type**\: int
                        
                        	**range:** 1..2147483
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Inspect.Udp.IdleTime, self).__init__()

                            self.yang_name = "idle-time"
                            self.yang_parent_name = "udp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                                ('ageout_time', (YLeaf(YType.uint32, 'ageout-time'), ['int'])),
                            ])
                            self.timeout = None
                            self.ageout_time = None
                            self._segment_path = lambda: "idle-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Inspect.Udp.IdleTime, ['timeout', 'ageout_time'], name, value)


                class ZoneMismatch(Entity):
                    """
                    Config zone\-mismatch option
                    
                    .. attribute:: drop
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Inspect.ZoneMismatch, self).__init__()

                        self.yang_name = "zone-mismatch"
                        self.yang_parent_name = "inspect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                        ])
                        self.drop = None
                        self._segment_path = lambda: "zone-mismatch"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Inspect.ZoneMismatch, ['drop'], name, value)


            class InspectGlobalDeprecate(Entity):
                """
                
                
                .. attribute:: inspect
                
                	inspect parameter\-map
                	**type**\:  :py:class:`Inspect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.ParameterMap.Type.InspectGlobalDeprecate, self).__init__()

                    self.yang_name = "inspect-global-deprecate"
                    self.yang_parent_name = "type"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("inspect", ("inspect", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect))])
                    self._leafs = OrderedDict()

                    self.inspect = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect()
                    self.inspect.parent = self
                    self._children_name_map["inspect"] = "inspect"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:inspect-global-deprecate"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate, [], name, value)


                class Inspect(Entity):
                    """
                    inspect parameter\-map
                    
                    .. attribute:: global_
                    
                    	inspect global parameter\-map
                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect, self).__init__()

                        self.yang_name = "inspect"
                        self.yang_parent_name = "inspect-global-deprecate"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("global", ("global_", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global))])
                        self._leafs = OrderedDict()

                        self.global_ = None
                        self._children_name_map["global_"] = "global"
                        self._segment_path = lambda: "inspect"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect, [], name, value)


                    class Global(Entity):
                        """
                        inspect global parameter\-map
                        
                        .. attribute:: alert
                        
                        	Turn on/off alert
                        	**type**\:  :py:class:`Alert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Alert>`
                        
                        .. attribute:: lisp
                        
                        	Turn on LISP options
                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Lisp>`
                        
                        .. attribute:: log
                        
                        	Configure inspect logging parameters
                        	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log>`
                        
                        .. attribute:: max_incomplete
                        
                        	Specify max half\-open connection
                        	**type**\:  :py:class:`MaxIncomplete <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete>`
                        
                        .. attribute:: multi_tenancy
                        
                        	Enable multi\-tenancy
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: per_box
                        
                        	Configure per\-box attributes
                        	**type**\:  :py:class:`PerBox <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox>`
                        
                        .. attribute:: session
                        
                        	Configure session total parameter
                        	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Session>`
                        
                        .. attribute:: tcp
                        
                        	Configure tcp syn\-flood limit
                        	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Tcp>`
                        
                        .. attribute:: vrf
                        
                        	vrf binding with parameter map
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Vrf>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "inspect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("alert", ("alert", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Alert)), ("lisp", ("lisp", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Lisp)), ("log", ("log", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log)), ("max-incomplete", ("max_incomplete", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete)), ("per-box", ("per_box", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox)), ("session", ("session", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Session)), ("tcp", ("tcp", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Tcp)), ("vrf", ("vrf", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Vrf))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('multi_tenancy', (YLeaf(YType.empty, 'multi-tenancy'), ['Empty'])),
                            ])
                            self.multi_tenancy = None

                            self.alert = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Alert()
                            self.alert.parent = self
                            self._children_name_map["alert"] = "alert"

                            self.lisp = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Lisp()
                            self.lisp.parent = self
                            self._children_name_map["lisp"] = "lisp"

                            self.log = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log()
                            self.log.parent = self
                            self._children_name_map["log"] = "log"

                            self.max_incomplete = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete()
                            self.max_incomplete.parent = self
                            self._children_name_map["max_incomplete"] = "max-incomplete"

                            self.per_box = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox()
                            self.per_box.parent = self
                            self._children_name_map["per_box"] = "per-box"

                            self.session = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Session()
                            self.session.parent = self
                            self._children_name_map["session"] = "session"

                            self.tcp = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Tcp()
                            self.tcp.parent = self
                            self._children_name_map["tcp"] = "tcp"

                            self.vrf = YList(self)
                            self._segment_path = lambda: "global"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global, ['multi_tenancy'], name, value)


                        class Alert(Entity):
                            """
                            Turn on/off alert
                            
                            .. attribute:: on
                            
                            	Turn on alert
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Alert, self).__init__()

                                self.yang_name = "alert"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                                ])
                                self.on = None
                                self._segment_path = lambda: "alert"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Alert, ['on'], name, value)


                        class Lisp(Entity):
                            """
                            Turn on LISP options
                            
                            .. attribute:: inner_packet_inspection
                            
                            	inner\-packet\-inspection
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Lisp, self).__init__()

                                self.yang_name = "lisp"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('inner_packet_inspection', (YLeaf(YType.empty, 'inner-packet-inspection'), ['Empty'])),
                                ])
                                self.inner_packet_inspection = None
                                self._segment_path = lambda: "lisp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Lisp, ['inner_packet_inspection'], name, value)


                        class Log(Entity):
                            """
                            Configure inspect logging parameters
                            
                            .. attribute:: dropped_packets
                            
                            	Log dropped packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: flow_export
                            
                            	Configure inspect external logging parameters
                            	**type**\:  :py:class:`FlowExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log, self).__init__()

                                self.yang_name = "log"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("flow-export", ("flow_export", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport))])
                                self._leafs = OrderedDict([
                                    ('dropped_packets', (YLeaf(YType.empty, 'dropped-packets'), ['Empty'])),
                                ])
                                self.dropped_packets = None

                                self.flow_export = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport()
                                self.flow_export.parent = self
                                self._children_name_map["flow_export"] = "flow-export"
                                self._segment_path = lambda: "log"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log, ['dropped_packets'], name, value)


                            class FlowExport(Entity):
                                """
                                Configure inspect external logging parameters
                                
                                .. attribute:: template
                                
                                	Configure record template parameters
                                	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.Template>`
                                
                                .. attribute:: v9
                                
                                	Netflow version 9
                                	**type**\:  :py:class:`V9 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport, self).__init__()

                                    self.yang_name = "flow-export"
                                    self.yang_parent_name = "log"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("template", ("template", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.Template)), ("v9", ("v9", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9))])
                                    self._leafs = OrderedDict()

                                    self.template = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.Template()
                                    self.template.parent = self
                                    self._children_name_map["template"] = "template"

                                    self.v9 = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9()
                                    self.v9.parent = self
                                    self._children_name_map["v9"] = "v9"
                                    self._segment_path = lambda: "flow-export"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/log/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport, [], name, value)


                                class Template(Entity):
                                    """
                                    Configure record template parameters
                                    
                                    .. attribute:: timeout_rate
                                    
                                    	Rate to resend the template in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.Template, self).__init__()

                                        self.yang_name = "template"
                                        self.yang_parent_name = "flow-export"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('timeout_rate', (YLeaf(YType.uint32, 'timeout-rate'), ['int'])),
                                        ])
                                        self.timeout_rate = None
                                        self._segment_path = lambda: "template"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/log/flow-export/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.Template, ['timeout_rate'], name, value)


                                class V9(Entity):
                                    """
                                    Netflow version 9
                                    
                                    .. attribute:: udp
                                    
                                    	Use UDP to export records
                                    	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9.Udp>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9, self).__init__()

                                        self.yang_name = "v9"
                                        self.yang_parent_name = "flow-export"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("udp", ("udp", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9.Udp))])
                                        self._leafs = OrderedDict()

                                        self.udp = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9.Udp()
                                        self.udp.parent = self
                                        self._children_name_map["udp"] = "udp"
                                        self._segment_path = lambda: "v9"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/log/flow-export/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9, [], name, value)


                                    class Udp(Entity):
                                        """
                                        Use UDP to export records
                                        
                                        .. attribute:: destination
                                        
                                        	Specify the flow\-export destination
                                        	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9.Udp.Destination>`
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9.Udp, self).__init__()

                                            self.yang_name = "udp"
                                            self.yang_parent_name = "v9"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("destination", ("destination", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9.Udp.Destination))])
                                            self._leafs = OrderedDict()

                                            self.destination = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9.Udp.Destination()
                                            self.destination.parent = self
                                            self._children_name_map["destination"] = "destination"
                                            self._segment_path = lambda: "udp"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/log/flow-export/v9/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9.Udp, [], name, value)


                                        class Destination(Entity):
                                            """
                                            Specify the flow\-export destination
                                            
                                            .. attribute:: dst_ip
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: dst_port
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-policy'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9.Udp.Destination, self).__init__()

                                                self.yang_name = "destination"
                                                self.yang_parent_name = "udp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dst_ip', (YLeaf(YType.str, 'dst-ip'), ['str'])),
                                                    ('dst_port', (YLeaf(YType.uint16, 'dst-port'), ['int'])),
                                                ])
                                                self.dst_ip = None
                                                self.dst_port = None
                                                self._segment_path = lambda: "destination"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/log/flow-export/v9/udp/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Log.FlowExport.V9.Udp.Destination, ['dst_ip', 'dst_port'], name, value)


                        class MaxIncomplete(Entity):
                            """
                            Specify max half\-open connection
                            
                            .. attribute:: half_open_sessions
                            
                            	
                            	**type**\:  :py:class:`HalfOpenSessions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete.HalfOpenSessions>`
                            
                            .. attribute:: icmp
                            
                            	Specify max half\-open ICMP connections
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: tcp
                            
                            	Specify max half\-open TCP connections
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: udp
                            
                            	Specify max half\-open UDP connections
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete, self).__init__()

                                self.yang_name = "max-incomplete"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("half-open-sessions", ("half_open_sessions", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete.HalfOpenSessions))])
                                self._leafs = OrderedDict([
                                    ('icmp', (YLeaf(YType.uint32, 'icmp'), ['int'])),
                                    ('tcp', (YLeaf(YType.uint32, 'tcp'), ['int'])),
                                    ('udp', (YLeaf(YType.uint32, 'udp'), ['int'])),
                                ])
                                self.icmp = None
                                self.tcp = None
                                self.udp = None

                                self.half_open_sessions = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete.HalfOpenSessions()
                                self.half_open_sessions.parent = self
                                self._children_name_map["half_open_sessions"] = "half-open-sessions"
                                self._segment_path = lambda: "max-incomplete"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete, ['icmp', 'tcp', 'udp'], name, value)


                            class HalfOpenSessions(Entity):
                                """
                                
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: aggressive_aging
                                
                                	Aggressive Aging parameters
                                	**type**\:  :py:class:`AggressiveAging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete.HalfOpenSessions.AggressiveAging>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete.HalfOpenSessions, self).__init__()

                                    self.yang_name = "half-open-sessions"
                                    self.yang_parent_name = "max-incomplete"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aggressive-aging", ("aggressive_aging", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete.HalfOpenSessions.AggressiveAging))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                    ])
                                    self.number = None

                                    self.aggressive_aging = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete.HalfOpenSessions.AggressiveAging()
                                    self.aggressive_aging.parent = self
                                    self._children_name_map["aggressive_aging"] = "aggressive-aging"
                                    self._segment_path = lambda: "half-open-sessions"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/max-incomplete/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete.HalfOpenSessions, ['number'], name, value)


                                class AggressiveAging(Entity):
                                    """
                                    Aggressive Aging parameters
                                    
                                    .. attribute:: high
                                    
                                    	Specify the high watermark for aggressive\-aging
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: low
                                    
                                    	Specify the low watermark for aggressive\-aging
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: high_percent
                                    
                                    	Specify the high watermark for aggressive\-aging in percents
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: low_percent
                                    
                                    	Specify the low watermark for aggressive\-aging in percents
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete.HalfOpenSessions.AggressiveAging, self).__init__()

                                        self.yang_name = "aggressive-aging"
                                        self.yang_parent_name = "half-open-sessions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high', (YLeaf(YType.uint64, 'high'), ['int'])),
                                            ('low', (YLeaf(YType.uint64, 'low'), ['int'])),
                                            ('high_percent', (YLeaf(YType.uint8, 'high-percent'), ['int'])),
                                            ('low_percent', (YLeaf(YType.uint8, 'low-percent'), ['int'])),
                                        ])
                                        self.high = None
                                        self.low = None
                                        self.high_percent = None
                                        self.low_percent = None
                                        self._segment_path = lambda: "aggressive-aging"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/max-incomplete/half-open-sessions/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.MaxIncomplete.HalfOpenSessions.AggressiveAging, ['high', 'low', 'high_percent', 'low_percent'], name, value)


                        class PerBox(Entity):
                            """
                            Configure per\-box attributes
                            
                            .. attribute:: aggressive_aging
                            
                            	Aggressive Aging parameters
                            	**type**\:  :py:class:`AggressiveAging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.AggressiveAging>`
                            
                            .. attribute:: max_incomplete
                            
                            	Specify max half\-open connection
                            	**type**\:  :py:class:`MaxIncomplete <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete>`
                            
                            .. attribute:: tcp
                            
                            	Configure tcp syn\-flood limit
                            	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.Tcp>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox, self).__init__()

                                self.yang_name = "per-box"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aggressive-aging", ("aggressive_aging", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.AggressiveAging)), ("max-incomplete", ("max_incomplete", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete)), ("tcp", ("tcp", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.Tcp))])
                                self._leafs = OrderedDict()

                                self.aggressive_aging = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.AggressiveAging()
                                self.aggressive_aging.parent = self
                                self._children_name_map["aggressive_aging"] = "aggressive-aging"

                                self.max_incomplete = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete()
                                self.max_incomplete.parent = self
                                self._children_name_map["max_incomplete"] = "max-incomplete"

                                self.tcp = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.Tcp()
                                self.tcp.parent = self
                                self._children_name_map["tcp"] = "tcp"
                                self._segment_path = lambda: "per-box"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox, [], name, value)


                            class AggressiveAging(Entity):
                                """
                                Aggressive Aging parameters
                                
                                .. attribute:: high
                                
                                	Specify the high watermark for aggressive\-aging
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: low
                                
                                	Specify the low watermark for aggressive\-aging
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: high_percent
                                
                                	Specify the high watermark for aggressive\-aging in percents
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: low_percent
                                
                                	Specify the low watermark for aggressive\-aging in percents
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.AggressiveAging, self).__init__()

                                    self.yang_name = "aggressive-aging"
                                    self.yang_parent_name = "per-box"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('high', (YLeaf(YType.uint64, 'high'), ['int'])),
                                        ('low', (YLeaf(YType.uint64, 'low'), ['int'])),
                                        ('high_percent', (YLeaf(YType.uint8, 'high-percent'), ['int'])),
                                        ('low_percent', (YLeaf(YType.uint8, 'low-percent'), ['int'])),
                                    ])
                                    self.high = None
                                    self.low = None
                                    self.high_percent = None
                                    self.low_percent = None
                                    self._segment_path = lambda: "aggressive-aging"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/per-box/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.AggressiveAging, ['high', 'low', 'high_percent', 'low_percent'], name, value)


                            class MaxIncomplete(Entity):
                                """
                                Specify max half\-open connection
                                
                                .. attribute:: half_open_sessions
                                
                                	
                                	**type**\:  :py:class:`HalfOpenSessions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete.HalfOpenSessions>`
                                
                                .. attribute:: icmp
                                
                                	Specify max half\-open ICMP connections
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: tcp
                                
                                	Specify max half\-open TCP connections
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: udp
                                
                                	Specify max half\-open UDP connections
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete, self).__init__()

                                    self.yang_name = "max-incomplete"
                                    self.yang_parent_name = "per-box"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("half-open-sessions", ("half_open_sessions", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete.HalfOpenSessions))])
                                    self._leafs = OrderedDict([
                                        ('icmp', (YLeaf(YType.uint32, 'icmp'), ['int'])),
                                        ('tcp', (YLeaf(YType.uint32, 'tcp'), ['int'])),
                                        ('udp', (YLeaf(YType.uint32, 'udp'), ['int'])),
                                    ])
                                    self.icmp = None
                                    self.tcp = None
                                    self.udp = None

                                    self.half_open_sessions = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete.HalfOpenSessions()
                                    self.half_open_sessions.parent = self
                                    self._children_name_map["half_open_sessions"] = "half-open-sessions"
                                    self._segment_path = lambda: "max-incomplete"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/per-box/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete, ['icmp', 'tcp', 'udp'], name, value)


                                class HalfOpenSessions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: aggressive_aging
                                    
                                    	Aggressive Aging parameters
                                    	**type**\:  :py:class:`AggressiveAging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete.HalfOpenSessions.AggressiveAging>`
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete.HalfOpenSessions, self).__init__()

                                        self.yang_name = "half-open-sessions"
                                        self.yang_parent_name = "max-incomplete"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("aggressive-aging", ("aggressive_aging", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete.HalfOpenSessions.AggressiveAging))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.aggressive_aging = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete.HalfOpenSessions.AggressiveAging()
                                        self.aggressive_aging.parent = self
                                        self._children_name_map["aggressive_aging"] = "aggressive-aging"
                                        self._segment_path = lambda: "half-open-sessions"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/per-box/max-incomplete/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete.HalfOpenSessions, ['number'], name, value)


                                    class AggressiveAging(Entity):
                                        """
                                        Aggressive Aging parameters
                                        
                                        .. attribute:: high
                                        
                                        	Specify the high watermark for aggressive\-aging
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: low
                                        
                                        	Specify the low watermark for aggressive\-aging
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: high_percent
                                        
                                        	Specify the high watermark for aggressive\-aging in percents
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: low_percent
                                        
                                        	Specify the low watermark for aggressive\-aging in percents
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-policy'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete.HalfOpenSessions.AggressiveAging, self).__init__()

                                            self.yang_name = "aggressive-aging"
                                            self.yang_parent_name = "half-open-sessions"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('high', (YLeaf(YType.uint64, 'high'), ['int'])),
                                                ('low', (YLeaf(YType.uint64, 'low'), ['int'])),
                                                ('high_percent', (YLeaf(YType.uint8, 'high-percent'), ['int'])),
                                                ('low_percent', (YLeaf(YType.uint8, 'low-percent'), ['int'])),
                                            ])
                                            self.high = None
                                            self.low = None
                                            self.high_percent = None
                                            self.low_percent = None
                                            self._segment_path = lambda: "aggressive-aging"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/per-box/max-incomplete/half-open-sessions/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.MaxIncomplete.HalfOpenSessions.AggressiveAging, ['high', 'low', 'high_percent', 'low_percent'], name, value)


                            class Tcp(Entity):
                                """
                                Configure tcp syn\-flood limit
                                
                                .. attribute:: syn_flood
                                
                                	syn\-flood limit
                                	**type**\:  :py:class:`SynFlood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.Tcp.SynFlood>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.Tcp, self).__init__()

                                    self.yang_name = "tcp"
                                    self.yang_parent_name = "per-box"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("syn-flood", ("syn_flood", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.Tcp.SynFlood))])
                                    self._leafs = OrderedDict()

                                    self.syn_flood = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.Tcp.SynFlood()
                                    self.syn_flood.parent = self
                                    self._children_name_map["syn_flood"] = "syn-flood"
                                    self._segment_path = lambda: "tcp"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/per-box/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.Tcp, [], name, value)


                                class SynFlood(Entity):
                                    """
                                    syn\-flood limit
                                    
                                    .. attribute:: limit
                                    
                                    	syn\-flood limit
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.Tcp.SynFlood, self).__init__()

                                        self.yang_name = "syn-flood"
                                        self.yang_parent_name = "tcp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ])
                                        self.limit = None
                                        self._segment_path = lambda: "syn-flood"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/per-box/tcp/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.PerBox.Tcp.SynFlood, ['limit'], name, value)


                        class Session(Entity):
                            """
                            Configure session total parameter
                            
                            .. attribute:: packet
                            
                            	Simultaneous packets per session
                            	**type**\: int
                            
                            	**range:** 25..100
                            
                            .. attribute:: total
                            
                            	session total
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Session, self).__init__()

                                self.yang_name = "session"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('packet', (YLeaf(YType.uint8, 'packet'), ['int'])),
                                    ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                ])
                                self.packet = None
                                self.total = None
                                self._segment_path = lambda: "session"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Session, ['packet', 'total'], name, value)


                        class Tcp(Entity):
                            """
                            Configure tcp syn\-flood limit
                            
                            .. attribute:: syn_flood
                            
                            	syn\-flood limit
                            	**type**\:  :py:class:`SynFlood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Tcp.SynFlood>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Tcp, self).__init__()

                                self.yang_name = "tcp"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("syn-flood", ("syn_flood", Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Tcp.SynFlood))])
                                self._leafs = OrderedDict()

                                self.syn_flood = Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Tcp.SynFlood()
                                self.syn_flood.parent = self
                                self._children_name_map["syn_flood"] = "syn-flood"
                                self._segment_path = lambda: "tcp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Tcp, [], name, value)


                            class SynFlood(Entity):
                                """
                                syn\-flood limit
                                
                                .. attribute:: limit
                                
                                	syn\-flood limit
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Tcp.SynFlood, self).__init__()

                                    self.yang_name = "syn-flood"
                                    self.yang_parent_name = "tcp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ])
                                    self.limit = None
                                    self._segment_path = lambda: "syn-flood"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/tcp/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Tcp.SynFlood, ['limit'], name, value)


                        class Vrf(Entity):
                            """
                            vrf binding with parameter map
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..32
                            
                            .. attribute:: inspect
                            
                            	vrf binding with parameter map
                            	**type**\: str
                            
                            	**length:** 1..256
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('inspect', (YLeaf(YType.str, 'inspect'), ['str'])),
                                ])
                                self.id = None
                                self.inspect = None
                                self._segment_path = lambda: "vrf" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global-deprecate/inspect/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobalDeprecate.Inspect.Global.Vrf, ['id', 'inspect'], name, value)


            class InspectGlobal(Entity):
                """
                inspect global parameter\-map
                
                .. attribute:: aggressive_aging
                
                	Aggressive Aging parameters
                	**type**\:  :py:class:`AggressiveAging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.AggressiveAging>`
                
                .. attribute:: alert
                
                	Turn on/off alert
                	**type**\:  :py:class:`Alert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Alert>`
                
                .. attribute:: icmp_unreachable_allow
                
                	ICMP unreachable packets are allowed
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: inspect
                
                	vrf binding with parameter map
                	**type**\:  :py:class:`Inspect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Inspect>`
                
                .. attribute:: lisp
                
                	Turn on LISP options
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Lisp>`
                
                .. attribute:: log
                
                	Configure inspect logging parameters
                	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Log>`
                
                .. attribute:: max_incomplete
                
                	Specify max half\-open connection
                	**type**\:  :py:class:`MaxIncomplete <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.MaxIncomplete>`
                
                .. attribute:: multi_tenancy
                
                	Enable multi\-tenancy
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: tcp
                
                	Configure tcp syn\-flood limit
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Tcp>`
                
                .. attribute:: zone_mismatch
                
                	Config zone\-mismatch option
                	**type**\:  :py:class:`ZoneMismatch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.ZoneMismatch>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.ParameterMap.Type.InspectGlobal, self).__init__()

                    self.yang_name = "inspect-global"
                    self.yang_parent_name = "type"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("aggressive-aging", ("aggressive_aging", Native.ParameterMap.Type.InspectGlobal.AggressiveAging)), ("alert", ("alert", Native.ParameterMap.Type.InspectGlobal.Alert)), ("inspect", ("inspect", Native.ParameterMap.Type.InspectGlobal.Inspect)), ("lisp", ("lisp", Native.ParameterMap.Type.InspectGlobal.Lisp)), ("log", ("log", Native.ParameterMap.Type.InspectGlobal.Log)), ("max-incomplete", ("max_incomplete", Native.ParameterMap.Type.InspectGlobal.MaxIncomplete)), ("tcp", ("tcp", Native.ParameterMap.Type.InspectGlobal.Tcp)), ("zone-mismatch", ("zone_mismatch", Native.ParameterMap.Type.InspectGlobal.ZoneMismatch))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('icmp_unreachable_allow', (YLeaf(YType.empty, 'icmp-unreachable-allow'), ['Empty'])),
                        ('multi_tenancy', (YLeaf(YType.empty, 'multi-tenancy'), ['Empty'])),
                    ])
                    self.icmp_unreachable_allow = None
                    self.multi_tenancy = None

                    self.aggressive_aging = Native.ParameterMap.Type.InspectGlobal.AggressiveAging()
                    self.aggressive_aging.parent = self
                    self._children_name_map["aggressive_aging"] = "aggressive-aging"

                    self.alert = Native.ParameterMap.Type.InspectGlobal.Alert()
                    self.alert.parent = self
                    self._children_name_map["alert"] = "alert"

                    self.inspect = Native.ParameterMap.Type.InspectGlobal.Inspect()
                    self.inspect.parent = self
                    self._children_name_map["inspect"] = "inspect"

                    self.lisp = Native.ParameterMap.Type.InspectGlobal.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "lisp"

                    self.log = Native.ParameterMap.Type.InspectGlobal.Log()
                    self.log.parent = self
                    self._children_name_map["log"] = "log"

                    self.max_incomplete = Native.ParameterMap.Type.InspectGlobal.MaxIncomplete()
                    self.max_incomplete.parent = self
                    self._children_name_map["max_incomplete"] = "max-incomplete"

                    self.tcp = Native.ParameterMap.Type.InspectGlobal.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.zone_mismatch = Native.ParameterMap.Type.InspectGlobal.ZoneMismatch()
                    self.zone_mismatch.parent = self
                    self._children_name_map["zone_mismatch"] = "zone-mismatch"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:inspect-global"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ParameterMap.Type.InspectGlobal, ['icmp_unreachable_allow', 'multi_tenancy'], name, value)


                class AggressiveAging(Entity):
                    """
                    Aggressive Aging parameters
                    
                    .. attribute:: high
                    
                    	Specify the high watermark for aggressive\-aging
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: low
                    
                    	Specify the low watermark for aggressive\-aging
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: high_percent
                    
                    	Specify the high watermark for aggressive\-aging in percents
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    .. attribute:: low_percent
                    
                    	Specify the low watermark for aggressive\-aging in percents
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectGlobal.AggressiveAging, self).__init__()

                        self.yang_name = "aggressive-aging"
                        self.yang_parent_name = "inspect-global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('high', (YLeaf(YType.uint64, 'high'), ['int'])),
                            ('low', (YLeaf(YType.uint64, 'low'), ['int'])),
                            ('high_percent', (YLeaf(YType.uint8, 'high-percent'), ['int'])),
                            ('low_percent', (YLeaf(YType.uint8, 'low-percent'), ['int'])),
                        ])
                        self.high = None
                        self.low = None
                        self.high_percent = None
                        self.low_percent = None
                        self._segment_path = lambda: "aggressive-aging"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.AggressiveAging, ['high', 'low', 'high_percent', 'low_percent'], name, value)


                class Alert(Entity):
                    """
                    Turn on/off alert
                    
                    .. attribute:: on
                    
                    	Turn on alert
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectGlobal.Alert, self).__init__()

                        self.yang_name = "alert"
                        self.yang_parent_name = "inspect-global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                        ])
                        self.on = None
                        self._segment_path = lambda: "alert"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Alert, ['on'], name, value)


                class Inspect(Entity):
                    """
                    vrf binding with parameter map
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..256
                    
                    .. attribute:: vrf
                    
                    	vrf binding with parameter map
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Inspect.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectGlobal.Inspect, self).__init__()

                        self.yang_name = "inspect"
                        self.yang_parent_name = "inspect-global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.ParameterMap.Type.InspectGlobal.Inspect.Vrf))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.vrf = YList(self)
                        self._segment_path = lambda: "inspect"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Inspect, ['name'], name, value)


                    class Vrf(Entity):
                        """
                        vrf binding with parameter map
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        	**length:** 1..256
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.InspectGlobal.Inspect.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "inspect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.id = None
                            self.name = None
                            self._segment_path = lambda: "vrf" + "[id='" + str(self.id) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/inspect/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Inspect.Vrf, ['id', 'name'], name, value)


                class Lisp(Entity):
                    """
                    Turn on LISP options
                    
                    .. attribute:: inner_packet_inspection
                    
                    	inner\-packet\-inspection
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectGlobal.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "inspect-global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inner_packet_inspection', (YLeaf(YType.empty, 'inner-packet-inspection'), ['Empty'])),
                        ])
                        self.inner_packet_inspection = None
                        self._segment_path = lambda: "lisp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Lisp, ['inner_packet_inspection'], name, value)


                class Log(Entity):
                    """
                    Configure inspect logging parameters
                    
                    .. attribute:: dropped_packets
                    
                    	Log dropped packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: flow_export
                    
                    	Configure inspect external logging parameters
                    	**type**\:  :py:class:`FlowExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Log.FlowExport>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectGlobal.Log, self).__init__()

                        self.yang_name = "log"
                        self.yang_parent_name = "inspect-global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("flow-export", ("flow_export", Native.ParameterMap.Type.InspectGlobal.Log.FlowExport))])
                        self._leafs = OrderedDict([
                            ('dropped_packets', (YLeaf(YType.empty, 'dropped-packets'), ['Empty'])),
                        ])
                        self.dropped_packets = None

                        self.flow_export = Native.ParameterMap.Type.InspectGlobal.Log.FlowExport()
                        self.flow_export.parent = self
                        self._children_name_map["flow_export"] = "flow-export"
                        self._segment_path = lambda: "log"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Log, ['dropped_packets'], name, value)


                    class FlowExport(Entity):
                        """
                        Configure inspect external logging parameters
                        
                        .. attribute:: template
                        
                        	Configure record template parameters
                        	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.Template>`
                        
                        .. attribute:: v9
                        
                        	Netflow version 9
                        	**type**\:  :py:class:`V9 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.InspectGlobal.Log.FlowExport, self).__init__()

                            self.yang_name = "flow-export"
                            self.yang_parent_name = "log"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("template", ("template", Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.Template)), ("v9", ("v9", Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9))])
                            self._leafs = OrderedDict()

                            self.template = Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.Template()
                            self.template.parent = self
                            self._children_name_map["template"] = "template"

                            self.v9 = Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9()
                            self.v9.parent = self
                            self._children_name_map["v9"] = "v9"
                            self._segment_path = lambda: "flow-export"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/log/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Log.FlowExport, [], name, value)


                        class Template(Entity):
                            """
                            Configure record template parameters
                            
                            .. attribute:: timeout_rate
                            
                            	Rate to resend the template in seconds
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.Template, self).__init__()

                                self.yang_name = "template"
                                self.yang_parent_name = "flow-export"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('timeout_rate', (YLeaf(YType.uint32, 'timeout-rate'), ['int'])),
                                ])
                                self.timeout_rate = None
                                self._segment_path = lambda: "template"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/log/flow-export/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.Template, ['timeout_rate'], name, value)


                        class V9(Entity):
                            """
                            Netflow version 9
                            
                            .. attribute:: udp
                            
                            	Use UDP to export records
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9.Udp>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9, self).__init__()

                                self.yang_name = "v9"
                                self.yang_parent_name = "flow-export"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9.Udp))])
                                self._leafs = OrderedDict()

                                self.udp = Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "v9"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/log/flow-export/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9, [], name, value)


                            class Udp(Entity):
                                """
                                Use UDP to export records
                                
                                .. attribute:: destination
                                
                                	Specify the flow\-export destination
                                	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9.Udp.Destination>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "v9"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("destination", ("destination", Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9.Udp.Destination))])
                                    self._leafs = OrderedDict()

                                    self.destination = Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9.Udp.Destination()
                                    self.destination.parent = self
                                    self._children_name_map["destination"] = "destination"
                                    self._segment_path = lambda: "udp"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/log/flow-export/v9/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9.Udp, [], name, value)


                                class Destination(Entity):
                                    """
                                    Specify the flow\-export destination
                                    
                                    .. attribute:: dst_ip
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: dst_port
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9.Udp.Destination, self).__init__()

                                        self.yang_name = "destination"
                                        self.yang_parent_name = "udp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dst_ip', (YLeaf(YType.str, 'dst-ip'), ['str'])),
                                            ('dst_port', (YLeaf(YType.uint16, 'dst-port'), ['int'])),
                                        ])
                                        self.dst_ip = None
                                        self.dst_port = None
                                        self._segment_path = lambda: "destination"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/log/flow-export/v9/udp/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Log.FlowExport.V9.Udp.Destination, ['dst_ip', 'dst_port'], name, value)


                class MaxIncomplete(Entity):
                    """
                    Specify max half\-open connection
                    
                    .. attribute:: half_open_sessions
                    
                    	
                    	**type**\:  :py:class:`HalfOpenSessions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.MaxIncomplete.HalfOpenSessions>`
                    
                    .. attribute:: icmp
                    
                    	Specify max half\-open ICMP connections
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: tcp
                    
                    	Specify max half\-open TCP connections
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: udp
                    
                    	Specify max half\-open UDP connections
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectGlobal.MaxIncomplete, self).__init__()

                        self.yang_name = "max-incomplete"
                        self.yang_parent_name = "inspect-global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("half-open-sessions", ("half_open_sessions", Native.ParameterMap.Type.InspectGlobal.MaxIncomplete.HalfOpenSessions))])
                        self._leafs = OrderedDict([
                            ('icmp', (YLeaf(YType.uint32, 'icmp'), ['int'])),
                            ('tcp', (YLeaf(YType.uint32, 'tcp'), ['int'])),
                            ('udp', (YLeaf(YType.uint32, 'udp'), ['int'])),
                        ])
                        self.icmp = None
                        self.tcp = None
                        self.udp = None

                        self.half_open_sessions = Native.ParameterMap.Type.InspectGlobal.MaxIncomplete.HalfOpenSessions()
                        self.half_open_sessions.parent = self
                        self._children_name_map["half_open_sessions"] = "half-open-sessions"
                        self._segment_path = lambda: "max-incomplete"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.MaxIncomplete, ['icmp', 'tcp', 'udp'], name, value)


                    class HalfOpenSessions(Entity):
                        """
                        
                        
                        .. attribute:: number
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: aggressive_aging
                        
                        	Aggressive Aging parameters
                        	**type**\:  :py:class:`AggressiveAging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.MaxIncomplete.HalfOpenSessions.AggressiveAging>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.InspectGlobal.MaxIncomplete.HalfOpenSessions, self).__init__()

                            self.yang_name = "half-open-sessions"
                            self.yang_parent_name = "max-incomplete"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("aggressive-aging", ("aggressive_aging", Native.ParameterMap.Type.InspectGlobal.MaxIncomplete.HalfOpenSessions.AggressiveAging))])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                            ])
                            self.number = None

                            self.aggressive_aging = Native.ParameterMap.Type.InspectGlobal.MaxIncomplete.HalfOpenSessions.AggressiveAging()
                            self.aggressive_aging.parent = self
                            self._children_name_map["aggressive_aging"] = "aggressive-aging"
                            self._segment_path = lambda: "half-open-sessions"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/max-incomplete/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.MaxIncomplete.HalfOpenSessions, ['number'], name, value)


                        class AggressiveAging(Entity):
                            """
                            Aggressive Aging parameters
                            
                            .. attribute:: high
                            
                            	Specify the high watermark for aggressive\-aging
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: low
                            
                            	Specify the low watermark for aggressive\-aging
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: high_percent
                            
                            	Specify the high watermark for aggressive\-aging in percents
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: low_percent
                            
                            	Specify the low watermark for aggressive\-aging in percents
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectGlobal.MaxIncomplete.HalfOpenSessions.AggressiveAging, self).__init__()

                                self.yang_name = "aggressive-aging"
                                self.yang_parent_name = "half-open-sessions"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('high', (YLeaf(YType.uint64, 'high'), ['int'])),
                                    ('low', (YLeaf(YType.uint64, 'low'), ['int'])),
                                    ('high_percent', (YLeaf(YType.uint8, 'high-percent'), ['int'])),
                                    ('low_percent', (YLeaf(YType.uint8, 'low-percent'), ['int'])),
                                ])
                                self.high = None
                                self.low = None
                                self.high_percent = None
                                self.low_percent = None
                                self._segment_path = lambda: "aggressive-aging"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/max-incomplete/half-open-sessions/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.MaxIncomplete.HalfOpenSessions.AggressiveAging, ['high', 'low', 'high_percent', 'low_percent'], name, value)


                class Tcp(Entity):
                    """
                    Configure tcp syn\-flood limit
                    
                    .. attribute:: syn_flood
                    
                    	syn\-flood limit
                    	**type**\:  :py:class:`SynFlood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Tcp.SynFlood>`
                    
                    .. attribute:: window_scale_enforcement
                    
                    	Specify tcp window scaling enforcement
                    	**type**\:  :py:class:`WindowScaleEnforcement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectGlobal.Tcp.WindowScaleEnforcement>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectGlobal.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "inspect-global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("syn-flood", ("syn_flood", Native.ParameterMap.Type.InspectGlobal.Tcp.SynFlood)), ("window-scale-enforcement", ("window_scale_enforcement", Native.ParameterMap.Type.InspectGlobal.Tcp.WindowScaleEnforcement))])
                        self._leafs = OrderedDict()

                        self.syn_flood = Native.ParameterMap.Type.InspectGlobal.Tcp.SynFlood()
                        self.syn_flood.parent = self
                        self._children_name_map["syn_flood"] = "syn-flood"

                        self.window_scale_enforcement = Native.ParameterMap.Type.InspectGlobal.Tcp.WindowScaleEnforcement()
                        self.window_scale_enforcement.parent = self
                        self._children_name_map["window_scale_enforcement"] = "window-scale-enforcement"
                        self._segment_path = lambda: "tcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Tcp, [], name, value)


                    class SynFlood(Entity):
                        """
                        syn\-flood limit
                        
                        .. attribute:: limit
                        
                        	syn\-flood limit
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.InspectGlobal.Tcp.SynFlood, self).__init__()

                            self.yang_name = "syn-flood"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                            ])
                            self.limit = None
                            self._segment_path = lambda: "syn-flood"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/tcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Tcp.SynFlood, ['limit'], name, value)


                    class WindowScaleEnforcement(Entity):
                        """
                        Specify tcp window scaling enforcement
                        
                        .. attribute:: loose
                        
                        	Loose enforcement
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.InspectGlobal.Tcp.WindowScaleEnforcement, self).__init__()

                            self.yang_name = "window-scale-enforcement"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('loose', (YLeaf(YType.empty, 'loose'), ['Empty'])),
                            ])
                            self.loose = None
                            self._segment_path = lambda: "window-scale-enforcement"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/tcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.Tcp.WindowScaleEnforcement, ['loose'], name, value)


                class ZoneMismatch(Entity):
                    """
                    Config zone\-mismatch option
                    
                    .. attribute:: drop
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectGlobal.ZoneMismatch, self).__init__()

                        self.yang_name = "zone-mismatch"
                        self.yang_parent_name = "inspect-global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                        ])
                        self.drop = None
                        self._segment_path = lambda: "zone-mismatch"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:inspect-global/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectGlobal.ZoneMismatch, ['drop'], name, value)


            class InspectVrf(Entity):
                """
                inspect vrf parameter\-map
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                	**length:** 1..256
                
                .. attribute:: alert
                
                	Turn on/off alert
                	**type**\:  :py:class:`Alert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectVrf.Alert>`
                
                .. attribute:: max_incomplete
                
                	Specify max half\-open connection per VRF
                	**type**\:  :py:class:`MaxIncomplete <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectVrf.MaxIncomplete>`
                
                .. attribute:: session
                
                	Configure session total
                	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectVrf.Session>`
                
                .. attribute:: tcp
                
                	Configure tcp syn\-flood limit
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectVrf.Tcp>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.ParameterMap.Type.InspectVrf, self).__init__()

                    self.yang_name = "inspect-vrf"
                    self.yang_parent_name = "type"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("alert", ("alert", Native.ParameterMap.Type.InspectVrf.Alert)), ("max-incomplete", ("max_incomplete", Native.ParameterMap.Type.InspectVrf.MaxIncomplete)), ("session", ("session", Native.ParameterMap.Type.InspectVrf.Session)), ("tcp", ("tcp", Native.ParameterMap.Type.InspectVrf.Tcp))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.alert = Native.ParameterMap.Type.InspectVrf.Alert()
                    self.alert.parent = self
                    self._children_name_map["alert"] = "alert"

                    self.max_incomplete = Native.ParameterMap.Type.InspectVrf.MaxIncomplete()
                    self.max_incomplete.parent = self
                    self._children_name_map["max_incomplete"] = "max-incomplete"

                    self.session = Native.ParameterMap.Type.InspectVrf.Session()
                    self.session.parent = self
                    self._children_name_map["session"] = "session"

                    self.tcp = Native.ParameterMap.Type.InspectVrf.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:inspect-vrf" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ParameterMap.Type.InspectVrf, ['name'], name, value)


                class Alert(Entity):
                    """
                    Turn on/off alert
                    
                    .. attribute:: on
                    
                    	Turn on alert
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectVrf.Alert, self).__init__()

                        self.yang_name = "alert"
                        self.yang_parent_name = "inspect-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                        ])
                        self.on = None
                        self._segment_path = lambda: "alert"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectVrf.Alert, ['on'], name, value)


                class MaxIncomplete(Entity):
                    """
                    Specify max half\-open connection per VRF
                    
                    .. attribute:: half_open_sessions
                    
                    	
                    	**type**\:  :py:class:`HalfOpenSessions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectVrf.MaxIncomplete.HalfOpenSessions>`
                    
                    .. attribute:: icmp
                    
                    	Specify max half\-open ICMP connections per VRF
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: tcp
                    
                    	Specify max half\-open TCP connections per VRF
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: udp
                    
                    	Specify max half\-open UDP connections per VRF
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectVrf.MaxIncomplete, self).__init__()

                        self.yang_name = "max-incomplete"
                        self.yang_parent_name = "inspect-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("half-open-sessions", ("half_open_sessions", Native.ParameterMap.Type.InspectVrf.MaxIncomplete.HalfOpenSessions))])
                        self._leafs = OrderedDict([
                            ('icmp', (YLeaf(YType.uint32, 'icmp'), ['int'])),
                            ('tcp', (YLeaf(YType.uint32, 'tcp'), ['int'])),
                            ('udp', (YLeaf(YType.uint32, 'udp'), ['int'])),
                        ])
                        self.icmp = None
                        self.tcp = None
                        self.udp = None

                        self.half_open_sessions = Native.ParameterMap.Type.InspectVrf.MaxIncomplete.HalfOpenSessions()
                        self.half_open_sessions.parent = self
                        self._children_name_map["half_open_sessions"] = "half-open-sessions"
                        self._segment_path = lambda: "max-incomplete"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectVrf.MaxIncomplete, ['icmp', 'tcp', 'udp'], name, value)


                    class HalfOpenSessions(Entity):
                        """
                        
                        
                        .. attribute:: number
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.InspectVrf.MaxIncomplete.HalfOpenSessions, self).__init__()

                            self.yang_name = "half-open-sessions"
                            self.yang_parent_name = "max-incomplete"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                            ])
                            self.number = None
                            self._segment_path = lambda: "half-open-sessions"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.InspectVrf.MaxIncomplete.HalfOpenSessions, ['number'], name, value)


                class Session(Entity):
                    """
                    Configure session total
                    
                    .. attribute:: total
                    
                    	total
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectVrf.Session, self).__init__()

                        self.yang_name = "session"
                        self.yang_parent_name = "inspect-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                        ])
                        self.total = None
                        self._segment_path = lambda: "session"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectVrf.Session, ['total'], name, value)


                class Tcp(Entity):
                    """
                    Configure tcp syn\-flood limit
                    
                    .. attribute:: syn_flood
                    
                    	syn\-flood limit
                    	**type**\:  :py:class:`SynFlood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectVrf.Tcp.SynFlood>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectVrf.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "inspect-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("syn-flood", ("syn_flood", Native.ParameterMap.Type.InspectVrf.Tcp.SynFlood))])
                        self._leafs = OrderedDict()

                        self.syn_flood = Native.ParameterMap.Type.InspectVrf.Tcp.SynFlood()
                        self.syn_flood.parent = self
                        self._children_name_map["syn_flood"] = "syn-flood"
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectVrf.Tcp, [], name, value)


                    class SynFlood(Entity):
                        """
                        syn\-flood limit
                        
                        .. attribute:: limit
                        
                        	syn\-flood limit
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.InspectVrf.Tcp.SynFlood, self).__init__()

                            self.yang_name = "syn-flood"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                            ])
                            self.limit = None
                            self._segment_path = lambda: "syn-flood"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.InspectVrf.Tcp.SynFlood, ['limit'], name, value)


            class InspectZone(Entity):
                """
                inspect zone parameter\-map
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                	**length:** 1..256
                
                .. attribute:: alert
                
                	Turn on/off alert
                	**type**\:  :py:class:`Alert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectZone.Alert>`
                
                .. attribute:: max_destination
                
                	config maximum destination
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: tcp
                
                	Configure tcp syn\-flood per\-destination rate
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectZone.Tcp>`
                
                .. attribute:: threat_detection
                
                	Configure Threat Detection
                	**type**\:  :py:class:`ThreatDetection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectZone.ThreatDetection>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.ParameterMap.Type.InspectZone, self).__init__()

                    self.yang_name = "inspect-zone"
                    self.yang_parent_name = "type"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("alert", ("alert", Native.ParameterMap.Type.InspectZone.Alert)), ("tcp", ("tcp", Native.ParameterMap.Type.InspectZone.Tcp)), ("threat-detection", ("threat_detection", Native.ParameterMap.Type.InspectZone.ThreatDetection))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('max_destination', (YLeaf(YType.uint32, 'max-destination'), ['int'])),
                    ])
                    self.name = None
                    self.max_destination = None

                    self.alert = Native.ParameterMap.Type.InspectZone.Alert()
                    self.alert.parent = self
                    self._children_name_map["alert"] = "alert"

                    self.tcp = Native.ParameterMap.Type.InspectZone.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.threat_detection = Native.ParameterMap.Type.InspectZone.ThreatDetection()
                    self.threat_detection.parent = self
                    self._children_name_map["threat_detection"] = "threat-detection"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:inspect-zone" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ParameterMap.Type.InspectZone, ['name', 'max_destination'], name, value)


                class Alert(Entity):
                    """
                    Turn on/off alert
                    
                    .. attribute:: on
                    
                    	Turn on alert
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectZone.Alert, self).__init__()

                        self.yang_name = "alert"
                        self.yang_parent_name = "inspect-zone"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                        ])
                        self.on = None
                        self._segment_path = lambda: "alert"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectZone.Alert, ['on'], name, value)


                class Tcp(Entity):
                    """
                    Configure tcp syn\-flood per\-destination rate
                    
                    .. attribute:: syn_flood
                    
                    	maximum syn packet
                    	**type**\:  :py:class:`SynFlood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectZone.Tcp.SynFlood>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectZone.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "inspect-zone"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("syn-flood", ("syn_flood", Native.ParameterMap.Type.InspectZone.Tcp.SynFlood))])
                        self._leafs = OrderedDict()

                        self.syn_flood = Native.ParameterMap.Type.InspectZone.Tcp.SynFlood()
                        self.syn_flood.parent = self
                        self._children_name_map["syn_flood"] = "syn-flood"
                        self._segment_path = lambda: "tcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectZone.Tcp, [], name, value)


                    class SynFlood(Entity):
                        """
                        maximum syn packet
                        
                        .. attribute:: rate
                        
                        	maximum syn packet rate
                        	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectZone.Tcp.SynFlood.Rate>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.InspectZone.Tcp.SynFlood, self).__init__()

                            self.yang_name = "syn-flood"
                            self.yang_parent_name = "tcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rate", ("rate", Native.ParameterMap.Type.InspectZone.Tcp.SynFlood.Rate))])
                            self._leafs = OrderedDict()

                            self.rate = Native.ParameterMap.Type.InspectZone.Tcp.SynFlood.Rate()
                            self.rate.parent = self
                            self._children_name_map["rate"] = "rate"
                            self._segment_path = lambda: "syn-flood"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.InspectZone.Tcp.SynFlood, [], name, value)


                        class Rate(Entity):
                            """
                            maximum syn packet rate
                            
                            .. attribute:: per_destination
                            
                            	per destination
                            	**type**\: int
                            
                            	**range:** 1..1000000000
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectZone.Tcp.SynFlood.Rate, self).__init__()

                                self.yang_name = "rate"
                                self.yang_parent_name = "syn-flood"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('per_destination', (YLeaf(YType.uint32, 'per-destination'), ['int'])),
                                ])
                                self.per_destination = None
                                self._segment_path = lambda: "rate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectZone.Tcp.SynFlood.Rate, ['per_destination'], name, value)


                class ThreatDetection(Entity):
                    """
                    Configure Threat Detection
                    
                    .. attribute:: basic_threat
                    
                    	Enable Threat Detection
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: rate
                    
                    	Configure Threat Detection rate
                    	**type**\:  :py:class:`Rate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.InspectZone.ThreatDetection, self).__init__()

                        self.yang_name = "threat-detection"
                        self.yang_parent_name = "inspect-zone"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rate", ("rate", Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate))])
                        self._leafs = OrderedDict([
                            ('basic_threat', (YLeaf(YType.empty, 'basic-threat'), ['Empty'])),
                        ])
                        self.basic_threat = None

                        self.rate = Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate()
                        self.rate.parent = self
                        self._children_name_map["rate"] = "rate"
                        self._segment_path = lambda: "threat-detection"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.InspectZone.ThreatDetection, ['basic_threat'], name, value)


                    class Rate(Entity):
                        """
                        Configure Threat Detection rate
                        
                        .. attribute:: fw_drop
                        
                        	Configure Threat Detection rate for firewall drop events
                        	**type**\:  :py:class:`FwDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.FwDrop>`
                        
                        .. attribute:: inspect_drop
                        
                        	Configure Threat Detection rate for firewall inspection based drop events
                        	**type**\:  :py:class:`InspectDrop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.InspectDrop>`
                        
                        .. attribute:: syn_attack
                        
                        	Configure Threat Detection rate for syn attack events
                        	**type**\:  :py:class:`SynAttack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.SynAttack>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate, self).__init__()

                            self.yang_name = "rate"
                            self.yang_parent_name = "threat-detection"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fw-drop", ("fw_drop", Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.FwDrop)), ("inspect-drop", ("inspect_drop", Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.InspectDrop)), ("syn-attack", ("syn_attack", Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.SynAttack))])
                            self._leafs = OrderedDict()

                            self.fw_drop = Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.FwDrop()
                            self.fw_drop.parent = self
                            self._children_name_map["fw_drop"] = "fw-drop"

                            self.inspect_drop = Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.InspectDrop()
                            self.inspect_drop.parent = self
                            self._children_name_map["inspect_drop"] = "inspect-drop"

                            self.syn_attack = Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.SynAttack()
                            self.syn_attack.parent = self
                            self._children_name_map["syn_attack"] = "syn-attack"
                            self._segment_path = lambda: "rate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate, [], name, value)


                        class FwDrop(Entity):
                            """
                            Configure Threat Detection rate for firewall drop events
                            
                            .. attribute:: average_time_frame
                            
                            	Configure Threat Detection average time frame
                            	**type**\: int
                            
                            	**range:** 600..3600
                            
                            .. attribute:: average_threshold
                            
                            	Configure Threat Detection average threshold
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: burst_threshold
                            
                            	Configure Threat Detection burst threshold
                            	**type**\: int
                            
                            	**range:** 1..1000000000
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.FwDrop, self).__init__()

                                self.yang_name = "fw-drop"
                                self.yang_parent_name = "rate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('average_time_frame', (YLeaf(YType.uint16, 'average-time-frame'), ['int'])),
                                    ('average_threshold', (YLeaf(YType.uint32, 'average-threshold'), ['int'])),
                                    ('burst_threshold', (YLeaf(YType.uint32, 'burst-threshold'), ['int'])),
                                ])
                                self.average_time_frame = None
                                self.average_threshold = None
                                self.burst_threshold = None
                                self._segment_path = lambda: "fw-drop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.FwDrop, ['average_time_frame', 'average_threshold', 'burst_threshold'], name, value)


                        class InspectDrop(Entity):
                            """
                            Configure Threat Detection rate for firewall inspection based drop events
                            
                            .. attribute:: average_time_frame
                            
                            	Configure Threat Detection average time frame
                            	**type**\: int
                            
                            	**range:** 600..3600
                            
                            .. attribute:: average_threshold
                            
                            	Configure Threat Detection average threshold
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: burst_threshold
                            
                            	Configure Threat Detection burst threshold
                            	**type**\: int
                            
                            	**range:** 1..1000000000
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.InspectDrop, self).__init__()

                                self.yang_name = "inspect-drop"
                                self.yang_parent_name = "rate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('average_time_frame', (YLeaf(YType.uint16, 'average-time-frame'), ['int'])),
                                    ('average_threshold', (YLeaf(YType.uint32, 'average-threshold'), ['int'])),
                                    ('burst_threshold', (YLeaf(YType.uint32, 'burst-threshold'), ['int'])),
                                ])
                                self.average_time_frame = None
                                self.average_threshold = None
                                self.burst_threshold = None
                                self._segment_path = lambda: "inspect-drop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.InspectDrop, ['average_time_frame', 'average_threshold', 'burst_threshold'], name, value)


                        class SynAttack(Entity):
                            """
                            Configure Threat Detection rate for syn attack events
                            
                            .. attribute:: average_time_frame
                            
                            	Configure Threat Detection average time frame
                            	**type**\: int
                            
                            	**range:** 600..3600
                            
                            .. attribute:: average_threshold
                            
                            	Configure Threat Detection average threshold
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: burst_threshold
                            
                            	Configure Threat Detection burst threshold
                            	**type**\: int
                            
                            	**range:** 1..1000000000
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.SynAttack, self).__init__()

                                self.yang_name = "syn-attack"
                                self.yang_parent_name = "rate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('average_time_frame', (YLeaf(YType.uint16, 'average-time-frame'), ['int'])),
                                    ('average_threshold', (YLeaf(YType.uint32, 'average-threshold'), ['int'])),
                                    ('burst_threshold', (YLeaf(YType.uint32, 'burst-threshold'), ['int'])),
                                ])
                                self.average_time_frame = None
                                self.average_threshold = None
                                self.burst_threshold = None
                                self._segment_path = lambda: "syn-attack"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.InspectZone.ThreatDetection.Rate.SynAttack, ['average_time_frame', 'average_threshold', 'burst_threshold'], name, value)


            class Regex(Entity):
                """
                regex parameter\-map
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                	**length:** 1..256
                
                .. attribute:: pattern
                
                	Configure pattern to match
                	**type**\: list of  		 :py:class:`Pattern <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Regex.Pattern>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.ParameterMap.Type.Regex, self).__init__()

                    self.yang_name = "regex"
                    self.yang_parent_name = "type"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("pattern", ("pattern", Native.ParameterMap.Type.Regex.Pattern))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.pattern = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:regex" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ParameterMap.Type.Regex, ['name'], name, value)


                class Pattern(Entity):
                    """
                    Configure pattern to match
                    
                    .. attribute:: regexp  (key)
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..240
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Regex.Pattern, self).__init__()

                        self.yang_name = "pattern"
                        self.yang_parent_name = "regex"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['regexp']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('regexp', (YLeaf(YType.str, 'regexp'), ['str'])),
                        ])
                        self.regexp = None
                        self._segment_path = lambda: "pattern" + "[regexp='" + str(self.regexp) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Regex.Pattern, ['regexp'], name, value)


            class Webauth(Entity):
                """
                WEBAUTH parameters
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                	**length:** 1..256
                
                .. attribute:: captive_bypass_portal
                
                	Turn on captive bypass
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: consent
                
                	consent parameters
                	**type**\:  :py:class:`Consent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.Consent>`
                
                .. attribute:: custom_page
                
                	custom\-page \- login, expired, success or failure page
                	**type**\:  :py:class:`CustomPage <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.CustomPage>`
                
                .. attribute:: login_auth_bypass
                
                	Login Auth Bypass for FQDN
                	**type**\:  :py:class:`LoginAuthBypass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.LoginAuthBypass>`
                
                .. attribute:: logout_window_disabled
                
                	Webauth logout window disable
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: max_http_conns
                
                	Webauth max HTTP connections per client
                	**type**\: int
                
                	**range:** 1..200
                
                .. attribute:: redirect
                
                	redirect url
                	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.Redirect>`
                
                .. attribute:: sleeping_client
                
                	enable sleeping client for webauth
                	**type**\:  :py:class:`SleepingClient <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.SleepingClient>`
                
                .. attribute:: success_window_disable
                
                	Disable Success Window
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timeout
                
                	timeout for the webauth session
                	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.Timeout>`
                
                .. attribute:: type
                
                	type \- web\-auth, consent or both
                	**type**\:  :py:class:`Type_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.Type_>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.ParameterMap.Type.Webauth, self).__init__()

                    self.yang_name = "webauth"
                    self.yang_parent_name = "type"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("consent", ("consent", Native.ParameterMap.Type.Webauth.Consent)), ("custom-page", ("custom_page", Native.ParameterMap.Type.Webauth.CustomPage)), ("login-auth-bypass", ("login_auth_bypass", Native.ParameterMap.Type.Webauth.LoginAuthBypass)), ("redirect", ("redirect", Native.ParameterMap.Type.Webauth.Redirect)), ("sleeping-client", ("sleeping_client", Native.ParameterMap.Type.Webauth.SleepingClient)), ("timeout", ("timeout", Native.ParameterMap.Type.Webauth.Timeout))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('captive_bypass_portal', (YLeaf(YType.empty, 'captive-bypass-portal'), ['Empty'])),
                        ('logout_window_disabled', (YLeaf(YType.empty, 'logout-window-disabled'), ['Empty'])),
                        ('max_http_conns', (YLeaf(YType.uint8, 'max-http-conns'), ['int'])),
                        ('success_window_disable', (YLeaf(YType.empty, 'success-window-disable'), ['Empty'])),
                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'ParameterMap.Type.Webauth.Type_')])),
                    ])
                    self.name = None
                    self.captive_bypass_portal = None
                    self.logout_window_disabled = None
                    self.max_http_conns = None
                    self.success_window_disable = None
                    self.type = None

                    self.consent = Native.ParameterMap.Type.Webauth.Consent()
                    self.consent.parent = self
                    self._children_name_map["consent"] = "consent"

                    self.custom_page = Native.ParameterMap.Type.Webauth.CustomPage()
                    self.custom_page.parent = self
                    self._children_name_map["custom_page"] = "custom-page"

                    self.login_auth_bypass = Native.ParameterMap.Type.Webauth.LoginAuthBypass()
                    self.login_auth_bypass.parent = self
                    self._children_name_map["login_auth_bypass"] = "login-auth-bypass"

                    self.redirect = Native.ParameterMap.Type.Webauth.Redirect()
                    self.redirect.parent = self
                    self._children_name_map["redirect"] = "redirect"

                    self.sleeping_client = Native.ParameterMap.Type.Webauth.SleepingClient()
                    self.sleeping_client.parent = self
                    self._children_name_map["sleeping_client"] = "sleeping-client"

                    self.timeout = Native.ParameterMap.Type.Webauth.Timeout()
                    self.timeout.parent = self
                    self._children_name_map["timeout"] = "timeout"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:webauth" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ParameterMap.Type.Webauth, ['name', 'captive_bypass_portal', 'logout_window_disabled', 'max_http_conns', 'success_window_disable', 'type'], name, value)

                class Type_(Enum):
                    """
                    Type\_ (Enum Class)

                    type \- web\-auth, consent or both

                    .. data:: authbypass = 0

                    .. data:: consent = 1

                    .. data:: webauth = 2

                    .. data:: webconsent = 3

                    """

                    authbypass = Enum.YLeaf(0, "authbypass")

                    consent = Enum.YLeaf(1, "consent")

                    webauth = Enum.YLeaf(2, "webauth")

                    webconsent = Enum.YLeaf(3, "webconsent")



                class Consent(Entity):
                    """
                    consent parameters
                    
                    .. attribute:: email
                    
                    	Turn\-on Consent with Email
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Webauth.Consent, self).__init__()

                        self.yang_name = "consent"
                        self.yang_parent_name = "webauth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('email', (YLeaf(YType.empty, 'email'), ['Empty'])),
                        ])
                        self.email = None
                        self._segment_path = lambda: "consent"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Webauth.Consent, ['email'], name, value)


                class CustomPage(Entity):
                    """
                    custom\-page \- login, expired, success or failure page
                    
                    .. attribute:: login
                    
                    	auth\-proxy login parameters
                    	**type**\:  :py:class:`Login <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.CustomPage.Login>`
                    
                    .. attribute:: failure
                    
                    	Failed authentication proxy
                    	**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.CustomPage.Failure>`
                    
                    .. attribute:: success
                    
                    	Successful authentication proxy
                    	**type**\:  :py:class:`Success <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.CustomPage.Success>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Webauth.CustomPage, self).__init__()

                        self.yang_name = "custom-page"
                        self.yang_parent_name = "webauth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("login", ("login", Native.ParameterMap.Type.Webauth.CustomPage.Login)), ("failure", ("failure", Native.ParameterMap.Type.Webauth.CustomPage.Failure)), ("success", ("success", Native.ParameterMap.Type.Webauth.CustomPage.Success))])
                        self._leafs = OrderedDict()

                        self.login = Native.ParameterMap.Type.Webauth.CustomPage.Login()
                        self.login.parent = self
                        self._children_name_map["login"] = "login"

                        self.failure = Native.ParameterMap.Type.Webauth.CustomPage.Failure()
                        self.failure.parent = self
                        self._children_name_map["failure"] = "failure"

                        self.success = Native.ParameterMap.Type.Webauth.CustomPage.Success()
                        self.success.parent = self
                        self._children_name_map["success"] = "success"
                        self._segment_path = lambda: "custom-page"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Webauth.CustomPage, [], name, value)


                    class Login(Entity):
                        """
                        auth\-proxy login parameters
                        
                        .. attribute:: device
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: expired
                        
                        	Expired authentication proxy
                        	**type**\:  :py:class:`Expired <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.CustomPage.Login.Expired>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Webauth.CustomPage.Login, self).__init__()

                            self.yang_name = "login"
                            self.yang_parent_name = "custom-page"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("expired", ("expired", Native.ParameterMap.Type.Webauth.CustomPage.Login.Expired))])
                            self._leafs = OrderedDict([
                                ('device', (YLeaf(YType.str, 'device'), ['str'])),
                            ])
                            self.device = None

                            self.expired = Native.ParameterMap.Type.Webauth.CustomPage.Login.Expired()
                            self.expired.parent = self
                            self._children_name_map["expired"] = "expired"
                            self._segment_path = lambda: "login"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Webauth.CustomPage.Login, ['device'], name, value)


                        class Expired(Entity):
                            """
                            Expired authentication proxy
                            
                            .. attribute:: device
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Webauth.CustomPage.Login.Expired, self).__init__()

                                self.yang_name = "expired"
                                self.yang_parent_name = "login"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('device', (YLeaf(YType.str, 'device'), ['str'])),
                                ])
                                self.device = None
                                self._segment_path = lambda: "expired"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Webauth.CustomPage.Login.Expired, ['device'], name, value)


                    class Failure(Entity):
                        """
                        Failed authentication proxy
                        
                        .. attribute:: device
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Webauth.CustomPage.Failure, self).__init__()

                            self.yang_name = "failure"
                            self.yang_parent_name = "custom-page"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('device', (YLeaf(YType.str, 'device'), ['str'])),
                            ])
                            self.device = None
                            self._segment_path = lambda: "failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Webauth.CustomPage.Failure, ['device'], name, value)


                    class Success(Entity):
                        """
                        Successful authentication proxy
                        
                        .. attribute:: device
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Webauth.CustomPage.Success, self).__init__()

                            self.yang_name = "success"
                            self.yang_parent_name = "custom-page"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('device', (YLeaf(YType.str, 'device'), ['str'])),
                            ])
                            self.device = None
                            self._segment_path = lambda: "success"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Webauth.CustomPage.Success, ['device'], name, value)


                class LoginAuthBypass(Entity):
                    """
                    Login Auth Bypass for FQDN
                    
                    .. attribute:: ip_access_list
                    
                    	fqdn acl name
                    	**type**\:  :py:class:`IpAccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.LoginAuthBypass.IpAccessList>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Webauth.LoginAuthBypass, self).__init__()

                        self.yang_name = "login-auth-bypass"
                        self.yang_parent_name = "webauth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip-access-list", ("ip_access_list", Native.ParameterMap.Type.Webauth.LoginAuthBypass.IpAccessList))])
                        self._leafs = OrderedDict()

                        self.ip_access_list = Native.ParameterMap.Type.Webauth.LoginAuthBypass.IpAccessList()
                        self.ip_access_list.parent = self
                        self._children_name_map["ip_access_list"] = "ip-access-list"
                        self._segment_path = lambda: "login-auth-bypass"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Webauth.LoginAuthBypass, [], name, value)


                    class IpAccessList(Entity):
                        """
                        fqdn acl name
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: domain_name_list
                        
                        	Domain list name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Webauth.LoginAuthBypass.IpAccessList, self).__init__()

                            self.yang_name = "ip-access-list"
                            self.yang_parent_name = "login-auth-bypass"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('domain_name_list', (YLeaf(YType.str, 'domain-name-list'), ['str'])),
                            ])
                            self.name = None
                            self.domain_name_list = None
                            self._segment_path = lambda: "ip-access-list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Webauth.LoginAuthBypass.IpAccessList, ['name', 'domain_name_list'], name, value)


                class Redirect(Entity):
                    """
                    redirect url
                    
                    .. attribute:: append
                    
                    	Append tag name to redirect URL
                    	**type**\:  :py:class:`Append <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.Redirect.Append>`
                    
                    .. attribute:: portal
                    
                    	External Portal
                    	**type**\:  :py:class:`Portal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.Redirect.Portal>`
                    
                    .. attribute:: for_login
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: on_failure
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: on_success
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Webauth.Redirect, self).__init__()

                        self.yang_name = "redirect"
                        self.yang_parent_name = "webauth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("append", ("append", Native.ParameterMap.Type.Webauth.Redirect.Append)), ("portal", ("portal", Native.ParameterMap.Type.Webauth.Redirect.Portal))])
                        self._leafs = OrderedDict([
                            ('for_login', (YLeaf(YType.str, 'for-login'), ['str'])),
                            ('on_failure', (YLeaf(YType.str, 'on-failure'), ['str'])),
                            ('on_success', (YLeaf(YType.str, 'on-success'), ['str'])),
                        ])
                        self.for_login = None
                        self.on_failure = None
                        self.on_success = None

                        self.append = Native.ParameterMap.Type.Webauth.Redirect.Append()
                        self.append.parent = self
                        self._children_name_map["append"] = "append"

                        self.portal = Native.ParameterMap.Type.Webauth.Redirect.Portal()
                        self.portal.parent = self
                        self._children_name_map["portal"] = "portal"
                        self._segment_path = lambda: "redirect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Webauth.Redirect, ['for_login', 'on_failure', 'on_success'], name, value)


                    class Append(Entity):
                        """
                        Append tag name to redirect URL
                        
                        .. attribute:: ap_mac
                        
                        	AP MAC Address
                        	**type**\:  :py:class:`ApMac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.Redirect.Append.ApMac>`
                        
                        .. attribute:: client_mac
                        
                        	client MAC name
                        	**type**\:  :py:class:`ClientMac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.Redirect.Append.ClientMac>`
                        
                        .. attribute:: wlan_ssid
                        
                        	WLAN SSID name
                        	**type**\:  :py:class:`WlanSsid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.Redirect.Append.WlanSsid>`
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Webauth.Redirect.Append, self).__init__()

                            self.yang_name = "append"
                            self.yang_parent_name = "redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ap-mac", ("ap_mac", Native.ParameterMap.Type.Webauth.Redirect.Append.ApMac)), ("client-mac", ("client_mac", Native.ParameterMap.Type.Webauth.Redirect.Append.ClientMac)), ("wlan-ssid", ("wlan_ssid", Native.ParameterMap.Type.Webauth.Redirect.Append.WlanSsid))])
                            self._leafs = OrderedDict()

                            self.ap_mac = Native.ParameterMap.Type.Webauth.Redirect.Append.ApMac()
                            self.ap_mac.parent = self
                            self._children_name_map["ap_mac"] = "ap-mac"

                            self.client_mac = Native.ParameterMap.Type.Webauth.Redirect.Append.ClientMac()
                            self.client_mac.parent = self
                            self._children_name_map["client_mac"] = "client-mac"

                            self.wlan_ssid = Native.ParameterMap.Type.Webauth.Redirect.Append.WlanSsid()
                            self.wlan_ssid.parent = self
                            self._children_name_map["wlan_ssid"] = "wlan-ssid"
                            self._segment_path = lambda: "append"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Webauth.Redirect.Append, [], name, value)


                        class ApMac(Entity):
                            """
                            AP MAC Address
                            
                            .. attribute:: tag
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Webauth.Redirect.Append.ApMac, self).__init__()

                                self.yang_name = "ap-mac"
                                self.yang_parent_name = "append"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                                ])
                                self.tag = None
                                self._segment_path = lambda: "ap-mac"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Webauth.Redirect.Append.ApMac, ['tag'], name, value)


                        class ClientMac(Entity):
                            """
                            client MAC name
                            
                            .. attribute:: tag
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Webauth.Redirect.Append.ClientMac, self).__init__()

                                self.yang_name = "client-mac"
                                self.yang_parent_name = "append"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                                ])
                                self.tag = None
                                self._segment_path = lambda: "client-mac"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Webauth.Redirect.Append.ClientMac, ['tag'], name, value)


                        class WlanSsid(Entity):
                            """
                            WLAN SSID name
                            
                            .. attribute:: tag
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Webauth.Redirect.Append.WlanSsid, self).__init__()

                                self.yang_name = "wlan-ssid"
                                self.yang_parent_name = "append"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                                ])
                                self.tag = None
                                self._segment_path = lambda: "wlan-ssid"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Webauth.Redirect.Append.WlanSsid, ['tag'], name, value)


                    class Portal(Entity):
                        """
                        External Portal
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Webauth.Redirect.Portal, self).__init__()

                            self.yang_name = "portal"
                            self.yang_parent_name = "redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                            ])
                            self.ipv4 = None
                            self.ipv6 = None
                            self._segment_path = lambda: "portal"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Webauth.Redirect.Portal, ['ipv4', 'ipv6'], name, value)


                class SleepingClient(Entity):
                    """
                    enable sleeping client for webauth
                    
                    .. attribute:: timeout
                    
                    	Sleep timeout in Minute
                    	**type**\: int
                    
                    	**range:** 60..3932100
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Webauth.SleepingClient, self).__init__()

                        self.yang_name = "sleeping-client"
                        self.yang_parent_name = "webauth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "sleeping-client"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Webauth.SleepingClient, ['timeout'], name, value)


                class Timeout(Entity):
                    """
                    timeout for the webauth session
                    
                    .. attribute:: init_state
                    
                    	init\-state timeout
                    	**type**\:  :py:class:`InitState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.Timeout.InitState>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fin_wait
                    
                    	fin\-wait timeout
                    	**type**\:  :py:class:`FinWait <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Webauth.Timeout.FinWait>`
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Webauth.Timeout, self).__init__()

                        self.yang_name = "timeout"
                        self.yang_parent_name = "webauth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("init-state", ("init_state", Native.ParameterMap.Type.Webauth.Timeout.InitState)), ("fin-wait", ("fin_wait", Native.ParameterMap.Type.Webauth.Timeout.FinWait))])
                        self._leafs = OrderedDict()

                        self.init_state = None
                        self._children_name_map["init_state"] = "init-state"

                        self.fin_wait = Native.ParameterMap.Type.Webauth.Timeout.FinWait()
                        self.fin_wait.parent = self
                        self._children_name_map["fin_wait"] = "fin-wait"
                        self._segment_path = lambda: "timeout"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Webauth.Timeout, [], name, value)


                    class InitState(Entity):
                        """
                        init\-state timeout
                        
                        .. attribute:: sec
                        
                        	WEBAUTH Timeout in Seconds
                        	**type**\: int
                        
                        	**range:** 60..3932100
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Webauth.Timeout.InitState, self).__init__()

                            self.yang_name = "init-state"
                            self.yang_parent_name = "timeout"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('sec', (YLeaf(YType.uint32, 'sec'), ['int'])),
                            ])
                            self.sec = None
                            self._segment_path = lambda: "init-state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Webauth.Timeout.InitState, ['sec'], name, value)


                    class FinWait(Entity):
                        """
                        fin\-wait timeout
                        
                        .. attribute:: msec
                        
                        	WEBAUTH Timeout in milliseconds
                        	**type**\: int
                        
                        	**range:** 1..2147483647
                        
                        

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Webauth.Timeout.FinWait, self).__init__()

                            self.yang_name = "fin-wait"
                            self.yang_parent_name = "timeout"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('msec', (YLeaf(YType.uint32, 'msec'), ['int'])),
                            ])
                            self.msec = None
                            self._segment_path = lambda: "fin-wait"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Webauth.Timeout.FinWait, ['msec'], name, value)


            class WebauthGlobal(Entity):
                """
                
                
                .. attribute:: webauth
                
                	WEBAUTH parameters
                	**type**\:  :py:class:`Webauth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth>`
                
                

                """

                _prefix = 'ios-policy'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.ParameterMap.Type.WebauthGlobal, self).__init__()

                    self.yang_name = "webauth-global"
                    self.yang_parent_name = "type"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("webauth", ("webauth", Native.ParameterMap.Type.WebauthGlobal.Webauth))])
                    self._leafs = OrderedDict()

                    self.webauth = Native.ParameterMap.Type.WebauthGlobal.Webauth()
                    self.webauth.parent = self
                    self._children_name_map["webauth"] = "webauth"
                    self._segment_path = lambda: "Cisco-IOS-XE-policy:webauth-global"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal, [], name, value)


                class Webauth(Entity):
                    """
                    WEBAUTH parameters
                    
                    .. attribute:: global_
                    
                    	Global parameter\-map
                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-policy'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.ParameterMap.Type.WebauthGlobal.Webauth, self).__init__()

                        self.yang_name = "webauth"
                        self.yang_parent_name = "webauth-global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("global", ("global_", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global))])
                        self._leafs = OrderedDict()

                        self.global_ = None
                        self._children_name_map["global_"] = "global"
                        self._segment_path = lambda: "webauth"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth, [], name, value)


                    class Global(Entity):
                        """
                        Global parameter\-map
                        
                        .. attribute:: captive_bypass_portal
                        
                        	Turn on captive bypass
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: consent
                        
                        	consent parameters
                        	**type**\:  :py:class:`Consent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Consent>`
                        
                        .. attribute:: custom_page
                        
                        	custom\-page \- login, expired, success or failure page
                        	**type**\:  :py:class:`CustomPage <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage>`
                        
                        .. attribute:: intercept_https_enable
                        
                        	Enable intercept of https traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: login_auth_bypass
                        
                        	Login Auth Bypass for FQDN
                        	**type**\:  :py:class:`LoginAuthBypass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.LoginAuthBypass>`
                        
                        .. attribute:: logout_window_disabled
                        
                        	Webauth logout window disable
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_http_conns
                        
                        	Webauth max HTTP connections per client
                        	**type**\: int
                        
                        	**range:** 1..200
                        
                        .. attribute:: redirect
                        
                        	redirect url
                        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect>`
                        
                        .. attribute:: sleeping_client
                        
                        	enable sleeping client for webauth
                        	**type**\:  :py:class:`SleepingClient <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.SleepingClient>`
                        
                        .. attribute:: success_window_disable
                        
                        	Disable Success Window
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: timeout
                        
                        	timeout for the webauth session
                        	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout>`
                        
                        .. attribute:: type
                        
                        	type \- web\-auth, consent or both
                        	**type**\:  :py:class:`Type_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Type_>`
                        
                        .. attribute:: virtual_ip
                        
                        	Virtual Ip Address
                        	**type**\:  :py:class:`VirtualIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp>`
                        
                        .. attribute:: watch_list
                        
                        	Watch List of webauth clients
                        	**type**\:  :py:class:`WatchList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.WatchList>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-policy'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "webauth"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("consent", ("consent", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Consent)), ("custom-page", ("custom_page", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage)), ("login-auth-bypass", ("login_auth_bypass", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.LoginAuthBypass)), ("redirect", ("redirect", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect)), ("sleeping-client", ("sleeping_client", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.SleepingClient)), ("timeout", ("timeout", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout)), ("virtual-ip", ("virtual_ip", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp)), ("watch-list", ("watch_list", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.WatchList))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('captive_bypass_portal', (YLeaf(YType.empty, 'captive-bypass-portal'), ['Empty'])),
                                ('intercept_https_enable', (YLeaf(YType.empty, 'intercept-https-enable'), ['Empty'])),
                                ('logout_window_disabled', (YLeaf(YType.empty, 'logout-window-disabled'), ['Empty'])),
                                ('max_http_conns', (YLeaf(YType.uint8, 'max-http-conns'), ['int'])),
                                ('success_window_disable', (YLeaf(YType.empty, 'success-window-disable'), ['Empty'])),
                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'ParameterMap.Type.WebauthGlobal.Webauth.Global.Type_')])),
                            ])
                            self.captive_bypass_portal = None
                            self.intercept_https_enable = None
                            self.logout_window_disabled = None
                            self.max_http_conns = None
                            self.success_window_disable = None
                            self.type = None

                            self.consent = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Consent()
                            self.consent.parent = self
                            self._children_name_map["consent"] = "consent"

                            self.custom_page = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage()
                            self.custom_page.parent = self
                            self._children_name_map["custom_page"] = "custom-page"

                            self.login_auth_bypass = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.LoginAuthBypass()
                            self.login_auth_bypass.parent = self
                            self._children_name_map["login_auth_bypass"] = "login-auth-bypass"

                            self.redirect = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect()
                            self.redirect.parent = self
                            self._children_name_map["redirect"] = "redirect"

                            self.sleeping_client = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.SleepingClient()
                            self.sleeping_client.parent = self
                            self._children_name_map["sleeping_client"] = "sleeping-client"

                            self.timeout = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout()
                            self.timeout.parent = self
                            self._children_name_map["timeout"] = "timeout"

                            self.virtual_ip = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp()
                            self.virtual_ip.parent = self
                            self._children_name_map["virtual_ip"] = "virtual-ip"

                            self.watch_list = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.WatchList()
                            self.watch_list.parent = self
                            self._children_name_map["watch_list"] = "watch-list"
                            self._segment_path = lambda: "global"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global, ['captive_bypass_portal', 'intercept_https_enable', 'logout_window_disabled', 'max_http_conns', 'success_window_disable', 'type'], name, value)

                        class Type_(Enum):
                            """
                            Type\_ (Enum Class)

                            type \- web\-auth, consent or both

                            .. data:: authbypass = 0

                            .. data:: consent = 1

                            .. data:: webauth = 2

                            .. data:: webconsent = 3

                            """

                            authbypass = Enum.YLeaf(0, "authbypass")

                            consent = Enum.YLeaf(1, "consent")

                            webauth = Enum.YLeaf(2, "webauth")

                            webconsent = Enum.YLeaf(3, "webconsent")



                        class Consent(Entity):
                            """
                            consent parameters
                            
                            .. attribute:: email
                            
                            	Turn\-on Consent with Email
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Consent, self).__init__()

                                self.yang_name = "consent"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('email', (YLeaf(YType.empty, 'email'), ['Empty'])),
                                ])
                                self.email = None
                                self._segment_path = lambda: "consent"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Consent, ['email'], name, value)


                        class CustomPage(Entity):
                            """
                            custom\-page \- login, expired, success or failure page
                            
                            .. attribute:: login
                            
                            	auth\-proxy login parameters
                            	**type**\:  :py:class:`Login <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Login>`
                            
                            .. attribute:: failure
                            
                            	Failed authentication proxy
                            	**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Failure>`
                            
                            .. attribute:: success
                            
                            	Successful authentication proxy
                            	**type**\:  :py:class:`Success <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Success>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage, self).__init__()

                                self.yang_name = "custom-page"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("login", ("login", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Login)), ("failure", ("failure", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Failure)), ("success", ("success", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Success))])
                                self._leafs = OrderedDict()

                                self.login = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Login()
                                self.login.parent = self
                                self._children_name_map["login"] = "login"

                                self.failure = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Failure()
                                self.failure.parent = self
                                self._children_name_map["failure"] = "failure"

                                self.success = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Success()
                                self.success.parent = self
                                self._children_name_map["success"] = "success"
                                self._segment_path = lambda: "custom-page"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage, [], name, value)


                            class Login(Entity):
                                """
                                auth\-proxy login parameters
                                
                                .. attribute:: device
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: expired
                                
                                	Expired authentication proxy
                                	**type**\:  :py:class:`Expired <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Login.Expired>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Login, self).__init__()

                                    self.yang_name = "login"
                                    self.yang_parent_name = "custom-page"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("expired", ("expired", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Login.Expired))])
                                    self._leafs = OrderedDict([
                                        ('device', (YLeaf(YType.str, 'device'), ['str'])),
                                    ])
                                    self.device = None

                                    self.expired = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Login.Expired()
                                    self.expired.parent = self
                                    self._children_name_map["expired"] = "expired"
                                    self._segment_path = lambda: "login"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/custom-page/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Login, ['device'], name, value)


                                class Expired(Entity):
                                    """
                                    Expired authentication proxy
                                    
                                    .. attribute:: device
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Login.Expired, self).__init__()

                                        self.yang_name = "expired"
                                        self.yang_parent_name = "login"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('device', (YLeaf(YType.str, 'device'), ['str'])),
                                        ])
                                        self.device = None
                                        self._segment_path = lambda: "expired"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/custom-page/login/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Login.Expired, ['device'], name, value)


                            class Failure(Entity):
                                """
                                Failed authentication proxy
                                
                                .. attribute:: device
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Failure, self).__init__()

                                    self.yang_name = "failure"
                                    self.yang_parent_name = "custom-page"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('device', (YLeaf(YType.str, 'device'), ['str'])),
                                    ])
                                    self.device = None
                                    self._segment_path = lambda: "failure"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/custom-page/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Failure, ['device'], name, value)


                            class Success(Entity):
                                """
                                Successful authentication proxy
                                
                                .. attribute:: device
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Success, self).__init__()

                                    self.yang_name = "success"
                                    self.yang_parent_name = "custom-page"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('device', (YLeaf(YType.str, 'device'), ['str'])),
                                    ])
                                    self.device = None
                                    self._segment_path = lambda: "success"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/custom-page/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.CustomPage.Success, ['device'], name, value)


                        class LoginAuthBypass(Entity):
                            """
                            Login Auth Bypass for FQDN
                            
                            .. attribute:: ip_access_list
                            
                            	fqdn acl name
                            	**type**\:  :py:class:`IpAccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.LoginAuthBypass.IpAccessList>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.LoginAuthBypass, self).__init__()

                                self.yang_name = "login-auth-bypass"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ip-access-list", ("ip_access_list", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.LoginAuthBypass.IpAccessList))])
                                self._leafs = OrderedDict()

                                self.ip_access_list = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.LoginAuthBypass.IpAccessList()
                                self.ip_access_list.parent = self
                                self._children_name_map["ip_access_list"] = "ip-access-list"
                                self._segment_path = lambda: "login-auth-bypass"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.LoginAuthBypass, [], name, value)


                            class IpAccessList(Entity):
                                """
                                fqdn acl name
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: domain_name_list
                                
                                	Domain list name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.LoginAuthBypass.IpAccessList, self).__init__()

                                    self.yang_name = "ip-access-list"
                                    self.yang_parent_name = "login-auth-bypass"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('domain_name_list', (YLeaf(YType.str, 'domain-name-list'), ['str'])),
                                    ])
                                    self.name = None
                                    self.domain_name_list = None
                                    self._segment_path = lambda: "ip-access-list"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/login-auth-bypass/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.LoginAuthBypass.IpAccessList, ['name', 'domain_name_list'], name, value)


                        class Redirect(Entity):
                            """
                            redirect url
                            
                            .. attribute:: append
                            
                            	Append tag name to redirect URL
                            	**type**\:  :py:class:`Append <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append>`
                            
                            .. attribute:: portal
                            
                            	External portal
                            	**type**\:  :py:class:`Portal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Portal>`
                            
                            .. attribute:: for_login
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: on_failure
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: on_success
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect, self).__init__()

                                self.yang_name = "redirect"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("append", ("append", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append)), ("portal", ("portal", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Portal))])
                                self._leafs = OrderedDict([
                                    ('for_login', (YLeaf(YType.str, 'for-login'), ['str'])),
                                    ('on_failure', (YLeaf(YType.str, 'on-failure'), ['str'])),
                                    ('on_success', (YLeaf(YType.str, 'on-success'), ['str'])),
                                ])
                                self.for_login = None
                                self.on_failure = None
                                self.on_success = None

                                self.append = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append()
                                self.append.parent = self
                                self._children_name_map["append"] = "append"

                                self.portal = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Portal()
                                self.portal.parent = self
                                self._children_name_map["portal"] = "portal"
                                self._segment_path = lambda: "redirect"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect, ['for_login', 'on_failure', 'on_success'], name, value)


                            class Append(Entity):
                                """
                                Append tag name to redirect URL
                                
                                .. attribute:: ap_mac
                                
                                	AP MAC Address
                                	**type**\:  :py:class:`ApMac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.ApMac>`
                                
                                .. attribute:: client_mac
                                
                                	client MAC name
                                	**type**\:  :py:class:`ClientMac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.ClientMac>`
                                
                                .. attribute:: wlan_ssid
                                
                                	WLAN SSID name
                                	**type**\:  :py:class:`WlanSsid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.WlanSsid>`
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append, self).__init__()

                                    self.yang_name = "append"
                                    self.yang_parent_name = "redirect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ap-mac", ("ap_mac", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.ApMac)), ("client-mac", ("client_mac", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.ClientMac)), ("wlan-ssid", ("wlan_ssid", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.WlanSsid))])
                                    self._leafs = OrderedDict()

                                    self.ap_mac = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.ApMac()
                                    self.ap_mac.parent = self
                                    self._children_name_map["ap_mac"] = "ap-mac"

                                    self.client_mac = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.ClientMac()
                                    self.client_mac.parent = self
                                    self._children_name_map["client_mac"] = "client-mac"

                                    self.wlan_ssid = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.WlanSsid()
                                    self.wlan_ssid.parent = self
                                    self._children_name_map["wlan_ssid"] = "wlan-ssid"
                                    self._segment_path = lambda: "append"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/redirect/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append, [], name, value)


                                class ApMac(Entity):
                                    """
                                    AP MAC Address
                                    
                                    .. attribute:: tag
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.ApMac, self).__init__()

                                        self.yang_name = "ap-mac"
                                        self.yang_parent_name = "append"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                                        ])
                                        self.tag = None
                                        self._segment_path = lambda: "ap-mac"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/redirect/append/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.ApMac, ['tag'], name, value)


                                class ClientMac(Entity):
                                    """
                                    client MAC name
                                    
                                    .. attribute:: tag
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.ClientMac, self).__init__()

                                        self.yang_name = "client-mac"
                                        self.yang_parent_name = "append"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                                        ])
                                        self.tag = None
                                        self._segment_path = lambda: "client-mac"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/redirect/append/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.ClientMac, ['tag'], name, value)


                                class WlanSsid(Entity):
                                    """
                                    WLAN SSID name
                                    
                                    .. attribute:: tag
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-policy'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.WlanSsid, self).__init__()

                                        self.yang_name = "wlan-ssid"
                                        self.yang_parent_name = "append"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                                        ])
                                        self.tag = None
                                        self._segment_path = lambda: "wlan-ssid"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/redirect/append/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Append.WlanSsid, ['tag'], name, value)


                            class Portal(Entity):
                                """
                                External portal
                                
                                .. attribute:: ipv4
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Portal, self).__init__()

                                    self.yang_name = "portal"
                                    self.yang_parent_name = "redirect"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "portal"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/redirect/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Redirect.Portal, ['ipv4', 'ipv6'], name, value)


                        class SleepingClient(Entity):
                            """
                            enable sleeping client for webauth
                            
                            .. attribute:: timeout
                            
                            	Sleep timeout in Minute
                            	**type**\: int
                            
                            	**range:** 60..3932100
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.SleepingClient, self).__init__()

                                self.yang_name = "sleeping-client"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                                ])
                                self.timeout = None
                                self._segment_path = lambda: "sleeping-client"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.SleepingClient, ['timeout'], name, value)


                        class Timeout(Entity):
                            """
                            timeout for the webauth session
                            
                            .. attribute:: init_state
                            
                            	init\-state timeout
                            	**type**\:  :py:class:`InitState <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout.InitState>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: fin_wait
                            
                            	fin\-wait timeout
                            	**type**\:  :py:class:`FinWait <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout.FinWait>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout, self).__init__()

                                self.yang_name = "timeout"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("init-state", ("init_state", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout.InitState)), ("fin-wait", ("fin_wait", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout.FinWait))])
                                self._leafs = OrderedDict()

                                self.init_state = None
                                self._children_name_map["init_state"] = "init-state"

                                self.fin_wait = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout.FinWait()
                                self.fin_wait.parent = self
                                self._children_name_map["fin_wait"] = "fin-wait"
                                self._segment_path = lambda: "timeout"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout, [], name, value)


                            class InitState(Entity):
                                """
                                init\-state timeout
                                
                                .. attribute:: sec
                                
                                	WEBAUTH Timeout in Seconds
                                	**type**\: int
                                
                                	**range:** 60..3932100
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout.InitState, self).__init__()

                                    self.yang_name = "init-state"
                                    self.yang_parent_name = "timeout"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('sec', (YLeaf(YType.uint32, 'sec'), ['int'])),
                                    ])
                                    self.sec = None
                                    self._segment_path = lambda: "init-state"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/timeout/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout.InitState, ['sec'], name, value)


                            class FinWait(Entity):
                                """
                                fin\-wait timeout
                                
                                .. attribute:: msec
                                
                                	WEBAUTH Timeout in milliseconds
                                	**type**\: int
                                
                                	**range:** 1..2147483647
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout.FinWait, self).__init__()

                                    self.yang_name = "fin-wait"
                                    self.yang_parent_name = "timeout"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('msec', (YLeaf(YType.uint32, 'msec'), ['int'])),
                                    ])
                                    self.msec = None
                                    self._segment_path = lambda: "fin-wait"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/timeout/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.Timeout.FinWait, ['msec'], name, value)


                        class VirtualIp(Entity):
                            """
                            Virtual Ip Address
                            
                            .. attribute:: ipv4
                            
                            	Ipv4 Address
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp.Ipv4>`
                            
                            .. attribute:: ipv6
                            
                            	Ipv6 Address
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp.Ipv6>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp, self).__init__()

                                self.yang_name = "virtual-ip"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp.Ipv4)), ("ipv6", ("ipv6", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp.Ipv6))])
                                self._leafs = OrderedDict()

                                self.ipv4 = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp.Ipv6()
                                self.ipv6.parent = self
                                self._children_name_map["ipv6"] = "ipv6"
                                self._segment_path = lambda: "virtual-ip"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp, [], name, value)


                            class Ipv4(Entity):
                                """
                                Ipv4 Address
                                
                                .. attribute:: address
                                
                                	Recovery IP address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: virtual_host
                                
                                	Virtual host name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "virtual-ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                        ('virtual_host', (YLeaf(YType.str, 'virtual-host'), ['str'])),
                                    ])
                                    self.address = None
                                    self.virtual_host = None
                                    self._segment_path = lambda: "ipv4"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/virtual-ip/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp.Ipv4, ['address', 'virtual_host'], name, value)


                            class Ipv6(Entity):
                                """
                                Ipv6 Address
                                
                                .. attribute:: address
                                
                                	Recovery IP address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: virtual_host
                                
                                	Virtual host name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "virtual-ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                        ('virtual_host', (YLeaf(YType.str, 'virtual-host'), ['str'])),
                                    ])
                                    self.address = None
                                    self.virtual_host = None
                                    self._segment_path = lambda: "ipv6"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/virtual-ip/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.VirtualIp.Ipv6, ['address', 'virtual_host'], name, value)


                        class WatchList(Entity):
                            """
                            Watch List of webauth clients
                            
                            .. attribute:: enabled
                            
                            	Enable Watchlist
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dynamic_expiry_timeout
                            
                            	dynamic\_expiry\_timeout
                            	**type**\: int
                            
                            	**range:** 0..2147483
                            
                            .. attribute:: add_item
                            
                            	Add item to Watch\-list
                            	**type**\:  :py:class:`AddItem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.WatchList.AddItem>`
                            
                            

                            """

                            _prefix = 'ios-policy'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.WatchList, self).__init__()

                                self.yang_name = "watch-list"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("add-item", ("add_item", Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.WatchList.AddItem))])
                                self._leafs = OrderedDict([
                                    ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                                    ('dynamic_expiry_timeout', (YLeaf(YType.uint32, 'dynamic-expiry-timeout'), ['int'])),
                                ])
                                self.enabled = None
                                self.dynamic_expiry_timeout = None

                                self.add_item = Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.WatchList.AddItem()
                                self.add_item.parent = self
                                self._children_name_map["add_item"] = "add-item"
                                self._segment_path = lambda: "watch-list"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.WatchList, ['enabled', 'dynamic_expiry_timeout'], name, value)


                            class AddItem(Entity):
                                """
                                Add item to Watch\-list
                                
                                .. attribute:: ipv4
                                
                                	IPv4 Watch List Entry
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 Watch List Entry
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-policy'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.WatchList.AddItem, self).__init__()

                                    self.yang_name = "add-item"
                                    self.yang_parent_name = "watch-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "add-item"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-policy:webauth-global/webauth/global/watch-list/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.ParameterMap.Type.WebauthGlobal.Webauth.Global.WatchList.AddItem, ['ipv4', 'ipv6'], name, value)


            class Umbrella(Entity):
                """
                Umbrella mode
                
                .. attribute:: global_
                
                	umbrella global parameter\-map
                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Umbrella.Global>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-umbrella'
                _revision = '2018-05-14'

                def __init__(self):
                    super(Native.ParameterMap.Type.Umbrella, self).__init__()

                    self.yang_name = "umbrella"
                    self.yang_parent_name = "type"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("global", ("global_", Native.ParameterMap.Type.Umbrella.Global))])
                    self._leafs = OrderedDict()

                    self.global_ = None
                    self._children_name_map["global_"] = "global"
                    self._segment_path = lambda: "Cisco-IOS-XE-umbrella:umbrella"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ParameterMap.Type.Umbrella, [], name, value)


                class Global(Entity):
                    """
                    umbrella global parameter\-map
                    
                    .. attribute:: token
                    
                    	Config umbrella token
                    	**type**\: str
                    
                    	**length:** 1..64
                    
                    .. attribute:: local_domain
                    
                    	Local domain processing
                    	**type**\: str
                    
                    	**length:** 1..256
                    
                    .. attribute:: dnscrypt
                    
                    	Enable DNSCrypt
                    	**type**\: bool
                    
                    	**default value**\: true
                    
                    .. attribute:: public_key
                    
                    	DNSCrypt provider public key
                    	**type**\: str
                    
                    	**length:** 1..80
                    
                    .. attribute:: udp_timeout
                    
                    	Config timeout value for UDP sessions
                    	**type**\: int
                    
                    	**range:** 1..30
                    
                    .. attribute:: resolver
                    
                    	Anycast address
                    	**type**\:  :py:class:`Resolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Umbrella.Global.Resolver>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-umbrella'
                    _revision = '2018-05-14'

                    def __init__(self):
                        super(Native.ParameterMap.Type.Umbrella.Global, self).__init__()

                        self.yang_name = "global"
                        self.yang_parent_name = "umbrella"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("resolver", ("resolver", Native.ParameterMap.Type.Umbrella.Global.Resolver))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('token', (YLeaf(YType.str, 'token'), ['str'])),
                            ('local_domain', (YLeaf(YType.str, 'local-domain'), ['str'])),
                            ('dnscrypt', (YLeaf(YType.boolean, 'dnscrypt'), ['bool'])),
                            ('public_key', (YLeaf(YType.str, 'public-key'), ['str'])),
                            ('udp_timeout', (YLeaf(YType.uint8, 'udp-timeout'), ['int'])),
                        ])
                        self.token = None
                        self.local_domain = None
                        self.dnscrypt = None
                        self.public_key = None
                        self.udp_timeout = None

                        self.resolver = Native.ParameterMap.Type.Umbrella.Global.Resolver()
                        self.resolver.parent = self
                        self._children_name_map["resolver"] = "resolver"
                        self._segment_path = lambda: "global"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-umbrella:umbrella/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ParameterMap.Type.Umbrella.Global, ['token', 'local_domain', 'dnscrypt', 'public_key', 'udp_timeout'], name, value)


                    class Resolver(Entity):
                        """
                        Anycast address
                        
                        .. attribute:: ipv4
                        
                        	IPv4 anycast address
                        	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Umbrella.Global.Resolver.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	IPv6 anycast address
                        	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ParameterMap.Type.Umbrella.Global.Resolver.Ipv6>`
                        
                        

                        """

                        _prefix = 'ios-umbrella'
                        _revision = '2018-05-14'

                        def __init__(self):
                            super(Native.ParameterMap.Type.Umbrella.Global.Resolver, self).__init__()

                            self.yang_name = "resolver"
                            self.yang_parent_name = "global"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.ParameterMap.Type.Umbrella.Global.Resolver.Ipv4)), ("ipv6", ("ipv6", Native.ParameterMap.Type.Umbrella.Global.Resolver.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = YList(self)
                            self.ipv6 = YList(self)
                            self._segment_path = lambda: "resolver"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-umbrella:umbrella/global/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ParameterMap.Type.Umbrella.Global.Resolver, [], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 anycast address
                            
                            .. attribute:: address  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-umbrella'
                            _revision = '2018-05-14'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Umbrella.Global.Resolver.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ipv4" + "[address='" + str(self.address) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-umbrella:umbrella/global/resolver/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Umbrella.Global.Resolver.Ipv4, ['address'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 anycast address
                            
                            .. attribute:: address  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-umbrella'
                            _revision = '2018-05-14'

                            def __init__(self):
                                super(Native.ParameterMap.Type.Umbrella.Global.Resolver.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ipv6" + "[address='" + str(self.address) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/parameter-map/type/Cisco-IOS-XE-umbrella:umbrella/global/resolver/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.ParameterMap.Type.Umbrella.Global.Resolver.Ipv6, ['address'], name, value)


    class Ppp(Entity):
        """
        PPP global configuration
        
        .. attribute:: packet
        
        	Configure control packet rate throttling
        	**type**\:  :py:class:`Packet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ppp.Packet>`
        
        .. attribute:: analysis_module
        
        	Configure NAM on the interface
        	**type**\:  :py:class:`AnalysisModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ppp.AnalysisModule>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Ppp, self).__init__()

            self.yang_name = "ppp"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-ppp:packet", ("packet", Native.Ppp.Packet)), ("Cisco-IOS-XE-nam:analysis-module", ("analysis_module", Native.Ppp.AnalysisModule))])
            self._leafs = OrderedDict()

            self.packet = Native.Ppp.Packet()
            self.packet.parent = self
            self._children_name_map["packet"] = "Cisco-IOS-XE-ppp:packet"

            self.analysis_module = Native.Ppp.AnalysisModule()
            self.analysis_module.parent = self
            self._children_name_map["analysis_module"] = "Cisco-IOS-XE-nam:analysis-module"
            self._segment_path = lambda: "ppp"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Ppp, [], name, value)


        class Packet(Entity):
            """
            Configure control packet rate throttling
            
            .. attribute:: throttle
            
            	Configure control packet rate throttling
            	**type**\: int
            
            	**range:** 1..100000
            
            .. attribute:: allow_time
            
            	
            	**type**\: int
            
            	**range:** 1..3600
            
            .. attribute:: block_time
            
            	
            	**type**\: int
            
            	**range:** 2..3600
            
            

            """

            _prefix = 'ios-ppp'
            _revision = '2018-02-03'

            def __init__(self):
                super(Native.Ppp.Packet, self).__init__()

                self.yang_name = "packet"
                self.yang_parent_name = "ppp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('throttle', (YLeaf(YType.uint32, 'throttle'), ['int'])),
                    ('allow_time', (YLeaf(YType.uint32, 'allow_time'), ['int'])),
                    ('block_time', (YLeaf(YType.uint32, 'block_time'), ['int'])),
                ])
                self.throttle = None
                self.allow_time = None
                self.block_time = None
                self._segment_path = lambda: "Cisco-IOS-XE-ppp:packet"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ppp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ppp.Packet, ['throttle', 'allow_time', 'block_time'], name, value)


        class AnalysisModule(Entity):
            """
            Configure NAM on the interface
            
            .. attribute:: monitoring
            
            	Configure NAM monitoring on the interface
            	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ppp.AnalysisModule.Monitoring>`
            
            

            """

            _prefix = 'ios-nam'
            _revision = '2017-12-28'

            def __init__(self):
                super(Native.Ppp.AnalysisModule, self).__init__()

                self.yang_name = "analysis-module"
                self.yang_parent_name = "ppp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Ppp.AnalysisModule.Monitoring))])
                self._leafs = OrderedDict()

                self.monitoring = Native.Ppp.AnalysisModule.Monitoring()
                self.monitoring.parent = self
                self._children_name_map["monitoring"] = "monitoring"
                self._segment_path = lambda: "Cisco-IOS-XE-nam:analysis-module"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ppp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ppp.AnalysisModule, [], name, value)


            class Monitoring(Entity):
                """
                Configure NAM monitoring on the interface
                
                .. attribute:: interface_name
                
                	The name of the output interface.  E.g., 'ucse 1/0/0'
                	**type**\: str
                
                

                """

                _prefix = 'ios-nam'
                _revision = '2017-12-28'

                def __init__(self):
                    super(Native.Ppp.AnalysisModule.Monitoring, self).__init__()

                    self.yang_name = "monitoring"
                    self.yang_parent_name = "analysis-module"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                    ])
                    self.interface_name = None
                    self._segment_path = lambda: "monitoring"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ppp/Cisco-IOS-XE-nam:analysis-module/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ppp.AnalysisModule.Monitoring, ['interface_name'], name, value)


    class Mac(Entity):
        """
        Global MAC configuration subcommands
        
        .. attribute:: address_table
        
        	Configure the MAC address table
        	**type**\:  :py:class:`AddressTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AddressTable>`
        
        .. attribute:: access_list
        
        	Named access\-list
        	**type**\:  :py:class:`AccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AccessList>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Mac, self).__init__()

            self.yang_name = "mac"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("address-table", ("address_table", Native.Mac.AddressTable)), ("Cisco-IOS-XE-acl:access-list", ("access_list", Native.Mac.AccessList))])
            self._leafs = OrderedDict()

            self.address_table = Native.Mac.AddressTable()
            self.address_table.parent = self
            self._children_name_map["address_table"] = "address-table"

            self.access_list = Native.Mac.AccessList()
            self.access_list.parent = self
            self._children_name_map["access_list"] = "Cisco-IOS-XE-acl:access-list"
            self._segment_path = lambda: "mac"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Mac, [], name, value)


        class AddressTable(Entity):
            """
            Configure the MAC address table
            
            .. attribute:: aging_time
            
            	Set MAC address table entry maximum age
            	**type**\:  :py:class:`AgingTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AddressTable.AgingTime>`
            
            .. attribute:: control_packet_learn
            
            	Enable/Disable learning from Control Packets
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: learning
            
            	Enable MAC table learning feature
            	**type**\:  :py:class:`Learning <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AddressTable.Learning>`
            
            .. attribute:: notification
            
            	Enable/Disable MAC Notification on the switch
            	**type**\:  :py:class:`Notification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AddressTable.Notification>`
            
            .. attribute:: static
            
            	Static MAC entry
            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AddressTable.Static>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Mac.AddressTable, self).__init__()

                self.yang_name = "address-table"
                self.yang_parent_name = "mac"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("aging-time", ("aging_time", Native.Mac.AddressTable.AgingTime)), ("learning", ("learning", Native.Mac.AddressTable.Learning)), ("notification", ("notification", Native.Mac.AddressTable.Notification)), ("static", ("static", Native.Mac.AddressTable.Static))])
                self._leafs = OrderedDict([
                    ('control_packet_learn', (YLeaf(YType.empty, 'control-packet-learn'), ['Empty'])),
                ])
                self.control_packet_learn = None

                self.aging_time = Native.Mac.AddressTable.AgingTime()
                self.aging_time.parent = self
                self._children_name_map["aging_time"] = "aging-time"

                self.learning = Native.Mac.AddressTable.Learning()
                self.learning.parent = self
                self._children_name_map["learning"] = "learning"

                self.notification = Native.Mac.AddressTable.Notification()
                self.notification.parent = self
                self._children_name_map["notification"] = "notification"

                self.static = Native.Mac.AddressTable.Static()
                self.static.parent = self
                self._children_name_map["static"] = "static"
                self._segment_path = lambda: "address-table"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mac.AddressTable, [u'control_packet_learn'], name, value)


            class AgingTime(Entity):
                """
                Set MAC address table entry maximum age
                
                .. attribute:: val
                
                	
                	**type**\: int
                
                	**range:** 0..None \| 10..1000000
                
                .. attribute:: routed_mac
                
                	Set RM Aging interval
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	VLAN Keyword
                	**type**\: int
                
                	**range:** 1..4094
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Mac.AddressTable.AgingTime, self).__init__()

                    self.yang_name = "aging-time"
                    self.yang_parent_name = "address-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('val', (YLeaf(YType.uint32, 'val'), ['int'])),
                        ('routed_mac', (YLeaf(YType.empty, 'routed-mac'), ['Empty'])),
                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                    ])
                    self.val = None
                    self.routed_mac = None
                    self.vlan = None
                    self._segment_path = lambda: "aging-time"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac/address-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mac.AddressTable.AgingTime, [u'val', u'routed_mac', u'vlan'], name, value)


            class Learning(Entity):
                """
                Enable MAC table learning feature
                
                .. attribute:: vlan
                
                	<1\-4094>;;VLAN id to enable MAC Address learning
                	**type**\: int
                
                	**range:** 1..4094
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Mac.AddressTable.Learning, self).__init__()

                    self.yang_name = "learning"
                    self.yang_parent_name = "address-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                    ])
                    self.vlan = None
                    self._segment_path = lambda: "learning"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac/address-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mac.AddressTable.Learning, [u'vlan'], name, value)


            class Notification(Entity):
                """
                Enable/Disable MAC Notification on the switch
                
                .. attribute:: change
                
                	Enable/Disable MAC Notification feature on the switch
                	**type**\:  :py:class:`Change <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AddressTable.Notification.Change>`
                
                	**presence node**\: True
                
                .. attribute:: mac_move
                
                	Enable Mac Move Notification
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: threshold
                
                	Configure L2 Table monitoring
                	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AddressTable.Notification.Threshold>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Mac.AddressTable.Notification, self).__init__()

                    self.yang_name = "notification"
                    self.yang_parent_name = "address-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("change", ("change", Native.Mac.AddressTable.Notification.Change)), ("threshold", ("threshold", Native.Mac.AddressTable.Notification.Threshold))])
                    self._leafs = OrderedDict([
                        ('mac_move', (YLeaf(YType.empty, 'mac-move'), ['Empty'])),
                    ])
                    self.mac_move = None

                    self.change = None
                    self._children_name_map["change"] = "change"

                    self.threshold = None
                    self._children_name_map["threshold"] = "threshold"
                    self._segment_path = lambda: "notification"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac/address-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mac.AddressTable.Notification, [u'mac_move'], name, value)


                class Change(Entity):
                    """
                    Enable/Disable MAC Notification feature on the switch
                    
                    .. attribute:: history_size
                    
                    	Number of entries in history table (0\-500)
                    	**type**\: int
                    
                    	**range:** 0..500
                    
                    .. attribute:: interval
                    
                    	Notification interval in seconds (0\-2147483647)
                    	**type**\: int
                    
                    	**range:** 0..2147483647
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Mac.AddressTable.Notification.Change, self).__init__()

                        self.yang_name = "change"
                        self.yang_parent_name = "notification"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('history_size', (YLeaf(YType.uint16, 'history-size'), ['int'])),
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                        ])
                        self.history_size = None
                        self.interval = None
                        self._segment_path = lambda: "change"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac/address-table/notification/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mac.AddressTable.Notification.Change, [u'history_size', u'interval'], name, value)


                class Threshold(Entity):
                    """
                    Configure L2 Table monitoring
                    
                    .. attribute:: interval
                    
                    	<120\-1000000> Interval time in seconds
                    	**type**\: int
                    
                    	**range:** 120..1000000
                    
                    .. attribute:: limit
                    
                    	Limit percentage
                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AddressTable.Notification.Threshold.Limit>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Mac.AddressTable.Notification.Threshold, self).__init__()

                        self.yang_name = "threshold"
                        self.yang_parent_name = "notification"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("limit", ("limit", Native.Mac.AddressTable.Notification.Threshold.Limit))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                        ])
                        self.interval = None

                        self.limit = Native.Mac.AddressTable.Notification.Threshold.Limit()
                        self.limit.parent = self
                        self._children_name_map["limit"] = "limit"
                        self._segment_path = lambda: "threshold"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac/address-table/notification/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mac.AddressTable.Notification.Threshold, [u'interval'], name, value)


                    class Limit(Entity):
                        """
                        Limit percentage
                        
                        .. attribute:: percentage
                        
                        	Percentage (0\-100)
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        .. attribute:: interval
                        
                        	<120\-1000000> Interval time in seconds
                        	**type**\: int
                        
                        	**range:** 120..1000000
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Mac.AddressTable.Notification.Threshold.Limit, self).__init__()

                            self.yang_name = "limit"
                            self.yang_parent_name = "threshold"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('percentage', (YLeaf(YType.uint8, 'percentage'), ['int'])),
                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                            ])
                            self.percentage = None
                            self.interval = None
                            self._segment_path = lambda: "limit"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac/address-table/notification/threshold/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mac.AddressTable.Notification.Threshold.Limit, [u'percentage', u'interval'], name, value)


            class Static(Entity):
                """
                Static MAC entry
                
                .. attribute:: mac_address
                
                	xxxx.xxxx.xxxx 48 bit mac address
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                
                .. attribute:: vlan
                
                	<1\-4094> VLAN id of mac address table (1\-4094)
                	**type**\: int
                
                	**range:** 1..4094
                
                .. attribute:: drop
                
                	drop frames
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface
                
                	Output interface exact long name
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Mac.AddressTable.Static, self).__init__()

                    self.yang_name = "static"
                    self.yang_parent_name = "address-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                    ])
                    self.mac_address = None
                    self.vlan = None
                    self.drop = None
                    self.interface = None
                    self._segment_path = lambda: "static"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac/address-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mac.AddressTable.Static, [u'mac_address', u'vlan', u'drop', u'interface'], name, value)


        class AccessList(Entity):
            """
            Named access\-list
            
            .. attribute:: extended
            
            	Extended Access List
            	**type**\: list of  		 :py:class:`Extended <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AccessList.Extended>`
            
            

            """

            _prefix = 'ios-acl'
            _revision = '2018-05-31'

            def __init__(self):
                super(Native.Mac.AccessList, self).__init__()

                self.yang_name = "access-list"
                self.yang_parent_name = "mac"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("extended", ("extended", Native.Mac.AccessList.Extended))])
                self._leafs = OrderedDict()

                self.extended = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-acl:access-list"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mac.AccessList, [], name, value)


            class Extended(Entity):
                """
                Extended Access List
                
                .. attribute:: id  (key)
                
                	
                	**type**\: str
                
                .. attribute:: entry
                
                	
                	**type**\: list of  		 :py:class:`Entry <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AccessList.Extended.Entry>`
                
                

                """

                _prefix = 'ios-acl'
                _revision = '2018-05-31'

                def __init__(self):
                    super(Native.Mac.AccessList.Extended, self).__init__()

                    self.yang_name = "extended"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("entry", ("entry", Native.Mac.AccessList.Extended.Entry))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                    ])
                    self.id = None

                    self.entry = YList(self)
                    self._segment_path = lambda: "extended" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mac/Cisco-IOS-XE-acl:access-list/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mac.AccessList.Extended, ['id'], name, value)


                class Entry(Entity):
                    """
                    
                    
                    .. attribute:: action  (key)
                    
                    	
                    	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mac.AccessList.Extended.Entry.Action>`
                    
                    .. attribute:: values  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9a\-f]{4}[.][0\-9a\-f]{4}[.][0\-9a\-f]{4}\|host) [0\-9a\-f]{4}[.][0\-9a\-f]{4}[.][0\-9a\-f]{4}) (([0\-9a\-f]{4}[.][0\-9a\-f]{4}[.][0\-9a\-f]{4}\|host) [0\-9a\-f]{4}[.][0\-9a\-f]{4}[.][0\-9a\-f]{4})( (0x0\|0x[1\-9A\-F][0\-9A\-F]{,3}) (0x0\|0x[1\-9A\-F][0\-9A\-F]{,3}))?
                    
                    

                    """

                    _prefix = 'ios-acl'
                    _revision = '2018-05-31'

                    def __init__(self):
                        super(Native.Mac.AccessList.Extended.Entry, self).__init__()

                        self.yang_name = "entry"
                        self.yang_parent_name = "extended"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['action','values']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('action', (YLeaf(YType.enumeration, 'action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mac.AccessList.Extended.Entry.Action')])),
                            ('values', (YLeaf(YType.str, 'values'), ['str'])),
                        ])
                        self.action = None
                        self.values = None
                        self._segment_path = lambda: "entry" + "[action='" + str(self.action) + "']" + "[values='" + str(self.values) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mac.AccessList.Extended.Entry, ['action', 'values'], name, value)

                    class Action(Enum):
                        """
                        Action (Enum Class)

                        .. data:: deny = 0

                        .. data:: permit = 1

                        """

                        deny = Enum.YLeaf(0, "deny")

                        permit = Enum.YLeaf(1, "permit")



    class Tacacs(Entity):
        """
        TACACS server configuration command
        
        .. attribute:: server
        
        	Server configuration
        	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Tacacs.Server>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Tacacs, self).__init__()

            self.yang_name = "tacacs"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-aaa:server", ("server", Native.Tacacs.Server))])
            self._leafs = OrderedDict()

            self.server = YList(self)
            self._segment_path = lambda: "tacacs"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Tacacs, [], name, value)


        class Server(Entity):
            """
            Server configuration
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: address
            
            	Specify ip address for tacacs server
            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Tacacs.Server.Address>`
            
            .. attribute:: port
            
            	Configure port for tacacs server
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: timeout
            
            	Configure timeout for tacacs server
            	**type**\: int
            
            	**range:** 1..1000
            
            .. attribute:: key
            
            	per\-server encryption key (overrides default)
            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Tacacs.Server.Key>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Tacacs.Server, self).__init__()

                self.yang_name = "server"
                self.yang_parent_name = "tacacs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("address", ("address", Native.Tacacs.Server.Address)), ("key", ("key", Native.Tacacs.Server.Key))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                    ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                ])
                self.name = None
                self.port = None
                self.timeout = None

                self.address = Native.Tacacs.Server.Address()
                self.address.parent = self
                self._children_name_map["address"] = "address"

                self.key = Native.Tacacs.Server.Key()
                self.key.parent = self
                self._children_name_map["key"] = "key"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:server" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/tacacs/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Tacacs.Server, ['name', 'port', 'timeout'], name, value)


            class Address(Entity):
                """
                Specify ip address for tacacs server
                
                .. attribute:: ipv4
                
                	Configure ipv4 address for tacacs server
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Tacacs.Server.Address, self).__init__()

                    self.yang_name = "address"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str','str'])),
                    ])
                    self.ipv4 = None
                    self._segment_path = lambda: "address"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Tacacs.Server.Address, ['ipv4'], name, value)


            class Key(Entity):
                """
                per\-server encryption key (overrides default)
                
                .. attribute:: encryption
                
                	
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Tacacs.Server.Key.Encryption>`
                
                .. attribute:: key
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Tacacs.Server.Key, self).__init__()

                    self.yang_name = "key"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Tacacs.Server.Key.Encryption')])),
                        ('key', (YLeaf(YType.str, 'key'), ['str'])),
                    ])
                    self.encryption = None
                    self.key = None
                    self._segment_path = lambda: "key"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Tacacs.Server.Key, ['encryption', 'key'], name, value)

                class Encryption(Enum):
                    """
                    Encryption (Enum Class)

                    .. data:: Y_0 = 0

                    .. data:: Y_7 = 1

                    """

                    Y_0 = Enum.YLeaf(0, "0")

                    Y_7 = Enum.YLeaf(1, "7")



    class TacacsServer(Entity):
        """
        Modify TACACS query parameters
        
        .. attribute:: host
        
        	Specify a TACACS server
        	**type**\: list of  		 :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TacacsServer.Host>`
        
        .. attribute:: timeout
        
        	Time to wait for a TACACS server to reply
        	**type**\: int
        
        	**range:** 1..1000
        
        .. attribute:: directed_request
        
        	Allow user to specify tacacs server to use with `@server'
        	**type**\:  :py:class:`DirectedRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TacacsServer.DirectedRequest>`
        
        	**presence node**\: True
        
        .. attribute:: key
        
        	Set TACACS+ encryption key
        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TacacsServer.Key>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.TacacsServer, self).__init__()

            self.yang_name = "tacacs-server"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-aaa:host", ("host", Native.TacacsServer.Host)), ("Cisco-IOS-XE-aaa:directed-request", ("directed_request", Native.TacacsServer.DirectedRequest)), ("Cisco-IOS-XE-aaa:key", ("key", Native.TacacsServer.Key))])
            self._leafs = OrderedDict([
                ('timeout', (YLeaf(YType.uint16, 'Cisco-IOS-XE-aaa:timeout'), ['int'])),
            ])
            self.timeout = None

            self.directed_request = None
            self._children_name_map["directed_request"] = "Cisco-IOS-XE-aaa:directed-request"

            self.key = Native.TacacsServer.Key()
            self.key.parent = self
            self._children_name_map["key"] = "Cisco-IOS-XE-aaa:key"

            self.host = YList(self)
            self._segment_path = lambda: "tacacs-server"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.TacacsServer, ['timeout'], name, value)


        class Host(Entity):
            """
            Specify a TACACS server
            
            .. attribute:: name  (key)
            
            	
            	**type**\: union of the below types:
            
            		**type**\: str
            
            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            		**type**\: str
            
            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            		**type**\: str
            
            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
            
            .. attribute:: port
            
            	TCP port for TACACS+ server (default is 49)
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: key
            
            	Set TACACS+ encryption key
            	**type**\: union of the below types:
            
            		**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TacacsServer.Host.Key>`
            
            		**type**\: str
            
            .. attribute:: encryption_key
            
            	
            	**type**\: str
            
            .. attribute:: timeout
            
            	Time to wait for this TACACS server to reply (overrides default)
            	**type**\: int
            
            	**range:** 1..1000
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.TacacsServer.Host, self).__init__()

                self.yang_name = "host"
                self.yang_parent_name = "tacacs-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str','str','str'])),
                    ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                    ('key', (YLeaf(YType.str, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'TacacsServer.Host.Key'),'str'])),
                    ('encryption_key', (YLeaf(YType.str, 'encryption-key'), ['str'])),
                    ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                ])
                self.name = None
                self.port = None
                self.key = None
                self.encryption_key = None
                self.timeout = None
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:host" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/tacacs-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.TacacsServer.Host, ['name', 'port', 'key', 'encryption_key', 'timeout'], name, value)

            class Key(Enum):
                """
                Key (Enum Class)

                Set TACACS+ encryption key.

                .. data:: Y_0 = 0

                .. data:: Y_7 = 1

                """

                Y_0 = Enum.YLeaf(0, "0")

                Y_7 = Enum.YLeaf(1, "7")



        class DirectedRequest(Entity):
            """
            Allow user to specify tacacs server to use with `@server'
            
            .. attribute:: restricted
            
            	restrict queries to directed request servers only
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: no_truncate
            
            	Do not truncate the @hostname from username
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.TacacsServer.DirectedRequest, self).__init__()

                self.yang_name = "directed-request"
                self.yang_parent_name = "tacacs-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('restricted', (YLeaf(YType.empty, 'restricted'), ['Empty'])),
                    ('no_truncate', (YLeaf(YType.empty, 'no-truncate'), ['Empty'])),
                ])
                self.restricted = None
                self.no_truncate = None
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:directed-request"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/tacacs-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.TacacsServer.DirectedRequest, ['restricted', 'no_truncate'], name, value)


        class Key(Entity):
            """
            Set TACACS+ encryption key.
            
            .. attribute:: encryption
            
            	
            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TacacsServer.Key.Encryption>`
            
            .. attribute:: key
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.TacacsServer.Key, self).__init__()

                self.yang_name = "key"
                self.yang_parent_name = "tacacs-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'TacacsServer.Key.Encryption')])),
                    ('key', (YLeaf(YType.str, 'key'), ['str'])),
                ])
                self.encryption = None
                self.key = None
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:key"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/tacacs-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.TacacsServer.Key, ['encryption', 'key'], name, value)

            class Encryption(Enum):
                """
                Encryption (Enum Class)

                .. data:: Y_0 = 0

                .. data:: Y_7 = 1

                """

                Y_0 = Enum.YLeaf(0, "0")

                Y_7 = Enum.YLeaf(1, "7")



    class Software(Entity):
        """
        Configure software installation parameters
        
        .. attribute:: auto_upgrade
        
        	Configure software auto upgrade parameters
        	**type**\:  :py:class:`AutoUpgrade <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Software.AutoUpgrade>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Software, self).__init__()

            self.yang_name = "software"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("auto-upgrade", ("auto_upgrade", Native.Software.AutoUpgrade))])
            self._leafs = OrderedDict()

            self.auto_upgrade = Native.Software.AutoUpgrade()
            self.auto_upgrade.parent = self
            self._children_name_map["auto_upgrade"] = "auto-upgrade"
            self._segment_path = lambda: "software"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Software, [], name, value)


        class AutoUpgrade(Entity):
            """
            Configure software auto upgrade parameters
            
            .. attribute:: enable
            
            	Enable the auto upgrade installation feature
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Software.AutoUpgrade, self).__init__()

                self.yang_name = "auto-upgrade"
                self.yang_parent_name = "software"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                ])
                self.enable = None
                self._segment_path = lambda: "auto-upgrade"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/software/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Software.AutoUpgrade, [u'enable'], name, value)


    class Upgrade(Entity):
        """
        Global upgrade configuration subcommands
        
        .. attribute:: fpd
        
        	Configure field programmable devices upgrade options
        	**type**\:  :py:class:`Fpd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Upgrade.Fpd>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Upgrade, self).__init__()

            self.yang_name = "upgrade"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("fpd", ("fpd", Native.Upgrade.Fpd))])
            self._leafs = OrderedDict()

            self.fpd = Native.Upgrade.Fpd()
            self.fpd.parent = self
            self._children_name_map["fpd"] = "fpd"
            self._segment_path = lambda: "upgrade"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Upgrade, [], name, value)


        class Fpd(Entity):
            """
            Configure field programmable devices upgrade options
            
            .. attribute:: auto
            
            	Auto upgrade all FPD images
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: path
            
            	Set path to locate the FPD image package file for auto upgrade
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Upgrade.Fpd, self).__init__()

                self.yang_name = "fpd"
                self.yang_parent_name = "upgrade"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('auto', (YLeaf(YType.empty, 'auto'), ['Empty'])),
                    ('path', (YLeaf(YType.str, 'path'), ['str'])),
                ])
                self.auto = None
                self.path = None
                self._segment_path = lambda: "fpd"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/upgrade/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Upgrade.Fpd, [u'auto', u'path'], name, value)


    class Vtp(Entity):
        """
        Configure global VTP state
        
        .. attribute:: file
        
        	Configure IFS filesystem file where VTP configuration is stored
        	**type**\: str
        
        .. attribute:: interface
        
        	Configure Interface as the preferred source for the VTP IP updater address
        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vtp.Interface>`
        
        .. attribute:: password
        
        	Set the password for the VTP administrative domain
        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vtp.Password>`
        
        .. attribute:: pruning
        
        	Set the adminstrative domain to permit pruning
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: version
        
        	Set the adminstrative domain to VTP version
        	**type**\: int
        
        	**range:** 1..3
        
        .. attribute:: domain
        
        	Set the name of the VTP administrative domain
        	**type**\: str
        
        .. attribute:: mode
        
        	Configure VTP device mode
        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vtp.Mode>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Vtp, self).__init__()

            self.yang_name = "vtp"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-vtp:interface", ("interface", Native.Vtp.Interface)), ("Cisco-IOS-XE-vtp:password", ("password", Native.Vtp.Password)), ("Cisco-IOS-XE-vtp:mode", ("mode", Native.Vtp.Mode))])
            self._leafs = OrderedDict([
                ('file', (YLeaf(YType.str, 'Cisco-IOS-XE-vtp:file'), ['str'])),
                ('pruning', (YLeaf(YType.empty, 'Cisco-IOS-XE-vtp:pruning'), ['Empty'])),
                ('version', (YLeaf(YType.uint8, 'Cisco-IOS-XE-vtp:version'), ['int'])),
                ('domain', (YLeaf(YType.str, 'Cisco-IOS-XE-vtp:domain'), ['str'])),
            ])
            self.file = None
            self.pruning = None
            self.version = None
            self.domain = None

            self.interface = Native.Vtp.Interface()
            self.interface.parent = self
            self._children_name_map["interface"] = "Cisco-IOS-XE-vtp:interface"

            self.password = Native.Vtp.Password()
            self.password.parent = self
            self._children_name_map["password"] = "Cisco-IOS-XE-vtp:password"

            self.mode = Native.Vtp.Mode()
            self.mode.parent = self
            self._children_name_map["mode"] = "Cisco-IOS-XE-vtp:mode"
            self._segment_path = lambda: "vtp"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Vtp, [u'file', u'pruning', u'version', u'domain'], name, value)


        class Interface(Entity):
            """
            Configure Interface as the preferred source for the VTP IP updater address
            
            .. attribute:: interface_name
            
            	The name of the interface providing the VTP updater ID for this device
            	**type**\: str
            
            .. attribute:: only
            
            	Use only this interface's IP address as the VTP IP updater address
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-vtp'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Vtp.Interface, self).__init__()

                self.yang_name = "interface"
                self.yang_parent_name = "vtp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                    ('only', (YLeaf(YType.empty, 'only'), ['Empty'])),
                ])
                self.interface_name = None
                self.only = None
                self._segment_path = lambda: "Cisco-IOS-XE-vtp:interface"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vtp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vtp.Interface, [u'interface_name', u'only'], name, value)


        class Password(Entity):
            """
            Set the password for the VTP administrative domain
            
            .. attribute:: password
            
            	The ascii password for the VTP administrative domain
            	**type**\: str
            
            .. attribute:: hidden
            
            	Set the VTP password hidden option
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: secret
            
            	Specify the vtp password in encrypted form
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-vtp'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Vtp.Password, self).__init__()

                self.yang_name = "password"
                self.yang_parent_name = "vtp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('password', (YLeaf(YType.str, 'password'), ['str'])),
                    ('hidden', (YLeaf(YType.empty, 'hidden'), ['Empty'])),
                    ('secret', (YLeaf(YType.empty, 'secret'), ['Empty'])),
                ])
                self.password = None
                self.hidden = None
                self.secret = None
                self._segment_path = lambda: "Cisco-IOS-XE-vtp:password"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vtp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vtp.Password, [u'password', u'hidden', u'secret'], name, value)


        class Mode(Entity):
            """
            Configure VTP device mode
            
            .. attribute:: client
            
            	Set the device to client mode
            	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vtp.Mode.Client>`
            
            	**presence node**\: True
            
            .. attribute:: off
            
            	Set the device to off mode
            	**type**\:  :py:class:`Off <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vtp.Mode.Off>`
            
            	**presence node**\: True
            
            .. attribute:: server
            
            	Set the device to server mode
            	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vtp.Mode.Server>`
            
            	**presence node**\: True
            
            .. attribute:: transparent
            
            	Set the device to transparent mode
            	**type**\:  :py:class:`Transparent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vtp.Mode.Transparent>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios-vtp'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Vtp.Mode, self).__init__()

                self.yang_name = "mode"
                self.yang_parent_name = "vtp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("client", ("client", Native.Vtp.Mode.Client)), ("off", ("off", Native.Vtp.Mode.Off)), ("server", ("server", Native.Vtp.Mode.Server)), ("transparent", ("transparent", Native.Vtp.Mode.Transparent))])
                self._leafs = OrderedDict()

                self.client = None
                self._children_name_map["client"] = "client"

                self.off = None
                self._children_name_map["off"] = "off"

                self.server = None
                self._children_name_map["server"] = "server"

                self.transparent = None
                self._children_name_map["transparent"] = "transparent"
                self._segment_path = lambda: "Cisco-IOS-XE-vtp:mode"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vtp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Vtp.Mode, [], name, value)


            class Client(Entity):
                """
                Set the device to client mode
                
                .. attribute:: mst
                
                	Set the mode for MST VTP instance
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: unknown
                
                	Set the mode for unknown VTP instances
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Set the mode for VLAN VTP instance
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-vtp'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Vtp.Mode.Client, self).__init__()

                    self.yang_name = "client"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mst', (YLeaf(YType.empty, 'mst'), ['Empty'])),
                        ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.mst = None
                    self.unknown = None
                    self.vlan = None
                    self._segment_path = lambda: "client"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vtp/Cisco-IOS-XE-vtp:mode/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vtp.Mode.Client, [u'mst', u'unknown', u'vlan'], name, value)


            class Off(Entity):
                """
                Set the device to off mode
                
                .. attribute:: mst
                
                	Set the mode for MST VTP instance
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: unknown
                
                	Set the mode for unknown VTP instances
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Set the mode for VLAN VTP instance
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-vtp'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Vtp.Mode.Off, self).__init__()

                    self.yang_name = "off"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mst', (YLeaf(YType.empty, 'mst'), ['Empty'])),
                        ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.mst = None
                    self.unknown = None
                    self.vlan = None
                    self._segment_path = lambda: "off"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vtp/Cisco-IOS-XE-vtp:mode/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vtp.Mode.Off, [u'mst', u'unknown', u'vlan'], name, value)


            class Server(Entity):
                """
                Set the device to server mode
                
                .. attribute:: mst
                
                	Set the mode for MST VTP instance
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: unknown
                
                	Set the mode for unknown VTP instances
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Set the mode for VLAN VTP instance
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-vtp'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Vtp.Mode.Server, self).__init__()

                    self.yang_name = "server"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mst', (YLeaf(YType.empty, 'mst'), ['Empty'])),
                        ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.mst = None
                    self.unknown = None
                    self.vlan = None
                    self._segment_path = lambda: "server"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vtp/Cisco-IOS-XE-vtp:mode/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vtp.Mode.Server, [u'mst', u'unknown', u'vlan'], name, value)


            class Transparent(Entity):
                """
                Set the device to transparent mode
                
                .. attribute:: mst
                
                	Set the mode for MST VTP instance
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: unknown
                
                	Set the mode for unknown VTP instances
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vlan
                
                	Set the mode for VLAN VTP instance
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-vtp'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Vtp.Mode.Transparent, self).__init__()

                    self.yang_name = "transparent"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mst', (YLeaf(YType.empty, 'mst'), ['Empty'])),
                        ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.mst = None
                    self.unknown = None
                    self.vlan = None
                    self._segment_path = lambda: "transparent"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/vtp/Cisco-IOS-XE-vtp:mode/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Vtp.Mode.Transparent, [u'mst', u'unknown', u'vlan'], name, value)


    class Xconnect(Entity):
        """
        
        
        .. attribute:: logging
        
        	
        	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Xconnect.Logging>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Xconnect, self).__init__()

            self.yang_name = "xconnect"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-l2vpn:logging", ("logging", Native.Xconnect.Logging))])
            self._leafs = OrderedDict()

            self.logging = Native.Xconnect.Logging()
            self.logging.parent = self
            self._children_name_map["logging"] = "Cisco-IOS-XE-l2vpn:logging"
            self._segment_path = lambda: "xconnect"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Xconnect, [], name, value)


        class Logging(Entity):
            """
            
            
            .. attribute:: pseudowire
            
            	
            	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Xconnect.Logging.Pseudowire>`
            
            .. attribute:: redundancy
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.Xconnect.Logging, self).__init__()

                self.yang_name = "logging"
                self.yang_parent_name = "xconnect"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("pseudowire", ("pseudowire", Native.Xconnect.Logging.Pseudowire))])
                self._leafs = OrderedDict([
                    ('redundancy', (YLeaf(YType.empty, 'redundancy'), ['Empty'])),
                ])
                self.redundancy = None

                self.pseudowire = Native.Xconnect.Logging.Pseudowire()
                self.pseudowire.parent = self
                self._children_name_map["pseudowire"] = "pseudowire"
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:logging"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/xconnect/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Xconnect.Logging, ['redundancy'], name, value)


            class Pseudowire(Entity):
                """
                
                
                .. attribute:: status
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.Xconnect.Logging.Pseudowire, self).__init__()

                    self.yang_name = "pseudowire"
                    self.yang_parent_name = "logging"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                    ])
                    self.status = None
                    self._segment_path = lambda: "pseudowire"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/xconnect/Cisco-IOS-XE-l2vpn:logging/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Xconnect.Logging.Pseudowire, ['status'], name, value)


    class Fabric(Entity):
        """
        Catalyst 6000 crossbar fabric configuration commands
        
        .. attribute:: switching_mode
        
        	Switching mode settings
        	**type**\:  :py:class:`SwitchingMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fabric.SwitchingMode>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Fabric, self).__init__()

            self.yang_name = "fabric"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("switching-mode", ("switching_mode", Native.Fabric.SwitchingMode))])
            self._leafs = OrderedDict()

            self.switching_mode = Native.Fabric.SwitchingMode()
            self.switching_mode.parent = self
            self._children_name_map["switching_mode"] = "switching-mode"
            self._segment_path = lambda: "fabric"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Fabric, [], name, value)


        class SwitchingMode(Entity):
            """
            Switching mode settings
            
            .. attribute:: allow
            
            	Allow settings
            	**type**\:  :py:class:`Allow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fabric.SwitchingMode.Allow>`
            
            .. attribute:: force
            
            	Force modules to different switching modes
            	**type**\:  :py:class:`Force <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fabric.SwitchingMode.Force>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Fabric.SwitchingMode, self).__init__()

                self.yang_name = "switching-mode"
                self.yang_parent_name = "fabric"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("allow", ("allow", Native.Fabric.SwitchingMode.Allow)), ("force", ("force", Native.Fabric.SwitchingMode.Force))])
                self._leafs = OrderedDict()

                self.allow = Native.Fabric.SwitchingMode.Allow()
                self.allow.parent = self
                self._children_name_map["allow"] = "allow"

                self.force = Native.Fabric.SwitchingMode.Force()
                self.force.parent = self
                self._children_name_map["force"] = "force"
                self._segment_path = lambda: "switching-mode"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/fabric/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Fabric.SwitchingMode, [], name, value)


            class Allow(Entity):
                """
                Allow settings
                
                .. attribute:: bus_mode
                
                	Allow switching in bus mode for modules
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: truncated
                
                	Truncated switching mode
                	**type**\:  :py:class:`Truncated <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fabric.SwitchingMode.Allow.Truncated>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Fabric.SwitchingMode.Allow, self).__init__()

                    self.yang_name = "allow"
                    self.yang_parent_name = "switching-mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("truncated", ("truncated", Native.Fabric.SwitchingMode.Allow.Truncated))])
                    self._leafs = OrderedDict([
                        ('bus_mode', (YLeaf(YType.empty, 'bus-mode'), ['Empty'])),
                    ])
                    self.bus_mode = None

                    self.truncated = None
                    self._children_name_map["truncated"] = "truncated"
                    self._segment_path = lambda: "allow"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/fabric/switching-mode/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Fabric.SwitchingMode.Allow, [u'bus_mode'], name, value)


                class Truncated(Entity):
                    """
                    Truncated switching mode
                    
                    .. attribute:: threshold
                    
                    	Number of SFM\-capable modules for truncated switching mode. Switch applies the threshold only when the mode is disallowed. Switch ignores the threshold when the truncated mode is allowed
                    	**type**\: int
                    
                    	**range:** 1..9
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Fabric.SwitchingMode.Allow.Truncated, self).__init__()

                        self.yang_name = "truncated"
                        self.yang_parent_name = "allow"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                        ])
                        self.threshold = None
                        self._segment_path = lambda: "truncated"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/fabric/switching-mode/allow/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Fabric.SwitchingMode.Allow.Truncated, [u'threshold'], name, value)


            class Force(Entity):
                """
                Force modules to different switching modes
                
                .. attribute:: bus_mode
                
                	Switching mode of service modules will be forced to bus\-mode by powercycling it
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Fabric.SwitchingMode.Force, self).__init__()

                    self.yang_name = "force"
                    self.yang_parent_name = "switching-mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('bus_mode', (YLeaf(YType.empty, 'bus-mode'), ['Empty'])),
                    ])
                    self.bus_mode = None
                    self._segment_path = lambda: "force"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/fabric/switching-mode/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Fabric.SwitchingMode.Force, [u'bus_mode'], name, value)


    class PortChannel(Entity):
        """
        EtherChannel configuration
        
        .. attribute:: auto
        
        	LACP auto for the system
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: load_balance
        
        	Load Balancing method
        	**type**\:  :py:class:`LoadBalance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PortChannel.LoadBalance>`
        
        .. attribute:: load_balancing
        
        	Load Balance method
        	**type**\:  :py:class:`LoadBalancing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PortChannel.LoadBalancing>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.PortChannel, self).__init__()

            self.yang_name = "port-channel"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-ethernet:load-balance", ("load_balance", Native.PortChannel.LoadBalance)), ("Cisco-IOS-XE-ethernet:load-balancing", ("load_balancing", Native.PortChannel.LoadBalancing))])
            self._leafs = OrderedDict([
                ('auto', (YLeaf(YType.empty, 'Cisco-IOS-XE-ethernet:auto'), ['Empty'])),
            ])
            self.auto = None

            self.load_balance = Native.PortChannel.LoadBalance()
            self.load_balance.parent = self
            self._children_name_map["load_balance"] = "Cisco-IOS-XE-ethernet:load-balance"

            self.load_balancing = Native.PortChannel.LoadBalancing()
            self.load_balancing.parent = self
            self._children_name_map["load_balancing"] = "Cisco-IOS-XE-ethernet:load-balancing"
            self._segment_path = lambda: "port-channel"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.PortChannel, ['auto'], name, value)


        class LoadBalance(Entity):
            """
            Load Balancing method
            
            .. attribute:: load_balance
            
            	
            	**type**\:  :py:class:`LoadBalance_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PortChannel.LoadBalance.LoadBalance_>`
            
            .. attribute:: extended
            
            	Extended Load Balance Methods
            	**type**\:  :py:class:`Extended <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PortChannel.LoadBalance.Extended>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios-eth'
            _revision = '2018-04-09'

            def __init__(self):
                super(Native.PortChannel.LoadBalance, self).__init__()

                self.yang_name = "load-balance"
                self.yang_parent_name = "port-channel"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("extended", ("extended", Native.PortChannel.LoadBalance.Extended))])
                self._leafs = OrderedDict([
                    ('load_balance', (YLeaf(YType.enumeration, 'load-balance'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'PortChannel.LoadBalance.LoadBalance_')])),
                ])
                self.load_balance = None

                self.extended = None
                self._children_name_map["extended"] = "extended"
                self._segment_path = lambda: "Cisco-IOS-XE-ethernet:load-balance"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/port-channel/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PortChannel.LoadBalance, ['load_balance'], name, value)

            class LoadBalance_(Enum):
                """
                LoadBalance\_ (Enum Class)

                .. data:: dst_ip = 0

                .. data:: dst_mac = 1

                .. data:: dst_mixed_ip_port = 2

                .. data:: dst_port = 3

                .. data:: mpls = 4

                .. data:: src_dst_ip = 5

                .. data:: src_dst_mac = 6

                .. data:: src_dst_mixed_ip_port = 7

                .. data:: src_dst_port = 8

                .. data:: src_ip = 9

                .. data:: src_mac = 10

                .. data:: src_mixed_ip_port = 11

                .. data:: src_port = 12

                """

                dst_ip = Enum.YLeaf(0, "dst-ip")

                dst_mac = Enum.YLeaf(1, "dst-mac")

                dst_mixed_ip_port = Enum.YLeaf(2, "dst-mixed-ip-port")

                dst_port = Enum.YLeaf(3, "dst-port")

                mpls = Enum.YLeaf(4, "mpls")

                src_dst_ip = Enum.YLeaf(5, "src-dst-ip")

                src_dst_mac = Enum.YLeaf(6, "src-dst-mac")

                src_dst_mixed_ip_port = Enum.YLeaf(7, "src-dst-mixed-ip-port")

                src_dst_port = Enum.YLeaf(8, "src-dst-port")

                src_ip = Enum.YLeaf(9, "src-ip")

                src_mac = Enum.YLeaf(10, "src-mac")

                src_mixed_ip_port = Enum.YLeaf(11, "src-mixed-ip-port")

                src_port = Enum.YLeaf(12, "src-port")



            class Extended(Entity):
                """
                Extended Load Balance Methods
                
                .. attribute:: extended
                
                	
                	**type**\: list of   :py:class:`Extended_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PortChannel.LoadBalance.Extended.Extended_>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.PortChannel.LoadBalance.Extended, self).__init__()

                    self.yang_name = "extended"
                    self.yang_parent_name = "load-balance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('extended', (YLeafList(YType.enumeration, 'extended'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'PortChannel.LoadBalance.Extended.Extended_')])),
                    ])
                    self.extended = []
                    self._segment_path = lambda: "extended"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/port-channel/Cisco-IOS-XE-ethernet:load-balance/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PortChannel.LoadBalance.Extended, ['extended'], name, value)

                class Extended_(Enum):
                    """
                    Extended\_ (Enum Class)

                    .. data:: dst_ip = 0

                    .. data:: dst_mac = 1

                    .. data:: dst_port = 2

                    .. data:: ipv6_label = 3

                    .. data:: l3_proto = 4

                    .. data:: src_ip = 5

                    .. data:: src_mac = 6

                    .. data:: src_port = 7

                    """

                    dst_ip = Enum.YLeaf(0, "dst-ip")

                    dst_mac = Enum.YLeaf(1, "dst-mac")

                    dst_port = Enum.YLeaf(2, "dst-port")

                    ipv6_label = Enum.YLeaf(3, "ipv6-label")

                    l3_proto = Enum.YLeaf(4, "l3-proto")

                    src_ip = Enum.YLeaf(5, "src-ip")

                    src_mac = Enum.YLeaf(6, "src-mac")

                    src_port = Enum.YLeaf(7, "src-port")



        class LoadBalancing(Entity):
            """
            Load Balance method
            
            .. attribute:: vlan_manual
            
            	Manual Traffic Distribution based on VLAN id
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-eth'
            _revision = '2018-04-09'

            def __init__(self):
                super(Native.PortChannel.LoadBalancing, self).__init__()

                self.yang_name = "load-balancing"
                self.yang_parent_name = "port-channel"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('vlan_manual', (YLeaf(YType.empty, 'vlan-manual'), ['Empty'])),
                ])
                self.vlan_manual = None
                self._segment_path = lambda: "Cisco-IOS-XE-ethernet:load-balancing"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/port-channel/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PortChannel.LoadBalancing, ['vlan_manual'], name, value)


    class Key(Entity):
        """
        Key management
        
        .. attribute:: chain
        
        	Key\-chain management
        	**type**\: list of  		 :py:class:`Chain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Key.Chain>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Key, self).__init__()

            self.yang_name = "key"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-crypto:chain", ("chain", Native.Key.Chain))])
            self._leafs = OrderedDict()

            self.chain = YList(self)
            self._segment_path = lambda: "key"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Key, [], name, value)


        class Chain(Entity):
            """
            Key\-chain management
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: macsec
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: key
            
            	Configure a key
            	**type**\: list of  		 :py:class:`Key_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Key.Chain.Key_>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Key.Chain, self).__init__()

                self.yang_name = "chain"
                self.yang_parent_name = "key"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("key", ("key", Native.Key.Chain.Key_))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('macsec', (YLeaf(YType.empty, 'macsec'), ['Empty'])),
                ])
                self.name = None
                self.macsec = None

                self.key = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:chain" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/key/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Key.Chain, ['name', 'macsec'], name, value)


            class Key_(Entity):
                """
                Configure a key
                
                .. attribute:: id  (key)
                
                	
                	**type**\: str
                
                .. attribute:: cryptographic_algorithm
                
                	Set cryptographic authentication algorithm
                	**type**\:  :py:class:`CryptographicAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Key.Chain.Key_.CryptographicAlgorithm>`
                
                .. attribute:: key_string
                
                	Set key string
                	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Key.Chain.Key_.KeyString>`
                
                .. attribute:: lifetime
                
                	Set lifetime of Macsec key
                	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Key.Chain.Key_.Lifetime>`
                
                .. attribute:: lifetime_local
                
                	
                	**type**\:  :py:class:`LifetimeLocal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Key.Chain.Key_.LifetimeLocal>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Key.Chain.Key_, self).__init__()

                    self.yang_name = "key"
                    self.yang_parent_name = "chain"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("key-string", ("key_string", Native.Key.Chain.Key_.KeyString)), ("lifetime", ("lifetime", Native.Key.Chain.Key_.Lifetime)), ("lifetime-local", ("lifetime_local", Native.Key.Chain.Key_.LifetimeLocal))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                        ('cryptographic_algorithm', (YLeaf(YType.enumeration, 'cryptographic-algorithm'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Key.Chain.Key_.CryptographicAlgorithm')])),
                    ])
                    self.id = None
                    self.cryptographic_algorithm = None

                    self.key_string = Native.Key.Chain.Key_.KeyString()
                    self.key_string.parent = self
                    self._children_name_map["key_string"] = "key-string"

                    self.lifetime = Native.Key.Chain.Key_.Lifetime()
                    self.lifetime.parent = self
                    self._children_name_map["lifetime"] = "lifetime"

                    self.lifetime_local = Native.Key.Chain.Key_.LifetimeLocal()
                    self.lifetime_local.parent = self
                    self._children_name_map["lifetime_local"] = "lifetime-local"
                    self._segment_path = lambda: "key" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Key.Chain.Key_, ['id', 'cryptographic_algorithm'], name, value)

                class CryptographicAlgorithm(Enum):
                    """
                    CryptographicAlgorithm (Enum Class)

                    Set cryptographic authentication algorithm

                    .. data:: aes_128_cmac = 0

                    .. data:: aes_256_cmac = 1

                    .. data:: hmac_sha_1 = 2

                    .. data:: hmac_sha_256 = 3

                    .. data:: hmac_sha_384 = 4

                    .. data:: hmac_sha_512 = 5

                    .. data:: md5 = 6

                    """

                    aes_128_cmac = Enum.YLeaf(0, "aes-128-cmac")

                    aes_256_cmac = Enum.YLeaf(1, "aes-256-cmac")

                    hmac_sha_1 = Enum.YLeaf(2, "hmac-sha-1")

                    hmac_sha_256 = Enum.YLeaf(3, "hmac-sha-256")

                    hmac_sha_384 = Enum.YLeaf(4, "hmac-sha-384")

                    hmac_sha_512 = Enum.YLeaf(5, "hmac-sha-512")

                    md5 = Enum.YLeaf(6, "md5")



                class KeyString(Entity):
                    """
                    Set key string
                    
                    .. attribute:: encryption
                    
                    	
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Key.Chain.Key_.KeyString.Encryption>`
                    
                    .. attribute:: key
                    
                    	
                    	**type**\: str
                    
                    	**length:** 0..80
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Key.Chain.Key_.KeyString, self).__init__()

                        self.yang_name = "key-string"
                        self.yang_parent_name = "key"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Key.Chain.Key_.KeyString.Encryption')])),
                            ('key', (YLeaf(YType.str, 'key'), ['str'])),
                        ])
                        self.encryption = None
                        self.key = None
                        self._segment_path = lambda: "key-string"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Key.Chain.Key_.KeyString, ['encryption', 'key'], name, value)

                    class Encryption(Enum):
                        """
                        Encryption (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_6 = 1

                        .. data:: Y_7 = 2

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_6 = Enum.YLeaf(1, "6")

                        Y_7 = Enum.YLeaf(2, "7")



                class Lifetime(Entity):
                    """
                    Set lifetime of Macsec key
                    
                    .. attribute:: lifetime_group
                    
                    	
                    	**type**\:  :py:class:`LifetimeGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Key.Chain.Key_.Lifetime.LifetimeGroup>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Key.Chain.Key_.Lifetime, self).__init__()

                        self.yang_name = "lifetime"
                        self.yang_parent_name = "key"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("lifetime-group", ("lifetime_group", Native.Key.Chain.Key_.Lifetime.LifetimeGroup))])
                        self._leafs = OrderedDict()

                        self.lifetime_group = Native.Key.Chain.Key_.Lifetime.LifetimeGroup()
                        self.lifetime_group.parent = self
                        self._children_name_map["lifetime_group"] = "lifetime-group"
                        self._segment_path = lambda: "lifetime"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Key.Chain.Key_.Lifetime, [], name, value)


                    class LifetimeGroup(Entity):
                        """
                        
                        
                        .. attribute:: hh_mm_ss
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                        
                        .. attribute:: date1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..31
                        
                        .. attribute:: month1
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: date2
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..31
                        
                        .. attribute:: month2
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: year
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1993..2035
                        
                        .. attribute:: duration
                        
                        	Set key lifetime duration
                        	**type**\: int
                        
                        	**range:** 1..864000
                        
                        .. attribute:: hh_mm_ss1
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                        
                        .. attribute:: date3
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..31
                        
                        .. attribute:: month3
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: date4
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..31
                        
                        .. attribute:: month4
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: year1
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1993..2035
                        
                        .. attribute:: infinite
                        
                        	Never expires
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Key.Chain.Key_.Lifetime.LifetimeGroup, self).__init__()

                            self.yang_name = "lifetime-group"
                            self.yang_parent_name = "lifetime"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                ('date1', (YLeaf(YType.uint8, 'date1'), ['int'])),
                                ('month1', (YLeaf(YType.str, 'month1'), ['str'])),
                                ('date2', (YLeaf(YType.uint8, 'date2'), ['int'])),
                                ('month2', (YLeaf(YType.str, 'month2'), ['str'])),
                                ('year', (YLeaf(YType.uint16, 'year'), ['int'])),
                                ('duration', (YLeaf(YType.uint32, 'duration'), ['int'])),
                                ('hh_mm_ss1', (YLeaf(YType.str, 'hh-mm-ss1'), ['str'])),
                                ('date3', (YLeaf(YType.uint8, 'date3'), ['int'])),
                                ('month3', (YLeaf(YType.str, 'month3'), ['str'])),
                                ('date4', (YLeaf(YType.uint8, 'date4'), ['int'])),
                                ('month4', (YLeaf(YType.str, 'month4'), ['str'])),
                                ('year1', (YLeaf(YType.uint16, 'year1'), ['int'])),
                                ('infinite', (YLeaf(YType.empty, 'infinite'), ['Empty'])),
                            ])
                            self.hh_mm_ss = None
                            self.date1 = None
                            self.month1 = None
                            self.date2 = None
                            self.month2 = None
                            self.year = None
                            self.duration = None
                            self.hh_mm_ss1 = None
                            self.date3 = None
                            self.month3 = None
                            self.date4 = None
                            self.month4 = None
                            self.year1 = None
                            self.infinite = None
                            self._segment_path = lambda: "lifetime-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Key.Chain.Key_.Lifetime.LifetimeGroup, ['hh_mm_ss', 'date1', 'month1', 'date2', 'month2', 'year', 'duration', 'hh_mm_ss1', 'date3', 'month3', 'date4', 'month4', 'year1', 'infinite'], name, value)


                class LifetimeLocal(Entity):
                    """
                    
                    
                    .. attribute:: local
                    
                    	Specify time in local timezone
                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Key.Chain.Key_.LifetimeLocal.Local>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Key.Chain.Key_.LifetimeLocal, self).__init__()

                        self.yang_name = "lifetime-local"
                        self.yang_parent_name = "key"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("local", ("local", Native.Key.Chain.Key_.LifetimeLocal.Local))])
                        self._leafs = OrderedDict()

                        self.local = Native.Key.Chain.Key_.LifetimeLocal.Local()
                        self.local.parent = self
                        self._children_name_map["local"] = "local"
                        self._segment_path = lambda: "lifetime-local"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Key.Chain.Key_.LifetimeLocal, [], name, value)


                    class Local(Entity):
                        """
                        Specify time in local timezone
                        
                        .. attribute:: lifetime_group
                        
                        	
                        	**type**\:  :py:class:`LifetimeGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Key.Chain.Key_.LifetimeLocal.Local.LifetimeGroup>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Key.Chain.Key_.LifetimeLocal.Local, self).__init__()

                            self.yang_name = "local"
                            self.yang_parent_name = "lifetime-local"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lifetime-group", ("lifetime_group", Native.Key.Chain.Key_.LifetimeLocal.Local.LifetimeGroup))])
                            self._leafs = OrderedDict()

                            self.lifetime_group = Native.Key.Chain.Key_.LifetimeLocal.Local.LifetimeGroup()
                            self.lifetime_group.parent = self
                            self._children_name_map["lifetime_group"] = "lifetime-group"
                            self._segment_path = lambda: "local"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Key.Chain.Key_.LifetimeLocal.Local, [], name, value)


                        class LifetimeGroup(Entity):
                            """
                            
                            
                            .. attribute:: hh_mm_ss
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            .. attribute:: date1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: month1
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: date2
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: month2
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: year
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1993..2035
                            
                            .. attribute:: duration
                            
                            	Set key lifetime duration
                            	**type**\: int
                            
                            	**range:** 1..864000
                            
                            .. attribute:: hh_mm_ss1
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                            
                            .. attribute:: date3
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: month3
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: date4
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: month4
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: year1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1993..2035
                            
                            .. attribute:: infinite
                            
                            	Never expires
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Key.Chain.Key_.LifetimeLocal.Local.LifetimeGroup, self).__init__()

                                self.yang_name = "lifetime-group"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                    ('date1', (YLeaf(YType.uint8, 'date1'), ['int'])),
                                    ('month1', (YLeaf(YType.str, 'month1'), ['str'])),
                                    ('date2', (YLeaf(YType.uint8, 'date2'), ['int'])),
                                    ('month2', (YLeaf(YType.str, 'month2'), ['str'])),
                                    ('year', (YLeaf(YType.uint16, 'year'), ['int'])),
                                    ('duration', (YLeaf(YType.uint32, 'duration'), ['int'])),
                                    ('hh_mm_ss1', (YLeaf(YType.str, 'hh-mm-ss1'), ['str'])),
                                    ('date3', (YLeaf(YType.uint8, 'date3'), ['int'])),
                                    ('month3', (YLeaf(YType.str, 'month3'), ['str'])),
                                    ('date4', (YLeaf(YType.uint8, 'date4'), ['int'])),
                                    ('month4', (YLeaf(YType.str, 'month4'), ['str'])),
                                    ('year1', (YLeaf(YType.uint16, 'year1'), ['int'])),
                                    ('infinite', (YLeaf(YType.empty, 'infinite'), ['Empty'])),
                                ])
                                self.hh_mm_ss = None
                                self.date1 = None
                                self.month1 = None
                                self.date2 = None
                                self.month2 = None
                                self.year = None
                                self.duration = None
                                self.hh_mm_ss1 = None
                                self.date3 = None
                                self.month3 = None
                                self.date4 = None
                                self.month4 = None
                                self.year1 = None
                                self.infinite = None
                                self._segment_path = lambda: "lifetime-group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Key.Chain.Key_.LifetimeLocal.Local.LifetimeGroup, ['hh_mm_ss', 'date1', 'month1', 'date2', 'month2', 'year', 'duration', 'hh_mm_ss1', 'date3', 'month3', 'date4', 'month4', 'year1', 'infinite'], name, value)


    class L2(Entity):
        """
        Layer 2 configuration
        
        .. attribute:: router_id
        
        	Configure a layer 2 identifier
        	**type**\: str
        
        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
        
        .. attribute:: vfi
        
        	Configure a virtual forwarding instance
        	**type**\: list of  		 :py:class:`Vfi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2.Vfi>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.L2, self).__init__()

            self.yang_name = "l2"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-l2vpn:vfi", ("vfi", Native.L2.Vfi))])
            self._leafs = OrderedDict([
                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
            ])
            self.router_id = None

            self.vfi = YList(self)
            self._segment_path = lambda: "l2"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.L2, [u'router_id'], name, value)


        class Vfi(Entity):
            """
            Configure a virtual forwarding instance
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: mode
            
            	
            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2.Vfi.Mode>`
            
            .. attribute:: evc
            
            	
            	**type**\: str
            
            .. attribute:: vpn
            
            	VPN configuration
            	**type**\:  :py:class:`Vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2.Vfi.Vpn>`
            
            .. attribute:: bridge_domain
            
            	bridge\-domain
            	**type**\: int
            
            	**range:** 1..16384
            
            .. attribute:: mtu
            
            	MTU size in bytes
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: neighbor
            
            	VFI neighbor configuration
            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2.Vfi.Neighbor>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.L2.Vfi, self).__init__()

                self.yang_name = "vfi"
                self.yang_parent_name = "l2"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("vpn", ("vpn", Native.L2.Vfi.Vpn)), ("neighbor", ("neighbor", Native.L2.Vfi.Neighbor))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'L2.Vfi.Mode')])),
                    ('evc', (YLeaf(YType.str, 'evc'), ['str'])),
                    ('bridge_domain', (YLeaf(YType.uint16, 'bridge-domain'), ['int'])),
                    ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                ])
                self.name = None
                self.mode = None
                self.evc = None
                self.bridge_domain = None
                self.mtu = None

                self.vpn = Native.L2.Vfi.Vpn()
                self.vpn.parent = self
                self._children_name_map["vpn"] = "vpn"

                self.neighbor = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:vfi" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.L2.Vfi, ['name', 'mode', 'evc', 'bridge_domain', 'mtu'], name, value)

            class Mode(Enum):
                """
                Mode (Enum Class)

                .. data:: autodiscovery = 0

                .. data:: manual = 1

                .. data:: point_to_point = 2

                """

                autodiscovery = Enum.YLeaf(0, "autodiscovery")

                manual = Enum.YLeaf(1, "manual")

                point_to_point = Enum.YLeaf(2, "point-to-point")



            class Vpn(Entity):
                """
                VPN configuration
                
                .. attribute:: id
                
                	VPN id
                	**type**\: int
                
                	**range:** 1..4294967295
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.L2.Vfi.Vpn, self).__init__()

                    self.yang_name = "vpn"
                    self.yang_parent_name = "vfi"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.uint64, 'id'), ['int'])),
                    ])
                    self.id = None
                    self._segment_path = lambda: "vpn"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L2.Vfi.Vpn, ['id'], name, value)


            class Neighbor(Entity):
                """
                VFI neighbor configuration
                
                .. attribute:: router_id  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: vc_id
                
                	
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: encapsulation
                
                	Connection encapsulation type
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2.Vfi.Neighbor.Encapsulation>`
                
                .. attribute:: pw_class
                
                	Pseudowire\-class configuration
                	**type**\: str
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.L2.Vfi.Neighbor, self).__init__()

                    self.yang_name = "neighbor"
                    self.yang_parent_name = "vfi"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['router_id']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                        ('vc_id', (YLeaf(YType.uint64, 'vc-id'), ['int'])),
                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'L2.Vfi.Neighbor.Encapsulation')])),
                        ('pw_class', (YLeaf(YType.str, 'pw-class'), ['str'])),
                    ])
                    self.router_id = None
                    self.vc_id = None
                    self.encapsulation = None
                    self.pw_class = None
                    self._segment_path = lambda: "neighbor" + "[router-id='" + str(self.router_id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L2.Vfi.Neighbor, ['router_id', 'vc_id', 'encapsulation', 'pw_class'], name, value)

                class Encapsulation(Enum):
                    """
                    Encapsulation (Enum Class)

                    Connection encapsulation type

                    .. data:: l2tpv3 = 0

                    .. data:: mpls = 1

                    """

                    l2tpv3 = Enum.YLeaf(0, "l2tpv3")

                    mpls = Enum.YLeaf(1, "mpls")



    class System(Entity):
        """
        Set the system configuration
        
        .. attribute:: debug
        
        	Debug Shell
        	**type**\:  :py:class:`Debug <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Debug>`
        
        .. attribute:: disable
        
        	Disable password recovery
        	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Disable>`
        
        .. attribute:: environment
        
        	Set the system environment settings
        	**type**\:  :py:class:`Environment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Environment>`
        
        .. attribute:: fnf
        
        	Flexible Netflow
        	**type**\:  :py:class:`Fnf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Fnf>`
        
        .. attribute:: ignore
        
        	Ignore Startup Config
        	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Ignore>`
        
        .. attribute:: mode_button
        
        	Enable Mode button for reset
        	**type**\:  :py:class:`ModeButton <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.ModeButton>`
        
        .. attribute:: mtu
        
        	Set the system Maximum Transmission Unit (MTU)
        	**type**\:  :py:class:`Mtu <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Mtu>`
        
        .. attribute:: mode
        
        	System mode
        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Mode>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.System, self).__init__()

            self.yang_name = "system"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-switch:debug", ("debug", Native.System.Debug)), ("Cisco-IOS-XE-switch:disable", ("disable", Native.System.Disable)), ("Cisco-IOS-XE-switch:environment", ("environment", Native.System.Environment)), ("Cisco-IOS-XE-switch:fnf", ("fnf", Native.System.Fnf)), ("Cisco-IOS-XE-switch:ignore", ("ignore", Native.System.Ignore)), ("Cisco-IOS-XE-switch:mode-button", ("mode_button", Native.System.ModeButton)), ("Cisco-IOS-XE-switch:mtu", ("mtu", Native.System.Mtu)), ("Cisco-IOS-XE-mmode:mode", ("mode", Native.System.Mode))])
            self._leafs = OrderedDict()

            self.debug = Native.System.Debug()
            self.debug.parent = self
            self._children_name_map["debug"] = "Cisco-IOS-XE-switch:debug"

            self.disable = Native.System.Disable()
            self.disable.parent = self
            self._children_name_map["disable"] = "Cisco-IOS-XE-switch:disable"

            self.environment = Native.System.Environment()
            self.environment.parent = self
            self._children_name_map["environment"] = "Cisco-IOS-XE-switch:environment"

            self.fnf = Native.System.Fnf()
            self.fnf.parent = self
            self._children_name_map["fnf"] = "Cisco-IOS-XE-switch:fnf"

            self.ignore = Native.System.Ignore()
            self.ignore.parent = self
            self._children_name_map["ignore"] = "Cisco-IOS-XE-switch:ignore"

            self.mode_button = Native.System.ModeButton()
            self.mode_button.parent = self
            self._children_name_map["mode_button"] = "Cisco-IOS-XE-switch:mode-button"

            self.mtu = Native.System.Mtu()
            self.mtu.parent = self
            self._children_name_map["mtu"] = "Cisco-IOS-XE-switch:mtu"

            self.mode = Native.System.Mode()
            self.mode.parent = self
            self._children_name_map["mode"] = "Cisco-IOS-XE-mmode:mode"
            self._segment_path = lambda: "system"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.System, [], name, value)


        class Debug(Entity):
            """
            Debug Shell
            
            .. attribute:: shell
            
            	Debug Shell
            	**type**\:  :py:class:`Shell <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Debug.Shell>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.System.Debug, self).__init__()

                self.yang_name = "debug"
                self.yang_parent_name = "system"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("shell", ("shell", Native.System.Debug.Shell))])
                self._leafs = OrderedDict()

                self.shell = Native.System.Debug.Shell()
                self.shell.parent = self
                self._children_name_map["shell"] = "shell"
                self._segment_path = lambda: "Cisco-IOS-XE-switch:debug"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.System.Debug, [], name, value)


            class Shell(Entity):
                """
                Debug Shell
                
                .. attribute:: switch
                
                	Set config on switches in stack
                	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Debug.Shell.Switch>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.System.Debug.Shell, self).__init__()

                    self.yang_name = "shell"
                    self.yang_parent_name = "debug"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("switch", ("switch", Native.System.Debug.Shell.Switch))])
                    self._leafs = OrderedDict()

                    self.switch = Native.System.Debug.Shell.Switch()
                    self.switch.parent = self
                    self._children_name_map["switch"] = "switch"
                    self._segment_path = lambda: "shell"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:debug/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.System.Debug.Shell, [], name, value)


                class Switch(Entity):
                    """
                    Set config on switches in stack
                    
                    .. attribute:: switch_number
                    
                    	Switch number
                    	**type**\: int
                    
                    	**range:** 1..9
                    
                    .. attribute:: all
                    
                    	Set config for all switches in stack
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.System.Debug.Shell.Switch, self).__init__()

                        self.yang_name = "switch"
                        self.yang_parent_name = "shell"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('switch_number', (YLeaf(YType.uint8, 'switch-number'), ['int'])),
                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                        ])
                        self.switch_number = None
                        self.all = None
                        self._segment_path = lambda: "switch"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:debug/shell/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.System.Debug.Shell.Switch, [u'switch_number', u'all'], name, value)


        class Disable(Entity):
            """
            Disable password recovery
            
            .. attribute:: password
            
            	Disable password recovery
            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Disable.Password>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.System.Disable, self).__init__()

                self.yang_name = "disable"
                self.yang_parent_name = "system"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("password", ("password", Native.System.Disable.Password))])
                self._leafs = OrderedDict()

                self.password = Native.System.Disable.Password()
                self.password.parent = self
                self._children_name_map["password"] = "password"
                self._segment_path = lambda: "Cisco-IOS-XE-switch:disable"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.System.Disable, [], name, value)


            class Password(Entity):
                """
                Disable password recovery
                
                .. attribute:: recovery
                
                	Disable password recovery
                	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Disable.Password.Recovery>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.System.Disable.Password, self).__init__()

                    self.yang_name = "password"
                    self.yang_parent_name = "disable"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("recovery", ("recovery", Native.System.Disable.Password.Recovery))])
                    self._leafs = OrderedDict()

                    self.recovery = Native.System.Disable.Password.Recovery()
                    self.recovery.parent = self
                    self._children_name_map["recovery"] = "recovery"
                    self._segment_path = lambda: "password"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:disable/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.System.Disable.Password, [], name, value)


                class Recovery(Entity):
                    """
                    Disable password recovery
                    
                    .. attribute:: switch
                    
                    	Set config on switches in stack
                    	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Disable.Password.Recovery.Switch>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.System.Disable.Password.Recovery, self).__init__()

                        self.yang_name = "recovery"
                        self.yang_parent_name = "password"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("switch", ("switch", Native.System.Disable.Password.Recovery.Switch))])
                        self._leafs = OrderedDict()

                        self.switch = Native.System.Disable.Password.Recovery.Switch()
                        self.switch.parent = self
                        self._children_name_map["switch"] = "switch"
                        self._segment_path = lambda: "recovery"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:disable/password/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.System.Disable.Password.Recovery, [], name, value)


                    class Switch(Entity):
                        """
                        Set config on switches in stack
                        
                        .. attribute:: number
                        
                        	Switch number
                        	**type**\: int
                        
                        	**range:** 1..9
                        
                        .. attribute:: all
                        
                        	Set config for all switches in stack
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.System.Disable.Password.Recovery.Switch, self).__init__()

                            self.yang_name = "switch"
                            self.yang_parent_name = "recovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                            ])
                            self.number = None
                            self.all = None
                            self._segment_path = lambda: "switch"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:disable/password/recovery/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.System.Disable.Password.Recovery.Switch, [u'number', u'all'], name, value)


        class Environment(Entity):
            """
            Set the system environment settings
            
            .. attribute:: fan_fail_action
            
            	Set the FRU/PS fan fail action. 
            	**type**\:  :py:class:`FanFailAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Environment.FanFailAction>`
            
            .. attribute:: temperature
            
            	Set the system temperature settings
            	**type**\:  :py:class:`Temperature <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Environment.Temperature>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.System.Environment, self).__init__()

                self.yang_name = "environment"
                self.yang_parent_name = "system"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("fan-fail-action", ("fan_fail_action", Native.System.Environment.FanFailAction)), ("temperature", ("temperature", Native.System.Environment.Temperature))])
                self._leafs = OrderedDict()

                self.fan_fail_action = Native.System.Environment.FanFailAction()
                self.fan_fail_action.parent = self
                self._children_name_map["fan_fail_action"] = "fan-fail-action"

                self.temperature = Native.System.Environment.Temperature()
                self.temperature.parent = self
                self._children_name_map["temperature"] = "temperature"
                self._segment_path = lambda: "Cisco-IOS-XE-switch:environment"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.System.Environment, [], name, value)


            class FanFailAction(Entity):
                """
                Set the FRU/PS fan fail action. 
                
                .. attribute:: shut
                
                	Shutdown the system when multiple fan fails
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.System.Environment.FanFailAction, self).__init__()

                    self.yang_name = "fan-fail-action"
                    self.yang_parent_name = "environment"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('shut', (YLeaf(YType.empty, 'shut'), ['Empty'])),
                    ])
                    self.shut = None
                    self._segment_path = lambda: "fan-fail-action"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:environment/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.System.Environment.FanFailAction, [u'shut'], name, value)


            class Temperature(Entity):
                """
                Set the system temperature settings
                
                .. attribute:: threshold
                
                	Set the system temperature thresholds
                	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Environment.Temperature.Threshold>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.System.Environment.Temperature, self).__init__()

                    self.yang_name = "temperature"
                    self.yang_parent_name = "environment"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("threshold", ("threshold", Native.System.Environment.Temperature.Threshold))])
                    self._leafs = OrderedDict()

                    self.threshold = Native.System.Environment.Temperature.Threshold()
                    self.threshold.parent = self
                    self._children_name_map["threshold"] = "threshold"
                    self._segment_path = lambda: "temperature"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:environment/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.System.Environment.Temperature, [], name, value)


                class Threshold(Entity):
                    """
                    Set the system temperature thresholds
                    
                    .. attribute:: yellow
                    
                    	Set the yellow thresholds. 
                    	**type**\:  :py:class:`Yellow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Environment.Temperature.Threshold.Yellow>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.System.Environment.Temperature.Threshold, self).__init__()

                        self.yang_name = "threshold"
                        self.yang_parent_name = "temperature"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("yellow", ("yellow", Native.System.Environment.Temperature.Threshold.Yellow))])
                        self._leafs = OrderedDict()

                        self.yellow = Native.System.Environment.Temperature.Threshold.Yellow()
                        self.yellow.parent = self
                        self._children_name_map["yellow"] = "yellow"
                        self._segment_path = lambda: "threshold"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:environment/temperature/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.System.Environment.Temperature.Threshold, [], name, value)


                    class Yellow(Entity):
                        """
                        Set the yellow thresholds. 
                        
                        .. attribute:: delta_value
                        
                        	Delta value from Red threshold in Degree Celcius
                        	**type**\: int
                        
                        	**range:** 5..25
                        
                        .. attribute:: detail
                        
                        	print yellow temperature threshold
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.System.Environment.Temperature.Threshold.Yellow, self).__init__()

                            self.yang_name = "yellow"
                            self.yang_parent_name = "threshold"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('delta_value', (YLeaf(YType.uint8, 'delta-value'), ['int'])),
                                ('detail', (YLeaf(YType.empty, 'detail'), ['Empty'])),
                            ])
                            self.delta_value = None
                            self.detail = None
                            self._segment_path = lambda: "yellow"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:environment/temperature/threshold/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.System.Environment.Temperature.Threshold.Yellow, [u'delta_value', u'detail'], name, value)


        class Fnf(Entity):
            """
            Flexible Netflow
            
            .. attribute:: bytes_count
            
            	Bytes Count
            	**type**\:  :py:class:`BytesCount <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Fnf.BytesCount>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.System.Fnf, self).__init__()

                self.yang_name = "fnf"
                self.yang_parent_name = "system"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("bytes-count", ("bytes_count", Native.System.Fnf.BytesCount))])
                self._leafs = OrderedDict()

                self.bytes_count = Native.System.Fnf.BytesCount()
                self.bytes_count.parent = self
                self._children_name_map["bytes_count"] = "bytes-count"
                self._segment_path = lambda: "Cisco-IOS-XE-switch:fnf"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.System.Fnf, [], name, value)


            class BytesCount(Entity):
                """
                Bytes Count
                
                .. attribute:: layer2
                
                	Show L2 bytes in byte count collect field
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.System.Fnf.BytesCount, self).__init__()

                    self.yang_name = "bytes-count"
                    self.yang_parent_name = "fnf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('layer2', (YLeaf(YType.empty, 'layer2'), ['Empty'])),
                    ])
                    self.layer2 = None
                    self._segment_path = lambda: "bytes-count"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:fnf/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.System.Fnf.BytesCount, [u'layer2'], name, value)


        class Ignore(Entity):
            """
            Ignore Startup Config
            
            .. attribute:: startupconfig
            
            	Ignore Startup Config
            	**type**\:  :py:class:`Startupconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Ignore.Startupconfig>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.System.Ignore, self).__init__()

                self.yang_name = "ignore"
                self.yang_parent_name = "system"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("startupconfig", ("startupconfig", Native.System.Ignore.Startupconfig))])
                self._leafs = OrderedDict()

                self.startupconfig = Native.System.Ignore.Startupconfig()
                self.startupconfig.parent = self
                self._children_name_map["startupconfig"] = "startupconfig"
                self._segment_path = lambda: "Cisco-IOS-XE-switch:ignore"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.System.Ignore, [], name, value)


            class Startupconfig(Entity):
                """
                Ignore Startup Config
                
                .. attribute:: switch
                
                	Set config on switches in stack
                	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Ignore.Startupconfig.Switch>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.System.Ignore.Startupconfig, self).__init__()

                    self.yang_name = "startupconfig"
                    self.yang_parent_name = "ignore"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("switch", ("switch", Native.System.Ignore.Startupconfig.Switch))])
                    self._leafs = OrderedDict()

                    self.switch = Native.System.Ignore.Startupconfig.Switch()
                    self.switch.parent = self
                    self._children_name_map["switch"] = "switch"
                    self._segment_path = lambda: "startupconfig"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:ignore/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.System.Ignore.Startupconfig, [], name, value)


                class Switch(Entity):
                    """
                    Set config on switches in stack
                    
                    .. attribute:: number
                    
                    	Switch number
                    	**type**\: int
                    
                    	**range:** 1..9
                    
                    .. attribute:: all
                    
                    	Set config for all switches in stack
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.System.Ignore.Startupconfig.Switch, self).__init__()

                        self.yang_name = "switch"
                        self.yang_parent_name = "startupconfig"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                        ])
                        self.number = None
                        self.all = None
                        self._segment_path = lambda: "switch"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-switch:ignore/startupconfig/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.System.Ignore.Startupconfig.Switch, [u'number', u'all'], name, value)


        class ModeButton(Entity):
            """
            Enable Mode button for reset
            
            .. attribute:: reset
            
            	Enable reset
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.System.ModeButton, self).__init__()

                self.yang_name = "mode-button"
                self.yang_parent_name = "system"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('reset', (YLeaf(YType.empty, 'reset'), ['Empty'])),
                ])
                self.reset = None
                self._segment_path = lambda: "Cisco-IOS-XE-switch:mode-button"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.System.ModeButton, [u'reset'], name, value)


        class Mtu(Entity):
            """
            Set the system Maximum Transmission Unit (MTU)
            
            .. attribute:: size
            
            	
            	**type**\: int
            
            	**range:** 1500..9198
            
            .. attribute:: jumbo
            
            	Set Jumbo MTU value for GigabitEthernet or TenGigabitEthernet interfaces
            	**type**\: int
            
            	**range:** 1500..9000
            
            .. attribute:: routing
            
            	Set the Routing MTU for the system
            	**type**\: int
            
            	**range:** 1500..None
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.System.Mtu, self).__init__()

                self.yang_name = "mtu"
                self.yang_parent_name = "system"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                    ('jumbo', (YLeaf(YType.uint16, 'jumbo'), ['int'])),
                    ('routing', (YLeaf(YType.uint16, 'routing'), ['int'])),
                ])
                self.size = None
                self.jumbo = None
                self.routing = None
                self._segment_path = lambda: "Cisco-IOS-XE-switch:mtu"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.System.Mtu, [u'size', u'jumbo', u'routing'], name, value)


        class Mode(Entity):
            """
            System mode
            
            .. attribute:: maintenance
            
            	System maintenance
            	**type**\:  :py:class:`Maintenance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Mode.Maintenance>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios-mmode'
            _revision = '2017-11-29'

            def __init__(self):
                super(Native.System.Mode, self).__init__()

                self.yang_name = "mode"
                self.yang_parent_name = "system"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("maintenance", ("maintenance", Native.System.Mode.Maintenance))])
                self._leafs = OrderedDict()

                self.maintenance = None
                self._children_name_map["maintenance"] = "maintenance"
                self._segment_path = lambda: "Cisco-IOS-XE-mmode:mode"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.System.Mode, [], name, value)


            class Maintenance(Entity):
                """
                System maintenance
                
                .. attribute:: config_maintenance
                
                	
                	**type**\:  :py:class:`ConfigMaintenance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Mode.Maintenance.ConfigMaintenance>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-mmode'
                _revision = '2017-11-29'

                def __init__(self):
                    super(Native.System.Mode.Maintenance, self).__init__()

                    self.yang_name = "maintenance"
                    self.yang_parent_name = "mode"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("config-maintenance", ("config_maintenance", Native.System.Mode.Maintenance.ConfigMaintenance))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.config_maintenance = Native.System.Mode.Maintenance.ConfigMaintenance()
                    self.config_maintenance.parent = self
                    self._children_name_map["config_maintenance"] = "config-maintenance"
                    self._segment_path = lambda: "maintenance"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-mmode:mode/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.System.Mode.Maintenance, [], name, value)


                class ConfigMaintenance(Entity):
                    """
                    
                    
                    .. attribute:: failsafe
                    
                    	Client ack timeout minutes (default is 30 mins)
                    	**type**\: int
                    
                    	**range:** 15..180
                    
                    .. attribute:: on_reload
                    
                    	On reload maintenance mode configuration
                    	**type**\:  :py:class:`OnReload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Mode.Maintenance.ConfigMaintenance.OnReload>`
                    
                    .. attribute:: template
                    
                    	maintenance\-template name
                    	**type**\: str
                    
                    .. attribute:: timeout
                    
                    	maintenance duration minutes (default is 30 mins)
                    	**type**\: int
                    
                    	**range:** 15..180
                    
                    

                    """

                    _prefix = 'ios-mmode'
                    _revision = '2017-11-29'

                    def __init__(self):
                        super(Native.System.Mode.Maintenance.ConfigMaintenance, self).__init__()

                        self.yang_name = "config-maintenance"
                        self.yang_parent_name = "maintenance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("on-reload", ("on_reload", Native.System.Mode.Maintenance.ConfigMaintenance.OnReload))])
                        self._leafs = OrderedDict([
                            ('failsafe', (YLeaf(YType.uint8, 'failsafe'), ['int'])),
                            ('template', (YLeaf(YType.str, 'template'), ['str'])),
                            ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                        ])
                        self.failsafe = None
                        self.template = None
                        self.timeout = None

                        self.on_reload = Native.System.Mode.Maintenance.ConfigMaintenance.OnReload()
                        self.on_reload.parent = self
                        self._children_name_map["on_reload"] = "on-reload"
                        self._segment_path = lambda: "config-maintenance"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-mmode:mode/maintenance/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.System.Mode.Maintenance.ConfigMaintenance, ['failsafe', 'template', 'timeout'], name, value)


                    class OnReload(Entity):
                        """
                        On reload maintenance mode configuration
                        
                        .. attribute:: reset_reason
                        
                        	Reset reason
                        	**type**\:  :py:class:`ResetReason <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.System.Mode.Maintenance.ConfigMaintenance.OnReload.ResetReason>`
                        
                        

                        """

                        _prefix = 'ios-mmode'
                        _revision = '2017-11-29'

                        def __init__(self):
                            super(Native.System.Mode.Maintenance.ConfigMaintenance.OnReload, self).__init__()

                            self.yang_name = "on-reload"
                            self.yang_parent_name = "config-maintenance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reset-reason", ("reset_reason", Native.System.Mode.Maintenance.ConfigMaintenance.OnReload.ResetReason))])
                            self._leafs = OrderedDict()

                            self.reset_reason = Native.System.Mode.Maintenance.ConfigMaintenance.OnReload.ResetReason()
                            self.reset_reason.parent = self
                            self._children_name_map["reset_reason"] = "reset-reason"
                            self._segment_path = lambda: "on-reload"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-mmode:mode/maintenance/config-maintenance/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.System.Mode.Maintenance.ConfigMaintenance.OnReload, [], name, value)


                        class ResetReason(Entity):
                            """
                            Reset reason
                            
                            .. attribute:: maintenance
                            
                            	Maintenance mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-mmode'
                            _revision = '2017-11-29'

                            def __init__(self):
                                super(Native.System.Mode.Maintenance.ConfigMaintenance.OnReload.ResetReason, self).__init__()

                                self.yang_name = "reset-reason"
                                self.yang_parent_name = "on-reload"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('maintenance', (YLeaf(YType.empty, 'maintenance'), ['Empty'])),
                                ])
                                self.maintenance = None
                                self._segment_path = lambda: "reset-reason"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/system/Cisco-IOS-XE-mmode:mode/maintenance/config-maintenance/on-reload/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.System.Mode.Maintenance.ConfigMaintenance.OnReload.ResetReason, ['maintenance'], name, value)


    class Errdisable(Entity):
        """
        Error disable
        
        .. attribute:: detect
        
        	Error disable detection
        	**type**\:  :py:class:`Detect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.Detect>`
        
        .. attribute:: flap_setting
        
        	Error disable flap detection setting
        	**type**\:  :py:class:`FlapSetting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.FlapSetting>`
        
        .. attribute:: recovery
        
        	Error disable recovery
        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.Recovery>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Errdisable, self).__init__()

            self.yang_name = "errdisable"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("detect", ("detect", Native.Errdisable.Detect)), ("flap-setting", ("flap_setting", Native.Errdisable.FlapSetting)), ("recovery", ("recovery", Native.Errdisable.Recovery))])
            self._leafs = OrderedDict()

            self.detect = Native.Errdisable.Detect()
            self.detect.parent = self
            self._children_name_map["detect"] = "detect"

            self.flap_setting = Native.Errdisable.FlapSetting()
            self.flap_setting.parent = self
            self._children_name_map["flap_setting"] = "flap-setting"

            self.recovery = Native.Errdisable.Recovery()
            self.recovery.parent = self
            self._children_name_map["recovery"] = "recovery"
            self._segment_path = lambda: "errdisable"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Errdisable, [], name, value)


        class Detect(Entity):
            """
            Error disable detection
            
            .. attribute:: cause
            
            	Enable error disable detection for application
            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.Detect.Cause>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Errdisable.Detect, self).__init__()

                self.yang_name = "detect"
                self.yang_parent_name = "errdisable"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("cause", ("cause", Native.Errdisable.Detect.Cause))])
                self._leafs = OrderedDict()

                self.cause = Native.Errdisable.Detect.Cause()
                self.cause.parent = self
                self._children_name_map["cause"] = "cause"
                self._segment_path = lambda: "detect"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Errdisable.Detect, [], name, value)


            class Cause(Entity):
                """
                Enable error disable detection for application
                
                .. attribute:: all
                
                	Enable error detection on all cases
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: arp_inspection
                
                	Enable error detection for arp inspection
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bpduguard
                
                	Enable error detection on bpdu\-guard
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dhcp_rate_limit
                
                	Enable error detection on dhcp\-rate\-limit
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dtp_flap
                
                	Enable error detection on dtp\-flapping
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: gbic_invalid
                
                	Enable error detection on gbic\-invalid
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: inline_power
                
                	Enable error detection for inline\-power
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: l2ptguard
                
                	Enable timer to recover from l2protocol\-tunnel error disable state
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link_flap
                
                	Enable error detection on linkstate\-flapping
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: loopback
                
                	Enable error detection on loopback
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mlacp_minlink
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pagp_flap
                
                	Enable error detection on pagp\-flapping
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pppoe_ia_rate_limit
                
                	Enable error detection on PPPoE IA rate\-limit
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: security_violation
                
                	Enable error detection on 802.1x\-guard
                	**type**\:  :py:class:`SecurityViolation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.Detect.Cause.SecurityViolation>`
                
                .. attribute:: sfp_config_mismatch
                
                	Enable error detection on SFP config mismatch
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: small_frame
                
                	Enable error detection on small\_frame
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Errdisable.Detect.Cause, self).__init__()

                    self.yang_name = "cause"
                    self.yang_parent_name = "detect"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("security-violation", ("security_violation", Native.Errdisable.Detect.Cause.SecurityViolation))])
                    self._leafs = OrderedDict([
                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                        ('arp_inspection', (YLeaf(YType.empty, 'arp-inspection'), ['Empty'])),
                        ('bpduguard', (YLeaf(YType.empty, 'bpduguard'), ['Empty'])),
                        ('dhcp_rate_limit', (YLeaf(YType.empty, 'dhcp-rate-limit'), ['Empty'])),
                        ('dtp_flap', (YLeaf(YType.empty, 'dtp-flap'), ['Empty'])),
                        ('gbic_invalid', (YLeaf(YType.empty, 'gbic-invalid'), ['Empty'])),
                        ('inline_power', (YLeaf(YType.empty, 'inline-power'), ['Empty'])),
                        ('l2ptguard', (YLeaf(YType.empty, 'l2ptguard'), ['Empty'])),
                        ('link_flap', (YLeaf(YType.empty, 'link-flap'), ['Empty'])),
                        ('loopback', (YLeaf(YType.empty, 'loopback'), ['Empty'])),
                        ('mlacp_minlink', (YLeaf(YType.empty, 'mlacp-minlink'), ['Empty'])),
                        ('pagp_flap', (YLeaf(YType.empty, 'pagp-flap'), ['Empty'])),
                        ('pppoe_ia_rate_limit', (YLeaf(YType.empty, 'pppoe-ia-rate-limit'), ['Empty'])),
                        ('sfp_config_mismatch', (YLeaf(YType.empty, 'sfp-config-mismatch'), ['Empty'])),
                        ('small_frame', (YLeaf(YType.empty, 'small-frame'), ['Empty'])),
                    ])
                    self.all = None
                    self.arp_inspection = None
                    self.bpduguard = None
                    self.dhcp_rate_limit = None
                    self.dtp_flap = None
                    self.gbic_invalid = None
                    self.inline_power = None
                    self.l2ptguard = None
                    self.link_flap = None
                    self.loopback = None
                    self.mlacp_minlink = None
                    self.pagp_flap = None
                    self.pppoe_ia_rate_limit = None
                    self.sfp_config_mismatch = None
                    self.small_frame = None

                    self.security_violation = Native.Errdisable.Detect.Cause.SecurityViolation()
                    self.security_violation.parent = self
                    self._children_name_map["security_violation"] = "security-violation"
                    self._segment_path = lambda: "cause"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/detect/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Errdisable.Detect.Cause, [u'all', u'arp_inspection', u'bpduguard', u'dhcp_rate_limit', u'dtp_flap', u'gbic_invalid', u'inline_power', u'l2ptguard', u'link_flap', u'loopback', u'mlacp_minlink', u'pagp_flap', u'pppoe_ia_rate_limit', u'sfp_config_mismatch', u'small_frame'], name, value)


                class SecurityViolation(Entity):
                    """
                    Enable error detection on 802.1x\-guard
                    
                    .. attribute:: shutdown
                    
                    	Specify error disable shutdown mode for 802.1x\-guard
                    	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.Detect.Cause.SecurityViolation.Shutdown>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Errdisable.Detect.Cause.SecurityViolation, self).__init__()

                        self.yang_name = "security-violation"
                        self.yang_parent_name = "cause"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("shutdown", ("shutdown", Native.Errdisable.Detect.Cause.SecurityViolation.Shutdown))])
                        self._leafs = OrderedDict()

                        self.shutdown = Native.Errdisable.Detect.Cause.SecurityViolation.Shutdown()
                        self.shutdown.parent = self
                        self._children_name_map["shutdown"] = "shutdown"
                        self._segment_path = lambda: "security-violation"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/detect/cause/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Errdisable.Detect.Cause.SecurityViolation, [], name, value)


                    class Shutdown(Entity):
                        """
                        Specify error disable shutdown mode for 802.1x\-guard
                        
                        .. attribute:: vlan
                        
                        	Shutdown vlan on 802.1x\-guard violation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Errdisable.Detect.Cause.SecurityViolation.Shutdown, self).__init__()

                            self.yang_name = "shutdown"
                            self.yang_parent_name = "security-violation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                            ])
                            self.vlan = None
                            self._segment_path = lambda: "shutdown"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/detect/cause/security-violation/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Errdisable.Detect.Cause.SecurityViolation.Shutdown, [u'vlan'], name, value)


        class FlapSetting(Entity):
            """
            Error disable flap detection setting
            
            .. attribute:: cause
            
            	Set error disable flap parameters for application
            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.FlapSetting.Cause>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Errdisable.FlapSetting, self).__init__()

                self.yang_name = "flap-setting"
                self.yang_parent_name = "errdisable"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("cause", ("cause", Native.Errdisable.FlapSetting.Cause))])
                self._leafs = OrderedDict()

                self.cause = Native.Errdisable.FlapSetting.Cause()
                self.cause.parent = self
                self._children_name_map["cause"] = "cause"
                self._segment_path = lambda: "flap-setting"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Errdisable.FlapSetting, [], name, value)


            class Cause(Entity):
                """
                Set error disable flap parameters for application
                
                .. attribute:: dtp_flap
                
                	Set the variables related to detection of dtp flaps
                	**type**\:  :py:class:`DtpFlap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.FlapSetting.Cause.DtpFlap>`
                
                .. attribute:: link_flap
                
                	Set the variables related to detection of link flaps
                	**type**\:  :py:class:`LinkFlap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.FlapSetting.Cause.LinkFlap>`
                
                .. attribute:: pagp_flap
                
                	Set the variables related to detection of pagp flaps
                	**type**\:  :py:class:`PagpFlap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.FlapSetting.Cause.PagpFlap>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Errdisable.FlapSetting.Cause, self).__init__()

                    self.yang_name = "cause"
                    self.yang_parent_name = "flap-setting"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dtp-flap", ("dtp_flap", Native.Errdisable.FlapSetting.Cause.DtpFlap)), ("link-flap", ("link_flap", Native.Errdisable.FlapSetting.Cause.LinkFlap)), ("pagp-flap", ("pagp_flap", Native.Errdisable.FlapSetting.Cause.PagpFlap))])
                    self._leafs = OrderedDict()

                    self.dtp_flap = Native.Errdisable.FlapSetting.Cause.DtpFlap()
                    self.dtp_flap.parent = self
                    self._children_name_map["dtp_flap"] = "dtp-flap"

                    self.link_flap = Native.Errdisable.FlapSetting.Cause.LinkFlap()
                    self.link_flap.parent = self
                    self._children_name_map["link_flap"] = "link-flap"

                    self.pagp_flap = Native.Errdisable.FlapSetting.Cause.PagpFlap()
                    self.pagp_flap.parent = self
                    self._children_name_map["pagp_flap"] = "pagp-flap"
                    self._segment_path = lambda: "cause"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/flap-setting/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Errdisable.FlapSetting.Cause, [], name, value)


                class DtpFlap(Entity):
                    """
                    Set the variables related to detection of dtp flaps
                    
                    .. attribute:: max_flaps
                    
                    	maximum flaps allowed before setting to errdisable
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    .. attribute:: time
                    
                    	time period the flaps are counted
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Errdisable.FlapSetting.Cause.DtpFlap, self).__init__()

                        self.yang_name = "dtp-flap"
                        self.yang_parent_name = "cause"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_flaps', (YLeaf(YType.uint8, 'max-flaps'), ['int'])),
                            ('time', (YLeaf(YType.uint8, 'time'), ['int'])),
                        ])
                        self.max_flaps = None
                        self.time = None
                        self._segment_path = lambda: "dtp-flap"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/flap-setting/cause/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Errdisable.FlapSetting.Cause.DtpFlap, [u'max_flaps', u'time'], name, value)


                class LinkFlap(Entity):
                    """
                    Set the variables related to detection of link flaps
                    
                    .. attribute:: max_flaps
                    
                    	maximum flaps allowed before setting to errdisable
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    .. attribute:: time
                    
                    	time period the flaps are counted
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Errdisable.FlapSetting.Cause.LinkFlap, self).__init__()

                        self.yang_name = "link-flap"
                        self.yang_parent_name = "cause"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_flaps', (YLeaf(YType.uint8, 'max-flaps'), ['int'])),
                            ('time', (YLeaf(YType.uint8, 'time'), ['int'])),
                        ])
                        self.max_flaps = None
                        self.time = None
                        self._segment_path = lambda: "link-flap"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/flap-setting/cause/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Errdisable.FlapSetting.Cause.LinkFlap, [u'max_flaps', u'time'], name, value)


                class PagpFlap(Entity):
                    """
                    Set the variables related to detection of pagp flaps
                    
                    .. attribute:: max_flaps
                    
                    	maximum flaps allowed before setting to errdisable
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    .. attribute:: time
                    
                    	time period the flaps are counted
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Errdisable.FlapSetting.Cause.PagpFlap, self).__init__()

                        self.yang_name = "pagp-flap"
                        self.yang_parent_name = "cause"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_flaps', (YLeaf(YType.uint8, 'max-flaps'), ['int'])),
                            ('time', (YLeaf(YType.uint8, 'time'), ['int'])),
                        ])
                        self.max_flaps = None
                        self.time = None
                        self._segment_path = lambda: "pagp-flap"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/flap-setting/cause/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Errdisable.FlapSetting.Cause.PagpFlap, [u'max_flaps', u'time'], name, value)


        class Recovery(Entity):
            """
            Error disable recovery
            
            .. attribute:: cause
            
            	Enable error disable recovery for application
            	**type**\:  :py:class:`Cause <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.Recovery.Cause>`
            
            .. attribute:: interval
            
            	Error disable recovery timer value
            	**type**\: int
            
            	**range:** 30..86400
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Errdisable.Recovery, self).__init__()

                self.yang_name = "recovery"
                self.yang_parent_name = "errdisable"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("cause", ("cause", Native.Errdisable.Recovery.Cause))])
                self._leafs = OrderedDict([
                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                ])
                self.interval = None

                self.cause = Native.Errdisable.Recovery.Cause()
                self.cause.parent = self
                self._children_name_map["cause"] = "cause"
                self._segment_path = lambda: "recovery"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Errdisable.Recovery, [u'interval'], name, value)


            class Cause(Entity):
                """
                Enable error disable recovery for application
                
                .. attribute:: all
                
                	Enable timer to recover from all error causes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: arp_inspection
                
                	Enable timer to recover from arp inspection error disable state
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bpduguard
                
                	Enable timer to recover from BPDU Guard error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: channel_misconfig
                
                	(STP)  Enable timer to recover from channel misconfig error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dhcp_rate_limit
                
                	Enable timer to recover from dhcp\-rate\-limit error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dtp_flap
                
                	Enable timer to recover from dtp\-flap error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: gbic_invalid
                
                	Enable timer to recover from invalid GBIC error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: inline_power
                
                	Enable timer to recover from inline\-power error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: l2ptguard
                
                	Enable timer to recover from l2protocol\-tunnel error disable state
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link_flap
                
                	Enable timer to recover from link\-flap error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: link_monitor_failure
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: loopback
                
                	Enable timer to recover from loopback error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mac_limit
                
                	Enable timer to recover from mac limit disable state
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mlacp_minlink
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: oam_remote_failure
                
                	
                	**type**\:  :py:class:`OamRemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Errdisable.Recovery.Cause.OamRemoteFailure>`
                
                	**presence node**\: True
                
                .. attribute:: pagp_flap
                
                	Enable timer to recover from pagp\-flap error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: port_mode_failure
                
                	Enable timer to recover from port mode change failure
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pppoe_ia_rate_limit
                
                	Enable timer to recover from PPPoE IA rate\-limit error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: psp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: psecure_violation
                
                	Enable timer to recover from psecure violation error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: security_violation
                
                	Enable timer to recover from 802.1x violation error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sfp_config_mismatch
                
                	Enable timer to recover from SFP config mismatch error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: small_frame
                
                	Enable timer to recover from small frame error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: storm_control
                
                	Enable timer to recover from storm\-control error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: udld
                
                	Enable timer to recover from udld error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: unicast_flood
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vmps
                
                	Enable timer to recover from vmps shutdown error
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Errdisable.Recovery.Cause, self).__init__()

                    self.yang_name = "cause"
                    self.yang_parent_name = "recovery"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam-remote-failure", ("oam_remote_failure", Native.Errdisable.Recovery.Cause.OamRemoteFailure))])
                    self._leafs = OrderedDict([
                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                        ('arp_inspection', (YLeaf(YType.empty, 'arp-inspection'), ['Empty'])),
                        ('bpduguard', (YLeaf(YType.empty, 'bpduguard'), ['Empty'])),
                        ('channel_misconfig', (YLeaf(YType.empty, 'channel-misconfig'), ['Empty'])),
                        ('dhcp_rate_limit', (YLeaf(YType.empty, 'dhcp-rate-limit'), ['Empty'])),
                        ('dtp_flap', (YLeaf(YType.empty, 'dtp-flap'), ['Empty'])),
                        ('gbic_invalid', (YLeaf(YType.empty, 'gbic-invalid'), ['Empty'])),
                        ('inline_power', (YLeaf(YType.empty, 'inline-power'), ['Empty'])),
                        ('l2ptguard', (YLeaf(YType.empty, 'l2ptguard'), ['Empty'])),
                        ('link_flap', (YLeaf(YType.empty, 'link-flap'), ['Empty'])),
                        ('link_monitor_failure', (YLeaf(YType.empty, 'link-monitor-failure'), ['Empty'])),
                        ('loopback', (YLeaf(YType.empty, 'loopback'), ['Empty'])),
                        ('mac_limit', (YLeaf(YType.empty, 'mac-limit'), ['Empty'])),
                        ('mlacp_minlink', (YLeaf(YType.empty, 'mlacp-minlink'), ['Empty'])),
                        ('pagp_flap', (YLeaf(YType.empty, 'pagp-flap'), ['Empty'])),
                        ('port_mode_failure', (YLeaf(YType.empty, 'port-mode-failure'), ['Empty'])),
                        ('pppoe_ia_rate_limit', (YLeaf(YType.empty, 'pppoe-ia-rate-limit'), ['Empty'])),
                        ('psp', (YLeaf(YType.empty, 'psp'), ['Empty'])),
                        ('psecure_violation', (YLeaf(YType.empty, 'psecure-violation'), ['Empty'])),
                        ('security_violation', (YLeaf(YType.empty, 'security-violation'), ['Empty'])),
                        ('sfp_config_mismatch', (YLeaf(YType.empty, 'sfp-config-mismatch'), ['Empty'])),
                        ('small_frame', (YLeaf(YType.empty, 'small-frame'), ['Empty'])),
                        ('storm_control', (YLeaf(YType.empty, 'storm-control'), ['Empty'])),
                        ('udld', (YLeaf(YType.empty, 'udld'), ['Empty'])),
                        ('unicast_flood', (YLeaf(YType.empty, 'unicast-flood'), ['Empty'])),
                        ('vmps', (YLeaf(YType.empty, 'vmps'), ['Empty'])),
                    ])
                    self.all = None
                    self.arp_inspection = None
                    self.bpduguard = None
                    self.channel_misconfig = None
                    self.dhcp_rate_limit = None
                    self.dtp_flap = None
                    self.gbic_invalid = None
                    self.inline_power = None
                    self.l2ptguard = None
                    self.link_flap = None
                    self.link_monitor_failure = None
                    self.loopback = None
                    self.mac_limit = None
                    self.mlacp_minlink = None
                    self.pagp_flap = None
                    self.port_mode_failure = None
                    self.pppoe_ia_rate_limit = None
                    self.psp = None
                    self.psecure_violation = None
                    self.security_violation = None
                    self.sfp_config_mismatch = None
                    self.small_frame = None
                    self.storm_control = None
                    self.udld = None
                    self.unicast_flood = None
                    self.vmps = None

                    self.oam_remote_failure = None
                    self._children_name_map["oam_remote_failure"] = "oam-remote-failure"
                    self._segment_path = lambda: "cause"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/recovery/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Errdisable.Recovery.Cause, [u'all', u'arp_inspection', u'bpduguard', u'channel_misconfig', u'dhcp_rate_limit', u'dtp_flap', u'gbic_invalid', u'inline_power', u'l2ptguard', u'link_flap', u'link_monitor_failure', u'loopback', u'mac_limit', u'mlacp_minlink', u'pagp_flap', u'port_mode_failure', u'pppoe_ia_rate_limit', u'psp', u'psecure_violation', u'security_violation', u'sfp_config_mismatch', u'small_frame', u'storm_control', u'udld', u'unicast_flood', u'vmps'], name, value)


                class OamRemoteFailure(Entity):
                    """
                    
                    
                    .. attribute:: critical_event
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dying_gasp
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: link_fault
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Errdisable.Recovery.Cause.OamRemoteFailure, self).__init__()

                        self.yang_name = "oam-remote-failure"
                        self.yang_parent_name = "cause"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('critical_event', (YLeaf(YType.empty, 'critical-event'), ['Empty'])),
                            ('dying_gasp', (YLeaf(YType.empty, 'dying-gasp'), ['Empty'])),
                            ('link_fault', (YLeaf(YType.empty, 'link-fault'), ['Empty'])),
                        ])
                        self.critical_event = None
                        self.dying_gasp = None
                        self.link_fault = None
                        self._segment_path = lambda: "oam-remote-failure"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/errdisable/recovery/cause/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Errdisable.Recovery.Cause.OamRemoteFailure, [u'critical_event', u'dying_gasp', u'link_fault'], name, value)


    class Identity(Entity):
        """
        Identity Configuration Commands
        
        .. attribute:: policy
        
        	Create an Identity policy
        	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy>`
        
        .. attribute:: profile
        
        	Create an Identity profile
        	**type**\:  :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Profile>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Identity, self).__init__()

            self.yang_name = "identity"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("policy", ("policy", Native.Identity.Policy)), ("profile", ("profile", Native.Identity.Profile))])
            self._leafs = OrderedDict()

            self.profile = Native.Identity.Profile()
            self.profile.parent = self
            self._children_name_map["profile"] = "profile"

            self.policy = YList(self)
            self._segment_path = lambda: "identity"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Identity, [], name, value)


        class Policy(Entity):
            """
            Create an Identity policy
            
            .. attribute:: name  (key)
            
            	Specify a policy name
            	**type**\: str
            
            .. attribute:: no
            
            	Negate a command or set its defaults
            	**type**\:  :py:class:`No <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.No>`
            
            .. attribute:: absolute_timer
            
            	Absolute timeout value in seconds
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: access_group
            
            	Access list to be applied
            	**type**\: str
            
            .. attribute:: description
            
            	Enter a description
            	**type**\: str
            
            .. attribute:: inactivity_timer
            
            	Inactivity timeout value in seconds
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: interface_template
            
            	Interface template to be applied
            	**type**\: str
            
            .. attribute:: linksec
            
            	Configure link security parameters
            	**type**\:  :py:class:`Linksec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.Linksec>`
            
            .. attribute:: redirect
            
            	Redirect clients to a particular location
            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.Redirect>`
            
            .. attribute:: service_policy
            
            	Configure service policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.ServicePolicy>`
            
            .. attribute:: sgt
            
            	SGT tag
            	**type**\: int
            
            	**range:** 2..65519
            
            .. attribute:: tag
            
            	tag name
            	**type**\: str
            
            .. attribute:: tunnel
            
            	tunnel for wired client access
            	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.Tunnel>`
            
            .. attribute:: vlan
            
            	Enter a VlanId
            	**type**\: int
            
            	**range:** 1..4094
            
            .. attribute:: voice
            
            	Voice feature
            	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.Voice>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Identity.Policy, self).__init__()

                self.yang_name = "policy"
                self.yang_parent_name = "identity"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("no", ("no", Native.Identity.Policy.No)), ("linksec", ("linksec", Native.Identity.Policy.Linksec)), ("redirect", ("redirect", Native.Identity.Policy.Redirect)), ("service-policy", ("service_policy", Native.Identity.Policy.ServicePolicy)), ("tunnel", ("tunnel", Native.Identity.Policy.Tunnel)), ("voice", ("voice", Native.Identity.Policy.Voice))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('absolute_timer', (YLeaf(YType.uint16, 'absolute-timer'), ['int'])),
                    ('access_group', (YLeaf(YType.str, 'access-group'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('inactivity_timer', (YLeaf(YType.uint16, 'inactivity-timer'), ['int'])),
                    ('interface_template', (YLeaf(YType.str, 'interface-template'), ['str'])),
                    ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                    ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                ])
                self.name = None
                self.absolute_timer = None
                self.access_group = None
                self.description = None
                self.inactivity_timer = None
                self.interface_template = None
                self.sgt = None
                self.tag = None
                self.vlan = None

                self.no = Native.Identity.Policy.No()
                self.no.parent = self
                self._children_name_map["no"] = "no"

                self.linksec = Native.Identity.Policy.Linksec()
                self.linksec.parent = self
                self._children_name_map["linksec"] = "linksec"

                self.redirect = Native.Identity.Policy.Redirect()
                self.redirect.parent = self
                self._children_name_map["redirect"] = "redirect"

                self.service_policy = Native.Identity.Policy.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.tunnel = Native.Identity.Policy.Tunnel()
                self.tunnel.parent = self
                self._children_name_map["tunnel"] = "tunnel"

                self.voice = Native.Identity.Policy.Voice()
                self.voice.parent = self
                self._children_name_map["voice"] = "voice"
                self._segment_path = lambda: "policy" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/identity/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Identity.Policy, [u'name', u'absolute_timer', u'access_group', u'description', u'inactivity_timer', u'interface_template', u'sgt', u'tag', u'vlan'], name, value)


            class No(Entity):
                """
                Negate a command or set its defaults
                
                .. attribute:: absolute_timer
                
                	Absolute timeout value in seconds
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: access_group
                
                	Access list to be applied
                	**type**\: str
                
                .. attribute:: description
                
                	Enter a description
                	**type**\: str
                
                .. attribute:: inactivity_timer
                
                	Inactivity timeout value in seconds
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: interface_template
                
                	Interface template to be applied
                	**type**\: str
                
                .. attribute:: linksec
                
                	Configure link security parameters
                	**type**\:  :py:class:`Linksec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.No.Linksec>`
                
                .. attribute:: redirect
                
                	Redirect clients to a particular location
                	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.No.Redirect>`
                
                .. attribute:: service_policy
                
                	Configure service policy
                	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.No.ServicePolicy>`
                
                .. attribute:: sgt
                
                	SGT tag
                	**type**\: int
                
                	**range:** 2..65519
                
                .. attribute:: tag
                
                	tag name
                	**type**\: str
                
                .. attribute:: tunnel
                
                	tunnel for wired client access
                	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.No.Tunnel>`
                
                .. attribute:: vlan
                
                	Enter a VlanId
                	**type**\: int
                
                	**range:** 1..4094
                
                .. attribute:: voice
                
                	Voice feature
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.No.Voice>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Identity.Policy.No, self).__init__()

                    self.yang_name = "no"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("linksec", ("linksec", Native.Identity.Policy.No.Linksec)), ("redirect", ("redirect", Native.Identity.Policy.No.Redirect)), ("service-policy", ("service_policy", Native.Identity.Policy.No.ServicePolicy)), ("tunnel", ("tunnel", Native.Identity.Policy.No.Tunnel)), ("voice", ("voice", Native.Identity.Policy.No.Voice))])
                    self._leafs = OrderedDict([
                        ('absolute_timer', (YLeaf(YType.uint16, 'absolute-timer'), ['int'])),
                        ('access_group', (YLeaf(YType.str, 'access-group'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('inactivity_timer', (YLeaf(YType.uint16, 'inactivity-timer'), ['int'])),
                        ('interface_template', (YLeaf(YType.str, 'interface-template'), ['str'])),
                        ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                        ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                    ])
                    self.absolute_timer = None
                    self.access_group = None
                    self.description = None
                    self.inactivity_timer = None
                    self.interface_template = None
                    self.sgt = None
                    self.tag = None
                    self.vlan = None

                    self.linksec = Native.Identity.Policy.No.Linksec()
                    self.linksec.parent = self
                    self._children_name_map["linksec"] = "linksec"

                    self.redirect = Native.Identity.Policy.No.Redirect()
                    self.redirect.parent = self
                    self._children_name_map["redirect"] = "redirect"

                    self.service_policy = Native.Identity.Policy.No.ServicePolicy()
                    self.service_policy.parent = self
                    self._children_name_map["service_policy"] = "service-policy"

                    self.tunnel = Native.Identity.Policy.No.Tunnel()
                    self.tunnel.parent = self
                    self._children_name_map["tunnel"] = "tunnel"

                    self.voice = Native.Identity.Policy.No.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "no"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Identity.Policy.No, [u'absolute_timer', u'access_group', u'description', u'inactivity_timer', u'interface_template', u'sgt', u'tag', u'vlan'], name, value)


                class Linksec(Entity):
                    """
                    Configure link security parameters
                    
                    .. attribute:: policy
                    
                    	Set the link security policy
                    	**type**\:  :py:class:`Policy_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.No.Linksec.Policy_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Identity.Policy.No.Linksec, self).__init__()

                        self.yang_name = "linksec"
                        self.yang_parent_name = "no"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy', (YLeaf(YType.enumeration, 'policy'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Identity.Policy.No.Linksec.Policy_')])),
                        ])
                        self.policy = None
                        self._segment_path = lambda: "linksec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Identity.Policy.No.Linksec, [u'policy'], name, value)

                    class Policy_(Enum):
                        """
                        Policy\_ (Enum Class)

                        Set the link security policy

                        .. data:: must_not_secure = 0

                        .. data:: must_secure = 1

                        .. data:: should_secure = 2

                        """

                        must_not_secure = Enum.YLeaf(0, "must-not-secure")

                        must_secure = Enum.YLeaf(1, "must-secure")

                        should_secure = Enum.YLeaf(2, "should-secure")



                class Redirect(Entity):
                    """
                    Redirect clients to a particular location
                    
                    .. attribute:: url
                    
                    	URL where clients should be redirected
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Identity.Policy.No.Redirect, self).__init__()

                        self.yang_name = "redirect"
                        self.yang_parent_name = "no"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('url', (YLeaf(YType.str, 'url'), ['str'])),
                        ])
                        self.url = None
                        self._segment_path = lambda: "redirect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Identity.Policy.No.Redirect, [u'url'], name, value)


                class ServicePolicy(Entity):
                    """
                    Configure service policy
                    
                    .. attribute:: qos
                    
                    	Configure qos policies for client
                    	**type**\: list of  		 :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.No.ServicePolicy.Qos>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Identity.Policy.No.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "no"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("qos", ("qos", Native.Identity.Policy.No.ServicePolicy.Qos))])
                        self._leafs = OrderedDict()

                        self.qos = YList(self)
                        self._segment_path = lambda: "service-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Identity.Policy.No.ServicePolicy, [], name, value)


                    class Qos(Entity):
                        """
                        Configure qos policies for client
                        
                        .. attribute:: direction  (key)
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.No.ServicePolicy.Qos.Direction>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Identity.Policy.No.ServicePolicy.Qos, self).__init__()

                            self.yang_name = "qos"
                            self.yang_parent_name = "service-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['direction']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Identity.Policy.No.ServicePolicy.Qos.Direction')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.direction = None
                            self.name = None
                            self._segment_path = lambda: "qos" + "[direction='" + str(self.direction) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Identity.Policy.No.ServicePolicy.Qos, [u'direction', u'name'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: input = 0

                            .. data:: output = 1

                            """

                            input = Enum.YLeaf(0, "input")

                            output = Enum.YLeaf(1, "output")



                class Tunnel(Entity):
                    """
                    tunnel for wired client access
                    
                    .. attribute:: type
                    
                    	tunnel type
                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.No.Tunnel.Type>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Identity.Policy.No.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "no"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("type", ("type", Native.Identity.Policy.No.Tunnel.Type))])
                        self._leafs = OrderedDict()

                        self.type = Native.Identity.Policy.No.Tunnel.Type()
                        self.type.parent = self
                        self._children_name_map["type"] = "type"
                        self._segment_path = lambda: "tunnel"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Identity.Policy.No.Tunnel, [], name, value)


                    class Type(Entity):
                        """
                        tunnel type
                        
                        .. attribute:: capwap
                        
                        	capwap tunnel type
                        	**type**\:  :py:class:`Capwap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.No.Tunnel.Type.Capwap>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Identity.Policy.No.Tunnel.Type, self).__init__()

                            self.yang_name = "type"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("capwap", ("capwap", Native.Identity.Policy.No.Tunnel.Type.Capwap))])
                            self._leafs = OrderedDict()

                            self.capwap = Native.Identity.Policy.No.Tunnel.Type.Capwap()
                            self.capwap.parent = self
                            self._children_name_map["capwap"] = "capwap"
                            self._segment_path = lambda: "type"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Identity.Policy.No.Tunnel.Type, [], name, value)


                        class Capwap(Entity):
                            """
                            capwap tunnel type
                            
                            .. attribute:: name
                            
                            	tunnel profile name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Identity.Policy.No.Tunnel.Type.Capwap, self).__init__()

                                self.yang_name = "capwap"
                                self.yang_parent_name = "type"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "capwap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Identity.Policy.No.Tunnel.Type.Capwap, [u'name'], name, value)


                class Voice(Entity):
                    """
                    Voice feature
                    
                    .. attribute:: vlan
                    
                    	Critical voice vlan
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Identity.Policy.No.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "no"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Identity.Policy.No.Voice, [u'vlan'], name, value)


            class Linksec(Entity):
                """
                Configure link security parameters
                
                .. attribute:: policy
                
                	Set the link security policy
                	**type**\:  :py:class:`Policy_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.Linksec.Policy_>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Identity.Policy.Linksec, self).__init__()

                    self.yang_name = "linksec"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('policy', (YLeaf(YType.enumeration, 'policy'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Identity.Policy.Linksec.Policy_')])),
                    ])
                    self.policy = None
                    self._segment_path = lambda: "linksec"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Identity.Policy.Linksec, [u'policy'], name, value)

                class Policy_(Enum):
                    """
                    Policy\_ (Enum Class)

                    Set the link security policy

                    .. data:: must_not_secure = 0

                    .. data:: must_secure = 1

                    .. data:: should_secure = 2

                    """

                    must_not_secure = Enum.YLeaf(0, "must-not-secure")

                    must_secure = Enum.YLeaf(1, "must-secure")

                    should_secure = Enum.YLeaf(2, "should-secure")



            class Redirect(Entity):
                """
                Redirect clients to a particular location
                
                .. attribute:: url
                
                	URL where clients should be redirected
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Identity.Policy.Redirect, self).__init__()

                    self.yang_name = "redirect"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('url', (YLeaf(YType.str, 'url'), ['str'])),
                    ])
                    self.url = None
                    self._segment_path = lambda: "redirect"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Identity.Policy.Redirect, [u'url'], name, value)


            class ServicePolicy(Entity):
                """
                Configure service policy
                
                .. attribute:: qos
                
                	Configure qos policies for client
                	**type**\: list of  		 :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.ServicePolicy.Qos>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Identity.Policy.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("qos", ("qos", Native.Identity.Policy.ServicePolicy.Qos))])
                    self._leafs = OrderedDict()

                    self.qos = YList(self)
                    self._segment_path = lambda: "service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Identity.Policy.ServicePolicy, [], name, value)


                class Qos(Entity):
                    """
                    Configure qos policies for client
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.ServicePolicy.Qos.Direction>`
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Identity.Policy.ServicePolicy.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Identity.Policy.ServicePolicy.Qos.Direction')])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.direction = None
                        self.name = None
                        self._segment_path = lambda: "qos" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Identity.Policy.ServicePolicy.Qos, [u'direction', u'name'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: input = 0

                        .. data:: output = 1

                        """

                        input = Enum.YLeaf(0, "input")

                        output = Enum.YLeaf(1, "output")



            class Tunnel(Entity):
                """
                tunnel for wired client access
                
                .. attribute:: type
                
                	tunnel type
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.Tunnel.Type>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Identity.Policy.Tunnel, self).__init__()

                    self.yang_name = "tunnel"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Identity.Policy.Tunnel.Type))])
                    self._leafs = OrderedDict()

                    self.type = Native.Identity.Policy.Tunnel.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Identity.Policy.Tunnel, [], name, value)


                class Type(Entity):
                    """
                    tunnel type
                    
                    .. attribute:: capwap
                    
                    	capwap tunnel type
                    	**type**\:  :py:class:`Capwap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Identity.Policy.Tunnel.Type.Capwap>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Identity.Policy.Tunnel.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("capwap", ("capwap", Native.Identity.Policy.Tunnel.Type.Capwap))])
                        self._leafs = OrderedDict()

                        self.capwap = Native.Identity.Policy.Tunnel.Type.Capwap()
                        self.capwap.parent = self
                        self._children_name_map["capwap"] = "capwap"
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Identity.Policy.Tunnel.Type, [], name, value)


                    class Capwap(Entity):
                        """
                        capwap tunnel type
                        
                        .. attribute:: name
                        
                        	tunnel profile name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Identity.Policy.Tunnel.Type.Capwap, self).__init__()

                            self.yang_name = "capwap"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "capwap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Identity.Policy.Tunnel.Type.Capwap, [u'name'], name, value)


            class Voice(Entity):
                """
                Voice feature
                
                .. attribute:: vlan
                
                	Critical voice vlan
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Identity.Policy.Voice, self).__init__()

                    self.yang_name = "voice"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                    ])
                    self.vlan = None
                    self._segment_path = lambda: "voice"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Identity.Policy.Voice, [u'vlan'], name, value)


        class Profile(Entity):
            """
            Create an Identity profile
            
            .. attribute:: dot1x
            
            	Service type for 802.1x
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: default
            
            	Service type default
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Identity.Profile, self).__init__()

                self.yang_name = "profile"
                self.yang_parent_name = "identity"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('dot1x', (YLeaf(YType.empty, 'dot1x'), ['Empty'])),
                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                ])
                self.dot1x = None
                self.default = None
                self._segment_path = lambda: "profile"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/identity/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Identity.Profile, [u'dot1x', u'default'], name, value)


    class Monitor(Entity):
        """
        Monitoring different system events
        
        .. attribute:: event_trace
        
        	Tracing of system events
        	**type**\:  :py:class:`EventTrace <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.EventTrace>`
        
        .. attribute:: session
        
        	Configure a SPAN session
        	**type**\: list of  		 :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Monitor, self).__init__()

            self.yang_name = "monitor"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("event-trace", ("event_trace", Native.Monitor.EventTrace)), ("session", ("session", Native.Monitor.Session))])
            self._leafs = OrderedDict()

            self.event_trace = Native.Monitor.EventTrace()
            self.event_trace.parent = self
            self._children_name_map["event_trace"] = "event-trace"

            self.session = YList(self)
            self._segment_path = lambda: "monitor"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Monitor, [], name, value)


        class EventTrace(Entity):
            """
            Tracing of system events
            
            .. attribute:: timestamps
            
            	Format of event trace timestamps
            	**type**\:  :py:class:`Timestamps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.EventTrace.Timestamps>`
            
            	**presence node**\: True
            
            .. attribute:: atom
            
            	AToM traces
            	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.EventTrace.Atom>`
            
            .. attribute:: sequence_number
            
            	Display event trace entries with sequence number
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Monitor.EventTrace, self).__init__()

                self.yang_name = "event-trace"
                self.yang_parent_name = "monitor"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("timestamps", ("timestamps", Native.Monitor.EventTrace.Timestamps)), ("atom", ("atom", Native.Monitor.EventTrace.Atom))])
                self._leafs = OrderedDict([
                    ('sequence_number', (YLeaf(YType.empty, 'sequence-number'), ['Empty'])),
                ])
                self.sequence_number = None

                self.timestamps = None
                self._children_name_map["timestamps"] = "timestamps"

                self.atom = Native.Monitor.EventTrace.Atom()
                self.atom.parent = self
                self._children_name_map["atom"] = "atom"
                self._segment_path = lambda: "event-trace"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/monitor/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Monitor.EventTrace, [u'sequence_number'], name, value)


            class Timestamps(Entity):
                """
                Format of event trace timestamps
                
                .. attribute:: uptime
                
                	Timestamp with system uptime
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Monitor.EventTrace.Timestamps, self).__init__()

                    self.yang_name = "timestamps"
                    self.yang_parent_name = "event-trace"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('uptime', (YLeaf(YType.empty, 'uptime'), ['Empty'])),
                    ])
                    self.uptime = None
                    self._segment_path = lambda: "timestamps"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/monitor/event-trace/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Monitor.EventTrace.Timestamps, [u'uptime'], name, value)


            class Atom(Entity):
                """
                AToM traces
                
                .. attribute:: error
                
                	This buffer stores only error logs by default
                	**type**\:  :py:class:`Error <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.EventTrace.Atom.Error>`
                
                .. attribute:: event
                
                	This buffer stores all logs by default
                	**type**\:  :py:class:`Event <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.EventTrace.Atom.Event>`
                
                .. attribute:: major
                
                	This buffer stores only major logs and error logs by default
                	**type**\:  :py:class:`Major <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.EventTrace.Atom.Major>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Monitor.EventTrace.Atom, self).__init__()

                    self.yang_name = "atom"
                    self.yang_parent_name = "event-trace"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("error", ("error", Native.Monitor.EventTrace.Atom.Error)), ("event", ("event", Native.Monitor.EventTrace.Atom.Event)), ("major", ("major", Native.Monitor.EventTrace.Atom.Major))])
                    self._leafs = OrderedDict()

                    self.error = Native.Monitor.EventTrace.Atom.Error()
                    self.error.parent = self
                    self._children_name_map["error"] = "error"

                    self.event = Native.Monitor.EventTrace.Atom.Event()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.major = Native.Monitor.EventTrace.Atom.Major()
                    self.major.parent = self
                    self._children_name_map["major"] = "major"
                    self._segment_path = lambda: "atom"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/monitor/event-trace/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Monitor.EventTrace.Atom, [], name, value)


                class Error(Entity):
                    """
                    This buffer stores only error logs by default.
                    
                    .. attribute:: enable
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: include
                    
                    	Include a subset of debug types
                    	**type**\: list of   :py:class:`MonitorEventType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.MonitorEventType>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.EventTrace.Atom.Error, self).__init__()

                        self.yang_name = "error"
                        self.yang_parent_name = "atom"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('include', (YLeafList(YType.enumeration, 'include'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'MonitorEventType', '')])),
                        ])
                        self.enable = None
                        self.disable = None
                        self.include = []
                        self._segment_path = lambda: "error"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/monitor/event-trace/atom/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.EventTrace.Atom.Error, [u'enable', u'disable', u'include'], name, value)


                class Event(Entity):
                    """
                    This buffer stores all logs by default.
                    
                    .. attribute:: enable
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: size
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: exclude
                    
                    	Include a subset of debug types
                    	**type**\: list of   :py:class:`MonitorEventType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.MonitorEventType>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.EventTrace.Atom.Event, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "atom"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('size', (YLeaf(YType.uint32, 'size'), ['int'])),
                            ('exclude', (YLeafList(YType.enumeration, 'exclude'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'MonitorEventType', '')])),
                        ])
                        self.enable = None
                        self.disable = None
                        self.size = None
                        self.exclude = []
                        self._segment_path = lambda: "event"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/monitor/event-trace/atom/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.EventTrace.Atom.Event, [u'enable', u'disable', u'size', u'exclude'], name, value)


                class Major(Entity):
                    """
                    This buffer stores only major logs and error logs by default.
                    
                    .. attribute:: enable
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disable
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: include
                    
                    	Include a subset of debug types
                    	**type**\: list of   :py:class:`MonitorEventType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.MonitorEventType>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.EventTrace.Atom.Major, self).__init__()

                        self.yang_name = "major"
                        self.yang_parent_name = "atom"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('include', (YLeafList(YType.enumeration, 'include'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'MonitorEventType', '')])),
                        ])
                        self.enable = None
                        self.disable = None
                        self.include = []
                        self._segment_path = lambda: "major"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/monitor/event-trace/atom/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.EventTrace.Atom.Major, [u'enable', u'disable', u'include'], name, value)


        class Session(Entity):
            """
            Configure a SPAN session
            
            .. attribute:: id  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..66
            
            .. attribute:: destination
            
            	SPAN destination interface or VLAN
            	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Destination>`
            
            .. attribute:: filter
            
            	SPAN filter VLAN
            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Filter>`
            
            .. attribute:: source
            
            	SPAN source interface, VLAN 
            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Source>`
            
            .. attribute:: type
            
            	Type of monitor session
            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Monitor.Session, self).__init__()

                self.yang_name = "session"
                self.yang_parent_name = "monitor"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("destination", ("destination", Native.Monitor.Session.Destination)), ("filter", ("filter", Native.Monitor.Session.Filter)), ("source", ("source", Native.Monitor.Session.Source)), ("type", ("type", Native.Monitor.Session.Type))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                ])
                self.id = None

                self.destination = Native.Monitor.Session.Destination()
                self.destination.parent = self
                self._children_name_map["destination"] = "destination"

                self.filter = Native.Monitor.Session.Filter()
                self.filter.parent = self
                self._children_name_map["filter"] = "filter"

                self.source = Native.Monitor.Session.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"

                self.type = Native.Monitor.Session.Type()
                self.type.parent = self
                self._children_name_map["type"] = "type"
                self._segment_path = lambda: "session" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/monitor/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Monitor.Session, [u'id'], name, value)


            class Destination(Entity):
                """
                SPAN destination interface or VLAN
                
                .. attribute:: interface
                
                	SPAN destination interface
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Destination.Interface>`
                
                .. attribute:: remote
                
                	SPAN destination Remote
                	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Destination.Remote>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Monitor.Session.Destination, self).__init__()

                    self.yang_name = "destination"
                    self.yang_parent_name = "session"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Native.Monitor.Session.Destination.Interface)), ("remote", ("remote", Native.Monitor.Session.Destination.Remote))])
                    self._leafs = OrderedDict()

                    self.remote = Native.Monitor.Session.Destination.Remote()
                    self.remote.parent = self
                    self._children_name_map["remote"] = "remote"

                    self.interface = YList(self)
                    self._segment_path = lambda: "destination"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Monitor.Session.Destination, [], name, value)


                class Interface(Entity):
                    """
                    SPAN destination interface
                    
                    .. attribute:: name  (key)
                    
                    	Interface Name
                    	**type**\: str
                    
                    .. attribute:: encapsulation
                    
                    	Set encapsulation for destination interface
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Destination.Interface.Encapsulation>`
                    
                    .. attribute:: ingress
                    
                    	Enable ingress traffic forwarding
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ingress_encap
                    
                    	
                    	**type**\:  :py:class:`IngressEncap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Destination.Interface.IngressEncap>`
                    
                    .. attribute:: vlan
                    
                    	Set default VLAN for untagged ingress traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.Session.Destination.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "destination"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Monitor.Session.Destination.Interface.Encapsulation')])),
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('ingress_encap', (YLeaf(YType.enumeration, 'ingress-encap'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Monitor.Session.Destination.Interface.IngressEncap')])),
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.name = None
                        self.encapsulation = None
                        self.ingress = None
                        self.ingress_encap = None
                        self.vlan = None
                        self._segment_path = lambda: "interface" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.Session.Destination.Interface, [u'name', u'encapsulation', u'ingress', u'ingress_encap', u'vlan'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Set encapsulation for destination interface

                        .. data:: dot1q = 0

                        .. data:: isl = 1

                        .. data:: replicate = 2

                        """

                        dot1q = Enum.YLeaf(0, "dot1q")

                        isl = Enum.YLeaf(1, "isl")

                        replicate = Enum.YLeaf(2, "replicate")


                    class IngressEncap(Enum):
                        """
                        IngressEncap (Enum Class)

                        .. data:: dot1q = 0

                        .. data:: isl = 1

                        .. data:: untagged = 2

                        """

                        dot1q = Enum.YLeaf(0, "dot1q")

                        isl = Enum.YLeaf(1, "isl")

                        untagged = Enum.YLeaf(2, "untagged")



                class Remote(Entity):
                    """
                    SPAN destination Remote
                    
                    .. attribute:: vlan
                    
                    	Remote SPAN destination RSPAN VLAN
                    	**type**\: int
                    
                    	**range:** 1006..4094
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.Session.Destination.Remote, self).__init__()

                        self.yang_name = "remote"
                        self.yang_parent_name = "destination"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "remote"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.Session.Destination.Remote, [u'vlan'], name, value)


            class Filter(Entity):
                """
                SPAN filter VLAN
                
                .. attribute:: packet_type
                
                	
                	**type**\:  :py:class:`PacketType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Filter.PacketType>`
                
                .. attribute:: ip
                
                	Specify IP Access control rules
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Filter.Ip>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Monitor.Session.Filter, self).__init__()

                    self.yang_name = "filter"
                    self.yang_parent_name = "session"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("packet-type", ("packet_type", Native.Monitor.Session.Filter.PacketType)), ("ip", ("ip", Native.Monitor.Session.Filter.Ip))])
                    self._leafs = OrderedDict()

                    self.packet_type = Native.Monitor.Session.Filter.PacketType()
                    self.packet_type.parent = self
                    self._children_name_map["packet_type"] = "packet-type"

                    self.ip = Native.Monitor.Session.Filter.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "filter"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Monitor.Session.Filter, [], name, value)


                class PacketType(Entity):
                    """
                    
                    
                    .. attribute:: status
                    
                    	
                    	**type**\:  :py:class:`Status <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Filter.PacketType.Status>`
                    
                    .. attribute:: direction
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Filter.PacketType.Direction>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.Session.Filter.PacketType, self).__init__()

                        self.yang_name = "packet-type"
                        self.yang_parent_name = "filter"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Monitor.Session.Filter.PacketType.Status')])),
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Monitor.Session.Filter.PacketType.Direction')])),
                        ])
                        self.status = None
                        self.direction = None
                        self._segment_path = lambda: "packet-type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.Session.Filter.PacketType, [u'status', u'direction'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: rx = 0

                        .. data:: tx = 1

                        """

                        rx = Enum.YLeaf(0, "rx")

                        tx = Enum.YLeaf(1, "tx")


                    class Status(Enum):
                        """
                        Status (Enum Class)

                        .. data:: good = 0

                        .. data:: bad = 1

                        """

                        good = Enum.YLeaf(0, "good")

                        bad = Enum.YLeaf(1, "bad")



                class Ip(Entity):
                    """
                    Specify IP Access control rules
                    
                    .. attribute:: access_group
                    
                    	Specify access control group
                    	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Filter.Ip.AccessGroup>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.Session.Filter.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "filter"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-group", ("access_group", Native.Monitor.Session.Filter.Ip.AccessGroup))])
                        self._leafs = OrderedDict()

                        self.access_group = Native.Monitor.Session.Filter.Ip.AccessGroup()
                        self.access_group.parent = self
                        self._children_name_map["access_group"] = "access-group"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.Session.Filter.Ip, [], name, value)


                    class AccessGroup(Entity):
                        """
                        Specify access control group
                        
                        .. attribute:: acl_name
                        
                        	Access\-list name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Monitor.Session.Filter.Ip.AccessGroup, self).__init__()

                            self.yang_name = "access-group"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                            ])
                            self.acl_name = None
                            self._segment_path = lambda: "access-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Monitor.Session.Filter.Ip.AccessGroup, [u'acl_name'], name, value)


            class Source(Entity):
                """
                SPAN source interface, VLAN 
                
                .. attribute:: interface
                
                	SPAN source interface
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Source.Interface>`
                
                .. attribute:: vlan
                
                	SPAN source VLAN
                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Source.Vlan>`
                
                .. attribute:: remote
                
                	SPAN source Remote
                	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Source.Remote>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Monitor.Session.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "session"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Native.Monitor.Session.Source.Interface)), ("vlan", ("vlan", Native.Monitor.Session.Source.Vlan)), ("remote", ("remote", Native.Monitor.Session.Source.Remote))])
                    self._leafs = OrderedDict()

                    self.vlan = Native.Monitor.Session.Source.Vlan()
                    self.vlan.parent = self
                    self._children_name_map["vlan"] = "vlan"

                    self.remote = Native.Monitor.Session.Source.Remote()
                    self.remote.parent = self
                    self._children_name_map["remote"] = "remote"

                    self.interface = YList(self)
                    self._segment_path = lambda: "source"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Monitor.Session.Source, [], name, value)


                class Interface(Entity):
                    """
                    SPAN source interface
                    
                    .. attribute:: name  (key)
                    
                    	Interface Name
                    	**type**\: str
                    
                    .. attribute:: direction
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Source.Interface.Direction>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.Session.Source.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Monitor.Session.Source.Interface.Direction')])),
                        ])
                        self.name = None
                        self.direction = None
                        self._segment_path = lambda: "interface" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.Session.Source.Interface, [u'name', u'direction'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: both = 0

                        .. data:: rx = 1

                        .. data:: tx = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        rx = Enum.YLeaf(1, "rx")

                        tx = Enum.YLeaf(2, "tx")



                class Vlan(Entity):
                    """
                    SPAN source VLAN
                    
                    .. attribute:: vlan
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: direction
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Source.Vlan.Direction>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.Session.Source.Vlan, self).__init__()

                        self.yang_name = "vlan"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Monitor.Session.Source.Vlan.Direction')])),
                        ])
                        self.vlan = None
                        self.direction = None
                        self._segment_path = lambda: "vlan"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.Session.Source.Vlan, [u'vlan', u'direction'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: both = 0

                        .. data:: rx = 1

                        .. data:: tx = 2

                        """

                        both = Enum.YLeaf(0, "both")

                        rx = Enum.YLeaf(1, "rx")

                        tx = Enum.YLeaf(2, "tx")



                class Remote(Entity):
                    """
                    SPAN source Remote
                    
                    .. attribute:: vlan
                    
                    	Remote SPAN source RSPAN VLAN <1\-1001>\|<1006\-4094>
                    	**type**\: int
                    
                    	**range:** 1..1001 \| 1006..4094
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.Session.Source.Remote, self).__init__()

                        self.yang_name = "remote"
                        self.yang_parent_name = "source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "remote"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.Session.Source.Remote, [u'vlan'], name, value)


            class Type(Entity):
                """
                Type of monitor session
                
                .. attribute:: erspan_source
                
                	Encapsulated RSPAN Source Session
                	**type**\:  :py:class:`ErspanSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource>`
                
                	**presence node**\: True
                
                .. attribute:: erspan_destination
                
                	Encapsulated RSPAN Destination Session
                	**type**\:  :py:class:`ErspanDestination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanDestination>`
                
                	**presence node**\: True
                
                .. attribute:: local
                
                	Local SPAN Session
                	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.Local>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Monitor.Session.Type, self).__init__()

                    self.yang_name = "type"
                    self.yang_parent_name = "session"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("erspan-source", ("erspan_source", Native.Monitor.Session.Type.ErspanSource)), ("erspan-destination", ("erspan_destination", Native.Monitor.Session.Type.ErspanDestination)), ("local", ("local", Native.Monitor.Session.Type.Local))])
                    self._leafs = OrderedDict()

                    self.erspan_source = None
                    self._children_name_map["erspan_source"] = "erspan-source"

                    self.erspan_destination = None
                    self._children_name_map["erspan_destination"] = "erspan-destination"

                    self.local = None
                    self._children_name_map["local"] = "local"
                    self._segment_path = lambda: "type"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Monitor.Session.Type, [], name, value)


                class ErspanSource(Entity):
                    """
                    Encapsulated RSPAN Source Session
                    
                    .. attribute:: description
                    
                    	Description for this session
                    	**type**\: str
                    
                    .. attribute:: source
                    
                    	SPAN source interface, VLAN 
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Source>`
                    
                    .. attribute:: filter
                    
                    	SPAN filter VLAN
                    	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Filter>`
                    
                    .. attribute:: header_type
                    
                    	ERSPAN header\-type for encapsulation. Default is type 2
                    	**type**\: int
                    
                    	**range:** 2..3
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: destination
                    
                    	Specify Destination and their properties
                    	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Destination>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.Session.Type.ErspanSource, self).__init__()

                        self.yang_name = "erspan-source"
                        self.yang_parent_name = "type"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Monitor.Session.Type.ErspanSource.Source)), ("filter", ("filter", Native.Monitor.Session.Type.ErspanSource.Filter)), ("destination", ("destination", Native.Monitor.Session.Type.ErspanSource.Destination))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('header_type', (YLeaf(YType.uint8, 'header-type'), ['int'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.description = None
                        self.header_type = None
                        self.shutdown = None

                        self.source = Native.Monitor.Session.Type.ErspanSource.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"

                        self.filter = Native.Monitor.Session.Type.ErspanSource.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"

                        self.destination = None
                        self._children_name_map["destination"] = "destination"
                        self._segment_path = lambda: "erspan-source"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.Session.Type.ErspanSource, [u'description', u'header_type', u'shutdown'], name, value)


                    class Source(Entity):
                        """
                        SPAN source interface, VLAN 
                        
                        .. attribute:: interface
                        
                        	SPAN source interface
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Source.Interface>`
                        
                        .. attribute:: vlan
                        
                        	SPAN source VLAN
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Source.Vlan>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Monitor.Session.Type.ErspanSource.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "erspan-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", Native.Monitor.Session.Type.ErspanSource.Source.Interface)), ("vlan", ("vlan", Native.Monitor.Session.Type.ErspanSource.Source.Vlan))])
                            self._leafs = OrderedDict()

                            self.interface = YList(self)
                            self.vlan = YList(self)
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Monitor.Session.Type.ErspanSource.Source, [], name, value)


                        class Interface(Entity):
                            """
                            SPAN source interface
                            
                            .. attribute:: name  (key)
                            
                            	Interface Name
                            	**type**\: str
                            
                            .. attribute:: direction
                            
                            	
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Source.Interface.Direction>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.ErspanSource.Source.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Monitor.Session.Type.ErspanSource.Source.Interface.Direction')])),
                                ])
                                self.name = None
                                self.direction = None
                                self._segment_path = lambda: "interface" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.ErspanSource.Source.Interface, [u'name', u'direction'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                .. data:: both = 0

                                .. data:: rx = 1

                                .. data:: tx = 2

                                """

                                both = Enum.YLeaf(0, "both")

                                rx = Enum.YLeaf(1, "rx")

                                tx = Enum.YLeaf(2, "tx")



                        class Vlan(Entity):
                            """
                            SPAN source VLAN
                            
                            .. attribute:: vlan1  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: direction
                            
                            	
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Source.Vlan.Direction>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.ErspanSource.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['vlan1']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlan1', (YLeaf(YType.uint16, 'vlan1'), ['int'])),
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Monitor.Session.Type.ErspanSource.Source.Vlan.Direction')])),
                                ])
                                self.vlan1 = None
                                self.direction = None
                                self._segment_path = lambda: "vlan" + "[vlan1='" + str(self.vlan1) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.ErspanSource.Source.Vlan, [u'vlan1', u'direction'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                .. data:: both = 0

                                .. data:: rx = 1

                                .. data:: tx = 2

                                """

                                both = Enum.YLeaf(0, "both")

                                rx = Enum.YLeaf(1, "rx")

                                tx = Enum.YLeaf(2, "tx")



                    class Filter(Entity):
                        """
                        SPAN filter VLAN
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Filter.Vlan>`
                        
                        .. attribute:: ip
                        
                        	Specify IP Access control rules
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Filter.Ip>`
                        
                        .. attribute:: sgt
                        
                        	SPAN source SGT
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Monitor.Session.Type.ErspanSource.Filter, self).__init__()

                            self.yang_name = "filter"
                            self.yang_parent_name = "erspan-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Monitor.Session.Type.ErspanSource.Filter.Vlan)), ("ip", ("ip", Native.Monitor.Session.Type.ErspanSource.Filter.Ip))])
                            self._leafs = OrderedDict([
                                ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                            ])
                            self.sgt = None

                            self.ip = Native.Monitor.Session.Type.ErspanSource.Filter.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"

                            self.vlan = YList(self)
                            self._segment_path = lambda: "filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Monitor.Session.Type.ErspanSource.Filter, [u'sgt'], name, value)


                        class Vlan(Entity):
                            """
                            
                            
                            .. attribute:: vlan1  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.ErspanSource.Filter.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "filter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['vlan1']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlan1', (YLeaf(YType.uint16, 'vlan1'), ['int'])),
                                ])
                                self.vlan1 = None
                                self._segment_path = lambda: "vlan" + "[vlan1='" + str(self.vlan1) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.ErspanSource.Filter.Vlan, [u'vlan1'], name, value)


                        class Ip(Entity):
                            """
                            Specify IP Access control rules
                            
                            .. attribute:: access_group
                            
                            	Specify access control group
                            	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Filter.Ip.AccessGroup>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.ErspanSource.Filter.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "filter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("access-group", ("access_group", Native.Monitor.Session.Type.ErspanSource.Filter.Ip.AccessGroup))])
                                self._leafs = OrderedDict()

                                self.access_group = Native.Monitor.Session.Type.ErspanSource.Filter.Ip.AccessGroup()
                                self.access_group.parent = self
                                self._children_name_map["access_group"] = "access-group"
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.ErspanSource.Filter.Ip, [], name, value)


                            class AccessGroup(Entity):
                                """
                                Specify access control group
                                
                                .. attribute:: acl_name
                                
                                	Access\-list name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Monitor.Session.Type.ErspanSource.Filter.Ip.AccessGroup, self).__init__()

                                    self.yang_name = "access-group"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ])
                                    self.acl_name = None
                                    self._segment_path = lambda: "access-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Monitor.Session.Type.ErspanSource.Filter.Ip.AccessGroup, [u'acl_name'], name, value)


                    class Destination(Entity):
                        """
                        Specify Destination and their properties
                        
                        .. attribute:: ip
                        
                        	IP Properties
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Destination.Ip>`
                        
                        .. attribute:: erspan_id
                        
                        	Enter ERSPAN Identifier
                        	**type**\: int
                        
                        	**range:** 1..1023
                        
                        .. attribute:: origin
                        
                        	Origin IP Properties
                        	**type**\:  :py:class:`Origin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Destination.Origin>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Monitor.Session.Type.ErspanSource.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "erspan-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Monitor.Session.Type.ErspanSource.Destination.Ip)), ("origin", ("origin", Native.Monitor.Session.Type.ErspanSource.Destination.Origin))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('erspan_id', (YLeaf(YType.uint16, 'erspan-id'), ['int'])),
                            ])
                            self.erspan_id = None

                            self.ip = Native.Monitor.Session.Type.ErspanSource.Destination.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"

                            self.origin = Native.Monitor.Session.Type.ErspanSource.Destination.Origin()
                            self.origin.parent = self
                            self._children_name_map["origin"] = "origin"
                            self._segment_path = lambda: "destination"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Monitor.Session.Type.ErspanSource.Destination, [u'erspan_id'], name, value)


                        class Ip(Entity):
                            """
                            IP Properties
                            
                            .. attribute:: address
                            
                            	Enter IP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ttl
                            
                            	IP TTL
                            	**type**\: int
                            
                            	**range:** 2..255
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.ErspanSource.Destination.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('ttl', (YLeaf(YType.uint16, 'ttl'), ['int'])),
                                ])
                                self.address = None
                                self.ttl = None
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.ErspanSource.Destination.Ip, [u'address', u'ttl'], name, value)


                        class Origin(Entity):
                            """
                            Origin IP Properties
                            
                            .. attribute:: ip
                            
                            	origin IP Properties
                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanSource.Destination.Origin.Ip>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.ErspanSource.Destination.Origin, self).__init__()

                                self.yang_name = "origin"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ip", ("ip", Native.Monitor.Session.Type.ErspanSource.Destination.Origin.Ip))])
                                self._leafs = OrderedDict()

                                self.ip = Native.Monitor.Session.Type.ErspanSource.Destination.Origin.Ip()
                                self.ip.parent = self
                                self._children_name_map["ip"] = "ip"
                                self._segment_path = lambda: "origin"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.ErspanSource.Destination.Origin, [], name, value)


                            class Ip(Entity):
                                """
                                origin IP Properties
                                
                                .. attribute:: address
                                
                                	Enter IP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Monitor.Session.Type.ErspanSource.Destination.Origin.Ip, self).__init__()

                                    self.yang_name = "ip"
                                    self.yang_parent_name = "origin"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ])
                                    self.address = None
                                    self._segment_path = lambda: "ip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Monitor.Session.Type.ErspanSource.Destination.Origin.Ip, [u'address'], name, value)


                class ErspanDestination(Entity):
                    """
                    Encapsulated RSPAN Destination Session
                    
                    .. attribute:: description
                    
                    	Properties for this session
                    	**type**\: str
                    
                    .. attribute:: destination
                    
                    	SPAN destination interface, VLAN 
                    	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanDestination.Destination>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this session
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: source
                    
                    	Specify Source and their properties
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanDestination.Source>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.Session.Type.ErspanDestination, self).__init__()

                        self.yang_name = "erspan-destination"
                        self.yang_parent_name = "type"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination", ("destination", Native.Monitor.Session.Type.ErspanDestination.Destination)), ("source", ("source", Native.Monitor.Session.Type.ErspanDestination.Source))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.description = None
                        self.shutdown = None

                        self.destination = Native.Monitor.Session.Type.ErspanDestination.Destination()
                        self.destination.parent = self
                        self._children_name_map["destination"] = "destination"

                        self.source = None
                        self._children_name_map["source"] = "source"
                        self._segment_path = lambda: "erspan-destination"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.Session.Type.ErspanDestination, [u'description', u'shutdown'], name, value)


                    class Destination(Entity):
                        """
                        SPAN destination interface, VLAN 
                        
                        .. attribute:: interface
                        
                        	SPAN destination interface
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanDestination.Destination.Interface>`
                        
                        .. attribute:: vlan
                        
                        	Remote SPAN destination RSPAN VLAN <1\-1001>\|<1006\-4094>
                        	**type**\: int
                        
                        	**range:** 1..1001 \| 1006..4094
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Monitor.Session.Type.ErspanDestination.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "erspan-destination"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", Native.Monitor.Session.Type.ErspanDestination.Destination.Interface))])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                            ])
                            self.vlan = None

                            self.interface = YList(self)
                            self._segment_path = lambda: "destination"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Monitor.Session.Type.ErspanDestination.Destination, [u'vlan'], name, value)


                        class Interface(Entity):
                            """
                            SPAN destination interface
                            
                            .. attribute:: name  (key)
                            
                            	Interface Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.ErspanDestination.Destination.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "interface" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.ErspanDestination.Destination.Interface, [u'name'], name, value)


                    class Source(Entity):
                        """
                        Specify Source and their properties
                        
                        .. attribute:: ip
                        
                        	IP Address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.ErspanDestination.Source.Ip>`
                        
                        .. attribute:: vrf
                        
                        	Enter VRF number
                        	**type**\: str
                        
                        .. attribute:: erspan_id
                        
                        	Enter ERSPAN Identifier
                        	**type**\: int
                        
                        	**range:** 1..1023
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Monitor.Session.Type.ErspanDestination.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "erspan-destination"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Monitor.Session.Type.ErspanDestination.Source.Ip))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ('erspan_id', (YLeaf(YType.uint16, 'erspan-id'), ['int'])),
                            ])
                            self.vrf = None
                            self.erspan_id = None

                            self.ip = Native.Monitor.Session.Type.ErspanDestination.Source.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Monitor.Session.Type.ErspanDestination.Source, [u'vrf', u'erspan_id'], name, value)


                        class Ip(Entity):
                            """
                            IP Address
                            
                            .. attribute:: address
                            
                            	Enter IP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.ErspanDestination.Source.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.ErspanDestination.Source.Ip, [u'address'], name, value)


                class Local(Entity):
                    """
                    Local SPAN Session
                    
                    .. attribute:: description
                    
                    	Description for this session
                    	**type**\: str
                    
                    .. attribute:: source
                    
                    	SPAN source Interface/VLAN/CPU
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.Local.Source>`
                    
                    .. attribute:: destination
                    
                    	SPAN destination interface or VLAN
                    	**type**\:  :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.Local.Destination>`
                    
                    .. attribute:: filter
                    
                    	SPAN filter VLAN
                    	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.Local.Filter>`
                    
                    .. attribute:: shutdown
                    
                    	Take the Service Instance out of Service
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Monitor.Session.Type.Local, self).__init__()

                        self.yang_name = "local"
                        self.yang_parent_name = "type"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Native.Monitor.Session.Type.Local.Source)), ("destination", ("destination", Native.Monitor.Session.Type.Local.Destination)), ("filter", ("filter", Native.Monitor.Session.Type.Local.Filter))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.description = None
                        self.shutdown = None

                        self.source = Native.Monitor.Session.Type.Local.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"

                        self.destination = Native.Monitor.Session.Type.Local.Destination()
                        self.destination.parent = self
                        self._children_name_map["destination"] = "destination"

                        self.filter = Native.Monitor.Session.Type.Local.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                        self._segment_path = lambda: "local"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Monitor.Session.Type.Local, [u'description', u'shutdown'], name, value)


                    class Source(Entity):
                        """
                        SPAN source Interface/VLAN/CPU
                        
                        .. attribute:: interface
                        
                        	SPAN source interface
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.Local.Source.Interface>`
                        
                        .. attribute:: vlan
                        
                        	SPAN source VLAN
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.Local.Source.Vlan>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Monitor.Session.Type.Local.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "local"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", Native.Monitor.Session.Type.Local.Source.Interface)), ("vlan", ("vlan", Native.Monitor.Session.Type.Local.Source.Vlan))])
                            self._leafs = OrderedDict()

                            self.interface = YList(self)
                            self.vlan = YList(self)
                            self._segment_path = lambda: "source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Monitor.Session.Type.Local.Source, [], name, value)


                        class Interface(Entity):
                            """
                            SPAN source interface
                            
                            .. attribute:: name  (key)
                            
                            	Interface Name
                            	**type**\: str
                            
                            .. attribute:: direction
                            
                            	
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.Local.Source.Interface.Direction>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.Local.Source.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Monitor.Session.Type.Local.Source.Interface.Direction')])),
                                ])
                                self.name = None
                                self.direction = None
                                self._segment_path = lambda: "interface" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.Local.Source.Interface, [u'name', u'direction'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                .. data:: both = 0

                                .. data:: rx = 1

                                .. data:: tx = 2

                                """

                                both = Enum.YLeaf(0, "both")

                                rx = Enum.YLeaf(1, "rx")

                                tx = Enum.YLeaf(2, "tx")



                        class Vlan(Entity):
                            """
                            SPAN source VLAN
                            
                            .. attribute:: vlan1  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            .. attribute:: direction
                            
                            	
                            	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.Local.Source.Vlan.Direction>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.Local.Source.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['vlan1']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlan1', (YLeaf(YType.uint16, 'vlan1'), ['int'])),
                                    ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Monitor.Session.Type.Local.Source.Vlan.Direction')])),
                                ])
                                self.vlan1 = None
                                self.direction = None
                                self._segment_path = lambda: "vlan" + "[vlan1='" + str(self.vlan1) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.Local.Source.Vlan, [u'vlan1', u'direction'], name, value)

                            class Direction(Enum):
                                """
                                Direction (Enum Class)

                                .. data:: both = 0

                                .. data:: rx = 1

                                .. data:: tx = 2

                                """

                                both = Enum.YLeaf(0, "both")

                                rx = Enum.YLeaf(1, "rx")

                                tx = Enum.YLeaf(2, "tx")



                    class Destination(Entity):
                        """
                        SPAN destination interface or VLAN
                        
                        .. attribute:: interface
                        
                        	SPAN destination interface
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.Local.Destination.Interface>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Monitor.Session.Type.Local.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "local"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", Native.Monitor.Session.Type.Local.Destination.Interface))])
                            self._leafs = OrderedDict()

                            self.interface = YList(self)
                            self._segment_path = lambda: "destination"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Monitor.Session.Type.Local.Destination, [], name, value)


                        class Interface(Entity):
                            """
                            SPAN destination interface
                            
                            .. attribute:: name  (key)
                            
                            	Interface Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.Local.Destination.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "destination"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "interface" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.Local.Destination.Interface, [u'name'], name, value)


                    class Filter(Entity):
                        """
                        SPAN filter VLAN
                        
                        .. attribute:: vlan
                        
                        	
                        	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Monitor.Session.Type.Local.Filter.Vlan>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Monitor.Session.Type.Local.Filter, self).__init__()

                            self.yang_name = "filter"
                            self.yang_parent_name = "local"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vlan", ("vlan", Native.Monitor.Session.Type.Local.Filter.Vlan))])
                            self._leafs = OrderedDict()

                            self.vlan = YList(self)
                            self._segment_path = lambda: "filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Monitor.Session.Type.Local.Filter, [], name, value)


                        class Vlan(Entity):
                            """
                            
                            
                            .. attribute:: vlan1  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Monitor.Session.Type.Local.Filter.Vlan, self).__init__()

                                self.yang_name = "vlan"
                                self.yang_parent_name = "filter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['vlan1']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vlan1', (YLeaf(YType.uint16, 'vlan1'), ['int'])),
                                ])
                                self.vlan1 = None
                                self._segment_path = lambda: "vlan" + "[vlan1='" + str(self.vlan1) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Monitor.Session.Type.Local.Filter.Vlan, [u'vlan1'], name, value)


    class TftpServer(Entity):
        """
        Provide TFTP service for netload requests
        
        .. attribute:: name  (key)
        
        	
        	**type**\: str
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.TftpServer, self).__init__()

            self.yang_name = "tftp-server"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['name']
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('name', (YLeaf(YType.str, 'name'), ['str'])),
            ])
            self.name = None
            self._segment_path = lambda: "tftp-server" + "[name='" + str(self.name) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.TftpServer, [u'name'], name, value)


    class RadiusServer(Entity):
        """
        Modify RADIUS query parameters
        
        .. attribute:: attribute
        
        	Customize selected radius attributes
        	**type**\: list of  		 :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Attribute>`
        
        .. attribute:: dead_criteria
        
        	Set the criteria used to decide when a radius server ismarked dead
        	**type**\:  :py:class:`DeadCriteria <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.DeadCriteria>`
        
        .. attribute:: deadtime
        
        	Time to stop using a server that doesn't respond
        	**type**\: int
        
        	**range:** 1..1440
        
        .. attribute:: host
        
        	Specify a RADIUS server
        	**type**\: list of  		 :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Host>`
        
        .. attribute:: key
        
        	encryption key shared with the radius servers
        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Key>`
        
        .. attribute:: retransmit
        
        	Specify the number of retries to active server
        	**type**\: int
        
        	**range:** 1..100
        
        .. attribute:: source_ports
        
        	source ports used for sending out RADIUS requests
        	**type**\:  :py:class:`SourcePorts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.SourcePorts>`
        
        .. attribute:: timeout
        
        	Time to wait for a RADIUS server to reply
        	**type**\: int
        
        	**range:** 1..1000
        
        .. attribute:: vsa
        
        	Vendor specific attribute configuration
        	**type**\:  :py:class:`Vsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Vsa>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.RadiusServer, self).__init__()

            self.yang_name = "radius-server"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-aaa:attribute", ("attribute", Native.RadiusServer.Attribute)), ("Cisco-IOS-XE-aaa:dead-criteria", ("dead_criteria", Native.RadiusServer.DeadCriteria)), ("Cisco-IOS-XE-aaa:host", ("host", Native.RadiusServer.Host)), ("Cisco-IOS-XE-aaa:key", ("key", Native.RadiusServer.Key)), ("Cisco-IOS-XE-aaa:source-ports", ("source_ports", Native.RadiusServer.SourcePorts)), ("Cisco-IOS-XE-aaa:vsa", ("vsa", Native.RadiusServer.Vsa))])
            self._leafs = OrderedDict([
                ('deadtime', (YLeaf(YType.uint32, 'Cisco-IOS-XE-aaa:deadtime'), ['int'])),
                ('retransmit', (YLeaf(YType.uint8, 'Cisco-IOS-XE-aaa:retransmit'), ['int'])),
                ('timeout', (YLeaf(YType.uint16, 'Cisco-IOS-XE-aaa:timeout'), ['int'])),
            ])
            self.deadtime = None
            self.retransmit = None
            self.timeout = None

            self.dead_criteria = Native.RadiusServer.DeadCriteria()
            self.dead_criteria.parent = self
            self._children_name_map["dead_criteria"] = "Cisco-IOS-XE-aaa:dead-criteria"

            self.key = Native.RadiusServer.Key()
            self.key.parent = self
            self._children_name_map["key"] = "Cisco-IOS-XE-aaa:key"

            self.source_ports = Native.RadiusServer.SourcePorts()
            self.source_ports.parent = self
            self._children_name_map["source_ports"] = "Cisco-IOS-XE-aaa:source-ports"

            self.vsa = Native.RadiusServer.Vsa()
            self.vsa.parent = self
            self._children_name_map["vsa"] = "Cisco-IOS-XE-aaa:vsa"

            self.attribute = YList(self)
            self.host = YList(self)
            self._segment_path = lambda: "radius-server"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.RadiusServer, ['deadtime', 'retransmit', 'timeout'], name, value)


        class Attribute(Entity):
            """
            Customize selected radius attributes
            
            .. attribute:: number  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: send_attribute
            
            	
            	**type**\: list of   :py:class:`SendAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Attribute.SendAttribute>`
            
            .. attribute:: access_request
            
            	Access\-Request packet
            	**type**\:  :py:class:`AccessRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Attribute.AccessRequest>`
            
            .. attribute:: attri31
            
            	Calling Station ID
            	**type**\:  :py:class:`Attri31 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Attribute.Attri31>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.RadiusServer.Attribute, self).__init__()

                self.yang_name = "attribute"
                self.yang_parent_name = "radius-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['number']
                self._child_classes = OrderedDict([("access-request", ("access_request", Native.RadiusServer.Attribute.AccessRequest)), ("attri31", ("attri31", Native.RadiusServer.Attribute.Attri31))])
                self._leafs = OrderedDict([
                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                    ('send_attribute', (YLeafList(YType.enumeration, 'send-attribute'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RadiusServer.Attribute.SendAttribute')])),
                ])
                self.number = None
                self.send_attribute = []

                self.access_request = Native.RadiusServer.Attribute.AccessRequest()
                self.access_request.parent = self
                self._children_name_map["access_request"] = "access-request"

                self.attri31 = Native.RadiusServer.Attribute.Attri31()
                self.attri31.parent = self
                self._children_name_map["attri31"] = "attri31"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:attribute" + "[number='" + str(self.number) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.RadiusServer.Attribute, ['number', 'send_attribute'], name, value)

            class SendAttribute(Enum):
                """
                SendAttribute (Enum Class)

                .. data:: on_for_login_auth = 0

                .. data:: include_in_access_req = 1

                .. data:: support_multiple = 2

                """

                on_for_login_auth = Enum.YLeaf(0, "on-for-login-auth")

                include_in_access_req = Enum.YLeaf(1, "include-in-access-req")

                support_multiple = Enum.YLeaf(2, "support-multiple")



            class AccessRequest(Entity):
                """
                Access\-Request packet
                
                .. attribute:: include
                
                	Include attribute
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.RadiusServer.Attribute.AccessRequest, self).__init__()

                    self.yang_name = "access-request"
                    self.yang_parent_name = "attribute"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('include', (YLeaf(YType.empty, 'include'), ['Empty'])),
                    ])
                    self.include = None
                    self._segment_path = lambda: "access-request"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.RadiusServer.Attribute.AccessRequest, ['include'], name, value)


            class Attri31(Entity):
                """
                Calling Station ID
                
                .. attribute:: attri31_list
                
                	
                	**type**\: list of  		 :py:class:`Attri31List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Attribute.Attri31.Attri31List>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.RadiusServer.Attribute.Attri31, self).__init__()

                    self.yang_name = "attri31"
                    self.yang_parent_name = "attribute"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("attri31-list", ("attri31_list", Native.RadiusServer.Attribute.Attri31.Attri31List))])
                    self._leafs = OrderedDict()

                    self.attri31_list = YList(self)
                    self._segment_path = lambda: "attri31"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.RadiusServer.Attribute.Attri31, [], name, value)


                class Attri31List(Entity):
                    """
                    
                    
                    .. attribute:: calling_station_id  (key)
                    
                    	
                    	**type**\:  :py:class:`CallingStationId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Attribute.Attri31.Attri31List.CallingStationId>`
                    
                    .. attribute:: id_mac
                    
                    	
                    	**type**\:  :py:class:`IdMac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Attribute.Attri31.Attri31List.IdMac>`
                    
                    .. attribute:: id_send
                    
                    	
                    	**type**\:  :py:class:`IdSend <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Attribute.Attri31.Attri31List.IdSend>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.RadiusServer.Attribute.Attri31.Attri31List, self).__init__()

                        self.yang_name = "attri31-list"
                        self.yang_parent_name = "attri31"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['calling_station_id']
                        self._child_classes = OrderedDict([("id-mac", ("id_mac", Native.RadiusServer.Attribute.Attri31.Attri31List.IdMac)), ("id-send", ("id_send", Native.RadiusServer.Attribute.Attri31.Attri31List.IdSend))])
                        self._leafs = OrderedDict([
                            ('calling_station_id', (YLeaf(YType.enumeration, 'calling-station-id'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RadiusServer.Attribute.Attri31.Attri31List.CallingStationId')])),
                        ])
                        self.calling_station_id = None

                        self.id_mac = Native.RadiusServer.Attribute.Attri31.Attri31List.IdMac()
                        self.id_mac.parent = self
                        self._children_name_map["id_mac"] = "id-mac"

                        self.id_send = Native.RadiusServer.Attribute.Attri31.Attri31List.IdSend()
                        self.id_send.parent = self
                        self._children_name_map["id_send"] = "id-send"
                        self._segment_path = lambda: "attri31-list" + "[calling-station-id='" + str(self.calling_station_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RadiusServer.Attribute.Attri31.Attri31List, ['calling_station_id'], name, value)

                    class CallingStationId(Enum):
                        """
                        CallingStationId (Enum Class)

                        .. data:: mac = 0

                        .. data:: send = 1

                        """

                        mac = Enum.YLeaf(0, "mac")

                        send = Enum.YLeaf(1, "send")



                    class IdMac(Entity):
                        """
                        
                        
                        .. attribute:: format
                        
                        	
                        	**type**\:  :py:class:`Format <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Attribute.Attri31.Attri31List.IdMac.Format>`
                        
                        .. attribute:: lu_case
                        
                        	
                        	**type**\:  :py:class:`LuCase <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Attribute.Attri31.Attri31List.IdMac.LuCase>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.RadiusServer.Attribute.Attri31.Attri31List.IdMac, self).__init__()

                            self.yang_name = "id-mac"
                            self.yang_parent_name = "attri31-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('format', (YLeaf(YType.enumeration, 'format'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RadiusServer.Attribute.Attri31.Attri31List.IdMac.Format')])),
                                ('lu_case', (YLeaf(YType.enumeration, 'lu-case'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RadiusServer.Attribute.Attri31.Attri31List.IdMac.LuCase')])),
                            ])
                            self.format = None
                            self.lu_case = None
                            self._segment_path = lambda: "id-mac"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RadiusServer.Attribute.Attri31.Attri31List.IdMac, ['format', 'lu_case'], name, value)

                        class Format(Enum):
                            """
                            Format (Enum Class)

                            .. data:: ietf = 0

                            """

                            ietf = Enum.YLeaf(0, "ietf")


                        class LuCase(Enum):
                            """
                            LuCase (Enum Class)

                            .. data:: lower_case = 0

                            .. data:: upper_case = 1

                            """

                            lower_case = Enum.YLeaf(0, "lower-case")

                            upper_case = Enum.YLeaf(1, "upper-case")



                    class IdSend(Entity):
                        """
                        
                        
                        .. attribute:: nas_port_detail
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mac_only
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.RadiusServer.Attribute.Attri31.Attri31List.IdSend, self).__init__()

                            self.yang_name = "id-send"
                            self.yang_parent_name = "attri31-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('nas_port_detail', (YLeaf(YType.empty, 'nas-port-detail'), ['Empty'])),
                                ('mac_only', (YLeaf(YType.empty, 'mac-only'), ['Empty'])),
                            ])
                            self.nas_port_detail = None
                            self.mac_only = None
                            self._segment_path = lambda: "id-send"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RadiusServer.Attribute.Attri31.Attri31List.IdSend, ['nas_port_detail', 'mac_only'], name, value)


        class DeadCriteria(Entity):
            """
            Set the criteria used to decide when a radius server ismarked dead
            
            .. attribute:: time
            
            	The time during which no properly formed response must be recievedfrom the RADIUS server
            	**type**\: int
            
            	**range:** 1..120
            
            .. attribute:: tries
            
            	The number of times the router must fail to recieve a response fromthe radius server to mark it as dead
            	**type**\: int
            
            	**range:** 1..100
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.RadiusServer.DeadCriteria, self).__init__()

                self.yang_name = "dead-criteria"
                self.yang_parent_name = "radius-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('time', (YLeaf(YType.uint8, 'time'), ['int'])),
                    ('tries', (YLeaf(YType.uint8, 'tries'), ['int'])),
                ])
                self.time = None
                self.tries = None
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:dead-criteria"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.RadiusServer.DeadCriteria, ['time', 'tries'], name, value)


        class Host(Entity):
            """
            Specify a RADIUS server
            
            .. attribute:: id  (key)
            
            	
            	**type**\: union of the below types:
            
            		**type**\: str
            
            		**type**\: str
            
            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: auth_port
            
            	UDP port for RADIUS authentication server (default is 1645)
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: acct_port
            
            	UDP port for RADIUS accounting server (default is 1646)
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: retransmit
            
            	Specify the number of retries to active server
            	**type**\: int
            
            	**range:** 1..100
            
            .. attribute:: test
            
            	Configure server automated testing
            	**type**\:  :py:class:`Test <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Host.Test>`
            
            .. attribute:: timeout
            
            	Time to wait for a RADIUS server to reply (overrides default)
            	**type**\: int
            
            	**range:** 1..1000
            
            .. attribute:: key
            
            	per\-server encryption key (overrides default)
            	**type**\: union of the below types:
            
            		**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Host.Key>`
            
            		**type**\: str
            
            .. attribute:: clear_key
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.RadiusServer.Host, self).__init__()

                self.yang_name = "host"
                self.yang_parent_name = "radius-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("test", ("test", Native.RadiusServer.Host.Test))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                    ('auth_port', (YLeaf(YType.uint16, 'auth-port'), ['int'])),
                    ('acct_port', (YLeaf(YType.uint16, 'acct-port'), ['int'])),
                    ('retransmit', (YLeaf(YType.uint8, 'retransmit'), ['int'])),
                    ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                    ('key', (YLeaf(YType.str, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RadiusServer.Host.Key'),'str'])),
                    ('clear_key', (YLeaf(YType.str, 'clear-key'), ['str'])),
                ])
                self.id = None
                self.auth_port = None
                self.acct_port = None
                self.retransmit = None
                self.timeout = None
                self.key = None
                self.clear_key = None

                self.test = Native.RadiusServer.Host.Test()
                self.test.parent = self
                self._children_name_map["test"] = "test"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:host" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.RadiusServer.Host, ['id', 'auth_port', 'acct_port', 'retransmit', 'timeout', 'key', 'clear_key'], name, value)

            class Key(Enum):
                """
                Key (Enum Class)

                per\-server encryption key (overrides default)

                .. data:: Y_0 = 0

                .. data:: Y_7 = 1

                """

                Y_0 = Enum.YLeaf(0, "0")

                Y_7 = Enum.YLeaf(1, "7")



            class Test(Entity):
                """
                Configure server automated testing
                
                .. attribute:: username
                
                	A name (from local database) that should be used to send requests
                	**type**\: list of  		 :py:class:`Username <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Host.Test.Username>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.RadiusServer.Host.Test, self).__init__()

                    self.yang_name = "test"
                    self.yang_parent_name = "host"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("username", ("username", Native.RadiusServer.Host.Test.Username))])
                    self._leafs = OrderedDict()

                    self.username = YList(self)
                    self._segment_path = lambda: "test"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.RadiusServer.Host.Test, [], name, value)


                class Username(Entity):
                    """
                    A name (from local database) that should be used to send requests.
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: key
                    
                    	per\-server encryption key (overrides default)
                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Host.Test.Username.Key>`
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.RadiusServer.Host.Test.Username, self).__init__()

                        self.yang_name = "username"
                        self.yang_parent_name = "test"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("key", ("key", Native.RadiusServer.Host.Test.Username.Key))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.key = Native.RadiusServer.Host.Test.Username.Key()
                        self.key.parent = self
                        self._children_name_map["key"] = "key"
                        self._segment_path = lambda: "username" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RadiusServer.Host.Test.Username, ['name'], name, value)


                    class Key(Entity):
                        """
                        per\-server encryption key (overrides default)
                        
                        .. attribute:: encryption
                        
                        	
                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Host.Test.Username.Key.Encryption>`
                        
                        .. attribute:: clear_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-aaa'
                        _revision = '2018-01-15'

                        def __init__(self):
                            super(Native.RadiusServer.Host.Test.Username.Key, self).__init__()

                            self.yang_name = "key"
                            self.yang_parent_name = "username"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RadiusServer.Host.Test.Username.Key.Encryption')])),
                                ('clear_key', (YLeaf(YType.str, 'clear-key'), ['str'])),
                            ])
                            self.encryption = None
                            self.clear_key = None
                            self._segment_path = lambda: "key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.RadiusServer.Host.Test.Username.Key, ['encryption', 'clear_key'], name, value)

                        class Encryption(Enum):
                            """
                            Encryption (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: Y_7 = 1

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_7 = Enum.YLeaf(1, "7")



        class Key(Entity):
            """
            encryption key shared with the radius servers
            
            .. attribute:: encryption
            
            	
            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Key.Encryption>`
            
            .. attribute:: clear_key
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.RadiusServer.Key, self).__init__()

                self.yang_name = "key"
                self.yang_parent_name = "radius-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'RadiusServer.Key.Encryption')])),
                    ('clear_key', (YLeaf(YType.str, 'clear-key'), ['str'])),
                ])
                self.encryption = None
                self.clear_key = None
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:key"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.RadiusServer.Key, ['encryption', 'clear_key'], name, value)

            class Encryption(Enum):
                """
                Encryption (Enum Class)

                .. data:: Y_0 = 0

                .. data:: Y_7 = 1

                """

                Y_0 = Enum.YLeaf(0, "0")

                Y_7 = Enum.YLeaf(1, "7")



        class SourcePorts(Entity):
            """
            source ports used for sending out RADIUS requests
            
            .. attribute:: extended
            
            	Use 200 source\-ports between 21645\-21844
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.RadiusServer.SourcePorts, self).__init__()

                self.yang_name = "source-ports"
                self.yang_parent_name = "radius-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('extended', (YLeaf(YType.empty, 'extended'), ['Empty'])),
                ])
                self.extended = None
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:source-ports"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.RadiusServer.SourcePorts, ['extended'], name, value)


        class Vsa(Entity):
            """
            Vendor specific attribute configuration
            
            .. attribute:: disallow
            
            	Forbid certain VSA behaviour
            	**type**\:  :py:class:`Disallow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Vsa.Disallow>`
            
            .. attribute:: send
            
            	Send vendor\-specific attributes in requests
            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Vsa.Send>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.RadiusServer.Vsa, self).__init__()

                self.yang_name = "vsa"
                self.yang_parent_name = "radius-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("disallow", ("disallow", Native.RadiusServer.Vsa.Disallow)), ("send", ("send", Native.RadiusServer.Vsa.Send))])
                self._leafs = OrderedDict()

                self.disallow = Native.RadiusServer.Vsa.Disallow()
                self.disallow.parent = self
                self._children_name_map["disallow"] = "disallow"

                self.send = None
                self._children_name_map["send"] = "send"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:vsa"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.RadiusServer.Vsa, [], name, value)


            class Disallow(Entity):
                """
                Forbid certain VSA behaviour
                
                .. attribute:: unknown
                
                	Forbid unknown VSAs
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.RadiusServer.Vsa.Disallow, self).__init__()

                    self.yang_name = "disallow"
                    self.yang_parent_name = "vsa"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('unknown', (YLeaf(YType.empty, 'unknown'), ['Empty'])),
                    ])
                    self.unknown = None
                    self._segment_path = lambda: "disallow"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius-server/Cisco-IOS-XE-aaa:vsa/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.RadiusServer.Vsa.Disallow, ['unknown'], name, value)


            class Send(Entity):
                """
                Send vendor\-specific attributes in requests
                
                .. attribute:: accounting
                
                	Send in accounting requests
                	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Vsa.Send.Accounting>`
                
                	**presence node**\: True
                
                .. attribute:: authentication
                
                	Send in access requests
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Vsa.Send.Authentication>`
                
                	**presence node**\: True
                
                .. attribute:: cisco_nas_port
                
                	Send cisco\-nas\-port VSA(2)
                	**type**\:  :py:class:`CiscoNasPort <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.RadiusServer.Vsa.Send.CiscoNasPort>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.RadiusServer.Vsa.Send, self).__init__()

                    self.yang_name = "send"
                    self.yang_parent_name = "vsa"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("accounting", ("accounting", Native.RadiusServer.Vsa.Send.Accounting)), ("authentication", ("authentication", Native.RadiusServer.Vsa.Send.Authentication)), ("cisco-nas-port", ("cisco_nas_port", Native.RadiusServer.Vsa.Send.CiscoNasPort))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.accounting = None
                    self._children_name_map["accounting"] = "accounting"

                    self.authentication = None
                    self._children_name_map["authentication"] = "authentication"

                    self.cisco_nas_port = None
                    self._children_name_map["cisco_nas_port"] = "cisco-nas-port"
                    self._segment_path = lambda: "send"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius-server/Cisco-IOS-XE-aaa:vsa/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.RadiusServer.Vsa.Send, [], name, value)


                class Accounting(Entity):
                    """
                    Send in accounting requests
                    
                    .. attribute:: threegpp2
                    
                    	Send 3GPP2 VSAs in accounting requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.RadiusServer.Vsa.Send.Accounting, self).__init__()

                        self.yang_name = "accounting"
                        self.yang_parent_name = "send"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('threegpp2', (YLeaf(YType.empty, 'threegpp2'), ['Empty'])),
                        ])
                        self.threegpp2 = None
                        self._segment_path = lambda: "accounting"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius-server/Cisco-IOS-XE-aaa:vsa/send/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RadiusServer.Vsa.Send.Accounting, ['threegpp2'], name, value)


                class Authentication(Entity):
                    """
                    Send in access requests
                    
                    .. attribute:: threegpp2
                    
                    	Send 3GPP2 VSAs in accounting requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.RadiusServer.Vsa.Send.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "send"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('threegpp2', (YLeaf(YType.empty, 'threegpp2'), ['Empty'])),
                        ])
                        self.threegpp2 = None
                        self._segment_path = lambda: "authentication"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius-server/Cisco-IOS-XE-aaa:vsa/send/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RadiusServer.Vsa.Send.Authentication, ['threegpp2'], name, value)


                class CiscoNasPort(Entity):
                    """
                    Send cisco\-nas\-port VSA(2)
                    
                    .. attribute:: threegpp2
                    
                    	Send 3GPP2 VSAs in accounting requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.RadiusServer.Vsa.Send.CiscoNasPort, self).__init__()

                        self.yang_name = "cisco-nas-port"
                        self.yang_parent_name = "send"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('threegpp2', (YLeaf(YType.empty, 'threegpp2'), ['Empty'])),
                        ])
                        self.threegpp2 = None
                        self._segment_path = lambda: "cisco-nas-port"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius-server/Cisco-IOS-XE-aaa:vsa/send/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.RadiusServer.Vsa.Send.CiscoNasPort, ['threegpp2'], name, value)


    class Radius(Entity):
        """
        RADIUS server configuration command
        
        .. attribute:: filter
        
        	Packet filter configuration
        	**type**\: list of  		 :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Filter>`
        
        .. attribute:: server
        
        	Server configuration
        	**type**\: list of  		 :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Radius, self).__init__()

            self.yang_name = "radius"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-aaa:filter", ("filter", Native.Radius.Filter)), ("Cisco-IOS-XE-aaa:server", ("server", Native.Radius.Server))])
            self._leafs = OrderedDict()

            self.filter = YList(self)
            self.server = YList(self)
            self._segment_path = lambda: "radius"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Radius, [], name, value)


        class Filter(Entity):
            """
            Packet filter configuration
            
            .. attribute:: id  (key)
            
            	
            	**type**\: str
            
            .. attribute:: match
            
            	
            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Filter.Match>`
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Radius.Filter, self).__init__()

                self.yang_name = "filter"
                self.yang_parent_name = "radius"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                    ('match', (YLeaf(YType.enumeration, 'match'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Radius.Filter.Match')])),
                ])
                self.id = None
                self.match = None
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:filter" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Radius.Filter, ['id', 'match'], name, value)

            class Match(Enum):
                """
                Match (Enum Class)

                .. data:: match_all = 0

                .. data:: match_any = 1

                """

                match_all = Enum.YLeaf(0, "match-all")

                match_any = Enum.YLeaf(1, "match-any")



        class Server(Entity):
            """
            Server configuration
            
            .. attribute:: id  (key)
            
            	
            	**type**\: str
            
            .. attribute:: address
            
            	Specify the radius server address
            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server.Address>`
            
            .. attribute:: timeout
            
            	Time to wait for a RADIUS server to reply (overrides default)
            	**type**\: int
            
            	**range:** 1..1000
            
            .. attribute:: automate_tester
            
            	Configure server automated testing
            	**type**\:  :py:class:`AutomateTester <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server.AutomateTester>`
            
            .. attribute:: backoff
            
            	Retry backoff pattern(Default is retransmits with constant delay)
            	**type**\:  :py:class:`Backoff <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server.Backoff>`
            
            .. attribute:: key
            
            	Per\-server encryption key
            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server.Key>`
            
            .. attribute:: pac
            
            	Protected Access Credential key
            	**type**\:  :py:class:`Pac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server.Pac>`
            
            .. attribute:: retransmit
            
            	Number of retries to active server (overrides default)
            	**type**\: int
            
            	**range:** 0..100
            
            

            """

            _prefix = 'ios-aaa'
            _revision = '2018-01-15'

            def __init__(self):
                super(Native.Radius.Server, self).__init__()

                self.yang_name = "server"
                self.yang_parent_name = "radius"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("address", ("address", Native.Radius.Server.Address)), ("automate-tester", ("automate_tester", Native.Radius.Server.AutomateTester)), ("backoff", ("backoff", Native.Radius.Server.Backoff)), ("key", ("key", Native.Radius.Server.Key)), ("pac", ("pac", Native.Radius.Server.Pac))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                    ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                    ('retransmit', (YLeaf(YType.uint8, 'retransmit'), ['int'])),
                ])
                self.id = None
                self.timeout = None
                self.retransmit = None

                self.address = Native.Radius.Server.Address()
                self.address.parent = self
                self._children_name_map["address"] = "address"

                self.automate_tester = Native.Radius.Server.AutomateTester()
                self.automate_tester.parent = self
                self._children_name_map["automate_tester"] = "automate-tester"

                self.backoff = Native.Radius.Server.Backoff()
                self.backoff.parent = self
                self._children_name_map["backoff"] = "backoff"

                self.key = Native.Radius.Server.Key()
                self.key.parent = self
                self._children_name_map["key"] = "key"

                self.pac = Native.Radius.Server.Pac()
                self.pac.parent = self
                self._children_name_map["pac"] = "pac"
                self._segment_path = lambda: "Cisco-IOS-XE-aaa:server" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/radius/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Radius.Server, ['id', 'timeout', 'retransmit'], name, value)


            class Address(Entity):
                """
                Specify the radius server address
                
                .. attribute:: ipv4
                
                	IPv4 Address
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server.Address.Ipv4>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Radius.Server.Address, self).__init__()

                    self.yang_name = "address"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Radius.Server.Address.Ipv4))])
                    self._leafs = OrderedDict()

                    self.ipv4 = Native.Radius.Server.Address.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._segment_path = lambda: "address"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Radius.Server.Address, [], name, value)


                class Ipv4(Entity):
                    """
                    IPv4 Address
                    
                    .. attribute:: host
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: auth_port
                    
                    	UDP port for RADIUS authentication server (default is 1645)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: acct_port
                    
                    	UDP port for RADIUS accounting server (default is 1646)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Radius.Server.Address.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('host', (YLeaf(YType.str, 'host'), ['str'])),
                            ('auth_port', (YLeaf(YType.uint16, 'auth-port'), ['int'])),
                            ('acct_port', (YLeaf(YType.uint16, 'acct-port'), ['int'])),
                        ])
                        self.host = None
                        self.auth_port = None
                        self.acct_port = None
                        self._segment_path = lambda: "ipv4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Radius.Server.Address.Ipv4, ['host', 'auth_port', 'acct_port'], name, value)


            class AutomateTester(Entity):
                """
                Configure server automated testing.
                
                .. attribute:: username
                
                	
                	**type**\: str
                
                .. attribute:: at_option
                
                	
                	**type**\:  :py:class:`AtOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server.AutomateTester.AtOption>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Radius.Server.AutomateTester, self).__init__()

                    self.yang_name = "automate-tester"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('username', (YLeaf(YType.str, 'username'), ['str'])),
                        ('at_option', (YLeaf(YType.enumeration, 'at-option'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Radius.Server.AutomateTester.AtOption')])),
                    ])
                    self.username = None
                    self.at_option = None
                    self._segment_path = lambda: "automate-tester"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Radius.Server.AutomateTester, ['username', 'at_option'], name, value)

                class AtOption(Enum):
                    """
                    AtOption (Enum Class)

                    .. data:: probe_on = 0

                    """

                    probe_on = Enum.YLeaf(0, "probe-on")



            class Backoff(Entity):
                """
                Retry backoff pattern(Default is retransmits with constant delay)
                
                .. attribute:: exponential
                
                	Exponential retransmit backoff
                	**type**\:  :py:class:`Exponential <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server.Backoff.Exponential>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Radius.Server.Backoff, self).__init__()

                    self.yang_name = "backoff"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("exponential", ("exponential", Native.Radius.Server.Backoff.Exponential))])
                    self._leafs = OrderedDict()

                    self.exponential = None
                    self._children_name_map["exponential"] = "exponential"
                    self._segment_path = lambda: "backoff"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Radius.Server.Backoff, [], name, value)


                class Exponential(Entity):
                    """
                    Exponential retransmit backoff
                    
                    .. attribute:: max_delay
                    
                    	Max delay between retransmits(default is 3 min)
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    .. attribute:: backoff_retry
                    
                    	Exponential backoff retry number(default is 8)
                    	**type**\: int
                    
                    	**range:** 1..50
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Radius.Server.Backoff.Exponential, self).__init__()

                        self.yang_name = "exponential"
                        self.yang_parent_name = "backoff"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_delay', (YLeaf(YType.uint8, 'max-delay'), ['int'])),
                            ('backoff_retry', (YLeaf(YType.uint8, 'backoff-retry'), ['int'])),
                        ])
                        self.max_delay = None
                        self.backoff_retry = None
                        self._segment_path = lambda: "exponential"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Radius.Server.Backoff.Exponential, ['max_delay', 'backoff_retry'], name, value)


            class Key(Entity):
                """
                Per\-server encryption key
                
                .. attribute:: encryption
                
                	
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server.Key.Encryption>`
                
                .. attribute:: key
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Radius.Server.Key, self).__init__()

                    self.yang_name = "key"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Radius.Server.Key.Encryption')])),
                        ('key', (YLeaf(YType.str, 'key'), ['str'])),
                    ])
                    self.encryption = None
                    self.key = None
                    self._segment_path = lambda: "key"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Radius.Server.Key, ['encryption', 'key'], name, value)

                class Encryption(Enum):
                    """
                    Encryption (Enum Class)

                    .. data:: Y_0 = 0

                    .. data:: Y_5 = 1

                    """

                    Y_0 = Enum.YLeaf(0, "0")

                    Y_5 = Enum.YLeaf(1, "5")



            class Pac(Entity):
                """
                Protected Access Credential key
                
                .. attribute:: key
                
                	Per\-server encryption key
                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server.Pac.Key>`
                
                

                """

                _prefix = 'ios-aaa'
                _revision = '2018-01-15'

                def __init__(self):
                    super(Native.Radius.Server.Pac, self).__init__()

                    self.yang_name = "pac"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("key", ("key", Native.Radius.Server.Pac.Key))])
                    self._leafs = OrderedDict()

                    self.key = Native.Radius.Server.Pac.Key()
                    self.key.parent = self
                    self._children_name_map["key"] = "key"
                    self._segment_path = lambda: "pac"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Radius.Server.Pac, [], name, value)


                class Key(Entity):
                    """
                    Per\-server encryption key
                    
                    .. attribute:: encryption
                    
                    	
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Radius.Server.Pac.Key.Encryption>`
                    
                    .. attribute:: key
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-aaa'
                    _revision = '2018-01-15'

                    def __init__(self):
                        super(Native.Radius.Server.Pac.Key, self).__init__()

                        self.yang_name = "key"
                        self.yang_parent_name = "pac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Radius.Server.Pac.Key.Encryption')])),
                            ('key', (YLeaf(YType.str, 'key'), ['str'])),
                        ])
                        self.encryption = None
                        self.key = None
                        self._segment_path = lambda: "key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Radius.Server.Pac.Key, ['encryption', 'key'], name, value)

                    class Encryption(Enum):
                        """
                        Encryption (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_6 = 1

                        .. data:: Y_7 = 2

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_6 = Enum.YLeaf(1, "6")

                        Y_7 = Enum.YLeaf(2, "7")



    class Zone(Entity):
        """
        FW with zoning
        
        .. attribute:: security
        
        	Security zone
        	**type**\: list of  		 :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Zone.Security>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Zone, self).__init__()

            self.yang_name = "zone"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-zone:security", ("security", Native.Zone.Security))])
            self._leafs = OrderedDict()

            self.security = YList(self)
            self._segment_path = lambda: "zone"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Zone, [], name, value)


        class Security(Entity):
            """
            Security zone
            
            .. attribute:: id  (key)
            
            	
            	**type**\: str
            
            	**length:** 1..64
            
            .. attribute:: description
            
            	Zone description
            	**type**\: str
            
            	**length:** 1..200
            
            .. attribute:: protection
            
            	config sync cookie protection against sync flood
            	**type**\: str
            
            	**length:** 1..256
            
            

            """

            _prefix = 'ios-zone'
            _revision = '2018-06-12'

            def __init__(self):
                super(Native.Zone.Security, self).__init__()

                self.yang_name = "security"
                self.yang_parent_name = "zone"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('protection', (YLeaf(YType.str, 'protection'), ['str'])),
                ])
                self.id = None
                self.description = None
                self.protection = None
                self._segment_path = lambda: "Cisco-IOS-XE-zone:security" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/zone/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Zone.Security, ['id', 'description', 'protection'], name, value)


    class ZonePair(Entity):
        """
        Zone pair command
        
        .. attribute:: security
        
        	Zone\-pair name
        	**type**\: list of  		 :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ZonePair.Security>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.ZonePair, self).__init__()

            self.yang_name = "zone-pair"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-zone:security", ("security", Native.ZonePair.Security))])
            self._leafs = OrderedDict()

            self.security = YList(self)
            self._segment_path = lambda: "zone-pair"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.ZonePair, [], name, value)


        class Security(Entity):
            """
            Zone\-pair name
            
            .. attribute:: id  (key)
            
            	
            	**type**\: str
            
            	**length:** 1..128
            
            .. attribute:: source
            
            	Source zone
            	**type**\: str
            
            	**length:** 1..64
            
            .. attribute:: destination
            
            	Destination zone
            	**type**\: str
            
            	**length:** 1..64
            
            .. attribute:: description
            
            	Zone description
            	**type**\: str
            
            	**length:** 1..200
            
            .. attribute:: service_policy
            
            	Configure Zone Pair Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ZonePair.Security.ServicePolicy>`
            
            

            """

            _prefix = 'ios-zone'
            _revision = '2018-06-12'

            def __init__(self):
                super(Native.ZonePair.Security, self).__init__()

                self.yang_name = "security"
                self.yang_parent_name = "zone-pair"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.ZonePair.Security.ServicePolicy))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                    ('source', (YLeaf(YType.str, 'source'), ['str'])),
                    ('destination', (YLeaf(YType.str, 'destination'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                ])
                self.id = None
                self.source = None
                self.destination = None
                self.description = None

                self.service_policy = Native.ZonePair.Security.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"
                self._segment_path = lambda: "Cisco-IOS-XE-zone:security" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/zone-pair/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ZonePair.Security, ['id', 'source', 'destination', 'description'], name, value)


            class ServicePolicy(Entity):
                """
                Configure Zone Pair Service Policy
                
                .. attribute:: type
                
                	Service Policy type
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ZonePair.Security.ServicePolicy.Type>`
                
                

                """

                _prefix = 'ios-zone'
                _revision = '2018-06-12'

                def __init__(self):
                    super(Native.ZonePair.Security.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "security"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.ZonePair.Security.ServicePolicy.Type))])
                    self._leafs = OrderedDict()

                    self.type = Native.ZonePair.Security.ServicePolicy.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ZonePair.Security.ServicePolicy, [], name, value)


                class Type(Entity):
                    """
                    Service Policy type
                    
                    .. attribute:: inspect
                    
                    	Configure Zone Pair Service Policy type inspect
                    	**type**\: str
                    
                    	**length:** 1..512
                    
                    

                    """

                    _prefix = 'ios-zone'
                    _revision = '2018-06-12'

                    def __init__(self):
                        super(Native.ZonePair.Security.ServicePolicy.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inspect', (YLeaf(YType.str, 'inspect'), ['str'])),
                        ])
                        self.inspect = None
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ZonePair.Security.ServicePolicy.Type, ['inspect'], name, value)


    class AlarmContact(Entity):
        """
        
        
        .. attribute:: name  (key)
        
        	
        	**type**\: int
        
        	**range:** 1..4
        
        .. attribute:: description
        
        	
        	**type**\: str
        
        	**length:** 1..80
        
        .. attribute:: severity
        
        	
        	**type**\:  :py:class:`Severity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.AlarmContact.Severity>`
        
        .. attribute:: trigger
        
        	
        	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.AlarmContact.Trigger>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.AlarmContact, self).__init__()

            self.yang_name = "alarm-contact"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['name']
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('name', (YLeaf(YType.uint8, 'name'), ['int'])),
                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                ('severity', (YLeaf(YType.enumeration, 'severity'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'AlarmContact.Severity')])),
                ('trigger', (YLeaf(YType.enumeration, 'trigger'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'AlarmContact.Trigger')])),
            ])
            self.name = None
            self.description = None
            self.severity = None
            self.trigger = None
            self._segment_path = lambda: "alarm-contact" + "[name='" + str(self.name) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.AlarmContact, [u'name', u'description', u'severity', u'trigger'], name, value)

        class Severity(Enum):
            """
            Severity (Enum Class)

            .. data:: critical = 0

            .. data:: major = 1

            .. data:: minor = 2

            """

            critical = Enum.YLeaf(0, "critical")

            major = Enum.YLeaf(1, "major")

            minor = Enum.YLeaf(2, "minor")


        class Trigger(Enum):
            """
            Trigger (Enum Class)

            .. data:: open = 0

            .. data:: closed = 1

            """

            open = Enum.YLeaf(0, "open")

            closed = Enum.YLeaf(1, "closed")



    class Ethernet(Entity):
        """
        Ethernet configuration
        
        .. attribute:: evc
        
        	define an Ethernet virtual connection (EVC)
        	**type**\: list of  		 :py:class:`Evc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Evc>`
        
        .. attribute:: lmi
        
        	Local Management Interface
        	**type**\:  :py:class:`Lmi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Lmi>`
        
        .. attribute:: cfm
        
        	Connectivity Fault Management
        	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Ethernet, self).__init__()

            self.yang_name = "ethernet"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-ethernet:evc", ("evc", Native.Ethernet.Evc)), ("Cisco-IOS-XE-ethernet:lmi", ("lmi", Native.Ethernet.Lmi)), ("Cisco-IOS-XE-ethernet:cfm", ("cfm", Native.Ethernet.Cfm))])
            self._leafs = OrderedDict()

            self.lmi = Native.Ethernet.Lmi()
            self.lmi.parent = self
            self._children_name_map["lmi"] = "Cisco-IOS-XE-ethernet:lmi"

            self.cfm = Native.Ethernet.Cfm()
            self.cfm.parent = self
            self._children_name_map["cfm"] = "Cisco-IOS-XE-ethernet:cfm"

            self.evc = YList(self)
            self._segment_path = lambda: "ethernet"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Ethernet, [], name, value)


        class Evc(Entity):
            """
            define an Ethernet virtual connection (EVC)
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            	**length:** 1..100
            
            

            """

            _prefix = 'ios-eth'
            _revision = '2018-04-09'

            def __init__(self):
                super(Native.Ethernet.Evc, self).__init__()

                self.yang_name = "evc"
                self.yang_parent_name = "ethernet"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None
                self._segment_path = lambda: "Cisco-IOS-XE-ethernet:evc" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ethernet.Evc, ['name'], name, value)


        class Lmi(Entity):
            """
            Local Management Interface
            
            .. attribute:: ce
            
            	Ethernet LMI Customer Edge
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: global_
            
            	Ethernet LMI is enabled on all supported Interfaces
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-eth'
            _revision = '2018-04-09'

            def __init__(self):
                super(Native.Ethernet.Lmi, self).__init__()

                self.yang_name = "lmi"
                self.yang_parent_name = "ethernet"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('ce', (YLeaf(YType.empty, 'ce'), ['Empty'])),
                    ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                ])
                self.ce = None
                self.global_ = None
                self._segment_path = lambda: "Cisco-IOS-XE-ethernet:lmi"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ethernet.Lmi, ['ce', 'global_'], name, value)


        class Cfm(Entity):
            """
            Connectivity Fault Management
            
            .. attribute:: ais
            
            	AIS Maintenance Condition
            	**type**\:  :py:class:`Ais <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Ais>`
            
            .. attribute:: alarm
            
            	CFM Alarm
            	**type**\:  :py:class:`Alarm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Alarm>`
            
            .. attribute:: ieee
            
            	CFM IEEE enable
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: global_
            
            	CFM global enable
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: domain
            
            	Configure a domain
            	**type**\: list of  		 :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Domain>`
            
            .. attribute:: logging
            
            	Enable CFM syslog messages
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Logging>`
            
            	**presence node**\: True
            
            .. attribute:: mep
            
            	Maintenance End Point
            	**type**\:  :py:class:`Mep <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Mep>`
            
            .. attribute:: mip
            
            	CFM MIP commands
            	**type**\:  :py:class:`Mip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Mip>`
            
            .. attribute:: traceroute
            
            	CFM Traceroute
            	**type**\:  :py:class:`Traceroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Traceroute>`
            
            

            """

            _prefix = 'ios-eth'
            _revision = '2018-04-09'

            def __init__(self):
                super(Native.Ethernet.Cfm, self).__init__()

                self.yang_name = "cfm"
                self.yang_parent_name = "ethernet"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ais", ("ais", Native.Ethernet.Cfm.Ais)), ("alarm", ("alarm", Native.Ethernet.Cfm.Alarm)), ("domain", ("domain", Native.Ethernet.Cfm.Domain)), ("logging", ("logging", Native.Ethernet.Cfm.Logging)), ("mep", ("mep", Native.Ethernet.Cfm.Mep)), ("mip", ("mip", Native.Ethernet.Cfm.Mip)), ("traceroute", ("traceroute", Native.Ethernet.Cfm.Traceroute))])
                self._leafs = OrderedDict([
                    ('ieee', (YLeaf(YType.empty, 'ieee'), ['Empty'])),
                    ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                ])
                self.ieee = None
                self.global_ = None

                self.ais = Native.Ethernet.Cfm.Ais()
                self.ais.parent = self
                self._children_name_map["ais"] = "ais"

                self.alarm = Native.Ethernet.Cfm.Alarm()
                self.alarm.parent = self
                self._children_name_map["alarm"] = "alarm"

                self.logging = None
                self._children_name_map["logging"] = "logging"

                self.mep = Native.Ethernet.Cfm.Mep()
                self.mep.parent = self
                self._children_name_map["mep"] = "mep"

                self.mip = Native.Ethernet.Cfm.Mip()
                self.mip.parent = self
                self._children_name_map["mip"] = "mip"

                self.traceroute = Native.Ethernet.Cfm.Traceroute()
                self.traceroute.parent = self
                self._children_name_map["traceroute"] = "traceroute"

                self.domain = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-ethernet:cfm"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ethernet.Cfm, ['ieee', 'global_'], name, value)


            class Ais(Entity):
                """
                AIS Maintenance Condition
                
                .. attribute:: link_status
                
                	8023ah SMEP or link state up/down
                	**type**\:  :py:class:`LinkStatus <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Ais.LinkStatus>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Ethernet.Cfm.Ais, self).__init__()

                    self.yang_name = "ais"
                    self.yang_parent_name = "cfm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("link-status", ("link_status", Native.Ethernet.Cfm.Ais.LinkStatus))])
                    self._leafs = OrderedDict()

                    self.link_status = Native.Ethernet.Cfm.Ais.LinkStatus()
                    self.link_status.parent = self
                    self._children_name_map["link_status"] = "link-status"
                    self._segment_path = lambda: "ais"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ethernet.Cfm.Ais, [], name, value)


                class LinkStatus(Entity):
                    """
                    8023ah SMEP or link state up/down
                    
                    .. attribute:: global_
                    
                    	8023ah SMEP or link state state up/down AIS global configuration
                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Ais.LinkStatus.Global>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Ethernet.Cfm.Ais.LinkStatus, self).__init__()

                        self.yang_name = "link-status"
                        self.yang_parent_name = "ais"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("global", ("global_", Native.Ethernet.Cfm.Ais.LinkStatus.Global))])
                        self._leafs = OrderedDict()

                        self.global_ = None
                        self._children_name_map["global_"] = "global"
                        self._segment_path = lambda: "link-status"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/ais/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ethernet.Cfm.Ais.LinkStatus, [], name, value)


                    class Global(Entity):
                        """
                        8023ah SMEP or link state state up/down AIS global configuration
                        
                        .. attribute:: cfm_mode__config_ais_link_cfm
                        
                        	
                        	**type**\:  :py:class:`CfmModeConfigAisLinkCfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Ais.LinkStatus.Global.CfmModeConfigAisLinkCfm>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Ethernet.Cfm.Ais.LinkStatus.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "link-status"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cfm-Mode__config-ais-link-cfm", ("cfm_mode__config_ais_link_cfm", Native.Ethernet.Cfm.Ais.LinkStatus.Global.CfmModeConfigAisLinkCfm))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.cfm_mode__config_ais_link_cfm = Native.Ethernet.Cfm.Ais.LinkStatus.Global.CfmModeConfigAisLinkCfm()
                            self.cfm_mode__config_ais_link_cfm.parent = self
                            self._children_name_map["cfm_mode__config_ais_link_cfm"] = "cfm-Mode__config-ais-link-cfm"
                            self._segment_path = lambda: "global"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/ais/link-status/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ethernet.Cfm.Ais.LinkStatus.Global, [], name, value)


                        class CfmModeConfigAisLinkCfm(Entity):
                            """
                            
                            
                            .. attribute:: disable
                            
                            	Disable AIS transmission
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: level
                            
                            	Maintenance Level
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: period
                            
                            	AIS Transmission period
                            	**type**\:  :py:class:`Period <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Ais.LinkStatus.Global.CfmModeConfigAisLinkCfm.Period>`
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Ethernet.Cfm.Ais.LinkStatus.Global.CfmModeConfigAisLinkCfm, self).__init__()

                                self.yang_name = "cfm-Mode__config-ais-link-cfm"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("period", ("period", Native.Ethernet.Cfm.Ais.LinkStatus.Global.CfmModeConfigAisLinkCfm.Period))])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                                ])
                                self.disable = None
                                self.level = None

                                self.period = Native.Ethernet.Cfm.Ais.LinkStatus.Global.CfmModeConfigAisLinkCfm.Period()
                                self.period.parent = self
                                self._children_name_map["period"] = "period"
                                self._segment_path = lambda: "cfm-Mode__config-ais-link-cfm"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/ais/link-status/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ethernet.Cfm.Ais.LinkStatus.Global.CfmModeConfigAisLinkCfm, ['disable', 'level'], name, value)


                            class Period(Entity):
                                """
                                AIS Transmission period
                                
                                .. attribute:: tp_1
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: tp_60
                                
                                	Seconds
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eth'
                                _revision = '2018-04-09'

                                def __init__(self):
                                    super(Native.Ethernet.Cfm.Ais.LinkStatus.Global.CfmModeConfigAisLinkCfm.Period, self).__init__()

                                    self.yang_name = "period"
                                    self.yang_parent_name = "cfm-Mode__config-ais-link-cfm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('tp_1', (YLeaf(YType.empty, 'tp-1'), ['Empty'])),
                                        ('tp_60', (YLeaf(YType.empty, 'tp-60'), ['Empty'])),
                                    ])
                                    self.tp_1 = None
                                    self.tp_60 = None
                                    self._segment_path = lambda: "period"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/ais/link-status/global/cfm-Mode__config-ais-link-cfm/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Ethernet.Cfm.Ais.LinkStatus.Global.CfmModeConfigAisLinkCfm.Period, ['tp_1', 'tp_60'], name, value)


            class Alarm(Entity):
                """
                CFM Alarm
                
                .. attribute:: delay
                
                	msec (default 2500 msec)
                	**type**\: int
                
                	**range:** 2500..10000
                
                .. attribute:: notification
                
                	CFM alarm notification
                	**type**\:  :py:class:`Notification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Alarm.Notification>`
                
                .. attribute:: packet
                
                	max DefError and DefXcon packets
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: reset
                
                	msec (default 10000 msec)
                	**type**\: int
                
                	**range:** 2500..10000
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Ethernet.Cfm.Alarm, self).__init__()

                    self.yang_name = "alarm"
                    self.yang_parent_name = "cfm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("notification", ("notification", Native.Ethernet.Cfm.Alarm.Notification))])
                    self._leafs = OrderedDict([
                        ('delay', (YLeaf(YType.uint16, 'delay'), ['int'])),
                        ('packet', (YLeaf(YType.uint16, 'packet'), ['int'])),
                        ('reset', (YLeaf(YType.uint16, 'reset'), ['int'])),
                    ])
                    self.delay = None
                    self.packet = None
                    self.reset = None

                    self.notification = Native.Ethernet.Cfm.Alarm.Notification()
                    self.notification.parent = self
                    self._children_name_map["notification"] = "notification"
                    self._segment_path = lambda: "alarm"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ethernet.Cfm.Alarm, ['delay', 'packet', 'reset'], name, value)


                class Notification(Entity):
                    """
                    CFM alarm notification
                    
                    .. attribute:: all
                    
                    	Report all defects\: DefRDI, DefMACStatus, DefRemote, DefError, DefXcon
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: error_xcon
                    
                    	Report only\: DefError and DefXcon
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mac_remote_error_xcon
                    
                    	Report only\: DefMACStatus, DefRemote, DefError and DefXcon (default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: none
                    
                    	No defects to be reported
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: remote_error_xcon
                    
                    	Report only\: DefRemote, DefError and DefXcon
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: xcon
                    
                    	Report only\: DefXcon
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Ethernet.Cfm.Alarm.Notification, self).__init__()

                        self.yang_name = "notification"
                        self.yang_parent_name = "alarm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                            ('error_xcon', (YLeaf(YType.empty, 'error-xcon'), ['Empty'])),
                            ('mac_remote_error_xcon', (YLeaf(YType.empty, 'mac-remote-error-xcon'), ['Empty'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ('remote_error_xcon', (YLeaf(YType.empty, 'remote-error-xcon'), ['Empty'])),
                            ('xcon', (YLeaf(YType.empty, 'xcon'), ['Empty'])),
                        ])
                        self.all = None
                        self.error_xcon = None
                        self.mac_remote_error_xcon = None
                        self.none = None
                        self.remote_error_xcon = None
                        self.xcon = None
                        self._segment_path = lambda: "notification"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/alarm/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ethernet.Cfm.Alarm.Notification, ['all', 'error_xcon', 'mac_remote_error_xcon', 'none', 'remote_error_xcon', 'xcon'], name, value)


            class Domain(Entity):
                """
                Configure a domain
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: level
                
                	Maintenance Level
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: service
                
                	Maintenance Association within Domain
                	**type**\: list of  		 :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Domain.Service>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Ethernet.Cfm.Domain, self).__init__()

                    self.yang_name = "domain"
                    self.yang_parent_name = "cfm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("service", ("service", Native.Ethernet.Cfm.Domain.Service))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                    ])
                    self.name = None
                    self.level = None

                    self.service = YList(self)
                    self._segment_path = lambda: "domain" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ethernet.Cfm.Domain, ['name', 'level'], name, value)


                class Service(Entity):
                    """
                    Maintenance Association within Domain
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: evc
                    
                    	Specify EVC
                    	**type**\: str
                    
                    .. attribute:: vlan
                    
                    	VLAN id
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: continuity_check
                    
                    	Enable Continuity Check for Maintenance Association
                    	**type**\:  :py:class:`ContinuityCheck <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Domain.Service.ContinuityCheck>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Ethernet.Cfm.Domain.Service, self).__init__()

                        self.yang_name = "service"
                        self.yang_parent_name = "domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("continuity-check", ("continuity_check", Native.Ethernet.Cfm.Domain.Service.ContinuityCheck))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('evc', (YLeaf(YType.str, 'evc'), ['str'])),
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.name = None
                        self.evc = None
                        self.vlan = None

                        self.continuity_check = None
                        self._children_name_map["continuity_check"] = "continuity-check"
                        self._segment_path = lambda: "service" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ethernet.Cfm.Domain.Service, ['name', 'evc', 'vlan'], name, value)


                    class ContinuityCheck(Entity):
                        """
                        Enable Continuity Check for Maintenance Association
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Ethernet.Cfm.Domain.Service.ContinuityCheck, self).__init__()

                            self.yang_name = "continuity-check"
                            self.yang_parent_name = "service"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "continuity-check"
                            self._is_frozen = True


            class Logging(Entity):
                """
                Enable CFM syslog messages
                
                .. attribute:: ais
                
                	AIS logging
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: alarm
                
                	Alarm logging
                	**type**\:  :py:class:`Alarm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Logging.Alarm>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Ethernet.Cfm.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "cfm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("alarm", ("alarm", Native.Ethernet.Cfm.Logging.Alarm))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('ais', (YLeaf(YType.empty, 'ais'), ['Empty'])),
                    ])
                    self.ais = None

                    self.alarm = Native.Ethernet.Cfm.Logging.Alarm()
                    self.alarm.parent = self
                    self._children_name_map["alarm"] = "alarm"
                    self._segment_path = lambda: "logging"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ethernet.Cfm.Logging, ['ais'], name, value)


                class Alarm(Entity):
                    """
                    Alarm logging
                    
                    .. attribute:: cisco
                    
                    	Cisco MIB syslogs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ieee
                    
                    	IEEE MIB syslogs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Ethernet.Cfm.Logging.Alarm, self).__init__()

                        self.yang_name = "alarm"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('cisco', (YLeaf(YType.empty, 'cisco'), ['Empty'])),
                            ('ieee', (YLeaf(YType.empty, 'ieee'), ['Empty'])),
                        ])
                        self.cisco = None
                        self.ieee = None
                        self._segment_path = lambda: "alarm"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/logging/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ethernet.Cfm.Logging.Alarm, ['cisco', 'ieee'], name, value)


            class Mep(Entity):
                """
                Maintenance End Point
                
                .. attribute:: crosscheck
                
                	Cross Check remote MEPs
                	**type**\:  :py:class:`Crosscheck <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Mep.Crosscheck>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Ethernet.Cfm.Mep, self).__init__()

                    self.yang_name = "mep"
                    self.yang_parent_name = "cfm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("crosscheck", ("crosscheck", Native.Ethernet.Cfm.Mep.Crosscheck))])
                    self._leafs = OrderedDict()

                    self.crosscheck = Native.Ethernet.Cfm.Mep.Crosscheck()
                    self.crosscheck.parent = self
                    self._children_name_map["crosscheck"] = "crosscheck"
                    self._segment_path = lambda: "mep"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ethernet.Cfm.Mep, [], name, value)


                class Crosscheck(Entity):
                    """
                    Cross Check remote MEPs
                    
                    .. attribute:: start_delay
                    
                    	seconds (30 seconds default)
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Ethernet.Cfm.Mep.Crosscheck, self).__init__()

                        self.yang_name = "crosscheck"
                        self.yang_parent_name = "mep"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('start_delay', (YLeaf(YType.uint16, 'start-delay'), ['int'])),
                        ])
                        self.start_delay = None
                        self._segment_path = lambda: "crosscheck"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/mep/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ethernet.Cfm.Mep.Crosscheck, ['start_delay'], name, value)


            class Mip(Entity):
                """
                CFM MIP commands
                
                .. attribute:: auto_create
                
                	CFM MIP auto creation
                	**type**\:  :py:class:`AutoCreate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Mip.AutoCreate>`
                
                .. attribute:: filter
                
                	CFM MIP filter
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Ethernet.Cfm.Mip, self).__init__()

                    self.yang_name = "mip"
                    self.yang_parent_name = "cfm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("auto-create", ("auto_create", Native.Ethernet.Cfm.Mip.AutoCreate))])
                    self._leafs = OrderedDict([
                        ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                    ])
                    self.filter = None

                    self.auto_create = Native.Ethernet.Cfm.Mip.AutoCreate()
                    self.auto_create.parent = self
                    self._children_name_map["auto_create"] = "auto-create"
                    self._segment_path = lambda: "mip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ethernet.Cfm.Mip, ['filter'], name, value)


                class AutoCreate(Entity):
                    """
                    CFM MIP auto creation
                    
                    .. attribute:: level
                    
                    	Maintenance Level
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Mip.AutoCreate.Level>`
                    
                    

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Ethernet.Cfm.Mip.AutoCreate, self).__init__()

                        self.yang_name = "auto-create"
                        self.yang_parent_name = "mip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Ethernet.Cfm.Mip.AutoCreate.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Ethernet.Cfm.Mip.AutoCreate.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "auto-create"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/mip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ethernet.Cfm.Mip.AutoCreate, [], name, value)


                    class Level(Entity):
                        """
                        Maintenance Level
                        
                        .. attribute:: mef_num
                        
                        	
                        	**type**\: list of  		 :py:class:`MefNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Mip.AutoCreate.Level.MefNum>`
                        
                        

                        """

                        _prefix = 'ios-eth'
                        _revision = '2018-04-09'

                        def __init__(self):
                            super(Native.Ethernet.Cfm.Mip.AutoCreate.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "auto-create"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mef-num", ("mef_num", Native.Ethernet.Cfm.Mip.AutoCreate.Level.MefNum))])
                            self._leafs = OrderedDict()

                            self.mef_num = YList(self)
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/mip/auto-create/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Ethernet.Cfm.Mip.AutoCreate.Level, [], name, value)


                        class MefNum(Entity):
                            """
                            
                            
                            .. attribute:: mef_num  (key)
                            
                            	maintenance level number
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: evc
                            
                            	EVC name
                            	**type**\: str
                            
                            .. attribute:: vlan
                            
                            	VLAN id
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            

                            """

                            _prefix = 'ios-eth'
                            _revision = '2018-04-09'

                            def __init__(self):
                                super(Native.Ethernet.Cfm.Mip.AutoCreate.Level.MefNum, self).__init__()

                                self.yang_name = "mef-num"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['mef_num']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mef_num', (YLeaf(YType.uint8, 'mef-num'), ['int'])),
                                    ('evc', (YLeaf(YType.str, 'evc'), ['str'])),
                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                ])
                                self.mef_num = None
                                self.evc = None
                                self.vlan = None
                                self._segment_path = lambda: "mef-num" + "[mef-num='" + str(self.mef_num) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/mip/auto-create/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Ethernet.Cfm.Mip.AutoCreate.Level.MefNum, ['mef_num', 'evc', 'vlan'], name, value)


            class Traceroute(Entity):
                """
                CFM Traceroute
                
                .. attribute:: cache
                
                	CFM Traceroute Cache
                	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ethernet.Cfm.Traceroute.Cache>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-eth'
                _revision = '2018-04-09'

                def __init__(self):
                    super(Native.Ethernet.Cfm.Traceroute, self).__init__()

                    self.yang_name = "traceroute"
                    self.yang_parent_name = "cfm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cache", ("cache", Native.Ethernet.Cfm.Traceroute.Cache))])
                    self._leafs = OrderedDict()

                    self.cache = None
                    self._children_name_map["cache"] = "cache"
                    self._segment_path = lambda: "traceroute"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ethernet.Cfm.Traceroute, [], name, value)


                class Cache(Entity):
                    """
                    CFM Traceroute Cache
                    
                    .. attribute:: hold_time
                    
                    	minutes (default 100)
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: size
                    
                    	Number of cached lines (default 100)
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eth'
                    _revision = '2018-04-09'

                    def __init__(self):
                        super(Native.Ethernet.Cfm.Traceroute.Cache, self).__init__()

                        self.yang_name = "cache"
                        self.yang_parent_name = "traceroute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                            ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                        ])
                        self.hold_time = None
                        self.size = None
                        self._segment_path = lambda: "cache"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ethernet/Cisco-IOS-XE-ethernet:cfm/traceroute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ethernet.Cfm.Traceroute.Cache, ['hold_time', 'size'], name, value)


    class BridgeDomain(Entity):
        """
        Bridge\-domain global configuration commands
        
        .. attribute:: brd_id
        
        	
        	**type**\: list of  		 :py:class:`BrdId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId>`
        
        .. attribute:: c_mac
        
        	Configure c\-mac global commands
        	**type**\:  :py:class:`CMac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.CMac>`
        
        .. attribute:: otv
        
        	Configure overlay bridge domains
        	**type**\:  :py:class:`Otv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Otv>`
        
        .. attribute:: parameterized
        
        	bridge\-domain is derived from parameters
        	**type**\:  :py:class:`Parameterized <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.BridgeDomain, self).__init__()

            self.yang_name = "bridge-domain"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-bridge-domain:brd-id", ("brd_id", Native.BridgeDomain.BrdId)), ("Cisco-IOS-XE-bridge-domain:c-mac", ("c_mac", Native.BridgeDomain.CMac)), ("Cisco-IOS-XE-bridge-domain:otv", ("otv", Native.BridgeDomain.Otv)), ("Cisco-IOS-XE-bridge-domain:parameterized", ("parameterized", Native.BridgeDomain.Parameterized))])
            self._leafs = OrderedDict()

            self.c_mac = Native.BridgeDomain.CMac()
            self.c_mac.parent = self
            self._children_name_map["c_mac"] = "Cisco-IOS-XE-bridge-domain:c-mac"

            self.otv = Native.BridgeDomain.Otv()
            self.otv.parent = self
            self._children_name_map["otv"] = "Cisco-IOS-XE-bridge-domain:otv"

            self.parameterized = Native.BridgeDomain.Parameterized()
            self.parameterized.parent = self
            self._children_name_map["parameterized"] = "Cisco-IOS-XE-bridge-domain:parameterized"

            self.brd_id = YList(self)
            self._segment_path = lambda: "bridge-domain"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.BridgeDomain, [], name, value)


        class BrdId(Entity):
            """
            
            
            .. attribute:: bridge_domain_id  (key)
            
            	<1..8192>;;bridge\-domain ID
            	**type**\: int
            
            	**range:** 1..8192
            
            .. attribute:: ip
            
            	IP related commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Ip>`
            
            .. attribute:: mac
            
            	MAC Address related commands
            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Mac>`
            
            .. attribute:: member
            
            	bridge\-domain member
            	**type**\:  :py:class:`Member <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Member>`
            
            .. attribute:: shutdown
            
            	Take the bridge domain admin down
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-bd'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.BridgeDomain.BrdId, self).__init__()

                self.yang_name = "brd-id"
                self.yang_parent_name = "bridge-domain"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['bridge_domain_id']
                self._child_classes = OrderedDict([("ip", ("ip", Native.BridgeDomain.BrdId.Ip)), ("mac", ("mac", Native.BridgeDomain.BrdId.Mac)), ("member", ("member", Native.BridgeDomain.BrdId.Member))])
                self._leafs = OrderedDict([
                    ('bridge_domain_id', (YLeaf(YType.uint16, 'bridge-domain-id'), ['int'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                ])
                self.bridge_domain_id = None
                self.shutdown = None

                self.ip = Native.BridgeDomain.BrdId.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.mac = Native.BridgeDomain.BrdId.Mac()
                self.mac.parent = self
                self._children_name_map["mac"] = "mac"

                self.member = Native.BridgeDomain.BrdId.Member()
                self.member.parent = self
                self._children_name_map["member"] = "member"
                self._segment_path = lambda: "Cisco-IOS-XE-bridge-domain:brd-id" + "[bridge-domain-id='" + str(self.bridge_domain_id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.BridgeDomain.BrdId, ['bridge_domain_id', 'shutdown'], name, value)


            class Ip(Entity):
                """
                IP related commands
                
                .. attribute:: igmp
                
                	IP igmp commands
                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Ip.Igmp>`
                
                

                """

                _prefix = 'ios-bd'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.BridgeDomain.BrdId.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "brd-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("igmp", ("igmp", Native.BridgeDomain.BrdId.Ip.Igmp))])
                    self._leafs = OrderedDict()

                    self.igmp = Native.BridgeDomain.BrdId.Ip.Igmp()
                    self.igmp.parent = self
                    self._children_name_map["igmp"] = "igmp"
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.BridgeDomain.BrdId.Ip, [], name, value)


                class Igmp(Entity):
                    """
                    IP igmp commands
                    
                    .. attribute:: snooping
                    
                    	IP igmp snooping commands
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Ip.Igmp.Snooping>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-bd'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.BridgeDomain.BrdId.Ip.Igmp, self).__init__()

                        self.yang_name = "igmp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.BridgeDomain.BrdId.Ip.Igmp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = None
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "igmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.BridgeDomain.BrdId.Ip.Igmp, [], name, value)


                    class Snooping(Entity):
                        """
                        IP igmp snooping commands
                        
                        .. attribute:: check
                        
                        	enforce TTL or Rtr\-Alert Option checking
                        	**type**\:  :py:class:`Check <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Check>`
                        
                        .. attribute:: explicit_tracking
                        
                        	IGMP explicit host tracking configuration
                        	**type**\:  :py:class:`ExplicitTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.ExplicitTracking>`
                        
                        .. attribute:: immediate_leave
                        
                        	Enable IGMPv2 immediate leave processing
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: last_member_query_count
                        
                        	Last member query count
                        	**type**\: int
                        
                        	**range:** 1..7
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last member query interval
                        	**type**\: int
                        
                        	**range:** 100..32767
                        
                        .. attribute:: mrouter
                        
                        	Configure an L2 port as a multicast router port
                        	**type**\:  :py:class:`Mrouter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Mrouter>`
                        
                        .. attribute:: querier
                        
                        	Enable IGMP querier for this Bdomain
                        	**type**\:  :py:class:`Querier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Querier>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: report_suppression
                        
                        	Enable IGMP report suppression
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: robustness_variable
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..3
                        
                        .. attribute:: static
                        
                        	Configure an L2 port as a member of a group
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.BrdId.Ip.Igmp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "igmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("check", ("check", Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Check)), ("explicit-tracking", ("explicit_tracking", Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.ExplicitTracking)), ("mrouter", ("mrouter", Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Mrouter)), ("querier", ("querier", Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Querier))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('immediate_leave', (YLeaf(YType.empty, 'immediate-leave'), ['Empty'])),
                                ('last_member_query_count', (YLeaf(YType.uint8, 'last-member-query-count'), ['int'])),
                                ('last_member_query_interval', (YLeaf(YType.uint16, 'last-member-query-interval'), ['int'])),
                                ('report_suppression', (YLeaf(YType.empty, 'report-suppression'), ['Empty'])),
                                ('robustness_variable', (YLeaf(YType.uint8, 'robustness-variable'), ['int'])),
                                ('static', (YLeaf(YType.str, 'static'), ['str'])),
                            ])
                            self.immediate_leave = None
                            self.last_member_query_count = None
                            self.last_member_query_interval = None
                            self.report_suppression = None
                            self.robustness_variable = None
                            self.static = None

                            self.check = Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Check()
                            self.check.parent = self
                            self._children_name_map["check"] = "check"

                            self.explicit_tracking = Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.ExplicitTracking()
                            self.explicit_tracking.parent = self
                            self._children_name_map["explicit_tracking"] = "explicit-tracking"

                            self.mrouter = Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Mrouter()
                            self.mrouter.parent = self
                            self._children_name_map["mrouter"] = "mrouter"

                            self.querier = None
                            self._children_name_map["querier"] = "querier"
                            self._segment_path = lambda: "snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.BrdId.Ip.Igmp.Snooping, ['immediate_leave', 'last_member_query_count', 'last_member_query_interval', 'report_suppression', 'robustness_variable', 'static'], name, value)


                        class Check(Entity):
                            """
                            enforce TTL or Rtr\-Alert Option checking
                            
                            .. attribute:: rtr_alert_option
                            
                            	Only accept IGMP packets with router\-alert option
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ttl
                            
                            	Only accept IGMP packets with TTL=1
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Check, self).__init__()

                                self.yang_name = "check"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rtr_alert_option', (YLeaf(YType.empty, 'rtr-alert-option'), ['Empty'])),
                                    ('ttl', (YLeaf(YType.empty, 'ttl'), ['Empty'])),
                                ])
                                self.rtr_alert_option = None
                                self.ttl = None
                                self._segment_path = lambda: "check"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Check, ['rtr_alert_option', 'ttl'], name, value)


                        class ExplicitTracking(Entity):
                            """
                            IGMP explicit host tracking configuration
                            
                            .. attribute:: limit
                            
                            	Explicit Host Tracking DB limit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.ExplicitTracking, self).__init__()

                                self.yang_name = "explicit-tracking"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.empty, 'limit'), ['Empty'])),
                                ])
                                self.limit = None
                                self._segment_path = lambda: "explicit-tracking"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.ExplicitTracking, ['limit'], name, value)


                        class Mrouter(Entity):
                            """
                            Configure an L2 port as a multicast router port
                            
                            .. attribute:: interface
                            
                            	next\-hop interface to mrouter
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Mrouter, self).__init__()

                                self.yang_name = "mrouter"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                                ])
                                self.interface = None
                                self._segment_path = lambda: "mrouter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Mrouter, ['interface'], name, value)


                        class Querier(Entity):
                            """
                            Enable IGMP querier for this Bdomain
                            
                            .. attribute:: address
                            
                            	IGMP querier source IP address
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_response_time
                            
                            	IGMP querier maximum response time (sec)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: query_interval
                            
                            	IGMP querier query interval (sec)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: tcn
                            
                            	IGMP querier TCN related parameters
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timer
                            
                            	IGMP other querier timer
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: version
                            
                            	IGMP version
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Querier, self).__init__()

                                self.yang_name = "querier"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ('max_response_time', (YLeaf(YType.empty, 'max-response-time'), ['Empty'])),
                                    ('query_interval', (YLeaf(YType.empty, 'query-interval'), ['Empty'])),
                                    ('tcn', (YLeaf(YType.empty, 'tcn'), ['Empty'])),
                                    ('timer', (YLeaf(YType.empty, 'timer'), ['Empty'])),
                                    ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                                ])
                                self.address = None
                                self.max_response_time = None
                                self.query_interval = None
                                self.tcn = None
                                self.timer = None
                                self.version = None
                                self._segment_path = lambda: "querier"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.BrdId.Ip.Igmp.Snooping.Querier, ['address', 'max_response_time', 'query_interval', 'tcn', 'timer', 'version'], name, value)


            class Mac(Entity):
                """
                MAC Address related commands
                
                .. attribute:: aging_time
                
                	Set age time of mac addresses per bridge domain
                	**type**\: int
                
                	**range:** 30..3600
                
                .. attribute:: learning
                
                	Disable mac learning on bridge domain
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: limit
                
                	Limit the MAC Addresses learnt
                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Mac.Limit>`
                
                

                """

                _prefix = 'ios-bd'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.BridgeDomain.BrdId.Mac, self).__init__()

                    self.yang_name = "mac"
                    self.yang_parent_name = "brd-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("limit", ("limit", Native.BridgeDomain.BrdId.Mac.Limit))])
                    self._leafs = OrderedDict([
                        ('aging_time', (YLeaf(YType.uint16, 'aging-time'), ['int'])),
                        ('learning', (YLeaf(YType.empty, 'learning'), ['Empty'])),
                    ])
                    self.aging_time = None
                    self.learning = None

                    self.limit = Native.BridgeDomain.BrdId.Mac.Limit()
                    self.limit.parent = self
                    self._children_name_map["limit"] = "limit"
                    self._segment_path = lambda: "mac"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.BridgeDomain.BrdId.Mac, ['aging_time', 'learning'], name, value)


                class Limit(Entity):
                    """
                    Limit the MAC Addresses learnt
                    
                    .. attribute:: action
                    
                    	action when exceeding the limit
                    	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Mac.Limit.Action>`
                    
                    .. attribute:: maximum
                    
                    	Maximum
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Mac.Limit.Maximum>`
                    
                    

                    """

                    _prefix = 'ios-bd'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.BridgeDomain.BrdId.Mac.Limit, self).__init__()

                        self.yang_name = "limit"
                        self.yang_parent_name = "mac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("action", ("action", Native.BridgeDomain.BrdId.Mac.Limit.Action)), ("maximum", ("maximum", Native.BridgeDomain.BrdId.Mac.Limit.Maximum))])
                        self._leafs = OrderedDict()

                        self.action = Native.BridgeDomain.BrdId.Mac.Limit.Action()
                        self.action.parent = self
                        self._children_name_map["action"] = "action"

                        self.maximum = Native.BridgeDomain.BrdId.Mac.Limit.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"
                        self._segment_path = lambda: "limit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.BridgeDomain.BrdId.Mac.Limit, [], name, value)


                    class Action(Entity):
                        """
                        action when exceeding the limit
                        
                        .. attribute:: flooding
                        
                        	Mac flooding
                        	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Mac.Limit.Action.Flooding>`
                        
                        

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.BrdId.Mac.Limit.Action, self).__init__()

                            self.yang_name = "action"
                            self.yang_parent_name = "limit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("flooding", ("flooding", Native.BridgeDomain.BrdId.Mac.Limit.Action.Flooding))])
                            self._leafs = OrderedDict()

                            self.flooding = Native.BridgeDomain.BrdId.Mac.Limit.Action.Flooding()
                            self.flooding.parent = self
                            self._children_name_map["flooding"] = "flooding"
                            self._segment_path = lambda: "action"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.BrdId.Mac.Limit.Action, [], name, value)


                        class Flooding(Entity):
                            """
                            Mac flooding
                            
                            .. attribute:: disable
                            
                            	disable
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.BrdId.Mac.Limit.Action.Flooding, self).__init__()

                                self.yang_name = "flooding"
                                self.yang_parent_name = "action"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "flooding"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.BrdId.Mac.Limit.Action.Flooding, ['disable'], name, value)


                    class Maximum(Entity):
                        """
                        Maximum
                        
                        .. attribute:: addresses
                        
                        	Addresses
                        	**type**\: int
                        
                        	**range:** 1..65536
                        
                        

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.BrdId.Mac.Limit.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "limit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('addresses', (YLeaf(YType.uint32, 'addresses'), ['int'])),
                            ])
                            self.addresses = None
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.BrdId.Mac.Limit.Maximum, ['addresses'], name, value)


            class Member(Entity):
                """
                bridge\-domain member
                
                .. attribute:: mem_ipv4
                
                	
                	**type**\: list of  		 :py:class:`MemIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Member.MemIpv4>`
                
                .. attribute:: acr
                
                	
                	**type**\: list of  		 :py:class:`ACR <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Member.ACR>`
                
                .. attribute:: analysis_module
                
                	Cisco network analysis service module
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: fcpa
                
                	Fiber Channel
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: sbc
                
                	Session Border Controller
                	**type**\: int
                
                	**range:** 0..2147483647
                
                .. attribute:: sonet_acr
                
                	Virtual SONET\-ACR controller
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: y_controller
                
                	
                	**type**\: str
                
                .. attribute:: service_engine
                
                	Cisco service engine module
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: tunnel_tp
                
                	MPLS Transport Profile interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vpn
                
                	VPN interface
                	**type**\: int
                
                	**range:** 0..2147483647
                
                .. attribute:: virtual_tokenring
                
                	Virtual TokenRing
                	**type**\: int
                
                	**range:** 0..2147483647
                
                .. attribute:: ucse
                
                	Cisco ucse server
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: vasileft
                
                	VasiLeft interface
                	**type**\: int
                
                	**range:** 1..2000
                
                .. attribute:: vasiright
                
                	VasiRight interface
                	**type**\: int
                
                	**range:** 1..2000
                
                .. attribute:: vfi
                
                	Enter VFI name
                	**type**\: str
                
                .. attribute:: vni
                
                	
                	**type**\: int
                
                	**range:** 4096..16777215
                
                .. attribute:: member_interface
                
                	
                	**type**\: list of  		 :py:class:`MemberInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Member.MemberInterface>`
                
                

                """

                _prefix = 'ios-bd'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.BridgeDomain.BrdId.Member, self).__init__()

                    self.yang_name = "member"
                    self.yang_parent_name = "brd-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mem-ipv4", ("mem_ipv4", Native.BridgeDomain.BrdId.Member.MemIpv4)), ("ACR", ("acr", Native.BridgeDomain.BrdId.Member.ACR)), ("member-interface", ("member_interface", Native.BridgeDomain.BrdId.Member.MemberInterface))])
                    self._leafs = OrderedDict([
                        ('analysis_module', (YLeaf(YType.uint8, 'Analysis-Module'), ['int'])),
                        ('fcpa', (YLeaf(YType.uint8, 'Fcpa'), ['int'])),
                        ('sbc', (YLeaf(YType.uint32, 'SBC'), ['int'])),
                        ('sonet_acr', (YLeaf(YType.uint8, 'SONET_ACR'), ['int'])),
                        ('y_controller', (YLeaf(YType.str, '_controller'), ['str'])),
                        ('service_engine', (YLeaf(YType.uint8, 'Service-Engine'), ['int'])),
                        ('tunnel_tp', (YLeaf(YType.uint16, 'Tunnel-tp'), ['int'])),
                        ('vpn', (YLeaf(YType.uint32, 'VPN'), ['int'])),
                        ('virtual_tokenring', (YLeaf(YType.uint32, 'Virtual-TokenRing'), ['int'])),
                        ('ucse', (YLeaf(YType.uint8, 'ucse'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ('vfi', (YLeaf(YType.str, 'vfi'), ['str'])),
                        ('vni', (YLeaf(YType.uint32, 'vni'), ['int'])),
                    ])
                    self.analysis_module = None
                    self.fcpa = None
                    self.sbc = None
                    self.sonet_acr = None
                    self.y_controller = None
                    self.service_engine = None
                    self.tunnel_tp = None
                    self.vpn = None
                    self.virtual_tokenring = None
                    self.ucse = None
                    self.vasileft = None
                    self.vasiright = None
                    self.vfi = None
                    self.vni = None

                    self.mem_ipv4 = YList(self)
                    self.acr = YList(self)
                    self.member_interface = YList(self)
                    self._segment_path = lambda: "member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.BridgeDomain.BrdId.Member, ['analysis_module', 'fcpa', 'sbc', 'sonet_acr', 'y_controller', 'service_engine', 'tunnel_tp', 'vpn', 'virtual_tokenring', 'ucse', 'vasileft', 'vasiright', 'vfi', 'vni'], name, value)


                class MemIpv4(Entity):
                    """
                    
                    
                    .. attribute:: mem_ipv4  (key)
                    
                    	IP address of the peer
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mem_vcid
                    
                    	
                    	**type**\: list of  		 :py:class:`MemVcid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid>`
                    
                    .. attribute:: encapsulation
                    
                    	Data encapsulation method
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Member.MemIpv4.Encapsulation>`
                    
                    .. attribute:: template
                    
                    	Template to use for encapsulation and protocol configuration
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-bd'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.BridgeDomain.BrdId.Member.MemIpv4, self).__init__()

                        self.yang_name = "mem-ipv4"
                        self.yang_parent_name = "member"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['mem_ipv4']
                        self._child_classes = OrderedDict([("mem-vcid", ("mem_vcid", Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid)), ("encapsulation", ("encapsulation", Native.BridgeDomain.BrdId.Member.MemIpv4.Encapsulation))])
                        self._leafs = OrderedDict([
                            ('mem_ipv4', (YLeaf(YType.str, 'mem-ipv4'), ['str'])),
                            ('template', (YLeaf(YType.str, 'template'), ['str'])),
                        ])
                        self.mem_ipv4 = None
                        self.template = None

                        self.encapsulation = Native.BridgeDomain.BrdId.Member.MemIpv4.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.mem_vcid = YList(self)
                        self._segment_path = lambda: "mem-ipv4" + "[mem-ipv4='" + str(self.mem_ipv4) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.BridgeDomain.BrdId.Member.MemIpv4, ['mem_ipv4', 'template'], name, value)


                    class MemVcid(Entity):
                        """
                        
                        
                        .. attribute:: mem_vcid  (key)
                        
                        	<1..4294967295>;;Enter VC ID value
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid.Encapsulation>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: template
                        
                        	Template to use for encapsulation and protocol configuration
                        	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid.Template>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid, self).__init__()

                            self.yang_name = "mem-vcid"
                            self.yang_parent_name = "mem-ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['mem_vcid']
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid.Encapsulation)), ("template", ("template", Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid.Template))])
                            self._leafs = OrderedDict([
                                ('mem_vcid', (YLeaf(YType.uint32, 'mem-vcid'), ['int'])),
                            ])
                            self.mem_vcid = None

                            self.encapsulation = None
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.template = None
                            self._children_name_map["template"] = "template"
                            self._segment_path = lambda: "mem-vcid" + "[mem-vcid='" + str(self.mem_vcid) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid, ['mem_vcid'], name, value)


                        class Encapsulation(Entity):
                            """
                            Data encapsulation method
                            
                            .. attribute:: mpls
                            
                            	Use MPLS encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "mem-vcid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                ])
                                self.mpls = None
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid.Encapsulation, ['mpls'], name, value)


                        class Template(Entity):
                            """
                            Template to use for encapsulation and protocol configuration
                            
                            .. attribute:: template
                            
                            	<WORD>;;template name (Max size 32)
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid.Template, self).__init__()

                                self.yang_name = "template"
                                self.yang_parent_name = "mem-vcid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('template', (YLeaf(YType.str, 'template'), ['str'])),
                                ])
                                self.template = None
                                self._segment_path = lambda: "template"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.BrdId.Member.MemIpv4.MemVcid.Template, ['template'], name, value)


                    class Encapsulation(Entity):
                        """
                        Data encapsulation method
                        
                        .. attribute:: mpls
                        
                        	Use MPLS encapsulation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.BrdId.Member.MemIpv4.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "mem-ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                            ])
                            self.mpls = None
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.BrdId.Member.MemIpv4.Encapsulation, ['mpls'], name, value)


                class ACR(Entity):
                    """
                    
                    
                    .. attribute:: acr_int  (key)
                    
                    	<WORD>;;Virtual ACR interface
                    	**type**\: str
                    
                    .. attribute:: service_instance
                    
                    	ethernt serivce instance
                    	**type**\:  :py:class:`ServiceInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Member.ACR.ServiceInstance>`
                    
                    

                    """

                    _prefix = 'ios-bd'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.BridgeDomain.BrdId.Member.ACR, self).__init__()

                        self.yang_name = "ACR"
                        self.yang_parent_name = "member"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['acr_int']
                        self._child_classes = OrderedDict([("service-instance", ("service_instance", Native.BridgeDomain.BrdId.Member.ACR.ServiceInstance))])
                        self._leafs = OrderedDict([
                            ('acr_int', (YLeaf(YType.str, 'acr-int'), ['str'])),
                        ])
                        self.acr_int = None

                        self.service_instance = Native.BridgeDomain.BrdId.Member.ACR.ServiceInstance()
                        self.service_instance.parent = self
                        self._children_name_map["service_instance"] = "service-instance"
                        self._segment_path = lambda: "ACR" + "[acr-int='" + str(self.acr_int) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.BridgeDomain.BrdId.Member.ACR, ['acr_int'], name, value)


                    class ServiceInstance(Entity):
                        """
                        ethernt serivce instance
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: list of  		 :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Member.ACR.ServiceInstance.Id>`
                        
                        

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.BrdId.Member.ACR.ServiceInstance, self).__init__()

                            self.yang_name = "service-instance"
                            self.yang_parent_name = "ACR"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("id", ("id", Native.BridgeDomain.BrdId.Member.ACR.ServiceInstance.Id))])
                            self._leafs = OrderedDict()

                            self.id = YList(self)
                            self._segment_path = lambda: "service-instance"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.BrdId.Member.ACR.ServiceInstance, [], name, value)


                        class Id(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	<1..8000>;;Service Instance Identifier
                            	**type**\: int
                            
                            	**range:** 1..8000
                            
                            .. attribute:: split_horizon
                            
                            	Configure this port as a member of a split horizon group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.BrdId.Member.ACR.ServiceInstance.Id, self).__init__()

                                self.yang_name = "id"
                                self.yang_parent_name = "service-instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ('split_horizon', (YLeaf(YType.empty, 'split-horizon'), ['Empty'])),
                                ])
                                self.id = None
                                self.split_horizon = None
                                self._segment_path = lambda: "id" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.BrdId.Member.ACR.ServiceInstance.Id, ['id', 'split_horizon'], name, value)


                class MemberInterface(Entity):
                    """
                    
                    
                    .. attribute:: interface  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: interface_id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\: int
                    
                    			**range:** 0..4294967295
                    
                    .. attribute:: service_instance
                    
                    	ethernt serivce instance
                    	**type**\: int
                    
                    	**range:** 1..8000
                    
                    .. attribute:: split_horizon
                    
                    	Configure this port as a member of a split horizon group
                    	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.BrdId.Member.MemberInterface.SplitHorizon>`
                    
                    

                    """

                    _prefix = 'ios-bd'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.BridgeDomain.BrdId.Member.MemberInterface, self).__init__()

                        self.yang_name = "member-interface"
                        self.yang_parent_name = "member"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface']
                        self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.BridgeDomain.BrdId.Member.MemberInterface.SplitHorizon))])
                        self._leafs = OrderedDict([
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str','int'])),
                            ('service_instance', (YLeaf(YType.uint32, 'service-instance'), ['int'])),
                        ])
                        self.interface = None
                        self.interface_id = None
                        self.service_instance = None

                        self.split_horizon = Native.BridgeDomain.BrdId.Member.MemberInterface.SplitHorizon()
                        self.split_horizon.parent = self
                        self._children_name_map["split_horizon"] = "split-horizon"
                        self._segment_path = lambda: "member-interface" + "[interface='" + str(self.interface) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.BridgeDomain.BrdId.Member.MemberInterface, ['interface', 'interface_id', 'service_instance'], name, value)


                    class SplitHorizon(Entity):
                        """
                        Configure this port as a member of a split horizon group
                        
                        .. attribute:: group
                        
                        	Split\-horizon group
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.BrdId.Member.MemberInterface.SplitHorizon, self).__init__()

                            self.yang_name = "split-horizon"
                            self.yang_parent_name = "member-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                            ])
                            self.group = None
                            self._segment_path = lambda: "split-horizon"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.BrdId.Member.MemberInterface.SplitHorizon, ['group'], name, value)


        class CMac(Entity):
            """
            Configure c\-mac global commands
            
            .. attribute:: aging_time
            
            	Configure aging time for c\-mac bridge domains
            	**type**\: int
            
            	**range:** 30..3600
            
            

            """

            _prefix = 'ios-bd'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.BridgeDomain.CMac, self).__init__()

                self.yang_name = "c-mac"
                self.yang_parent_name = "bridge-domain"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('aging_time', (YLeaf(YType.uint16, 'aging-time'), ['int'])),
                ])
                self.aging_time = None
                self._segment_path = lambda: "Cisco-IOS-XE-bridge-domain:c-mac"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.BridgeDomain.CMac, ['aging_time'], name, value)


        class Otv(Entity):
            """
            Configure overlay bridge domains
            
            .. attribute:: default
            
            	Change default setting of overlay bridge domains
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Otv.Default>`
            
            

            """

            _prefix = 'ios-bd'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.BridgeDomain.Otv, self).__init__()

                self.yang_name = "otv"
                self.yang_parent_name = "bridge-domain"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("default", ("default", Native.BridgeDomain.Otv.Default))])
                self._leafs = OrderedDict()

                self.default = Native.BridgeDomain.Otv.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"
                self._segment_path = lambda: "Cisco-IOS-XE-bridge-domain:otv"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.BridgeDomain.Otv, [], name, value)


            class Default(Entity):
                """
                Change default setting of overlay bridge domains
                
                .. attribute:: age_time
                
                	Configure default mac aging time of overlay bridge domains
                	**type**\: int
                
                	**range:** 30..3600
                
                

                """

                _prefix = 'ios-bd'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.BridgeDomain.Otv.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "otv"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('age_time', (YLeaf(YType.uint16, 'age-time'), ['int'])),
                    ])
                    self.age_time = None
                    self._segment_path = lambda: "default"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:otv/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.BridgeDomain.Otv.Default, ['age_time'], name, value)


        class Parameterized(Entity):
            """
            bridge\-domain is derived from parameters
            
            .. attribute:: vlan
            
            	bridge\-domain from service instance vlan
            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios-bd'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.BridgeDomain.Parameterized, self).__init__()

                self.yang_name = "parameterized"
                self.yang_parent_name = "bridge-domain"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vlan", ("vlan", Native.BridgeDomain.Parameterized.Vlan))])
                self._leafs = OrderedDict()

                self.vlan = None
                self._children_name_map["vlan"] = "vlan"
                self._segment_path = lambda: "Cisco-IOS-XE-bridge-domain:parameterized"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.BridgeDomain.Parameterized, [], name, value)


            class Vlan(Entity):
                """
                bridge\-domain from service instance vlan
                
                .. attribute:: ip
                
                	IP related commands
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Ip>`
                
                .. attribute:: mac
                
                	MAC Address related commands
                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Mac>`
                
                .. attribute:: member
                
                	bridge\-domain member
                	**type**\:  :py:class:`Member <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Member>`
                
                .. attribute:: shutdown
                
                	Take the bridge domain admin down
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-bd'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.BridgeDomain.Parameterized.Vlan, self).__init__()

                    self.yang_name = "vlan"
                    self.yang_parent_name = "parameterized"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.BridgeDomain.Parameterized.Vlan.Ip)), ("mac", ("mac", Native.BridgeDomain.Parameterized.Vlan.Mac)), ("member", ("member", Native.BridgeDomain.Parameterized.Vlan.Member))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ])
                    self.shutdown = None

                    self.ip = Native.BridgeDomain.Parameterized.Vlan.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.mac = Native.BridgeDomain.Parameterized.Vlan.Mac()
                    self.mac.parent = self
                    self._children_name_map["mac"] = "mac"

                    self.member = Native.BridgeDomain.Parameterized.Vlan.Member()
                    self.member.parent = self
                    self._children_name_map["member"] = "member"
                    self._segment_path = lambda: "vlan"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan, ['shutdown'], name, value)


                class Ip(Entity):
                    """
                    IP related commands
                    
                    .. attribute:: igmp
                    
                    	IP igmp commands
                    	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp>`
                    
                    

                    """

                    _prefix = 'ios-bd'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.BridgeDomain.Parameterized.Vlan.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "vlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("igmp", ("igmp", Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp))])
                        self._leafs = OrderedDict()

                        self.igmp = Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp()
                        self.igmp.parent = self
                        self._children_name_map["igmp"] = "igmp"
                        self._segment_path = lambda: "ip"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Ip, [], name, value)


                    class Igmp(Entity):
                        """
                        IP igmp commands
                        
                        .. attribute:: snooping
                        
                        	IP igmp snooping commands
                        	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp, self).__init__()

                            self.yang_name = "igmp"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("snooping", ("snooping", Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping))])
                            self._leafs = OrderedDict()

                            self.snooping = None
                            self._children_name_map["snooping"] = "snooping"
                            self._segment_path = lambda: "igmp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/ip/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp, [], name, value)


                        class Snooping(Entity):
                            """
                            IP igmp snooping commands
                            
                            .. attribute:: check
                            
                            	enforce TTL or Rtr\-Alert Option checking
                            	**type**\:  :py:class:`Check <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Check>`
                            
                            .. attribute:: explicit_tracking
                            
                            	IGMP explicit host tracking configuration
                            	**type**\:  :py:class:`ExplicitTracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.ExplicitTracking>`
                            
                            .. attribute:: immediate_leave
                            
                            	Enable IGMPv2 immediate leave processing
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: last_member_query_count
                            
                            	Last member query count
                            	**type**\: int
                            
                            	**range:** 1..7
                            
                            .. attribute:: last_member_query_interval
                            
                            	Last member query interval
                            	**type**\: int
                            
                            	**range:** 100..32767
                            
                            .. attribute:: mrouter
                            
                            	Configure an L2 port as a multicast router port
                            	**type**\:  :py:class:`Mrouter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Mrouter>`
                            
                            .. attribute:: querier
                            
                            	Enable IGMP querier for this Bdomain
                            	**type**\:  :py:class:`Querier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Querier>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: report_suppression
                            
                            	Enable IGMP report suppression
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: robustness_variable
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..3
                            
                            .. attribute:: static
                            
                            	Configure an L2 port as a member of a group
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping, self).__init__()

                                self.yang_name = "snooping"
                                self.yang_parent_name = "igmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("check", ("check", Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Check)), ("explicit-tracking", ("explicit_tracking", Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.ExplicitTracking)), ("mrouter", ("mrouter", Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Mrouter)), ("querier", ("querier", Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Querier))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('immediate_leave', (YLeaf(YType.empty, 'immediate-leave'), ['Empty'])),
                                    ('last_member_query_count', (YLeaf(YType.uint8, 'last-member-query-count'), ['int'])),
                                    ('last_member_query_interval', (YLeaf(YType.uint16, 'last-member-query-interval'), ['int'])),
                                    ('report_suppression', (YLeaf(YType.empty, 'report-suppression'), ['Empty'])),
                                    ('robustness_variable', (YLeaf(YType.uint8, 'robustness-variable'), ['int'])),
                                    ('static', (YLeaf(YType.str, 'static'), ['str'])),
                                ])
                                self.immediate_leave = None
                                self.last_member_query_count = None
                                self.last_member_query_interval = None
                                self.report_suppression = None
                                self.robustness_variable = None
                                self.static = None

                                self.check = Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Check()
                                self.check.parent = self
                                self._children_name_map["check"] = "check"

                                self.explicit_tracking = Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.ExplicitTracking()
                                self.explicit_tracking.parent = self
                                self._children_name_map["explicit_tracking"] = "explicit-tracking"

                                self.mrouter = Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Mrouter()
                                self.mrouter.parent = self
                                self._children_name_map["mrouter"] = "mrouter"

                                self.querier = None
                                self._children_name_map["querier"] = "querier"
                                self._segment_path = lambda: "snooping"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/ip/igmp/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping, ['immediate_leave', 'last_member_query_count', 'last_member_query_interval', 'report_suppression', 'robustness_variable', 'static'], name, value)


                            class Check(Entity):
                                """
                                enforce TTL or Rtr\-Alert Option checking
                                
                                .. attribute:: rtr_alert_option
                                
                                	Only accept IGMP packets with router\-alert option
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ttl
                                
                                	Only accept IGMP packets with TTL=1
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bd'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Check, self).__init__()

                                    self.yang_name = "check"
                                    self.yang_parent_name = "snooping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rtr_alert_option', (YLeaf(YType.empty, 'rtr-alert-option'), ['Empty'])),
                                        ('ttl', (YLeaf(YType.empty, 'ttl'), ['Empty'])),
                                    ])
                                    self.rtr_alert_option = None
                                    self.ttl = None
                                    self._segment_path = lambda: "check"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/ip/igmp/snooping/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Check, ['rtr_alert_option', 'ttl'], name, value)


                            class ExplicitTracking(Entity):
                                """
                                IGMP explicit host tracking configuration
                                
                                .. attribute:: limit
                                
                                	Explicit Host Tracking DB limit
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bd'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.ExplicitTracking, self).__init__()

                                    self.yang_name = "explicit-tracking"
                                    self.yang_parent_name = "snooping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.empty, 'limit'), ['Empty'])),
                                    ])
                                    self.limit = None
                                    self._segment_path = lambda: "explicit-tracking"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/ip/igmp/snooping/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.ExplicitTracking, ['limit'], name, value)


                            class Mrouter(Entity):
                                """
                                Configure an L2 port as a multicast router port
                                
                                .. attribute:: interface
                                
                                	next\-hop interface to mrouter
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bd'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Mrouter, self).__init__()

                                    self.yang_name = "mrouter"
                                    self.yang_parent_name = "snooping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                                    ])
                                    self.interface = None
                                    self._segment_path = lambda: "mrouter"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/ip/igmp/snooping/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Mrouter, ['interface'], name, value)


                            class Querier(Entity):
                                """
                                Enable IGMP querier for this Bdomain
                                
                                .. attribute:: address
                                
                                	IGMP querier source IP address
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_response_time
                                
                                	IGMP querier maximum response time (sec)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: query_interval
                                
                                	IGMP querier query interval (sec)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: tcn
                                
                                	IGMP querier TCN related parameters
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: timer
                                
                                	IGMP other querier timer
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: version
                                
                                	IGMP version
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bd'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Querier, self).__init__()

                                    self.yang_name = "querier"
                                    self.yang_parent_name = "snooping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                        ('max_response_time', (YLeaf(YType.empty, 'max-response-time'), ['Empty'])),
                                        ('query_interval', (YLeaf(YType.empty, 'query-interval'), ['Empty'])),
                                        ('tcn', (YLeaf(YType.empty, 'tcn'), ['Empty'])),
                                        ('timer', (YLeaf(YType.empty, 'timer'), ['Empty'])),
                                        ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self.max_response_time = None
                                    self.query_interval = None
                                    self.tcn = None
                                    self.timer = None
                                    self.version = None
                                    self._segment_path = lambda: "querier"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/ip/igmp/snooping/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Ip.Igmp.Snooping.Querier, ['address', 'max_response_time', 'query_interval', 'tcn', 'timer', 'version'], name, value)


                class Mac(Entity):
                    """
                    MAC Address related commands
                    
                    .. attribute:: aging_time
                    
                    	Set age time of mac addresses per bridge domain
                    	**type**\: int
                    
                    	**range:** 30..3600
                    
                    .. attribute:: learning
                    
                    	Disable mac learning on bridge domain
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: limit
                    
                    	Limit the MAC Addresses learnt
                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Mac.Limit>`
                    
                    

                    """

                    _prefix = 'ios-bd'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.BridgeDomain.Parameterized.Vlan.Mac, self).__init__()

                        self.yang_name = "mac"
                        self.yang_parent_name = "vlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("limit", ("limit", Native.BridgeDomain.Parameterized.Vlan.Mac.Limit))])
                        self._leafs = OrderedDict([
                            ('aging_time', (YLeaf(YType.uint16, 'aging-time'), ['int'])),
                            ('learning', (YLeaf(YType.empty, 'learning'), ['Empty'])),
                        ])
                        self.aging_time = None
                        self.learning = None

                        self.limit = Native.BridgeDomain.Parameterized.Vlan.Mac.Limit()
                        self.limit.parent = self
                        self._children_name_map["limit"] = "limit"
                        self._segment_path = lambda: "mac"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Mac, ['aging_time', 'learning'], name, value)


                    class Limit(Entity):
                        """
                        Limit the MAC Addresses learnt
                        
                        .. attribute:: action
                        
                        	action when exceeding the limit
                        	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Action>`
                        
                        .. attribute:: maximum
                        
                        	Maximum
                        	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Maximum>`
                        
                        

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.Parameterized.Vlan.Mac.Limit, self).__init__()

                            self.yang_name = "limit"
                            self.yang_parent_name = "mac"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("action", ("action", Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Action)), ("maximum", ("maximum", Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Maximum))])
                            self._leafs = OrderedDict()

                            self.action = Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"

                            self.maximum = Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Maximum()
                            self.maximum.parent = self
                            self._children_name_map["maximum"] = "maximum"
                            self._segment_path = lambda: "limit"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/mac/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Mac.Limit, [], name, value)


                        class Action(Entity):
                            """
                            action when exceeding the limit
                            
                            .. attribute:: flooding
                            
                            	Mac flooding
                            	**type**\:  :py:class:`Flooding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Action.Flooding>`
                            
                            

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Action, self).__init__()

                                self.yang_name = "action"
                                self.yang_parent_name = "limit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("flooding", ("flooding", Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Action.Flooding))])
                                self._leafs = OrderedDict()

                                self.flooding = Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Action.Flooding()
                                self.flooding.parent = self
                                self._children_name_map["flooding"] = "flooding"
                                self._segment_path = lambda: "action"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/mac/limit/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Action, [], name, value)


                            class Flooding(Entity):
                                """
                                Mac flooding
                                
                                .. attribute:: disable
                                
                                	disable
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bd'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Action.Flooding, self).__init__()

                                    self.yang_name = "flooding"
                                    self.yang_parent_name = "action"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self._segment_path = lambda: "flooding"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/mac/limit/action/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Action.Flooding, ['disable'], name, value)


                        class Maximum(Entity):
                            """
                            Maximum
                            
                            .. attribute:: addresses
                            
                            	Addresses
                            	**type**\: int
                            
                            	**range:** 1..65536
                            
                            

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Maximum, self).__init__()

                                self.yang_name = "maximum"
                                self.yang_parent_name = "limit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('addresses', (YLeaf(YType.uint32, 'addresses'), ['int'])),
                                ])
                                self.addresses = None
                                self._segment_path = lambda: "maximum"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/mac/limit/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Mac.Limit.Maximum, ['addresses'], name, value)


                class Member(Entity):
                    """
                    bridge\-domain member
                    
                    .. attribute:: mem_ipv4
                    
                    	
                    	**type**\: list of  		 :py:class:`MemIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4>`
                    
                    .. attribute:: acr
                    
                    	
                    	**type**\: list of  		 :py:class:`ACR <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Member.ACR>`
                    
                    .. attribute:: analysis_module
                    
                    	Cisco network analysis service module
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: fcpa
                    
                    	Fiber Channel
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: sbc
                    
                    	Session Border Controller
                    	**type**\: int
                    
                    	**range:** 0..2147483647
                    
                    .. attribute:: sonet_acr
                    
                    	Virtual SONET\-ACR controller
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: y_controller
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: service_engine
                    
                    	Cisco service engine module
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: tunnel_tp
                    
                    	MPLS Transport Profile interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vpn
                    
                    	VPN interface
                    	**type**\: int
                    
                    	**range:** 0..2147483647
                    
                    .. attribute:: virtual_tokenring
                    
                    	Virtual TokenRing
                    	**type**\: int
                    
                    	**range:** 0..2147483647
                    
                    .. attribute:: ucse
                    
                    	Cisco ucse server
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: vasileft
                    
                    	VasiLeft interface
                    	**type**\: int
                    
                    	**range:** 1..2000
                    
                    .. attribute:: vasiright
                    
                    	VasiRight interface
                    	**type**\: int
                    
                    	**range:** 1..2000
                    
                    .. attribute:: vfi
                    
                    	Enter VFI name
                    	**type**\: str
                    
                    .. attribute:: vni
                    
                    	
                    	**type**\: int
                    
                    	**range:** 4096..16777215
                    
                    .. attribute:: member_interface
                    
                    	
                    	**type**\: list of  		 :py:class:`MemberInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Member.MemberInterface>`
                    
                    

                    """

                    _prefix = 'ios-bd'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.BridgeDomain.Parameterized.Vlan.Member, self).__init__()

                        self.yang_name = "member"
                        self.yang_parent_name = "vlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mem-ipv4", ("mem_ipv4", Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4)), ("ACR", ("acr", Native.BridgeDomain.Parameterized.Vlan.Member.ACR)), ("member-interface", ("member_interface", Native.BridgeDomain.Parameterized.Vlan.Member.MemberInterface))])
                        self._leafs = OrderedDict([
                            ('analysis_module', (YLeaf(YType.uint8, 'Analysis-Module'), ['int'])),
                            ('fcpa', (YLeaf(YType.uint8, 'Fcpa'), ['int'])),
                            ('sbc', (YLeaf(YType.uint32, 'SBC'), ['int'])),
                            ('sonet_acr', (YLeaf(YType.uint8, 'SONET_ACR'), ['int'])),
                            ('y_controller', (YLeaf(YType.str, '_controller'), ['str'])),
                            ('service_engine', (YLeaf(YType.uint8, 'Service-Engine'), ['int'])),
                            ('tunnel_tp', (YLeaf(YType.uint16, 'Tunnel-tp'), ['int'])),
                            ('vpn', (YLeaf(YType.uint32, 'VPN'), ['int'])),
                            ('virtual_tokenring', (YLeaf(YType.uint32, 'Virtual-TokenRing'), ['int'])),
                            ('ucse', (YLeaf(YType.uint8, 'ucse'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ('vfi', (YLeaf(YType.str, 'vfi'), ['str'])),
                            ('vni', (YLeaf(YType.uint32, 'vni'), ['int'])),
                        ])
                        self.analysis_module = None
                        self.fcpa = None
                        self.sbc = None
                        self.sonet_acr = None
                        self.y_controller = None
                        self.service_engine = None
                        self.tunnel_tp = None
                        self.vpn = None
                        self.virtual_tokenring = None
                        self.ucse = None
                        self.vasileft = None
                        self.vasiright = None
                        self.vfi = None
                        self.vni = None

                        self.mem_ipv4 = YList(self)
                        self.acr = YList(self)
                        self.member_interface = YList(self)
                        self._segment_path = lambda: "member"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Member, ['analysis_module', 'fcpa', 'sbc', 'sonet_acr', 'y_controller', 'service_engine', 'tunnel_tp', 'vpn', 'virtual_tokenring', 'ucse', 'vasileft', 'vasiright', 'vfi', 'vni'], name, value)


                    class MemIpv4(Entity):
                        """
                        
                        
                        .. attribute:: mem_ipv4  (key)
                        
                        	IP address of the peer
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mem_vcid
                        
                        	
                        	**type**\: list of  		 :py:class:`MemVcid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid>`
                        
                        .. attribute:: encapsulation
                        
                        	Data encapsulation method
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.Encapsulation>`
                        
                        .. attribute:: template
                        
                        	Template to use for encapsulation and protocol configuration
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4, self).__init__()

                            self.yang_name = "mem-ipv4"
                            self.yang_parent_name = "member"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['mem_ipv4']
                            self._child_classes = OrderedDict([("mem-vcid", ("mem_vcid", Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid)), ("encapsulation", ("encapsulation", Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.Encapsulation))])
                            self._leafs = OrderedDict([
                                ('mem_ipv4', (YLeaf(YType.str, 'mem-ipv4'), ['str'])),
                                ('template', (YLeaf(YType.str, 'template'), ['str'])),
                            ])
                            self.mem_ipv4 = None
                            self.template = None

                            self.encapsulation = Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.mem_vcid = YList(self)
                            self._segment_path = lambda: "mem-ipv4" + "[mem-ipv4='" + str(self.mem_ipv4) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/member/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4, ['mem_ipv4', 'template'], name, value)


                        class MemVcid(Entity):
                            """
                            
                            
                            .. attribute:: mem_vcid  (key)
                            
                            	<1..4294967295>;;Enter VC ID value
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: encapsulation
                            
                            	Data encapsulation method
                            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid.Encapsulation>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: template
                            
                            	Template to use for encapsulation and protocol configuration
                            	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid.Template>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid, self).__init__()

                                self.yang_name = "mem-vcid"
                                self.yang_parent_name = "mem-ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['mem_vcid']
                                self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid.Encapsulation)), ("template", ("template", Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid.Template))])
                                self._leafs = OrderedDict([
                                    ('mem_vcid', (YLeaf(YType.uint32, 'mem-vcid'), ['int'])),
                                ])
                                self.mem_vcid = None

                                self.encapsulation = None
                                self._children_name_map["encapsulation"] = "encapsulation"

                                self.template = None
                                self._children_name_map["template"] = "template"
                                self._segment_path = lambda: "mem-vcid" + "[mem-vcid='" + str(self.mem_vcid) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid, ['mem_vcid'], name, value)


                            class Encapsulation(Entity):
                                """
                                Data encapsulation method
                                
                                .. attribute:: mpls
                                
                                	Use MPLS encapsulation
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bd'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid.Encapsulation, self).__init__()

                                    self.yang_name = "encapsulation"
                                    self.yang_parent_name = "mem-vcid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                    ])
                                    self.mpls = None
                                    self._segment_path = lambda: "encapsulation"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid.Encapsulation, ['mpls'], name, value)


                            class Template(Entity):
                                """
                                Template to use for encapsulation and protocol configuration
                                
                                .. attribute:: template
                                
                                	<WORD>;;template name (Max size 32)
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bd'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid.Template, self).__init__()

                                    self.yang_name = "template"
                                    self.yang_parent_name = "mem-vcid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('template', (YLeaf(YType.str, 'template'), ['str'])),
                                    ])
                                    self.template = None
                                    self._segment_path = lambda: "template"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.MemVcid.Template, ['template'], name, value)


                        class Encapsulation(Entity):
                            """
                            Data encapsulation method
                            
                            .. attribute:: mpls
                            
                            	Use MPLS encapsulation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "mem-ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                ])
                                self.mpls = None
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Member.MemIpv4.Encapsulation, ['mpls'], name, value)


                    class ACR(Entity):
                        """
                        
                        
                        .. attribute:: acr_int  (key)
                        
                        	<WORD>;;Virtual ACR interface
                        	**type**\: str
                        
                        .. attribute:: service_instance
                        
                        	ethernt serivce instance
                        	**type**\:  :py:class:`ServiceInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Member.ACR.ServiceInstance>`
                        
                        

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.Parameterized.Vlan.Member.ACR, self).__init__()

                            self.yang_name = "ACR"
                            self.yang_parent_name = "member"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['acr_int']
                            self._child_classes = OrderedDict([("service-instance", ("service_instance", Native.BridgeDomain.Parameterized.Vlan.Member.ACR.ServiceInstance))])
                            self._leafs = OrderedDict([
                                ('acr_int', (YLeaf(YType.str, 'acr-int'), ['str'])),
                            ])
                            self.acr_int = None

                            self.service_instance = Native.BridgeDomain.Parameterized.Vlan.Member.ACR.ServiceInstance()
                            self.service_instance.parent = self
                            self._children_name_map["service_instance"] = "service-instance"
                            self._segment_path = lambda: "ACR" + "[acr-int='" + str(self.acr_int) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/member/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Member.ACR, ['acr_int'], name, value)


                        class ServiceInstance(Entity):
                            """
                            ethernt serivce instance
                            
                            .. attribute:: id
                            
                            	
                            	**type**\: list of  		 :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Member.ACR.ServiceInstance.Id>`
                            
                            

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.Parameterized.Vlan.Member.ACR.ServiceInstance, self).__init__()

                                self.yang_name = "service-instance"
                                self.yang_parent_name = "ACR"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("id", ("id", Native.BridgeDomain.Parameterized.Vlan.Member.ACR.ServiceInstance.Id))])
                                self._leafs = OrderedDict()

                                self.id = YList(self)
                                self._segment_path = lambda: "service-instance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Member.ACR.ServiceInstance, [], name, value)


                            class Id(Entity):
                                """
                                
                                
                                .. attribute:: id  (key)
                                
                                	<1..8000>;;Service Instance Identifier
                                	**type**\: int
                                
                                	**range:** 1..8000
                                
                                .. attribute:: split_horizon
                                
                                	Configure this port as a member of a split horizon group
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bd'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.BridgeDomain.Parameterized.Vlan.Member.ACR.ServiceInstance.Id, self).__init__()

                                    self.yang_name = "id"
                                    self.yang_parent_name = "service-instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ('split_horizon', (YLeaf(YType.empty, 'split-horizon'), ['Empty'])),
                                    ])
                                    self.id = None
                                    self.split_horizon = None
                                    self._segment_path = lambda: "id" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Member.ACR.ServiceInstance.Id, ['id', 'split_horizon'], name, value)


                    class MemberInterface(Entity):
                        """
                        
                        
                        .. attribute:: interface  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: interface_id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        .. attribute:: service_instance
                        
                        	ethernt serivce instance
                        	**type**\: int
                        
                        	**range:** 1..8000
                        
                        .. attribute:: split_horizon
                        
                        	Configure this port as a member of a split horizon group
                        	**type**\:  :py:class:`SplitHorizon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BridgeDomain.Parameterized.Vlan.Member.MemberInterface.SplitHorizon>`
                        
                        

                        """

                        _prefix = 'ios-bd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.BridgeDomain.Parameterized.Vlan.Member.MemberInterface, self).__init__()

                            self.yang_name = "member-interface"
                            self.yang_parent_name = "member"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['interface']
                            self._child_classes = OrderedDict([("split-horizon", ("split_horizon", Native.BridgeDomain.Parameterized.Vlan.Member.MemberInterface.SplitHorizon))])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str','int'])),
                                ('service_instance', (YLeaf(YType.uint32, 'service-instance'), ['int'])),
                            ])
                            self.interface = None
                            self.interface_id = None
                            self.service_instance = None

                            self.split_horizon = Native.BridgeDomain.Parameterized.Vlan.Member.MemberInterface.SplitHorizon()
                            self.split_horizon.parent = self
                            self._children_name_map["split_horizon"] = "split-horizon"
                            self._segment_path = lambda: "member-interface" + "[interface='" + str(self.interface) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bridge-domain/Cisco-IOS-XE-bridge-domain:parameterized/vlan/member/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Member.MemberInterface, ['interface', 'interface_id', 'service_instance'], name, value)


                        class SplitHorizon(Entity):
                            """
                            Configure this port as a member of a split horizon group
                            
                            .. attribute:: group
                            
                            	Split\-horizon group
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-bd'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.BridgeDomain.Parameterized.Vlan.Member.MemberInterface.SplitHorizon, self).__init__()

                                self.yang_name = "split-horizon"
                                self.yang_parent_name = "member-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.uint8, 'group'), ['int'])),
                                ])
                                self.group = None
                                self._segment_path = lambda: "split-horizon"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.BridgeDomain.Parameterized.Vlan.Member.MemberInterface.SplitHorizon, ['group'], name, value)


    class Crypto(Entity):
        """
        Encryption module
        
        .. attribute:: call
        
        	Configure Crypto Call Admission Control
        	**type**\:  :py:class:`Call <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Call>`
        
        .. attribute:: dynamic_map
        
        	Specify a dynamic crypto map template
        	**type**\: list of  		 :py:class:`DynamicMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap>`
        
        .. attribute:: engine
        
        	Enter a crypto engine configurable menu
        	**type**\:  :py:class:`Engine <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Engine>`
        
        .. attribute:: gdoi
        
        	Configure GKM (Group Key Management, GDOI or G\-IKEv2) Policy
        	**type**\:  :py:class:`Gdoi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi>`
        
        .. attribute:: ikev2
        
        	Configure IKEv2 Options
        	**type**\:  :py:class:`Ikev2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2>`
        
        .. attribute:: gkm
        
        	Configure GKM (Group Key Management, GDOI or G\-IKEv2) Policy
        	**type**\:  :py:class:`Gkm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm>`
        
        .. attribute:: identity
        
        	Enter a crypto identity list
        	**type**\: list of  		 :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Identity>`
        
        .. attribute:: ipsec
        
        	Configure IPSEC policy
        	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec>`
        
        .. attribute:: key
        
        	Long term key operations
        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key>`
        
        .. attribute:: keyring
        
        	Key ring commands
        	**type**\: list of  		 :py:class:`Keyring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring>`
        
        .. attribute:: isakmp
        
        	Configure ISAKMP policy
        	**type**\:  :py:class:`Isakmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp>`
        
        .. attribute:: logging
        
        	logging messages
        	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Logging>`
        
        .. attribute:: crypto_map
        
        	
        	**type**\:  :py:class:`CryptoMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap>`
        
        .. attribute:: map_ipv6_gdoi
        
        	
        	**type**\:  :py:class:`MapIpv6Gdoi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapIpv6Gdoi>`
        
        .. attribute:: map_client
        
        	
        	**type**\:  :py:class:`MapClient <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapClient>`
        
        .. attribute:: mib
        
        	Configure Crypto\-related MIB Parameters
        	**type**\:  :py:class:`Mib <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Mib>`
        
        .. attribute:: pki
        
        	Public Key components
        	**type**\:  :py:class:`Pki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki>`
        
        .. attribute:: tls_tunnel
        
        	
        	**type**\:  :py:class:`TlsTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel>`
        
        .. attribute:: ssl
        
        	Configure Crypto SSL Options
        	**type**\:  :py:class:`Ssl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ssl>`
        
        .. attribute:: vpn
        
        	Configure crypto vpn commands
        	**type**\:  :py:class:`Vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Vpn>`
        
        .. attribute:: xauth
        
        	X\-Auth parameters
        	**type**\: str
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Crypto, self).__init__()

            self.yang_name = "crypto"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-crypto:call", ("call", Native.Crypto.Call)), ("Cisco-IOS-XE-crypto:dynamic-map", ("dynamic_map", Native.Crypto.DynamicMap)), ("Cisco-IOS-XE-crypto:engine", ("engine", Native.Crypto.Engine)), ("Cisco-IOS-XE-crypto:gdoi", ("gdoi", Native.Crypto.Gdoi)), ("Cisco-IOS-XE-crypto:ikev2", ("ikev2", Native.Crypto.Ikev2)), ("Cisco-IOS-XE-crypto:gkm", ("gkm", Native.Crypto.Gkm)), ("Cisco-IOS-XE-crypto:identity", ("identity", Native.Crypto.Identity)), ("Cisco-IOS-XE-crypto:ipsec", ("ipsec", Native.Crypto.Ipsec)), ("Cisco-IOS-XE-crypto:key", ("key", Native.Crypto.Key)), ("Cisco-IOS-XE-crypto:keyring", ("keyring", Native.Crypto.Keyring)), ("Cisco-IOS-XE-crypto:isakmp", ("isakmp", Native.Crypto.Isakmp)), ("Cisco-IOS-XE-crypto:logging", ("logging", Native.Crypto.Logging)), ("Cisco-IOS-XE-crypto:crypto-map", ("crypto_map", Native.Crypto.CryptoMap)), ("Cisco-IOS-XE-crypto:map-ipv6-gdoi", ("map_ipv6_gdoi", Native.Crypto.MapIpv6Gdoi)), ("Cisco-IOS-XE-crypto:map-client", ("map_client", Native.Crypto.MapClient)), ("Cisco-IOS-XE-crypto:mib", ("mib", Native.Crypto.Mib)), ("Cisco-IOS-XE-crypto:pki", ("pki", Native.Crypto.Pki)), ("Cisco-IOS-XE-crypto:tls-tunnel", ("tls_tunnel", Native.Crypto.TlsTunnel)), ("Cisco-IOS-XE-crypto:ssl", ("ssl", Native.Crypto.Ssl)), ("Cisco-IOS-XE-crypto:vpn", ("vpn", Native.Crypto.Vpn))])
            self._leafs = OrderedDict([
                ('xauth', (YLeaf(YType.str, 'Cisco-IOS-XE-crypto:xauth'), ['str'])),
            ])
            self.xauth = None

            self.call = Native.Crypto.Call()
            self.call.parent = self
            self._children_name_map["call"] = "Cisco-IOS-XE-crypto:call"

            self.engine = Native.Crypto.Engine()
            self.engine.parent = self
            self._children_name_map["engine"] = "Cisco-IOS-XE-crypto:engine"

            self.gdoi = Native.Crypto.Gdoi()
            self.gdoi.parent = self
            self._children_name_map["gdoi"] = "Cisco-IOS-XE-crypto:gdoi"

            self.ikev2 = Native.Crypto.Ikev2()
            self.ikev2.parent = self
            self._children_name_map["ikev2"] = "Cisco-IOS-XE-crypto:ikev2"

            self.gkm = Native.Crypto.Gkm()
            self.gkm.parent = self
            self._children_name_map["gkm"] = "Cisco-IOS-XE-crypto:gkm"

            self.ipsec = Native.Crypto.Ipsec()
            self.ipsec.parent = self
            self._children_name_map["ipsec"] = "Cisco-IOS-XE-crypto:ipsec"

            self.key = Native.Crypto.Key()
            self.key.parent = self
            self._children_name_map["key"] = "Cisco-IOS-XE-crypto:key"

            self.isakmp = Native.Crypto.Isakmp()
            self.isakmp.parent = self
            self._children_name_map["isakmp"] = "Cisco-IOS-XE-crypto:isakmp"

            self.logging = Native.Crypto.Logging()
            self.logging.parent = self
            self._children_name_map["logging"] = "Cisco-IOS-XE-crypto:logging"

            self.crypto_map = Native.Crypto.CryptoMap()
            self.crypto_map.parent = self
            self._children_name_map["crypto_map"] = "Cisco-IOS-XE-crypto:crypto-map"

            self.map_ipv6_gdoi = Native.Crypto.MapIpv6Gdoi()
            self.map_ipv6_gdoi.parent = self
            self._children_name_map["map_ipv6_gdoi"] = "Cisco-IOS-XE-crypto:map-ipv6-gdoi"

            self.map_client = Native.Crypto.MapClient()
            self.map_client.parent = self
            self._children_name_map["map_client"] = "Cisco-IOS-XE-crypto:map-client"

            self.mib = Native.Crypto.Mib()
            self.mib.parent = self
            self._children_name_map["mib"] = "Cisco-IOS-XE-crypto:mib"

            self.pki = Native.Crypto.Pki()
            self.pki.parent = self
            self._children_name_map["pki"] = "Cisco-IOS-XE-crypto:pki"

            self.tls_tunnel = Native.Crypto.TlsTunnel()
            self.tls_tunnel.parent = self
            self._children_name_map["tls_tunnel"] = "Cisco-IOS-XE-crypto:tls-tunnel"

            self.ssl = Native.Crypto.Ssl()
            self.ssl.parent = self
            self._children_name_map["ssl"] = "Cisco-IOS-XE-crypto:ssl"

            self.vpn = Native.Crypto.Vpn()
            self.vpn.parent = self
            self._children_name_map["vpn"] = "Cisco-IOS-XE-crypto:vpn"

            self.dynamic_map = YList(self)
            self.identity = YList(self)
            self.keyring = YList(self)
            self._segment_path = lambda: "crypto"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Crypto, ['xauth'], name, value)


        class Call(Entity):
            """
            Configure Crypto Call Admission Control
            
            .. attribute:: admission
            
            	Configure Crypto Call Admission Control
            	**type**\:  :py:class:`Admission <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Call.Admission>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Call, self).__init__()

                self.yang_name = "call"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("admission", ("admission", Native.Crypto.Call.Admission))])
                self._leafs = OrderedDict()

                self.admission = Native.Crypto.Call.Admission()
                self.admission.parent = self
                self._children_name_map["admission"] = "admission"
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:call"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Call, [], name, value)


            class Admission(Entity):
                """
                Configure Crypto Call Admission Control
                
                .. attribute:: limit
                
                	Configure Crypto Call Admission Control limits
                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Call.Admission.Limit>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Call.Admission, self).__init__()

                    self.yang_name = "admission"
                    self.yang_parent_name = "call"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("limit", ("limit", Native.Crypto.Call.Admission.Limit))])
                    self._leafs = OrderedDict()

                    self.limit = Native.Crypto.Call.Admission.Limit()
                    self.limit.parent = self
                    self._children_name_map["limit"] = "limit"
                    self._segment_path = lambda: "admission"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:call/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Call.Admission, [], name, value)


                class Limit(Entity):
                    """
                    Configure Crypto Call Admission Control limits
                    
                    .. attribute:: all
                    
                    	onfigure Crypto Call Admission Control total in\-negotiation SA limit
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Call.Admission.Limit.All>`
                    
                    .. attribute:: ike
                    
                    	Configure Crypto Call Admission Control active IKE SA limit
                    	**type**\:  :py:class:`Ike <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Call.Admission.Limit.Ike>`
                    
                    .. attribute:: ipsec
                    
                    	Configure Crypto Call Admission Control active IPSec SA limit
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Call.Admission.Limit.Ipsec>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Call.Admission.Limit, self).__init__()

                        self.yang_name = "limit"
                        self.yang_parent_name = "admission"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("all", ("all", Native.Crypto.Call.Admission.Limit.All)), ("ike", ("ike", Native.Crypto.Call.Admission.Limit.Ike)), ("ipsec", ("ipsec", Native.Crypto.Call.Admission.Limit.Ipsec))])
                        self._leafs = OrderedDict()

                        self.all = Native.Crypto.Call.Admission.Limit.All()
                        self.all.parent = self
                        self._children_name_map["all"] = "all"

                        self.ike = Native.Crypto.Call.Admission.Limit.Ike()
                        self.ike.parent = self
                        self._children_name_map["ike"] = "ike"

                        self.ipsec = Native.Crypto.Call.Admission.Limit.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"
                        self._segment_path = lambda: "limit"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:call/admission/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Call.Admission.Limit, [], name, value)


                    class All(Entity):
                        """
                        onfigure Crypto Call Admission Control total in\-negotiation SA limit
                        
                        .. attribute:: in_negotiation_sa
                        
                        	Maximum number of in\-negotiation SAs allowed
                        	**type**\: int
                        
                        	**range:** 10..99999
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Call.Admission.Limit.All, self).__init__()

                            self.yang_name = "all"
                            self.yang_parent_name = "limit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('in_negotiation_sa', (YLeaf(YType.uint32, 'in-negotiation-sa'), ['int'])),
                            ])
                            self.in_negotiation_sa = None
                            self._segment_path = lambda: "all"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:call/admission/limit/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Call.Admission.Limit.All, ['in_negotiation_sa'], name, value)


                    class Ike(Entity):
                        """
                        Configure Crypto Call Admission Control active IKE SA limit
                        
                        .. attribute:: in_negotiation_sa
                        
                        	Maximum number of in\-negotiation IKE SAs allowed
                        	**type**\: int
                        
                        	**range:** 10..99999
                        
                        .. attribute:: sa
                        
                        	Maximum active IKE SAs allowed
                        	**type**\: int
                        
                        	**range:** 0..99999
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Call.Admission.Limit.Ike, self).__init__()

                            self.yang_name = "ike"
                            self.yang_parent_name = "limit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('in_negotiation_sa', (YLeaf(YType.uint32, 'in-negotiation-sa'), ['int'])),
                                ('sa', (YLeaf(YType.uint32, 'sa'), ['int'])),
                            ])
                            self.in_negotiation_sa = None
                            self.sa = None
                            self._segment_path = lambda: "ike"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:call/admission/limit/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Call.Admission.Limit.Ike, ['in_negotiation_sa', 'sa'], name, value)


                    class Ipsec(Entity):
                        """
                        Configure Crypto Call Admission Control active IPSec SA limit
                        
                        .. attribute:: sa
                        
                        	Maximum active IPSec SAs allowed
                        	**type**\: int
                        
                        	**range:** 0..99999
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Call.Admission.Limit.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "limit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sa', (YLeaf(YType.uint32, 'sa'), ['int'])),
                            ])
                            self.sa = None
                            self._segment_path = lambda: "ipsec"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:call/admission/limit/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Call.Admission.Limit.Ipsec, ['sa'], name, value)


        class DynamicMap(Entity):
            """
            Specify a dynamic crypto map template
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: sequence  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: default
            
            	Set a command to its defaults
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default>`
            
            .. attribute:: description
            
            	Description of the crypto map statement policy
            	**type**\: str
            
            .. attribute:: dialer
            
            	Dialer related commands
            	**type**\:  :py:class:`Dialer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Dialer>`
            
            .. attribute:: match
            
            	Match values
            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Match>`
            
            .. attribute:: qos
            
            	Quality of Service related commands
            	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Qos>`
            
            .. attribute:: reverse_route
            
            	Reverse Route Injection
            	**type**\:  :py:class:`ReverseRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.ReverseRoute>`
            
            	**presence node**\: True
            
            .. attribute:: set
            
            	Set values for encryption/decryption
            	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.DynamicMap, self).__init__()

                self.yang_name = "dynamic-map"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name','sequence']
                self._child_classes = OrderedDict([("default", ("default", Native.Crypto.DynamicMap.Default)), ("dialer", ("dialer", Native.Crypto.DynamicMap.Dialer)), ("match", ("match", Native.Crypto.DynamicMap.Match)), ("qos", ("qos", Native.Crypto.DynamicMap.Qos)), ("reverse-route", ("reverse_route", Native.Crypto.DynamicMap.ReverseRoute)), ("set", ("set", Native.Crypto.DynamicMap.Set))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('sequence', (YLeaf(YType.uint16, 'sequence'), ['int'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                ])
                self.name = None
                self.sequence = None
                self.description = None

                self.default = Native.Crypto.DynamicMap.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.dialer = Native.Crypto.DynamicMap.Dialer()
                self.dialer.parent = self
                self._children_name_map["dialer"] = "dialer"

                self.match = Native.Crypto.DynamicMap.Match()
                self.match.parent = self
                self._children_name_map["match"] = "match"

                self.qos = Native.Crypto.DynamicMap.Qos()
                self.qos.parent = self
                self._children_name_map["qos"] = "qos"

                self.reverse_route = None
                self._children_name_map["reverse_route"] = "reverse-route"

                self.set = Native.Crypto.DynamicMap.Set()
                self.set.parent = self
                self._children_name_map["set"] = "set"
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:dynamic-map" + "[name='" + str(self.name) + "']" + "[sequence='" + str(self.sequence) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.DynamicMap, ['name', 'sequence', 'description'], name, value)


            class Default(Entity):
                """
                Set a command to its defaults
                
                .. attribute:: description
                
                	Description of the crypto map statement policy
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dialer
                
                	Dialer related commands
                	**type**\:  :py:class:`Dialer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Dialer>`
                
                .. attribute:: match
                
                	Match values
                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Match>`
                
                .. attribute:: qos
                
                	Quality of Service related commands
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Qos>`
                
                .. attribute:: reverse_route
                
                	Reverse Route Injection
                	**type**\:  :py:class:`ReverseRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.ReverseRoute>`
                
                	**presence node**\: True
                
                .. attribute:: set
                
                	Set values for encryption/decryption
                	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.DynamicMap.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "dynamic-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dialer", ("dialer", Native.Crypto.DynamicMap.Default.Dialer)), ("match", ("match", Native.Crypto.DynamicMap.Default.Match)), ("qos", ("qos", Native.Crypto.DynamicMap.Default.Qos)), ("reverse-route", ("reverse_route", Native.Crypto.DynamicMap.Default.ReverseRoute)), ("set", ("set", Native.Crypto.DynamicMap.Default.Set))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.empty, 'description'), ['Empty'])),
                    ])
                    self.description = None

                    self.dialer = Native.Crypto.DynamicMap.Default.Dialer()
                    self.dialer.parent = self
                    self._children_name_map["dialer"] = "dialer"

                    self.match = Native.Crypto.DynamicMap.Default.Match()
                    self.match.parent = self
                    self._children_name_map["match"] = "match"

                    self.qos = Native.Crypto.DynamicMap.Default.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"

                    self.reverse_route = None
                    self._children_name_map["reverse_route"] = "reverse-route"

                    self.set = Native.Crypto.DynamicMap.Default.Set()
                    self.set.parent = self
                    self._children_name_map["set"] = "set"
                    self._segment_path = lambda: "default"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.DynamicMap.Default, ['description'], name, value)


                class Dialer(Entity):
                    """
                    Dialer related commands
                    
                    .. attribute:: pre_classify
                    
                    	Enable dialer list classification before initiating IKE
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Default.Dialer, self).__init__()

                        self.yang_name = "dialer"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pre_classify', (YLeaf(YType.empty, 'pre-classify'), ['Empty'])),
                        ])
                        self.pre_classify = None
                        self._segment_path = lambda: "dialer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Default.Dialer, ['pre_classify'], name, value)


                class Match(Entity):
                    """
                    Match values
                    
                    .. attribute:: address
                    
                    	Match address of packets to encrypt
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Default.Match, self).__init__()

                        self.yang_name = "match"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "match"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Default.Match, ['address'], name, value)


                class Qos(Entity):
                    """
                    Quality of Service related commands
                    
                    .. attribute:: pre_classify
                    
                    	Enable QOS classification before packets are tunnel encapsulated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Default.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pre_classify', (YLeaf(YType.empty, 'pre-classify'), ['Empty'])),
                        ])
                        self.pre_classify = None
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Default.Qos, ['pre_classify'], name, value)


                class ReverseRoute(Entity):
                    """
                    Reverse Route Injection.
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Default.ReverseRoute, self).__init__()

                        self.yang_name = "reverse-route"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "reverse-route"
                        self._is_frozen = True


                class Set(Entity):
                    """
                    Set values for encryption/decryption
                    
                    .. attribute:: group
                    
                    	Set the san group parameters
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: identity
                    
                    	Identity restriction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ikev2_profile
                    
                    	Specify ikev2 Profile
                    	**type**\: str
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set.Ip>`
                    
                    .. attribute:: isakmp_profile
                    
                    	Specify isakmp Profile
                    	**type**\: str
                    
                    .. attribute:: nat
                    
                    	Set NAT translation
                    	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set.Nat>`
                    
                    .. attribute:: peer_container
                    
                    	
                    	**type**\:  :py:class:`PeerContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set.PeerContainer>`
                    
                    .. attribute:: pfs
                    
                    	Specify pfs settings
                    	**type**\:  :py:class:`Pfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set.Pfs>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: reverse_route
                    
                    	Reverse Route Injection
                    	**type**\:  :py:class:`ReverseRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set.ReverseRoute>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: security_association
                    
                    	Security association parameters
                    	**type**\:  :py:class:`SecurityAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set.SecurityAssociation>`
                    
                    .. attribute:: transform_set
                    
                    	Specify list of transform sets in priority order
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Default.Set, self).__init__()

                        self.yang_name = "set"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Crypto.DynamicMap.Default.Set.Ip)), ("nat", ("nat", Native.Crypto.DynamicMap.Default.Set.Nat)), ("peer-container", ("peer_container", Native.Crypto.DynamicMap.Default.Set.PeerContainer)), ("pfs", ("pfs", Native.Crypto.DynamicMap.Default.Set.Pfs)), ("reverse-route", ("reverse_route", Native.Crypto.DynamicMap.Default.Set.ReverseRoute)), ("security-association", ("security_association", Native.Crypto.DynamicMap.Default.Set.SecurityAssociation))])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.empty, 'group'), ['Empty'])),
                            ('identity', (YLeaf(YType.empty, 'identity'), ['Empty'])),
                            ('ikev2_profile', (YLeaf(YType.str, 'ikev2-profile'), ['str'])),
                            ('isakmp_profile', (YLeaf(YType.str, 'isakmp-profile'), ['str'])),
                            ('transform_set', (YLeaf(YType.empty, 'transform-set'), ['Empty'])),
                        ])
                        self.group = None
                        self.identity = None
                        self.ikev2_profile = None
                        self.isakmp_profile = None
                        self.transform_set = None

                        self.ip = Native.Crypto.DynamicMap.Default.Set.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.nat = Native.Crypto.DynamicMap.Default.Set.Nat()
                        self.nat.parent = self
                        self._children_name_map["nat"] = "nat"

                        self.peer_container = Native.Crypto.DynamicMap.Default.Set.PeerContainer()
                        self.peer_container.parent = self
                        self._children_name_map["peer_container"] = "peer-container"

                        self.pfs = None
                        self._children_name_map["pfs"] = "pfs"

                        self.reverse_route = None
                        self._children_name_map["reverse_route"] = "reverse-route"

                        self.security_association = Native.Crypto.DynamicMap.Default.Set.SecurityAssociation()
                        self.security_association.parent = self
                        self._children_name_map["security_association"] = "security-association"
                        self._segment_path = lambda: "set"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Default.Set, ['group', 'identity', 'ikev2_profile', 'isakmp_profile', 'transform_set'], name, value)


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: direction
                        
                        	
                        	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set.Ip.Direction>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Default.Set.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.DynamicMap.Default.Set.Ip.Direction')])),
                            ])
                            self.access_group = None
                            self.direction = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.DynamicMap.Default.Set.Ip, ['access_group', 'direction'], name, value)

                        class Direction(Enum):
                            """
                            Direction (Enum Class)

                            .. data:: in_ = 0

                            .. data:: out = 1

                            """

                            in_ = Enum.YLeaf(0, "in")

                            out = Enum.YLeaf(1, "out")



                    class Nat(Entity):
                        """
                        Set NAT translation
                        
                        .. attribute:: demux
                        
                        	Set NAT demultiplexing
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Default.Set.Nat, self).__init__()

                            self.yang_name = "nat"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('demux', (YLeaf(YType.empty, 'demux'), ['Empty'])),
                            ])
                            self.demux = None
                            self._segment_path = lambda: "nat"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.DynamicMap.Default.Set.Nat, ['demux'], name, value)


                    class PeerContainer(Entity):
                        """
                        
                        
                        .. attribute:: peer
                        
                        	Allowed Encryption/Decryption peer
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: default
                        
                        	Reset to default peer in list in the event of a failure
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Default.Set.PeerContainer, self).__init__()

                            self.yang_name = "peer-container"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('peer', (YLeaf(YType.str, 'peer'), ['str','str','str'])),
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.peer = None
                            self.default = None
                            self._segment_path = lambda: "peer-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.DynamicMap.Default.Set.PeerContainer, ['peer', 'default'], name, value)


                    class Pfs(Entity):
                        """
                        Specify pfs settings
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Default.Set.Pfs, self).__init__()

                            self.yang_name = "pfs"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "pfs"
                            self._is_frozen = True


                    class ReverseRoute(Entity):
                        """
                        Reverse Route Injection
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Default.Set.ReverseRoute, self).__init__()

                            self.yang_name = "reverse-route"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "reverse-route"
                            self._is_frozen = True


                    class SecurityAssociation(Entity):
                        """
                        Security association parameters
                        
                        .. attribute:: dfbit
                        
                        	Handling of encapsulated DF bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dummy
                        
                        	Enable transmitting dummy packets
                        	**type**\:  :py:class:`Dummy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Dummy>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ecn
                        
                        	Handling of ECN bit
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: idle_time_container
                        
                        	
                        	**type**\:  :py:class:`IdleTimeContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.IdleTimeContainer>`
                        
                        .. attribute:: lifetime
                        
                        	security association lifetime
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Lifetime>`
                        
                        .. attribute:: replay
                        
                        	Set replay checking
                        	**type**\:  :py:class:`Replay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Replay>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Default.Set.SecurityAssociation, self).__init__()

                            self.yang_name = "security-association"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dummy", ("dummy", Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Dummy)), ("idle-time-container", ("idle_time_container", Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.IdleTimeContainer)), ("lifetime", ("lifetime", Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Lifetime)), ("replay", ("replay", Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Replay))])
                            self._leafs = OrderedDict([
                                ('dfbit', (YLeaf(YType.empty, 'dfbit'), ['Empty'])),
                                ('ecn', (YLeaf(YType.empty, 'ecn'), ['Empty'])),
                            ])
                            self.dfbit = None
                            self.ecn = None

                            self.dummy = None
                            self._children_name_map["dummy"] = "dummy"

                            self.idle_time_container = Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.IdleTimeContainer()
                            self.idle_time_container.parent = self
                            self._children_name_map["idle_time_container"] = "idle-time-container"

                            self.lifetime = Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"

                            self.replay = Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Replay()
                            self.replay.parent = self
                            self._children_name_map["replay"] = "replay"
                            self._segment_path = lambda: "security-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.DynamicMap.Default.Set.SecurityAssociation, ['dfbit', 'ecn'], name, value)


                        class Dummy(Entity):
                            """
                            Enable transmitting dummy packets
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Dummy, self).__init__()

                                self.yang_name = "dummy"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "dummy"
                                self._is_frozen = True


                        class IdleTimeContainer(Entity):
                            """
                            
                            
                            .. attribute:: idle_time
                            
                            	Automatically delete IPSec SAs after a given idle period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: default
                            
                            	All SAs idle\-out reset to default peer
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.IdleTimeContainer, self).__init__()

                                self.yang_name = "idle-time-container"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('idle_time', (YLeaf(YType.empty, 'idle-time'), ['Empty'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ])
                                self.idle_time = None
                                self.default = None
                                self._segment_path = lambda: "idle-time-container"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.IdleTimeContainer, ['idle_time', 'default'], name, value)


                        class Lifetime(Entity):
                            """
                            security association lifetime
                            
                            .. attribute:: days
                            
                            	Time\-based key duration in days
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: kilobytes
                            
                            	Volume\-based key duration
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: seconds
                            
                            	Time\-based key duration in seconds
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('days', (YLeaf(YType.empty, 'days'), ['Empty'])),
                                    ('kilobytes', (YLeaf(YType.empty, 'kilobytes'), ['Empty'])),
                                    ('seconds', (YLeaf(YType.empty, 'seconds'), ['Empty'])),
                                ])
                                self.days = None
                                self.kilobytes = None
                                self.seconds = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Lifetime, ['days', 'kilobytes', 'seconds'], name, value)


                        class Replay(Entity):
                            """
                            Set replay checking.
                            
                            .. attribute:: disable
                            
                            	Disable replay checking
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: window_size
                            
                            	Set replay window size
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Replay, self).__init__()

                                self.yang_name = "replay"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('window_size', (YLeaf(YType.empty, 'window-size'), ['Empty'])),
                                ])
                                self.disable = None
                                self.window_size = None
                                self._segment_path = lambda: "replay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.DynamicMap.Default.Set.SecurityAssociation.Replay, ['disable', 'window_size'], name, value)


            class Dialer(Entity):
                """
                Dialer related commands
                
                .. attribute:: pre_classify
                
                	Enable dialer list classification before initiating IKE
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.DynamicMap.Dialer, self).__init__()

                    self.yang_name = "dialer"
                    self.yang_parent_name = "dynamic-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('pre_classify', (YLeaf(YType.empty, 'pre-classify'), ['Empty'])),
                    ])
                    self.pre_classify = None
                    self._segment_path = lambda: "dialer"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.DynamicMap.Dialer, ['pre_classify'], name, value)


            class Match(Entity):
                """
                Match values
                
                .. attribute:: address
                
                	Match address of packets to encrypt
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 100..199
                
                		**type**\: int
                
                			**range:** 2000..2699
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.DynamicMap.Match, self).__init__()

                    self.yang_name = "match"
                    self.yang_parent_name = "dynamic-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['int','int','str'])),
                    ])
                    self.address = None
                    self._segment_path = lambda: "match"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.DynamicMap.Match, ['address'], name, value)


            class Qos(Entity):
                """
                Quality of Service related commands
                
                .. attribute:: pre_classify
                
                	Enable QOS classification before packets are tunnel encapsulated
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.DynamicMap.Qos, self).__init__()

                    self.yang_name = "qos"
                    self.yang_parent_name = "dynamic-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('pre_classify', (YLeaf(YType.empty, 'pre-classify'), ['Empty'])),
                    ])
                    self.pre_classify = None
                    self._segment_path = lambda: "qos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.DynamicMap.Qos, ['pre_classify'], name, value)


            class ReverseRoute(Entity):
                """
                Reverse Route Injection.
                
                .. attribute:: remote_peer_conatiner
                
                	
                	**type**\:  :py:class:`RemotePeerConatiner <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.ReverseRoute.RemotePeerConatiner>`
                
                .. attribute:: static
                
                	Create routes based on static ACLs permanently
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.DynamicMap.ReverseRoute, self).__init__()

                    self.yang_name = "reverse-route"
                    self.yang_parent_name = "dynamic-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("remote-peer-conatiner", ("remote_peer_conatiner", Native.Crypto.DynamicMap.ReverseRoute.RemotePeerConatiner))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                    ])
                    self.static = None

                    self.remote_peer_conatiner = Native.Crypto.DynamicMap.ReverseRoute.RemotePeerConatiner()
                    self.remote_peer_conatiner.parent = self
                    self._children_name_map["remote_peer_conatiner"] = "remote-peer-conatiner"
                    self._segment_path = lambda: "reverse-route"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.DynamicMap.ReverseRoute, ['static'], name, value)


                class RemotePeerConatiner(Entity):
                    """
                    
                    
                    .. attribute:: remote_peer
                    
                    	Create route in route table for remote tunnel endpoint
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: gateway
                    
                    	Force encrypted traffic via this preferred gateway
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: static
                    
                    	Create routes based on static ACLs permanently
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.ReverseRoute.RemotePeerConatiner, self).__init__()

                        self.yang_name = "remote-peer-conatiner"
                        self.yang_parent_name = "reverse-route"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('remote_peer', (YLeaf(YType.str, 'remote-peer'), ['str','str'])),
                            ('gateway', (YLeaf(YType.empty, 'gateway'), ['Empty'])),
                            ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                        ])
                        self.remote_peer = None
                        self.gateway = None
                        self.static = None
                        self._segment_path = lambda: "remote-peer-conatiner"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.ReverseRoute.RemotePeerConatiner, ['remote_peer', 'gateway', 'static'], name, value)


            class Set(Entity):
                """
                Set values for encryption/decryption
                
                .. attribute:: group
                
                	Set the san group parameters
                	**type**\: str
                
                .. attribute:: identity
                
                	Identity restriction
                	**type**\: str
                
                .. attribute:: ikev2_profile
                
                	Specify ikev2 Profile
                	**type**\: str
                
                .. attribute:: isakmp_profile
                
                	Specify isakmp Profile
                	**type**\: str
                
                .. attribute:: peer
                
                	Allowed Encryption/Decryption peer
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.Peer>`
                
                .. attribute:: pfs
                
                	Specify pfs settings
                	**type**\:  :py:class:`Pfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.Pfs>`
                
                	**presence node**\: True
                
                .. attribute:: reverse_route
                
                	Reverse Route Injection
                	**type**\:  :py:class:`ReverseRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.ReverseRoute>`
                
                .. attribute:: transform_set
                
                	Specify list of transform sets in priority order
                	**type**\: list of str
                
                .. attribute:: ip_in
                
                	
                	**type**\:  :py:class:`IpIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.IpIn>`
                
                .. attribute:: ip_out
                
                	
                	**type**\:  :py:class:`IpOut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.IpOut>`
                
                .. attribute:: nat
                
                	Set NAT translation
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.Nat>`
                
                .. attribute:: peer_container
                
                	
                	**type**\:  :py:class:`PeerContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.PeerContainer>`
                
                .. attribute:: security_association
                
                	Security association parameters
                	**type**\:  :py:class:`SecurityAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.SecurityAssociation>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.DynamicMap.Set, self).__init__()

                    self.yang_name = "set"
                    self.yang_parent_name = "dynamic-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("peer", ("peer", Native.Crypto.DynamicMap.Set.Peer)), ("pfs", ("pfs", Native.Crypto.DynamicMap.Set.Pfs)), ("reverse-route", ("reverse_route", Native.Crypto.DynamicMap.Set.ReverseRoute)), ("ip-in", ("ip_in", Native.Crypto.DynamicMap.Set.IpIn)), ("ip-out", ("ip_out", Native.Crypto.DynamicMap.Set.IpOut)), ("nat", ("nat", Native.Crypto.DynamicMap.Set.Nat)), ("peer-container", ("peer_container", Native.Crypto.DynamicMap.Set.PeerContainer)), ("security-association", ("security_association", Native.Crypto.DynamicMap.Set.SecurityAssociation))])
                    self._leafs = OrderedDict([
                        ('group', (YLeaf(YType.str, 'group'), ['str'])),
                        ('identity', (YLeaf(YType.str, 'identity'), ['str'])),
                        ('ikev2_profile', (YLeaf(YType.str, 'ikev2-profile'), ['str'])),
                        ('isakmp_profile', (YLeaf(YType.str, 'isakmp-profile'), ['str'])),
                        ('transform_set', (YLeafList(YType.str, 'transform-set'), ['str'])),
                    ])
                    self.group = None
                    self.identity = None
                    self.ikev2_profile = None
                    self.isakmp_profile = None
                    self.transform_set = []

                    self.peer = Native.Crypto.DynamicMap.Set.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"

                    self.pfs = None
                    self._children_name_map["pfs"] = "pfs"

                    self.reverse_route = Native.Crypto.DynamicMap.Set.ReverseRoute()
                    self.reverse_route.parent = self
                    self._children_name_map["reverse_route"] = "reverse-route"

                    self.ip_in = Native.Crypto.DynamicMap.Set.IpIn()
                    self.ip_in.parent = self
                    self._children_name_map["ip_in"] = "ip-in"

                    self.ip_out = Native.Crypto.DynamicMap.Set.IpOut()
                    self.ip_out.parent = self
                    self._children_name_map["ip_out"] = "ip-out"

                    self.nat = Native.Crypto.DynamicMap.Set.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "nat"

                    self.peer_container = Native.Crypto.DynamicMap.Set.PeerContainer()
                    self.peer_container.parent = self
                    self._children_name_map["peer_container"] = "peer-container"

                    self.security_association = Native.Crypto.DynamicMap.Set.SecurityAssociation()
                    self.security_association.parent = self
                    self._children_name_map["security_association"] = "security-association"
                    self._segment_path = lambda: "set"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.DynamicMap.Set, ['group', 'identity', 'ikev2_profile', 'isakmp_profile', 'transform_set'], name, value)


                class Peer(Entity):
                    """
                    Allowed Encryption/Decryption peer.
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: default
                    
                    	Reset to default peer in list in the event of a failure
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dynamic
                    
                    	Resolve the peer address at the time of negotiation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Set.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str','str','str'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                        ])
                        self.address = None
                        self.default = None
                        self.dynamic = None
                        self._segment_path = lambda: "peer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Set.Peer, ['address', 'default', 'dynamic'], name, value)


                class Pfs(Entity):
                    """
                    Specify pfs settings
                    
                    .. attribute:: group
                    
                    	
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.Pfs.Group>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Set.Pfs, self).__init__()

                        self.yang_name = "pfs"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.enumeration, 'group'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.DynamicMap.Set.Pfs.Group')])),
                        ])
                        self.group = None
                        self._segment_path = lambda: "pfs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Set.Pfs, ['group'], name, value)

                    class Group(Enum):
                        """
                        Group (Enum Class)

                        .. data:: group1 = 0

                        .. data:: group14 = 1

                        .. data:: group15 = 2

                        .. data:: group16 = 3

                        .. data:: group19 = 4

                        .. data:: group2 = 5

                        .. data:: group20 = 6

                        .. data:: group21 = 7

                        .. data:: group24 = 8

                        .. data:: group5 = 9

                        """

                        group1 = Enum.YLeaf(0, "group1")

                        group14 = Enum.YLeaf(1, "group14")

                        group15 = Enum.YLeaf(2, "group15")

                        group16 = Enum.YLeaf(3, "group16")

                        group19 = Enum.YLeaf(4, "group19")

                        group2 = Enum.YLeaf(5, "group2")

                        group20 = Enum.YLeaf(6, "group20")

                        group21 = Enum.YLeaf(7, "group21")

                        group24 = Enum.YLeaf(8, "group24")

                        group5 = Enum.YLeaf(9, "group5")



                class ReverseRoute(Entity):
                    """
                    Reverse Route Injection
                    
                    .. attribute:: distance
                    
                    	Distance metric for this static route
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: tag
                    
                    	Create route and tag it
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Set.ReverseRoute, self).__init__()

                        self.yang_name = "reverse-route"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                            ('tag', (YLeaf(YType.uint64, 'tag'), ['int'])),
                        ])
                        self.distance = None
                        self.tag = None
                        self._segment_path = lambda: "reverse-route"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Set.ReverseRoute, ['distance', 'tag'], name, value)


                class IpIn(Entity):
                    """
                    
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.IpIn.Ip>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Set.IpIn, self).__init__()

                        self.yang_name = "ip-in"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Crypto.DynamicMap.Set.IpIn.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Crypto.DynamicMap.Set.IpIn.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "ip-in"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Set.IpIn, [], name, value)


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: in_
                        
                        	inbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Set.IpIn.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "ip-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                            ])
                            self.access_group = None
                            self.in_ = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.DynamicMap.Set.IpIn.Ip, ['access_group', 'in_'], name, value)


                class IpOut(Entity):
                    """
                    
                    
                    .. attribute:: ip
                    
                    	Interface Internet Protocol config commands
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.IpOut.Ip>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Set.IpOut, self).__init__()

                        self.yang_name = "ip-out"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Crypto.DynamicMap.Set.IpOut.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Crypto.DynamicMap.Set.IpOut.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "ip-out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Set.IpOut, [], name, value)


                    class Ip(Entity):
                        """
                        Interface Internet Protocol config commands
                        
                        .. attribute:: access_group
                        
                        	Specify access control for packets
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199 \| 1300..2699
                        
                        		**type**\: str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: out
                        
                        	outbound packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Set.IpOut.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "ip-out"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_group', (YLeaf(YType.str, 'access-group'), ['int','str'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.access_group = None
                            self.out = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.DynamicMap.Set.IpOut.Ip, ['access_group', 'out'], name, value)


                class Nat(Entity):
                    """
                    Set NAT translation
                    
                    .. attribute:: demux
                    
                    	Set NAT demultiplexing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Set.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('demux', (YLeaf(YType.empty, 'demux'), ['Empty'])),
                        ])
                        self.demux = None
                        self._segment_path = lambda: "nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Set.Nat, ['demux'], name, value)


                class PeerContainer(Entity):
                    """
                    
                    
                    .. attribute:: peer
                    
                    	Allowed Encryption/Decryption peer
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                    
                    .. attribute:: default
                    
                    	Reset to default peer in list in the event of a failure
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Set.PeerContainer, self).__init__()

                        self.yang_name = "peer-container"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('peer', (YLeaf(YType.str, 'peer'), ['str','str','str'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.peer = None
                        self.default = None
                        self._segment_path = lambda: "peer-container"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Set.PeerContainer, ['peer', 'default'], name, value)


                class SecurityAssociation(Entity):
                    """
                    Security association parameters
                    
                    .. attribute:: dfbit
                    
                    	Handling of encapsulated DF bit
                    	**type**\:  :py:class:`Dfbit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.SecurityAssociation.Dfbit>`
                    
                    .. attribute:: dummy
                    
                    	Enable transmitting dummy packets
                    	**type**\:  :py:class:`Dummy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.SecurityAssociation.Dummy>`
                    
                    .. attribute:: ecn
                    
                    	Handling of ECN bit
                    	**type**\:  :py:class:`Ecn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.SecurityAssociation.Ecn>`
                    
                    .. attribute:: idle_time_container
                    
                    	
                    	**type**\:  :py:class:`IdleTimeContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.SecurityAssociation.IdleTimeContainer>`
                    
                    .. attribute:: lifetime
                    
                    	security association lifetime
                    	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.SecurityAssociation.Lifetime>`
                    
                    .. attribute:: replay
                    
                    	Set replay checking
                    	**type**\:  :py:class:`Replay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.SecurityAssociation.Replay>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.DynamicMap.Set.SecurityAssociation, self).__init__()

                        self.yang_name = "security-association"
                        self.yang_parent_name = "set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dummy", ("dummy", Native.Crypto.DynamicMap.Set.SecurityAssociation.Dummy)), ("idle-time-container", ("idle_time_container", Native.Crypto.DynamicMap.Set.SecurityAssociation.IdleTimeContainer)), ("lifetime", ("lifetime", Native.Crypto.DynamicMap.Set.SecurityAssociation.Lifetime)), ("replay", ("replay", Native.Crypto.DynamicMap.Set.SecurityAssociation.Replay))])
                        self._leafs = OrderedDict([
                            ('dfbit', (YLeaf(YType.enumeration, 'dfbit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.DynamicMap.Set.SecurityAssociation.Dfbit')])),
                            ('ecn', (YLeaf(YType.enumeration, 'ecn'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.DynamicMap.Set.SecurityAssociation.Ecn')])),
                        ])
                        self.dfbit = None
                        self.ecn = None

                        self.dummy = Native.Crypto.DynamicMap.Set.SecurityAssociation.Dummy()
                        self.dummy.parent = self
                        self._children_name_map["dummy"] = "dummy"

                        self.idle_time_container = Native.Crypto.DynamicMap.Set.SecurityAssociation.IdleTimeContainer()
                        self.idle_time_container.parent = self
                        self._children_name_map["idle_time_container"] = "idle-time-container"

                        self.lifetime = Native.Crypto.DynamicMap.Set.SecurityAssociation.Lifetime()
                        self.lifetime.parent = self
                        self._children_name_map["lifetime"] = "lifetime"

                        self.replay = Native.Crypto.DynamicMap.Set.SecurityAssociation.Replay()
                        self.replay.parent = self
                        self._children_name_map["replay"] = "replay"
                        self._segment_path = lambda: "security-association"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.DynamicMap.Set.SecurityAssociation, ['dfbit', 'ecn'], name, value)

                    class Dfbit(Enum):
                        """
                        Dfbit (Enum Class)

                        Handling of encapsulated DF bit.

                        .. data:: clear = 0

                        .. data:: copy = 1

                        .. data:: set = 2

                        """

                        clear = Enum.YLeaf(0, "clear")

                        copy = Enum.YLeaf(1, "copy")

                        set = Enum.YLeaf(2, "set")


                    class Ecn(Enum):
                        """
                        Ecn (Enum Class)

                        Handling of ECN bit

                        .. data:: discard = 0

                        .. data:: propagate = 1

                        """

                        discard = Enum.YLeaf(0, "discard")

                        propagate = Enum.YLeaf(1, "propagate")



                    class Dummy(Entity):
                        """
                        Enable transmitting dummy packets
                        
                        .. attribute:: pps
                        
                        	Simulated traffic rate (in pps)
                        	**type**\: int
                        
                        	**range:** 0..25
                        
                        .. attribute:: seconds
                        
                        	Simulated traffic rate (in seconds)
                        	**type**\: int
                        
                        	**range:** 1..3600
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Set.SecurityAssociation.Dummy, self).__init__()

                            self.yang_name = "dummy"
                            self.yang_parent_name = "security-association"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('pps', (YLeaf(YType.uint8, 'pps'), ['int'])),
                                ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                            ])
                            self.pps = None
                            self.seconds = None
                            self._segment_path = lambda: "dummy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.DynamicMap.Set.SecurityAssociation.Dummy, ['pps', 'seconds'], name, value)


                    class IdleTimeContainer(Entity):
                        """
                        
                        
                        .. attribute:: idle_time
                        
                        	Automatically delete IPSec SAs after a given idle period
                        	**type**\: int
                        
                        	**range:** 60..86400
                        
                        .. attribute:: default
                        
                        	All SAs idle\-out reset to default peer
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Set.SecurityAssociation.IdleTimeContainer, self).__init__()

                            self.yang_name = "idle-time-container"
                            self.yang_parent_name = "security-association"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('idle_time', (YLeaf(YType.uint32, 'idle-time'), ['int'])),
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ])
                            self.idle_time = None
                            self.default = None
                            self._segment_path = lambda: "idle-time-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.DynamicMap.Set.SecurityAssociation.IdleTimeContainer, ['idle_time', 'default'], name, value)


                    class Lifetime(Entity):
                        """
                        security association lifetime
                        
                        .. attribute:: days
                        
                        	Time\-based key duration in days
                        	**type**\: int
                        
                        	**range:** 1..30
                        
                        .. attribute:: kilobytes
                        
                        	Volume\-based key duration
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 2560..4294967295
                        
                        		**type**\:  :py:class:`Kilobytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Lifetime.Kilobytes>`
                        
                        .. attribute:: seconds
                        
                        	Time\-based key duration in seconds
                        	**type**\: int
                        
                        	**range:** 120..2592000
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Set.SecurityAssociation.Lifetime, self).__init__()

                            self.yang_name = "lifetime"
                            self.yang_parent_name = "security-association"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('days', (YLeaf(YType.uint8, 'days'), ['int'])),
                                ('kilobytes', (YLeaf(YType.str, 'kilobytes'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.CryptoMap.Map.Set.SecurityAssociation.Lifetime.Kilobytes')])),
                                ('seconds', (YLeaf(YType.uint64, 'seconds'), ['int'])),
                            ])
                            self.days = None
                            self.kilobytes = None
                            self.seconds = None
                            self._segment_path = lambda: "lifetime"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.DynamicMap.Set.SecurityAssociation.Lifetime, ['days', 'kilobytes', 'seconds'], name, value)

                        class Kilobytes(Enum):
                            """
                            Kilobytes (Enum Class)

                            Volume\-based key duration

                            .. data:: disable = 0

                            """

                            disable = Enum.YLeaf(0, "disable")



                    class Replay(Entity):
                        """
                        Set replay checking.
                        
                        .. attribute:: disable
                        
                        	Disable replay checking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: window_size
                        
                        	Set replay window size
                        	**type**\:  :py:class:`WindowSize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.DynamicMap.Set.SecurityAssociation.Replay.WindowSize>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.DynamicMap.Set.SecurityAssociation.Replay, self).__init__()

                            self.yang_name = "replay"
                            self.yang_parent_name = "security-association"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('window_size', (YLeaf(YType.enumeration, 'window-size'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.DynamicMap.Set.SecurityAssociation.Replay.WindowSize')])),
                            ])
                            self.disable = None
                            self.window_size = None
                            self._segment_path = lambda: "replay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.DynamicMap.Set.SecurityAssociation.Replay, ['disable', 'window_size'], name, value)

                        class WindowSize(Enum):
                            """
                            WindowSize (Enum Class)

                            Set replay window size.

                            .. data:: Y_1024 = 0

                            .. data:: Y_128 = 1

                            .. data:: Y_256 = 2

                            .. data:: Y_512 = 3

                            .. data:: Y_64 = 4

                            """

                            Y_1024 = Enum.YLeaf(0, "1024")

                            Y_128 = Enum.YLeaf(1, "128")

                            Y_256 = Enum.YLeaf(2, "256")

                            Y_512 = Enum.YLeaf(3, "512")

                            Y_64 = Enum.YLeaf(4, "64")



        class Engine(Entity):
            """
            Enter a crypto engine configurable menu
            
            .. attribute:: software
            
            	Software crypto engine
            	**type**\:  :py:class:`Software <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Engine.Software>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Engine, self).__init__()

                self.yang_name = "engine"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('software', (YLeaf(YType.enumeration, 'software'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Engine.Software')])),
                ])
                self.software = None
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:engine"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Engine, ['software'], name, value)

            class Software(Enum):
                """
                Software (Enum Class)

                Software crypto engine

                .. data:: ipsec = 0

                .. data:: isakmp = 1

                """

                ipsec = Enum.YLeaf(0, "ipsec")

                isakmp = Enum.YLeaf(1, "isakmp")



        class Gdoi(Entity):
            """
            Configure GKM (Group Key Management, GDOI or G\-IKEv2) Policy
            
            .. attribute:: group
            
            	Configure a GKM (Group Key Management, GDOI or G\-IKEv2) Group
            	**type**\: list of  		 :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Gdoi, self).__init__()

                self.yang_name = "gdoi"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("group", ("group", Native.Crypto.Gdoi.Group))])
                self._leafs = OrderedDict()

                self.group = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:gdoi"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Gdoi, [], name, value)


            class Group(Entity):
                """
                Configure a GKM (Group Key Management, GDOI or G\-IKEv2) Group
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: ipv6
                
                	IPv6 GKM (Group Key Management) Group
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: client
                
                	Set the group client parameters
                	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Client>`
                
                .. attribute:: identity
                
                	Set the identity of the group
                	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Identity>`
                
                .. attribute:: passive
                
                	Set the group in passive mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: server
                
                	Set the group server for of the group
                	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server>`
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Gdoi.Group, self).__init__()

                    self.yang_name = "group"
                    self.yang_parent_name = "gdoi"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("client", ("client", Native.Crypto.Gdoi.Group.Client)), ("identity", ("identity", Native.Crypto.Gdoi.Group.Identity)), ("server", ("server", Native.Crypto.Gdoi.Group.Server)), ("default", ("default", Native.Crypto.Gdoi.Group.Default))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                        ('passive', (YLeaf(YType.empty, 'passive'), ['Empty'])),
                    ])
                    self.name = None
                    self.ipv6 = None
                    self.passive = None

                    self.client = Native.Crypto.Gdoi.Group.Client()
                    self.client.parent = self
                    self._children_name_map["client"] = "client"

                    self.identity = Native.Crypto.Gdoi.Group.Identity()
                    self.identity.parent = self
                    self._children_name_map["identity"] = "identity"

                    self.server = Native.Crypto.Gdoi.Group.Server()
                    self.server.parent = self
                    self._children_name_map["server"] = "server"

                    self.default = Native.Crypto.Gdoi.Group.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "group" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:gdoi/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Gdoi.Group, ['name', 'ipv6', 'passive'], name, value)


                class Client(Entity):
                    """
                    Set the group client parameters
                    
                    .. attribute:: bypass_policy
                    
                    	Allow group\-key management traffic sent to this GM only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: protocol
                    
                    	Group Member Registration & Rekey Protocol
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Client.Protocol>`
                    
                    .. attribute:: recovery_check
                    
                    	Specify GM recovery check parameters
                    	**type**\:  :py:class:`RecoveryCheck <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Client.RecoveryCheck>`
                    
                    .. attribute:: registration
                    
                    	Set the group client management/register interface
                    	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Client.Registration>`
                    
                    .. attribute:: rekey
                    
                    	Set the group client acceptable rekey ciphers and hashs
                    	**type**\:  :py:class:`Rekey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Client.Rekey>`
                    
                    .. attribute:: status
                    
                    	group\-member status
                    	**type**\:  :py:class:`Status <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Client.Status>`
                    
                    .. attribute:: transform_sets
                    
                    	Specify list of group client acceptable transform sets
                    	**type**\: list of str
                    
                    .. attribute:: transport_encrypt_key
                    
                    	Enforce group or pair\-wise keying
                    	**type**\:  :py:class:`TransportEncryptKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Client.TransportEncryptKey>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Gdoi.Group.Client, self).__init__()

                        self.yang_name = "client"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol", ("protocol", Native.Crypto.Gdoi.Group.Client.Protocol)), ("recovery-check", ("recovery_check", Native.Crypto.Gdoi.Group.Client.RecoveryCheck)), ("registration", ("registration", Native.Crypto.Gdoi.Group.Client.Registration)), ("rekey", ("rekey", Native.Crypto.Gdoi.Group.Client.Rekey)), ("status", ("status", Native.Crypto.Gdoi.Group.Client.Status))])
                        self._leafs = OrderedDict([
                            ('bypass_policy', (YLeaf(YType.empty, 'bypass-policy'), ['Empty'])),
                            ('transform_sets', (YLeafList(YType.str, 'transform-sets'), ['str'])),
                            ('transport_encrypt_key', (YLeaf(YType.enumeration, 'transport-encrypt-key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gdoi.Group.Client.TransportEncryptKey')])),
                        ])
                        self.bypass_policy = None
                        self.transform_sets = []
                        self.transport_encrypt_key = None

                        self.protocol = Native.Crypto.Gdoi.Group.Client.Protocol()
                        self.protocol.parent = self
                        self._children_name_map["protocol"] = "protocol"

                        self.recovery_check = Native.Crypto.Gdoi.Group.Client.RecoveryCheck()
                        self.recovery_check.parent = self
                        self._children_name_map["recovery_check"] = "recovery-check"

                        self.registration = Native.Crypto.Gdoi.Group.Client.Registration()
                        self.registration.parent = self
                        self._children_name_map["registration"] = "registration"

                        self.rekey = Native.Crypto.Gdoi.Group.Client.Rekey()
                        self.rekey.parent = self
                        self._children_name_map["rekey"] = "rekey"

                        self.status = Native.Crypto.Gdoi.Group.Client.Status()
                        self.status.parent = self
                        self._children_name_map["status"] = "status"
                        self._segment_path = lambda: "client"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Gdoi.Group.Client, ['bypass_policy', 'transform_sets', 'transport_encrypt_key'], name, value)

                    class TransportEncryptKey(Enum):
                        """
                        TransportEncryptKey (Enum Class)

                        Enforce group or pair\-wise keying

                        .. data:: group_key = 0

                        .. data:: pair_wise_key = 1

                        """

                        group_key = Enum.YLeaf(0, "group-key")

                        pair_wise_key = Enum.YLeaf(1, "pair-wise-key")



                    class Protocol(Entity):
                        """
                        Group Member Registration & Rekey Protocol
                        
                        .. attribute:: gdoi
                        
                        	Use GDOI (ISAKMP) Protocol for Registration & Rekey
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: gikev2
                        
                        	Use G\-IKEv2 Protocol for Registration & Rekey
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Client.Protocol, self).__init__()

                            self.yang_name = "protocol"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('gdoi', (YLeaf(YType.empty, 'gdoi'), ['Empty'])),
                                ('gikev2', (YLeaf(YType.str, 'gikev2'), ['str'])),
                            ])
                            self.gdoi = None
                            self.gikev2 = None
                            self._segment_path = lambda: "protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gdoi.Group.Client.Protocol, ['gdoi', 'gikev2'], name, value)


                    class RecoveryCheck(Entity):
                        """
                        Specify GM recovery check parameters
                        
                        .. attribute:: interval
                        
                        	Waiting period(sec) between consecutive recovery registrations
                        	**type**\: int
                        
                        	**range:** 100..1000
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Client.RecoveryCheck, self).__init__()

                            self.yang_name = "recovery-check"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "recovery-check"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gdoi.Group.Client.RecoveryCheck, ['interval'], name, value)


                    class Registration(Entity):
                        """
                        Set the group client management/register interface
                        
                        .. attribute:: interface
                        
                        	Set the group client management/register interface
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Client.Registration, self).__init__()

                            self.yang_name = "registration"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "registration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gdoi.Group.Client.Registration, ['interface'], name, value)


                    class Rekey(Entity):
                        """
                        Set the group client acceptable rekey ciphers and hashs
                        
                        .. attribute:: encryption
                        
                        	Set the group client acceptable rekey ciphers
                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Client.Rekey.Encryption>`
                        
                        .. attribute:: hash
                        
                        	Set the group client acceptable rekey hash
                        	**type**\:  :py:class:`Hash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Client.Rekey.Hash>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Client.Rekey, self).__init__()

                            self.yang_name = "rekey"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encryption", ("encryption", Native.Crypto.Gdoi.Group.Client.Rekey.Encryption)), ("hash", ("hash", Native.Crypto.Gdoi.Group.Client.Rekey.Hash))])
                            self._leafs = OrderedDict()

                            self.encryption = Native.Crypto.Gdoi.Group.Client.Rekey.Encryption()
                            self.encryption.parent = self
                            self._children_name_map["encryption"] = "encryption"

                            self.hash = Native.Crypto.Gdoi.Group.Client.Rekey.Hash()
                            self.hash.parent = self
                            self._children_name_map["hash"] = "hash"
                            self._segment_path = lambda: "rekey"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gdoi.Group.Client.Rekey, [], name, value)


                        class Encryption(Entity):
                            """
                            Set the group client acceptable rekey ciphers
                            
                            .. attribute:: rekey_3des_cbc
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: aes_128
                            
                            	128 bit AES
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: aes_192
                            
                            	192 bit AES
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: aes_256
                            
                            	256 bit AES
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: des_cbc
                            
                            	DES in CBC mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Client.Rekey.Encryption, self).__init__()

                                self.yang_name = "encryption"
                                self.yang_parent_name = "rekey"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rekey_3des_cbc', (YLeaf(YType.empty, 'rekey-3des-cbc'), ['Empty'])),
                                    ('aes_128', (YLeaf(YType.empty, 'aes-128'), ['Empty'])),
                                    ('aes_192', (YLeaf(YType.empty, 'aes-192'), ['Empty'])),
                                    ('aes_256', (YLeaf(YType.empty, 'aes-256'), ['Empty'])),
                                    ('des_cbc', (YLeaf(YType.empty, 'des-cbc'), ['Empty'])),
                                ])
                                self.rekey_3des_cbc = None
                                self.aes_128 = None
                                self.aes_192 = None
                                self.aes_256 = None
                                self.des_cbc = None
                                self._segment_path = lambda: "encryption"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Client.Rekey.Encryption, ['rekey_3des_cbc', 'aes_128', 'aes_192', 'aes_256', 'des_cbc'], name, value)


                        class Hash(Entity):
                            """
                            Set the group client acceptable rekey hash
                            
                            .. attribute:: sha
                            
                            	Secure Hash Standard
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sha256
                            
                            	Secure Hash Standard 2 (256 bit)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sha384
                            
                            	Secure Hash Standard 2 (384 bit)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sha512
                            
                            	Secure Hash Standard 2 (512 bit)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Client.Rekey.Hash, self).__init__()

                                self.yang_name = "hash"
                                self.yang_parent_name = "rekey"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sha', (YLeaf(YType.empty, 'sha'), ['Empty'])),
                                    ('sha256', (YLeaf(YType.empty, 'sha256'), ['Empty'])),
                                    ('sha384', (YLeaf(YType.empty, 'sha384'), ['Empty'])),
                                    ('sha512', (YLeaf(YType.empty, 'sha512'), ['Empty'])),
                                ])
                                self.sha = None
                                self.sha256 = None
                                self.sha384 = None
                                self.sha512 = None
                                self._segment_path = lambda: "hash"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Client.Rekey.Hash, ['sha', 'sha256', 'sha384', 'sha512'], name, value)


                    class Status(Entity):
                        """
                        group\-member status
                        
                        .. attribute:: active_sa
                        
                        	TEK SA with positive remaining lifetime
                        	**type**\:  :py:class:`ActiveSa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Client.Status.ActiveSa>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Client.Status, self).__init__()

                            self.yang_name = "status"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("active-sa", ("active_sa", Native.Crypto.Gdoi.Group.Client.Status.ActiveSa))])
                            self._leafs = OrderedDict()

                            self.active_sa = Native.Crypto.Gdoi.Group.Client.Status.ActiveSa()
                            self.active_sa.parent = self
                            self._children_name_map["active_sa"] = "active-sa"
                            self._segment_path = lambda: "status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gdoi.Group.Client.Status, [], name, value)


                        class ActiveSa(Entity):
                            """
                            TEK SA with positive remaining lifetime
                            
                            .. attribute:: track
                            
                            	enable stub tracking object
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Client.Status.ActiveSa, self).__init__()

                                self.yang_name = "active-sa"
                                self.yang_parent_name = "status"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.track = None
                                self._segment_path = lambda: "active-sa"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Client.Status.ActiveSa, ['track'], name, value)


                class Identity(Entity):
                    """
                    Set the identity of the group
                    
                    .. attribute:: address
                    
                    	Set the identity of the group as an address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Identity.Address>`
                    
                    .. attribute:: number
                    
                    	Set the identity of the group as a number
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Gdoi.Group.Identity, self).__init__()

                        self.yang_name = "identity"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Identity.Address))])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint64, 'number'), ['int'])),
                        ])
                        self.number = None

                        self.address = Native.Crypto.Gdoi.Group.Identity.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._segment_path = lambda: "identity"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Gdoi.Group.Identity, ['number'], name, value)


                    class Address(Entity):
                        """
                        Set the identity of the group as an address
                        
                        .. attribute:: ipv4
                        
                        	Set the identity of the group as an IPv4 address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Identity.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "identity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                            ])
                            self.ipv4 = None
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gdoi.Group.Identity.Address, ['ipv4'], name, value)


                class Server(Entity):
                    """
                    Set the group server for of the group
                    
                    .. attribute:: address
                    
                    	Identify the group server by address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Address>`
                    
                    .. attribute:: hostname
                    
                    	Identify the group server by hostname
                    	**type**\:  :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Hostname>`
                    
                    .. attribute:: local
                    
                    	Configure GKM group server defined locally
                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Gdoi.Group.Server, self).__init__()

                        self.yang_name = "server"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Server.Address)), ("hostname", ("hostname", Native.Crypto.Gdoi.Group.Server.Hostname)), ("local", ("local", Native.Crypto.Gdoi.Group.Server.Local))])
                        self._leafs = OrderedDict()

                        self.address = Native.Crypto.Gdoi.Group.Server.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.hostname = Native.Crypto.Gdoi.Group.Server.Hostname()
                        self.hostname.parent = self
                        self._children_name_map["hostname"] = "hostname"

                        self.local = Native.Crypto.Gdoi.Group.Server.Local()
                        self.local.parent = self
                        self._children_name_map["local"] = "local"
                        self._segment_path = lambda: "server"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server, [], name, value)


                    class Address(Entity):
                        """
                        Identify the group server by address
                        
                        .. attribute:: ipv4
                        
                        	Set the IPv4 address of the group server
                        	**type**\: list of str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6
                        
                        	Set the IPv6 address of the group server
                        	**type**\: list of str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Server.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeafList(YType.str, 'ipv4'), ['str'])),
                                ('ipv6', (YLeafList(YType.str, 'ipv6'), ['str'])),
                            ])
                            self.ipv4 = []
                            self.ipv6 = []
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Address, ['ipv4', 'ipv6'], name, value)


                    class Hostname(Entity):
                        """
                        Identify the group server by hostname
                        
                        .. attribute:: ipv4
                        
                        	Set the IPv4 hostname of the group server
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Server.Hostname, self).__init__()

                            self.yang_name = "hostname"
                            self.yang_parent_name = "server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                            ])
                            self.ipv4 = None
                            self._segment_path = lambda: "hostname"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Hostname, ['ipv4'], name, value)


                    class Local(Entity):
                        """
                        Configure GKM group server defined locally
                        
                        .. attribute:: address
                        
                        	Configure server source address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Address>`
                        
                        .. attribute:: authorization
                        
                        	Configure authorization for the group
                        	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Authorization>`
                        
                        .. attribute:: gdoi
                        
                        	Enable GDOI (ISAKMP) Protocol for Registration & Rekey
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: gikev2
                        
                        	Enable G\-IKEv2 (IKEv2) Protocol for Registration & Rekey
                        	**type**\: str
                        
                        .. attribute:: group
                        
                        	Configure parameters for the group (e.g. Suite\-B)
                        	**type**\:  :py:class:`Group_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Group_>`
                        
                        .. attribute:: identifier
                        
                        	Enter Suite\-B KSSID (Key Server Sender ID) config mode
                        	**type**\:  :py:class:`Identifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Identifier>`
                        
                        .. attribute:: redundancy
                        
                        	Enter cooperative key server configuration mode
                        	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy>`
                        
                        .. attribute:: registration
                        
                        	Configure registration for the group
                        	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Registration>`
                        
                        .. attribute:: rekey
                        
                        	Configure rekey policy for the group
                        	**type**\:  :py:class:`Rekey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Rekey>`
                        
                        .. attribute:: sa
                        
                        	Configure a security association
                        	**type**\:  :py:class:`Sa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa>`
                        
                        .. attribute:: default
                        
                        	Set a command to its defaults
                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Server.Local, self).__init__()

                            self.yang_name = "local"
                            self.yang_parent_name = "server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Server.Local.Address)), ("authorization", ("authorization", Native.Crypto.Gdoi.Group.Server.Local.Authorization)), ("group", ("group", Native.Crypto.Gdoi.Group.Server.Local.Group_)), ("identifier", ("identifier", Native.Crypto.Gdoi.Group.Server.Local.Identifier)), ("redundancy", ("redundancy", Native.Crypto.Gdoi.Group.Server.Local.Redundancy)), ("registration", ("registration", Native.Crypto.Gdoi.Group.Server.Local.Registration)), ("rekey", ("rekey", Native.Crypto.Gdoi.Group.Server.Local.Rekey)), ("sa", ("sa", Native.Crypto.Gdoi.Group.Server.Local.Sa)), ("default", ("default", Native.Crypto.Gdoi.Group.Server.Local.Default))])
                            self._leafs = OrderedDict([
                                ('gdoi', (YLeaf(YType.empty, 'gdoi'), ['Empty'])),
                                ('gikev2', (YLeaf(YType.str, 'gikev2'), ['str'])),
                            ])
                            self.gdoi = None
                            self.gikev2 = None

                            self.address = Native.Crypto.Gdoi.Group.Server.Local.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"

                            self.authorization = Native.Crypto.Gdoi.Group.Server.Local.Authorization()
                            self.authorization.parent = self
                            self._children_name_map["authorization"] = "authorization"

                            self.group = Native.Crypto.Gdoi.Group.Server.Local.Group_()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"

                            self.identifier = Native.Crypto.Gdoi.Group.Server.Local.Identifier()
                            self.identifier.parent = self
                            self._children_name_map["identifier"] = "identifier"

                            self.redundancy = Native.Crypto.Gdoi.Group.Server.Local.Redundancy()
                            self.redundancy.parent = self
                            self._children_name_map["redundancy"] = "redundancy"

                            self.registration = Native.Crypto.Gdoi.Group.Server.Local.Registration()
                            self.registration.parent = self
                            self._children_name_map["registration"] = "registration"

                            self.rekey = Native.Crypto.Gdoi.Group.Server.Local.Rekey()
                            self.rekey.parent = self
                            self._children_name_map["rekey"] = "rekey"

                            self.sa = Native.Crypto.Gdoi.Group.Server.Local.Sa()
                            self.sa.parent = self
                            self._children_name_map["sa"] = "sa"

                            self.default = Native.Crypto.Gdoi.Group.Server.Local.Default()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"
                            self._segment_path = lambda: "local"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local, ['gdoi', 'gikev2'], name, value)


                        class Address(Entity):
                            """
                            Configure server source address
                            
                            .. attribute:: ipv4
                            
                            	Set ipv4 address of local server
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Server.Local.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ])
                                self.ipv4 = None
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Address, ['ipv4'], name, value)


                        class Authorization(Entity):
                            """
                            Configure authorization for the group
                            
                            .. attribute:: address
                            
                            	Set authorization by address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Authorization.Address>`
                            
                            .. attribute:: identity
                            
                            	Set authorization by identity
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Server.Local.Authorization, self).__init__()

                                self.yang_name = "authorization"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Server.Local.Authorization.Address))])
                                self._leafs = OrderedDict([
                                    ('identity', (YLeaf(YType.str, 'identity'), ['str'])),
                                ])
                                self.identity = None

                                self.address = Native.Crypto.Gdoi.Group.Server.Local.Authorization.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "authorization"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Authorization, ['identity'], name, value)


                            class Address(Entity):
                                """
                                Set authorization by address
                                
                                .. attribute:: ipv4
                                
                                	Set authorization by address
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..99
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Authorization.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "authorization"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['int','str'])),
                                    ])
                                    self.ipv4 = None
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Authorization.Address, ['ipv4'], name, value)


                        class Group_(Entity):
                            """
                            Configure parameters for the group (e.g. Suite\-B)
                            
                            .. attribute:: size
                            
                            	Set Group Size for Suite\-B counter transforms (SID length)
                            	**type**\:  :py:class:`Size <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Group_.Size>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Server.Local.Group_, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("size", ("size", Native.Crypto.Gdoi.Group.Server.Local.Group_.Size))])
                                self._leafs = OrderedDict()

                                self.size = Native.Crypto.Gdoi.Group.Server.Local.Group_.Size()
                                self.size.parent = self
                                self._children_name_map["size"] = "size"
                                self._segment_path = lambda: "group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Group_, [], name, value)


                            class Size(Entity):
                                """
                                Set Group Size for Suite\-B counter transforms (SID length)
                                
                                .. attribute:: large
                                
                                	32\-bit Sender ID (FIPS 140\-2 Operating Mode)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: medium
                                
                                	24\-bit Sender ID (Default)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: small
                                
                                	Interoperable with GDOI / G\-IKEv2 Standard
                                	**type**\:  :py:class:`Small <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Group_.Size.Small>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Group_.Size, self).__init__()

                                    self.yang_name = "size"
                                    self.yang_parent_name = "group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('large', (YLeaf(YType.empty, 'large'), ['Empty'])),
                                        ('medium', (YLeaf(YType.empty, 'medium'), ['Empty'])),
                                        ('small', (YLeaf(YType.enumeration, 'small'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gdoi.Group.Server.Local.Group_.Size.Small')])),
                                    ])
                                    self.large = None
                                    self.medium = None
                                    self.small = None
                                    self._segment_path = lambda: "size"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Group_.Size, ['large', 'medium', 'small'], name, value)

                                class Small(Enum):
                                    """
                                    Small (Enum Class)

                                    Interoperable with GDOI / G\-IKEv2 Standard

                                    .. data:: Y_12 = 0

                                    .. data:: Y_16 = 1

                                    .. data:: Y_8 = 2

                                    """

                                    Y_12 = Enum.YLeaf(0, "12")

                                    Y_16 = Enum.YLeaf(1, "16")

                                    Y_8 = Enum.YLeaf(2, "8")



                        class Identifier(Entity):
                            """
                            Enter Suite\-B KSSID (Key Server Sender ID) config mode
                            
                            .. attribute:: default
                            
                            	Set a command to its defaults
                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Identifier.Default>`
                            
                            .. attribute:: range
                            
                            	Assign range of Key Server Sender IDs (unique in entire group)
                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Identifier.Range>`
                            
                            .. attribute:: value
                            
                            	Assign Key Server Sender ID (unique in entire group)
                            	**type**\: int
                            
                            	**range:** 0..1
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Server.Local.Identifier, self).__init__()

                                self.yang_name = "identifier"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Gdoi.Group.Server.Local.Identifier.Default)), ("range", ("range", Native.Crypto.Gdoi.Group.Server.Local.Identifier.Range))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.default = Native.Crypto.Gdoi.Group.Server.Local.Identifier.Default()
                                self.default.parent = self
                                self._children_name_map["default"] = "default"

                                self.range = Native.Crypto.Gdoi.Group.Server.Local.Identifier.Range()
                                self.range.parent = self
                                self._children_name_map["range"] = "range"
                                self._segment_path = lambda: "identifier"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Identifier, ['value'], name, value)


                            class Default(Entity):
                                """
                                Set a command to its defaults
                                
                                .. attribute:: range
                                
                                	Assign range of Key Server Sender IDs (unique in entire group)
                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Identifier.Default.Range>`
                                
                                .. attribute:: value
                                
                                	Assign Key Server Sender ID (unique in entire group)
                                	**type**\: int
                                
                                	**range:** 0..1
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Identifier.Default, self).__init__()

                                    self.yang_name = "default"
                                    self.yang_parent_name = "identifier"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Crypto.Gdoi.Group.Server.Local.Identifier.Default.Range))])
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None

                                    self.range = Native.Crypto.Gdoi.Group.Server.Local.Identifier.Default.Range()
                                    self.range.parent = self
                                    self._children_name_map["range"] = "range"
                                    self._segment_path = lambda: "default"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Identifier.Default, ['value'], name, value)


                                class Range(Entity):
                                    """
                                    Assign range of Key Server Sender IDs (unique in entire group)
                                    
                                    .. attribute:: lowest
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..1
                                    
                                    .. attribute:: hyphen
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: highest
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..1
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Identifier.Default.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lowest', (YLeaf(YType.uint8, 'lowest'), ['int'])),
                                            ('hyphen', (YLeaf(YType.empty, 'hyphen'), ['Empty'])),
                                            ('highest', (YLeaf(YType.uint8, 'highest'), ['int'])),
                                        ])
                                        self.lowest = None
                                        self.hyphen = None
                                        self.highest = None
                                        self._segment_path = lambda: "range"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Identifier.Default.Range, ['lowest', 'hyphen', 'highest'], name, value)


                            class Range(Entity):
                                """
                                Assign range of Key Server Sender IDs (unique in entire group)
                                
                                .. attribute:: lowest
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..1
                                
                                .. attribute:: hyphen
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: highest
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..1
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Identifier.Range, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "identifier"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lowest', (YLeaf(YType.uint8, 'lowest'), ['int'])),
                                        ('hyphen', (YLeaf(YType.empty, 'hyphen'), ['Empty'])),
                                        ('highest', (YLeaf(YType.uint8, 'highest'), ['int'])),
                                    ])
                                    self.lowest = None
                                    self.hyphen = None
                                    self.highest = None
                                    self._segment_path = lambda: "range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Identifier.Range, ['lowest', 'hyphen', 'highest'], name, value)


                        class Redundancy(Entity):
                            """
                            Enter cooperative key server configuration mode
                            
                            .. attribute:: default
                            
                            	Set a command to its defaults
                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default>`
                            
                            .. attribute:: local
                            
                            	Local key server configurations
                            	**type**\:  :py:class:`Local_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Local_>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: peer
                            
                            	Peer server configurations
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Peer>`
                            
                            .. attribute:: protocol
                            
                            	Specify various protocol operational values
                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Protocol>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Server.Local.Redundancy, self).__init__()

                                self.yang_name = "redundancy"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default)), ("local", ("local", Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Local_)), ("peer", ("peer", Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Peer)), ("protocol", ("protocol", Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Protocol))])
                                self._leafs = OrderedDict()

                                self.default = Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default()
                                self.default.parent = self
                                self._children_name_map["default"] = "default"

                                self.local = None
                                self._children_name_map["local"] = "local"

                                self.peer = Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.protocol = None
                                self._children_name_map["protocol"] = "protocol"
                                self._segment_path = lambda: "redundancy"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Redundancy, [], name, value)


                            class Default(Entity):
                                """
                                Set a command to its defaults
                                
                                .. attribute:: local
                                
                                	Local key server configurations
                                	**type**\:  :py:class:`Local_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Local_>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: peer
                                
                                	Peer server configurations
                                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Peer>`
                                
                                .. attribute:: protocol
                                
                                	Specify various protocol operational values
                                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Protocol>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default, self).__init__()

                                    self.yang_name = "default"
                                    self.yang_parent_name = "redundancy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local", ("local", Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Local_)), ("peer", ("peer", Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Peer)), ("protocol", ("protocol", Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Protocol))])
                                    self._leafs = OrderedDict()

                                    self.local = None
                                    self._children_name_map["local"] = "local"

                                    self.peer = Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Peer()
                                    self.peer.parent = self
                                    self._children_name_map["peer"] = "peer"

                                    self.protocol = None
                                    self._children_name_map["protocol"] = "protocol"
                                    self._segment_path = lambda: "default"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default, [], name, value)


                                class Local_(Entity):
                                    """
                                    Local key server configurations
                                    
                                    .. attribute:: priority
                                    
                                    	Set local server priority
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Local_, self).__init__()

                                        self.yang_name = "local"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "local"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Local_, ['priority'], name, value)


                                class Peer(Entity):
                                    """
                                    Peer server configurations
                                    
                                    .. attribute:: address
                                    
                                    	Peer server address
                                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Peer.Address>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Peer, self).__init__()

                                        self.yang_name = "peer"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Peer.Address))])
                                        self._leafs = OrderedDict()

                                        self.address = Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Peer.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._segment_path = lambda: "peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Peer, [], name, value)


                                    class Address(Entity):
                                        """
                                        Peer server address
                                        
                                        .. attribute:: ipv4
                                        
                                        	Set peer server ipv4 address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Peer.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ])
                                            self.ipv4 = None
                                            self._segment_path = lambda: "address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Peer.Address, ['ipv4'], name, value)


                                class Protocol(Entity):
                                    """
                                    Specify various protocol operational values
                                    
                                    .. attribute:: pdu
                                    
                                    	Maximum size of COOP messages
                                    	**type**\: int
                                    
                                    	**range:** 1..65000
                                    
                                    .. attribute:: version
                                    
                                    	Set COOP ANN version
                                    	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Protocol.Version>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Protocol, self).__init__()

                                        self.yang_name = "protocol"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('pdu', (YLeaf(YType.uint32, 'pdu'), ['int'])),
                                            ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Protocol.Version')])),
                                        ])
                                        self.pdu = None
                                        self.version = None
                                        self._segment_path = lambda: "protocol"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Default.Protocol, ['pdu', 'version'], name, value)

                                    class Version(Enum):
                                        """
                                        Version (Enum Class)

                                        Set COOP ANN version

                                        .. data:: base = 0

                                        .. data:: optimize = 1

                                        """

                                        base = Enum.YLeaf(0, "base")

                                        optimize = Enum.YLeaf(1, "optimize")



                            class Local_(Entity):
                                """
                                Local key server configurations
                                
                                .. attribute:: priority
                                
                                	Set local server priority
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Local_, self).__init__()

                                    self.yang_name = "local"
                                    self.yang_parent_name = "redundancy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.priority = None
                                    self._segment_path = lambda: "local"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Local_, ['priority'], name, value)


                            class Peer(Entity):
                                """
                                Peer server configurations
                                
                                .. attribute:: address
                                
                                	Peer server address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Peer.Address>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "redundancy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Peer.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Peer.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Peer, [], name, value)


                                class Address(Entity):
                                    """
                                    Peer server address
                                    
                                    .. attribute:: ipv4
                                    
                                    	Set peer server ipv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Peer.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "peer"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Peer.Address, ['ipv4'], name, value)


                            class Protocol(Entity):
                                """
                                Specify various protocol operational values
                                
                                .. attribute:: pdu
                                
                                	Maximum size of COOP messages
                                	**type**\: int
                                
                                	**range:** 1..65000
                                
                                .. attribute:: version
                                
                                	Set COOP ANN version
                                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Protocol.Version>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Protocol, self).__init__()

                                    self.yang_name = "protocol"
                                    self.yang_parent_name = "redundancy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pdu', (YLeaf(YType.uint32, 'pdu'), ['int'])),
                                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gdoi.Group.Server.Local.Redundancy.Protocol.Version')])),
                                    ])
                                    self.pdu = None
                                    self.version = None
                                    self._segment_path = lambda: "protocol"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Redundancy.Protocol, ['pdu', 'version'], name, value)

                                class Version(Enum):
                                    """
                                    Version (Enum Class)

                                    Set COOP ANN version

                                    .. data:: base = 0

                                    .. data:: optimize = 1

                                    """

                                    base = Enum.YLeaf(0, "base")

                                    optimize = Enum.YLeaf(1, "optimize")



                        class Registration(Entity):
                            """
                            Configure registration for the group
                            
                            .. attribute:: interface
                            
                            	Identify an interface on which to respond to GKM registrations
                            	**type**\: str
                            
                            .. attribute:: periodic
                            
                            	Define periodic registrations for the group
                            	**type**\:  :py:class:`Periodic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Registration.Periodic>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Server.Local.Registration, self).__init__()

                                self.yang_name = "registration"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("periodic", ("periodic", Native.Crypto.Gdoi.Group.Server.Local.Registration.Periodic))])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ])
                                self.interface = None

                                self.periodic = Native.Crypto.Gdoi.Group.Server.Local.Registration.Periodic()
                                self.periodic.parent = self
                                self._children_name_map["periodic"] = "periodic"
                                self._segment_path = lambda: "registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Registration, ['interface'], name, value)


                            class Periodic(Entity):
                                """
                                Define periodic registrations for the group
                                
                                .. attribute:: crl
                                
                                	On every new CRL
                                	**type**\:  :py:class:`Crl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Registration.Periodic.Crl>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Registration.Periodic, self).__init__()

                                    self.yang_name = "periodic"
                                    self.yang_parent_name = "registration"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("crl", ("crl", Native.Crypto.Gdoi.Group.Server.Local.Registration.Periodic.Crl))])
                                    self._leafs = OrderedDict()

                                    self.crl = Native.Crypto.Gdoi.Group.Server.Local.Registration.Periodic.Crl()
                                    self.crl.parent = self
                                    self._children_name_map["crl"] = "crl"
                                    self._segment_path = lambda: "periodic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Registration.Periodic, [], name, value)


                                class Crl(Entity):
                                    """
                                    On every new CRL
                                    
                                    .. attribute:: trustpoint
                                    
                                    	For a PKI trustpoint
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Registration.Periodic.Crl, self).__init__()

                                        self.yang_name = "crl"
                                        self.yang_parent_name = "periodic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('trustpoint', (YLeaf(YType.str, 'trustpoint'), ['str'])),
                                        ])
                                        self.trustpoint = None
                                        self._segment_path = lambda: "crl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Registration.Periodic.Crl, ['trustpoint'], name, value)


                        class Rekey(Entity):
                            """
                            Configure rekey policy for the group
                            
                            .. attribute:: acknowledgement
                            
                            	Request group members to acknowledge rekeys
                            	**type**\:  :py:class:`Acknowledgement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Rekey.Acknowledgement>`
                            
                            .. attribute:: address
                            
                            	Define the rekey packet format
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Rekey.Address>`
                            
                            .. attribute:: algorithm
                            
                            	Set the rekey encryption algorithm
                            	**type**\:  :py:class:`Algorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Rekey.Algorithm>`
                            
                            .. attribute:: authentication
                            
                            	Identify the rekey authentication keypair
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Rekey.Authentication>`
                            
                            .. attribute:: lifetime
                            
                            	Define the rekey lifetime
                            	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Rekey.Lifetime>`
                            
                            .. attribute:: retransmit
                            
                            	Define the rekey retransmission parameters
                            	**type**\:  :py:class:`Retransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Rekey.Retransmit>`
                            
                            .. attribute:: sig_hash
                            
                            	Set rekey signature\-hash parameters
                            	**type**\:  :py:class:`SigHash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Rekey.SigHash>`
                            
                            .. attribute:: transport
                            
                            	Specify the rekey distribution method
                            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Rekey.Transport>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Server.Local.Rekey, self).__init__()

                                self.yang_name = "rekey"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Server.Local.Rekey.Address)), ("algorithm", ("algorithm", Native.Crypto.Gdoi.Group.Server.Local.Rekey.Algorithm)), ("authentication", ("authentication", Native.Crypto.Gdoi.Group.Server.Local.Rekey.Authentication)), ("lifetime", ("lifetime", Native.Crypto.Gdoi.Group.Server.Local.Rekey.Lifetime)), ("retransmit", ("retransmit", Native.Crypto.Gdoi.Group.Server.Local.Rekey.Retransmit)), ("sig-hash", ("sig_hash", Native.Crypto.Gdoi.Group.Server.Local.Rekey.SigHash)), ("transport", ("transport", Native.Crypto.Gdoi.Group.Server.Local.Rekey.Transport))])
                                self._leafs = OrderedDict([
                                    ('acknowledgement', (YLeaf(YType.enumeration, 'acknowledgement'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gdoi.Group.Server.Local.Rekey.Acknowledgement')])),
                                ])
                                self.acknowledgement = None

                                self.address = Native.Crypto.Gdoi.Group.Server.Local.Rekey.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.algorithm = Native.Crypto.Gdoi.Group.Server.Local.Rekey.Algorithm()
                                self.algorithm.parent = self
                                self._children_name_map["algorithm"] = "algorithm"

                                self.authentication = Native.Crypto.Gdoi.Group.Server.Local.Rekey.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"

                                self.lifetime = Native.Crypto.Gdoi.Group.Server.Local.Rekey.Lifetime()
                                self.lifetime.parent = self
                                self._children_name_map["lifetime"] = "lifetime"

                                self.retransmit = Native.Crypto.Gdoi.Group.Server.Local.Rekey.Retransmit()
                                self.retransmit.parent = self
                                self._children_name_map["retransmit"] = "retransmit"

                                self.sig_hash = Native.Crypto.Gdoi.Group.Server.Local.Rekey.SigHash()
                                self.sig_hash.parent = self
                                self._children_name_map["sig_hash"] = "sig-hash"

                                self.transport = Native.Crypto.Gdoi.Group.Server.Local.Rekey.Transport()
                                self.transport.parent = self
                                self._children_name_map["transport"] = "transport"
                                self._segment_path = lambda: "rekey"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Rekey, ['acknowledgement'], name, value)

                            class Acknowledgement(Enum):
                                """
                                Acknowledgement (Enum Class)

                                Request group members to acknowledge rekeys

                                .. data:: any = 0

                                .. data:: cisco = 1

                                .. data:: interoperable = 2

                                """

                                any = Enum.YLeaf(0, "any")

                                cisco = Enum.YLeaf(1, "cisco")

                                interoperable = Enum.YLeaf(2, "interoperable")



                            class Address(Entity):
                                """
                                Define the rekey packet format
                                
                                .. attribute:: ipv4
                                
                                	Match ipv4 packets
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 100..199
                                
                                		**type**\: int
                                
                                			**range:** 2000..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['int','int','str'])),
                                    ])
                                    self.ipv4 = None
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Address, ['ipv4'], name, value)


                            class Algorithm(Entity):
                                """
                                Set the rekey encryption algorithm
                                
                                .. attribute:: a3des_cbc
                                
                                	Triple DES in CBC mode
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: aes_128
                                
                                	128 bit AES
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: aes_192
                                
                                	192 bit AES
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: aes_256
                                
                                	256 bit AES
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: des_cbc
                                
                                	DES in CBC mode
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Algorithm, self).__init__()

                                    self.yang_name = "algorithm"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('a3des_cbc', (YLeaf(YType.empty, 'a3des-cbc'), ['Empty'])),
                                        ('aes_128', (YLeaf(YType.empty, 'aes-128'), ['Empty'])),
                                        ('aes_192', (YLeaf(YType.empty, 'aes-192'), ['Empty'])),
                                        ('aes_256', (YLeaf(YType.empty, 'aes-256'), ['Empty'])),
                                        ('des_cbc', (YLeaf(YType.empty, 'des-cbc'), ['Empty'])),
                                    ])
                                    self.a3des_cbc = None
                                    self.aes_128 = None
                                    self.aes_192 = None
                                    self.aes_256 = None
                                    self.des_cbc = None
                                    self._segment_path = lambda: "algorithm"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Algorithm, ['a3des_cbc', 'aes_128', 'aes_192', 'aes_256', 'des_cbc'], name, value)


                            class Authentication(Entity):
                                """
                                Identify the rekey authentication keypair
                                
                                .. attribute:: mypubkey
                                
                                	Identify a keypair associated with this device
                                	**type**\:  :py:class:`Mypubkey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Rekey.Authentication.Mypubkey>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mypubkey", ("mypubkey", Native.Crypto.Gdoi.Group.Server.Local.Rekey.Authentication.Mypubkey))])
                                    self._leafs = OrderedDict()

                                    self.mypubkey = Native.Crypto.Gdoi.Group.Server.Local.Rekey.Authentication.Mypubkey()
                                    self.mypubkey.parent = self
                                    self._children_name_map["mypubkey"] = "mypubkey"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Authentication, [], name, value)


                                class Mypubkey(Entity):
                                    """
                                    Identify a keypair associated with this device
                                    
                                    .. attribute:: rsa
                                    
                                    	Identify an RSA keypair
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Authentication.Mypubkey, self).__init__()

                                        self.yang_name = "mypubkey"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rsa', (YLeaf(YType.str, 'rsa'), ['str'])),
                                        ])
                                        self.rsa = None
                                        self._segment_path = lambda: "mypubkey"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Authentication.Mypubkey, ['rsa'], name, value)


                            class Lifetime(Entity):
                                """
                                Define the rekey lifetime
                                
                                .. attribute:: days
                                
                                	Time\-based key duration in days
                                	**type**\: int
                                
                                	**range:** 1..30
                                
                                .. attribute:: seconds
                                
                                	Time\-based key duration in seconds
                                	**type**\: int
                                
                                	**range:** 300..2592000
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Lifetime, self).__init__()

                                    self.yang_name = "lifetime"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('days', (YLeaf(YType.uint8, 'days'), ['int'])),
                                        ('seconds', (YLeaf(YType.uint64, 'seconds'), ['int'])),
                                    ])
                                    self.days = None
                                    self.seconds = None
                                    self._segment_path = lambda: "lifetime"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Lifetime, ['days', 'seconds'], name, value)


                            class Retransmit(Entity):
                                """
                                Define the rekey retransmission parameters
                                
                                .. attribute:: seconds
                                
                                	
                                	**type**\: int
                                
                                	**range:** 10..60
                                
                                .. attribute:: number
                                
                                	Retransmit this many times
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: periodic
                                
                                	Periodically send retransmit rekeys
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Retransmit, self).__init__()

                                    self.yang_name = "retransmit"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                        ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                                    ])
                                    self.seconds = None
                                    self.number = None
                                    self.periodic = None
                                    self._segment_path = lambda: "retransmit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Retransmit, ['seconds', 'number', 'periodic'], name, value)


                            class SigHash(Entity):
                                """
                                Set rekey signature\-hash parameters
                                
                                .. attribute:: algorithm
                                
                                	Set the rekey signature\-hash algorithm
                                	**type**\:  :py:class:`Algorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Rekey.SigHash.Algorithm>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Rekey.SigHash, self).__init__()

                                    self.yang_name = "sig-hash"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('algorithm', (YLeaf(YType.enumeration, 'algorithm'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gdoi.Group.Server.Local.Rekey.SigHash.Algorithm')])),
                                    ])
                                    self.algorithm = None
                                    self._segment_path = lambda: "sig-hash"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Rekey.SigHash, ['algorithm'], name, value)

                                class Algorithm(Enum):
                                    """
                                    Algorithm (Enum Class)

                                    Set the rekey signature\-hash algorithm

                                    .. data:: sha = 0

                                    .. data:: sha256 = 1

                                    .. data:: sha384 = 2

                                    .. data:: sha512 = 3

                                    """

                                    sha = Enum.YLeaf(0, "sha")

                                    sha256 = Enum.YLeaf(1, "sha256")

                                    sha384 = Enum.YLeaf(2, "sha384")

                                    sha512 = Enum.YLeaf(3, "sha512")



                            class Transport(Entity):
                                """
                                Specify the rekey distribution method
                                
                                .. attribute:: unicast
                                
                                	specify unicast rekey distribution
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Transport, self).__init__()

                                    self.yang_name = "transport"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                    ])
                                    self.unicast = None
                                    self._segment_path = lambda: "transport"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Rekey.Transport, ['unicast'], name, value)


                        class Sa(Entity):
                            """
                            Configure a security association
                            
                            .. attribute:: d3p
                            
                            	Enable IP delivery delay detection protocol for all SAs within the group
                            	**type**\:  :py:class:`D3p <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.D3p>`
                            
                            .. attribute:: ipsec
                            
                            	Configure an IPsec SA
                            	**type**\: list of  		 :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec>`
                            
                            .. attribute:: pair_wise_keying
                            
                            	Enable KGS pair\-wise\-keying
                            	**type**\:  :py:class:`PairWiseKeying <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.PairWiseKeying>`
                            
                            .. attribute:: receive_only
                            
                            	Configure SA to work only in inbound direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Server.Local.Sa, self).__init__()

                                self.yang_name = "sa"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("d3p", ("d3p", Native.Crypto.Gdoi.Group.Server.Local.Sa.D3p)), ("ipsec", ("ipsec", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec)), ("pair-wise-keying", ("pair_wise_keying", Native.Crypto.Gdoi.Group.Server.Local.Sa.PairWiseKeying))])
                                self._leafs = OrderedDict([
                                    ('receive_only', (YLeaf(YType.empty, 'receive-only'), ['Empty'])),
                                ])
                                self.receive_only = None

                                self.d3p = Native.Crypto.Gdoi.Group.Server.Local.Sa.D3p()
                                self.d3p.parent = self
                                self._children_name_map["d3p"] = "d3p"

                                self.pair_wise_keying = Native.Crypto.Gdoi.Group.Server.Local.Sa.PairWiseKeying()
                                self.pair_wise_keying.parent = self
                                self._children_name_map["pair_wise_keying"] = "pair-wise-keying"

                                self.ipsec = YList(self)
                                self._segment_path = lambda: "sa"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa, ['receive_only'], name, value)


                            class D3p(Entity):
                                """
                                Enable IP delivery delay detection protocol for all SAs within the group
                                
                                .. attribute:: window
                                
                                	IP\-D3P window size
                                	**type**\:  :py:class:`Window <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.D3p.Window>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Sa.D3p, self).__init__()

                                    self.yang_name = "d3p"
                                    self.yang_parent_name = "sa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("window", ("window", Native.Crypto.Gdoi.Group.Server.Local.Sa.D3p.Window))])
                                    self._leafs = OrderedDict()

                                    self.window = Native.Crypto.Gdoi.Group.Server.Local.Sa.D3p.Window()
                                    self.window.parent = self
                                    self._children_name_map["window"] = "window"
                                    self._segment_path = lambda: "d3p"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.D3p, [], name, value)


                                class Window(Entity):
                                    """
                                    IP\-D3P window size
                                    
                                    .. attribute:: msec
                                    
                                    	IP\-D3P window size in milliseconds
                                    	**type**\: int
                                    
                                    	**range:** 1000..100000
                                    
                                    .. attribute:: sec
                                    
                                    	IP\-D3P window size in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Sa.D3p.Window, self).__init__()

                                        self.yang_name = "window"
                                        self.yang_parent_name = "d3p"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('msec', (YLeaf(YType.uint32, 'msec'), ['int'])),
                                            ('sec', (YLeaf(YType.uint8, 'sec'), ['int'])),
                                        ])
                                        self.msec = None
                                        self.sec = None
                                        self._segment_path = lambda: "window"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.D3p.Window, ['msec', 'sec'], name, value)


                            class Ipsec(Entity):
                                """
                                Configure an IPsec SA
                                
                                .. attribute:: sequence  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: default
                                
                                	Set a command to its defaults
                                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default>`
                                
                                .. attribute:: match
                                
                                	Match characteristics of packets to encrypt
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Match>`
                                
                                .. attribute:: profile
                                
                                	Configure an ipsec profile for the SA
                                	**type**\: str
                                
                                .. attribute:: replay
                                
                                	Set replay method
                                	**type**\:  :py:class:`Replay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay>`
                                
                                .. attribute:: tag
                                
                                	Set inline tagging method
                                	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Tag>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec, self).__init__()

                                    self.yang_name = "ipsec"
                                    self.yang_parent_name = "sa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['sequence']
                                    self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default)), ("match", ("match", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Match)), ("replay", ("replay", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay)), ("tag", ("tag", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Tag))])
                                    self._leafs = OrderedDict([
                                        ('sequence', (YLeaf(YType.uint16, 'sequence'), ['int'])),
                                        ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                                    ])
                                    self.sequence = None
                                    self.profile = None

                                    self.default = Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.match = Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"

                                    self.replay = Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay()
                                    self.replay.parent = self
                                    self._children_name_map["replay"] = "replay"

                                    self.tag = Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Tag()
                                    self.tag.parent = self
                                    self._children_name_map["tag"] = "tag"
                                    self._segment_path = lambda: "ipsec" + "[sequence='" + str(self.sequence) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec, ['sequence', 'profile'], name, value)


                                class Default(Entity):
                                    """
                                    Set a command to its defaults
                                    
                                    .. attribute:: match
                                    
                                    	Match characteristics of packets to encrypt
                                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Match>`
                                    
                                    .. attribute:: profile
                                    
                                    	Configure an ipsec profile for the SA
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replay
                                    
                                    	Set replay method
                                    	**type**\:  :py:class:`Replay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Replay>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: tag
                                    
                                    	Set inline tagging method
                                    	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Tag>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ipsec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("match", ("match", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Match)), ("replay", ("replay", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Replay)), ("tag", ("tag", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Tag))])
                                        self._leafs = OrderedDict([
                                            ('profile', (YLeaf(YType.empty, 'profile'), ['Empty'])),
                                        ])
                                        self.profile = None

                                        self.match = Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Match()
                                        self.match.parent = self
                                        self._children_name_map["match"] = "match"

                                        self.replay = None
                                        self._children_name_map["replay"] = "replay"

                                        self.tag = None
                                        self._children_name_map["tag"] = "tag"
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default, ['profile'], name, value)


                                    class Match(Entity):
                                        """
                                        Match characteristics of packets to encrypt
                                        
                                        .. attribute:: address
                                        
                                        	Match addresses of packets to encrypt
                                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Match.Address>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Match, self).__init__()

                                            self.yang_name = "match"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Match.Address))])
                                            self._leafs = OrderedDict()

                                            self.address = None
                                            self._children_name_map["address"] = "address"
                                            self._segment_path = lambda: "match"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Match, [], name, value)


                                        class Address(Entity):
                                            """
                                            Match addresses of packets to encrypt
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-crypto'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Match.Address, self).__init__()

                                                self.yang_name = "address"
                                                self.yang_parent_name = "match"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()
                                                self._segment_path = lambda: "address"
                                                self._is_frozen = True


                                    class Replay(Entity):
                                        """
                                        Set replay method
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Replay, self).__init__()

                                            self.yang_name = "replay"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()
                                            self._segment_path = lambda: "replay"
                                            self._is_frozen = True


                                    class Tag(Entity):
                                        """
                                        Set inline tagging method
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Default.Tag, self).__init__()

                                            self.yang_name = "tag"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()
                                            self._segment_path = lambda: "tag"
                                            self._is_frozen = True


                                class Match(Entity):
                                    """
                                    Match characteristics of packets to encrypt
                                    
                                    .. attribute:: address
                                    
                                    	Match addresses of packets to encrypt
                                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Match.Address>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ipsec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Match.Address))])
                                        self._leafs = OrderedDict()

                                        self.address = Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Match.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Match, [], name, value)


                                    class Address(Entity):
                                        """
                                        Match addresses of packets to encrypt
                                        
                                        .. attribute:: ipv4
                                        
                                        	Match ipv4 packets
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 100..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 2000..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        .. attribute:: ipv6
                                        
                                        	Match ipv6 packets
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Match.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['int','int','str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Match.Address, ['ipv4', 'ipv6'], name, value)


                                class Replay(Entity):
                                    """
                                    Set replay method
                                    
                                    .. attribute:: counter
                                    
                                    	Enable anti\-replay check for single source traffic by using sequence number
                                    	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay.Counter>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: time
                                    
                                    	Enable anti\-replay check for any traffic by using time
                                    	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay.Time>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay, self).__init__()

                                        self.yang_name = "replay"
                                        self.yang_parent_name = "ipsec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("counter", ("counter", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay.Counter)), ("time", ("time", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay.Time))])
                                        self._leafs = OrderedDict()

                                        self.counter = None
                                        self._children_name_map["counter"] = "counter"

                                        self.time = None
                                        self._children_name_map["time"] = "time"
                                        self._segment_path = lambda: "replay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay, [], name, value)


                                    class Counter(Entity):
                                        """
                                        Enable anti\-replay check for single source traffic by using sequence number
                                        
                                        .. attribute:: window_size
                                        
                                        	Set replay window size
                                        	**type**\:  :py:class:`WindowSize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay.Counter.WindowSize>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay.Counter, self).__init__()

                                            self.yang_name = "counter"
                                            self.yang_parent_name = "replay"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('window_size', (YLeaf(YType.enumeration, 'window-size'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay.Counter.WindowSize')])),
                                            ])
                                            self.window_size = None
                                            self._segment_path = lambda: "counter"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay.Counter, ['window_size'], name, value)

                                        class WindowSize(Enum):
                                            """
                                            WindowSize (Enum Class)

                                            Set replay window size.

                                            .. data:: Y_1024 = 0

                                            .. data:: Y_128 = 1

                                            .. data:: Y_256 = 2

                                            .. data:: Y_512 = 3

                                            .. data:: Y_64 = 4

                                            """

                                            Y_1024 = Enum.YLeaf(0, "1024")

                                            Y_128 = Enum.YLeaf(1, "128")

                                            Y_256 = Enum.YLeaf(2, "256")

                                            Y_512 = Enum.YLeaf(3, "512")

                                            Y_64 = Enum.YLeaf(4, "64")



                                    class Time(Entity):
                                        """
                                        Enable anti\-replay check for any traffic by using time
                                        
                                        .. attribute:: window_size
                                        
                                        	Time based replay window size
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay.Time, self).__init__()

                                            self.yang_name = "time"
                                            self.yang_parent_name = "replay"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                                            ])
                                            self.window_size = None
                                            self._segment_path = lambda: "time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Replay.Time, ['window_size'], name, value)


                                class Tag(Entity):
                                    """
                                    Set inline tagging method
                                    
                                    .. attribute:: cts
                                    
                                    	Cisco Trust Security
                                    	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Tag.Cts>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Tag, self).__init__()

                                        self.yang_name = "tag"
                                        self.yang_parent_name = "ipsec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("cts", ("cts", Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Tag.Cts))])
                                        self._leafs = OrderedDict()

                                        self.cts = Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Tag.Cts()
                                        self.cts.parent = self
                                        self._children_name_map["cts"] = "cts"
                                        self._segment_path = lambda: "tag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Tag, [], name, value)


                                    class Cts(Entity):
                                        """
                                        Cisco Trust Security
                                        
                                        .. attribute:: sgt
                                        
                                        	Security Group Tag
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Tag.Cts, self).__init__()

                                            self.yang_name = "cts"
                                            self.yang_parent_name = "tag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ])
                                            self.sgt = None
                                            self._segment_path = lambda: "cts"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.Ipsec.Tag.Cts, ['sgt'], name, value)


                            class PairWiseKeying(Entity):
                                """
                                Enable KGS pair\-wise\-keying
                                
                                .. attribute:: safety_limit
                                
                                	KGS safety limit
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Sa.PairWiseKeying, self).__init__()

                                    self.yang_name = "pair-wise-keying"
                                    self.yang_parent_name = "sa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('safety_limit', (YLeaf(YType.uint8, 'safety-limit'), ['int'])),
                                    ])
                                    self.safety_limit = None
                                    self._segment_path = lambda: "pair-wise-keying"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Sa.PairWiseKeying, ['safety_limit'], name, value)


                        class Default(Entity):
                            """
                            Set a command to its defaults
                            
                            .. attribute:: address
                            
                            	Configure server source address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Address>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: authorization
                            
                            	Configure authorization for the group
                            	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Authorization>`
                            
                            .. attribute:: gdoi
                            
                            	Enable GDOI (ISAKMP) Protocol for Registration & Rekey
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: gikev2
                            
                            	Enable G\-IKEv2 (IKEv2) Protocol for Registration & Rekey
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: group
                            
                            	Configure parameters for the group (e.g. Suite\-B)
                            	**type**\:  :py:class:`Group_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Group_>`
                            
                            .. attribute:: identifier
                            
                            	Enter Suite\-B KSSID (Key Server Sender ID) config mode
                            	**type**\:  :py:class:`Identifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Identifier>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: redundancy
                            
                            	Enter cooperative key server configuration mode
                            	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Redundancy>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: registration
                            
                            	Configure registration for the group
                            	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Registration>`
                            
                            .. attribute:: rekey
                            
                            	Configure rekey policy for the group
                            	**type**\:  :py:class:`Rekey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey>`
                            
                            .. attribute:: sa
                            
                            	Configure a security association
                            	**type**\:  :py:class:`Sa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Sa>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Server.Local.Default, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Server.Local.Default.Address)), ("authorization", ("authorization", Native.Crypto.Gdoi.Group.Server.Local.Default.Authorization)), ("group", ("group", Native.Crypto.Gdoi.Group.Server.Local.Default.Group_)), ("identifier", ("identifier", Native.Crypto.Gdoi.Group.Server.Local.Default.Identifier)), ("redundancy", ("redundancy", Native.Crypto.Gdoi.Group.Server.Local.Default.Redundancy)), ("registration", ("registration", Native.Crypto.Gdoi.Group.Server.Local.Default.Registration)), ("rekey", ("rekey", Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey)), ("sa", ("sa", Native.Crypto.Gdoi.Group.Server.Local.Default.Sa))])
                                self._leafs = OrderedDict([
                                    ('gdoi', (YLeaf(YType.empty, 'gdoi'), ['Empty'])),
                                    ('gikev2', (YLeaf(YType.empty, 'gikev2'), ['Empty'])),
                                ])
                                self.gdoi = None
                                self.gikev2 = None

                                self.address = None
                                self._children_name_map["address"] = "address"

                                self.authorization = Native.Crypto.Gdoi.Group.Server.Local.Default.Authorization()
                                self.authorization.parent = self
                                self._children_name_map["authorization"] = "authorization"

                                self.group = Native.Crypto.Gdoi.Group.Server.Local.Default.Group_()
                                self.group.parent = self
                                self._children_name_map["group"] = "group"

                                self.identifier = None
                                self._children_name_map["identifier"] = "identifier"

                                self.redundancy = None
                                self._children_name_map["redundancy"] = "redundancy"

                                self.registration = Native.Crypto.Gdoi.Group.Server.Local.Default.Registration()
                                self.registration.parent = self
                                self._children_name_map["registration"] = "registration"

                                self.rekey = Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey()
                                self.rekey.parent = self
                                self._children_name_map["rekey"] = "rekey"

                                self.sa = Native.Crypto.Gdoi.Group.Server.Local.Default.Sa()
                                self.sa.parent = self
                                self._children_name_map["sa"] = "sa"
                                self._segment_path = lambda: "default"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default, ['gdoi', 'gikev2'], name, value)


                            class Address(Entity):
                                """
                                Configure server source address
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Default.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True


                            class Authorization(Entity):
                                """
                                Configure authorization for the group
                                
                                .. attribute:: address
                                
                                	Set authorization by address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Authorization.Address>`
                                
                                .. attribute:: identity
                                
                                	Set authorization by identity
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Default.Authorization, self).__init__()

                                    self.yang_name = "authorization"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Server.Local.Default.Authorization.Address))])
                                    self._leafs = OrderedDict([
                                        ('identity', (YLeaf(YType.empty, 'identity'), ['Empty'])),
                                    ])
                                    self.identity = None

                                    self.address = Native.Crypto.Gdoi.Group.Server.Local.Default.Authorization.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "authorization"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Authorization, ['identity'], name, value)


                                class Address(Entity):
                                    """
                                    Set authorization by address
                                    
                                    .. attribute:: ipv4
                                    
                                    	Set authorization by address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Authorization.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "authorization"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Authorization.Address, ['ipv4'], name, value)


                            class Group_(Entity):
                                """
                                Configure parameters for the group (e.g. Suite\-B)
                                
                                .. attribute:: size
                                
                                	Set Group Size for Suite\-B counter transforms (SID length)
                                	**type**\:  :py:class:`Size <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Group_.Size>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Default.Group_, self).__init__()

                                    self.yang_name = "group"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("size", ("size", Native.Crypto.Gdoi.Group.Server.Local.Default.Group_.Size))])
                                    self._leafs = OrderedDict()

                                    self.size = None
                                    self._children_name_map["size"] = "size"
                                    self._segment_path = lambda: "group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Group_, [], name, value)


                                class Size(Entity):
                                    """
                                    Set Group Size for Suite\-B counter transforms (SID length)
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Group_.Size, self).__init__()

                                        self.yang_name = "size"
                                        self.yang_parent_name = "group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "size"
                                        self._is_frozen = True


                            class Identifier(Entity):
                                """
                                Enter Suite\-B KSSID (Key Server Sender ID) config mode
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Default.Identifier, self).__init__()

                                    self.yang_name = "identifier"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "identifier"
                                    self._is_frozen = True


                            class Redundancy(Entity):
                                """
                                Enter cooperative key server configuration mode
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Default.Redundancy, self).__init__()

                                    self.yang_name = "redundancy"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "redundancy"
                                    self._is_frozen = True


                            class Registration(Entity):
                                """
                                Configure registration for the group
                                
                                .. attribute:: interface
                                
                                	Identify an interface on which to respond to GKM registrations
                                	**type**\: str
                                
                                .. attribute:: periodic
                                
                                	Define periodic registrations for the group
                                	**type**\:  :py:class:`Periodic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Registration.Periodic>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Default.Registration, self).__init__()

                                    self.yang_name = "registration"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("periodic", ("periodic", Native.Crypto.Gdoi.Group.Server.Local.Default.Registration.Periodic))])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ])
                                    self.interface = None

                                    self.periodic = Native.Crypto.Gdoi.Group.Server.Local.Default.Registration.Periodic()
                                    self.periodic.parent = self
                                    self._children_name_map["periodic"] = "periodic"
                                    self._segment_path = lambda: "registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Registration, ['interface'], name, value)


                                class Periodic(Entity):
                                    """
                                    Define periodic registrations for the group
                                    
                                    .. attribute:: crl
                                    
                                    	On every new CRL
                                    	**type**\:  :py:class:`Crl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Registration.Periodic.Crl>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Registration.Periodic, self).__init__()

                                        self.yang_name = "periodic"
                                        self.yang_parent_name = "registration"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("crl", ("crl", Native.Crypto.Gdoi.Group.Server.Local.Default.Registration.Periodic.Crl))])
                                        self._leafs = OrderedDict()

                                        self.crl = Native.Crypto.Gdoi.Group.Server.Local.Default.Registration.Periodic.Crl()
                                        self.crl.parent = self
                                        self._children_name_map["crl"] = "crl"
                                        self._segment_path = lambda: "periodic"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Registration.Periodic, [], name, value)


                                    class Crl(Entity):
                                        """
                                        On every new CRL
                                        
                                        .. attribute:: trustpoint
                                        
                                        	For a PKI trustpoint
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gdoi.Group.Server.Local.Default.Registration.Periodic.Crl, self).__init__()

                                            self.yang_name = "crl"
                                            self.yang_parent_name = "periodic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('trustpoint', (YLeaf(YType.empty, 'trustpoint'), ['Empty'])),
                                            ])
                                            self.trustpoint = None
                                            self._segment_path = lambda: "crl"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Registration.Periodic.Crl, ['trustpoint'], name, value)


                            class Rekey(Entity):
                                """
                                Configure rekey policy for the group
                                
                                .. attribute:: acknowledgement
                                
                                	Request group members to acknowledge rekeys
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: address
                                
                                	Define the rekey packet format
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Address>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: algorithm
                                
                                	Set the rekey encryption algorithm
                                	**type**\:  :py:class:`Algorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Algorithm>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: authentication
                                
                                	Identify the rekey authentication keypair
                                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Authentication>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: lifetime
                                
                                	Define the rekey lifetime
                                	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Lifetime>`
                                
                                .. attribute:: retransmit
                                
                                	Define the rekey retransmission parameters
                                	**type**\:  :py:class:`Retransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Retransmit>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: sig_hash
                                
                                	Set rekey signature\-hash parameters
                                	**type**\:  :py:class:`SigHash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.SigHash>`
                                
                                .. attribute:: transport
                                
                                	Specify the rekey distribution method
                                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Transport>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey, self).__init__()

                                    self.yang_name = "rekey"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Address)), ("algorithm", ("algorithm", Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Algorithm)), ("authentication", ("authentication", Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Authentication)), ("lifetime", ("lifetime", Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Lifetime)), ("retransmit", ("retransmit", Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Retransmit)), ("sig-hash", ("sig_hash", Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.SigHash)), ("transport", ("transport", Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Transport))])
                                    self._leafs = OrderedDict([
                                        ('acknowledgement', (YLeaf(YType.empty, 'acknowledgement'), ['Empty'])),
                                    ])
                                    self.acknowledgement = None

                                    self.address = None
                                    self._children_name_map["address"] = "address"

                                    self.algorithm = None
                                    self._children_name_map["algorithm"] = "algorithm"

                                    self.authentication = None
                                    self._children_name_map["authentication"] = "authentication"

                                    self.lifetime = Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Lifetime()
                                    self.lifetime.parent = self
                                    self._children_name_map["lifetime"] = "lifetime"

                                    self.retransmit = None
                                    self._children_name_map["retransmit"] = "retransmit"

                                    self.sig_hash = Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.SigHash()
                                    self.sig_hash.parent = self
                                    self._children_name_map["sig_hash"] = "sig-hash"

                                    self.transport = Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Transport()
                                    self.transport.parent = self
                                    self._children_name_map["transport"] = "transport"
                                    self._segment_path = lambda: "rekey"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey, ['acknowledgement'], name, value)


                                class Address(Entity):
                                    """
                                    Define the rekey packet format
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True


                                class Algorithm(Entity):
                                    """
                                    Set the rekey encryption algorithm
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Algorithm, self).__init__()

                                        self.yang_name = "algorithm"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "algorithm"
                                        self._is_frozen = True


                                class Authentication(Entity):
                                    """
                                    Identify the rekey authentication keypair
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "authentication"
                                        self._is_frozen = True


                                class Lifetime(Entity):
                                    """
                                    Define the rekey lifetime
                                    
                                    .. attribute:: days
                                    
                                    	Time\-based key duration in days
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: seconds
                                    
                                    	Time\-based key duration in seconds
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Lifetime, self).__init__()

                                        self.yang_name = "lifetime"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('days', (YLeaf(YType.empty, 'days'), ['Empty'])),
                                            ('seconds', (YLeaf(YType.empty, 'seconds'), ['Empty'])),
                                        ])
                                        self.days = None
                                        self.seconds = None
                                        self._segment_path = lambda: "lifetime"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Lifetime, ['days', 'seconds'], name, value)


                                class Retransmit(Entity):
                                    """
                                    Define the rekey retransmission parameters
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Retransmit, self).__init__()

                                        self.yang_name = "retransmit"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "retransmit"
                                        self._is_frozen = True


                                class SigHash(Entity):
                                    """
                                    Set rekey signature\-hash parameters
                                    
                                    .. attribute:: algorithm
                                    
                                    	Set the rekey signature\-hash algorithm
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.SigHash, self).__init__()

                                        self.yang_name = "sig-hash"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('algorithm', (YLeaf(YType.empty, 'algorithm'), ['Empty'])),
                                        ])
                                        self.algorithm = None
                                        self._segment_path = lambda: "sig-hash"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.SigHash, ['algorithm'], name, value)


                                class Transport(Entity):
                                    """
                                    Specify the rekey distribution method
                                    
                                    .. attribute:: unicast
                                    
                                    	specify unicast rekey distribution
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Transport, self).__init__()

                                        self.yang_name = "transport"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                        ])
                                        self.unicast = None
                                        self._segment_path = lambda: "transport"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Rekey.Transport, ['unicast'], name, value)


                            class Sa(Entity):
                                """
                                Configure a security association
                                
                                .. attribute:: d3p
                                
                                	Enable IP delivery delay detection protocol for all SAs within the group
                                	**type**\:  :py:class:`D3p <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Sa.D3p>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ipsec
                                
                                	Configure an IPsec SA
                                	**type**\: list of  		 :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Sa.Ipsec>`
                                
                                .. attribute:: pair_wise_keying
                                
                                	Enable KGS pair\-wise\-keying
                                	**type**\:  :py:class:`PairWiseKeying <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Server.Local.Default.Sa.PairWiseKeying>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: receive_only
                                
                                	Configure SA to work only in inbound direction
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Server.Local.Default.Sa, self).__init__()

                                    self.yang_name = "sa"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("d3p", ("d3p", Native.Crypto.Gdoi.Group.Server.Local.Default.Sa.D3p)), ("ipsec", ("ipsec", Native.Crypto.Gdoi.Group.Server.Local.Default.Sa.Ipsec)), ("pair-wise-keying", ("pair_wise_keying", Native.Crypto.Gdoi.Group.Server.Local.Default.Sa.PairWiseKeying))])
                                    self._leafs = OrderedDict([
                                        ('receive_only', (YLeaf(YType.empty, 'receive-only'), ['Empty'])),
                                    ])
                                    self.receive_only = None

                                    self.d3p = None
                                    self._children_name_map["d3p"] = "d3p"

                                    self.pair_wise_keying = None
                                    self._children_name_map["pair_wise_keying"] = "pair-wise-keying"

                                    self.ipsec = YList(self)
                                    self._segment_path = lambda: "sa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Sa, ['receive_only'], name, value)


                                class D3p(Entity):
                                    """
                                    Enable IP delivery delay detection protocol for all SAs within the group
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Sa.D3p, self).__init__()

                                        self.yang_name = "d3p"
                                        self.yang_parent_name = "sa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "d3p"
                                        self._is_frozen = True


                                class Ipsec(Entity):
                                    """
                                    Configure an IPsec SA
                                    
                                    .. attribute:: sequence  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Sa.Ipsec, self).__init__()

                                        self.yang_name = "ipsec"
                                        self.yang_parent_name = "sa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['sequence']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence', (YLeaf(YType.uint16, 'sequence'), ['int'])),
                                        ])
                                        self.sequence = None
                                        self._segment_path = lambda: "ipsec" + "[sequence='" + str(self.sequence) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gdoi.Group.Server.Local.Default.Sa.Ipsec, ['sequence'], name, value)


                                class PairWiseKeying(Entity):
                                    """
                                    Enable KGS pair\-wise\-keying
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gdoi.Group.Server.Local.Default.Sa.PairWiseKeying, self).__init__()

                                        self.yang_name = "pair-wise-keying"
                                        self.yang_parent_name = "sa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "pair-wise-keying"
                                        self._is_frozen = True


                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: client
                    
                    	Set the group client parameters
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Client>`
                    
                    .. attribute:: identity
                    
                    	Set the identity of the group
                    	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Identity>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: passive
                    
                    	Set the group in passive mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: server
                    
                    	Set the group server for of the group
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Server>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Gdoi.Group.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("client", ("client", Native.Crypto.Gdoi.Group.Default.Client)), ("identity", ("identity", Native.Crypto.Gdoi.Group.Default.Identity)), ("server", ("server", Native.Crypto.Gdoi.Group.Default.Server))])
                        self._leafs = OrderedDict([
                            ('passive', (YLeaf(YType.empty, 'passive'), ['Empty'])),
                        ])
                        self.passive = None

                        self.client = Native.Crypto.Gdoi.Group.Default.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "client"

                        self.identity = None
                        self._children_name_map["identity"] = "identity"

                        self.server = Native.Crypto.Gdoi.Group.Default.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Gdoi.Group.Default, ['passive'], name, value)


                    class Client(Entity):
                        """
                        Set the group client parameters
                        
                        .. attribute:: bypass_policy
                        
                        	Allow group\-key management traffic sent to this GM only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: protocol
                        
                        	Group Member Registration & Rekey Protocol
                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Client.Protocol>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: recovery_check
                        
                        	Specify GM recovery check parameters
                        	**type**\:  :py:class:`RecoveryCheck <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Client.RecoveryCheck>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: registration
                        
                        	Set the group client management/register interface
                        	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Client.Registration>`
                        
                        .. attribute:: rekey
                        
                        	Set the group client acceptable rekey ciphers and hashs
                        	**type**\:  :py:class:`Rekey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Client.Rekey>`
                        
                        .. attribute:: status
                        
                        	group\-member status
                        	**type**\:  :py:class:`Status <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Client.Status>`
                        
                        .. attribute:: transform_sets
                        
                        	Specify list of group client acceptable transform sets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: transport_encrypt_key
                        
                        	Enforce group or pair\-wise keying
                        	**type**\:  :py:class:`TransportEncryptKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Client.TransportEncryptKey>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Default.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol", ("protocol", Native.Crypto.Gdoi.Group.Default.Client.Protocol)), ("recovery-check", ("recovery_check", Native.Crypto.Gdoi.Group.Default.Client.RecoveryCheck)), ("registration", ("registration", Native.Crypto.Gdoi.Group.Default.Client.Registration)), ("rekey", ("rekey", Native.Crypto.Gdoi.Group.Default.Client.Rekey)), ("status", ("status", Native.Crypto.Gdoi.Group.Default.Client.Status))])
                            self._leafs = OrderedDict([
                                ('bypass_policy', (YLeaf(YType.empty, 'bypass-policy'), ['Empty'])),
                                ('transform_sets', (YLeaf(YType.empty, 'transform-sets'), ['Empty'])),
                                ('transport_encrypt_key', (YLeaf(YType.enumeration, 'transport-encrypt-key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gdoi.Group.Default.Client.TransportEncryptKey')])),
                            ])
                            self.bypass_policy = None
                            self.transform_sets = None
                            self.transport_encrypt_key = None

                            self.protocol = None
                            self._children_name_map["protocol"] = "protocol"

                            self.recovery_check = None
                            self._children_name_map["recovery_check"] = "recovery-check"

                            self.registration = Native.Crypto.Gdoi.Group.Default.Client.Registration()
                            self.registration.parent = self
                            self._children_name_map["registration"] = "registration"

                            self.rekey = Native.Crypto.Gdoi.Group.Default.Client.Rekey()
                            self.rekey.parent = self
                            self._children_name_map["rekey"] = "rekey"

                            self.status = Native.Crypto.Gdoi.Group.Default.Client.Status()
                            self.status.parent = self
                            self._children_name_map["status"] = "status"
                            self._segment_path = lambda: "client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gdoi.Group.Default.Client, ['bypass_policy', 'transform_sets', 'transport_encrypt_key'], name, value)

                        class TransportEncryptKey(Enum):
                            """
                            TransportEncryptKey (Enum Class)

                            Enforce group or pair\-wise keying

                            .. data:: group_key = 0

                            .. data:: pair_wise_key = 1

                            """

                            group_key = Enum.YLeaf(0, "group-key")

                            pair_wise_key = Enum.YLeaf(1, "pair-wise-key")



                        class Protocol(Entity):
                            """
                            Group Member Registration & Rekey Protocol
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Default.Client.Protocol, self).__init__()

                                self.yang_name = "protocol"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "protocol"
                                self._is_frozen = True


                        class RecoveryCheck(Entity):
                            """
                            Specify GM recovery check parameters
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Default.Client.RecoveryCheck, self).__init__()

                                self.yang_name = "recovery-check"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "recovery-check"
                                self._is_frozen = True


                        class Registration(Entity):
                            """
                            Set the group client management/register interface
                            
                            .. attribute:: interface
                            
                            	Set the group client management/register interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Default.Client.Registration, self).__init__()

                                self.yang_name = "registration"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                                ])
                                self.interface = None
                                self._segment_path = lambda: "registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Default.Client.Registration, ['interface'], name, value)


                        class Rekey(Entity):
                            """
                            Set the group client acceptable rekey ciphers and hashs
                            
                            .. attribute:: encryption
                            
                            	Set the group client acceptable rekey ciphers
                            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Client.Rekey.Encryption>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: hash
                            
                            	Set the group client acceptable rekey hash
                            	**type**\:  :py:class:`Hash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Client.Rekey.Hash>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Default.Client.Rekey, self).__init__()

                                self.yang_name = "rekey"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("encryption", ("encryption", Native.Crypto.Gdoi.Group.Default.Client.Rekey.Encryption)), ("hash", ("hash", Native.Crypto.Gdoi.Group.Default.Client.Rekey.Hash))])
                                self._leafs = OrderedDict()

                                self.encryption = None
                                self._children_name_map["encryption"] = "encryption"

                                self.hash = None
                                self._children_name_map["hash"] = "hash"
                                self._segment_path = lambda: "rekey"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Default.Client.Rekey, [], name, value)


                            class Encryption(Entity):
                                """
                                Set the group client acceptable rekey ciphers
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Default.Client.Rekey.Encryption, self).__init__()

                                    self.yang_name = "encryption"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "encryption"
                                    self._is_frozen = True


                            class Hash(Entity):
                                """
                                Set the group client acceptable rekey hash
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Default.Client.Rekey.Hash, self).__init__()

                                    self.yang_name = "hash"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "hash"
                                    self._is_frozen = True


                        class Status(Entity):
                            """
                            group\-member status
                            
                            .. attribute:: active_sa
                            
                            	TEK SA with positive remaining lifetime
                            	**type**\:  :py:class:`ActiveSa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Client.Status.ActiveSa>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Default.Client.Status, self).__init__()

                                self.yang_name = "status"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("active-sa", ("active_sa", Native.Crypto.Gdoi.Group.Default.Client.Status.ActiveSa))])
                                self._leafs = OrderedDict()

                                self.active_sa = None
                                self._children_name_map["active_sa"] = "active-sa"
                                self._segment_path = lambda: "status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Default.Client.Status, [], name, value)


                            class ActiveSa(Entity):
                                """
                                TEK SA with positive remaining lifetime
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gdoi.Group.Default.Client.Status.ActiveSa, self).__init__()

                                    self.yang_name = "active-sa"
                                    self.yang_parent_name = "status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "active-sa"
                                    self._is_frozen = True


                    class Identity(Entity):
                        """
                        Set the identity of the group
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Default.Identity, self).__init__()

                            self.yang_name = "identity"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "identity"
                            self._is_frozen = True


                    class Server(Entity):
                        """
                        Set the group server for of the group
                        
                        .. attribute:: address
                        
                        	Identify the group server by address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Server.Address>`
                        
                        .. attribute:: hostname
                        
                        	Identify the group server by hostname
                        	**type**\:  :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gdoi.Group.Default.Server.Hostname>`
                        
                        .. attribute:: local
                        
                        	Configure GKM group server defined locally
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gdoi.Group.Default.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gdoi.Group.Default.Server.Address)), ("hostname", ("hostname", Native.Crypto.Gdoi.Group.Default.Server.Hostname))])
                            self._leafs = OrderedDict([
                                ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ])
                            self.local = None

                            self.address = Native.Crypto.Gdoi.Group.Default.Server.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"

                            self.hostname = Native.Crypto.Gdoi.Group.Default.Server.Hostname()
                            self.hostname.parent = self
                            self._children_name_map["hostname"] = "hostname"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gdoi.Group.Default.Server, ['local'], name, value)


                        class Address(Entity):
                            """
                            Identify the group server by address
                            
                            .. attribute:: ipv4
                            
                            	Set the IPv4 address of the group server
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Default.Server.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ])
                                self.ipv4 = None
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Default.Server.Address, ['ipv4'], name, value)


                        class Hostname(Entity):
                            """
                            Identify the group server by hostname
                            
                            .. attribute:: ipv4
                            
                            	Set the IPv4 hostname of the group server
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gdoi.Group.Default.Server.Hostname, self).__init__()

                                self.yang_name = "hostname"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ])
                                self.ipv4 = None
                                self._segment_path = lambda: "hostname"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gdoi.Group.Default.Server.Hostname, ['ipv4'], name, value)


        class Ikev2(Entity):
            """
            Configure IKEv2 Options
            
            .. attribute:: authorization
            
            	IKEv2 authorization
            	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Authorization>`
            
            .. attribute:: certificate_cache
            
            	Cache for storing certs fetched from HTTP URLs
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: client
            
            	IKEv2 client configuration
            	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Client>`
            
            .. attribute:: cluster
            
            	Cluster load\-balancer settings
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cookie_challenge
            
            	Set Cookie\-challenge watermark
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: cts
            
            	Cisco Trust Security
            	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Cts>`
            
            .. attribute:: diagnose
            
            	IKEV2 diagnose
            	**type**\:  :py:class:`Diagnose <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Diagnose>`
            
            .. attribute:: disconnect_revoked_peers
            
            	Disconnect Crypto Session with Cert Revoked Peer
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: dpd_container
            
            	
            	**type**\:  :py:class:`DpdContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.DpdContainer>`
            
            .. attribute:: fragmentation
            
            	Enable fragmentation of ikev2 packets
            	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Fragmentation>`
            
            	**presence node**\: True
            
            .. attribute:: http_url
            
            	Enable http URL lookup
            	**type**\:  :py:class:`HttpUrl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.HttpUrl>`
            
            .. attribute:: keyring
            
            	Define IKEv2 Keyring
            	**type**\: list of  		 :py:class:`Keyring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Keyring>`
            
            .. attribute:: limit
            
            	Limit the number of maximum and negotiating sa
            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Limit>`
            
            .. attribute:: name_mangler
            
            	Name mangler
            	**type**\: str
            
            .. attribute:: nat
            
            	NAT\-transparency
            	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Nat>`
            
            .. attribute:: policy
            
            	Define IKEV2 policies
            	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Policy>`
            
            .. attribute:: profile
            
            	Define IKEV2 profiles
            	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile>`
            
            .. attribute:: proposal
            
            	Define IKEV2 proposals
            	**type**\: list of  		 :py:class:`Proposal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Proposal>`
            
            .. attribute:: reconnect
            
            	Cluster Reconnect
            	**type**\:  :py:class:`Reconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Reconnect>`
            
            .. attribute:: redirect
            
            	IKEv2 Redirect Mechanism for load\-balancing
            	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Redirect>`
            
            .. attribute:: window
            
            	IKEV2 window size
            	**type**\: int
            
            	**range:** 0..255
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Ikev2, self).__init__()

                self.yang_name = "ikev2"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("authorization", ("authorization", Native.Crypto.Ikev2.Authorization)), ("client", ("client", Native.Crypto.Ikev2.Client)), ("cts", ("cts", Native.Crypto.Ikev2.Cts)), ("diagnose", ("diagnose", Native.Crypto.Ikev2.Diagnose)), ("dpd-container", ("dpd_container", Native.Crypto.Ikev2.DpdContainer)), ("fragmentation", ("fragmentation", Native.Crypto.Ikev2.Fragmentation)), ("http-url", ("http_url", Native.Crypto.Ikev2.HttpUrl)), ("keyring", ("keyring", Native.Crypto.Ikev2.Keyring)), ("limit", ("limit", Native.Crypto.Ikev2.Limit)), ("nat", ("nat", Native.Crypto.Ikev2.Nat)), ("policy", ("policy", Native.Crypto.Ikev2.Policy)), ("profile", ("profile", Native.Crypto.Ikev2.Profile)), ("proposal", ("proposal", Native.Crypto.Ikev2.Proposal)), ("reconnect", ("reconnect", Native.Crypto.Ikev2.Reconnect)), ("redirect", ("redirect", Native.Crypto.Ikev2.Redirect))])
                self._leafs = OrderedDict([
                    ('certificate_cache', (YLeaf(YType.uint16, 'certificate-cache'), ['int'])),
                    ('cluster', (YLeaf(YType.empty, 'cluster'), ['Empty'])),
                    ('cookie_challenge', (YLeaf(YType.uint16, 'cookie-challenge'), ['int'])),
                    ('disconnect_revoked_peers', (YLeaf(YType.empty, 'disconnect-revoked-peers'), ['Empty'])),
                    ('name_mangler', (YLeaf(YType.str, 'name-mangler'), ['str'])),
                    ('window', (YLeaf(YType.uint8, 'window'), ['int'])),
                ])
                self.certificate_cache = None
                self.cluster = None
                self.cookie_challenge = None
                self.disconnect_revoked_peers = None
                self.name_mangler = None
                self.window = None

                self.authorization = Native.Crypto.Ikev2.Authorization()
                self.authorization.parent = self
                self._children_name_map["authorization"] = "authorization"

                self.client = Native.Crypto.Ikev2.Client()
                self.client.parent = self
                self._children_name_map["client"] = "client"

                self.cts = Native.Crypto.Ikev2.Cts()
                self.cts.parent = self
                self._children_name_map["cts"] = "cts"

                self.diagnose = Native.Crypto.Ikev2.Diagnose()
                self.diagnose.parent = self
                self._children_name_map["diagnose"] = "diagnose"

                self.dpd_container = Native.Crypto.Ikev2.DpdContainer()
                self.dpd_container.parent = self
                self._children_name_map["dpd_container"] = "dpd-container"

                self.fragmentation = None
                self._children_name_map["fragmentation"] = "fragmentation"

                self.http_url = Native.Crypto.Ikev2.HttpUrl()
                self.http_url.parent = self
                self._children_name_map["http_url"] = "http-url"

                self.limit = Native.Crypto.Ikev2.Limit()
                self.limit.parent = self
                self._children_name_map["limit"] = "limit"

                self.nat = Native.Crypto.Ikev2.Nat()
                self.nat.parent = self
                self._children_name_map["nat"] = "nat"

                self.reconnect = Native.Crypto.Ikev2.Reconnect()
                self.reconnect.parent = self
                self._children_name_map["reconnect"] = "reconnect"

                self.redirect = Native.Crypto.Ikev2.Redirect()
                self.redirect.parent = self
                self._children_name_map["redirect"] = "redirect"

                self.keyring = YList(self)
                self.policy = YList(self)
                self.profile = YList(self)
                self.proposal = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:ikev2"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Ikev2, ['certificate_cache', 'cluster', 'cookie_challenge', 'disconnect_revoked_peers', 'name_mangler', 'window'], name, value)


            class Authorization(Entity):
                """
                IKEv2 authorization
                
                .. attribute:: policy
                
                	IKEv2 authorization policy
                	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Authorization.Policy>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Authorization, self).__init__()

                    self.yang_name = "authorization"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Native.Crypto.Ikev2.Authorization.Policy))])
                    self._leafs = OrderedDict()

                    self.policy = YList(self)
                    self._segment_path = lambda: "authorization"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Authorization, [], name, value)


                class Policy(Entity):
                    """
                    IKEv2 authorization policy
                    
                    .. attribute:: policy_name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: route
                    
                    	
                    	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Authorization.Policy.Route>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Authorization.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "authorization"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['policy_name']
                        self._child_classes = OrderedDict([("route", ("route", Native.Crypto.Ikev2.Authorization.Policy.Route))])
                        self._leafs = OrderedDict([
                            ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                        ])
                        self.policy_name = None

                        self.route = Native.Crypto.Ikev2.Authorization.Policy.Route()
                        self.route.parent = self
                        self._children_name_map["route"] = "route"
                        self._segment_path = lambda: "policy" + "[policy-name='" + str(self.policy_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/authorization/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Authorization.Policy, ['policy_name'], name, value)


                    class Route(Entity):
                        """
                        
                        
                        .. attribute:: set
                        
                        	
                        	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Authorization.Policy.Route.Set>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Authorization.Policy.Route, self).__init__()

                            self.yang_name = "route"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("set", ("set", Native.Crypto.Ikev2.Authorization.Policy.Route.Set))])
                            self._leafs = OrderedDict()

                            self.set = Native.Crypto.Ikev2.Authorization.Policy.Route.Set()
                            self.set.parent = self
                            self._children_name_map["set"] = "set"
                            self._segment_path = lambda: "route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Authorization.Policy.Route, [], name, value)


                        class Set(Entity):
                            """
                            
                            
                            .. attribute:: interface
                            
                            	
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Authorization.Policy.Route.Set.Interface>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Authorization.Policy.Route.Set, self).__init__()

                                self.yang_name = "set"
                                self.yang_parent_name = "route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", Native.Crypto.Ikev2.Authorization.Policy.Route.Set.Interface))])
                                self._leafs = OrderedDict()

                                self.interface = Native.Crypto.Ikev2.Authorization.Policy.Route.Set.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._segment_path = lambda: "set"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Authorization.Policy.Route.Set, [], name, value)


                            class Interface(Entity):
                                """
                                
                                
                                .. attribute:: interface_default
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: interface_list
                                
                                	
                                	**type**\: list of  		 :py:class:`InterfaceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Authorization.Policy.Route.Set.Interface.InterfaceList>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Authorization.Policy.Route.Set.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "set"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("interface-list", ("interface_list", Native.Crypto.Ikev2.Authorization.Policy.Route.Set.Interface.InterfaceList))])
                                    self._leafs = OrderedDict([
                                        ('interface_default', (YLeaf(YType.empty, 'interface-default'), ['Empty'])),
                                    ])
                                    self.interface_default = None

                                    self.interface_list = YList(self)
                                    self._segment_path = lambda: "interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Authorization.Policy.Route.Set.Interface, ['interface_default'], name, value)


                                class InterfaceList(Entity):
                                    """
                                    
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Authorization.Policy.Route.Set.Interface.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ])
                                        self.interface_name = None
                                        self._segment_path = lambda: "interface-list" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Authorization.Policy.Route.Set.Interface.InterfaceList, ['interface_name'], name, value)


            class Client(Entity):
                """
                IKEv2 client configuration
                
                .. attribute:: flexvpn
                
                	
                	**type**\: list of  		 :py:class:`Flexvpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Client.Flexvpn>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Client, self).__init__()

                    self.yang_name = "client"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flexvpn", ("flexvpn", Native.Crypto.Ikev2.Client.Flexvpn))])
                    self._leafs = OrderedDict()

                    self.flexvpn = YList(self)
                    self._segment_path = lambda: "client"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Client, [], name, value)


                class Flexvpn(Entity):
                    """
                    
                    
                    .. attribute:: flexvpn_name  (key)
                    
                    	Configure an IKEv2 FlexVPN client
                    	**type**\: str
                    
                    .. attribute:: peer
                    
                    	
                    	**type**\: list of  		 :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Client.Flexvpn.Peer>`
                    
                    .. attribute:: connect
                    
                    	
                    	**type**\:  :py:class:`Connect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Client.Flexvpn.Connect>`
                    
                    .. attribute:: source
                    
                    	
                    	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Client.Flexvpn.Source>`
                    
                    .. attribute:: client
                    
                    	
                    	**type**\:  :py:class:`Client_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Client.Flexvpn.Client_>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Client.Flexvpn, self).__init__()

                        self.yang_name = "flexvpn"
                        self.yang_parent_name = "client"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['flexvpn_name']
                        self._child_classes = OrderedDict([("peer", ("peer", Native.Crypto.Ikev2.Client.Flexvpn.Peer)), ("connect", ("connect", Native.Crypto.Ikev2.Client.Flexvpn.Connect)), ("source", ("source", Native.Crypto.Ikev2.Client.Flexvpn.Source)), ("client", ("client", Native.Crypto.Ikev2.Client.Flexvpn.Client_))])
                        self._leafs = OrderedDict([
                            ('flexvpn_name', (YLeaf(YType.str, 'flexvpn-name'), ['str'])),
                        ])
                        self.flexvpn_name = None

                        self.connect = Native.Crypto.Ikev2.Client.Flexvpn.Connect()
                        self.connect.parent = self
                        self._children_name_map["connect"] = "connect"

                        self.client = Native.Crypto.Ikev2.Client.Flexvpn.Client_()
                        self.client.parent = self
                        self._children_name_map["client"] = "client"

                        self.peer = YList(self)
                        self.source = YList(self)
                        self._segment_path = lambda: "flexvpn" + "[flexvpn-name='" + str(self.flexvpn_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/client/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Client.Flexvpn, ['flexvpn_name'], name, value)


                    class Peer(Entity):
                        """
                        
                        
                        .. attribute:: peer_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: peer_id_container
                        
                        	
                        	**type**\:  :py:class:`PeerIdContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Client.Flexvpn.Peer.PeerIdContainer>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Client.Flexvpn.Peer, self).__init__()

                            self.yang_name = "peer"
                            self.yang_parent_name = "flexvpn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['peer_id']
                            self._child_classes = OrderedDict([("peer-id-container", ("peer_id_container", Native.Crypto.Ikev2.Client.Flexvpn.Peer.PeerIdContainer))])
                            self._leafs = OrderedDict([
                                ('peer_id', (YLeaf(YType.uint8, 'peer-id'), ['int'])),
                            ])
                            self.peer_id = None

                            self.peer_id_container = Native.Crypto.Ikev2.Client.Flexvpn.Peer.PeerIdContainer()
                            self.peer_id_container.parent = self
                            self._children_name_map["peer_id_container"] = "peer-id-container"
                            self._segment_path = lambda: "peer" + "[peer-id='" + str(self.peer_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Client.Flexvpn.Peer, ['peer_id'], name, value)


                        class PeerIdContainer(Entity):
                            """
                            
                            
                            .. attribute:: peer_address
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: track
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..1000
                            
                            .. attribute:: up_down
                            
                            	
                            	**type**\:  :py:class:`UpDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Client.Flexvpn.Peer.PeerIdContainer.UpDown>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Client.Flexvpn.Peer.PeerIdContainer, self).__init__()

                                self.yang_name = "peer-id-container"
                                self.yang_parent_name = "peer"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('peer_address', (YLeaf(YType.str, 'peer-address'), ['str','str'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                    ('up_down', (YLeaf(YType.enumeration, 'up-down'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Client.Flexvpn.Peer.PeerIdContainer.UpDown')])),
                                ])
                                self.peer_address = None
                                self.track = None
                                self.up_down = None
                                self._segment_path = lambda: "peer-id-container"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Client.Flexvpn.Peer.PeerIdContainer, ['peer_address', 'track', 'up_down'], name, value)

                            class UpDown(Enum):
                                """
                                UpDown (Enum Class)

                                .. data:: up = 0

                                .. data:: down = 1

                                """

                                up = Enum.YLeaf(0, "up")

                                down = Enum.YLeaf(1, "down")



                    class Connect(Entity):
                        """
                        
                        
                        .. attribute:: track
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..1000
                        
                        .. attribute:: up_down
                        
                        	
                        	**type**\:  :py:class:`UpDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Client.Flexvpn.Connect.UpDown>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Client.Flexvpn.Connect, self).__init__()

                            self.yang_name = "connect"
                            self.yang_parent_name = "flexvpn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ('up_down', (YLeaf(YType.enumeration, 'up-down'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Client.Flexvpn.Connect.UpDown')])),
                            ])
                            self.track = None
                            self.up_down = None
                            self._segment_path = lambda: "connect"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Client.Flexvpn.Connect, ['track', 'up_down'], name, value)

                        class UpDown(Enum):
                            """
                            UpDown (Enum Class)

                            .. data:: up = 0

                            .. data:: down = 1

                            """

                            up = Enum.YLeaf(0, "up")

                            down = Enum.YLeaf(1, "down")



                    class Source(Entity):
                        """
                        
                        
                        .. attribute:: source_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: source_id_container
                        
                        	
                        	**type**\:  :py:class:`SourceIdContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Client.Flexvpn.Source.SourceIdContainer>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Client.Flexvpn.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "flexvpn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['source_id']
                            self._child_classes = OrderedDict([("source-id-container", ("source_id_container", Native.Crypto.Ikev2.Client.Flexvpn.Source.SourceIdContainer))])
                            self._leafs = OrderedDict([
                                ('source_id', (YLeaf(YType.uint8, 'source-id'), ['int'])),
                            ])
                            self.source_id = None

                            self.source_id_container = Native.Crypto.Ikev2.Client.Flexvpn.Source.SourceIdContainer()
                            self.source_id_container.parent = self
                            self._children_name_map["source_id_container"] = "source-id-container"
                            self._segment_path = lambda: "source" + "[source-id='" + str(self.source_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Client.Flexvpn.Source, ['source_id'], name, value)


                        class SourceIdContainer(Entity):
                            """
                            
                            
                            .. attribute:: interface_name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: track
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Client.Flexvpn.Source.SourceIdContainer, self).__init__()

                                self.yang_name = "source-id-container"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.interface_name = None
                                self.track = None
                                self._segment_path = lambda: "source-id-container"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Client.Flexvpn.Source.SourceIdContainer, ['interface_name', 'track'], name, value)


                    class Client_(Entity):
                        """
                        
                        
                        .. attribute:: connect
                        
                        	
                        	**type**\:  :py:class:`Connect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Client.Flexvpn.Client_.Connect>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Client.Flexvpn.Client_, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "flexvpn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("connect", ("connect", Native.Crypto.Ikev2.Client.Flexvpn.Client_.Connect))])
                            self._leafs = OrderedDict()

                            self.connect = Native.Crypto.Ikev2.Client.Flexvpn.Client_.Connect()
                            self.connect.parent = self
                            self._children_name_map["connect"] = "connect"
                            self._segment_path = lambda: "client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Client.Flexvpn.Client_, [], name, value)


                        class Connect(Entity):
                            """
                            
                            
                            .. attribute:: tunnel
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..2147483647
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Client.Flexvpn.Client_.Connect, self).__init__()

                                self.yang_name = "connect"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ])
                                self.tunnel = None
                                self._segment_path = lambda: "connect"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Client.Flexvpn.Client_.Connect, ['tunnel'], name, value)


            class Cts(Entity):
                """
                Cisco Trust Security
                
                .. attribute:: sgt
                
                	Security Group Tag
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Cts, self).__init__()

                    self.yang_name = "cts"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                    ])
                    self.sgt = None
                    self._segment_path = lambda: "cts"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Cts, ['sgt'], name, value)


            class Diagnose(Entity):
                """
                IKEV2 diagnose
                
                .. attribute:: error
                
                	Start IKEv2 error trace debug
                	**type**\: int
                
                	**range:** 1..1000
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Diagnose, self).__init__()

                    self.yang_name = "diagnose"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('error', (YLeaf(YType.uint16, 'error'), ['int'])),
                    ])
                    self.error = None
                    self._segment_path = lambda: "diagnose"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Diagnose, ['error'], name, value)


            class DpdContainer(Entity):
                """
                
                
                .. attribute:: dpd
                
                	Enable IKE liveness check for peers
                	**type**\: int
                
                	**range:** 10..3600
                
                .. attribute:: retry_interval
                
                	
                	**type**\: int
                
                	**range:** 2..60
                
                .. attribute:: dpd_query
                
                	
                	**type**\:  :py:class:`DpdQuery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.DpdContainer.DpdQuery>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.DpdContainer, self).__init__()

                    self.yang_name = "dpd-container"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('dpd', (YLeaf(YType.uint16, 'dpd'), ['int'])),
                        ('retry_interval', (YLeaf(YType.uint8, 'retry-interval'), ['int'])),
                        ('dpd_query', (YLeaf(YType.enumeration, 'dpd-query'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.DpdContainer.DpdQuery')])),
                    ])
                    self.dpd = None
                    self.retry_interval = None
                    self.dpd_query = None
                    self._segment_path = lambda: "dpd-container"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.DpdContainer, ['dpd', 'retry_interval', 'dpd_query'], name, value)

                class DpdQuery(Enum):
                    """
                    DpdQuery (Enum Class)

                    .. data:: on_demand = 0

                    .. data:: periodic = 1

                    """

                    on_demand = Enum.YLeaf(0, "on-demand")

                    periodic = Enum.YLeaf(1, "periodic")



            class Fragmentation(Entity):
                """
                Enable fragmentation of ikev2 packets
                
                .. attribute:: mtu
                
                	MTU size for fragmentation
                	**type**\: int
                
                	**range:** 68..1500
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Fragmentation, self).__init__()

                    self.yang_name = "fragmentation"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                    ])
                    self.mtu = None
                    self._segment_path = lambda: "fragmentation"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Fragmentation, ['mtu'], name, value)


            class HttpUrl(Entity):
                """
                Enable http URL lookup
                
                .. attribute:: cert
                
                	Enable certificate lookup based on HTTP\-based URL
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.HttpUrl, self).__init__()

                    self.yang_name = "http-url"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('cert', (YLeaf(YType.empty, 'cert'), ['Empty'])),
                    ])
                    self.cert = None
                    self._segment_path = lambda: "http-url"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.HttpUrl, ['cert'], name, value)


            class Keyring(Entity):
                """
                Define IKEv2 Keyring
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: peer
                
                	Configure a Peer and associated keys
                	**type**\: list of  		 :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Keyring.Peer>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Keyring, self).__init__()

                    self.yang_name = "keyring"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("peer", ("peer", Native.Crypto.Ikev2.Keyring.Peer))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.peer = YList(self)
                    self._segment_path = lambda: "keyring" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Keyring, ['name'], name, value)


                class Peer(Entity):
                    """
                    Configure a Peer and associated keys
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: address
                    
                    	Specify IPv4/IPv6 address of peer
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Keyring.Peer.Address>`
                    
                    .. attribute:: description
                    
                    	Specify a description of this peer
                    	**type**\: str
                    
                    .. attribute:: hostname
                    
                    	Hostname of peer
                    	**type**\: str
                    
                    .. attribute:: identity
                    
                    	Specify IKE identity to use
                    	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Keyring.Peer.Identity>`
                    
                    .. attribute:: pre_shared_key
                    
                    	specify the pre\-shared key
                    	**type**\:  :py:class:`PreSharedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Keyring.Peer.PreSharedKey>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Keyring.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "keyring"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Ikev2.Keyring.Peer.Address)), ("identity", ("identity", Native.Crypto.Ikev2.Keyring.Peer.Identity)), ("pre-shared-key", ("pre_shared_key", Native.Crypto.Ikev2.Keyring.Peer.PreSharedKey))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                        ])
                        self.name = None
                        self.description = None
                        self.hostname = None

                        self.address = Native.Crypto.Ikev2.Keyring.Peer.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.identity = Native.Crypto.Ikev2.Keyring.Peer.Identity()
                        self.identity.parent = self
                        self._children_name_map["identity"] = "identity"

                        self.pre_shared_key = Native.Crypto.Ikev2.Keyring.Peer.PreSharedKey()
                        self.pre_shared_key.parent = self
                        self._children_name_map["pre_shared_key"] = "pre-shared-key"
                        self._segment_path = lambda: "peer" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Keyring.Peer, ['name', 'description', 'hostname'], name, value)


                    class Address(Entity):
                        """
                        Specify IPv4/IPv6 address of peer
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Keyring.Peer.Address.Ipv4>`
                        
                        .. attribute:: ipv6_prefix
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Keyring.Peer.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Crypto.Ikev2.Keyring.Peer.Address.Ipv4))])
                            self._leafs = OrderedDict([
                                ('ipv6_prefix', (YLeaf(YType.str, 'ipv6-prefix'), ['str'])),
                            ])
                            self.ipv6_prefix = None

                            self.ipv4 = Native.Crypto.Ikev2.Keyring.Peer.Address.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Keyring.Peer.Address, ['ipv6_prefix'], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4_address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Keyring.Peer.Address.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv4_mask', (YLeaf(YType.str, 'ipv4-mask'), ['str'])),
                                ])
                                self.ipv4_address = None
                                self.ipv4_mask = None
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Keyring.Peer.Address.Ipv4, ['ipv4_address', 'ipv4_mask'], name, value)


                    class Identity(Entity):
                        """
                        Specify IKE identity to use
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: email
                        
                        	Use email address
                        	**type**\:  :py:class:`Email <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Keyring.Peer.Identity.Email>`
                        
                        .. attribute:: fqdn
                        
                        	Use FQDN
                        	**type**\:  :py:class:`Fqdn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Keyring.Peer.Identity.Fqdn>`
                        
                        .. attribute:: key_id
                        
                        	proprietary types of identification (ID KEY ID)
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Keyring.Peer.Identity, self).__init__()

                            self.yang_name = "identity"
                            self.yang_parent_name = "peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("email", ("email", Native.Crypto.Ikev2.Keyring.Peer.Identity.Email)), ("fqdn", ("fqdn", Native.Crypto.Ikev2.Keyring.Peer.Identity.Fqdn))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                ('key_id', (YLeaf(YType.str, 'key-id'), ['str'])),
                            ])
                            self.address = None
                            self.key_id = None

                            self.email = Native.Crypto.Ikev2.Keyring.Peer.Identity.Email()
                            self.email.parent = self
                            self._children_name_map["email"] = "email"

                            self.fqdn = Native.Crypto.Ikev2.Keyring.Peer.Identity.Fqdn()
                            self.fqdn.parent = self
                            self._children_name_map["fqdn"] = "fqdn"
                            self._segment_path = lambda: "identity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Keyring.Peer.Identity, ['address', 'key_id'], name, value)


                        class Email(Entity):
                            """
                            Use email address
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: domain
                            
                            	email Domain Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Keyring.Peer.Identity.Email, self).__init__()

                                self.yang_name = "email"
                                self.yang_parent_name = "identity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                ])
                                self.name = None
                                self.domain = None
                                self._segment_path = lambda: "email"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Keyring.Peer.Identity.Email, ['name', 'domain'], name, value)


                        class Fqdn(Entity):
                            """
                            Use FQDN
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: domain
                            
                            	email Domain Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Keyring.Peer.Identity.Fqdn, self).__init__()

                                self.yang_name = "fqdn"
                                self.yang_parent_name = "identity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                ])
                                self.name = None
                                self.domain = None
                                self._segment_path = lambda: "fqdn"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Keyring.Peer.Identity.Fqdn, ['name', 'domain'], name, value)


                    class PreSharedKey(Entity):
                        """
                        specify the pre\-shared key
                        
                        .. attribute:: local
                        
                        	specify signing key
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: remote
                        
                        	specify verifying key
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: encryption
                        
                        	
                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Keyring.Peer.PreSharedKey.Encryption>`
                        
                        .. attribute:: key
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: hex
                        
                        	Key entered in hex string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Keyring.Peer.PreSharedKey, self).__init__()

                            self.yang_name = "pre-shared-key"
                            self.yang_parent_name = "peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                                ('remote', (YLeaf(YType.empty, 'remote'), ['Empty'])),
                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Keyring.Peer.PreSharedKey.Encryption')])),
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ('hex', (YLeaf(YType.str, 'hex'), ['str'])),
                            ])
                            self.local = None
                            self.remote = None
                            self.encryption = None
                            self.key = None
                            self.hex = None
                            self._segment_path = lambda: "pre-shared-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Keyring.Peer.PreSharedKey, ['local', 'remote', 'encryption', 'key', 'hex'], name, value)

                        class Encryption(Enum):
                            """
                            Encryption (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: Y_6 = 1

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_6 = Enum.YLeaf(1, "6")



            class Limit(Entity):
                """
                Limit the number of maximum and negotiating sa
                
                .. attribute:: max_neg_sa
                
                	
                	**type**\:  :py:class:`MaxNegSa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Limit.MaxNegSa>`
                
                .. attribute:: max_sa
                
                	Limit the maximum number of SA allowed
                	**type**\: int
                
                	**range:** 1..9999
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Limit, self).__init__()

                    self.yang_name = "limit"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("max-neg-sa", ("max_neg_sa", Native.Crypto.Ikev2.Limit.MaxNegSa))])
                    self._leafs = OrderedDict([
                        ('max_sa', (YLeaf(YType.uint32, 'max-sa'), ['int'])),
                    ])
                    self.max_sa = None

                    self.max_neg_sa = Native.Crypto.Ikev2.Limit.MaxNegSa()
                    self.max_neg_sa.parent = self
                    self._children_name_map["max_neg_sa"] = "max-neg-sa"
                    self._segment_path = lambda: "limit"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Limit, ['max_sa'], name, value)


                class MaxNegSa(Entity):
                    """
                    
                    
                    .. attribute:: max_in_negotation_sa
                    
                    	Limit the maximum number of negotiating SA
                    	**type**\: int
                    
                    	**range:** 1..9999
                    
                    .. attribute:: direction
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Limit.MaxNegSa.Direction>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Limit.MaxNegSa, self).__init__()

                        self.yang_name = "max-neg-sa"
                        self.yang_parent_name = "limit"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_in_negotation_sa', (YLeaf(YType.uint32, 'max-in-negotation-sa'), ['int'])),
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Limit.MaxNegSa.Direction')])),
                        ])
                        self.max_in_negotation_sa = None
                        self.direction = None
                        self._segment_path = lambda: "max-neg-sa"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/limit/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Limit.MaxNegSa, ['max_in_negotation_sa', 'direction'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: incoming = 0

                        .. data:: outgoing = 1

                        """

                        incoming = Enum.YLeaf(0, "incoming")

                        outgoing = Enum.YLeaf(1, "outgoing")



            class Nat(Entity):
                """
                NAT\-transparency
                
                .. attribute:: keepalive
                
                	Set NAT keepalive interval
                	**type**\: int
                
                	**range:** 5..3600
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Nat, self).__init__()

                    self.yang_name = "nat"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('keepalive', (YLeaf(YType.uint16, 'keepalive'), ['int'])),
                    ])
                    self.keepalive = None
                    self._segment_path = lambda: "nat"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Nat, ['keepalive'], name, value)


            class Policy(Entity):
                """
                Define IKEV2 policies
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: match
                
                	Match values of local fields
                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Policy.Match>`
                
                .. attribute:: proposal
                
                	Specify Proposal
                	**type**\: str
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Policy, self).__init__()

                    self.yang_name = "policy"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("match", ("match", Native.Crypto.Ikev2.Policy.Match))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('proposal', (YLeaf(YType.str, 'proposal'), ['str'])),
                    ])
                    self.name = None
                    self.proposal = None

                    self.match = Native.Crypto.Ikev2.Policy.Match()
                    self.match.parent = self
                    self._children_name_map["match"] = "match"
                    self._segment_path = lambda: "policy" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Policy, ['name', 'proposal'], name, value)


                class Match(Entity):
                    """
                    Match values of local fields
                    
                    .. attribute:: address
                    
                    	Specify the address to match
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Policy.Match.Address>`
                    
                    .. attribute:: fvrf
                    
                    	Specify fvrf
                    	**type**\:  :py:class:`Fvrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Policy.Match.Fvrf>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Policy.Match, self).__init__()

                        self.yang_name = "match"
                        self.yang_parent_name = "policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Ikev2.Policy.Match.Address)), ("fvrf", ("fvrf", Native.Crypto.Ikev2.Policy.Match.Fvrf))])
                        self._leafs = OrderedDict()

                        self.address = Native.Crypto.Ikev2.Policy.Match.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.fvrf = Native.Crypto.Ikev2.Policy.Match.Fvrf()
                        self.fvrf.parent = self
                        self._children_name_map["fvrf"] = "fvrf"
                        self._segment_path = lambda: "match"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Policy.Match, [], name, value)


                    class Address(Entity):
                        """
                        Specify the address to match
                        
                        .. attribute:: local
                        
                        	Local address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Policy.Match.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local', (YLeaf(YType.str, 'local'), ['str','str'])),
                            ])
                            self.local = None
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Policy.Match.Address, ['local'], name, value)


                    class Fvrf(Entity):
                        """
                        Specify fvrf
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: any
                        
                        	Any fvrf
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Policy.Match.Fvrf, self).__init__()

                            self.yang_name = "fvrf"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                            ])
                            self.name = None
                            self.any = None
                            self._segment_path = lambda: "fvrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Policy.Match.Fvrf, ['name', 'any'], name, value)


            class Profile(Entity):
                """
                Define IKEV2 profiles
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: aaa
                
                	Specify AAA related configs
                	**type**\:  :py:class:`Aaa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa>`
                
                .. attribute:: authentication
                
                	Set authentication method
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication>`
                
                .. attribute:: config_exchange
                
                	config\-exchange options
                	**type**\:  :py:class:`ConfigExchange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.ConfigExchange>`
                
                .. attribute:: description
                
                	Specify a description of this profile
                	**type**\: str
                
                .. attribute:: dpd
                
                	Enable IKE liveness check for peers
                	**type**\:  :py:class:`Dpd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Dpd>`
                
                .. attribute:: identity
                
                	Specify IKE identity to use
                	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Identity>`
                
                .. attribute:: initial_contact
                
                	initial\-contact processing options
                	**type**\:  :py:class:`InitialContact <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.InitialContact>`
                
                .. attribute:: ivrf
                
                	I\-VRF of the profile
                	**type**\: str
                
                .. attribute:: keyring
                
                	Specify keyring to use
                	**type**\:  :py:class:`Keyring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Keyring>`
                
                .. attribute:: lifetime
                
                	Set lifetime for ISAKMP security association
                	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Lifetime>`
                
                .. attribute:: match
                
                	Match values of peer
                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Match>`
                
                .. attribute:: nat
                
                	NAT\-transparency
                	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Nat>`
                
                .. attribute:: pki
                
                	Specify certificate authorities to trust
                	**type**\:  :py:class:`Pki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Pki>`
                
                .. attribute:: reconnect
                
                	Enable profile for auto re\-connect
                	**type**\:  :py:class:`Reconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Reconnect>`
                
                	**presence node**\: True
                
                .. attribute:: redirect
                
                	IKEv2 Redirect Mechanism for load\-balancing
                	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Redirect>`
                
                .. attribute:: shutdown
                
                	shutdown the IKEv2 profile
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: virtual_template
                
                	Specify the virtual\-template for dynamic interface creation
                	**type**\:  :py:class:`VirtualTemplate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.VirtualTemplate>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Profile, self).__init__()

                    self.yang_name = "profile"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("aaa", ("aaa", Native.Crypto.Ikev2.Profile.Aaa)), ("authentication", ("authentication", Native.Crypto.Ikev2.Profile.Authentication)), ("config-exchange", ("config_exchange", Native.Crypto.Ikev2.Profile.ConfigExchange)), ("dpd", ("dpd", Native.Crypto.Ikev2.Profile.Dpd)), ("identity", ("identity", Native.Crypto.Ikev2.Profile.Identity)), ("initial-contact", ("initial_contact", Native.Crypto.Ikev2.Profile.InitialContact)), ("keyring", ("keyring", Native.Crypto.Ikev2.Profile.Keyring)), ("lifetime", ("lifetime", Native.Crypto.Ikev2.Profile.Lifetime)), ("match", ("match", Native.Crypto.Ikev2.Profile.Match)), ("nat", ("nat", Native.Crypto.Ikev2.Profile.Nat)), ("pki", ("pki", Native.Crypto.Ikev2.Profile.Pki)), ("reconnect", ("reconnect", Native.Crypto.Ikev2.Profile.Reconnect)), ("redirect", ("redirect", Native.Crypto.Ikev2.Profile.Redirect)), ("virtual-template", ("virtual_template", Native.Crypto.Ikev2.Profile.VirtualTemplate))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('ivrf', (YLeaf(YType.str, 'ivrf'), ['str'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ])
                    self.name = None
                    self.description = None
                    self.ivrf = None
                    self.shutdown = None

                    self.aaa = Native.Crypto.Ikev2.Profile.Aaa()
                    self.aaa.parent = self
                    self._children_name_map["aaa"] = "aaa"

                    self.authentication = Native.Crypto.Ikev2.Profile.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.config_exchange = Native.Crypto.Ikev2.Profile.ConfigExchange()
                    self.config_exchange.parent = self
                    self._children_name_map["config_exchange"] = "config-exchange"

                    self.dpd = Native.Crypto.Ikev2.Profile.Dpd()
                    self.dpd.parent = self
                    self._children_name_map["dpd"] = "dpd"

                    self.identity = Native.Crypto.Ikev2.Profile.Identity()
                    self.identity.parent = self
                    self._children_name_map["identity"] = "identity"

                    self.initial_contact = Native.Crypto.Ikev2.Profile.InitialContact()
                    self.initial_contact.parent = self
                    self._children_name_map["initial_contact"] = "initial-contact"

                    self.keyring = Native.Crypto.Ikev2.Profile.Keyring()
                    self.keyring.parent = self
                    self._children_name_map["keyring"] = "keyring"

                    self.lifetime = Native.Crypto.Ikev2.Profile.Lifetime()
                    self.lifetime.parent = self
                    self._children_name_map["lifetime"] = "lifetime"

                    self.match = Native.Crypto.Ikev2.Profile.Match()
                    self.match.parent = self
                    self._children_name_map["match"] = "match"

                    self.nat = Native.Crypto.Ikev2.Profile.Nat()
                    self.nat.parent = self
                    self._children_name_map["nat"] = "nat"

                    self.pki = Native.Crypto.Ikev2.Profile.Pki()
                    self.pki.parent = self
                    self._children_name_map["pki"] = "pki"

                    self.reconnect = None
                    self._children_name_map["reconnect"] = "reconnect"

                    self.redirect = Native.Crypto.Ikev2.Profile.Redirect()
                    self.redirect.parent = self
                    self._children_name_map["redirect"] = "redirect"

                    self.virtual_template = Native.Crypto.Ikev2.Profile.VirtualTemplate()
                    self.virtual_template.parent = self
                    self._children_name_map["virtual_template"] = "virtual-template"
                    self._segment_path = lambda: "profile" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Profile, ['name', 'description', 'ivrf', 'shutdown'], name, value)


                class Aaa(Entity):
                    """
                    Specify AAA related configs
                    
                    .. attribute:: accounting
                    
                    	AAA accounting
                    	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Accounting>`
                    
                    .. attribute:: authentication
                    
                    	AAA authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authentication>`
                    
                    .. attribute:: authorization
                    
                    	AAA authorization
                    	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.Aaa, self).__init__()

                        self.yang_name = "aaa"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("accounting", ("accounting", Native.Crypto.Ikev2.Profile.Aaa.Accounting)), ("authentication", ("authentication", Native.Crypto.Ikev2.Profile.Aaa.Authentication)), ("authorization", ("authorization", Native.Crypto.Ikev2.Profile.Aaa.Authorization))])
                        self._leafs = OrderedDict()

                        self.accounting = Native.Crypto.Ikev2.Profile.Aaa.Accounting()
                        self.accounting.parent = self
                        self._children_name_map["accounting"] = "accounting"

                        self.authentication = Native.Crypto.Ikev2.Profile.Aaa.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.authorization = Native.Crypto.Ikev2.Profile.Aaa.Authorization()
                        self.authorization.parent = self
                        self._children_name_map["authorization"] = "authorization"
                        self._segment_path = lambda: "aaa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa, [], name, value)


                    class Accounting(Entity):
                        """
                        AAA accounting
                        
                        .. attribute:: anyconnect_eap
                        
                        	AAA list to use when IKEv2 remote auth method is AnyConnect EAP
                        	**type**\: str
                        
                        .. attribute:: cert
                        
                        	AAA list to use when IKEv2 remote auth method is certificate based
                        	**type**\: str
                        
                        .. attribute:: eap
                        
                        	AAA list to use when IKEv2 remote auth method is EAP
                        	**type**\: str
                        
                        .. attribute:: psk
                        
                        	AAA list to use when IKEv2 remote auth method is PSK
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Profile.Aaa.Accounting, self).__init__()

                            self.yang_name = "accounting"
                            self.yang_parent_name = "aaa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('anyconnect_eap', (YLeaf(YType.str, 'anyconnect-eap'), ['str'])),
                                ('cert', (YLeaf(YType.str, 'cert'), ['str'])),
                                ('eap', (YLeaf(YType.str, 'eap'), ['str'])),
                                ('psk', (YLeaf(YType.str, 'psk'), ['str'])),
                            ])
                            self.anyconnect_eap = None
                            self.cert = None
                            self.eap = None
                            self.psk = None
                            self._segment_path = lambda: "accounting"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Accounting, ['anyconnect_eap', 'cert', 'eap', 'psk'], name, value)


                    class Authentication(Entity):
                        """
                        AAA authentication
                        
                        .. attribute:: anyconnect_eap
                        
                        	AAA AnyConnect EAP authentication
                        	**type**\: str
                        
                        .. attribute:: eap
                        
                        	AAA EAP authentication
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Profile.Aaa.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "aaa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('anyconnect_eap', (YLeaf(YType.str, 'anyconnect-eap'), ['str'])),
                                ('eap', (YLeaf(YType.str, 'eap'), ['str'])),
                            ])
                            self.anyconnect_eap = None
                            self.eap = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authentication, ['anyconnect_eap', 'eap'], name, value)


                    class Authorization(Entity):
                        """
                        AAA authorization
                        
                        .. attribute:: group
                        
                        	AAA group authorization
                        	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group>`
                        
                        .. attribute:: user
                        
                        	AAA user authorization
                        	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Profile.Aaa.Authorization, self).__init__()

                            self.yang_name = "authorization"
                            self.yang_parent_name = "aaa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group", ("group", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group)), ("user", ("user", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User))])
                            self._leafs = OrderedDict()

                            self.group = Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"

                            self.user = Native.Crypto.Ikev2.Profile.Aaa.Authorization.User()
                            self.user.parent = self
                            self._children_name_map["user"] = "user"
                            self._segment_path = lambda: "authorization"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization, [], name, value)


                        class Group(Entity):
                            """
                            AAA group authorization
                            
                            .. attribute:: anyconnect_eap
                            
                            	AAA list to use when IKEv2 remote auth method is anyconnect eap based
                            	**type**\:  :py:class:`AnyconnectEap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap>`
                            
                            .. attribute:: cert
                            
                            	AAA list to use when IKEv2 remote auth method is certificate based
                            	**type**\:  :py:class:`Cert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert>`
                            
                            .. attribute:: eap
                            
                            	AAA list to use when IKEv2 remote auth method is EAP
                            	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap>`
                            
                            .. attribute:: psk
                            
                            	AAA list to use when IKEv2 remote auth method is PSK
                            	**type**\:  :py:class:`Psk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk>`
                            
                            .. attribute:: override
                            
                            	Override user authorization with group authorization.By default, group authorization isoverridden with user authorization
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "authorization"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("anyconnect-eap", ("anyconnect_eap", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap)), ("cert", ("cert", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert)), ("eap", ("eap", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap)), ("psk", ("psk", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk))])
                                self._leafs = OrderedDict([
                                    ('override', (YLeaf(YType.empty, 'override'), ['Empty'])),
                                ])
                                self.override = None

                                self.anyconnect_eap = Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap()
                                self.anyconnect_eap.parent = self
                                self._children_name_map["anyconnect_eap"] = "anyconnect-eap"

                                self.cert = Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert()
                                self.cert.parent = self
                                self._children_name_map["cert"] = "cert"

                                self.eap = Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap()
                                self.eap.parent = self
                                self._children_name_map["eap"] = "eap"

                                self.psk = Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk()
                                self.psk.parent = self
                                self._children_name_map["psk"] = "psk"
                                self._segment_path = lambda: "group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group, ['override'], name, value)


                            class AnyconnectEap(Entity):
                                """
                                AAA list to use when IKEv2 remote auth method is anyconnect eap based
                                
                                .. attribute:: list
                                
                                	AAA method list
                                	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap.List>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap, self).__init__()

                                    self.yang_name = "anyconnect-eap"
                                    self.yang_parent_name = "group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("list", ("list", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap.List))])
                                    self._leafs = OrderedDict()

                                    self.list = YList(self)
                                    self._segment_path = lambda: "anyconnect-eap"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap, [], name, value)


                                class List(Entity):
                                    """
                                    AAA method list
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: username
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: local
                                    
                                    	Local AAA Authorization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: name_mangler
                                    
                                    	Specify the name\-mangler to derive AAA username
                                    	**type**\: str
                                    
                                    .. attribute:: password
                                    
                                    	Specify the AAA password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap.List.Password>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap.List, self).__init__()

                                        self.yang_name = "list"
                                        self.yang_parent_name = "anyconnect-eap"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap.List.Password))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                                            ('name_mangler', (YLeaf(YType.str, 'name-mangler'), ['str'])),
                                        ])
                                        self.name = None
                                        self.username = None
                                        self.local = None
                                        self.name_mangler = None

                                        self.password = Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap.List.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"
                                        self._segment_path = lambda: "list" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap.List, ['name', 'username', 'local', 'name_mangler'], name, value)


                                    class Password(Entity):
                                        """
                                        Specify the AAA password
                                        
                                        .. attribute:: encryption
                                        
                                        	
                                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap.List.Password.Encryption>`
                                        
                                        .. attribute:: key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap.List.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap.List.Password.Encryption')])),
                                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                            ])
                                            self.encryption = None
                                            self.key = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.AnyconnectEap.List.Password, ['encryption', 'key'], name, value)

                                        class Encryption(Enum):
                                            """
                                            Encryption (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_6 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_6 = Enum.YLeaf(1, "6")



                            class Cert(Entity):
                                """
                                AAA list to use when IKEv2 remote auth method is certificate based
                                
                                .. attribute:: list
                                
                                	AAA method list
                                	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert.List>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert, self).__init__()

                                    self.yang_name = "cert"
                                    self.yang_parent_name = "group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("list", ("list", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert.List))])
                                    self._leafs = OrderedDict()

                                    self.list = YList(self)
                                    self._segment_path = lambda: "cert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert, [], name, value)


                                class List(Entity):
                                    """
                                    AAA method list
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: username
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: local
                                    
                                    	Local AAA Authorization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: name_mangler
                                    
                                    	Specify the name\-mangler to derive AAA username
                                    	**type**\: str
                                    
                                    .. attribute:: password
                                    
                                    	Specify the AAA password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert.List.Password>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert.List, self).__init__()

                                        self.yang_name = "list"
                                        self.yang_parent_name = "cert"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert.List.Password))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                                            ('name_mangler', (YLeaf(YType.str, 'name-mangler'), ['str'])),
                                        ])
                                        self.name = None
                                        self.username = None
                                        self.local = None
                                        self.name_mangler = None

                                        self.password = Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert.List.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"
                                        self._segment_path = lambda: "list" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert.List, ['name', 'username', 'local', 'name_mangler'], name, value)


                                    class Password(Entity):
                                        """
                                        Specify the AAA password
                                        
                                        .. attribute:: encryption
                                        
                                        	
                                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert.List.Password.Encryption>`
                                        
                                        .. attribute:: key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert.List.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert.List.Password.Encryption')])),
                                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                            ])
                                            self.encryption = None
                                            self.key = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Cert.List.Password, ['encryption', 'key'], name, value)

                                        class Encryption(Enum):
                                            """
                                            Encryption (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_6 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_6 = Enum.YLeaf(1, "6")



                            class Eap(Entity):
                                """
                                AAA list to use when IKEv2 remote auth method is EAP
                                
                                .. attribute:: list
                                
                                	AAA method list
                                	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap.List>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap, self).__init__()

                                    self.yang_name = "eap"
                                    self.yang_parent_name = "group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("list", ("list", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap.List))])
                                    self._leafs = OrderedDict()

                                    self.list = YList(self)
                                    self._segment_path = lambda: "eap"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap, [], name, value)


                                class List(Entity):
                                    """
                                    AAA method list
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: username
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: local
                                    
                                    	Local AAA Authorization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: name_mangler
                                    
                                    	Specify the name\-mangler to derive AAA username
                                    	**type**\: str
                                    
                                    .. attribute:: password
                                    
                                    	Specify the AAA password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap.List.Password>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap.List, self).__init__()

                                        self.yang_name = "list"
                                        self.yang_parent_name = "eap"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap.List.Password))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                                            ('name_mangler', (YLeaf(YType.str, 'name-mangler'), ['str'])),
                                        ])
                                        self.name = None
                                        self.username = None
                                        self.local = None
                                        self.name_mangler = None

                                        self.password = Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap.List.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"
                                        self._segment_path = lambda: "list" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap.List, ['name', 'username', 'local', 'name_mangler'], name, value)


                                    class Password(Entity):
                                        """
                                        Specify the AAA password
                                        
                                        .. attribute:: encryption
                                        
                                        	
                                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap.List.Password.Encryption>`
                                        
                                        .. attribute:: key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap.List.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap.List.Password.Encryption')])),
                                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                            ])
                                            self.encryption = None
                                            self.key = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Eap.List.Password, ['encryption', 'key'], name, value)

                                        class Encryption(Enum):
                                            """
                                            Encryption (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_6 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_6 = Enum.YLeaf(1, "6")



                            class Psk(Entity):
                                """
                                AAA list to use when IKEv2 remote auth method is PSK
                                
                                .. attribute:: list
                                
                                	AAA method list
                                	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk.List>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk, self).__init__()

                                    self.yang_name = "psk"
                                    self.yang_parent_name = "group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("list", ("list", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk.List))])
                                    self._leafs = OrderedDict()

                                    self.list = YList(self)
                                    self._segment_path = lambda: "psk"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk, [], name, value)


                                class List(Entity):
                                    """
                                    AAA method list
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: username
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: local
                                    
                                    	Local AAA Authorization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: name_mangler
                                    
                                    	Specify the name\-mangler to derive AAA username
                                    	**type**\: str
                                    
                                    .. attribute:: password
                                    
                                    	Specify the AAA password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk.List.Password>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk.List, self).__init__()

                                        self.yang_name = "list"
                                        self.yang_parent_name = "psk"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk.List.Password))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                                            ('name_mangler', (YLeaf(YType.str, 'name-mangler'), ['str'])),
                                        ])
                                        self.name = None
                                        self.username = None
                                        self.local = None
                                        self.name_mangler = None

                                        self.password = Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk.List.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"
                                        self._segment_path = lambda: "list" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk.List, ['name', 'username', 'local', 'name_mangler'], name, value)


                                    class Password(Entity):
                                        """
                                        Specify the AAA password
                                        
                                        .. attribute:: encryption
                                        
                                        	
                                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk.List.Password.Encryption>`
                                        
                                        .. attribute:: key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk.List.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk.List.Password.Encryption')])),
                                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                            ])
                                            self.encryption = None
                                            self.key = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.Group.Psk.List.Password, ['encryption', 'key'], name, value)

                                        class Encryption(Enum):
                                            """
                                            Encryption (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_6 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_6 = Enum.YLeaf(1, "6")



                        class User(Entity):
                            """
                            AAA user authorization
                            
                            .. attribute:: anyconnect_eap
                            
                            	AAA list to use when IKEv2 remote auth method is anyconnect eap based
                            	**type**\:  :py:class:`AnyconnectEap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap>`
                            
                            .. attribute:: cert
                            
                            	AAA list to use when IKEv2 remote auth method is certificate based
                            	**type**\:  :py:class:`Cert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert>`
                            
                            .. attribute:: eap
                            
                            	AAA list to use when IKEv2 remote auth method is EAP
                            	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap>`
                            
                            .. attribute:: psk
                            
                            	AAA list to use when IKEv2 remote auth method is PSK
                            	**type**\:  :py:class:`Psk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User, self).__init__()

                                self.yang_name = "user"
                                self.yang_parent_name = "authorization"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("anyconnect-eap", ("anyconnect_eap", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap)), ("cert", ("cert", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert)), ("eap", ("eap", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap)), ("psk", ("psk", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk))])
                                self._leafs = OrderedDict()

                                self.anyconnect_eap = Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap()
                                self.anyconnect_eap.parent = self
                                self._children_name_map["anyconnect_eap"] = "anyconnect-eap"

                                self.cert = Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert()
                                self.cert.parent = self
                                self._children_name_map["cert"] = "cert"

                                self.eap = Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap()
                                self.eap.parent = self
                                self._children_name_map["eap"] = "eap"

                                self.psk = Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk()
                                self.psk.parent = self
                                self._children_name_map["psk"] = "psk"
                                self._segment_path = lambda: "user"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User, [], name, value)


                            class AnyconnectEap(Entity):
                                """
                                AAA list to use when IKEv2 remote auth method is anyconnect eap based
                                
                                .. attribute:: cached
                                
                                	Use cached attributes from EAP authentication or AAA pre\-shared key fetch
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: list
                                
                                	AAA method list
                                	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap.List>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap, self).__init__()

                                    self.yang_name = "anyconnect-eap"
                                    self.yang_parent_name = "user"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("list", ("list", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap.List))])
                                    self._leafs = OrderedDict([
                                        ('cached', (YLeaf(YType.empty, 'cached'), ['Empty'])),
                                    ])
                                    self.cached = None

                                    self.list = YList(self)
                                    self._segment_path = lambda: "anyconnect-eap"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap, ['cached'], name, value)


                                class List(Entity):
                                    """
                                    AAA method list
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: username
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: local
                                    
                                    	Local AAA Authorization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: name_mangler
                                    
                                    	Specify the name\-mangler to derive AAA username
                                    	**type**\: str
                                    
                                    .. attribute:: password
                                    
                                    	Specify the AAA password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap.List.Password>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap.List, self).__init__()

                                        self.yang_name = "list"
                                        self.yang_parent_name = "anyconnect-eap"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap.List.Password))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                                            ('name_mangler', (YLeaf(YType.str, 'name-mangler'), ['str'])),
                                        ])
                                        self.name = None
                                        self.username = None
                                        self.local = None
                                        self.name_mangler = None

                                        self.password = Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap.List.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"
                                        self._segment_path = lambda: "list" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap.List, ['name', 'username', 'local', 'name_mangler'], name, value)


                                    class Password(Entity):
                                        """
                                        Specify the AAA password
                                        
                                        .. attribute:: encryption
                                        
                                        	
                                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap.List.Password.Encryption>`
                                        
                                        .. attribute:: key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap.List.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap.List.Password.Encryption')])),
                                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                            ])
                                            self.encryption = None
                                            self.key = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.AnyconnectEap.List.Password, ['encryption', 'key'], name, value)

                                        class Encryption(Enum):
                                            """
                                            Encryption (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_6 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_6 = Enum.YLeaf(1, "6")



                            class Cert(Entity):
                                """
                                AAA list to use when IKEv2 remote auth method is certificate based
                                
                                .. attribute:: list
                                
                                	AAA method list
                                	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert.List>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert, self).__init__()

                                    self.yang_name = "cert"
                                    self.yang_parent_name = "user"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("list", ("list", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert.List))])
                                    self._leafs = OrderedDict()

                                    self.list = YList(self)
                                    self._segment_path = lambda: "cert"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert, [], name, value)


                                class List(Entity):
                                    """
                                    AAA method list
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: username
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: local
                                    
                                    	Local AAA Authorization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: name_mangler
                                    
                                    	Specify the name\-mangler to derive AAA username
                                    	**type**\: str
                                    
                                    .. attribute:: password
                                    
                                    	Specify the AAA password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert.List.Password>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert.List, self).__init__()

                                        self.yang_name = "list"
                                        self.yang_parent_name = "cert"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert.List.Password))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                                            ('name_mangler', (YLeaf(YType.str, 'name-mangler'), ['str'])),
                                        ])
                                        self.name = None
                                        self.username = None
                                        self.local = None
                                        self.name_mangler = None

                                        self.password = Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert.List.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"
                                        self._segment_path = lambda: "list" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert.List, ['name', 'username', 'local', 'name_mangler'], name, value)


                                    class Password(Entity):
                                        """
                                        Specify the AAA password
                                        
                                        .. attribute:: encryption
                                        
                                        	
                                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert.List.Password.Encryption>`
                                        
                                        .. attribute:: key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert.List.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert.List.Password.Encryption')])),
                                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                            ])
                                            self.encryption = None
                                            self.key = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Cert.List.Password, ['encryption', 'key'], name, value)

                                        class Encryption(Enum):
                                            """
                                            Encryption (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_6 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_6 = Enum.YLeaf(1, "6")



                            class Eap(Entity):
                                """
                                AAA list to use when IKEv2 remote auth method is EAP
                                
                                .. attribute:: cached
                                
                                	Use cached attributes from EAP authentication or AAA pre\-shared key fetch
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: list
                                
                                	AAA method list
                                	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap.List>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap, self).__init__()

                                    self.yang_name = "eap"
                                    self.yang_parent_name = "user"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("list", ("list", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap.List))])
                                    self._leafs = OrderedDict([
                                        ('cached', (YLeaf(YType.empty, 'cached'), ['Empty'])),
                                    ])
                                    self.cached = None

                                    self.list = YList(self)
                                    self._segment_path = lambda: "eap"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap, ['cached'], name, value)


                                class List(Entity):
                                    """
                                    AAA method list
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: username
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: local
                                    
                                    	Local AAA Authorization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: name_mangler
                                    
                                    	Specify the name\-mangler to derive AAA username
                                    	**type**\: str
                                    
                                    .. attribute:: password
                                    
                                    	Specify the AAA password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap.List.Password>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap.List, self).__init__()

                                        self.yang_name = "list"
                                        self.yang_parent_name = "eap"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap.List.Password))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                                            ('name_mangler', (YLeaf(YType.str, 'name-mangler'), ['str'])),
                                        ])
                                        self.name = None
                                        self.username = None
                                        self.local = None
                                        self.name_mangler = None

                                        self.password = Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap.List.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"
                                        self._segment_path = lambda: "list" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap.List, ['name', 'username', 'local', 'name_mangler'], name, value)


                                    class Password(Entity):
                                        """
                                        Specify the AAA password
                                        
                                        .. attribute:: encryption
                                        
                                        	
                                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap.List.Password.Encryption>`
                                        
                                        .. attribute:: key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap.List.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap.List.Password.Encryption')])),
                                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                            ])
                                            self.encryption = None
                                            self.key = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Eap.List.Password, ['encryption', 'key'], name, value)

                                        class Encryption(Enum):
                                            """
                                            Encryption (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_6 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_6 = Enum.YLeaf(1, "6")



                            class Psk(Entity):
                                """
                                AAA list to use when IKEv2 remote auth method is PSK
                                
                                .. attribute:: cached
                                
                                	Use cached attributes from EAP authentication or AAA pre\-shared key fetch
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: list
                                
                                	AAA method list
                                	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk.List>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk, self).__init__()

                                    self.yang_name = "psk"
                                    self.yang_parent_name = "user"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("list", ("list", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk.List))])
                                    self._leafs = OrderedDict([
                                        ('cached', (YLeaf(YType.empty, 'cached'), ['Empty'])),
                                    ])
                                    self.cached = None

                                    self.list = YList(self)
                                    self._segment_path = lambda: "psk"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk, ['cached'], name, value)


                                class List(Entity):
                                    """
                                    AAA method list
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: username
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: local
                                    
                                    	Local AAA Authorization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: name_mangler
                                    
                                    	Specify the name\-mangler to derive AAA username
                                    	**type**\: str
                                    
                                    .. attribute:: password
                                    
                                    	Specify the AAA password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk.List.Password>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk.List, self).__init__()

                                        self.yang_name = "list"
                                        self.yang_parent_name = "psk"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk.List.Password))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                            ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                                            ('name_mangler', (YLeaf(YType.str, 'name-mangler'), ['str'])),
                                        ])
                                        self.name = None
                                        self.username = None
                                        self.local = None
                                        self.name_mangler = None

                                        self.password = Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk.List.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"
                                        self._segment_path = lambda: "list" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk.List, ['name', 'username', 'local', 'name_mangler'], name, value)


                                    class Password(Entity):
                                        """
                                        Specify the AAA password
                                        
                                        .. attribute:: encryption
                                        
                                        	
                                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk.List.Password.Encryption>`
                                        
                                        .. attribute:: key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk.List.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk.List.Password.Encryption')])),
                                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                            ])
                                            self.encryption = None
                                            self.key = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Aaa.Authorization.User.Psk.List.Password, ['encryption', 'key'], name, value)

                                        class Encryption(Enum):
                                            """
                                            Encryption (Enum Class)

                                            .. data:: Y_0 = 0

                                            .. data:: Y_6 = 1

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")

                                            Y_6 = Enum.YLeaf(1, "6")



                class Authentication(Entity):
                    """
                    Set authentication method
                    
                    .. attribute:: local
                    
                    	Set local authentication method
                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local>`
                    
                    .. attribute:: remote
                    
                    	Set remote authentication method
                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Remote>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("local", ("local", Native.Crypto.Ikev2.Profile.Authentication.Local)), ("remote", ("remote", Native.Crypto.Ikev2.Profile.Authentication.Remote))])
                        self._leafs = OrderedDict()

                        self.local = Native.Crypto.Ikev2.Profile.Authentication.Local()
                        self.local.parent = self
                        self._children_name_map["local"] = "local"

                        self.remote = Native.Crypto.Ikev2.Profile.Authentication.Remote()
                        self.remote.parent = self
                        self._children_name_map["remote"] = "remote"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication, [], name, value)


                    class Local(Entity):
                        """
                        Set local authentication method
                        
                        .. attribute:: eap
                        
                        	Extended Authentication Protocol
                        	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.Eap>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ecdsa_sig
                        
                        	ECDSA Signature
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pre_share
                        
                        	Pre\-Shared Key
                        	**type**\:  :py:class:`PreShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.PreShare>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: rsa_sig
                        
                        	Rivest\-Shamir\-Adleman Signature
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Profile.Authentication.Local, self).__init__()

                            self.yang_name = "local"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("eap", ("eap", Native.Crypto.Ikev2.Profile.Authentication.Local.Eap)), ("pre-share", ("pre_share", Native.Crypto.Ikev2.Profile.Authentication.Local.PreShare))])
                            self._leafs = OrderedDict([
                                ('ecdsa_sig', (YLeaf(YType.empty, 'ecdsa-sig'), ['Empty'])),
                                ('rsa_sig', (YLeaf(YType.empty, 'rsa-sig'), ['Empty'])),
                            ])
                            self.ecdsa_sig = None
                            self.rsa_sig = None

                            self.eap = None
                            self._children_name_map["eap"] = "eap"

                            self.pre_share = None
                            self._children_name_map["pre_share"] = "pre-share"
                            self._segment_path = lambda: "local"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Local, ['ecdsa_sig', 'rsa_sig'], name, value)


                        class Eap(Entity):
                            """
                            Extended Authentication Protocol
                            
                            .. attribute:: gtc
                            
                            	eap method gtc credentials
                            	**type**\:  :py:class:`Gtc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc>`
                            
                            .. attribute:: md5
                            
                            	eap method md5 credentials
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5>`
                            
                            .. attribute:: mschapv2
                            
                            	eap method mschapv2 credentials
                            	**type**\:  :py:class:`Mschapv2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap, self).__init__()

                                self.yang_name = "eap"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("gtc", ("gtc", Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc)), ("md5", ("md5", Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5)), ("mschapv2", ("mschapv2", Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.gtc = Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc()
                                self.gtc.parent = self
                                self._children_name_map["gtc"] = "gtc"

                                self.md5 = Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"

                                self.mschapv2 = Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2()
                                self.mschapv2.parent = self
                                self._children_name_map["mschapv2"] = "mschapv2"
                                self._segment_path = lambda: "eap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap, [], name, value)


                            class Gtc(Entity):
                                """
                                eap method gtc credentials
                                
                                .. attribute:: username
                                
                                	EAP username
                                	**type**\: str
                                
                                .. attribute:: password
                                
                                	EAP password
                                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc.Password>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc, self).__init__()

                                    self.yang_name = "gtc"
                                    self.yang_parent_name = "eap"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc.Password))])
                                    self._leafs = OrderedDict([
                                        ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                    ])
                                    self.username = None

                                    self.password = Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._segment_path = lambda: "gtc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc, ['username'], name, value)


                                class Password(Entity):
                                    """
                                    EAP password
                                    
                                    .. attribute:: encryption
                                    
                                    	
                                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc.Password.Encryption>`
                                    
                                    .. attribute:: key
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "gtc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc.Password.Encryption')])),
                                            ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                        ])
                                        self.encryption = None
                                        self.key = None
                                        self._segment_path = lambda: "password"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Gtc.Password, ['encryption', 'key'], name, value)

                                    class Encryption(Enum):
                                        """
                                        Encryption (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_6 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_6 = Enum.YLeaf(1, "6")



                            class Md5(Entity):
                                """
                                eap method md5 credentials
                                
                                .. attribute:: username
                                
                                	EAP username
                                	**type**\: str
                                
                                .. attribute:: password
                                
                                	EAP password
                                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5.Password>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "eap"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5.Password))])
                                    self._leafs = OrderedDict([
                                        ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                    ])
                                    self.username = None

                                    self.password = Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5, ['username'], name, value)


                                class Password(Entity):
                                    """
                                    EAP password
                                    
                                    .. attribute:: encryption
                                    
                                    	
                                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5.Password.Encryption>`
                                    
                                    .. attribute:: key
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "md5"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5.Password.Encryption')])),
                                            ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                        ])
                                        self.encryption = None
                                        self.key = None
                                        self._segment_path = lambda: "password"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Md5.Password, ['encryption', 'key'], name, value)

                                    class Encryption(Enum):
                                        """
                                        Encryption (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_6 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_6 = Enum.YLeaf(1, "6")



                            class Mschapv2(Entity):
                                """
                                eap method mschapv2 credentials
                                
                                .. attribute:: username
                                
                                	EAP username
                                	**type**\: str
                                
                                .. attribute:: password
                                
                                	EAP password
                                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2.Password>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2, self).__init__()

                                    self.yang_name = "mschapv2"
                                    self.yang_parent_name = "eap"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2.Password))])
                                    self._leafs = OrderedDict([
                                        ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                    ])
                                    self.username = None

                                    self.password = Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._segment_path = lambda: "mschapv2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2, ['username'], name, value)


                                class Password(Entity):
                                    """
                                    EAP password
                                    
                                    .. attribute:: encryption
                                    
                                    	
                                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2.Password.Encryption>`
                                    
                                    .. attribute:: key
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "mschapv2"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2.Password.Encryption')])),
                                            ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                        ])
                                        self.encryption = None
                                        self.key = None
                                        self._segment_path = lambda: "password"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Local.Eap.Mschapv2.Password, ['encryption', 'key'], name, value)

                                    class Encryption(Enum):
                                        """
                                        Encryption (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_6 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_6 = Enum.YLeaf(1, "6")



                        class PreShare(Entity):
                            """
                            Pre\-Shared Key
                            
                            .. attribute:: key
                            
                            	specify key
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.PreShare.Key>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Profile.Authentication.Local.PreShare, self).__init__()

                                self.yang_name = "pre-share"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key", ("key", Native.Crypto.Ikev2.Profile.Authentication.Local.PreShare.Key))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.key = Native.Crypto.Ikev2.Profile.Authentication.Local.PreShare.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "pre-share"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Local.PreShare, [], name, value)


                            class Key(Entity):
                                """
                                specify key
                                
                                .. attribute:: encryption
                                
                                	
                                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Local.PreShare.Key.Encryption>`
                                
                                .. attribute:: key
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Authentication.Local.PreShare.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "pre-share"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Authentication.Local.PreShare.Key.Encryption')])),
                                        ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                    ])
                                    self.encryption = None
                                    self.key = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Local.PreShare.Key, ['encryption', 'key'], name, value)

                                class Encryption(Enum):
                                    """
                                    Encryption (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_6 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_6 = Enum.YLeaf(1, "6")



                    class Remote(Entity):
                        """
                        Set remote authentication method
                        
                        .. attribute:: anyconnect_eap
                        
                        	AnyConnect EAP
                        	**type**\:  :py:class:`AnyconnectEap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Remote.AnyconnectEap>`
                        
                        .. attribute:: eap
                        
                        	Extended Authentication Protocol
                        	**type**\:  :py:class:`Eap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Remote.Eap>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ecdsa_sig
                        
                        	ECDSA Signature
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pre_share
                        
                        	Pre\-Shared Key
                        	**type**\:  :py:class:`PreShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Remote.PreShare>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: rsa_sig
                        
                        	Rivest\-Shamir\-Adleman Signature
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Profile.Authentication.Remote, self).__init__()

                            self.yang_name = "remote"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("anyconnect-eap", ("anyconnect_eap", Native.Crypto.Ikev2.Profile.Authentication.Remote.AnyconnectEap)), ("eap", ("eap", Native.Crypto.Ikev2.Profile.Authentication.Remote.Eap)), ("pre-share", ("pre_share", Native.Crypto.Ikev2.Profile.Authentication.Remote.PreShare))])
                            self._leafs = OrderedDict([
                                ('ecdsa_sig', (YLeaf(YType.empty, 'ecdsa-sig'), ['Empty'])),
                                ('rsa_sig', (YLeaf(YType.empty, 'rsa-sig'), ['Empty'])),
                            ])
                            self.ecdsa_sig = None
                            self.rsa_sig = None

                            self.anyconnect_eap = Native.Crypto.Ikev2.Profile.Authentication.Remote.AnyconnectEap()
                            self.anyconnect_eap.parent = self
                            self._children_name_map["anyconnect_eap"] = "anyconnect-eap"

                            self.eap = None
                            self._children_name_map["eap"] = "eap"

                            self.pre_share = None
                            self._children_name_map["pre_share"] = "pre-share"
                            self._segment_path = lambda: "remote"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Remote, ['ecdsa_sig', 'rsa_sig'], name, value)


                        class AnyconnectEap(Entity):
                            """
                            AnyConnect EAP
                            
                            .. attribute:: aggregate
                            
                            	use aggregate auth for anyconnect eap
                            	**type**\:  :py:class:`Aggregate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Remote.AnyconnectEap.Aggregate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Profile.Authentication.Remote.AnyconnectEap, self).__init__()

                                self.yang_name = "anyconnect-eap"
                                self.yang_parent_name = "remote"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aggregate", ("aggregate", Native.Crypto.Ikev2.Profile.Authentication.Remote.AnyconnectEap.Aggregate))])
                                self._leafs = OrderedDict()

                                self.aggregate = None
                                self._children_name_map["aggregate"] = "aggregate"
                                self._segment_path = lambda: "anyconnect-eap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Remote.AnyconnectEap, [], name, value)


                            class Aggregate(Entity):
                                """
                                use aggregate auth for anyconnect eap
                                
                                .. attribute:: cert_request
                                
                                	use double authentication during anyconnect eap
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Authentication.Remote.AnyconnectEap.Aggregate, self).__init__()

                                    self.yang_name = "aggregate"
                                    self.yang_parent_name = "anyconnect-eap"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('cert_request', (YLeaf(YType.empty, 'cert-request'), ['Empty'])),
                                    ])
                                    self.cert_request = None
                                    self._segment_path = lambda: "aggregate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Remote.AnyconnectEap.Aggregate, ['cert_request'], name, value)


                        class Eap(Entity):
                            """
                            Extended Authentication Protocol
                            
                            .. attribute:: query_identity
                            
                            	query EAP identity from peer
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: timeout
                            
                            	timeout
                            	**type**\: int
                            
                            	**range:** 45..180
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Profile.Authentication.Remote.Eap, self).__init__()

                                self.yang_name = "eap"
                                self.yang_parent_name = "remote"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('query_identity', (YLeaf(YType.empty, 'query-identity'), ['Empty'])),
                                    ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                                ])
                                self.query_identity = None
                                self.timeout = None
                                self._segment_path = lambda: "eap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Remote.Eap, ['query_identity', 'timeout'], name, value)


                        class PreShare(Entity):
                            """
                            Pre\-Shared Key
                            
                            .. attribute:: key
                            
                            	specify key
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Remote.PreShare.Key>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Profile.Authentication.Remote.PreShare, self).__init__()

                                self.yang_name = "pre-share"
                                self.yang_parent_name = "remote"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key", ("key", Native.Crypto.Ikev2.Profile.Authentication.Remote.PreShare.Key))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.key = Native.Crypto.Ikev2.Profile.Authentication.Remote.PreShare.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "pre-share"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Remote.PreShare, [], name, value)


                            class Key(Entity):
                                """
                                specify key
                                
                                .. attribute:: encryption
                                
                                	
                                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Authentication.Remote.PreShare.Key.Encryption>`
                                
                                .. attribute:: key
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Authentication.Remote.PreShare.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "pre-share"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Authentication.Remote.PreShare.Key.Encryption')])),
                                        ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                    ])
                                    self.encryption = None
                                    self.key = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Authentication.Remote.PreShare.Key, ['encryption', 'key'], name, value)

                                class Encryption(Enum):
                                    """
                                    Encryption (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_6 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_6 = Enum.YLeaf(1, "6")



                class ConfigExchange(Entity):
                    """
                    config\-exchange options
                    
                    .. attribute:: request
                    
                    	enable config\-exchange request
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: set
                    
                    	config\-exchange set options
                    	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.ConfigExchange.Set>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.ConfigExchange, self).__init__()

                        self.yang_name = "config-exchange"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('request', (YLeaf(YType.empty, 'request'), ['Empty'])),
                            ('set', (YLeaf(YType.enumeration, 'set'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.ConfigExchange.Set')])),
                        ])
                        self.request = None
                        self.set = None
                        self._segment_path = lambda: "config-exchange"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.ConfigExchange, ['request', 'set'], name, value)

                    class Set(Enum):
                        """
                        Set (Enum Class)

                        config\-exchange set options

                        .. data:: accept = 0

                        .. data:: send = 1

                        """

                        accept = Enum.YLeaf(0, "accept")

                        send = Enum.YLeaf(1, "send")



                class Dpd(Entity):
                    """
                    Enable IKE liveness check for peers
                    
                    .. attribute:: interval
                    
                    	
                    	**type**\: int
                    
                    	**range:** 10..3600
                    
                    .. attribute:: retry
                    
                    	
                    	**type**\: int
                    
                    	**range:** 2..60
                    
                    .. attribute:: query
                    
                    	
                    	**type**\:  :py:class:`Query <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Dpd.Query>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.Dpd, self).__init__()

                        self.yang_name = "dpd"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ('retry', (YLeaf(YType.uint8, 'retry'), ['int'])),
                            ('query', (YLeaf(YType.enumeration, 'query'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Dpd.Query')])),
                        ])
                        self.interval = None
                        self.retry = None
                        self.query = None
                        self._segment_path = lambda: "dpd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Dpd, ['interval', 'retry', 'query'], name, value)

                    class Query(Enum):
                        """
                        Query (Enum Class)

                        .. data:: on_demand = 0

                        .. data:: periodic = 1

                        """

                        on_demand = Enum.YLeaf(0, "on-demand")

                        periodic = Enum.YLeaf(1, "periodic")



                class Identity(Entity):
                    """
                    Specify IKE identity to use
                    
                    .. attribute:: local
                    
                    	Specify the local IKE identity to use for the negotiation
                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Identity.Local>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.Identity, self).__init__()

                        self.yang_name = "identity"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("local", ("local", Native.Crypto.Ikev2.Profile.Identity.Local))])
                        self._leafs = OrderedDict()

                        self.local = Native.Crypto.Ikev2.Profile.Identity.Local()
                        self.local.parent = self
                        self._children_name_map["local"] = "local"
                        self._segment_path = lambda: "identity"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Identity, [], name, value)


                    class Local(Entity):
                        """
                        Specify the local IKE identity to use for the negotiation
                        
                        .. attribute:: address
                        
                        	address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: dn
                        
                        	Distinguished Name
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: email
                        
                        	Fully qualified email string email <user@domain>
                        	**type**\: str
                        
                        .. attribute:: fqdn
                        
                        	Fully qualified domain name string FQDN <host.domain>
                        	**type**\: str
                        
                        .. attribute:: key_id
                        
                        	key\-id opaque string \- proprietary types of identification key\-id string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Profile.Identity.Local, self).__init__()

                            self.yang_name = "local"
                            self.yang_parent_name = "identity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                ('dn', (YLeaf(YType.empty, 'dn'), ['Empty'])),
                                ('email', (YLeaf(YType.str, 'email'), ['str'])),
                                ('fqdn', (YLeaf(YType.str, 'fqdn'), ['str'])),
                                ('key_id', (YLeaf(YType.str, 'key-id'), ['str'])),
                            ])
                            self.address = None
                            self.dn = None
                            self.email = None
                            self.fqdn = None
                            self.key_id = None
                            self._segment_path = lambda: "local"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Identity.Local, ['address', 'dn', 'email', 'fqdn', 'key_id'], name, value)


                class InitialContact(Entity):
                    """
                    initial\-contact processing options
                    
                    .. attribute:: force
                    
                    	Enforces initial\-contact based clean\-up
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.InitialContact, self).__init__()

                        self.yang_name = "initial-contact"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('force', (YLeaf(YType.empty, 'force'), ['Empty'])),
                        ])
                        self.force = None
                        self._segment_path = lambda: "initial-contact"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.InitialContact, ['force'], name, value)


                class Keyring(Entity):
                    """
                    Specify keyring to use
                    
                    .. attribute:: aaa
                    
                    	AAA based keyring
                    	**type**\: list of  		 :py:class:`Aaa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Keyring.Aaa>`
                    
                    .. attribute:: local
                    
                    	Local keyring
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.Keyring, self).__init__()

                        self.yang_name = "keyring"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aaa", ("aaa", Native.Crypto.Ikev2.Profile.Keyring.Aaa))])
                        self._leafs = OrderedDict([
                            ('local', (YLeaf(YType.str, 'local'), ['str'])),
                        ])
                        self.local = None

                        self.aaa = YList(self)
                        self._segment_path = lambda: "keyring"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Keyring, ['local'], name, value)


                    class Aaa(Entity):
                        """
                        AAA based keyring
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: name_mangler
                        
                        	Specify the name\-mangler to derive username
                        	**type**\: str
                        
                        .. attribute:: password
                        
                        	Specify the AAA password
                        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Keyring.Aaa.Password>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Profile.Keyring.Aaa, self).__init__()

                            self.yang_name = "aaa"
                            self.yang_parent_name = "keyring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Ikev2.Profile.Keyring.Aaa.Password))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('name_mangler', (YLeaf(YType.str, 'name-mangler'), ['str'])),
                            ])
                            self.name = None
                            self.name_mangler = None

                            self.password = Native.Crypto.Ikev2.Profile.Keyring.Aaa.Password()
                            self.password.parent = self
                            self._children_name_map["password"] = "password"
                            self._segment_path = lambda: "aaa" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Keyring.Aaa, ['name', 'name_mangler'], name, value)


                        class Password(Entity):
                            """
                            Specify the AAA password
                            
                            .. attribute:: encryption
                            
                            	
                            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Keyring.Aaa.Password.Encryption>`
                            
                            .. attribute:: key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Profile.Keyring.Aaa.Password, self).__init__()

                                self.yang_name = "password"
                                self.yang_parent_name = "aaa"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Keyring.Aaa.Password.Encryption')])),
                                    ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ])
                                self.encryption = None
                                self.key = None
                                self._segment_path = lambda: "password"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Profile.Keyring.Aaa.Password, ['encryption', 'key'], name, value)

                            class Encryption(Enum):
                                """
                                Encryption (Enum Class)

                                .. data:: Y_0 = 0

                                .. data:: Y_6 = 1

                                """

                                Y_0 = Enum.YLeaf(0, "0")

                                Y_6 = Enum.YLeaf(1, "6")



                class Lifetime(Entity):
                    """
                    Set lifetime for ISAKMP security association
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 120..86400
                    
                    .. attribute:: certificate
                    
                    	Enable certificate based lifetime
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.Lifetime, self).__init__()

                        self.yang_name = "lifetime"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                            ('certificate', (YLeaf(YType.empty, 'certificate'), ['Empty'])),
                        ])
                        self.seconds = None
                        self.certificate = None
                        self._segment_path = lambda: "lifetime"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Lifetime, ['seconds', 'certificate'], name, value)


                class Match(Entity):
                    """
                    Match values of peer
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Match.Address>`
                    
                    .. attribute:: certificate
                    
                    	Peer certificate attributes
                    	**type**\: str
                    
                    .. attribute:: fvrf
                    
                    	fvrf of the profile
                    	**type**\:  :py:class:`Fvrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Match.Fvrf>`
                    
                    .. attribute:: identity
                    
                    	IKE identity
                    	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Match.Identity>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.Match, self).__init__()

                        self.yang_name = "match"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Ikev2.Profile.Match.Address)), ("fvrf", ("fvrf", Native.Crypto.Ikev2.Profile.Match.Fvrf)), ("identity", ("identity", Native.Crypto.Ikev2.Profile.Match.Identity))])
                        self._leafs = OrderedDict([
                            ('certificate', (YLeaf(YType.str, 'certificate'), ['str'])),
                        ])
                        self.certificate = None

                        self.address = Native.Crypto.Ikev2.Profile.Match.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.fvrf = Native.Crypto.Ikev2.Profile.Match.Fvrf()
                        self.fvrf.parent = self
                        self._children_name_map["fvrf"] = "fvrf"

                        self.identity = Native.Crypto.Ikev2.Profile.Match.Identity()
                        self.identity.parent = self
                        self._children_name_map["identity"] = "identity"
                        self._segment_path = lambda: "match"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Match, ['certificate'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: local
                        
                        	Local address
                        	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Match.Address.Local>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Profile.Match.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("local", ("local", Native.Crypto.Ikev2.Profile.Match.Address.Local))])
                            self._leafs = OrderedDict()

                            self.local = Native.Crypto.Ikev2.Profile.Match.Address.Local()
                            self.local.parent = self
                            self._children_name_map["local"] = "local"
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Match.Address, [], name, value)


                        class Local(Entity):
                            """
                            Local address
                            
                            .. attribute:: ip
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface
                            
                            	Specify an interface
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Profile.Match.Address.Local, self).__init__()

                                self.yang_name = "local"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ])
                                self.ip = None
                                self.interface = None
                                self._segment_path = lambda: "local"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Profile.Match.Address.Local, ['ip', 'interface'], name, value)


                    class Fvrf(Entity):
                        """
                        fvrf of the profile
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: any
                        
                        	Any fvrf
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Profile.Match.Fvrf, self).__init__()

                            self.yang_name = "fvrf"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                            ])
                            self.name = None
                            self.any = None
                            self._segment_path = lambda: "fvrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Match.Fvrf, ['name', 'any'], name, value)


                    class Identity(Entity):
                        """
                        IKE identity
                        
                        .. attribute:: remote
                        
                        	Remote identity
                        	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Match.Identity.Remote>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Profile.Match.Identity, self).__init__()

                            self.yang_name = "identity"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("remote", ("remote", Native.Crypto.Ikev2.Profile.Match.Identity.Remote))])
                            self._leafs = OrderedDict()

                            self.remote = Native.Crypto.Ikev2.Profile.Match.Identity.Remote()
                            self.remote.parent = self
                            self._children_name_map["remote"] = "remote"
                            self._segment_path = lambda: "identity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Match.Identity, [], name, value)


                        class Remote(Entity):
                            """
                            Remote identity
                            
                            .. attribute:: address
                            
                            	IP address(es)
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Address>`
                            
                            .. attribute:: any
                            
                            	match any peer identity
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: email
                            
                            	Fully qualified email string [Max. 255 char(s)]
                            	**type**\:  :py:class:`Email <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Email>`
                            
                            .. attribute:: fqdn
                            
                            	Fully qualified domain name string [Max. 255 char(s)]
                            	**type**\:  :py:class:`Fqdn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Fqdn>`
                            
                            .. attribute:: key_id
                            
                            	key\-id opaque string
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ikev2.Profile.Match.Identity.Remote, self).__init__()

                                self.yang_name = "remote"
                                self.yang_parent_name = "identity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Address)), ("email", ("email", Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Email)), ("fqdn", ("fqdn", Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Fqdn))])
                                self._leafs = OrderedDict([
                                    ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                                    ('key_id', (YLeaf(YType.str, 'key-id'), ['str'])),
                                ])
                                self.any = None
                                self.key_id = None

                                self.address = Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.email = Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Email()
                                self.email.parent = self
                                self._children_name_map["email"] = "email"

                                self.fqdn = Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Fqdn()
                                self.fqdn.parent = self
                                self._children_name_map["fqdn"] = "fqdn"
                                self._segment_path = lambda: "remote"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ikev2.Profile.Match.Identity.Remote, ['any', 'key_id'], name, value)


                            class Address(Entity):
                                """
                                IP address(es)
                                
                                .. attribute:: ipv4
                                
                                	
                                	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Address.Ipv4>`
                                
                                .. attribute:: ipv6_prefix
                                
                                	
                                	**type**\: list of str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "remote"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Address.Ipv4))])
                                    self._leafs = OrderedDict([
                                        ('ipv6_prefix', (YLeafList(YType.str, 'ipv6-prefix'), ['str'])),
                                    ])
                                    self.ipv6_prefix = []

                                    self.ipv4 = YList(self)
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Address, ['ipv6_prefix'], name, value)


                                class Ipv4(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipv4_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mask
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Address.Ipv4, self).__init__()

                                        self.yang_name = "ipv4"
                                        self.yang_parent_name = "address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ipv4_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mask', (YLeaf(YType.str, 'ipv4-mask'), ['str'])),
                                        ])
                                        self.ipv4_address = None
                                        self.ipv4_mask = None
                                        self._segment_path = lambda: "ipv4" + "[ipv4-address='" + str(self.ipv4_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Address.Ipv4, ['ipv4_address', 'ipv4_mask'], name, value)


                            class Email(Entity):
                                """
                                Fully qualified email string [Max. 255 char(s)]
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: domain
                                
                                	match domain instead of exact
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Email, self).__init__()

                                    self.yang_name = "email"
                                    self.yang_parent_name = "remote"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ])
                                    self.name = None
                                    self.domain = None
                                    self._segment_path = lambda: "email"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Email, ['name', 'domain'], name, value)


                            class Fqdn(Entity):
                                """
                                Fully qualified domain name string [Max. 255 char(s)]
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: domain
                                
                                	match domain instead of exact
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Fqdn, self).__init__()

                                    self.yang_name = "fqdn"
                                    self.yang_parent_name = "remote"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                    ])
                                    self.name = None
                                    self.domain = None
                                    self._segment_path = lambda: "fqdn"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ikev2.Profile.Match.Identity.Remote.Fqdn, ['name', 'domain'], name, value)


                class Nat(Entity):
                    """
                    NAT\-transparency
                    
                    .. attribute:: keepalive
                    
                    	NAT keepalive interval
                    	**type**\: int
                    
                    	**range:** 5..3600
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.Nat, self).__init__()

                        self.yang_name = "nat"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('keepalive', (YLeaf(YType.uint16, 'keepalive'), ['int'])),
                        ])
                        self.keepalive = None
                        self._segment_path = lambda: "nat"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Nat, ['keepalive'], name, value)


                class Pki(Entity):
                    """
                    Specify certificate authorities to trust
                    
                    .. attribute:: trustpoint
                    
                    	Cert authority trustpoint for RSA sig
                    	**type**\: str
                    
                    .. attribute:: use
                    
                    	
                    	**type**\:  :py:class:`Use <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Pki.Use>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.Pki, self).__init__()

                        self.yang_name = "pki"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trustpoint', (YLeaf(YType.str, 'trustpoint'), ['str'])),
                            ('use', (YLeaf(YType.enumeration, 'use'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.Pki.Use')])),
                        ])
                        self.trustpoint = None
                        self.use = None
                        self._segment_path = lambda: "pki"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Pki, ['trustpoint', 'use'], name, value)

                    class Use(Enum):
                        """
                        Use (Enum Class)

                        .. data:: sign = 0

                        .. data:: verify = 1

                        """

                        sign = Enum.YLeaf(0, "sign")

                        verify = Enum.YLeaf(1, "verify")



                class Reconnect(Entity):
                    """
                    Enable profile for auto re\-connect
                    
                    .. attribute:: timeout
                    
                    	timeout value for session in reconnect state
                    	**type**\: int
                    
                    	**range:** 600..86400
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.Reconnect, self).__init__()

                        self.yang_name = "reconnect"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint32, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "reconnect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Reconnect, ['timeout'], name, value)


                class Redirect(Entity):
                    """
                    IKEv2 Redirect Mechanism for load\-balancing
                    
                    .. attribute:: gateway
                    
                    	Enables Redirect Mechanism on Gateway
                    	**type**\:  :py:class:`Gateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.Redirect.Gateway>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.Redirect, self).__init__()

                        self.yang_name = "redirect"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gateway", ("gateway", Native.Crypto.Ikev2.Profile.Redirect.Gateway))])
                        self._leafs = OrderedDict()

                        self.gateway = Native.Crypto.Ikev2.Profile.Redirect.Gateway()
                        self.gateway.parent = self
                        self._children_name_map["gateway"] = "gateway"
                        self._segment_path = lambda: "redirect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.Redirect, [], name, value)


                    class Gateway(Entity):
                        """
                        Enables Redirect Mechanism on Gateway
                        
                        .. attribute:: auth
                        
                        	Redirect at SA authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ikev2.Profile.Redirect.Gateway, self).__init__()

                            self.yang_name = "gateway"
                            self.yang_parent_name = "redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth', (YLeaf(YType.empty, 'auth'), ['Empty'])),
                            ])
                            self.auth = None
                            self._segment_path = lambda: "gateway"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ikev2.Profile.Redirect.Gateway, ['auth'], name, value)


                class VirtualTemplate(Entity):
                    """
                    Specify the virtual\-template for dynamic interface creation.
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4095
                    
                    .. attribute:: mode
                    
                    	Enabling Tunnel Auto Mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Profile.VirtualTemplate.Mode>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Profile.VirtualTemplate, self).__init__()

                        self.yang_name = "virtual-template"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Profile.VirtualTemplate.Mode')])),
                        ])
                        self.number = None
                        self.mode = None
                        self._segment_path = lambda: "virtual-template"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Profile.VirtualTemplate, ['number', 'mode'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        Enabling Tunnel Auto Mode

                        .. data:: auto = 0

                        """

                        auto = Enum.YLeaf(0, "auto")



            class Proposal(Entity):
                """
                Define IKEV2 proposals
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: encryption
                
                	Set encryption algorithm(s) for proposal
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Proposal.Encryption>`
                
                .. attribute:: group
                
                	Set the Diffie\-Hellman group(s)
                	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Proposal.Group>`
                
                .. attribute:: integrity
                
                	Set integrity hash algorithm(s) for proposal
                	**type**\:  :py:class:`Integrity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Proposal.Integrity>`
                
                .. attribute:: prf
                
                	Set prf algorithm(s) for proposal
                	**type**\:  :py:class:`Prf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Proposal.Prf>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Proposal, self).__init__()

                    self.yang_name = "proposal"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("encryption", ("encryption", Native.Crypto.Ikev2.Proposal.Encryption)), ("group", ("group", Native.Crypto.Ikev2.Proposal.Group)), ("integrity", ("integrity", Native.Crypto.Ikev2.Proposal.Integrity)), ("prf", ("prf", Native.Crypto.Ikev2.Proposal.Prf))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.encryption = Native.Crypto.Ikev2.Proposal.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"

                    self.group = Native.Crypto.Ikev2.Proposal.Group()
                    self.group.parent = self
                    self._children_name_map["group"] = "group"

                    self.integrity = Native.Crypto.Ikev2.Proposal.Integrity()
                    self.integrity.parent = self
                    self._children_name_map["integrity"] = "integrity"

                    self.prf = Native.Crypto.Ikev2.Proposal.Prf()
                    self.prf.parent = self
                    self._children_name_map["prf"] = "prf"
                    self._segment_path = lambda: "proposal" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Proposal, ['name'], name, value)


                class Encryption(Entity):
                    """
                    Set encryption algorithm(s) for proposal
                    
                    .. attribute:: en_3des
                    
                    	3DES
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: aes_cbc_128
                    
                    	AES\-CBC\-128
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: aes_cbc_192
                    
                    	AES\-CBC\-192
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: aes_cbc_256
                    
                    	AES\-CBC\-256
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: aes_gcm_128
                    
                    	Combined\-mode,128 bit key,16 byte ICV(Authentication Tag)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: aes_gcm_256
                    
                    	Combined\-mode,256 bit key,16 byte ICV(Authentication Tag)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: des
                    
                    	DES
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Proposal.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "proposal"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('en_3des', (YLeaf(YType.empty, 'en-3des'), ['Empty'])),
                            ('aes_cbc_128', (YLeaf(YType.empty, 'aes-cbc-128'), ['Empty'])),
                            ('aes_cbc_192', (YLeaf(YType.empty, 'aes-cbc-192'), ['Empty'])),
                            ('aes_cbc_256', (YLeaf(YType.empty, 'aes-cbc-256'), ['Empty'])),
                            ('aes_gcm_128', (YLeaf(YType.empty, 'aes-gcm-128'), ['Empty'])),
                            ('aes_gcm_256', (YLeaf(YType.empty, 'aes-gcm-256'), ['Empty'])),
                            ('des', (YLeaf(YType.empty, 'des'), ['Empty'])),
                        ])
                        self.en_3des = None
                        self.aes_cbc_128 = None
                        self.aes_cbc_192 = None
                        self.aes_cbc_256 = None
                        self.aes_gcm_128 = None
                        self.aes_gcm_256 = None
                        self.des = None
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Proposal.Encryption, ['en_3des', 'aes_cbc_128', 'aes_cbc_192', 'aes_cbc_256', 'aes_gcm_128', 'aes_gcm_256', 'des'], name, value)


                class Group(Entity):
                    """
                    Set the Diffie\-Hellman group(s)
                    
                    .. attribute:: one
                    
                    	DH 768 MODP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: fourteen
                    
                    	DH 2048 MODP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: fifteen
                    
                    	DH 3072 MODP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sixteen
                    
                    	DH 4096 MODP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nineteen
                    
                    	DH 256 ECP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: two
                    
                    	DH 1024 MODP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: twenty
                    
                    	DH 384 ECP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: twenty_one
                    
                    	DH 521 ECP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: twenty_four
                    
                    	DH 2048 (256 subgroup) MODP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: five
                    
                    	DH 1536 MODP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Proposal.Group, self).__init__()

                        self.yang_name = "group"
                        self.yang_parent_name = "proposal"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('one', (YLeaf(YType.empty, 'one'), ['Empty'])),
                            ('fourteen', (YLeaf(YType.empty, 'fourteen'), ['Empty'])),
                            ('fifteen', (YLeaf(YType.empty, 'fifteen'), ['Empty'])),
                            ('sixteen', (YLeaf(YType.empty, 'sixteen'), ['Empty'])),
                            ('nineteen', (YLeaf(YType.empty, 'nineteen'), ['Empty'])),
                            ('two', (YLeaf(YType.empty, 'two'), ['Empty'])),
                            ('twenty', (YLeaf(YType.empty, 'twenty'), ['Empty'])),
                            ('twenty_one', (YLeaf(YType.empty, 'twenty-one'), ['Empty'])),
                            ('twenty_four', (YLeaf(YType.empty, 'twenty-four'), ['Empty'])),
                            ('five', (YLeaf(YType.empty, 'five'), ['Empty'])),
                        ])
                        self.one = None
                        self.fourteen = None
                        self.fifteen = None
                        self.sixteen = None
                        self.nineteen = None
                        self.two = None
                        self.twenty = None
                        self.twenty_one = None
                        self.twenty_four = None
                        self.five = None
                        self._segment_path = lambda: "group"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Proposal.Group, ['one', 'fourteen', 'fifteen', 'sixteen', 'nineteen', 'two', 'twenty', 'twenty_one', 'twenty_four', 'five'], name, value)


                class Integrity(Entity):
                    """
                    Set integrity hash algorithm(s) for proposal
                    
                    .. attribute:: md5
                    
                    	Message Digest 5
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sha1
                    
                    	Secure Hash Standard
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sha256
                    
                    	Secure Hash Standard 2 (256 bit)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sha384
                    
                    	Secure Hash Standard 2 (384 bit)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sha512
                    
                    	Secure Hash Standard 2 (512 bit)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Proposal.Integrity, self).__init__()

                        self.yang_name = "integrity"
                        self.yang_parent_name = "proposal"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ('sha1', (YLeaf(YType.empty, 'sha1'), ['Empty'])),
                            ('sha256', (YLeaf(YType.empty, 'sha256'), ['Empty'])),
                            ('sha384', (YLeaf(YType.empty, 'sha384'), ['Empty'])),
                            ('sha512', (YLeaf(YType.empty, 'sha512'), ['Empty'])),
                        ])
                        self.md5 = None
                        self.sha1 = None
                        self.sha256 = None
                        self.sha384 = None
                        self.sha512 = None
                        self._segment_path = lambda: "integrity"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Proposal.Integrity, ['md5', 'sha1', 'sha256', 'sha384', 'sha512'], name, value)


                class Prf(Entity):
                    """
                    Set prf algorithm(s) for proposal
                    
                    .. attribute:: md5
                    
                    	Message Digest 5
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sha1
                    
                    	Secure Hash Standard
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sha256
                    
                    	Secure Hash Standard 2 (256 bit)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sha384
                    
                    	Secure Hash Standard 2 (384 bit)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sha512
                    
                    	Secure Hash Standard 2 (512 bit)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Proposal.Prf, self).__init__()

                        self.yang_name = "prf"
                        self.yang_parent_name = "proposal"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ('sha1', (YLeaf(YType.empty, 'sha1'), ['Empty'])),
                            ('sha256', (YLeaf(YType.empty, 'sha256'), ['Empty'])),
                            ('sha384', (YLeaf(YType.empty, 'sha384'), ['Empty'])),
                            ('sha512', (YLeaf(YType.empty, 'sha512'), ['Empty'])),
                        ])
                        self.md5 = None
                        self.sha1 = None
                        self.sha256 = None
                        self.sha384 = None
                        self.sha512 = None
                        self._segment_path = lambda: "prf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Proposal.Prf, ['md5', 'sha1', 'sha256', 'sha384', 'sha512'], name, value)


            class Reconnect(Entity):
                """
                Cluster Reconnect
                
                .. attribute:: key
                
                	Cluster Reconnect key
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: value
                
                	
                	**type**\: str
                
                	**length:** 1..128
                
                .. attribute:: active
                
                	Current active cluster reconnect key
                	**type**\: str
                
                	**length:** 1..128
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Reconnect, self).__init__()

                    self.yang_name = "reconnect"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('key', (YLeaf(YType.uint8, 'key'), ['int'])),
                        ('value', (YLeaf(YType.str, 'value'), ['str'])),
                        ('active', (YLeaf(YType.str, 'active'), ['str'])),
                    ])
                    self.key = None
                    self.value = None
                    self.active = None
                    self._segment_path = lambda: "reconnect"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Reconnect, ['key', 'value', 'active'], name, value)


            class Redirect(Entity):
                """
                IKEv2 Redirect Mechanism for load\-balancing
                
                .. attribute:: client
                
                	Enables Redirect Mechanism on Client
                	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Redirect.Client>`
                
                	**presence node**\: True
                
                .. attribute:: gateway
                
                	Enables Redirect Mechanism on Gateway
                	**type**\:  :py:class:`Gateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ikev2.Redirect.Gateway>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ikev2.Redirect, self).__init__()

                    self.yang_name = "redirect"
                    self.yang_parent_name = "ikev2"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("client", ("client", Native.Crypto.Ikev2.Redirect.Client))])
                    self._leafs = OrderedDict([
                        ('gateway', (YLeaf(YType.enumeration, 'gateway'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ikev2.Redirect.Gateway')])),
                    ])
                    self.gateway = None

                    self.client = None
                    self._children_name_map["client"] = "client"
                    self._segment_path = lambda: "redirect"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ikev2.Redirect, ['gateway'], name, value)

                class Gateway(Enum):
                    """
                    Gateway (Enum Class)

                    Enables Redirect Mechanism on Gateway

                    .. data:: auth = 0

                    .. data:: init = 1

                    """

                    auth = Enum.YLeaf(0, "auth")

                    init = Enum.YLeaf(1, "init")



                class Client(Entity):
                    """
                    Enables Redirect Mechanism on Client
                    
                    .. attribute:: max_redirects
                    
                    	Redirect loop detection
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ikev2.Redirect.Client, self).__init__()

                        self.yang_name = "client"
                        self.yang_parent_name = "redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_redirects', (YLeaf(YType.uint8, 'max-redirects'), ['int'])),
                        ])
                        self.max_redirects = None
                        self._segment_path = lambda: "client"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ikev2/redirect/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ikev2.Redirect.Client, ['max_redirects'], name, value)


        class Gkm(Entity):
            """
            Configure GKM (Group Key Management, GDOI or G\-IKEv2) Policy
            
            .. attribute:: group
            
            	Configure a GKM (Group Key Management, GDOI or G\-IKEv2) Group
            	**type**\: list of  		 :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Gkm, self).__init__()

                self.yang_name = "gkm"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("group", ("group", Native.Crypto.Gkm.Group))])
                self._leafs = OrderedDict()

                self.group = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:gkm"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Gkm, [], name, value)


            class Group(Entity):
                """
                Configure a GKM (Group Key Management, GDOI or G\-IKEv2) Group
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: ipv6
                
                	IPv6 GKM (Group Key Management) Group
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: client
                
                	Set the group client parameters
                	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Client>`
                
                .. attribute:: identity
                
                	Set the identity of the group
                	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Identity>`
                
                .. attribute:: passive
                
                	Set the group in passive mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: server
                
                	Set the group server for of the group
                	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server>`
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Gkm.Group, self).__init__()

                    self.yang_name = "group"
                    self.yang_parent_name = "gkm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("client", ("client", Native.Crypto.Gkm.Group.Client)), ("identity", ("identity", Native.Crypto.Gkm.Group.Identity)), ("server", ("server", Native.Crypto.Gkm.Group.Server)), ("default", ("default", Native.Crypto.Gkm.Group.Default))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                        ('passive', (YLeaf(YType.empty, 'passive'), ['Empty'])),
                    ])
                    self.name = None
                    self.ipv6 = None
                    self.passive = None

                    self.client = Native.Crypto.Gkm.Group.Client()
                    self.client.parent = self
                    self._children_name_map["client"] = "client"

                    self.identity = Native.Crypto.Gkm.Group.Identity()
                    self.identity.parent = self
                    self._children_name_map["identity"] = "identity"

                    self.server = Native.Crypto.Gkm.Group.Server()
                    self.server.parent = self
                    self._children_name_map["server"] = "server"

                    self.default = Native.Crypto.Gkm.Group.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"
                    self._segment_path = lambda: "group" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:gkm/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Gkm.Group, ['name', 'ipv6', 'passive'], name, value)


                class Client(Entity):
                    """
                    Set the group client parameters
                    
                    .. attribute:: bypass_policy
                    
                    	Allow group\-key management traffic sent to this GM only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: protocol
                    
                    	Group Member Registration & Rekey Protocol
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Client.Protocol>`
                    
                    .. attribute:: recovery_check
                    
                    	Specify GM recovery check parameters
                    	**type**\:  :py:class:`RecoveryCheck <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Client.RecoveryCheck>`
                    
                    .. attribute:: registration
                    
                    	Set the group client management/register interface
                    	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Client.Registration>`
                    
                    .. attribute:: rekey
                    
                    	Set the group client acceptable rekey ciphers and hashs
                    	**type**\:  :py:class:`Rekey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Client.Rekey>`
                    
                    .. attribute:: status
                    
                    	group\-member status
                    	**type**\:  :py:class:`Status <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Client.Status>`
                    
                    .. attribute:: transform_sets
                    
                    	Specify list of group client acceptable transform sets
                    	**type**\: list of str
                    
                    .. attribute:: transport_encrypt_key
                    
                    	Enforce group or pair\-wise keying
                    	**type**\:  :py:class:`TransportEncryptKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Client.TransportEncryptKey>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Gkm.Group.Client, self).__init__()

                        self.yang_name = "client"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol", ("protocol", Native.Crypto.Gkm.Group.Client.Protocol)), ("recovery-check", ("recovery_check", Native.Crypto.Gkm.Group.Client.RecoveryCheck)), ("registration", ("registration", Native.Crypto.Gkm.Group.Client.Registration)), ("rekey", ("rekey", Native.Crypto.Gkm.Group.Client.Rekey)), ("status", ("status", Native.Crypto.Gkm.Group.Client.Status))])
                        self._leafs = OrderedDict([
                            ('bypass_policy', (YLeaf(YType.empty, 'bypass-policy'), ['Empty'])),
                            ('transform_sets', (YLeafList(YType.str, 'transform-sets'), ['str'])),
                            ('transport_encrypt_key', (YLeaf(YType.enumeration, 'transport-encrypt-key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gkm.Group.Client.TransportEncryptKey')])),
                        ])
                        self.bypass_policy = None
                        self.transform_sets = []
                        self.transport_encrypt_key = None

                        self.protocol = Native.Crypto.Gkm.Group.Client.Protocol()
                        self.protocol.parent = self
                        self._children_name_map["protocol"] = "protocol"

                        self.recovery_check = Native.Crypto.Gkm.Group.Client.RecoveryCheck()
                        self.recovery_check.parent = self
                        self._children_name_map["recovery_check"] = "recovery-check"

                        self.registration = Native.Crypto.Gkm.Group.Client.Registration()
                        self.registration.parent = self
                        self._children_name_map["registration"] = "registration"

                        self.rekey = Native.Crypto.Gkm.Group.Client.Rekey()
                        self.rekey.parent = self
                        self._children_name_map["rekey"] = "rekey"

                        self.status = Native.Crypto.Gkm.Group.Client.Status()
                        self.status.parent = self
                        self._children_name_map["status"] = "status"
                        self._segment_path = lambda: "client"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Gkm.Group.Client, ['bypass_policy', 'transform_sets', 'transport_encrypt_key'], name, value)

                    class TransportEncryptKey(Enum):
                        """
                        TransportEncryptKey (Enum Class)

                        Enforce group or pair\-wise keying

                        .. data:: group_key = 0

                        .. data:: pair_wise_key = 1

                        """

                        group_key = Enum.YLeaf(0, "group-key")

                        pair_wise_key = Enum.YLeaf(1, "pair-wise-key")



                    class Protocol(Entity):
                        """
                        Group Member Registration & Rekey Protocol
                        
                        .. attribute:: gdoi
                        
                        	Use GDOI (ISAKMP) Protocol for Registration & Rekey
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: gikev2
                        
                        	Use G\-IKEv2 Protocol for Registration & Rekey
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Client.Protocol, self).__init__()

                            self.yang_name = "protocol"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('gdoi', (YLeaf(YType.empty, 'gdoi'), ['Empty'])),
                                ('gikev2', (YLeaf(YType.str, 'gikev2'), ['str'])),
                            ])
                            self.gdoi = None
                            self.gikev2 = None
                            self._segment_path = lambda: "protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gkm.Group.Client.Protocol, ['gdoi', 'gikev2'], name, value)


                    class RecoveryCheck(Entity):
                        """
                        Specify GM recovery check parameters
                        
                        .. attribute:: interval
                        
                        	Waiting period(sec) between consecutive recovery registrations
                        	**type**\: int
                        
                        	**range:** 100..1000
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Client.RecoveryCheck, self).__init__()

                            self.yang_name = "recovery-check"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "recovery-check"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gkm.Group.Client.RecoveryCheck, ['interval'], name, value)


                    class Registration(Entity):
                        """
                        Set the group client management/register interface
                        
                        .. attribute:: interface
                        
                        	Set the group client management/register interface
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Client.Registration, self).__init__()

                            self.yang_name = "registration"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "registration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gkm.Group.Client.Registration, ['interface'], name, value)


                    class Rekey(Entity):
                        """
                        Set the group client acceptable rekey ciphers and hashs
                        
                        .. attribute:: encryption
                        
                        	Set the group client acceptable rekey ciphers
                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Client.Rekey.Encryption>`
                        
                        .. attribute:: hash
                        
                        	Set the group client acceptable rekey hash
                        	**type**\:  :py:class:`Hash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Client.Rekey.Hash>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Client.Rekey, self).__init__()

                            self.yang_name = "rekey"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encryption", ("encryption", Native.Crypto.Gkm.Group.Client.Rekey.Encryption)), ("hash", ("hash", Native.Crypto.Gkm.Group.Client.Rekey.Hash))])
                            self._leafs = OrderedDict()

                            self.encryption = Native.Crypto.Gkm.Group.Client.Rekey.Encryption()
                            self.encryption.parent = self
                            self._children_name_map["encryption"] = "encryption"

                            self.hash = Native.Crypto.Gkm.Group.Client.Rekey.Hash()
                            self.hash.parent = self
                            self._children_name_map["hash"] = "hash"
                            self._segment_path = lambda: "rekey"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gkm.Group.Client.Rekey, [], name, value)


                        class Encryption(Entity):
                            """
                            Set the group client acceptable rekey ciphers
                            
                            .. attribute:: rekey_3des_cbc
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: aes_128
                            
                            	128 bit AES
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: aes_192
                            
                            	192 bit AES
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: aes_256
                            
                            	256 bit AES
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: des_cbc
                            
                            	DES in CBC mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Client.Rekey.Encryption, self).__init__()

                                self.yang_name = "encryption"
                                self.yang_parent_name = "rekey"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rekey_3des_cbc', (YLeaf(YType.empty, 'rekey-3des-cbc'), ['Empty'])),
                                    ('aes_128', (YLeaf(YType.empty, 'aes-128'), ['Empty'])),
                                    ('aes_192', (YLeaf(YType.empty, 'aes-192'), ['Empty'])),
                                    ('aes_256', (YLeaf(YType.empty, 'aes-256'), ['Empty'])),
                                    ('des_cbc', (YLeaf(YType.empty, 'des-cbc'), ['Empty'])),
                                ])
                                self.rekey_3des_cbc = None
                                self.aes_128 = None
                                self.aes_192 = None
                                self.aes_256 = None
                                self.des_cbc = None
                                self._segment_path = lambda: "encryption"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Client.Rekey.Encryption, ['rekey_3des_cbc', 'aes_128', 'aes_192', 'aes_256', 'des_cbc'], name, value)


                        class Hash(Entity):
                            """
                            Set the group client acceptable rekey hash
                            
                            .. attribute:: sha
                            
                            	Secure Hash Standard
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sha256
                            
                            	Secure Hash Standard 2 (256 bit)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sha384
                            
                            	Secure Hash Standard 2 (384 bit)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sha512
                            
                            	Secure Hash Standard 2 (512 bit)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Client.Rekey.Hash, self).__init__()

                                self.yang_name = "hash"
                                self.yang_parent_name = "rekey"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sha', (YLeaf(YType.empty, 'sha'), ['Empty'])),
                                    ('sha256', (YLeaf(YType.empty, 'sha256'), ['Empty'])),
                                    ('sha384', (YLeaf(YType.empty, 'sha384'), ['Empty'])),
                                    ('sha512', (YLeaf(YType.empty, 'sha512'), ['Empty'])),
                                ])
                                self.sha = None
                                self.sha256 = None
                                self.sha384 = None
                                self.sha512 = None
                                self._segment_path = lambda: "hash"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Client.Rekey.Hash, ['sha', 'sha256', 'sha384', 'sha512'], name, value)


                    class Status(Entity):
                        """
                        group\-member status
                        
                        .. attribute:: active_sa
                        
                        	TEK SA with positive remaining lifetime
                        	**type**\:  :py:class:`ActiveSa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Client.Status.ActiveSa>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Client.Status, self).__init__()

                            self.yang_name = "status"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("active-sa", ("active_sa", Native.Crypto.Gkm.Group.Client.Status.ActiveSa))])
                            self._leafs = OrderedDict()

                            self.active_sa = Native.Crypto.Gkm.Group.Client.Status.ActiveSa()
                            self.active_sa.parent = self
                            self._children_name_map["active_sa"] = "active-sa"
                            self._segment_path = lambda: "status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gkm.Group.Client.Status, [], name, value)


                        class ActiveSa(Entity):
                            """
                            TEK SA with positive remaining lifetime
                            
                            .. attribute:: track
                            
                            	enable stub tracking object
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Client.Status.ActiveSa, self).__init__()

                                self.yang_name = "active-sa"
                                self.yang_parent_name = "status"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('track', (YLeaf(YType.uint16, 'track'), ['int'])),
                                ])
                                self.track = None
                                self._segment_path = lambda: "active-sa"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Client.Status.ActiveSa, ['track'], name, value)


                class Identity(Entity):
                    """
                    Set the identity of the group
                    
                    .. attribute:: address
                    
                    	Set the identity of the group as an address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Identity.Address>`
                    
                    .. attribute:: number
                    
                    	Set the identity of the group as a number
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Gkm.Group.Identity, self).__init__()

                        self.yang_name = "identity"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Identity.Address))])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint64, 'number'), ['int'])),
                        ])
                        self.number = None

                        self.address = Native.Crypto.Gkm.Group.Identity.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._segment_path = lambda: "identity"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Gkm.Group.Identity, ['number'], name, value)


                    class Address(Entity):
                        """
                        Set the identity of the group as an address
                        
                        .. attribute:: ipv4
                        
                        	Set the identity of the group as an IPv4 address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Identity.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "identity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                            ])
                            self.ipv4 = None
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gkm.Group.Identity.Address, ['ipv4'], name, value)


                class Server(Entity):
                    """
                    Set the group server for of the group
                    
                    .. attribute:: address
                    
                    	Identify the group server by address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Address>`
                    
                    .. attribute:: hostname
                    
                    	Identify the group server by hostname
                    	**type**\:  :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Hostname>`
                    
                    .. attribute:: local
                    
                    	Configure GKM group server defined locally
                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Gkm.Group.Server, self).__init__()

                        self.yang_name = "server"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Server.Address)), ("hostname", ("hostname", Native.Crypto.Gkm.Group.Server.Hostname)), ("local", ("local", Native.Crypto.Gkm.Group.Server.Local))])
                        self._leafs = OrderedDict()

                        self.address = Native.Crypto.Gkm.Group.Server.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.hostname = Native.Crypto.Gkm.Group.Server.Hostname()
                        self.hostname.parent = self
                        self._children_name_map["hostname"] = "hostname"

                        self.local = Native.Crypto.Gkm.Group.Server.Local()
                        self.local.parent = self
                        self._children_name_map["local"] = "local"
                        self._segment_path = lambda: "server"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Gkm.Group.Server, [], name, value)


                    class Address(Entity):
                        """
                        Identify the group server by address
                        
                        .. attribute:: ipv4
                        
                        	Set the IPv4 address of the group server
                        	**type**\: list of str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6
                        
                        	Set the IPv6 address of the group server
                        	**type**\: list of str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Server.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeafList(YType.str, 'ipv4'), ['str'])),
                                ('ipv6', (YLeafList(YType.str, 'ipv6'), ['str'])),
                            ])
                            self.ipv4 = []
                            self.ipv6 = []
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gkm.Group.Server.Address, ['ipv4', 'ipv6'], name, value)


                    class Hostname(Entity):
                        """
                        Identify the group server by hostname
                        
                        .. attribute:: ipv4
                        
                        	Set the IPv4 hostname of the group server
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Server.Hostname, self).__init__()

                            self.yang_name = "hostname"
                            self.yang_parent_name = "server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                            ])
                            self.ipv4 = None
                            self._segment_path = lambda: "hostname"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gkm.Group.Server.Hostname, ['ipv4'], name, value)


                    class Local(Entity):
                        """
                        Configure GKM group server defined locally
                        
                        .. attribute:: address
                        
                        	Configure server source address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Address>`
                        
                        .. attribute:: authorization
                        
                        	Configure authorization for the group
                        	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Authorization>`
                        
                        .. attribute:: gdoi
                        
                        	Enable GDOI (ISAKMP) Protocol for Registration & Rekey
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: gikev2
                        
                        	Enable G\-IKEv2 (IKEv2) Protocol for Registration & Rekey
                        	**type**\: str
                        
                        .. attribute:: group
                        
                        	Configure parameters for the group (e.g. Suite\-B)
                        	**type**\:  :py:class:`Group_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Group_>`
                        
                        .. attribute:: identifier
                        
                        	Enter Suite\-B KSSID (Key Server Sender ID) config mode
                        	**type**\:  :py:class:`Identifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Identifier>`
                        
                        .. attribute:: redundancy
                        
                        	Enter cooperative key server configuration mode
                        	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy>`
                        
                        .. attribute:: registration
                        
                        	Configure registration for the group
                        	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Registration>`
                        
                        .. attribute:: rekey
                        
                        	Configure rekey policy for the group
                        	**type**\:  :py:class:`Rekey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Rekey>`
                        
                        .. attribute:: sa
                        
                        	Configure a security association
                        	**type**\:  :py:class:`Sa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa>`
                        
                        .. attribute:: default
                        
                        	Set a command to its defaults
                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Server.Local, self).__init__()

                            self.yang_name = "local"
                            self.yang_parent_name = "server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Server.Local.Address)), ("authorization", ("authorization", Native.Crypto.Gkm.Group.Server.Local.Authorization)), ("group", ("group", Native.Crypto.Gkm.Group.Server.Local.Group_)), ("identifier", ("identifier", Native.Crypto.Gkm.Group.Server.Local.Identifier)), ("redundancy", ("redundancy", Native.Crypto.Gkm.Group.Server.Local.Redundancy)), ("registration", ("registration", Native.Crypto.Gkm.Group.Server.Local.Registration)), ("rekey", ("rekey", Native.Crypto.Gkm.Group.Server.Local.Rekey)), ("sa", ("sa", Native.Crypto.Gkm.Group.Server.Local.Sa)), ("default", ("default", Native.Crypto.Gkm.Group.Server.Local.Default))])
                            self._leafs = OrderedDict([
                                ('gdoi', (YLeaf(YType.empty, 'gdoi'), ['Empty'])),
                                ('gikev2', (YLeaf(YType.str, 'gikev2'), ['str'])),
                            ])
                            self.gdoi = None
                            self.gikev2 = None

                            self.address = Native.Crypto.Gkm.Group.Server.Local.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"

                            self.authorization = Native.Crypto.Gkm.Group.Server.Local.Authorization()
                            self.authorization.parent = self
                            self._children_name_map["authorization"] = "authorization"

                            self.group = Native.Crypto.Gkm.Group.Server.Local.Group_()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"

                            self.identifier = Native.Crypto.Gkm.Group.Server.Local.Identifier()
                            self.identifier.parent = self
                            self._children_name_map["identifier"] = "identifier"

                            self.redundancy = Native.Crypto.Gkm.Group.Server.Local.Redundancy()
                            self.redundancy.parent = self
                            self._children_name_map["redundancy"] = "redundancy"

                            self.registration = Native.Crypto.Gkm.Group.Server.Local.Registration()
                            self.registration.parent = self
                            self._children_name_map["registration"] = "registration"

                            self.rekey = Native.Crypto.Gkm.Group.Server.Local.Rekey()
                            self.rekey.parent = self
                            self._children_name_map["rekey"] = "rekey"

                            self.sa = Native.Crypto.Gkm.Group.Server.Local.Sa()
                            self.sa.parent = self
                            self._children_name_map["sa"] = "sa"

                            self.default = Native.Crypto.Gkm.Group.Server.Local.Default()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"
                            self._segment_path = lambda: "local"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local, ['gdoi', 'gikev2'], name, value)


                        class Address(Entity):
                            """
                            Configure server source address
                            
                            .. attribute:: ipv4
                            
                            	Set ipv4 address of local server
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Server.Local.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ])
                                self.ipv4 = None
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Address, ['ipv4'], name, value)


                        class Authorization(Entity):
                            """
                            Configure authorization for the group
                            
                            .. attribute:: address
                            
                            	Set authorization by address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Authorization.Address>`
                            
                            .. attribute:: identity
                            
                            	Set authorization by identity
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Server.Local.Authorization, self).__init__()

                                self.yang_name = "authorization"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Server.Local.Authorization.Address))])
                                self._leafs = OrderedDict([
                                    ('identity', (YLeaf(YType.str, 'identity'), ['str'])),
                                ])
                                self.identity = None

                                self.address = Native.Crypto.Gkm.Group.Server.Local.Authorization.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "authorization"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Authorization, ['identity'], name, value)


                            class Address(Entity):
                                """
                                Set authorization by address
                                
                                .. attribute:: ipv4
                                
                                	Set authorization by address
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..99
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Authorization.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "authorization"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['int','str'])),
                                    ])
                                    self.ipv4 = None
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Authorization.Address, ['ipv4'], name, value)


                        class Group_(Entity):
                            """
                            Configure parameters for the group (e.g. Suite\-B)
                            
                            .. attribute:: size
                            
                            	Set Group Size for Suite\-B counter transforms (SID length)
                            	**type**\:  :py:class:`Size <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Group_.Size>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Server.Local.Group_, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("size", ("size", Native.Crypto.Gkm.Group.Server.Local.Group_.Size))])
                                self._leafs = OrderedDict()

                                self.size = Native.Crypto.Gkm.Group.Server.Local.Group_.Size()
                                self.size.parent = self
                                self._children_name_map["size"] = "size"
                                self._segment_path = lambda: "group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Group_, [], name, value)


                            class Size(Entity):
                                """
                                Set Group Size for Suite\-B counter transforms (SID length)
                                
                                .. attribute:: large
                                
                                	32\-bit Sender ID (FIPS 140\-2 Operating Mode)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: medium
                                
                                	24\-bit Sender ID (Default)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: small
                                
                                	Interoperable with GDOI / G\-IKEv2 Standard
                                	**type**\:  :py:class:`Small <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Group_.Size.Small>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Group_.Size, self).__init__()

                                    self.yang_name = "size"
                                    self.yang_parent_name = "group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('large', (YLeaf(YType.empty, 'large'), ['Empty'])),
                                        ('medium', (YLeaf(YType.empty, 'medium'), ['Empty'])),
                                        ('small', (YLeaf(YType.enumeration, 'small'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gkm.Group.Server.Local.Group_.Size.Small')])),
                                    ])
                                    self.large = None
                                    self.medium = None
                                    self.small = None
                                    self._segment_path = lambda: "size"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Group_.Size, ['large', 'medium', 'small'], name, value)

                                class Small(Enum):
                                    """
                                    Small (Enum Class)

                                    Interoperable with GDOI / G\-IKEv2 Standard

                                    .. data:: Y_12 = 0

                                    .. data:: Y_16 = 1

                                    .. data:: Y_8 = 2

                                    """

                                    Y_12 = Enum.YLeaf(0, "12")

                                    Y_16 = Enum.YLeaf(1, "16")

                                    Y_8 = Enum.YLeaf(2, "8")



                        class Identifier(Entity):
                            """
                            Enter Suite\-B KSSID (Key Server Sender ID) config mode
                            
                            .. attribute:: default
                            
                            	Set a command to its defaults
                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Identifier.Default>`
                            
                            .. attribute:: range
                            
                            	Assign range of Key Server Sender IDs (unique in entire group)
                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Identifier.Range>`
                            
                            .. attribute:: value
                            
                            	Assign Key Server Sender ID (unique in entire group)
                            	**type**\: int
                            
                            	**range:** 0..1
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Server.Local.Identifier, self).__init__()

                                self.yang_name = "identifier"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Gkm.Group.Server.Local.Identifier.Default)), ("range", ("range", Native.Crypto.Gkm.Group.Server.Local.Identifier.Range))])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                ])
                                self.value = None

                                self.default = Native.Crypto.Gkm.Group.Server.Local.Identifier.Default()
                                self.default.parent = self
                                self._children_name_map["default"] = "default"

                                self.range = Native.Crypto.Gkm.Group.Server.Local.Identifier.Range()
                                self.range.parent = self
                                self._children_name_map["range"] = "range"
                                self._segment_path = lambda: "identifier"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Identifier, ['value'], name, value)


                            class Default(Entity):
                                """
                                Set a command to its defaults
                                
                                .. attribute:: range
                                
                                	Assign range of Key Server Sender IDs (unique in entire group)
                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Identifier.Default.Range>`
                                
                                .. attribute:: value
                                
                                	Assign Key Server Sender ID (unique in entire group)
                                	**type**\: int
                                
                                	**range:** 0..1
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Identifier.Default, self).__init__()

                                    self.yang_name = "default"
                                    self.yang_parent_name = "identifier"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Crypto.Gkm.Group.Server.Local.Identifier.Default.Range))])
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.uint8, 'value'), ['int'])),
                                    ])
                                    self.value = None

                                    self.range = Native.Crypto.Gkm.Group.Server.Local.Identifier.Default.Range()
                                    self.range.parent = self
                                    self._children_name_map["range"] = "range"
                                    self._segment_path = lambda: "default"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Identifier.Default, ['value'], name, value)


                                class Range(Entity):
                                    """
                                    Assign range of Key Server Sender IDs (unique in entire group)
                                    
                                    .. attribute:: lowest
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..1
                                    
                                    .. attribute:: hyphen
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: highest
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..1
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Identifier.Default.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lowest', (YLeaf(YType.uint8, 'lowest'), ['int'])),
                                            ('hyphen', (YLeaf(YType.empty, 'hyphen'), ['Empty'])),
                                            ('highest', (YLeaf(YType.uint8, 'highest'), ['int'])),
                                        ])
                                        self.lowest = None
                                        self.hyphen = None
                                        self.highest = None
                                        self._segment_path = lambda: "range"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Identifier.Default.Range, ['lowest', 'hyphen', 'highest'], name, value)


                            class Range(Entity):
                                """
                                Assign range of Key Server Sender IDs (unique in entire group)
                                
                                .. attribute:: lowest
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..1
                                
                                .. attribute:: hyphen
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: highest
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..1
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Identifier.Range, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "identifier"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lowest', (YLeaf(YType.uint8, 'lowest'), ['int'])),
                                        ('hyphen', (YLeaf(YType.empty, 'hyphen'), ['Empty'])),
                                        ('highest', (YLeaf(YType.uint8, 'highest'), ['int'])),
                                    ])
                                    self.lowest = None
                                    self.hyphen = None
                                    self.highest = None
                                    self._segment_path = lambda: "range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Identifier.Range, ['lowest', 'hyphen', 'highest'], name, value)


                        class Redundancy(Entity):
                            """
                            Enter cooperative key server configuration mode
                            
                            .. attribute:: default
                            
                            	Set a command to its defaults
                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default>`
                            
                            .. attribute:: local
                            
                            	Local key server configurations
                            	**type**\:  :py:class:`Local_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy.Local_>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: peer
                            
                            	Peer server configurations
                            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy.Peer>`
                            
                            .. attribute:: protocol
                            
                            	Specify various protocol operational values
                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy.Protocol>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Server.Local.Redundancy, self).__init__()

                                self.yang_name = "redundancy"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default)), ("local", ("local", Native.Crypto.Gkm.Group.Server.Local.Redundancy.Local_)), ("peer", ("peer", Native.Crypto.Gkm.Group.Server.Local.Redundancy.Peer)), ("protocol", ("protocol", Native.Crypto.Gkm.Group.Server.Local.Redundancy.Protocol))])
                                self._leafs = OrderedDict()

                                self.default = Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default()
                                self.default.parent = self
                                self._children_name_map["default"] = "default"

                                self.local = None
                                self._children_name_map["local"] = "local"

                                self.peer = Native.Crypto.Gkm.Group.Server.Local.Redundancy.Peer()
                                self.peer.parent = self
                                self._children_name_map["peer"] = "peer"

                                self.protocol = None
                                self._children_name_map["protocol"] = "protocol"
                                self._segment_path = lambda: "redundancy"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Redundancy, [], name, value)


                            class Default(Entity):
                                """
                                Set a command to its defaults
                                
                                .. attribute:: local
                                
                                	Local key server configurations
                                	**type**\:  :py:class:`Local_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Local_>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: peer
                                
                                	Peer server configurations
                                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Peer>`
                                
                                .. attribute:: protocol
                                
                                	Specify various protocol operational values
                                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Protocol>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default, self).__init__()

                                    self.yang_name = "default"
                                    self.yang_parent_name = "redundancy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local", ("local", Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Local_)), ("peer", ("peer", Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Peer)), ("protocol", ("protocol", Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Protocol))])
                                    self._leafs = OrderedDict()

                                    self.local = None
                                    self._children_name_map["local"] = "local"

                                    self.peer = Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Peer()
                                    self.peer.parent = self
                                    self._children_name_map["peer"] = "peer"

                                    self.protocol = None
                                    self._children_name_map["protocol"] = "protocol"
                                    self._segment_path = lambda: "default"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default, [], name, value)


                                class Local_(Entity):
                                    """
                                    Local key server configurations
                                    
                                    .. attribute:: priority
                                    
                                    	Set local server priority
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Local_, self).__init__()

                                        self.yang_name = "local"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "local"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Local_, ['priority'], name, value)


                                class Peer(Entity):
                                    """
                                    Peer server configurations
                                    
                                    .. attribute:: address
                                    
                                    	Peer server address
                                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Peer.Address>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Peer, self).__init__()

                                        self.yang_name = "peer"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Peer.Address))])
                                        self._leafs = OrderedDict()

                                        self.address = Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Peer.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._segment_path = lambda: "peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Peer, [], name, value)


                                    class Address(Entity):
                                        """
                                        Peer server address
                                        
                                        .. attribute:: ipv4
                                        
                                        	Set peer server ipv4 address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Peer.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ])
                                            self.ipv4 = None
                                            self._segment_path = lambda: "address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Peer.Address, ['ipv4'], name, value)


                                class Protocol(Entity):
                                    """
                                    Specify various protocol operational values
                                    
                                    .. attribute:: pdu
                                    
                                    	Maximum size of COOP messages
                                    	**type**\: int
                                    
                                    	**range:** 1..65000
                                    
                                    .. attribute:: version
                                    
                                    	Set COOP ANN version
                                    	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Protocol.Version>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Protocol, self).__init__()

                                        self.yang_name = "protocol"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('pdu', (YLeaf(YType.uint32, 'pdu'), ['int'])),
                                            ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gkm.Group.Server.Local.Redundancy.Default.Protocol.Version')])),
                                        ])
                                        self.pdu = None
                                        self.version = None
                                        self._segment_path = lambda: "protocol"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Default.Protocol, ['pdu', 'version'], name, value)

                                    class Version(Enum):
                                        """
                                        Version (Enum Class)

                                        Set COOP ANN version

                                        .. data:: base = 0

                                        .. data:: optimize = 1

                                        """

                                        base = Enum.YLeaf(0, "base")

                                        optimize = Enum.YLeaf(1, "optimize")



                            class Local_(Entity):
                                """
                                Local key server configurations
                                
                                .. attribute:: priority
                                
                                	Set local server priority
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Local_, self).__init__()

                                    self.yang_name = "local"
                                    self.yang_parent_name = "redundancy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ])
                                    self.priority = None
                                    self._segment_path = lambda: "local"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Local_, ['priority'], name, value)


                            class Peer(Entity):
                                """
                                Peer server configurations
                                
                                .. attribute:: address
                                
                                	Peer server address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy.Peer.Address>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Peer, self).__init__()

                                    self.yang_name = "peer"
                                    self.yang_parent_name = "redundancy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Server.Local.Redundancy.Peer.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = Native.Crypto.Gkm.Group.Server.Local.Redundancy.Peer.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Peer, [], name, value)


                                class Address(Entity):
                                    """
                                    Peer server address
                                    
                                    .. attribute:: ipv4
                                    
                                    	Set peer server ipv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Peer.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "peer"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Peer.Address, ['ipv4'], name, value)


                            class Protocol(Entity):
                                """
                                Specify various protocol operational values
                                
                                .. attribute:: pdu
                                
                                	Maximum size of COOP messages
                                	**type**\: int
                                
                                	**range:** 1..65000
                                
                                .. attribute:: version
                                
                                	Set COOP ANN version
                                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Redundancy.Protocol.Version>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Protocol, self).__init__()

                                    self.yang_name = "protocol"
                                    self.yang_parent_name = "redundancy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('pdu', (YLeaf(YType.uint32, 'pdu'), ['int'])),
                                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gkm.Group.Server.Local.Redundancy.Protocol.Version')])),
                                    ])
                                    self.pdu = None
                                    self.version = None
                                    self._segment_path = lambda: "protocol"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Redundancy.Protocol, ['pdu', 'version'], name, value)

                                class Version(Enum):
                                    """
                                    Version (Enum Class)

                                    Set COOP ANN version

                                    .. data:: base = 0

                                    .. data:: optimize = 1

                                    """

                                    base = Enum.YLeaf(0, "base")

                                    optimize = Enum.YLeaf(1, "optimize")



                        class Registration(Entity):
                            """
                            Configure registration for the group
                            
                            .. attribute:: interface
                            
                            	Identify an interface on which to respond to GKM registrations
                            	**type**\: str
                            
                            .. attribute:: periodic
                            
                            	Define periodic registrations for the group
                            	**type**\:  :py:class:`Periodic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Registration.Periodic>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Server.Local.Registration, self).__init__()

                                self.yang_name = "registration"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("periodic", ("periodic", Native.Crypto.Gkm.Group.Server.Local.Registration.Periodic))])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ])
                                self.interface = None

                                self.periodic = Native.Crypto.Gkm.Group.Server.Local.Registration.Periodic()
                                self.periodic.parent = self
                                self._children_name_map["periodic"] = "periodic"
                                self._segment_path = lambda: "registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Registration, ['interface'], name, value)


                            class Periodic(Entity):
                                """
                                Define periodic registrations for the group
                                
                                .. attribute:: crl
                                
                                	On every new CRL
                                	**type**\:  :py:class:`Crl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Registration.Periodic.Crl>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Registration.Periodic, self).__init__()

                                    self.yang_name = "periodic"
                                    self.yang_parent_name = "registration"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("crl", ("crl", Native.Crypto.Gkm.Group.Server.Local.Registration.Periodic.Crl))])
                                    self._leafs = OrderedDict()

                                    self.crl = Native.Crypto.Gkm.Group.Server.Local.Registration.Periodic.Crl()
                                    self.crl.parent = self
                                    self._children_name_map["crl"] = "crl"
                                    self._segment_path = lambda: "periodic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Registration.Periodic, [], name, value)


                                class Crl(Entity):
                                    """
                                    On every new CRL
                                    
                                    .. attribute:: trustpoint
                                    
                                    	For a PKI trustpoint
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Registration.Periodic.Crl, self).__init__()

                                        self.yang_name = "crl"
                                        self.yang_parent_name = "periodic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('trustpoint', (YLeaf(YType.str, 'trustpoint'), ['str'])),
                                        ])
                                        self.trustpoint = None
                                        self._segment_path = lambda: "crl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Registration.Periodic.Crl, ['trustpoint'], name, value)


                        class Rekey(Entity):
                            """
                            Configure rekey policy for the group
                            
                            .. attribute:: acknowledgement
                            
                            	Request group members to acknowledge rekeys
                            	**type**\:  :py:class:`Acknowledgement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Rekey.Acknowledgement>`
                            
                            .. attribute:: address
                            
                            	Define the rekey packet format
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Rekey.Address>`
                            
                            .. attribute:: algorithm
                            
                            	Set the rekey encryption algorithm
                            	**type**\:  :py:class:`Algorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Rekey.Algorithm>`
                            
                            .. attribute:: authentication
                            
                            	Identify the rekey authentication keypair
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Rekey.Authentication>`
                            
                            .. attribute:: lifetime
                            
                            	Define the rekey lifetime
                            	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Rekey.Lifetime>`
                            
                            .. attribute:: retransmit
                            
                            	Define the rekey retransmission parameters
                            	**type**\:  :py:class:`Retransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Rekey.Retransmit>`
                            
                            .. attribute:: sig_hash
                            
                            	Set rekey signature\-hash parameters
                            	**type**\:  :py:class:`SigHash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Rekey.SigHash>`
                            
                            .. attribute:: transport
                            
                            	Specify the rekey distribution method
                            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Rekey.Transport>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Server.Local.Rekey, self).__init__()

                                self.yang_name = "rekey"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Server.Local.Rekey.Address)), ("algorithm", ("algorithm", Native.Crypto.Gkm.Group.Server.Local.Rekey.Algorithm)), ("authentication", ("authentication", Native.Crypto.Gkm.Group.Server.Local.Rekey.Authentication)), ("lifetime", ("lifetime", Native.Crypto.Gkm.Group.Server.Local.Rekey.Lifetime)), ("retransmit", ("retransmit", Native.Crypto.Gkm.Group.Server.Local.Rekey.Retransmit)), ("sig-hash", ("sig_hash", Native.Crypto.Gkm.Group.Server.Local.Rekey.SigHash)), ("transport", ("transport", Native.Crypto.Gkm.Group.Server.Local.Rekey.Transport))])
                                self._leafs = OrderedDict([
                                    ('acknowledgement', (YLeaf(YType.enumeration, 'acknowledgement'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gkm.Group.Server.Local.Rekey.Acknowledgement')])),
                                ])
                                self.acknowledgement = None

                                self.address = Native.Crypto.Gkm.Group.Server.Local.Rekey.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.algorithm = Native.Crypto.Gkm.Group.Server.Local.Rekey.Algorithm()
                                self.algorithm.parent = self
                                self._children_name_map["algorithm"] = "algorithm"

                                self.authentication = Native.Crypto.Gkm.Group.Server.Local.Rekey.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"

                                self.lifetime = Native.Crypto.Gkm.Group.Server.Local.Rekey.Lifetime()
                                self.lifetime.parent = self
                                self._children_name_map["lifetime"] = "lifetime"

                                self.retransmit = Native.Crypto.Gkm.Group.Server.Local.Rekey.Retransmit()
                                self.retransmit.parent = self
                                self._children_name_map["retransmit"] = "retransmit"

                                self.sig_hash = Native.Crypto.Gkm.Group.Server.Local.Rekey.SigHash()
                                self.sig_hash.parent = self
                                self._children_name_map["sig_hash"] = "sig-hash"

                                self.transport = Native.Crypto.Gkm.Group.Server.Local.Rekey.Transport()
                                self.transport.parent = self
                                self._children_name_map["transport"] = "transport"
                                self._segment_path = lambda: "rekey"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Rekey, ['acknowledgement'], name, value)

                            class Acknowledgement(Enum):
                                """
                                Acknowledgement (Enum Class)

                                Request group members to acknowledge rekeys

                                .. data:: any = 0

                                .. data:: cisco = 1

                                .. data:: interoperable = 2

                                """

                                any = Enum.YLeaf(0, "any")

                                cisco = Enum.YLeaf(1, "cisco")

                                interoperable = Enum.YLeaf(2, "interoperable")



                            class Address(Entity):
                                """
                                Define the rekey packet format
                                
                                .. attribute:: ipv4
                                
                                	Match ipv4 packets
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 100..199
                                
                                		**type**\: int
                                
                                			**range:** 2000..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Rekey.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['int','int','str'])),
                                    ])
                                    self.ipv4 = None
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Rekey.Address, ['ipv4'], name, value)


                            class Algorithm(Entity):
                                """
                                Set the rekey encryption algorithm
                                
                                .. attribute:: a3des_cbc
                                
                                	Triple DES in CBC mode
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: aes_128
                                
                                	128 bit AES
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: aes_192
                                
                                	192 bit AES
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: aes_256
                                
                                	256 bit AES
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: des_cbc
                                
                                	DES in CBC mode
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Rekey.Algorithm, self).__init__()

                                    self.yang_name = "algorithm"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('a3des_cbc', (YLeaf(YType.empty, 'a3des-cbc'), ['Empty'])),
                                        ('aes_128', (YLeaf(YType.empty, 'aes-128'), ['Empty'])),
                                        ('aes_192', (YLeaf(YType.empty, 'aes-192'), ['Empty'])),
                                        ('aes_256', (YLeaf(YType.empty, 'aes-256'), ['Empty'])),
                                        ('des_cbc', (YLeaf(YType.empty, 'des-cbc'), ['Empty'])),
                                    ])
                                    self.a3des_cbc = None
                                    self.aes_128 = None
                                    self.aes_192 = None
                                    self.aes_256 = None
                                    self.des_cbc = None
                                    self._segment_path = lambda: "algorithm"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Rekey.Algorithm, ['a3des_cbc', 'aes_128', 'aes_192', 'aes_256', 'des_cbc'], name, value)


                            class Authentication(Entity):
                                """
                                Identify the rekey authentication keypair
                                
                                .. attribute:: mypubkey
                                
                                	Identify a keypair associated with this device
                                	**type**\:  :py:class:`Mypubkey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Rekey.Authentication.Mypubkey>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Rekey.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mypubkey", ("mypubkey", Native.Crypto.Gkm.Group.Server.Local.Rekey.Authentication.Mypubkey))])
                                    self._leafs = OrderedDict()

                                    self.mypubkey = Native.Crypto.Gkm.Group.Server.Local.Rekey.Authentication.Mypubkey()
                                    self.mypubkey.parent = self
                                    self._children_name_map["mypubkey"] = "mypubkey"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Rekey.Authentication, [], name, value)


                                class Mypubkey(Entity):
                                    """
                                    Identify a keypair associated with this device
                                    
                                    .. attribute:: rsa
                                    
                                    	Identify an RSA keypair
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Rekey.Authentication.Mypubkey, self).__init__()

                                        self.yang_name = "mypubkey"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rsa', (YLeaf(YType.str, 'rsa'), ['str'])),
                                        ])
                                        self.rsa = None
                                        self._segment_path = lambda: "mypubkey"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Rekey.Authentication.Mypubkey, ['rsa'], name, value)


                            class Lifetime(Entity):
                                """
                                Define the rekey lifetime
                                
                                .. attribute:: days
                                
                                	Time\-based key duration in days
                                	**type**\: int
                                
                                	**range:** 1..30
                                
                                .. attribute:: seconds
                                
                                	Time\-based key duration in seconds
                                	**type**\: int
                                
                                	**range:** 300..2592000
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Rekey.Lifetime, self).__init__()

                                    self.yang_name = "lifetime"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('days', (YLeaf(YType.uint8, 'days'), ['int'])),
                                        ('seconds', (YLeaf(YType.uint64, 'seconds'), ['int'])),
                                    ])
                                    self.days = None
                                    self.seconds = None
                                    self._segment_path = lambda: "lifetime"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Rekey.Lifetime, ['days', 'seconds'], name, value)


                            class Retransmit(Entity):
                                """
                                Define the rekey retransmission parameters
                                
                                .. attribute:: seconds
                                
                                	
                                	**type**\: int
                                
                                	**range:** 10..60
                                
                                .. attribute:: number
                                
                                	Retransmit this many times
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: periodic
                                
                                	Periodically send retransmit rekeys
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Rekey.Retransmit, self).__init__()

                                    self.yang_name = "retransmit"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                        ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                                    ])
                                    self.seconds = None
                                    self.number = None
                                    self.periodic = None
                                    self._segment_path = lambda: "retransmit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Rekey.Retransmit, ['seconds', 'number', 'periodic'], name, value)


                            class SigHash(Entity):
                                """
                                Set rekey signature\-hash parameters
                                
                                .. attribute:: algorithm
                                
                                	Set the rekey signature\-hash algorithm
                                	**type**\:  :py:class:`Algorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Rekey.SigHash.Algorithm>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Rekey.SigHash, self).__init__()

                                    self.yang_name = "sig-hash"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('algorithm', (YLeaf(YType.enumeration, 'algorithm'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gkm.Group.Server.Local.Rekey.SigHash.Algorithm')])),
                                    ])
                                    self.algorithm = None
                                    self._segment_path = lambda: "sig-hash"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Rekey.SigHash, ['algorithm'], name, value)

                                class Algorithm(Enum):
                                    """
                                    Algorithm (Enum Class)

                                    Set the rekey signature\-hash algorithm

                                    .. data:: sha = 0

                                    .. data:: sha256 = 1

                                    .. data:: sha384 = 2

                                    .. data:: sha512 = 3

                                    """

                                    sha = Enum.YLeaf(0, "sha")

                                    sha256 = Enum.YLeaf(1, "sha256")

                                    sha384 = Enum.YLeaf(2, "sha384")

                                    sha512 = Enum.YLeaf(3, "sha512")



                            class Transport(Entity):
                                """
                                Specify the rekey distribution method
                                
                                .. attribute:: unicast
                                
                                	specify unicast rekey distribution
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Rekey.Transport, self).__init__()

                                    self.yang_name = "transport"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                    ])
                                    self.unicast = None
                                    self._segment_path = lambda: "transport"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Rekey.Transport, ['unicast'], name, value)


                        class Sa(Entity):
                            """
                            Configure a security association
                            
                            .. attribute:: d3p
                            
                            	Enable IP delivery delay detection protocol for all SAs within the group
                            	**type**\:  :py:class:`D3p <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.D3p>`
                            
                            .. attribute:: ipsec
                            
                            	Configure an IPsec SA
                            	**type**\: list of  		 :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec>`
                            
                            .. attribute:: pair_wise_keying
                            
                            	Enable KGS pair\-wise\-keying
                            	**type**\:  :py:class:`PairWiseKeying <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.PairWiseKeying>`
                            
                            .. attribute:: receive_only
                            
                            	Configure SA to work only in inbound direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Server.Local.Sa, self).__init__()

                                self.yang_name = "sa"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("d3p", ("d3p", Native.Crypto.Gkm.Group.Server.Local.Sa.D3p)), ("ipsec", ("ipsec", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec)), ("pair-wise-keying", ("pair_wise_keying", Native.Crypto.Gkm.Group.Server.Local.Sa.PairWiseKeying))])
                                self._leafs = OrderedDict([
                                    ('receive_only', (YLeaf(YType.empty, 'receive-only'), ['Empty'])),
                                ])
                                self.receive_only = None

                                self.d3p = Native.Crypto.Gkm.Group.Server.Local.Sa.D3p()
                                self.d3p.parent = self
                                self._children_name_map["d3p"] = "d3p"

                                self.pair_wise_keying = Native.Crypto.Gkm.Group.Server.Local.Sa.PairWiseKeying()
                                self.pair_wise_keying.parent = self
                                self._children_name_map["pair_wise_keying"] = "pair-wise-keying"

                                self.ipsec = YList(self)
                                self._segment_path = lambda: "sa"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa, ['receive_only'], name, value)


                            class D3p(Entity):
                                """
                                Enable IP delivery delay detection protocol for all SAs within the group
                                
                                .. attribute:: window
                                
                                	IP\-D3P window size
                                	**type**\:  :py:class:`Window <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.D3p.Window>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Sa.D3p, self).__init__()

                                    self.yang_name = "d3p"
                                    self.yang_parent_name = "sa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("window", ("window", Native.Crypto.Gkm.Group.Server.Local.Sa.D3p.Window))])
                                    self._leafs = OrderedDict()

                                    self.window = Native.Crypto.Gkm.Group.Server.Local.Sa.D3p.Window()
                                    self.window.parent = self
                                    self._children_name_map["window"] = "window"
                                    self._segment_path = lambda: "d3p"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.D3p, [], name, value)


                                class Window(Entity):
                                    """
                                    IP\-D3P window size
                                    
                                    .. attribute:: msec
                                    
                                    	IP\-D3P window size in milliseconds
                                    	**type**\: int
                                    
                                    	**range:** 1000..100000
                                    
                                    .. attribute:: sec
                                    
                                    	IP\-D3P window size in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Sa.D3p.Window, self).__init__()

                                        self.yang_name = "window"
                                        self.yang_parent_name = "d3p"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('msec', (YLeaf(YType.uint32, 'msec'), ['int'])),
                                            ('sec', (YLeaf(YType.uint8, 'sec'), ['int'])),
                                        ])
                                        self.msec = None
                                        self.sec = None
                                        self._segment_path = lambda: "window"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.D3p.Window, ['msec', 'sec'], name, value)


                            class Ipsec(Entity):
                                """
                                Configure an IPsec SA
                                
                                .. attribute:: sequence  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: default
                                
                                	Set a command to its defaults
                                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default>`
                                
                                .. attribute:: match
                                
                                	Match characteristics of packets to encrypt
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Match>`
                                
                                .. attribute:: profile
                                
                                	Configure an ipsec profile for the SA
                                	**type**\: str
                                
                                .. attribute:: replay
                                
                                	Set replay method
                                	**type**\:  :py:class:`Replay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay>`
                                
                                .. attribute:: tag
                                
                                	Set inline tagging method
                                	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Tag>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec, self).__init__()

                                    self.yang_name = "ipsec"
                                    self.yang_parent_name = "sa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['sequence']
                                    self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default)), ("match", ("match", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Match)), ("replay", ("replay", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay)), ("tag", ("tag", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Tag))])
                                    self._leafs = OrderedDict([
                                        ('sequence', (YLeaf(YType.uint16, 'sequence'), ['int'])),
                                        ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                                    ])
                                    self.sequence = None
                                    self.profile = None

                                    self.default = Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.match = Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"

                                    self.replay = Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay()
                                    self.replay.parent = self
                                    self._children_name_map["replay"] = "replay"

                                    self.tag = Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Tag()
                                    self.tag.parent = self
                                    self._children_name_map["tag"] = "tag"
                                    self._segment_path = lambda: "ipsec" + "[sequence='" + str(self.sequence) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec, ['sequence', 'profile'], name, value)


                                class Default(Entity):
                                    """
                                    Set a command to its defaults
                                    
                                    .. attribute:: match
                                    
                                    	Match characteristics of packets to encrypt
                                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Match>`
                                    
                                    .. attribute:: profile
                                    
                                    	Configure an ipsec profile for the SA
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replay
                                    
                                    	Set replay method
                                    	**type**\:  :py:class:`Replay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Replay>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: tag
                                    
                                    	Set inline tagging method
                                    	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Tag>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ipsec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("match", ("match", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Match)), ("replay", ("replay", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Replay)), ("tag", ("tag", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Tag))])
                                        self._leafs = OrderedDict([
                                            ('profile', (YLeaf(YType.empty, 'profile'), ['Empty'])),
                                        ])
                                        self.profile = None

                                        self.match = Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Match()
                                        self.match.parent = self
                                        self._children_name_map["match"] = "match"

                                        self.replay = None
                                        self._children_name_map["replay"] = "replay"

                                        self.tag = None
                                        self._children_name_map["tag"] = "tag"
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default, ['profile'], name, value)


                                    class Match(Entity):
                                        """
                                        Match characteristics of packets to encrypt
                                        
                                        .. attribute:: address
                                        
                                        	Match addresses of packets to encrypt
                                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Match.Address>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Match, self).__init__()

                                            self.yang_name = "match"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Match.Address))])
                                            self._leafs = OrderedDict()

                                            self.address = None
                                            self._children_name_map["address"] = "address"
                                            self._segment_path = lambda: "match"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Match, [], name, value)


                                        class Address(Entity):
                                            """
                                            Match addresses of packets to encrypt
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-crypto'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Match.Address, self).__init__()

                                                self.yang_name = "address"
                                                self.yang_parent_name = "match"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()
                                                self._segment_path = lambda: "address"
                                                self._is_frozen = True


                                    class Replay(Entity):
                                        """
                                        Set replay method
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Replay, self).__init__()

                                            self.yang_name = "replay"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()
                                            self._segment_path = lambda: "replay"
                                            self._is_frozen = True


                                    class Tag(Entity):
                                        """
                                        Set inline tagging method
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Default.Tag, self).__init__()

                                            self.yang_name = "tag"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()
                                            self._segment_path = lambda: "tag"
                                            self._is_frozen = True


                                class Match(Entity):
                                    """
                                    Match characteristics of packets to encrypt
                                    
                                    .. attribute:: address
                                    
                                    	Match addresses of packets to encrypt
                                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Match.Address>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ipsec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Match.Address))])
                                        self._leafs = OrderedDict()

                                        self.address = Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Match.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Match, [], name, value)


                                    class Address(Entity):
                                        """
                                        Match addresses of packets to encrypt
                                        
                                        .. attribute:: ipv4
                                        
                                        	Match ipv4 packets
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 100..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 2000..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        .. attribute:: ipv6
                                        
                                        	Match ipv6 packets
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Match.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['int','int','str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Match.Address, ['ipv4', 'ipv6'], name, value)


                                class Replay(Entity):
                                    """
                                    Set replay method
                                    
                                    .. attribute:: counter
                                    
                                    	Enable anti\-replay check for single source traffic by using sequence number
                                    	**type**\:  :py:class:`Counter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay.Counter>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: time
                                    
                                    	Enable anti\-replay check for any traffic by using time
                                    	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay.Time>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay, self).__init__()

                                        self.yang_name = "replay"
                                        self.yang_parent_name = "ipsec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("counter", ("counter", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay.Counter)), ("time", ("time", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay.Time))])
                                        self._leafs = OrderedDict()

                                        self.counter = None
                                        self._children_name_map["counter"] = "counter"

                                        self.time = None
                                        self._children_name_map["time"] = "time"
                                        self._segment_path = lambda: "replay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay, [], name, value)


                                    class Counter(Entity):
                                        """
                                        Enable anti\-replay check for single source traffic by using sequence number
                                        
                                        .. attribute:: window_size
                                        
                                        	Set replay window size
                                        	**type**\:  :py:class:`WindowSize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay.Counter.WindowSize>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay.Counter, self).__init__()

                                            self.yang_name = "counter"
                                            self.yang_parent_name = "replay"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('window_size', (YLeaf(YType.enumeration, 'window-size'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay.Counter.WindowSize')])),
                                            ])
                                            self.window_size = None
                                            self._segment_path = lambda: "counter"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay.Counter, ['window_size'], name, value)

                                        class WindowSize(Enum):
                                            """
                                            WindowSize (Enum Class)

                                            Set replay window size.

                                            .. data:: Y_1024 = 0

                                            .. data:: Y_128 = 1

                                            .. data:: Y_256 = 2

                                            .. data:: Y_512 = 3

                                            .. data:: Y_64 = 4

                                            """

                                            Y_1024 = Enum.YLeaf(0, "1024")

                                            Y_128 = Enum.YLeaf(1, "128")

                                            Y_256 = Enum.YLeaf(2, "256")

                                            Y_512 = Enum.YLeaf(3, "512")

                                            Y_64 = Enum.YLeaf(4, "64")



                                    class Time(Entity):
                                        """
                                        Enable anti\-replay check for any traffic by using time
                                        
                                        .. attribute:: window_size
                                        
                                        	Time based replay window size
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay.Time, self).__init__()

                                            self.yang_name = "time"
                                            self.yang_parent_name = "replay"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('window_size', (YLeaf(YType.uint8, 'window-size'), ['int'])),
                                            ])
                                            self.window_size = None
                                            self._segment_path = lambda: "time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Replay.Time, ['window_size'], name, value)


                                class Tag(Entity):
                                    """
                                    Set inline tagging method
                                    
                                    .. attribute:: cts
                                    
                                    	Cisco Trust Security
                                    	**type**\:  :py:class:`Cts <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Tag.Cts>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Tag, self).__init__()

                                        self.yang_name = "tag"
                                        self.yang_parent_name = "ipsec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("cts", ("cts", Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Tag.Cts))])
                                        self._leafs = OrderedDict()

                                        self.cts = Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Tag.Cts()
                                        self.cts.parent = self
                                        self._children_name_map["cts"] = "cts"
                                        self._segment_path = lambda: "tag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Tag, [], name, value)


                                    class Cts(Entity):
                                        """
                                        Cisco Trust Security
                                        
                                        .. attribute:: sgt
                                        
                                        	Security Group Tag
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Tag.Cts, self).__init__()

                                            self.yang_name = "cts"
                                            self.yang_parent_name = "tag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ])
                                            self.sgt = None
                                            self._segment_path = lambda: "cts"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.Ipsec.Tag.Cts, ['sgt'], name, value)


                            class PairWiseKeying(Entity):
                                """
                                Enable KGS pair\-wise\-keying
                                
                                .. attribute:: safety_limit
                                
                                	KGS safety limit
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Sa.PairWiseKeying, self).__init__()

                                    self.yang_name = "pair-wise-keying"
                                    self.yang_parent_name = "sa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('safety_limit', (YLeaf(YType.uint8, 'safety-limit'), ['int'])),
                                    ])
                                    self.safety_limit = None
                                    self._segment_path = lambda: "pair-wise-keying"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Sa.PairWiseKeying, ['safety_limit'], name, value)


                        class Default(Entity):
                            """
                            Set a command to its defaults
                            
                            .. attribute:: address
                            
                            	Configure server source address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Address>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: authorization
                            
                            	Configure authorization for the group
                            	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Authorization>`
                            
                            .. attribute:: gdoi
                            
                            	Enable GDOI (ISAKMP) Protocol for Registration & Rekey
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: gikev2
                            
                            	Enable G\-IKEv2 (IKEv2) Protocol for Registration & Rekey
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: group
                            
                            	Configure parameters for the group (e.g. Suite\-B)
                            	**type**\:  :py:class:`Group_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Group_>`
                            
                            .. attribute:: identifier
                            
                            	Enter Suite\-B KSSID (Key Server Sender ID) config mode
                            	**type**\:  :py:class:`Identifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Identifier>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: redundancy
                            
                            	Enter cooperative key server configuration mode
                            	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Redundancy>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: registration
                            
                            	Configure registration for the group
                            	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Registration>`
                            
                            .. attribute:: rekey
                            
                            	Configure rekey policy for the group
                            	**type**\:  :py:class:`Rekey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Rekey>`
                            
                            .. attribute:: sa
                            
                            	Configure a security association
                            	**type**\:  :py:class:`Sa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Sa>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Server.Local.Default, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "local"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Server.Local.Default.Address)), ("authorization", ("authorization", Native.Crypto.Gkm.Group.Server.Local.Default.Authorization)), ("group", ("group", Native.Crypto.Gkm.Group.Server.Local.Default.Group_)), ("identifier", ("identifier", Native.Crypto.Gkm.Group.Server.Local.Default.Identifier)), ("redundancy", ("redundancy", Native.Crypto.Gkm.Group.Server.Local.Default.Redundancy)), ("registration", ("registration", Native.Crypto.Gkm.Group.Server.Local.Default.Registration)), ("rekey", ("rekey", Native.Crypto.Gkm.Group.Server.Local.Default.Rekey)), ("sa", ("sa", Native.Crypto.Gkm.Group.Server.Local.Default.Sa))])
                                self._leafs = OrderedDict([
                                    ('gdoi', (YLeaf(YType.empty, 'gdoi'), ['Empty'])),
                                    ('gikev2', (YLeaf(YType.empty, 'gikev2'), ['Empty'])),
                                ])
                                self.gdoi = None
                                self.gikev2 = None

                                self.address = None
                                self._children_name_map["address"] = "address"

                                self.authorization = Native.Crypto.Gkm.Group.Server.Local.Default.Authorization()
                                self.authorization.parent = self
                                self._children_name_map["authorization"] = "authorization"

                                self.group = Native.Crypto.Gkm.Group.Server.Local.Default.Group_()
                                self.group.parent = self
                                self._children_name_map["group"] = "group"

                                self.identifier = None
                                self._children_name_map["identifier"] = "identifier"

                                self.redundancy = None
                                self._children_name_map["redundancy"] = "redundancy"

                                self.registration = Native.Crypto.Gkm.Group.Server.Local.Default.Registration()
                                self.registration.parent = self
                                self._children_name_map["registration"] = "registration"

                                self.rekey = Native.Crypto.Gkm.Group.Server.Local.Default.Rekey()
                                self.rekey.parent = self
                                self._children_name_map["rekey"] = "rekey"

                                self.sa = Native.Crypto.Gkm.Group.Server.Local.Default.Sa()
                                self.sa.parent = self
                                self._children_name_map["sa"] = "sa"
                                self._segment_path = lambda: "default"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default, ['gdoi', 'gikev2'], name, value)


                            class Address(Entity):
                                """
                                Configure server source address
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Default.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True


                            class Authorization(Entity):
                                """
                                Configure authorization for the group
                                
                                .. attribute:: address
                                
                                	Set authorization by address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Authorization.Address>`
                                
                                .. attribute:: identity
                                
                                	Set authorization by identity
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Default.Authorization, self).__init__()

                                    self.yang_name = "authorization"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Server.Local.Default.Authorization.Address))])
                                    self._leafs = OrderedDict([
                                        ('identity', (YLeaf(YType.empty, 'identity'), ['Empty'])),
                                    ])
                                    self.identity = None

                                    self.address = Native.Crypto.Gkm.Group.Server.Local.Default.Authorization.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "authorization"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Authorization, ['identity'], name, value)


                                class Address(Entity):
                                    """
                                    Set authorization by address
                                    
                                    .. attribute:: ipv4
                                    
                                    	Set authorization by address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Authorization.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "authorization"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                        ])
                                        self.ipv4 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Authorization.Address, ['ipv4'], name, value)


                            class Group_(Entity):
                                """
                                Configure parameters for the group (e.g. Suite\-B)
                                
                                .. attribute:: size
                                
                                	Set Group Size for Suite\-B counter transforms (SID length)
                                	**type**\:  :py:class:`Size <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Group_.Size>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Default.Group_, self).__init__()

                                    self.yang_name = "group"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("size", ("size", Native.Crypto.Gkm.Group.Server.Local.Default.Group_.Size))])
                                    self._leafs = OrderedDict()

                                    self.size = None
                                    self._children_name_map["size"] = "size"
                                    self._segment_path = lambda: "group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Group_, [], name, value)


                                class Size(Entity):
                                    """
                                    Set Group Size for Suite\-B counter transforms (SID length)
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Group_.Size, self).__init__()

                                        self.yang_name = "size"
                                        self.yang_parent_name = "group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "size"
                                        self._is_frozen = True


                            class Identifier(Entity):
                                """
                                Enter Suite\-B KSSID (Key Server Sender ID) config mode
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Default.Identifier, self).__init__()

                                    self.yang_name = "identifier"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "identifier"
                                    self._is_frozen = True


                            class Redundancy(Entity):
                                """
                                Enter cooperative key server configuration mode
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Default.Redundancy, self).__init__()

                                    self.yang_name = "redundancy"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "redundancy"
                                    self._is_frozen = True


                            class Registration(Entity):
                                """
                                Configure registration for the group
                                
                                .. attribute:: interface
                                
                                	Identify an interface on which to respond to GKM registrations
                                	**type**\: str
                                
                                .. attribute:: periodic
                                
                                	Define periodic registrations for the group
                                	**type**\:  :py:class:`Periodic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Registration.Periodic>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Default.Registration, self).__init__()

                                    self.yang_name = "registration"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("periodic", ("periodic", Native.Crypto.Gkm.Group.Server.Local.Default.Registration.Periodic))])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ])
                                    self.interface = None

                                    self.periodic = Native.Crypto.Gkm.Group.Server.Local.Default.Registration.Periodic()
                                    self.periodic.parent = self
                                    self._children_name_map["periodic"] = "periodic"
                                    self._segment_path = lambda: "registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Registration, ['interface'], name, value)


                                class Periodic(Entity):
                                    """
                                    Define periodic registrations for the group
                                    
                                    .. attribute:: crl
                                    
                                    	On every new CRL
                                    	**type**\:  :py:class:`Crl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Registration.Periodic.Crl>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Registration.Periodic, self).__init__()

                                        self.yang_name = "periodic"
                                        self.yang_parent_name = "registration"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("crl", ("crl", Native.Crypto.Gkm.Group.Server.Local.Default.Registration.Periodic.Crl))])
                                        self._leafs = OrderedDict()

                                        self.crl = Native.Crypto.Gkm.Group.Server.Local.Default.Registration.Periodic.Crl()
                                        self.crl.parent = self
                                        self._children_name_map["crl"] = "crl"
                                        self._segment_path = lambda: "periodic"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Registration.Periodic, [], name, value)


                                    class Crl(Entity):
                                        """
                                        On every new CRL
                                        
                                        .. attribute:: trustpoint
                                        
                                        	For a PKI trustpoint
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-crypto'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Crypto.Gkm.Group.Server.Local.Default.Registration.Periodic.Crl, self).__init__()

                                            self.yang_name = "crl"
                                            self.yang_parent_name = "periodic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('trustpoint', (YLeaf(YType.empty, 'trustpoint'), ['Empty'])),
                                            ])
                                            self.trustpoint = None
                                            self._segment_path = lambda: "crl"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Registration.Periodic.Crl, ['trustpoint'], name, value)


                            class Rekey(Entity):
                                """
                                Configure rekey policy for the group
                                
                                .. attribute:: acknowledgement
                                
                                	Request group members to acknowledge rekeys
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: address
                                
                                	Define the rekey packet format
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Address>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: algorithm
                                
                                	Set the rekey encryption algorithm
                                	**type**\:  :py:class:`Algorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Algorithm>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: authentication
                                
                                	Identify the rekey authentication keypair
                                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Authentication>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: lifetime
                                
                                	Define the rekey lifetime
                                	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Lifetime>`
                                
                                .. attribute:: retransmit
                                
                                	Define the rekey retransmission parameters
                                	**type**\:  :py:class:`Retransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Retransmit>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: sig_hash
                                
                                	Set rekey signature\-hash parameters
                                	**type**\:  :py:class:`SigHash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.SigHash>`
                                
                                .. attribute:: transport
                                
                                	Specify the rekey distribution method
                                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Transport>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey, self).__init__()

                                    self.yang_name = "rekey"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Address)), ("algorithm", ("algorithm", Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Algorithm)), ("authentication", ("authentication", Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Authentication)), ("lifetime", ("lifetime", Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Lifetime)), ("retransmit", ("retransmit", Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Retransmit)), ("sig-hash", ("sig_hash", Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.SigHash)), ("transport", ("transport", Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Transport))])
                                    self._leafs = OrderedDict([
                                        ('acknowledgement', (YLeaf(YType.empty, 'acknowledgement'), ['Empty'])),
                                    ])
                                    self.acknowledgement = None

                                    self.address = None
                                    self._children_name_map["address"] = "address"

                                    self.algorithm = None
                                    self._children_name_map["algorithm"] = "algorithm"

                                    self.authentication = None
                                    self._children_name_map["authentication"] = "authentication"

                                    self.lifetime = Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Lifetime()
                                    self.lifetime.parent = self
                                    self._children_name_map["lifetime"] = "lifetime"

                                    self.retransmit = None
                                    self._children_name_map["retransmit"] = "retransmit"

                                    self.sig_hash = Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.SigHash()
                                    self.sig_hash.parent = self
                                    self._children_name_map["sig_hash"] = "sig-hash"

                                    self.transport = Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Transport()
                                    self.transport.parent = self
                                    self._children_name_map["transport"] = "transport"
                                    self._segment_path = lambda: "rekey"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey, ['acknowledgement'], name, value)


                                class Address(Entity):
                                    """
                                    Define the rekey packet format
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True


                                class Algorithm(Entity):
                                    """
                                    Set the rekey encryption algorithm
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Algorithm, self).__init__()

                                        self.yang_name = "algorithm"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "algorithm"
                                        self._is_frozen = True


                                class Authentication(Entity):
                                    """
                                    Identify the rekey authentication keypair
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "authentication"
                                        self._is_frozen = True


                                class Lifetime(Entity):
                                    """
                                    Define the rekey lifetime
                                    
                                    .. attribute:: days
                                    
                                    	Time\-based key duration in days
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: seconds
                                    
                                    	Time\-based key duration in seconds
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Lifetime, self).__init__()

                                        self.yang_name = "lifetime"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('days', (YLeaf(YType.empty, 'days'), ['Empty'])),
                                            ('seconds', (YLeaf(YType.empty, 'seconds'), ['Empty'])),
                                        ])
                                        self.days = None
                                        self.seconds = None
                                        self._segment_path = lambda: "lifetime"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Lifetime, ['days', 'seconds'], name, value)


                                class Retransmit(Entity):
                                    """
                                    Define the rekey retransmission parameters
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Retransmit, self).__init__()

                                        self.yang_name = "retransmit"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "retransmit"
                                        self._is_frozen = True


                                class SigHash(Entity):
                                    """
                                    Set rekey signature\-hash parameters
                                    
                                    .. attribute:: algorithm
                                    
                                    	Set the rekey signature\-hash algorithm
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.SigHash, self).__init__()

                                        self.yang_name = "sig-hash"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('algorithm', (YLeaf(YType.empty, 'algorithm'), ['Empty'])),
                                        ])
                                        self.algorithm = None
                                        self._segment_path = lambda: "sig-hash"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.SigHash, ['algorithm'], name, value)


                                class Transport(Entity):
                                    """
                                    Specify the rekey distribution method
                                    
                                    .. attribute:: unicast
                                    
                                    	specify unicast rekey distribution
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Transport, self).__init__()

                                        self.yang_name = "transport"
                                        self.yang_parent_name = "rekey"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                        ])
                                        self.unicast = None
                                        self._segment_path = lambda: "transport"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Rekey.Transport, ['unicast'], name, value)


                            class Sa(Entity):
                                """
                                Configure a security association
                                
                                .. attribute:: d3p
                                
                                	Enable IP delivery delay detection protocol for all SAs within the group
                                	**type**\:  :py:class:`D3p <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Sa.D3p>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ipsec
                                
                                	Configure an IPsec SA
                                	**type**\: list of  		 :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Sa.Ipsec>`
                                
                                .. attribute:: pair_wise_keying
                                
                                	Enable KGS pair\-wise\-keying
                                	**type**\:  :py:class:`PairWiseKeying <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Server.Local.Default.Sa.PairWiseKeying>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: receive_only
                                
                                	Configure SA to work only in inbound direction
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Server.Local.Default.Sa, self).__init__()

                                    self.yang_name = "sa"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("d3p", ("d3p", Native.Crypto.Gkm.Group.Server.Local.Default.Sa.D3p)), ("ipsec", ("ipsec", Native.Crypto.Gkm.Group.Server.Local.Default.Sa.Ipsec)), ("pair-wise-keying", ("pair_wise_keying", Native.Crypto.Gkm.Group.Server.Local.Default.Sa.PairWiseKeying))])
                                    self._leafs = OrderedDict([
                                        ('receive_only', (YLeaf(YType.empty, 'receive-only'), ['Empty'])),
                                    ])
                                    self.receive_only = None

                                    self.d3p = None
                                    self._children_name_map["d3p"] = "d3p"

                                    self.pair_wise_keying = None
                                    self._children_name_map["pair_wise_keying"] = "pair-wise-keying"

                                    self.ipsec = YList(self)
                                    self._segment_path = lambda: "sa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Sa, ['receive_only'], name, value)


                                class D3p(Entity):
                                    """
                                    Enable IP delivery delay detection protocol for all SAs within the group
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Sa.D3p, self).__init__()

                                        self.yang_name = "d3p"
                                        self.yang_parent_name = "sa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "d3p"
                                        self._is_frozen = True


                                class Ipsec(Entity):
                                    """
                                    Configure an IPsec SA
                                    
                                    .. attribute:: sequence  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Sa.Ipsec, self).__init__()

                                        self.yang_name = "ipsec"
                                        self.yang_parent_name = "sa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['sequence']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence', (YLeaf(YType.uint16, 'sequence'), ['int'])),
                                        ])
                                        self.sequence = None
                                        self._segment_path = lambda: "ipsec" + "[sequence='" + str(self.sequence) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Gkm.Group.Server.Local.Default.Sa.Ipsec, ['sequence'], name, value)


                                class PairWiseKeying(Entity):
                                    """
                                    Enable KGS pair\-wise\-keying
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Gkm.Group.Server.Local.Default.Sa.PairWiseKeying, self).__init__()

                                        self.yang_name = "pair-wise-keying"
                                        self.yang_parent_name = "sa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "pair-wise-keying"
                                        self._is_frozen = True


                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: client
                    
                    	Set the group client parameters
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Client>`
                    
                    .. attribute:: identity
                    
                    	Set the identity of the group
                    	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Identity>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: passive
                    
                    	Set the group in passive mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: server
                    
                    	Set the group server for of the group
                    	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Server>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Gkm.Group.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("client", ("client", Native.Crypto.Gkm.Group.Default.Client)), ("identity", ("identity", Native.Crypto.Gkm.Group.Default.Identity)), ("server", ("server", Native.Crypto.Gkm.Group.Default.Server))])
                        self._leafs = OrderedDict([
                            ('passive', (YLeaf(YType.empty, 'passive'), ['Empty'])),
                        ])
                        self.passive = None

                        self.client = Native.Crypto.Gkm.Group.Default.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "client"

                        self.identity = None
                        self._children_name_map["identity"] = "identity"

                        self.server = Native.Crypto.Gkm.Group.Default.Server()
                        self.server.parent = self
                        self._children_name_map["server"] = "server"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Gkm.Group.Default, ['passive'], name, value)


                    class Client(Entity):
                        """
                        Set the group client parameters
                        
                        .. attribute:: bypass_policy
                        
                        	Allow group\-key management traffic sent to this GM only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: protocol
                        
                        	Group Member Registration & Rekey Protocol
                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Client.Protocol>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: recovery_check
                        
                        	Specify GM recovery check parameters
                        	**type**\:  :py:class:`RecoveryCheck <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Client.RecoveryCheck>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: registration
                        
                        	Set the group client management/register interface
                        	**type**\:  :py:class:`Registration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Client.Registration>`
                        
                        .. attribute:: rekey
                        
                        	Set the group client acceptable rekey ciphers and hashs
                        	**type**\:  :py:class:`Rekey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Client.Rekey>`
                        
                        .. attribute:: status
                        
                        	group\-member status
                        	**type**\:  :py:class:`Status <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Client.Status>`
                        
                        .. attribute:: transform_sets
                        
                        	Specify list of group client acceptable transform sets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: transport_encrypt_key
                        
                        	Enforce group or pair\-wise keying
                        	**type**\:  :py:class:`TransportEncryptKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Client.TransportEncryptKey>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Default.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol", ("protocol", Native.Crypto.Gkm.Group.Default.Client.Protocol)), ("recovery-check", ("recovery_check", Native.Crypto.Gkm.Group.Default.Client.RecoveryCheck)), ("registration", ("registration", Native.Crypto.Gkm.Group.Default.Client.Registration)), ("rekey", ("rekey", Native.Crypto.Gkm.Group.Default.Client.Rekey)), ("status", ("status", Native.Crypto.Gkm.Group.Default.Client.Status))])
                            self._leafs = OrderedDict([
                                ('bypass_policy', (YLeaf(YType.empty, 'bypass-policy'), ['Empty'])),
                                ('transform_sets', (YLeaf(YType.empty, 'transform-sets'), ['Empty'])),
                                ('transport_encrypt_key', (YLeaf(YType.enumeration, 'transport-encrypt-key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Gkm.Group.Default.Client.TransportEncryptKey')])),
                            ])
                            self.bypass_policy = None
                            self.transform_sets = None
                            self.transport_encrypt_key = None

                            self.protocol = None
                            self._children_name_map["protocol"] = "protocol"

                            self.recovery_check = None
                            self._children_name_map["recovery_check"] = "recovery-check"

                            self.registration = Native.Crypto.Gkm.Group.Default.Client.Registration()
                            self.registration.parent = self
                            self._children_name_map["registration"] = "registration"

                            self.rekey = Native.Crypto.Gkm.Group.Default.Client.Rekey()
                            self.rekey.parent = self
                            self._children_name_map["rekey"] = "rekey"

                            self.status = Native.Crypto.Gkm.Group.Default.Client.Status()
                            self.status.parent = self
                            self._children_name_map["status"] = "status"
                            self._segment_path = lambda: "client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gkm.Group.Default.Client, ['bypass_policy', 'transform_sets', 'transport_encrypt_key'], name, value)

                        class TransportEncryptKey(Enum):
                            """
                            TransportEncryptKey (Enum Class)

                            Enforce group or pair\-wise keying

                            .. data:: group_key = 0

                            .. data:: pair_wise_key = 1

                            """

                            group_key = Enum.YLeaf(0, "group-key")

                            pair_wise_key = Enum.YLeaf(1, "pair-wise-key")



                        class Protocol(Entity):
                            """
                            Group Member Registration & Rekey Protocol
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Default.Client.Protocol, self).__init__()

                                self.yang_name = "protocol"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "protocol"
                                self._is_frozen = True


                        class RecoveryCheck(Entity):
                            """
                            Specify GM recovery check parameters
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Default.Client.RecoveryCheck, self).__init__()

                                self.yang_name = "recovery-check"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "recovery-check"
                                self._is_frozen = True


                        class Registration(Entity):
                            """
                            Set the group client management/register interface
                            
                            .. attribute:: interface
                            
                            	Set the group client management/register interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Default.Client.Registration, self).__init__()

                                self.yang_name = "registration"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                                ])
                                self.interface = None
                                self._segment_path = lambda: "registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Default.Client.Registration, ['interface'], name, value)


                        class Rekey(Entity):
                            """
                            Set the group client acceptable rekey ciphers and hashs
                            
                            .. attribute:: encryption
                            
                            	Set the group client acceptable rekey ciphers
                            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Client.Rekey.Encryption>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: hash
                            
                            	Set the group client acceptable rekey hash
                            	**type**\:  :py:class:`Hash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Client.Rekey.Hash>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Default.Client.Rekey, self).__init__()

                                self.yang_name = "rekey"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("encryption", ("encryption", Native.Crypto.Gkm.Group.Default.Client.Rekey.Encryption)), ("hash", ("hash", Native.Crypto.Gkm.Group.Default.Client.Rekey.Hash))])
                                self._leafs = OrderedDict()

                                self.encryption = None
                                self._children_name_map["encryption"] = "encryption"

                                self.hash = None
                                self._children_name_map["hash"] = "hash"
                                self._segment_path = lambda: "rekey"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Default.Client.Rekey, [], name, value)


                            class Encryption(Entity):
                                """
                                Set the group client acceptable rekey ciphers
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Default.Client.Rekey.Encryption, self).__init__()

                                    self.yang_name = "encryption"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "encryption"
                                    self._is_frozen = True


                            class Hash(Entity):
                                """
                                Set the group client acceptable rekey hash
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Default.Client.Rekey.Hash, self).__init__()

                                    self.yang_name = "hash"
                                    self.yang_parent_name = "rekey"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "hash"
                                    self._is_frozen = True


                        class Status(Entity):
                            """
                            group\-member status
                            
                            .. attribute:: active_sa
                            
                            	TEK SA with positive remaining lifetime
                            	**type**\:  :py:class:`ActiveSa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Client.Status.ActiveSa>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Default.Client.Status, self).__init__()

                                self.yang_name = "status"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("active-sa", ("active_sa", Native.Crypto.Gkm.Group.Default.Client.Status.ActiveSa))])
                                self._leafs = OrderedDict()

                                self.active_sa = None
                                self._children_name_map["active_sa"] = "active-sa"
                                self._segment_path = lambda: "status"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Default.Client.Status, [], name, value)


                            class ActiveSa(Entity):
                                """
                                TEK SA with positive remaining lifetime
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Gkm.Group.Default.Client.Status.ActiveSa, self).__init__()

                                    self.yang_name = "active-sa"
                                    self.yang_parent_name = "status"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "active-sa"
                                    self._is_frozen = True


                    class Identity(Entity):
                        """
                        Set the identity of the group
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Default.Identity, self).__init__()

                            self.yang_name = "identity"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "identity"
                            self._is_frozen = True


                    class Server(Entity):
                        """
                        Set the group server for of the group
                        
                        .. attribute:: address
                        
                        	Identify the group server by address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Server.Address>`
                        
                        .. attribute:: hostname
                        
                        	Identify the group server by hostname
                        	**type**\:  :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Gkm.Group.Default.Server.Hostname>`
                        
                        .. attribute:: local
                        
                        	Configure GKM group server defined locally
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Gkm.Group.Default.Server, self).__init__()

                            self.yang_name = "server"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Gkm.Group.Default.Server.Address)), ("hostname", ("hostname", Native.Crypto.Gkm.Group.Default.Server.Hostname))])
                            self._leafs = OrderedDict([
                                ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                            ])
                            self.local = None

                            self.address = Native.Crypto.Gkm.Group.Default.Server.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"

                            self.hostname = Native.Crypto.Gkm.Group.Default.Server.Hostname()
                            self.hostname.parent = self
                            self._children_name_map["hostname"] = "hostname"
                            self._segment_path = lambda: "server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Gkm.Group.Default.Server, ['local'], name, value)


                        class Address(Entity):
                            """
                            Identify the group server by address
                            
                            .. attribute:: ipv4
                            
                            	Set the IPv4 address of the group server
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Default.Server.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ])
                                self.ipv4 = None
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Default.Server.Address, ['ipv4'], name, value)


                        class Hostname(Entity):
                            """
                            Identify the group server by hostname
                            
                            .. attribute:: ipv4
                            
                            	Set the IPv4 hostname of the group server
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Gkm.Group.Default.Server.Hostname, self).__init__()

                                self.yang_name = "hostname"
                                self.yang_parent_name = "server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ])
                                self.ipv4 = None
                                self._segment_path = lambda: "hostname"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Gkm.Group.Default.Server.Hostname, ['ipv4'], name, value)


        class Identity(Entity):
            """
            Enter a crypto identity list
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: default
            
            	Set a command to its defaults
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Identity.Default>`
            
            .. attribute:: description
            
            	Description of the crypto identity
            	**type**\: str
            
            .. attribute:: dn
            
            	Distinguished name identifier
            	**type**\: str
            
            .. attribute:: fqdn
            
            	Fully qualified distinguished name identifier
            	**type**\: str
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Identity, self).__init__()

                self.yang_name = "identity"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Identity.Default))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('dn', (YLeaf(YType.str, 'dn'), ['str'])),
                    ('fqdn', (YLeaf(YType.str, 'fqdn'), ['str'])),
                ])
                self.name = None
                self.description = None
                self.dn = None
                self.fqdn = None

                self.default = Native.Crypto.Identity.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:identity" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Identity, ['name', 'description', 'dn', 'fqdn'], name, value)


            class Default(Entity):
                """
                Set a command to its defaults
                
                .. attribute:: description
                
                	Description of the crypto identity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dn
                
                	Distinguished name identifier
                	**type**\: str
                
                .. attribute:: fqdn
                
                	Fully qualified distinguished name identifier
                	**type**\: str
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Identity.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "identity"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.empty, 'description'), ['Empty'])),
                        ('dn', (YLeaf(YType.str, 'dn'), ['str'])),
                        ('fqdn', (YLeaf(YType.str, 'fqdn'), ['str'])),
                    ])
                    self.description = None
                    self.dn = None
                    self.fqdn = None
                    self._segment_path = lambda: "default"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Identity.Default, ['description', 'dn', 'fqdn'], name, value)


        class Ipsec(Entity):
            """
            Configure IPSEC policy
            
            .. attribute:: df_bit
            
            	Handling of encapsulated DF bit
            	**type**\:  :py:class:`DfBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.DfBit>`
            
            .. attribute:: fragmentation
            
            	Handling of fragmentation of near\-MTU sized packets
            	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Fragmentation>`
            
            .. attribute:: ipv4_deny
            
            	Configure global ipv4 deny policy
            	**type**\:  :py:class:`Ipv4Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Ipv4Deny>`
            
            .. attribute:: nat_transparency
            
            	IPsec NAT transparency model
            	**type**\:  :py:class:`NatTransparency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.NatTransparency>`
            
            .. attribute:: optional
            
            	Enable optional encryption for IPSec
            	**type**\:  :py:class:`Optional <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Optional>`
            
            	**presence node**\: True
            
            .. attribute:: profile
            
            	Configure an ipsec policy profile
            	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile>`
            
            .. attribute:: security_association
            
            	Security association parameters
            	**type**\:  :py:class:`SecurityAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.SecurityAssociation>`
            
            .. attribute:: transform_set
            
            	Define transform and settings
            	**type**\: list of  		 :py:class:`TransformSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.TransformSet>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Ipsec, self).__init__()

                self.yang_name = "ipsec"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("optional", ("optional", Native.Crypto.Ipsec.Optional)), ("profile", ("profile", Native.Crypto.Ipsec.Profile)), ("security-association", ("security_association", Native.Crypto.Ipsec.SecurityAssociation)), ("transform-set", ("transform_set", Native.Crypto.Ipsec.TransformSet))])
                self._leafs = OrderedDict([
                    ('df_bit', (YLeaf(YType.enumeration, 'df-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.DfBit')])),
                    ('fragmentation', (YLeaf(YType.enumeration, 'fragmentation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.Fragmentation')])),
                    ('ipv4_deny', (YLeaf(YType.enumeration, 'ipv4-deny'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.Ipv4Deny')])),
                    ('nat_transparency', (YLeaf(YType.enumeration, 'nat-transparency'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.NatTransparency')])),
                ])
                self.df_bit = None
                self.fragmentation = None
                self.ipv4_deny = None
                self.nat_transparency = None

                self.optional = None
                self._children_name_map["optional"] = "optional"

                self.security_association = Native.Crypto.Ipsec.SecurityAssociation()
                self.security_association.parent = self
                self._children_name_map["security_association"] = "security-association"

                self.profile = YList(self)
                self.transform_set = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:ipsec"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Ipsec, ['df_bit', 'fragmentation', 'ipv4_deny', 'nat_transparency'], name, value)

            class DfBit(Enum):
                """
                DfBit (Enum Class)

                Handling of encapsulated DF bit.

                .. data:: clear = 0

                .. data:: copy = 1

                .. data:: set = 2

                """

                clear = Enum.YLeaf(0, "clear")

                copy = Enum.YLeaf(1, "copy")

                set = Enum.YLeaf(2, "set")


            class Fragmentation(Enum):
                """
                Fragmentation (Enum Class)

                Handling of fragmentation of near\-MTU sized packets

                .. data:: after_encryption = 0

                .. data:: before_encryption = 1

                """

                after_encryption = Enum.YLeaf(0, "after-encryption")

                before_encryption = Enum.YLeaf(1, "before-encryption")


            class Ipv4Deny(Enum):
                """
                Ipv4Deny (Enum Class)

                Configure global ipv4 deny policy.

                .. data:: clear = 0

                .. data:: drop = 1

                .. data:: jump = 2

                """

                clear = Enum.YLeaf(0, "clear")

                drop = Enum.YLeaf(1, "drop")

                jump = Enum.YLeaf(2, "jump")


            class NatTransparency(Enum):
                """
                NatTransparency (Enum Class)

                IPsec NAT transparency model

                .. data:: spi_matching = 0

                .. data:: udp_encapsulation = 1

                """

                spi_matching = Enum.YLeaf(0, "spi-matching")

                udp_encapsulation = Enum.YLeaf(1, "udp-encapsulation")



            class Optional(Entity):
                """
                Enable optional encryption for IPSec
                
                .. attribute:: retry
                
                	Configure length of IPSec retry interval
                	**type**\: int
                
                	**range:** 60..86400
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ipsec.Optional, self).__init__()

                    self.yang_name = "optional"
                    self.yang_parent_name = "ipsec"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('retry', (YLeaf(YType.uint32, 'retry'), ['int'])),
                    ])
                    self.retry = None
                    self._segment_path = lambda: "optional"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ipsec/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ipsec.Optional, ['retry'], name, value)


            class Profile(Entity):
                """
                Configure an ipsec policy profile
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default>`
                
                .. attribute:: description
                
                	Description of the crypto map statement policy
                	**type**\: str
                
                .. attribute:: dialer
                
                	Dialer related commands
                	**type**\:  :py:class:`Dialer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Dialer>`
                
                .. attribute:: redundancy
                
                	Configure HA for this ipsec profile
                	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Redundancy>`
                
                .. attribute:: responder_only
                
                	Do not initiate SAs from this device
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set
                
                	Set values for encryption/decryption
                	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ipsec.Profile, self).__init__()

                    self.yang_name = "profile"
                    self.yang_parent_name = "ipsec"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Ipsec.Profile.Default)), ("dialer", ("dialer", Native.Crypto.Ipsec.Profile.Dialer)), ("redundancy", ("redundancy", Native.Crypto.Ipsec.Profile.Redundancy)), ("set", ("set", Native.Crypto.Ipsec.Profile.Set))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('responder_only', (YLeaf(YType.empty, 'responder-only'), ['Empty'])),
                    ])
                    self.name = None
                    self.description = None
                    self.responder_only = None

                    self.default = Native.Crypto.Ipsec.Profile.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.dialer = Native.Crypto.Ipsec.Profile.Dialer()
                    self.dialer.parent = self
                    self._children_name_map["dialer"] = "dialer"

                    self.redundancy = Native.Crypto.Ipsec.Profile.Redundancy()
                    self.redundancy.parent = self
                    self._children_name_map["redundancy"] = "redundancy"

                    self.set = Native.Crypto.Ipsec.Profile.Set()
                    self.set.parent = self
                    self._children_name_map["set"] = "set"
                    self._segment_path = lambda: "profile" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ipsec/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ipsec.Profile, ['name', 'description', 'responder_only'], name, value)


                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: description
                    
                    	Description of the crypto map statement policy
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dialer
                    
                    	Dialer related commands
                    	**type**\:  :py:class:`Dialer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default.Dialer>`
                    
                    .. attribute:: redundancy
                    
                    	Configure HA for this ipsec profile
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: responder_only
                    
                    	Do not initiate SAs from this device
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: set
                    
                    	Set values for encryption/decryption
                    	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default.Set>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ipsec.Profile.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dialer", ("dialer", Native.Crypto.Ipsec.Profile.Default.Dialer)), ("set", ("set", Native.Crypto.Ipsec.Profile.Default.Set))])
                        self._leafs = OrderedDict([
                            ('description', (YLeaf(YType.empty, 'description'), ['Empty'])),
                            ('redundancy', (YLeaf(YType.empty, 'redundancy'), ['Empty'])),
                            ('responder_only', (YLeaf(YType.empty, 'responder-only'), ['Empty'])),
                        ])
                        self.description = None
                        self.redundancy = None
                        self.responder_only = None

                        self.dialer = Native.Crypto.Ipsec.Profile.Default.Dialer()
                        self.dialer.parent = self
                        self._children_name_map["dialer"] = "dialer"

                        self.set = Native.Crypto.Ipsec.Profile.Default.Set()
                        self.set.parent = self
                        self._children_name_map["set"] = "set"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ipsec.Profile.Default, ['description', 'redundancy', 'responder_only'], name, value)


                    class Dialer(Entity):
                        """
                        Dialer related commands
                        
                        .. attribute:: pre_classify
                        
                        	Enable dialer list classification before initiating IKE
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ipsec.Profile.Default.Dialer, self).__init__()

                            self.yang_name = "dialer"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('pre_classify', (YLeaf(YType.empty, 'pre-classify'), ['Empty'])),
                            ])
                            self.pre_classify = None
                            self._segment_path = lambda: "dialer"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ipsec.Profile.Default.Dialer, ['pre_classify'], name, value)


                    class Set(Entity):
                        """
                        Set values for encryption/decryption
                        
                        .. attribute:: group
                        
                        	Set the san group parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: identity
                        
                        	Identity restriction
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ikev2_profile
                        
                        	Specify ikev2 Profile
                        	**type**\: str
                        
                        .. attribute:: isakmp_profile
                        
                        	Specify isakmp Profile
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mixed_mode
                        
                        	Turn on IPSec mixed\-mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pfs
                        
                        	Specify pfs settings
                        	**type**\:  :py:class:`Pfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default.Set.Pfs>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: reverse_route
                        
                        	Reverse Route Injection
                        	**type**\:  :py:class:`ReverseRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default.Set.ReverseRoute>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: security_association
                        
                        	Security association parameters
                        	**type**\:  :py:class:`SecurityAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation>`
                        
                        .. attribute:: security_policy
                        
                        	Maximum number of Security Policy entries that can be negotiated with the peer
                        	**type**\:  :py:class:`SecurityPolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default.Set.SecurityPolicy>`
                        
                        .. attribute:: transform_set
                        
                        	Specify list of transform sets in priority order
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ipsec.Profile.Default.Set, self).__init__()

                            self.yang_name = "set"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pfs", ("pfs", Native.Crypto.Ipsec.Profile.Default.Set.Pfs)), ("reverse-route", ("reverse_route", Native.Crypto.Ipsec.Profile.Default.Set.ReverseRoute)), ("security-association", ("security_association", Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation)), ("security-policy", ("security_policy", Native.Crypto.Ipsec.Profile.Default.Set.SecurityPolicy))])
                            self._leafs = OrderedDict([
                                ('group', (YLeaf(YType.empty, 'group'), ['Empty'])),
                                ('identity', (YLeaf(YType.empty, 'identity'), ['Empty'])),
                                ('ikev2_profile', (YLeaf(YType.str, 'ikev2-profile'), ['str'])),
                                ('isakmp_profile', (YLeaf(YType.empty, 'isakmp-profile'), ['Empty'])),
                                ('mixed_mode', (YLeaf(YType.empty, 'mixed-mode'), ['Empty'])),
                                ('transform_set', (YLeaf(YType.empty, 'transform-set'), ['Empty'])),
                            ])
                            self.group = None
                            self.identity = None
                            self.ikev2_profile = None
                            self.isakmp_profile = None
                            self.mixed_mode = None
                            self.transform_set = None

                            self.pfs = None
                            self._children_name_map["pfs"] = "pfs"

                            self.reverse_route = None
                            self._children_name_map["reverse_route"] = "reverse-route"

                            self.security_association = Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation()
                            self.security_association.parent = self
                            self._children_name_map["security_association"] = "security-association"

                            self.security_policy = Native.Crypto.Ipsec.Profile.Default.Set.SecurityPolicy()
                            self.security_policy.parent = self
                            self._children_name_map["security_policy"] = "security-policy"
                            self._segment_path = lambda: "set"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ipsec.Profile.Default.Set, ['group', 'identity', 'ikev2_profile', 'isakmp_profile', 'mixed_mode', 'transform_set'], name, value)


                        class Pfs(Entity):
                            """
                            Specify pfs settings
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ipsec.Profile.Default.Set.Pfs, self).__init__()

                                self.yang_name = "pfs"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "pfs"
                                self._is_frozen = True


                        class ReverseRoute(Entity):
                            """
                            Reverse Route Injection
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ipsec.Profile.Default.Set.ReverseRoute, self).__init__()

                                self.yang_name = "reverse-route"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-route"
                                self._is_frozen = True


                        class SecurityAssociation(Entity):
                            """
                            Security association parameters
                            
                            .. attribute:: dfbit
                            
                            	Handling of encapsulated DF bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dummy
                            
                            	Enable transmitting dummy packets
                            	**type**\:  :py:class:`Dummy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Dummy>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ecn
                            
                            	Handling of ECN bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: idle_time_container
                            
                            	
                            	**type**\:  :py:class:`IdleTimeContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.IdleTimeContainer>`
                            
                            .. attribute:: level
                            
                            	specify a security association granularity level for identities
                            	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Level>`
                            
                            .. attribute:: lifetime
                            
                            	security association lifetime
                            	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Lifetime>`
                            
                            .. attribute:: replay
                            
                            	Set replay checking
                            	**type**\:  :py:class:`Replay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Replay>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation, self).__init__()

                                self.yang_name = "security-association"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dummy", ("dummy", Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Dummy)), ("idle-time-container", ("idle_time_container", Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.IdleTimeContainer)), ("lifetime", ("lifetime", Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Lifetime)), ("replay", ("replay", Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Replay))])
                                self._leafs = OrderedDict([
                                    ('dfbit', (YLeaf(YType.empty, 'dfbit'), ['Empty'])),
                                    ('ecn', (YLeaf(YType.empty, 'ecn'), ['Empty'])),
                                    ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Level')])),
                                ])
                                self.dfbit = None
                                self.ecn = None
                                self.level = None

                                self.dummy = None
                                self._children_name_map["dummy"] = "dummy"

                                self.idle_time_container = Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.IdleTimeContainer()
                                self.idle_time_container.parent = self
                                self._children_name_map["idle_time_container"] = "idle-time-container"

                                self.lifetime = Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Lifetime()
                                self.lifetime.parent = self
                                self._children_name_map["lifetime"] = "lifetime"

                                self.replay = Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Replay()
                                self.replay.parent = self
                                self._children_name_map["replay"] = "replay"
                                self._segment_path = lambda: "security-association"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation, ['dfbit', 'ecn', 'level'], name, value)

                            class Level(Enum):
                                """
                                Level (Enum Class)

                                specify a security association granularity level for identities

                                .. data:: per_host = 0

                                """

                                per_host = Enum.YLeaf(0, "per-host")



                            class Dummy(Entity):
                                """
                                Enable transmitting dummy packets
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Dummy, self).__init__()

                                    self.yang_name = "dummy"
                                    self.yang_parent_name = "security-association"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "dummy"
                                    self._is_frozen = True


                            class IdleTimeContainer(Entity):
                                """
                                
                                
                                .. attribute:: idle_time
                                
                                	Automatically delete IPSec SAs after a given idle period
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: default
                                
                                	All SAs idle\-out reset to default peer
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.IdleTimeContainer, self).__init__()

                                    self.yang_name = "idle-time-container"
                                    self.yang_parent_name = "security-association"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('idle_time', (YLeaf(YType.empty, 'idle-time'), ['Empty'])),
                                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ])
                                    self.idle_time = None
                                    self.default = None
                                    self._segment_path = lambda: "idle-time-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.IdleTimeContainer, ['idle_time', 'default'], name, value)


                            class Lifetime(Entity):
                                """
                                security association lifetime
                                
                                .. attribute:: days
                                
                                	Time\-based key duration in days
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: kilobytes
                                
                                	Volume\-based key duration
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: seconds
                                
                                	Time\-based key duration in seconds
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Lifetime, self).__init__()

                                    self.yang_name = "lifetime"
                                    self.yang_parent_name = "security-association"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('days', (YLeaf(YType.empty, 'days'), ['Empty'])),
                                        ('kilobytes', (YLeaf(YType.empty, 'kilobytes'), ['Empty'])),
                                        ('seconds', (YLeaf(YType.empty, 'seconds'), ['Empty'])),
                                    ])
                                    self.days = None
                                    self.kilobytes = None
                                    self.seconds = None
                                    self._segment_path = lambda: "lifetime"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Lifetime, ['days', 'kilobytes', 'seconds'], name, value)


                            class Replay(Entity):
                                """
                                Set replay checking.
                                
                                .. attribute:: disable
                                
                                	Disable replay checking
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: window_size
                                
                                	Set replay window size
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Replay, self).__init__()

                                    self.yang_name = "replay"
                                    self.yang_parent_name = "security-association"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ('window_size', (YLeaf(YType.empty, 'window-size'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self.window_size = None
                                    self._segment_path = lambda: "replay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Ipsec.Profile.Default.Set.SecurityAssociation.Replay, ['disable', 'window_size'], name, value)


                        class SecurityPolicy(Entity):
                            """
                            Maximum number of Security Policy entries that can be negotiated with the peer
                            
                            .. attribute:: limit
                            
                            	limit  0 \- 50000
                            	**type**\: int
                            
                            	**range:** 0..50000
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ipsec.Profile.Default.Set.SecurityPolicy, self).__init__()

                                self.yang_name = "security-policy"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ])
                                self.limit = None
                                self._segment_path = lambda: "security-policy"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ipsec.Profile.Default.Set.SecurityPolicy, ['limit'], name, value)


                class Dialer(Entity):
                    """
                    Dialer related commands
                    
                    .. attribute:: pre_classify
                    
                    	Enable dialer list classification before initiating IKE
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ipsec.Profile.Dialer, self).__init__()

                        self.yang_name = "dialer"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pre_classify', (YLeaf(YType.empty, 'pre-classify'), ['Empty'])),
                        ])
                        self.pre_classify = None
                        self._segment_path = lambda: "dialer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ipsec.Profile.Dialer, ['pre_classify'], name, value)


                class Redundancy(Entity):
                    """
                    Configure HA for this ipsec profile
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: stateful
                    
                    	enable stateful failover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ipsec.Profile.Redundancy, self).__init__()

                        self.yang_name = "redundancy"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('stateful', (YLeaf(YType.empty, 'stateful'), ['Empty'])),
                        ])
                        self.name = None
                        self.stateful = None
                        self._segment_path = lambda: "redundancy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ipsec.Profile.Redundancy, ['name', 'stateful'], name, value)


                class Set(Entity):
                    """
                    Set values for encryption/decryption
                    
                    .. attribute:: group
                    
                    	Set the san group parameters
                    	**type**\: str
                    
                    .. attribute:: identity
                    
                    	Identity restriction
                    	**type**\: str
                    
                    .. attribute:: ikev2_profile
                    
                    	Specify ikev2 Profile
                    	**type**\: str
                    
                    .. attribute:: isakmp_profile
                    
                    	Specify isakmp Profile
                    	**type**\: str
                    
                    .. attribute:: peer
                    
                    	Allowed Encryption/Decryption peer
                    	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.Peer>`
                    
                    .. attribute:: pfs
                    
                    	Specify pfs settings
                    	**type**\:  :py:class:`Pfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.Pfs>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: reverse_route
                    
                    	Reverse Route Injection
                    	**type**\:  :py:class:`ReverseRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.ReverseRoute>`
                    
                    .. attribute:: transform_set
                    
                    	Specify list of transform sets in priority order
                    	**type**\: list of str
                    
                    .. attribute:: mixed_mode
                    
                    	Turn on IPSec mixed\-mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: security_association
                    
                    	Security association parameters
                    	**type**\:  :py:class:`SecurityAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.SecurityAssociation>`
                    
                    .. attribute:: security_policy
                    
                    	Maximum number of Security Policy entries that can be negotiated with the peer
                    	**type**\:  :py:class:`SecurityPolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.SecurityPolicy>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ipsec.Profile.Set, self).__init__()

                        self.yang_name = "set"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peer", ("peer", Native.Crypto.Ipsec.Profile.Set.Peer)), ("pfs", ("pfs", Native.Crypto.Ipsec.Profile.Set.Pfs)), ("reverse-route", ("reverse_route", Native.Crypto.Ipsec.Profile.Set.ReverseRoute)), ("security-association", ("security_association", Native.Crypto.Ipsec.Profile.Set.SecurityAssociation)), ("security-policy", ("security_policy", Native.Crypto.Ipsec.Profile.Set.SecurityPolicy))])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str'])),
                            ('identity', (YLeaf(YType.str, 'identity'), ['str'])),
                            ('ikev2_profile', (YLeaf(YType.str, 'ikev2-profile'), ['str'])),
                            ('isakmp_profile', (YLeaf(YType.str, 'isakmp-profile'), ['str'])),
                            ('transform_set', (YLeafList(YType.str, 'transform-set'), ['str'])),
                            ('mixed_mode', (YLeaf(YType.empty, 'mixed-mode'), ['Empty'])),
                        ])
                        self.group = None
                        self.identity = None
                        self.ikev2_profile = None
                        self.isakmp_profile = None
                        self.transform_set = []
                        self.mixed_mode = None

                        self.peer = Native.Crypto.Ipsec.Profile.Set.Peer()
                        self.peer.parent = self
                        self._children_name_map["peer"] = "peer"

                        self.pfs = None
                        self._children_name_map["pfs"] = "pfs"

                        self.reverse_route = Native.Crypto.Ipsec.Profile.Set.ReverseRoute()
                        self.reverse_route.parent = self
                        self._children_name_map["reverse_route"] = "reverse-route"

                        self.security_association = Native.Crypto.Ipsec.Profile.Set.SecurityAssociation()
                        self.security_association.parent = self
                        self._children_name_map["security_association"] = "security-association"

                        self.security_policy = Native.Crypto.Ipsec.Profile.Set.SecurityPolicy()
                        self.security_policy.parent = self
                        self._children_name_map["security_policy"] = "security-policy"
                        self._segment_path = lambda: "set"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ipsec.Profile.Set, ['group', 'identity', 'ikev2_profile', 'isakmp_profile', 'transform_set', 'mixed_mode'], name, value)


                    class Peer(Entity):
                        """
                        Allowed Encryption/Decryption peer.
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: default
                        
                        	Reset to default peer in list in the event of a failure
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dynamic
                        
                        	Resolve the peer address at the time of negotiation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ipsec.Profile.Set.Peer, self).__init__()

                            self.yang_name = "peer"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str','str','str'])),
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                            ])
                            self.address = None
                            self.default = None
                            self.dynamic = None
                            self._segment_path = lambda: "peer"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ipsec.Profile.Set.Peer, ['address', 'default', 'dynamic'], name, value)


                    class Pfs(Entity):
                        """
                        Specify pfs settings
                        
                        .. attribute:: group
                        
                        	
                        	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.Pfs.Group>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ipsec.Profile.Set.Pfs, self).__init__()

                            self.yang_name = "pfs"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('group', (YLeaf(YType.enumeration, 'group'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.Profile.Set.Pfs.Group')])),
                            ])
                            self.group = None
                            self._segment_path = lambda: "pfs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ipsec.Profile.Set.Pfs, ['group'], name, value)

                        class Group(Enum):
                            """
                            Group (Enum Class)

                            .. data:: group1 = 0

                            .. data:: group14 = 1

                            .. data:: group15 = 2

                            .. data:: group16 = 3

                            .. data:: group19 = 4

                            .. data:: group2 = 5

                            .. data:: group20 = 6

                            .. data:: group21 = 7

                            .. data:: group24 = 8

                            .. data:: group5 = 9

                            """

                            group1 = Enum.YLeaf(0, "group1")

                            group14 = Enum.YLeaf(1, "group14")

                            group15 = Enum.YLeaf(2, "group15")

                            group16 = Enum.YLeaf(3, "group16")

                            group19 = Enum.YLeaf(4, "group19")

                            group2 = Enum.YLeaf(5, "group2")

                            group20 = Enum.YLeaf(6, "group20")

                            group21 = Enum.YLeaf(7, "group21")

                            group24 = Enum.YLeaf(8, "group24")

                            group5 = Enum.YLeaf(9, "group5")



                    class ReverseRoute(Entity):
                        """
                        Reverse Route Injection
                        
                        .. attribute:: distance
                        
                        	Distance metric for this static route
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tag
                        
                        	Create route and tag it
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ipsec.Profile.Set.ReverseRoute, self).__init__()

                            self.yang_name = "reverse-route"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                ('tag', (YLeaf(YType.uint64, 'tag'), ['int'])),
                            ])
                            self.distance = None
                            self.tag = None
                            self._segment_path = lambda: "reverse-route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ipsec.Profile.Set.ReverseRoute, ['distance', 'tag'], name, value)


                    class SecurityAssociation(Entity):
                        """
                        Security association parameters
                        
                        .. attribute:: dfbit
                        
                        	Handling of encapsulated DF bit
                        	**type**\:  :py:class:`Dfbit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Dfbit>`
                        
                        .. attribute:: dummy
                        
                        	Enable transmitting dummy packets
                        	**type**\:  :py:class:`Dummy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Dummy>`
                        
                        .. attribute:: ecn
                        
                        	Handling of ECN bit
                        	**type**\:  :py:class:`Ecn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Ecn>`
                        
                        .. attribute:: idle_time_container
                        
                        	
                        	**type**\:  :py:class:`IdleTimeContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.IdleTimeContainer>`
                        
                        .. attribute:: lifetime
                        
                        	security association lifetime
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Lifetime>`
                        
                        .. attribute:: replay
                        
                        	Set replay checking
                        	**type**\:  :py:class:`Replay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Replay>`
                        
                        .. attribute:: level
                        
                        	specify a security association granularity level for identities
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Level>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ipsec.Profile.Set.SecurityAssociation, self).__init__()

                            self.yang_name = "security-association"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dummy", ("dummy", Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Dummy)), ("idle-time-container", ("idle_time_container", Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.IdleTimeContainer)), ("lifetime", ("lifetime", Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Lifetime)), ("replay", ("replay", Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Replay))])
                            self._leafs = OrderedDict([
                                ('dfbit', (YLeaf(YType.enumeration, 'dfbit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.Profile.Set.SecurityAssociation.Dfbit')])),
                                ('ecn', (YLeaf(YType.enumeration, 'ecn'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.Profile.Set.SecurityAssociation.Ecn')])),
                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.Profile.Set.SecurityAssociation.Level')])),
                            ])
                            self.dfbit = None
                            self.ecn = None
                            self.level = None

                            self.dummy = Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Dummy()
                            self.dummy.parent = self
                            self._children_name_map["dummy"] = "dummy"

                            self.idle_time_container = Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.IdleTimeContainer()
                            self.idle_time_container.parent = self
                            self._children_name_map["idle_time_container"] = "idle-time-container"

                            self.lifetime = Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"

                            self.replay = Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Replay()
                            self.replay.parent = self
                            self._children_name_map["replay"] = "replay"
                            self._segment_path = lambda: "security-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ipsec.Profile.Set.SecurityAssociation, ['dfbit', 'ecn', 'level'], name, value)

                        class Dfbit(Enum):
                            """
                            Dfbit (Enum Class)

                            Handling of encapsulated DF bit.

                            .. data:: clear = 0

                            .. data:: copy = 1

                            .. data:: set = 2

                            """

                            clear = Enum.YLeaf(0, "clear")

                            copy = Enum.YLeaf(1, "copy")

                            set = Enum.YLeaf(2, "set")


                        class Ecn(Enum):
                            """
                            Ecn (Enum Class)

                            Handling of ECN bit

                            .. data:: discard = 0

                            .. data:: propagate = 1

                            """

                            discard = Enum.YLeaf(0, "discard")

                            propagate = Enum.YLeaf(1, "propagate")


                        class Level(Enum):
                            """
                            Level (Enum Class)

                            specify a security association granularity level for identities

                            .. data:: per_host = 0

                            """

                            per_host = Enum.YLeaf(0, "per-host")



                        class Dummy(Entity):
                            """
                            Enable transmitting dummy packets
                            
                            .. attribute:: pps
                            
                            	Simulated traffic rate (in pps)
                            	**type**\: int
                            
                            	**range:** 0..25
                            
                            .. attribute:: seconds
                            
                            	Simulated traffic rate (in seconds)
                            	**type**\: int
                            
                            	**range:** 1..3600
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Dummy, self).__init__()

                                self.yang_name = "dummy"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pps', (YLeaf(YType.uint8, 'pps'), ['int'])),
                                    ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                                ])
                                self.pps = None
                                self.seconds = None
                                self._segment_path = lambda: "dummy"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Dummy, ['pps', 'seconds'], name, value)


                        class IdleTimeContainer(Entity):
                            """
                            
                            
                            .. attribute:: idle_time
                            
                            	Automatically delete IPSec SAs after a given idle period
                            	**type**\: int
                            
                            	**range:** 60..86400
                            
                            .. attribute:: default
                            
                            	All SAs idle\-out reset to default peer
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.IdleTimeContainer, self).__init__()

                                self.yang_name = "idle-time-container"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('idle_time', (YLeaf(YType.uint32, 'idle-time'), ['int'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ])
                                self.idle_time = None
                                self.default = None
                                self._segment_path = lambda: "idle-time-container"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.IdleTimeContainer, ['idle_time', 'default'], name, value)


                        class Lifetime(Entity):
                            """
                            security association lifetime
                            
                            .. attribute:: days
                            
                            	Time\-based key duration in days
                            	**type**\: int
                            
                            	**range:** 1..30
                            
                            .. attribute:: kilobytes
                            
                            	Volume\-based key duration
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 2560..4294967295
                            
                            		**type**\:  :py:class:`Kilobytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Lifetime.Kilobytes>`
                            
                            .. attribute:: seconds
                            
                            	Time\-based key duration in seconds
                            	**type**\: int
                            
                            	**range:** 120..2592000
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('days', (YLeaf(YType.uint8, 'days'), ['int'])),
                                    ('kilobytes', (YLeaf(YType.str, 'kilobytes'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.CryptoMap.Map.Set.SecurityAssociation.Lifetime.Kilobytes')])),
                                    ('seconds', (YLeaf(YType.uint64, 'seconds'), ['int'])),
                                ])
                                self.days = None
                                self.kilobytes = None
                                self.seconds = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Lifetime, ['days', 'kilobytes', 'seconds'], name, value)

                            class Kilobytes(Enum):
                                """
                                Kilobytes (Enum Class)

                                Volume\-based key duration

                                .. data:: disable = 0

                                """

                                disable = Enum.YLeaf(0, "disable")



                        class Replay(Entity):
                            """
                            Set replay checking.
                            
                            .. attribute:: disable
                            
                            	Disable replay checking
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: window_size
                            
                            	Set replay window size
                            	**type**\:  :py:class:`WindowSize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Replay.WindowSize>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Replay, self).__init__()

                                self.yang_name = "replay"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('window_size', (YLeaf(YType.enumeration, 'window-size'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.Profile.Set.SecurityAssociation.Replay.WindowSize')])),
                                ])
                                self.disable = None
                                self.window_size = None
                                self._segment_path = lambda: "replay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Ipsec.Profile.Set.SecurityAssociation.Replay, ['disable', 'window_size'], name, value)

                            class WindowSize(Enum):
                                """
                                WindowSize (Enum Class)

                                Set replay window size.

                                .. data:: Y_1024 = 0

                                .. data:: Y_128 = 1

                                .. data:: Y_256 = 2

                                .. data:: Y_512 = 3

                                .. data:: Y_64 = 4

                                """

                                Y_1024 = Enum.YLeaf(0, "1024")

                                Y_128 = Enum.YLeaf(1, "128")

                                Y_256 = Enum.YLeaf(2, "256")

                                Y_512 = Enum.YLeaf(3, "512")

                                Y_64 = Enum.YLeaf(4, "64")



                    class SecurityPolicy(Entity):
                        """
                        Maximum number of Security Policy entries that can be negotiated with the peer
                        
                        .. attribute:: limit
                        
                        	limit  0 \- 50000
                        	**type**\: int
                        
                        	**range:** 0..50000
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ipsec.Profile.Set.SecurityPolicy, self).__init__()

                            self.yang_name = "security-policy"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                            ])
                            self.limit = None
                            self._segment_path = lambda: "security-policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ipsec.Profile.Set.SecurityPolicy, ['limit'], name, value)


            class SecurityAssociation(Entity):
                """
                Security association parameters
                
                .. attribute:: dummy
                
                	Enable transmitting dummy packets
                	**type**\:  :py:class:`Dummy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.SecurityAssociation.Dummy>`
                
                .. attribute:: ecn
                
                	Handling of ECN bit
                	**type**\:  :py:class:`Ecn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.SecurityAssociation.Ecn>`
                
                .. attribute:: idle_time
                
                	Automatically delete IPSec SAs after a given idle period
                	**type**\: int
                
                	**range:** 60..86400
                
                .. attribute:: lifetime
                
                	security association lifetime
                	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.SecurityAssociation.Lifetime>`
                
                .. attribute:: replay
                
                	Set replay checking
                	**type**\:  :py:class:`Replay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.SecurityAssociation.Replay>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ipsec.SecurityAssociation, self).__init__()

                    self.yang_name = "security-association"
                    self.yang_parent_name = "ipsec"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dummy", ("dummy", Native.Crypto.Ipsec.SecurityAssociation.Dummy)), ("lifetime", ("lifetime", Native.Crypto.Ipsec.SecurityAssociation.Lifetime)), ("replay", ("replay", Native.Crypto.Ipsec.SecurityAssociation.Replay))])
                    self._leafs = OrderedDict([
                        ('ecn', (YLeaf(YType.enumeration, 'ecn'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.SecurityAssociation.Ecn')])),
                        ('idle_time', (YLeaf(YType.uint32, 'idle-time'), ['int'])),
                    ])
                    self.ecn = None
                    self.idle_time = None

                    self.dummy = Native.Crypto.Ipsec.SecurityAssociation.Dummy()
                    self.dummy.parent = self
                    self._children_name_map["dummy"] = "dummy"

                    self.lifetime = Native.Crypto.Ipsec.SecurityAssociation.Lifetime()
                    self.lifetime.parent = self
                    self._children_name_map["lifetime"] = "lifetime"

                    self.replay = Native.Crypto.Ipsec.SecurityAssociation.Replay()
                    self.replay.parent = self
                    self._children_name_map["replay"] = "replay"
                    self._segment_path = lambda: "security-association"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ipsec/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ipsec.SecurityAssociation, ['ecn', 'idle_time'], name, value)

                class Ecn(Enum):
                    """
                    Ecn (Enum Class)

                    Handling of ECN bit

                    .. data:: discard = 0

                    .. data:: propagate = 1

                    """

                    discard = Enum.YLeaf(0, "discard")

                    propagate = Enum.YLeaf(1, "propagate")



                class Dummy(Entity):
                    """
                    Enable transmitting dummy packets
                    
                    .. attribute:: pps
                    
                    	Simulated traffic rate (in pps)
                    	**type**\: int
                    
                    	**range:** 0..25
                    
                    .. attribute:: seconds
                    
                    	Simulated traffic rate (in seconds)
                    	**type**\: int
                    
                    	**range:** 1..3600
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ipsec.SecurityAssociation.Dummy, self).__init__()

                        self.yang_name = "dummy"
                        self.yang_parent_name = "security-association"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pps', (YLeaf(YType.uint8, 'pps'), ['int'])),
                            ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                        ])
                        self.pps = None
                        self.seconds = None
                        self._segment_path = lambda: "dummy"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ipsec/security-association/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ipsec.SecurityAssociation.Dummy, ['pps', 'seconds'], name, value)


                class Lifetime(Entity):
                    """
                    security association lifetime
                    
                    .. attribute:: days
                    
                    	Time\-based key duration in days
                    	**type**\: int
                    
                    	**range:** 1..30
                    
                    .. attribute:: kilobytes
                    
                    	Volume\-based key duration
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 2560..4294967295
                    
                    		**type**\:  :py:class:`Kilobytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.SecurityAssociation.Lifetime.Kilobytes>`
                    
                    .. attribute:: seconds
                    
                    	Time\-based key duration in seconds
                    	**type**\: int
                    
                    	**range:** 120..2592000
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ipsec.SecurityAssociation.Lifetime, self).__init__()

                        self.yang_name = "lifetime"
                        self.yang_parent_name = "security-association"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('days', (YLeaf(YType.uint8, 'days'), ['int'])),
                            ('kilobytes', (YLeaf(YType.str, 'kilobytes'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.SecurityAssociation.Lifetime.Kilobytes')])),
                            ('seconds', (YLeaf(YType.uint64, 'seconds'), ['int'])),
                        ])
                        self.days = None
                        self.kilobytes = None
                        self.seconds = None
                        self._segment_path = lambda: "lifetime"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ipsec/security-association/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ipsec.SecurityAssociation.Lifetime, ['days', 'kilobytes', 'seconds'], name, value)

                    class Kilobytes(Enum):
                        """
                        Kilobytes (Enum Class)

                        Volume\-based key duration

                        .. data:: disable = 0

                        """

                        disable = Enum.YLeaf(0, "disable")



                class Replay(Entity):
                    """
                    Set replay checking.
                    
                    .. attribute:: disable
                    
                    	Disable replay checking
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: window_size
                    
                    	Set replay window size
                    	**type**\:  :py:class:`WindowSize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.SecurityAssociation.Replay.WindowSize>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ipsec.SecurityAssociation.Replay, self).__init__()

                        self.yang_name = "replay"
                        self.yang_parent_name = "security-association"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('window_size', (YLeaf(YType.enumeration, 'window-size'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.SecurityAssociation.Replay.WindowSize')])),
                        ])
                        self.disable = None
                        self.window_size = None
                        self._segment_path = lambda: "replay"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ipsec/security-association/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ipsec.SecurityAssociation.Replay, ['disable', 'window_size'], name, value)

                    class WindowSize(Enum):
                        """
                        WindowSize (Enum Class)

                        Set replay window size.

                        .. data:: Y_1024 = 0

                        .. data:: Y_128 = 1

                        .. data:: Y_256 = 2

                        .. data:: Y_512 = 3

                        .. data:: Y_64 = 4

                        """

                        Y_1024 = Enum.YLeaf(0, "1024")

                        Y_128 = Enum.YLeaf(1, "128")

                        Y_256 = Enum.YLeaf(2, "256")

                        Y_512 = Enum.YLeaf(3, "512")

                        Y_64 = Enum.YLeaf(4, "64")



            class TransformSet(Entity):
                """
                Define transform and settings
                
                .. attribute:: tag  (key)
                
                	
                	**type**\: str
                
                .. attribute:: ah_hmac
                
                	
                	**type**\:  :py:class:`AhHmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.TransformSet.AhHmac>`
                
                .. attribute:: comp_lzs
                
                	IP Compression using the LZS compression algorithm
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: esp
                
                	
                	**type**\:  :py:class:`Esp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.TransformSet.Esp>`
                
                .. attribute:: key_bit
                
                	
                	**type**\:  :py:class:`KeyBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.TransformSet.KeyBit>`
                
                .. attribute:: esp_hmac
                
                	
                	**type**\:  :py:class:`EspHmac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.TransformSet.EspHmac>`
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.TransformSet.Default>`
                
                .. attribute:: mode
                
                	encapsulation mode (transport/tunnel)
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.TransformSet.Mode>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ipsec.TransformSet, self).__init__()

                    self.yang_name = "transform-set"
                    self.yang_parent_name = "ipsec"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['tag']
                    self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Ipsec.TransformSet.Default)), ("mode", ("mode", Native.Crypto.Ipsec.TransformSet.Mode))])
                    self._leafs = OrderedDict([
                        ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                        ('ah_hmac', (YLeaf(YType.enumeration, 'ah-hmac'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.TransformSet.AhHmac')])),
                        ('comp_lzs', (YLeaf(YType.empty, 'comp-lzs'), ['Empty'])),
                        ('esp', (YLeaf(YType.enumeration, 'esp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.TransformSet.Esp')])),
                        ('key_bit', (YLeaf(YType.enumeration, 'key-bit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.TransformSet.KeyBit')])),
                        ('esp_hmac', (YLeaf(YType.enumeration, 'esp-hmac'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Ipsec.TransformSet.EspHmac')])),
                    ])
                    self.tag = None
                    self.ah_hmac = None
                    self.comp_lzs = None
                    self.esp = None
                    self.key_bit = None
                    self.esp_hmac = None

                    self.default = Native.Crypto.Ipsec.TransformSet.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.mode = Native.Crypto.Ipsec.TransformSet.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"
                    self._segment_path = lambda: "transform-set" + "[tag='" + str(self.tag) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ipsec/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ipsec.TransformSet, ['tag', 'ah_hmac', 'comp_lzs', 'esp', 'key_bit', 'esp_hmac'], name, value)

                class AhHmac(Enum):
                    """
                    AhHmac (Enum Class)

                    .. data:: ah_md5_hmac = 0

                    .. data:: ah_sha_hmac = 1

                    .. data:: ah_sha256_hmac = 2

                    .. data:: ah_sha384_hmac = 3

                    .. data:: ah_sha512_hmac = 4

                    """

                    ah_md5_hmac = Enum.YLeaf(0, "ah-md5-hmac")

                    ah_sha_hmac = Enum.YLeaf(1, "ah-sha-hmac")

                    ah_sha256_hmac = Enum.YLeaf(2, "ah-sha256-hmac")

                    ah_sha384_hmac = Enum.YLeaf(3, "ah-sha384-hmac")

                    ah_sha512_hmac = Enum.YLeaf(4, "ah-sha512-hmac")


                class Esp(Enum):
                    """
                    Esp (Enum Class)

                    .. data:: esp_3des = 0

                    .. data:: esp_aes = 1

                    .. data:: esp_des = 2

                    .. data:: esp_gcm = 3

                    .. data:: esp_gmac = 4

                    .. data:: esp_null = 5

                    .. data:: esp_seal = 6

                    """

                    esp_3des = Enum.YLeaf(0, "esp-3des")

                    esp_aes = Enum.YLeaf(1, "esp-aes")

                    esp_des = Enum.YLeaf(2, "esp-des")

                    esp_gcm = Enum.YLeaf(3, "esp-gcm")

                    esp_gmac = Enum.YLeaf(4, "esp-gmac")

                    esp_null = Enum.YLeaf(5, "esp-null")

                    esp_seal = Enum.YLeaf(6, "esp-seal")


                class EspHmac(Enum):
                    """
                    EspHmac (Enum Class)

                    .. data:: esp_md5_hmac = 0

                    .. data:: esp_sha_hmac = 1

                    .. data:: esp_sha256_hmac = 2

                    .. data:: esp_sha384_hmac = 3

                    .. data:: esp_sha512_hmac = 4

                    """

                    esp_md5_hmac = Enum.YLeaf(0, "esp-md5-hmac")

                    esp_sha_hmac = Enum.YLeaf(1, "esp-sha-hmac")

                    esp_sha256_hmac = Enum.YLeaf(2, "esp-sha256-hmac")

                    esp_sha384_hmac = Enum.YLeaf(3, "esp-sha384-hmac")

                    esp_sha512_hmac = Enum.YLeaf(4, "esp-sha512-hmac")


                class KeyBit(Enum):
                    """
                    KeyBit (Enum Class)

                    .. data:: Y_128 = 0

                    .. data:: Y_192 = 1

                    .. data:: Y_256 = 2

                    """

                    Y_128 = Enum.YLeaf(0, "128")

                    Y_192 = Enum.YLeaf(1, "192")

                    Y_256 = Enum.YLeaf(2, "256")



                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: mode
                    
                    	encapsulation mode (transport/tunnel)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ipsec.TransformSet.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "transform-set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                        ])
                        self.mode = None
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ipsec.TransformSet.Default, ['mode'], name, value)


                class Mode(Entity):
                    """
                    encapsulation mode (transport/tunnel)
                    
                    .. attribute:: transport
                    
                    	transport (payload encapsulation) mode
                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ipsec.TransformSet.Mode.Transport>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: tunnel
                    
                    	tunnel (datagram encapsulation) mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ipsec.TransformSet.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "transform-set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("transport", ("transport", Native.Crypto.Ipsec.TransformSet.Mode.Transport))])
                        self._leafs = OrderedDict([
                            ('tunnel', (YLeaf(YType.empty, 'tunnel'), ['Empty'])),
                        ])
                        self.tunnel = None

                        self.transport = None
                        self._children_name_map["transport"] = "transport"
                        self._segment_path = lambda: "mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ipsec.TransformSet.Mode, ['tunnel'], name, value)


                    class Transport(Entity):
                        """
                        transport (payload encapsulation) mode
                        
                        .. attribute:: require
                        
                        	Accept only the configured encapsulation mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Ipsec.TransformSet.Mode.Transport, self).__init__()

                            self.yang_name = "transport"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('require', (YLeaf(YType.empty, 'require'), ['Empty'])),
                            ])
                            self.require = None
                            self._segment_path = lambda: "transport"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Ipsec.TransformSet.Mode.Transport, ['require'], name, value)


        class Key(Entity):
            """
            Long term key operations
            
            .. attribute:: decrypt
            
            	Decrypt a keypair
            	**type**\:  :py:class:`Decrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Decrypt>`
            
            .. attribute:: encrypt
            
            	Encrypt a keypair
            	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Encrypt>`
            
            .. attribute:: export
            
            	Export keys
            	**type**\:  :py:class:`Export <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Export>`
            
            .. attribute:: generate
            
            	Generate new keys
            	**type**\:  :py:class:`Generate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Generate>`
            
            .. attribute:: import_
            
            	Import keys
            	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Import>`
            
            .. attribute:: move
            
            	Move keys
            	**type**\:  :py:class:`Move <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Move>`
            
            .. attribute:: pubkey_chain
            
            	Peer public key chain management
            	**type**\:  :py:class:`PubkeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain>`
            
            .. attribute:: storage
            
            	default storage location for keypairs
            	**type**\: str
            
            .. attribute:: zeroize
            
            	Remove keys
            	**type**\:  :py:class:`Zeroize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Zeroize>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Key, self).__init__()

                self.yang_name = "key"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("decrypt", ("decrypt", Native.Crypto.Key.Decrypt)), ("encrypt", ("encrypt", Native.Crypto.Key.Encrypt)), ("export", ("export", Native.Crypto.Key.Export)), ("generate", ("generate", Native.Crypto.Key.Generate)), ("import", ("import_", Native.Crypto.Key.Import)), ("move", ("move", Native.Crypto.Key.Move)), ("pubkey-chain", ("pubkey_chain", Native.Crypto.Key.PubkeyChain)), ("zeroize", ("zeroize", Native.Crypto.Key.Zeroize))])
                self._leafs = OrderedDict([
                    ('storage', (YLeaf(YType.str, 'storage'), ['str'])),
                ])
                self.storage = None

                self.decrypt = Native.Crypto.Key.Decrypt()
                self.decrypt.parent = self
                self._children_name_map["decrypt"] = "decrypt"

                self.encrypt = Native.Crypto.Key.Encrypt()
                self.encrypt.parent = self
                self._children_name_map["encrypt"] = "encrypt"

                self.export = Native.Crypto.Key.Export()
                self.export.parent = self
                self._children_name_map["export"] = "export"

                self.generate = Native.Crypto.Key.Generate()
                self.generate.parent = self
                self._children_name_map["generate"] = "generate"

                self.import_ = Native.Crypto.Key.Import()
                self.import_.parent = self
                self._children_name_map["import_"] = "import"

                self.move = Native.Crypto.Key.Move()
                self.move.parent = self
                self._children_name_map["move"] = "move"

                self.pubkey_chain = Native.Crypto.Key.PubkeyChain()
                self.pubkey_chain.parent = self
                self._children_name_map["pubkey_chain"] = "pubkey-chain"

                self.zeroize = Native.Crypto.Key.Zeroize()
                self.zeroize.parent = self
                self._children_name_map["zeroize"] = "zeroize"
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:key"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Key, ['storage'], name, value)


            class Decrypt(Entity):
                """
                Decrypt a keypair.
                
                .. attribute:: ec
                
                	EC keys
                	**type**\:  :py:class:`Ec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Decrypt.Ec>`
                
                	**presence node**\: True
                
                .. attribute:: rsa
                
                	RSA keys
                	**type**\:  :py:class:`Rsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Decrypt.Rsa>`
                
                	**presence node**\: True
                
                .. attribute:: write
                
                	Will write the configuration to startup\-config
                	**type**\:  :py:class:`Write <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Decrypt.Write>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Key.Decrypt, self).__init__()

                    self.yang_name = "decrypt"
                    self.yang_parent_name = "key"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ec", ("ec", Native.Crypto.Key.Decrypt.Ec)), ("rsa", ("rsa", Native.Crypto.Key.Decrypt.Rsa)), ("write", ("write", Native.Crypto.Key.Decrypt.Write))])
                    self._leafs = OrderedDict()

                    self.ec = None
                    self._children_name_map["ec"] = "ec"

                    self.rsa = None
                    self._children_name_map["rsa"] = "rsa"

                    self.write = Native.Crypto.Key.Decrypt.Write()
                    self.write.parent = self
                    self._children_name_map["write"] = "write"
                    self._segment_path = lambda: "decrypt"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Key.Decrypt, [], name, value)


                class Ec(Entity):
                    """
                    EC keys
                    
                    .. attribute:: name
                    
                    	Name of keypair to decrypt
                    	**type**\: str
                    
                    .. attribute:: passphrase
                    
                    	decryption key
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Decrypt.Ec, self).__init__()

                        self.yang_name = "ec"
                        self.yang_parent_name = "decrypt"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('passphrase', (YLeaf(YType.str, 'passphrase'), ['str'])),
                        ])
                        self.name = None
                        self.passphrase = None
                        self._segment_path = lambda: "ec"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/decrypt/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Decrypt.Ec, ['name', 'passphrase'], name, value)


                class Rsa(Entity):
                    """
                    RSA keys
                    
                    .. attribute:: name
                    
                    	Name of keypair to decrypt
                    	**type**\: str
                    
                    .. attribute:: passphrase
                    
                    	decryption key
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Decrypt.Rsa, self).__init__()

                        self.yang_name = "rsa"
                        self.yang_parent_name = "decrypt"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('passphrase', (YLeaf(YType.str, 'passphrase'), ['str'])),
                        ])
                        self.name = None
                        self.passphrase = None
                        self._segment_path = lambda: "rsa"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/decrypt/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Decrypt.Rsa, ['name', 'passphrase'], name, value)


                class Write(Entity):
                    """
                    Will write the configuration to startup\-config.
                    
                    .. attribute:: ec
                    
                    	EC keys
                    	**type**\:  :py:class:`Ec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Decrypt.Write.Ec>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: rsa
                    
                    	RSA keys
                    	**type**\:  :py:class:`Rsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Decrypt.Write.Rsa>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Decrypt.Write, self).__init__()

                        self.yang_name = "write"
                        self.yang_parent_name = "decrypt"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ec", ("ec", Native.Crypto.Key.Decrypt.Write.Ec)), ("rsa", ("rsa", Native.Crypto.Key.Decrypt.Write.Rsa))])
                        self._leafs = OrderedDict()

                        self.ec = None
                        self._children_name_map["ec"] = "ec"

                        self.rsa = None
                        self._children_name_map["rsa"] = "rsa"
                        self._segment_path = lambda: "write"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/decrypt/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Decrypt.Write, [], name, value)


                    class Ec(Entity):
                        """
                        EC keys
                        
                        .. attribute:: name
                        
                        	Name of keypair to decrypt
                        	**type**\: str
                        
                        .. attribute:: passphrase
                        
                        	decryption key
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Key.Decrypt.Write.Ec, self).__init__()

                            self.yang_name = "ec"
                            self.yang_parent_name = "write"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('passphrase', (YLeaf(YType.str, 'passphrase'), ['str'])),
                            ])
                            self.name = None
                            self.passphrase = None
                            self._segment_path = lambda: "ec"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/decrypt/write/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Key.Decrypt.Write.Ec, ['name', 'passphrase'], name, value)


                    class Rsa(Entity):
                        """
                        RSA keys
                        
                        .. attribute:: name
                        
                        	Name of keypair to decrypt
                        	**type**\: str
                        
                        .. attribute:: passphrase
                        
                        	decryption key
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Key.Decrypt.Write.Rsa, self).__init__()

                            self.yang_name = "rsa"
                            self.yang_parent_name = "write"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('passphrase', (YLeaf(YType.str, 'passphrase'), ['str'])),
                            ])
                            self.name = None
                            self.passphrase = None
                            self._segment_path = lambda: "rsa"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/decrypt/write/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Key.Decrypt.Write.Rsa, ['name', 'passphrase'], name, value)


            class Encrypt(Entity):
                """
                Encrypt a keypair.
                
                .. attribute:: ec
                
                	EC keys
                	**type**\:  :py:class:`Ec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Encrypt.Ec>`
                
                	**presence node**\: True
                
                .. attribute:: rsa
                
                	RSA keys
                	**type**\:  :py:class:`Rsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Encrypt.Rsa>`
                
                	**presence node**\: True
                
                .. attribute:: write
                
                	Will write the configuration to startup\-config
                	**type**\:  :py:class:`Write <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Encrypt.Write>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Key.Encrypt, self).__init__()

                    self.yang_name = "encrypt"
                    self.yang_parent_name = "key"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ec", ("ec", Native.Crypto.Key.Encrypt.Ec)), ("rsa", ("rsa", Native.Crypto.Key.Encrypt.Rsa)), ("write", ("write", Native.Crypto.Key.Encrypt.Write))])
                    self._leafs = OrderedDict()

                    self.ec = None
                    self._children_name_map["ec"] = "ec"

                    self.rsa = None
                    self._children_name_map["rsa"] = "rsa"

                    self.write = Native.Crypto.Key.Encrypt.Write()
                    self.write.parent = self
                    self._children_name_map["write"] = "write"
                    self._segment_path = lambda: "encrypt"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Key.Encrypt, [], name, value)


                class Ec(Entity):
                    """
                    EC keys
                    
                    .. attribute:: name
                    
                    	Name of keypair to encrypt
                    	**type**\: str
                    
                    .. attribute:: passphrase
                    
                    	encryption key
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Encrypt.Ec, self).__init__()

                        self.yang_name = "ec"
                        self.yang_parent_name = "encrypt"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('passphrase', (YLeaf(YType.str, 'passphrase'), ['str'])),
                        ])
                        self.name = None
                        self.passphrase = None
                        self._segment_path = lambda: "ec"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/encrypt/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Encrypt.Ec, ['name', 'passphrase'], name, value)


                class Rsa(Entity):
                    """
                    RSA keys
                    
                    .. attribute:: name
                    
                    	Name of keypair to encrypt
                    	**type**\: str
                    
                    .. attribute:: passphrase
                    
                    	encryption key
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Encrypt.Rsa, self).__init__()

                        self.yang_name = "rsa"
                        self.yang_parent_name = "encrypt"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('passphrase', (YLeaf(YType.str, 'passphrase'), ['str'])),
                        ])
                        self.name = None
                        self.passphrase = None
                        self._segment_path = lambda: "rsa"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/encrypt/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Encrypt.Rsa, ['name', 'passphrase'], name, value)


                class Write(Entity):
                    """
                    Will write the configuration to startup\-config.
                    
                    .. attribute:: ec
                    
                    	EC keys
                    	**type**\:  :py:class:`Ec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Encrypt.Write.Ec>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: rsa
                    
                    	RSA keys
                    	**type**\:  :py:class:`Rsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Encrypt.Write.Rsa>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Encrypt.Write, self).__init__()

                        self.yang_name = "write"
                        self.yang_parent_name = "encrypt"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ec", ("ec", Native.Crypto.Key.Encrypt.Write.Ec)), ("rsa", ("rsa", Native.Crypto.Key.Encrypt.Write.Rsa))])
                        self._leafs = OrderedDict()

                        self.ec = None
                        self._children_name_map["ec"] = "ec"

                        self.rsa = None
                        self._children_name_map["rsa"] = "rsa"
                        self._segment_path = lambda: "write"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/encrypt/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Encrypt.Write, [], name, value)


                    class Ec(Entity):
                        """
                        EC keys
                        
                        .. attribute:: name
                        
                        	Name of keypair to encrypt
                        	**type**\: str
                        
                        .. attribute:: passphrase
                        
                        	encryption key
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Key.Encrypt.Write.Ec, self).__init__()

                            self.yang_name = "ec"
                            self.yang_parent_name = "write"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('passphrase', (YLeaf(YType.str, 'passphrase'), ['str'])),
                            ])
                            self.name = None
                            self.passphrase = None
                            self._segment_path = lambda: "ec"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/encrypt/write/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Key.Encrypt.Write.Ec, ['name', 'passphrase'], name, value)


                    class Rsa(Entity):
                        """
                        RSA keys
                        
                        .. attribute:: name
                        
                        	Name of keypair to encrypt
                        	**type**\: str
                        
                        .. attribute:: passphrase
                        
                        	encryption key
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Key.Encrypt.Write.Rsa, self).__init__()

                            self.yang_name = "rsa"
                            self.yang_parent_name = "write"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('passphrase', (YLeaf(YType.str, 'passphrase'), ['str'])),
                            ])
                            self.name = None
                            self.passphrase = None
                            self._segment_path = lambda: "rsa"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/encrypt/write/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Key.Encrypt.Write.Rsa, ['name', 'passphrase'], name, value)


            class Export(Entity):
                """
                Export keys
                
                .. attribute:: ec
                
                	Export EC keys
                	**type**\: list of  		 :py:class:`Ec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Export.Ec>`
                
                .. attribute:: rsa
                
                	Export RSRA keys
                	**type**\: list of  		 :py:class:`Rsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Export.Rsa>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Key.Export, self).__init__()

                    self.yang_name = "export"
                    self.yang_parent_name = "key"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ec", ("ec", Native.Crypto.Key.Export.Ec)), ("rsa", ("rsa", Native.Crypto.Key.Export.Rsa))])
                    self._leafs = OrderedDict()

                    self.ec = YList(self)
                    self.rsa = YList(self)
                    self._segment_path = lambda: "export"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Key.Export, [], name, value)


                class Ec(Entity):
                    """
                    Export EC keys
                    
                    .. attribute:: label  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: pem
                    
                    	File type to export
                    	**type**\:  :py:class:`Pem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Export.Ec.Pem>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Export.Ec, self).__init__()

                        self.yang_name = "ec"
                        self.yang_parent_name = "export"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['label']
                        self._child_classes = OrderedDict([("pem", ("pem", Native.Crypto.Key.Export.Ec.Pem))])
                        self._leafs = OrderedDict([
                            ('label', (YLeaf(YType.str, 'label'), ['str'])),
                        ])
                        self.label = None

                        self.pem = Native.Crypto.Key.Export.Ec.Pem()
                        self.pem.parent = self
                        self._children_name_map["pem"] = "pem"
                        self._segment_path = lambda: "ec" + "[label='" + str(self.label) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/export/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Export.Ec, ['label'], name, value)


                    class Pem(Entity):
                        """
                        File type to export
                        
                        .. attribute:: terminal
                        
                        	Export via the terminal (cut\-and\-paste)
                        	**type**\:  :py:class:`Terminal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Export.Ec.Pem.Terminal>`
                        
                        .. attribute:: url
                        
                        	Export via the file systems
                        	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Export.Ec.Pem.Url>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Key.Export.Ec.Pem, self).__init__()

                            self.yang_name = "pem"
                            self.yang_parent_name = "ec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("terminal", ("terminal", Native.Crypto.Key.Export.Ec.Pem.Terminal)), ("url", ("url", Native.Crypto.Key.Export.Ec.Pem.Url))])
                            self._leafs = OrderedDict()

                            self.terminal = Native.Crypto.Key.Export.Ec.Pem.Terminal()
                            self.terminal.parent = self
                            self._children_name_map["terminal"] = "terminal"

                            self.url = Native.Crypto.Key.Export.Ec.Pem.Url()
                            self.url.parent = self
                            self._children_name_map["url"] = "url"
                            self._segment_path = lambda: "pem"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Key.Export.Ec.Pem, [], name, value)


                        class Terminal(Entity):
                            """
                            Export via the terminal (cut\-and\-paste)
                            
                            .. attribute:: pk_3des
                            
                            	Encrypt the private key with 3DES
                            	**type**\: str
                            
                            .. attribute:: des
                            
                            	Encrypt the private key with DES
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Key.Export.Ec.Pem.Terminal, self).__init__()

                                self.yang_name = "terminal"
                                self.yang_parent_name = "pem"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pk_3des', (YLeaf(YType.str, 'pk-3des'), ['str'])),
                                    ('des', (YLeaf(YType.str, 'des'), ['str'])),
                                ])
                                self.pk_3des = None
                                self.des = None
                                self._segment_path = lambda: "terminal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Key.Export.Ec.Pem.Terminal, ['pk_3des', 'des'], name, value)


                        class Url(Entity):
                            """
                            Export via the file systems
                            
                            .. attribute:: file
                            
                            	
                            	**type**\:  :py:class:`File <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Export.Ec.Pem.Url.File>`
                            
                            .. attribute:: url_3des
                            
                            	Encrypt the private key with 3DES
                            	**type**\: str
                            
                            .. attribute:: des
                            
                            	Encrypt the private key with DES
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Key.Export.Ec.Pem.Url, self).__init__()

                                self.yang_name = "url"
                                self.yang_parent_name = "pem"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('file', (YLeaf(YType.enumeration, 'file'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Key.Export.Ec.Pem.Url.File')])),
                                    ('url_3des', (YLeaf(YType.str, 'url-3des'), ['str'])),
                                    ('des', (YLeaf(YType.str, 'des'), ['str'])),
                                ])
                                self.file = None
                                self.url_3des = None
                                self.des = None
                                self._segment_path = lambda: "url"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Key.Export.Ec.Pem.Url, ['file', 'url_3des', 'des'], name, value)

                            class File(Enum):
                                """
                                File (Enum Class)

                                .. data:: bootflash__COLON__ = 0

                                .. data:: flash__COLON__ = 1

                                .. data:: ftp__COLON__ = 2

                                .. data:: http__COLON__ = 3

                                .. data:: https__COLON__ = 4

                                .. data:: null__COLON__ = 5

                                .. data:: nvram__COLON__ = 6

                                .. data:: pram__COLON__ = 7

                                .. data:: rcp__COLON__ = 8

                                .. data:: scp__COLON__ = 9

                                .. data:: system__COLON__ = 10

                                .. data:: tftp__COLON__ = 11

                                .. data:: tmpsys__COLON__ = 12

                                """

                                bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                                flash__COLON__ = Enum.YLeaf(1, "flash:")

                                ftp__COLON__ = Enum.YLeaf(2, "ftp:")

                                http__COLON__ = Enum.YLeaf(3, "http:")

                                https__COLON__ = Enum.YLeaf(4, "https:")

                                null__COLON__ = Enum.YLeaf(5, "null:")

                                nvram__COLON__ = Enum.YLeaf(6, "nvram:")

                                pram__COLON__ = Enum.YLeaf(7, "pram:")

                                rcp__COLON__ = Enum.YLeaf(8, "rcp:")

                                scp__COLON__ = Enum.YLeaf(9, "scp:")

                                system__COLON__ = Enum.YLeaf(10, "system:")

                                tftp__COLON__ = Enum.YLeaf(11, "tftp:")

                                tmpsys__COLON__ = Enum.YLeaf(12, "tmpsys:")



                class Rsa(Entity):
                    """
                    Export RSRA keys
                    
                    .. attribute:: label  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: pem
                    
                    	File type to export
                    	**type**\:  :py:class:`Pem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Export.Rsa.Pem>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Export.Rsa, self).__init__()

                        self.yang_name = "rsa"
                        self.yang_parent_name = "export"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['label']
                        self._child_classes = OrderedDict([("pem", ("pem", Native.Crypto.Key.Export.Rsa.Pem))])
                        self._leafs = OrderedDict([
                            ('label', (YLeaf(YType.str, 'label'), ['str'])),
                        ])
                        self.label = None

                        self.pem = Native.Crypto.Key.Export.Rsa.Pem()
                        self.pem.parent = self
                        self._children_name_map["pem"] = "pem"
                        self._segment_path = lambda: "rsa" + "[label='" + str(self.label) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/export/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Export.Rsa, ['label'], name, value)


                    class Pem(Entity):
                        """
                        File type to export
                        
                        .. attribute:: terminal
                        
                        	Export via the terminal (cut\-and\-paste)
                        	**type**\:  :py:class:`Terminal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Export.Rsa.Pem.Terminal>`
                        
                        .. attribute:: url
                        
                        	Export via the file systems
                        	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Export.Rsa.Pem.Url>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Key.Export.Rsa.Pem, self).__init__()

                            self.yang_name = "pem"
                            self.yang_parent_name = "rsa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("terminal", ("terminal", Native.Crypto.Key.Export.Rsa.Pem.Terminal)), ("url", ("url", Native.Crypto.Key.Export.Rsa.Pem.Url))])
                            self._leafs = OrderedDict()

                            self.terminal = Native.Crypto.Key.Export.Rsa.Pem.Terminal()
                            self.terminal.parent = self
                            self._children_name_map["terminal"] = "terminal"

                            self.url = Native.Crypto.Key.Export.Rsa.Pem.Url()
                            self.url.parent = self
                            self._children_name_map["url"] = "url"
                            self._segment_path = lambda: "pem"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Key.Export.Rsa.Pem, [], name, value)


                        class Terminal(Entity):
                            """
                            Export via the terminal (cut\-and\-paste)
                            
                            .. attribute:: pk_3des
                            
                            	Encrypt the private key with 3DES
                            	**type**\: str
                            
                            .. attribute:: des
                            
                            	Encrypt the private key with DES
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Key.Export.Rsa.Pem.Terminal, self).__init__()

                                self.yang_name = "terminal"
                                self.yang_parent_name = "pem"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pk_3des', (YLeaf(YType.str, 'pk-3des'), ['str'])),
                                    ('des', (YLeaf(YType.str, 'des'), ['str'])),
                                ])
                                self.pk_3des = None
                                self.des = None
                                self._segment_path = lambda: "terminal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Key.Export.Rsa.Pem.Terminal, ['pk_3des', 'des'], name, value)


                        class Url(Entity):
                            """
                            Export via the file systems
                            
                            .. attribute:: file
                            
                            	
                            	**type**\:  :py:class:`File <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Export.Rsa.Pem.Url.File>`
                            
                            .. attribute:: url_3des
                            
                            	Encrypt the private key with 3DES
                            	**type**\: str
                            
                            .. attribute:: des
                            
                            	Encrypt the private key with DES
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Key.Export.Rsa.Pem.Url, self).__init__()

                                self.yang_name = "url"
                                self.yang_parent_name = "pem"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('file', (YLeaf(YType.enumeration, 'file'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Key.Export.Rsa.Pem.Url.File')])),
                                    ('url_3des', (YLeaf(YType.str, 'url-3des'), ['str'])),
                                    ('des', (YLeaf(YType.str, 'des'), ['str'])),
                                ])
                                self.file = None
                                self.url_3des = None
                                self.des = None
                                self._segment_path = lambda: "url"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Key.Export.Rsa.Pem.Url, ['file', 'url_3des', 'des'], name, value)

                            class File(Enum):
                                """
                                File (Enum Class)

                                .. data:: bootflash__COLON__ = 0

                                .. data:: flash__COLON__ = 1

                                .. data:: ftp__COLON__ = 2

                                .. data:: http__COLON__ = 3

                                .. data:: https__COLON__ = 4

                                .. data:: null__COLON__ = 5

                                .. data:: nvram__COLON__ = 6

                                .. data:: pram__COLON__ = 7

                                .. data:: rcp__COLON__ = 8

                                .. data:: scp__COLON__ = 9

                                .. data:: system__COLON__ = 10

                                .. data:: tftp__COLON__ = 11

                                .. data:: tmpsys__COLON__ = 12

                                """

                                bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                                flash__COLON__ = Enum.YLeaf(1, "flash:")

                                ftp__COLON__ = Enum.YLeaf(2, "ftp:")

                                http__COLON__ = Enum.YLeaf(3, "http:")

                                https__COLON__ = Enum.YLeaf(4, "https:")

                                null__COLON__ = Enum.YLeaf(5, "null:")

                                nvram__COLON__ = Enum.YLeaf(6, "nvram:")

                                pram__COLON__ = Enum.YLeaf(7, "pram:")

                                rcp__COLON__ = Enum.YLeaf(8, "rcp:")

                                scp__COLON__ = Enum.YLeaf(9, "scp:")

                                system__COLON__ = Enum.YLeaf(10, "system:")

                                tftp__COLON__ = Enum.YLeaf(11, "tftp:")

                                tmpsys__COLON__ = Enum.YLeaf(12, "tmpsys:")



            class Generate(Entity):
                """
                Generate new keys
                
                .. attribute:: ec
                
                	Generate EC keys for ECDSA
                	**type**\:  :py:class:`Ec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Generate.Ec>`
                
                .. attribute:: rsa
                
                	Generate RSA keys
                	**type**\:  :py:class:`Rsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Generate.Rsa>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Key.Generate, self).__init__()

                    self.yang_name = "generate"
                    self.yang_parent_name = "key"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ec", ("ec", Native.Crypto.Key.Generate.Ec)), ("rsa", ("rsa", Native.Crypto.Key.Generate.Rsa))])
                    self._leafs = OrderedDict()

                    self.ec = Native.Crypto.Key.Generate.Ec()
                    self.ec.parent = self
                    self._children_name_map["ec"] = "ec"

                    self.rsa = None
                    self._children_name_map["rsa"] = "rsa"
                    self._segment_path = lambda: "generate"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Key.Generate, [], name, value)


                class Ec(Entity):
                    """
                    Generate EC keys for ECDSA
                    
                    .. attribute:: keysize
                    
                    	Number of bits
                    	**type**\:  :py:class:`Keysize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Generate.Ec.Keysize>`
                    
                    .. attribute:: exportable
                    
                    	Allow key to be exported
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: label
                    
                    	Provide a label
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Generate.Ec, self).__init__()

                        self.yang_name = "ec"
                        self.yang_parent_name = "generate"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('keysize', (YLeaf(YType.enumeration, 'keysize'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Key.Generate.Ec.Keysize')])),
                            ('exportable', (YLeaf(YType.empty, 'exportable'), ['Empty'])),
                            ('label', (YLeaf(YType.str, 'label'), ['str'])),
                        ])
                        self.keysize = None
                        self.exportable = None
                        self.label = None
                        self._segment_path = lambda: "ec"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/generate/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Generate.Ec, ['keysize', 'exportable', 'label'], name, value)

                    class Keysize(Enum):
                        """
                        Keysize (Enum Class)

                        Number of bits

                        .. data:: Y_256 = 0

                        .. data:: Y_384 = 1

                        """

                        Y_256 = Enum.YLeaf(0, "256")

                        Y_384 = Enum.YLeaf(1, "384")



                class Rsa(Entity):
                    """
                    Generate RSA keys
                    
                    .. attribute:: encryption
                    
                    	Generate a general purpose RSA key pair for signing and encryption
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: exportable
                    
                    	Allow the key to be exported
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: general_keys
                    
                    	Generate a general purpose RSA key pair for signing and encryption
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: label
                    
                    	Provide a label
                    	**type**\: str
                    
                    .. attribute:: modulus
                    
                    	Provide number of modulus bits on the command line
                    	**type**\: int
                    
                    	**range:** 360..4096
                    
                    .. attribute:: on
                    
                    	create key on specified device
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	Allow the key to be synced to high\-availability peer
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: signature
                    
                    	Generate a general purpose RSA key pair for signing and encryption
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: storage
                    
                    	Store key on specified device
                    	**type**\: str
                    
                    .. attribute:: usage_keys
                    
                    	Generate separate RSA key pairs for signing and encryption
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Generate.Rsa, self).__init__()

                        self.yang_name = "rsa"
                        self.yang_parent_name = "generate"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('encryption', (YLeaf(YType.empty, 'encryption'), ['Empty'])),
                            ('exportable', (YLeaf(YType.empty, 'exportable'), ['Empty'])),
                            ('general_keys', (YLeaf(YType.empty, 'general-keys'), ['Empty'])),
                            ('label', (YLeaf(YType.str, 'label'), ['str'])),
                            ('modulus', (YLeaf(YType.uint16, 'modulus'), ['int'])),
                            ('on', (YLeaf(YType.str, 'on'), ['str'])),
                            ('redundancy', (YLeaf(YType.empty, 'redundancy'), ['Empty'])),
                            ('signature', (YLeaf(YType.empty, 'signature'), ['Empty'])),
                            ('storage', (YLeaf(YType.str, 'storage'), ['str'])),
                            ('usage_keys', (YLeaf(YType.empty, 'usage-keys'), ['Empty'])),
                        ])
                        self.encryption = None
                        self.exportable = None
                        self.general_keys = None
                        self.label = None
                        self.modulus = None
                        self.on = None
                        self.redundancy = None
                        self.signature = None
                        self.storage = None
                        self.usage_keys = None
                        self._segment_path = lambda: "rsa"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/generate/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Generate.Rsa, ['encryption', 'exportable', 'general_keys', 'label', 'modulus', 'on', 'redundancy', 'signature', 'storage', 'usage_keys'], name, value)


            class Import(Entity):
                """
                Import keys
                
                .. attribute:: ec
                
                	Import EC keys
                	**type**\: list of  		 :py:class:`Ec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Import.Ec>`
                
                .. attribute:: rsa
                
                	Import RSA keys
                	**type**\: list of  		 :py:class:`Rsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Import.Rsa>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Key.Import, self).__init__()

                    self.yang_name = "import"
                    self.yang_parent_name = "key"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ec", ("ec", Native.Crypto.Key.Import.Ec)), ("rsa", ("rsa", Native.Crypto.Key.Import.Rsa))])
                    self._leafs = OrderedDict()

                    self.ec = YList(self)
                    self.rsa = YList(self)
                    self._segment_path = lambda: "import"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Key.Import, [], name, value)


                class Ec(Entity):
                    """
                    Import EC keys
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: exportable
                    
                    	Allow key to be exported
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: terminal
                    
                    	Import via the terminal (cut\-and\-paste)
                    	**type**\: str
                    
                    .. attribute:: url
                    
                    	Export via the file systems
                    	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Import.Ec.Url>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Import.Ec, self).__init__()

                        self.yang_name = "ec"
                        self.yang_parent_name = "import"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("url", ("url", Native.Crypto.Key.Import.Ec.Url))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('exportable', (YLeaf(YType.empty, 'exportable'), ['Empty'])),
                            ('terminal', (YLeaf(YType.str, 'terminal'), ['str'])),
                        ])
                        self.name = None
                        self.exportable = None
                        self.terminal = None

                        self.url = Native.Crypto.Key.Import.Ec.Url()
                        self.url.parent = self
                        self._children_name_map["url"] = "url"
                        self._segment_path = lambda: "ec" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/import/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Import.Ec, ['name', 'exportable', 'terminal'], name, value)


                    class Url(Entity):
                        """
                        Export via the file systems
                        
                        .. attribute:: file
                        
                        	
                        	**type**\:  :py:class:`File <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Import.Ec.Url.File>`
                        
                        .. attribute:: key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Key.Import.Ec.Url, self).__init__()

                            self.yang_name = "url"
                            self.yang_parent_name = "ec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('file', (YLeaf(YType.enumeration, 'file'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Key.Import.Ec.Url.File')])),
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                            ])
                            self.file = None
                            self.key = None
                            self._segment_path = lambda: "url"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Key.Import.Ec.Url, ['file', 'key'], name, value)

                        class File(Enum):
                            """
                            File (Enum Class)

                            .. data:: bootflash__COLON__ = 0

                            .. data:: cns__COLON__ = 1

                            .. data:: flash__COLON__ = 2

                            .. data:: ftp__COLON__ = 3

                            .. data:: http__COLON__ = 4

                            .. data:: https__COLON__ = 5

                            .. data:: null__COLON__ = 6

                            .. data:: nvram__COLON__ = 7

                            .. data:: pram__COLON__ = 8

                            .. data:: rcp__COLON__ = 9

                            .. data:: scp__COLON__ = 10

                            .. data:: system__COLON__ = 11

                            .. data:: tar__COLON__ = 12

                            .. data:: tftp__COLON__ = 13

                            .. data:: tmpsys__COLON__ = 14

                            """

                            bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                            cns__COLON__ = Enum.YLeaf(1, "cns:")

                            flash__COLON__ = Enum.YLeaf(2, "flash:")

                            ftp__COLON__ = Enum.YLeaf(3, "ftp:")

                            http__COLON__ = Enum.YLeaf(4, "http:")

                            https__COLON__ = Enum.YLeaf(5, "https:")

                            null__COLON__ = Enum.YLeaf(6, "null:")

                            nvram__COLON__ = Enum.YLeaf(7, "nvram:")

                            pram__COLON__ = Enum.YLeaf(8, "pram:")

                            rcp__COLON__ = Enum.YLeaf(9, "rcp:")

                            scp__COLON__ = Enum.YLeaf(10, "scp:")

                            system__COLON__ = Enum.YLeaf(11, "system:")

                            tar__COLON__ = Enum.YLeaf(12, "tar:")

                            tftp__COLON__ = Enum.YLeaf(13, "tftp:")

                            tmpsys__COLON__ = Enum.YLeaf(14, "tmpsys:")



                class Rsa(Entity):
                    """
                    Import RSA keys
                    
                    .. attribute:: label  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: encryption
                    
                    	Encryption key
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: exportable
                    
                    	Allow the key to be exported
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: general_purpose
                    
                    	General Purpose key
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: on
                    
                    	Make this an on\-token key
                    	**type**\: str
                    
                    .. attribute:: pem
                    
                    	File type to import
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: redundancy
                    
                    	Sync this key to the standby
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: signature
                    
                    	Signature key
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: storage
                    
                    	Store key on specified device
                    	**type**\: str
                    
                    .. attribute:: usage_keys
                    
                    	Usage key pairs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: terminal
                    
                    	Import via the terminal (cut\-and\-paste)
                    	**type**\: str
                    
                    .. attribute:: url
                    
                    	Export via the file systems
                    	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Import.Rsa.Url>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Import.Rsa, self).__init__()

                        self.yang_name = "rsa"
                        self.yang_parent_name = "import"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['label']
                        self._child_classes = OrderedDict([("url", ("url", Native.Crypto.Key.Import.Rsa.Url))])
                        self._leafs = OrderedDict([
                            ('label', (YLeaf(YType.str, 'label'), ['str'])),
                            ('encryption', (YLeaf(YType.empty, 'encryption'), ['Empty'])),
                            ('exportable', (YLeaf(YType.empty, 'exportable'), ['Empty'])),
                            ('general_purpose', (YLeaf(YType.empty, 'general-purpose'), ['Empty'])),
                            ('on', (YLeaf(YType.str, 'on'), ['str'])),
                            ('pem', (YLeaf(YType.empty, 'pem'), ['Empty'])),
                            ('redundancy', (YLeaf(YType.empty, 'redundancy'), ['Empty'])),
                            ('signature', (YLeaf(YType.empty, 'signature'), ['Empty'])),
                            ('storage', (YLeaf(YType.str, 'storage'), ['str'])),
                            ('usage_keys', (YLeaf(YType.empty, 'usage-keys'), ['Empty'])),
                            ('terminal', (YLeaf(YType.str, 'terminal'), ['str'])),
                        ])
                        self.label = None
                        self.encryption = None
                        self.exportable = None
                        self.general_purpose = None
                        self.on = None
                        self.pem = None
                        self.redundancy = None
                        self.signature = None
                        self.storage = None
                        self.usage_keys = None
                        self.terminal = None

                        self.url = Native.Crypto.Key.Import.Rsa.Url()
                        self.url.parent = self
                        self._children_name_map["url"] = "url"
                        self._segment_path = lambda: "rsa" + "[label='" + str(self.label) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/import/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Import.Rsa, ['label', 'encryption', 'exportable', 'general_purpose', 'on', 'pem', 'redundancy', 'signature', 'storage', 'usage_keys', 'terminal'], name, value)


                    class Url(Entity):
                        """
                        Export via the file systems
                        
                        .. attribute:: file
                        
                        	
                        	**type**\:  :py:class:`File <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Import.Rsa.Url.File>`
                        
                        .. attribute:: key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Key.Import.Rsa.Url, self).__init__()

                            self.yang_name = "url"
                            self.yang_parent_name = "rsa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('file', (YLeaf(YType.enumeration, 'file'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Key.Import.Rsa.Url.File')])),
                                ('key', (YLeaf(YType.str, 'key'), ['str'])),
                            ])
                            self.file = None
                            self.key = None
                            self._segment_path = lambda: "url"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Key.Import.Rsa.Url, ['file', 'key'], name, value)

                        class File(Enum):
                            """
                            File (Enum Class)

                            .. data:: bootflash__COLON__ = 0

                            .. data:: cns__COLON__ = 1

                            .. data:: flash__COLON__ = 2

                            .. data:: ftp__COLON__ = 3

                            .. data:: http__COLON__ = 4

                            .. data:: https__COLON__ = 5

                            .. data:: null__COLON__ = 6

                            .. data:: nvram__COLON__ = 7

                            .. data:: pram__COLON__ = 8

                            .. data:: rcp__COLON__ = 9

                            .. data:: scp__COLON__ = 10

                            .. data:: system__COLON__ = 11

                            .. data:: tar__COLON__ = 12

                            .. data:: tftp__COLON__ = 13

                            .. data:: tmpsys__COLON__ = 14

                            """

                            bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                            cns__COLON__ = Enum.YLeaf(1, "cns:")

                            flash__COLON__ = Enum.YLeaf(2, "flash:")

                            ftp__COLON__ = Enum.YLeaf(3, "ftp:")

                            http__COLON__ = Enum.YLeaf(4, "http:")

                            https__COLON__ = Enum.YLeaf(5, "https:")

                            null__COLON__ = Enum.YLeaf(6, "null:")

                            nvram__COLON__ = Enum.YLeaf(7, "nvram:")

                            pram__COLON__ = Enum.YLeaf(8, "pram:")

                            rcp__COLON__ = Enum.YLeaf(9, "rcp:")

                            scp__COLON__ = Enum.YLeaf(10, "scp:")

                            system__COLON__ = Enum.YLeaf(11, "system:")

                            tar__COLON__ = Enum.YLeaf(12, "tar:")

                            tftp__COLON__ = Enum.YLeaf(13, "tftp:")

                            tmpsys__COLON__ = Enum.YLeaf(14, "tmpsys:")



            class Move(Entity):
                """
                Move keys
                
                .. attribute:: rsa
                
                	Move RSA keys
                	**type**\:  :py:class:`Rsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Move.Rsa>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Key.Move, self).__init__()

                    self.yang_name = "move"
                    self.yang_parent_name = "key"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rsa", ("rsa", Native.Crypto.Key.Move.Rsa))])
                    self._leafs = OrderedDict()

                    self.rsa = Native.Crypto.Key.Move.Rsa()
                    self.rsa.parent = self
                    self._children_name_map["rsa"] = "rsa"
                    self._segment_path = lambda: "move"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Key.Move, [], name, value)


                class Rsa(Entity):
                    """
                    Move RSA keys
                    
                    .. attribute:: label
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: non_exportable
                    
                    	Do Not allow the key to be exported
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: on
                    
                    	Make this an on\-token key
                    	**type**\: str
                    
                    .. attribute:: redundancy
                    
                    	Sync this key to the standby
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: storage
                    
                    	Store key on specified device
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Move.Rsa, self).__init__()

                        self.yang_name = "rsa"
                        self.yang_parent_name = "move"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('label', (YLeaf(YType.str, 'label'), ['str'])),
                            ('non_exportable', (YLeaf(YType.empty, 'non-exportable'), ['Empty'])),
                            ('on', (YLeaf(YType.str, 'on'), ['str'])),
                            ('redundancy', (YLeaf(YType.empty, 'redundancy'), ['Empty'])),
                            ('storage', (YLeaf(YType.str, 'storage'), ['str'])),
                        ])
                        self.label = None
                        self.non_exportable = None
                        self.on = None
                        self.redundancy = None
                        self.storage = None
                        self._segment_path = lambda: "rsa"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/move/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Move.Rsa, ['label', 'non_exportable', 'on', 'redundancy', 'storage'], name, value)


            class PubkeyChain(Entity):
                """
                Peer public key chain management
                
                .. attribute:: rsa
                
                	Peer RSA public key chain management
                	**type**\:  :py:class:`Rsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Key.PubkeyChain, self).__init__()

                    self.yang_name = "pubkey-chain"
                    self.yang_parent_name = "key"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rsa", ("rsa", Native.Crypto.Key.PubkeyChain.Rsa))])
                    self._leafs = OrderedDict()

                    self.rsa = Native.Crypto.Key.PubkeyChain.Rsa()
                    self.rsa.parent = self
                    self._children_name_map["rsa"] = "rsa"
                    self._segment_path = lambda: "pubkey-chain"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Key.PubkeyChain, [], name, value)


                class Rsa(Entity):
                    """
                    Peer RSA public key chain management
                    
                    .. attribute:: addressed_key
                    
                    	Public key associated with an address
                    	**type**\: list of  		 :py:class:`AddressedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey>`
                    
                    .. attribute:: named_key
                    
                    	Public key associated with a name
                    	**type**\: list of  		 :py:class:`NamedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.NamedKey>`
                    
                    .. attribute:: default
                    
                    	Set a command to its defaults
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.Default>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.PubkeyChain.Rsa, self).__init__()

                        self.yang_name = "rsa"
                        self.yang_parent_name = "pubkey-chain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("addressed-key", ("addressed_key", Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey)), ("named-key", ("named_key", Native.Crypto.Key.PubkeyChain.Rsa.NamedKey)), ("default", ("default", Native.Crypto.Key.PubkeyChain.Rsa.Default))])
                        self._leafs = OrderedDict()

                        self.default = Native.Crypto.Key.PubkeyChain.Rsa.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.addressed_key = YList(self)
                        self.named_key = YList(self)
                        self._segment_path = lambda: "rsa"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/pubkey-chain/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.PubkeyChain.Rsa, [], name, value)


                    class AddressedKey(Entity):
                        """
                        Public key associated with an address
                        
                        .. attribute:: ip  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: use
                        
                        	
                        	**type**\:  :py:class:`Use <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.Use>`
                        
                        .. attribute:: address
                        
                        	Assign an address to the key
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: key_string
                        
                        	Key data
                        	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.KeyString>`
                        
                        .. attribute:: serial_number
                        
                        	Serial number of the device
                        	**type**\: str
                        
                        .. attribute:: default
                        
                        	Set a command to its defaults
                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.Default>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey, self).__init__()

                            self.yang_name = "addressed-key"
                            self.yang_parent_name = "rsa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ip']
                            self._child_classes = OrderedDict([("key-string", ("key_string", Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.KeyString)), ("default", ("default", Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.Default))])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('use', (YLeaf(YType.enumeration, 'use'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Key.PubkeyChain.Rsa.AddressedKey.Use')])),
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('serial_number', (YLeaf(YType.str, 'serial-number'), ['str'])),
                            ])
                            self.ip = None
                            self.use = None
                            self.address = None
                            self.serial_number = None

                            self.key_string = Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.KeyString()
                            self.key_string.parent = self
                            self._children_name_map["key_string"] = "key-string"

                            self.default = Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.Default()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"
                            self._segment_path = lambda: "addressed-key" + "[ip='" + str(self.ip) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/pubkey-chain/rsa/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey, ['ip', 'use', 'address', 'serial_number'], name, value)

                        class Use(Enum):
                            """
                            Use (Enum Class)

                            .. data:: encryption = 0

                            .. data:: signature = 1

                            """

                            encryption = Enum.YLeaf(0, "encryption")

                            signature = Enum.YLeaf(1, "signature")



                        class KeyString(Entity):
                            """
                            Key data
                            
                            .. attribute:: hex_data
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: quit
                            
                            	Exit data entry mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.KeyString, self).__init__()

                                self.yang_name = "key-string"
                                self.yang_parent_name = "addressed-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hex_data', (YLeaf(YType.str, 'hex-data'), ['str'])),
                                    ('quit', (YLeaf(YType.empty, 'quit'), ['Empty'])),
                                ])
                                self.hex_data = None
                                self.quit = None
                                self._segment_path = lambda: "key-string"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.KeyString, ['hex_data', 'quit'], name, value)


                        class Default(Entity):
                            """
                            Set a command to its defaults
                            
                            .. attribute:: address
                            
                            	Assign an address to the key
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: key_string
                            
                            	Key data
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.Default.KeyString>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: serial_number
                            
                            	Serial number of the device
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.Default, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "addressed-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.Default.KeyString))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ('serial_number', (YLeaf(YType.empty, 'serial-number'), ['Empty'])),
                                ])
                                self.address = None
                                self.serial_number = None

                                self.key_string = None
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "default"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.Default, ['address', 'serial_number'], name, value)


                            class KeyString(Entity):
                                """
                                Key data
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Key.PubkeyChain.Rsa.AddressedKey.Default.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True


                    class NamedKey(Entity):
                        """
                        Public key associated with a name
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: use
                        
                        	
                        	**type**\:  :py:class:`Use <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.Use>`
                        
                        .. attribute:: address
                        
                        	Assign an address to the key
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: key_string
                        
                        	Key data
                        	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.KeyString>`
                        
                        .. attribute:: serial_number
                        
                        	Serial number of the device
                        	**type**\: str
                        
                        .. attribute:: default
                        
                        	Set a command to its defaults
                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.Default>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Key.PubkeyChain.Rsa.NamedKey, self).__init__()

                            self.yang_name = "named-key"
                            self.yang_parent_name = "rsa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("key-string", ("key_string", Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.KeyString)), ("default", ("default", Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.Default))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('use', (YLeaf(YType.enumeration, 'use'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Key.PubkeyChain.Rsa.NamedKey.Use')])),
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('serial_number', (YLeaf(YType.str, 'serial-number'), ['str'])),
                            ])
                            self.name = None
                            self.use = None
                            self.address = None
                            self.serial_number = None

                            self.key_string = Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.KeyString()
                            self.key_string.parent = self
                            self._children_name_map["key_string"] = "key-string"

                            self.default = Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.Default()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"
                            self._segment_path = lambda: "named-key" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/pubkey-chain/rsa/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Key.PubkeyChain.Rsa.NamedKey, ['name', 'use', 'address', 'serial_number'], name, value)

                        class Use(Enum):
                            """
                            Use (Enum Class)

                            .. data:: encryption = 0

                            .. data:: signature = 1

                            """

                            encryption = Enum.YLeaf(0, "encryption")

                            signature = Enum.YLeaf(1, "signature")



                        class KeyString(Entity):
                            """
                            Key data
                            
                            .. attribute:: hex_data
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: quit
                            
                            	Exit data entry mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.KeyString, self).__init__()

                                self.yang_name = "key-string"
                                self.yang_parent_name = "named-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hex_data', (YLeaf(YType.str, 'hex-data'), ['str'])),
                                    ('quit', (YLeaf(YType.empty, 'quit'), ['Empty'])),
                                ])
                                self.hex_data = None
                                self.quit = None
                                self._segment_path = lambda: "key-string"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.KeyString, ['hex_data', 'quit'], name, value)


                        class Default(Entity):
                            """
                            Set a command to its defaults
                            
                            .. attribute:: address
                            
                            	Assign an address to the key
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: key_string
                            
                            	Key data
                            	**type**\:  :py:class:`KeyString <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.Default.KeyString>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: serial_number
                            
                            	Serial number of the device
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.Default, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "named-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("key-string", ("key_string", Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.Default.KeyString))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                                    ('serial_number', (YLeaf(YType.empty, 'serial-number'), ['Empty'])),
                                ])
                                self.address = None
                                self.serial_number = None

                                self.key_string = None
                                self._children_name_map["key_string"] = "key-string"
                                self._segment_path = lambda: "default"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.Default, ['address', 'serial_number'], name, value)


                            class KeyString(Entity):
                                """
                                Key data
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Key.PubkeyChain.Rsa.NamedKey.Default.KeyString, self).__init__()

                                    self.yang_name = "key-string"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "key-string"
                                    self._is_frozen = True


                    class Default(Entity):
                        """
                        Set a command to its defaults
                        
                        .. attribute:: addressed_key
                        
                        	Public key associated with an address
                        	**type**\: list of  		 :py:class:`AddressedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.Default.AddressedKey>`
                        
                        .. attribute:: named_key
                        
                        	Public key associated with a name
                        	**type**\: list of  		 :py:class:`NamedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.Default.NamedKey>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Key.PubkeyChain.Rsa.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "rsa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("addressed-key", ("addressed_key", Native.Crypto.Key.PubkeyChain.Rsa.Default.AddressedKey)), ("named-key", ("named_key", Native.Crypto.Key.PubkeyChain.Rsa.Default.NamedKey))])
                            self._leafs = OrderedDict()

                            self.addressed_key = YList(self)
                            self.named_key = YList(self)
                            self._segment_path = lambda: "default"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/pubkey-chain/rsa/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Key.PubkeyChain.Rsa.Default, [], name, value)


                        class AddressedKey(Entity):
                            """
                            Public key associated with an address
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: use
                            
                            	
                            	**type**\:  :py:class:`Use <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.Default.AddressedKey.Use>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Key.PubkeyChain.Rsa.Default.AddressedKey, self).__init__()

                                self.yang_name = "addressed-key"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                    ('use', (YLeaf(YType.enumeration, 'use'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Key.PubkeyChain.Rsa.Default.AddressedKey.Use')])),
                                ])
                                self.ip = None
                                self.use = None
                                self._segment_path = lambda: "addressed-key" + "[ip='" + str(self.ip) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/pubkey-chain/rsa/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Key.PubkeyChain.Rsa.Default.AddressedKey, ['ip', 'use'], name, value)

                            class Use(Enum):
                                """
                                Use (Enum Class)

                                .. data:: encryption = 0

                                .. data:: signature = 1

                                """

                                encryption = Enum.YLeaf(0, "encryption")

                                signature = Enum.YLeaf(1, "signature")



                        class NamedKey(Entity):
                            """
                            Public key associated with a name
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: use
                            
                            	
                            	**type**\:  :py:class:`Use <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.PubkeyChain.Rsa.Default.NamedKey.Use>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Key.PubkeyChain.Rsa.Default.NamedKey, self).__init__()

                                self.yang_name = "named-key"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('use', (YLeaf(YType.enumeration, 'use'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Key.PubkeyChain.Rsa.Default.NamedKey.Use')])),
                                ])
                                self.name = None
                                self.use = None
                                self._segment_path = lambda: "named-key" + "[name='" + str(self.name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/pubkey-chain/rsa/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Key.PubkeyChain.Rsa.Default.NamedKey, ['name', 'use'], name, value)

                            class Use(Enum):
                                """
                                Use (Enum Class)

                                .. data:: encryption = 0

                                .. data:: signature = 1

                                """

                                encryption = Enum.YLeaf(0, "encryption")

                                signature = Enum.YLeaf(1, "signature")



            class Zeroize(Entity):
                """
                Remove keys
                
                .. attribute:: ec
                
                	Remove EC keys
                	**type**\:  :py:class:`Ec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Zeroize.Ec>`
                
                	**presence node**\: True
                
                .. attribute:: pubkey_chain
                
                	Remove peer's cached public key
                	**type**\:  :py:class:`PubkeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Zeroize.PubkeyChain>`
                
                	**presence node**\: True
                
                .. attribute:: rsa
                
                	Remove RSA keys
                	**type**\:  :py:class:`Rsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Key.Zeroize.Rsa>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Key.Zeroize, self).__init__()

                    self.yang_name = "zeroize"
                    self.yang_parent_name = "key"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ec", ("ec", Native.Crypto.Key.Zeroize.Ec)), ("pubkey-chain", ("pubkey_chain", Native.Crypto.Key.Zeroize.PubkeyChain)), ("rsa", ("rsa", Native.Crypto.Key.Zeroize.Rsa))])
                    self._leafs = OrderedDict()

                    self.ec = None
                    self._children_name_map["ec"] = "ec"

                    self.pubkey_chain = None
                    self._children_name_map["pubkey_chain"] = "pubkey-chain"

                    self.rsa = None
                    self._children_name_map["rsa"] = "rsa"
                    self._segment_path = lambda: "zeroize"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Key.Zeroize, [], name, value)


                class Ec(Entity):
                    """
                    Remove EC keys
                    
                    .. attribute:: label
                    
                    	
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Zeroize.Ec, self).__init__()

                        self.yang_name = "ec"
                        self.yang_parent_name = "zeroize"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('label', (YLeaf(YType.str, 'label'), ['str'])),
                        ])
                        self.label = None
                        self._segment_path = lambda: "ec"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/zeroize/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Zeroize.Ec, ['label'], name, value)


                class PubkeyChain(Entity):
                    """
                    Remove peer's cached public key
                    
                    .. attribute:: index
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Zeroize.PubkeyChain, self).__init__()

                        self.yang_name = "pubkey-chain"
                        self.yang_parent_name = "zeroize"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('index', (YLeaf(YType.uint16, 'index'), ['int'])),
                        ])
                        self.index = None
                        self._segment_path = lambda: "pubkey-chain"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/zeroize/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Zeroize.PubkeyChain, ['index'], name, value)


                class Rsa(Entity):
                    """
                    Remove RSA keys
                    
                    .. attribute:: label
                    
                    	
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Key.Zeroize.Rsa, self).__init__()

                        self.yang_name = "rsa"
                        self.yang_parent_name = "zeroize"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('label', (YLeaf(YType.str, 'label'), ['str'])),
                        ])
                        self.label = None
                        self._segment_path = lambda: "rsa"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:key/zeroize/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Key.Zeroize.Rsa, ['label'], name, value)


        class Keyring(Entity):
            """
            Key ring commands
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: vrf
            
            	Mention a vrf it belongs to
            	**type**\: str
            
            .. attribute:: default
            
            	Set a command to its defaults
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default>`
            
            .. attribute:: description
            
            	Specify a description about this keyring
            	**type**\: str
            
            .. attribute:: local_address
            
            	Limit the keyring usage to a local address
            	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.LocalAddress>`
            
            .. attribute:: pre_shared_key
            
            	Pre\-Shared Key
            	**type**\:  :py:class:`PreSharedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.PreSharedKey>`
            
            .. attribute:: rsa_pubkey
            
            	Peer RSA public key chain management
            	**type**\:  :py:class:`RsaPubkey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.RsaPubkey>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Keyring, self).__init__()

                self.yang_name = "keyring"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Keyring.Default)), ("local-address", ("local_address", Native.Crypto.Keyring.LocalAddress)), ("pre-shared-key", ("pre_shared_key", Native.Crypto.Keyring.PreSharedKey)), ("rsa-pubkey", ("rsa_pubkey", Native.Crypto.Keyring.RsaPubkey))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                ])
                self.name = None
                self.vrf = None
                self.description = None

                self.default = Native.Crypto.Keyring.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.local_address = Native.Crypto.Keyring.LocalAddress()
                self.local_address.parent = self
                self._children_name_map["local_address"] = "local-address"

                self.pre_shared_key = Native.Crypto.Keyring.PreSharedKey()
                self.pre_shared_key.parent = self
                self._children_name_map["pre_shared_key"] = "pre-shared-key"

                self.rsa_pubkey = Native.Crypto.Keyring.RsaPubkey()
                self.rsa_pubkey.parent = self
                self._children_name_map["rsa_pubkey"] = "rsa-pubkey"
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:keyring" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Keyring, ['name', 'vrf', 'description'], name, value)


            class Default(Entity):
                """
                Set a command to its defaults
                
                .. attribute:: description
                
                	Specify a description about this keyring
                	**type**\: str
                
                .. attribute:: local_address
                
                	Limit the keyring usage to a local address
                	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.LocalAddress>`
                
                .. attribute:: pre_shared_key
                
                	Pre\-Shared Key
                	**type**\:  :py:class:`PreSharedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.PreSharedKey>`
                
                .. attribute:: rsa_pubkey
                
                	Peer RSA public key chain management
                	**type**\:  :py:class:`RsaPubkey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.RsaPubkey>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Keyring.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "keyring"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("local-address", ("local_address", Native.Crypto.Keyring.Default.LocalAddress)), ("pre-shared-key", ("pre_shared_key", Native.Crypto.Keyring.Default.PreSharedKey)), ("rsa-pubkey", ("rsa_pubkey", Native.Crypto.Keyring.Default.RsaPubkey))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.local_address = Native.Crypto.Keyring.Default.LocalAddress()
                    self.local_address.parent = self
                    self._children_name_map["local_address"] = "local-address"

                    self.pre_shared_key = Native.Crypto.Keyring.Default.PreSharedKey()
                    self.pre_shared_key.parent = self
                    self._children_name_map["pre_shared_key"] = "pre-shared-key"

                    self.rsa_pubkey = Native.Crypto.Keyring.Default.RsaPubkey()
                    self.rsa_pubkey.parent = self
                    self._children_name_map["rsa_pubkey"] = "rsa-pubkey"
                    self._segment_path = lambda: "default"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Keyring.Default, ['description'], name, value)


                class LocalAddress(Entity):
                    """
                    Limit the keyring usage to a local address
                    
                    .. attribute:: bind_ip_address
                    
                    	Specify an IP address to bind to
                    	**type**\:  :py:class:`BindIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.LocalAddress.BindIpAddress>`
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.LocalAddress.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.LocalAddress.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.LocalAddress.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.LocalAddress.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.Default.LocalAddress, self).__init__()

                        self.yang_name = "local-address"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bind-ip-address", ("bind_ip_address", Native.Crypto.Keyring.Default.LocalAddress.BindIpAddress)), ("ATM-subinterface", ("atm_subinterface", Native.Crypto.Keyring.Default.LocalAddress.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Crypto.Keyring.Default.LocalAddress.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Crypto.Keyring.Default.LocalAddress.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Crypto.Keyring.Default.LocalAddress.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.bind_ip_address = Native.Crypto.Keyring.Default.LocalAddress.BindIpAddress()
                        self.bind_ip_address.parent = self
                        self._children_name_map["bind_ip_address"] = "bind-ip-address"

                        self.atm_subinterface = Native.Crypto.Keyring.Default.LocalAddress.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Crypto.Keyring.Default.LocalAddress.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Crypto.Keyring.Default.LocalAddress.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Crypto.Keyring.Default.LocalAddress.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "local-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.Default.LocalAddress, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class BindIpAddress(Entity):
                        """
                        Specify an IP address to bind to
                        
                        .. attribute:: ip_address
                        
                        	Specify an IP address to bind to
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vrf
                        
                        	F\-VRF of the address
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Keyring.Default.LocalAddress.BindIpAddress, self).__init__()

                            self.yang_name = "bind-ip-address"
                            self.yang_parent_name = "local-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.ip_address = None
                            self.vrf = None
                            self._segment_path = lambda: "bind-ip-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Keyring.Default.LocalAddress.BindIpAddress, ['ip_address', 'vrf'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Keyring.Default.LocalAddress.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "local-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Keyring.Default.LocalAddress.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Keyring.Default.LocalAddress.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "local-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Keyring.Default.LocalAddress.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Keyring.Default.LocalAddress.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "local-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Keyring.Default.LocalAddress.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Keyring.Default.LocalAddress.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "local-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Keyring.Default.LocalAddress.PortChannelSubinterface, [u'port_channel'], name, value)


                class PreSharedKey(Entity):
                    """
                    Pre\-Shared Key
                    
                    .. attribute:: address
                    
                    	pre shared key by address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.PreSharedKey.Address>`
                    
                    .. attribute:: hostname
                    
                    	hostname  define peer policy for hostname
                    	**type**\: list of  		 :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.PreSharedKey.Hostname>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.Default.PreSharedKey, self).__init__()

                        self.yang_name = "pre-shared-key"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Keyring.Default.PreSharedKey.Address)), ("hostname", ("hostname", Native.Crypto.Keyring.Default.PreSharedKey.Hostname))])
                        self._leafs = OrderedDict()

                        self.address = Native.Crypto.Keyring.Default.PreSharedKey.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"

                        self.hostname = YList(self)
                        self._segment_path = lambda: "pre-shared-key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.Default.PreSharedKey, [], name, value)


                    class Address(Entity):
                        """
                        pre shared key by address
                        
                        .. attribute:: ipv4
                        
                        	address prefix
                        	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.PreSharedKey.Address.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	define shared key with IPv6 address
                        	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.PreSharedKey.Address.Ipv6>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Keyring.Default.PreSharedKey.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "pre-shared-key"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Crypto.Keyring.Default.PreSharedKey.Address.Ipv4)), ("ipv6", ("ipv6", Native.Crypto.Keyring.Default.PreSharedKey.Address.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = YList(self)
                            self.ipv6 = YList(self)
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Keyring.Default.PreSharedKey.Address, [], name, value)


                        class Ipv4(Entity):
                            """
                            address prefix
                            
                            .. attribute:: ipv4_addr  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	address prefix mask
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	specify the key
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: encryption
                            
                            	
                            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.PreSharedKey.Address.Ipv4.Encryption>`
                            
                            .. attribute:: unencryt_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Keyring.Default.PreSharedKey.Address.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ('key', (YLeaf(YType.empty, 'key'), ['Empty'])),
                                    ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Keyring.Default.PreSharedKey.Address.Ipv4.Encryption')])),
                                    ('unencryt_key', (YLeaf(YType.str, 'unencryt-key'), ['str'])),
                                ])
                                self.ipv4_addr = None
                                self.mask = None
                                self.key = None
                                self.encryption = None
                                self.unencryt_key = None
                                self._segment_path = lambda: "ipv4" + "[ipv4-addr='" + str(self.ipv4_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Keyring.Default.PreSharedKey.Address.Ipv4, ['ipv4_addr', 'mask', 'key', 'encryption', 'unencryt_key'], name, value)

                            class Encryption(Enum):
                                """
                                Encryption (Enum Class)

                                .. data:: Y_0 = 0

                                .. data:: Y_6 = 1

                                """

                                Y_0 = Enum.YLeaf(0, "0")

                                Y_6 = Enum.YLeaf(1, "6")



                        class Ipv6(Entity):
                            """
                            define shared key with IPv6 address
                            
                            .. attribute:: ipv6_addr  (key)
                            
                            	IPv6 address prefix
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: key
                            
                            	specify the key
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: encryption
                            
                            	
                            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.PreSharedKey.Address.Ipv6.Encryption>`
                            
                            .. attribute:: unencryt_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Keyring.Default.PreSharedKey.Address.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv6_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                    ('key', (YLeaf(YType.empty, 'key'), ['Empty'])),
                                    ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Keyring.Default.PreSharedKey.Address.Ipv6.Encryption')])),
                                    ('unencryt_key', (YLeaf(YType.str, 'unencryt-key'), ['str'])),
                                ])
                                self.ipv6_addr = None
                                self.key = None
                                self.encryption = None
                                self.unencryt_key = None
                                self._segment_path = lambda: "ipv6" + "[ipv6-addr='" + str(self.ipv6_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Keyring.Default.PreSharedKey.Address.Ipv6, ['ipv6_addr', 'key', 'encryption', 'unencryt_key'], name, value)

                            class Encryption(Enum):
                                """
                                Encryption (Enum Class)

                                .. data:: Y_0 = 0

                                .. data:: Y_6 = 1

                                """

                                Y_0 = Enum.YLeaf(0, "0")

                                Y_6 = Enum.YLeaf(1, "6")



                    class Hostname(Entity):
                        """
                        hostname  define peer policy for hostname
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: key
                        
                        	specify the key
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: encryption
                        
                        	
                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.PreSharedKey.Hostname.Encryption>`
                        
                        .. attribute:: unencryt_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Keyring.Default.PreSharedKey.Hostname, self).__init__()

                            self.yang_name = "hostname"
                            self.yang_parent_name = "pre-shared-key"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('key', (YLeaf(YType.empty, 'key'), ['Empty'])),
                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Keyring.Default.PreSharedKey.Hostname.Encryption')])),
                                ('unencryt_key', (YLeaf(YType.str, 'unencryt-key'), ['str'])),
                            ])
                            self.name = None
                            self.key = None
                            self.encryption = None
                            self.unencryt_key = None
                            self._segment_path = lambda: "hostname" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Keyring.Default.PreSharedKey.Hostname, ['name', 'key', 'encryption', 'unencryt_key'], name, value)

                        class Encryption(Enum):
                            """
                            Encryption (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: Y_6 = 1

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_6 = Enum.YLeaf(1, "6")



                class RsaPubkey(Entity):
                    """
                    Peer RSA public key chain management
                    
                    .. attribute:: addr
                    
                    	
                    	**type**\:  :py:class:`Addr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.RsaPubkey.Addr>`
                    
                    .. attribute:: hostname
                    
                    	
                    	**type**\:  :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.RsaPubkey.Hostname>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.Default.RsaPubkey, self).__init__()

                        self.yang_name = "rsa-pubkey"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("addr", ("addr", Native.Crypto.Keyring.Default.RsaPubkey.Addr)), ("hostname", ("hostname", Native.Crypto.Keyring.Default.RsaPubkey.Hostname))])
                        self._leafs = OrderedDict()

                        self.addr = Native.Crypto.Keyring.Default.RsaPubkey.Addr()
                        self.addr.parent = self
                        self._children_name_map["addr"] = "addr"

                        self.hostname = Native.Crypto.Keyring.Default.RsaPubkey.Hostname()
                        self.hostname.parent = self
                        self._children_name_map["hostname"] = "hostname"
                        self._segment_path = lambda: "rsa-pubkey"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.Default.RsaPubkey, [], name, value)


                    class Addr(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	Public key associated with an address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: way
                        
                        	
                        	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.RsaPubkey.Addr.Way>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Keyring.Default.RsaPubkey.Addr, self).__init__()

                            self.yang_name = "addr"
                            self.yang_parent_name = "rsa-pubkey"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Keyring.Default.RsaPubkey.Addr.Way')])),
                            ])
                            self.address = None
                            self.way = None
                            self._segment_path = lambda: "addr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Keyring.Default.RsaPubkey.Addr, ['address', 'way'], name, value)

                        class Way(Enum):
                            """
                            Way (Enum Class)

                            .. data:: encryption = 0

                            .. data:: signature = 1

                            """

                            encryption = Enum.YLeaf(0, "encryption")

                            signature = Enum.YLeaf(1, "signature")



                    class Hostname(Entity):
                        """
                        
                        
                        .. attribute:: name
                        
                        	Public key associated with a hostname
                        	**type**\: str
                        
                        .. attribute:: way
                        
                        	
                        	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.Default.RsaPubkey.Hostname.Way>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Keyring.Default.RsaPubkey.Hostname, self).__init__()

                            self.yang_name = "hostname"
                            self.yang_parent_name = "rsa-pubkey"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Keyring.Default.RsaPubkey.Hostname.Way')])),
                            ])
                            self.name = None
                            self.way = None
                            self._segment_path = lambda: "hostname"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Keyring.Default.RsaPubkey.Hostname, ['name', 'way'], name, value)

                        class Way(Enum):
                            """
                            Way (Enum Class)

                            .. data:: encryption = 0

                            .. data:: signature = 1

                            """

                            encryption = Enum.YLeaf(0, "encryption")

                            signature = Enum.YLeaf(1, "signature")



            class LocalAddress(Entity):
                """
                Limit the keyring usage to a local address
                
                .. attribute:: bind_ip_address
                
                	Specify an IP address to bind to
                	**type**\:  :py:class:`BindIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.LocalAddress.BindIpAddress>`
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.LocalAddress.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.LocalAddress.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.LocalAddress.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.LocalAddress.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Keyring.LocalAddress, self).__init__()

                    self.yang_name = "local-address"
                    self.yang_parent_name = "keyring"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bind-ip-address", ("bind_ip_address", Native.Crypto.Keyring.LocalAddress.BindIpAddress)), ("ATM-subinterface", ("atm_subinterface", Native.Crypto.Keyring.LocalAddress.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Crypto.Keyring.LocalAddress.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Crypto.Keyring.LocalAddress.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Crypto.Keyring.LocalAddress.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.bind_ip_address = Native.Crypto.Keyring.LocalAddress.BindIpAddress()
                    self.bind_ip_address.parent = self
                    self._children_name_map["bind_ip_address"] = "bind-ip-address"

                    self.atm_subinterface = Native.Crypto.Keyring.LocalAddress.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.Crypto.Keyring.LocalAddress.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.Crypto.Keyring.LocalAddress.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.Crypto.Keyring.LocalAddress.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "local-address"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Keyring.LocalAddress, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class BindIpAddress(Entity):
                    """
                    Specify an IP address to bind to
                    
                    .. attribute:: ip_address
                    
                    	Specify an IP address to bind to
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vrf
                    
                    	F\-VRF of the address
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.LocalAddress.BindIpAddress, self).__init__()

                        self.yang_name = "bind-ip-address"
                        self.yang_parent_name = "local-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.ip_address = None
                        self.vrf = None
                        self._segment_path = lambda: "bind-ip-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.LocalAddress.BindIpAddress, ['ip_address', 'vrf'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.LocalAddress.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "local-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.LocalAddress.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.LocalAddress.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "local-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.LocalAddress.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.LocalAddress.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "local-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.LocalAddress.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.LocalAddress.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "local-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.LocalAddress.PortChannelSubinterface, [u'port_channel'], name, value)


            class PreSharedKey(Entity):
                """
                Pre\-Shared Key
                
                .. attribute:: address
                
                	pre shared key by address
                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.PreSharedKey.Address>`
                
                .. attribute:: hostname
                
                	hostname  define peer policy for hostname
                	**type**\: list of  		 :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.PreSharedKey.Hostname>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Keyring.PreSharedKey, self).__init__()

                    self.yang_name = "pre-shared-key"
                    self.yang_parent_name = "keyring"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Keyring.PreSharedKey.Address)), ("hostname", ("hostname", Native.Crypto.Keyring.PreSharedKey.Hostname))])
                    self._leafs = OrderedDict()

                    self.address = Native.Crypto.Keyring.PreSharedKey.Address()
                    self.address.parent = self
                    self._children_name_map["address"] = "address"

                    self.hostname = YList(self)
                    self._segment_path = lambda: "pre-shared-key"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Keyring.PreSharedKey, [], name, value)


                class Address(Entity):
                    """
                    pre shared key by address
                    
                    .. attribute:: ipv4
                    
                    	address prefix
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.PreSharedKey.Address.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	define shared key with IPv6 address
                    	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.PreSharedKey.Address.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.PreSharedKey.Address, self).__init__()

                        self.yang_name = "address"
                        self.yang_parent_name = "pre-shared-key"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Crypto.Keyring.PreSharedKey.Address.Ipv4)), ("ipv6", ("ipv6", Native.Crypto.Keyring.PreSharedKey.Address.Ipv6))])
                        self._leafs = OrderedDict()

                        self.ipv4 = YList(self)
                        self.ipv6 = YList(self)
                        self._segment_path = lambda: "address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.PreSharedKey.Address, [], name, value)


                    class Ipv4(Entity):
                        """
                        address prefix
                        
                        .. attribute:: ipv4_addr  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	address prefix mask
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: key
                        
                        	specify the key
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: encryption
                        
                        	
                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.PreSharedKey.Address.Ipv4.Encryption>`
                        
                        .. attribute:: unencryt_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Keyring.PreSharedKey.Address.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv4_addr']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('key', (YLeaf(YType.empty, 'key'), ['Empty'])),
                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Keyring.PreSharedKey.Address.Ipv4.Encryption')])),
                                ('unencryt_key', (YLeaf(YType.str, 'unencryt-key'), ['str'])),
                            ])
                            self.ipv4_addr = None
                            self.mask = None
                            self.key = None
                            self.encryption = None
                            self.unencryt_key = None
                            self._segment_path = lambda: "ipv4" + "[ipv4-addr='" + str(self.ipv4_addr) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Keyring.PreSharedKey.Address.Ipv4, ['ipv4_addr', 'mask', 'key', 'encryption', 'unencryt_key'], name, value)

                        class Encryption(Enum):
                            """
                            Encryption (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: Y_6 = 1

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_6 = Enum.YLeaf(1, "6")



                    class Ipv6(Entity):
                        """
                        define shared key with IPv6 address
                        
                        .. attribute:: ipv6_addr  (key)
                        
                        	IPv6 address prefix
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: key
                        
                        	specify the key
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: encryption
                        
                        	
                        	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.PreSharedKey.Address.Ipv6.Encryption>`
                        
                        .. attribute:: unencryt_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Keyring.PreSharedKey.Address.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv6_addr']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                ('key', (YLeaf(YType.empty, 'key'), ['Empty'])),
                                ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Keyring.PreSharedKey.Address.Ipv6.Encryption')])),
                                ('unencryt_key', (YLeaf(YType.str, 'unencryt-key'), ['str'])),
                            ])
                            self.ipv6_addr = None
                            self.key = None
                            self.encryption = None
                            self.unencryt_key = None
                            self._segment_path = lambda: "ipv6" + "[ipv6-addr='" + str(self.ipv6_addr) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Keyring.PreSharedKey.Address.Ipv6, ['ipv6_addr', 'key', 'encryption', 'unencryt_key'], name, value)

                        class Encryption(Enum):
                            """
                            Encryption (Enum Class)

                            .. data:: Y_0 = 0

                            .. data:: Y_6 = 1

                            """

                            Y_0 = Enum.YLeaf(0, "0")

                            Y_6 = Enum.YLeaf(1, "6")



                class Hostname(Entity):
                    """
                    hostname  define peer policy for hostname
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: key
                    
                    	specify the key
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: encryption
                    
                    	
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.PreSharedKey.Hostname.Encryption>`
                    
                    .. attribute:: unencryt_key
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.PreSharedKey.Hostname, self).__init__()

                        self.yang_name = "hostname"
                        self.yang_parent_name = "pre-shared-key"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('key', (YLeaf(YType.empty, 'key'), ['Empty'])),
                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Keyring.PreSharedKey.Hostname.Encryption')])),
                            ('unencryt_key', (YLeaf(YType.str, 'unencryt-key'), ['str'])),
                        ])
                        self.name = None
                        self.key = None
                        self.encryption = None
                        self.unencryt_key = None
                        self._segment_path = lambda: "hostname" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.PreSharedKey.Hostname, ['name', 'key', 'encryption', 'unencryt_key'], name, value)

                    class Encryption(Enum):
                        """
                        Encryption (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_6 = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_6 = Enum.YLeaf(1, "6")



            class RsaPubkey(Entity):
                """
                Peer RSA public key chain management
                
                .. attribute:: addr
                
                	
                	**type**\:  :py:class:`Addr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.RsaPubkey.Addr>`
                
                .. attribute:: hostname
                
                	
                	**type**\:  :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.RsaPubkey.Hostname>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Keyring.RsaPubkey, self).__init__()

                    self.yang_name = "rsa-pubkey"
                    self.yang_parent_name = "keyring"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("addr", ("addr", Native.Crypto.Keyring.RsaPubkey.Addr)), ("hostname", ("hostname", Native.Crypto.Keyring.RsaPubkey.Hostname))])
                    self._leafs = OrderedDict()

                    self.addr = Native.Crypto.Keyring.RsaPubkey.Addr()
                    self.addr.parent = self
                    self._children_name_map["addr"] = "addr"

                    self.hostname = Native.Crypto.Keyring.RsaPubkey.Hostname()
                    self.hostname.parent = self
                    self._children_name_map["hostname"] = "hostname"
                    self._segment_path = lambda: "rsa-pubkey"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Keyring.RsaPubkey, [], name, value)


                class Addr(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	Public key associated with an address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: way
                    
                    	
                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.RsaPubkey.Addr.Way>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.RsaPubkey.Addr, self).__init__()

                        self.yang_name = "addr"
                        self.yang_parent_name = "rsa-pubkey"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Keyring.RsaPubkey.Addr.Way')])),
                        ])
                        self.address = None
                        self.way = None
                        self._segment_path = lambda: "addr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.RsaPubkey.Addr, ['address', 'way'], name, value)

                    class Way(Enum):
                        """
                        Way (Enum Class)

                        .. data:: encryption = 0

                        .. data:: signature = 1

                        """

                        encryption = Enum.YLeaf(0, "encryption")

                        signature = Enum.YLeaf(1, "signature")



                class Hostname(Entity):
                    """
                    
                    
                    .. attribute:: name
                    
                    	Public key associated with a hostname
                    	**type**\: str
                    
                    .. attribute:: way
                    
                    	
                    	**type**\:  :py:class:`Way <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Keyring.RsaPubkey.Hostname.Way>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Keyring.RsaPubkey.Hostname, self).__init__()

                        self.yang_name = "hostname"
                        self.yang_parent_name = "rsa-pubkey"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('way', (YLeaf(YType.enumeration, 'way'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Keyring.RsaPubkey.Hostname.Way')])),
                        ])
                        self.name = None
                        self.way = None
                        self._segment_path = lambda: "hostname"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Keyring.RsaPubkey.Hostname, ['name', 'way'], name, value)

                    class Way(Enum):
                        """
                        Way (Enum Class)

                        .. data:: encryption = 0

                        .. data:: signature = 1

                        """

                        encryption = Enum.YLeaf(0, "encryption")

                        signature = Enum.YLeaf(1, "signature")



        class Isakmp(Entity):
            """
            Configure ISAKMP policy
            
            .. attribute:: aggressive_mode
            
            	Disable ISAKMP aggressive mode
            	**type**\:  :py:class:`AggressiveMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.AggressiveMode>`
            
            .. attribute:: client
            
            	Set client configuration policy
            	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client>`
            
            .. attribute:: default
            
            	ISAKMP default policy
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Default>`
            
            .. attribute:: disconnect_revoked_peers
            
            	Disconnect Crypto Session with Revoked Peer
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: enable
            
            	Enable ISAKMP
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: fragmentation
            
            	IKE Fragmentation enabled if required
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: identity
            
            	Set the identity which ISAKMP will use
            	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Identity>`
            
            .. attribute:: invalid_spi_recovery
            
            	Initiate IKE and send Invalid SPI Notify
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: keepalive
            
            	Set a keepalive interval for use with IOS peers
            	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Keepalive>`
            
            .. attribute:: key
            
            	Set pre\-shared key for remote peer
            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Key>`
            
            .. attribute:: nat
            
            	Set a nat  keepalive interval for use with IOS peers
            	**type**\:  :py:class:`Nat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Nat>`
            
            .. attribute:: peer
            
            	Set Peer Policy
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer>`
            
            .. attribute:: policy
            
            	Set policy for an ISAKMP protection suite
            	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy>`
            
            .. attribute:: profile
            
            	Define ISAKMP Profiles
            	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile>`
            
            .. attribute:: xauth
            
            	Set Extended Authentication values
            	**type**\:  :py:class:`Xauth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Xauth>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Isakmp, self).__init__()

                self.yang_name = "isakmp"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("client", ("client", Native.Crypto.Isakmp.Client)), ("default", ("default", Native.Crypto.Isakmp.Default)), ("keepalive", ("keepalive", Native.Crypto.Isakmp.Keepalive)), ("key", ("key", Native.Crypto.Isakmp.Key)), ("nat", ("nat", Native.Crypto.Isakmp.Nat)), ("peer", ("peer", Native.Crypto.Isakmp.Peer)), ("policy", ("policy", Native.Crypto.Isakmp.Policy)), ("profile", ("profile", Native.Crypto.Isakmp.Profile)), ("xauth", ("xauth", Native.Crypto.Isakmp.Xauth))])
                self._leafs = OrderedDict([
                    ('aggressive_mode', (YLeaf(YType.enumeration, 'aggressive-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.AggressiveMode')])),
                    ('disconnect_revoked_peers', (YLeaf(YType.empty, 'disconnect-revoked-peers'), ['Empty'])),
                    ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ('fragmentation', (YLeaf(YType.empty, 'fragmentation'), ['Empty'])),
                    ('identity', (YLeaf(YType.enumeration, 'identity'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Identity')])),
                    ('invalid_spi_recovery', (YLeaf(YType.empty, 'invalid-spi-recovery'), ['Empty'])),
                ])
                self.aggressive_mode = None
                self.disconnect_revoked_peers = None
                self.enable = None
                self.fragmentation = None
                self.identity = None
                self.invalid_spi_recovery = None

                self.client = Native.Crypto.Isakmp.Client()
                self.client.parent = self
                self._children_name_map["client"] = "client"

                self.default = Native.Crypto.Isakmp.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.keepalive = Native.Crypto.Isakmp.Keepalive()
                self.keepalive.parent = self
                self._children_name_map["keepalive"] = "keepalive"

                self.key = Native.Crypto.Isakmp.Key()
                self.key.parent = self
                self._children_name_map["key"] = "key"

                self.nat = Native.Crypto.Isakmp.Nat()
                self.nat.parent = self
                self._children_name_map["nat"] = "nat"

                self.peer = Native.Crypto.Isakmp.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.xauth = Native.Crypto.Isakmp.Xauth()
                self.xauth.parent = self
                self._children_name_map["xauth"] = "xauth"

                self.policy = YList(self)
                self.profile = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:isakmp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Isakmp, ['aggressive_mode', 'disconnect_revoked_peers', 'enable', 'fragmentation', 'identity', 'invalid_spi_recovery'], name, value)

            class AggressiveMode(Enum):
                """
                AggressiveMode (Enum Class)

                Disable ISAKMP aggressive mode

                .. data:: disable = 0

                """

                disable = Enum.YLeaf(0, "disable")


            class Identity(Enum):
                """
                Identity (Enum Class)

                Set the identity which ISAKMP will use

                .. data:: address = 0

                .. data:: dn = 1

                .. data:: hostname = 2

                """

                address = Enum.YLeaf(0, "address")

                dn = Enum.YLeaf(1, "dn")

                hostname = Enum.YLeaf(2, "hostname")



            class Client(Entity):
                """
                Set client configuration policy
                
                .. attribute:: configuration
                
                	Set client configuration policy
                	**type**\:  :py:class:`Configuration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration>`
                
                .. attribute:: firewall
                
                	Define client firewall
                	**type**\: list of  		 :py:class:`Firewall <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Firewall>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Isakmp.Client, self).__init__()

                    self.yang_name = "client"
                    self.yang_parent_name = "isakmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("configuration", ("configuration", Native.Crypto.Isakmp.Client.Configuration)), ("firewall", ("firewall", Native.Crypto.Isakmp.Client.Firewall))])
                    self._leafs = OrderedDict()

                    self.configuration = Native.Crypto.Isakmp.Client.Configuration()
                    self.configuration.parent = self
                    self._children_name_map["configuration"] = "configuration"

                    self.firewall = YList(self)
                    self._segment_path = lambda: "client"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Isakmp.Client, [], name, value)


                class Configuration(Entity):
                    """
                    Set client configuration policy
                    
                    .. attribute:: address_pool
                    
                    	Set network address for client
                    	**type**\:  :py:class:`AddressPool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.AddressPool>`
                    
                    .. attribute:: browser_proxy
                    
                    	Set browser proxy attributes for client
                    	**type**\: str
                    
                    .. attribute:: group
                    
                    	Set group profile attributes for client
                    	**type**\: list of  		 :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Client.Configuration, self).__init__()

                        self.yang_name = "configuration"
                        self.yang_parent_name = "client"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address-pool", ("address_pool", Native.Crypto.Isakmp.Client.Configuration.AddressPool)), ("group", ("group", Native.Crypto.Isakmp.Client.Configuration.Group))])
                        self._leafs = OrderedDict([
                            ('browser_proxy', (YLeaf(YType.str, 'browser-proxy'), ['str'])),
                        ])
                        self.browser_proxy = None

                        self.address_pool = Native.Crypto.Isakmp.Client.Configuration.AddressPool()
                        self.address_pool.parent = self
                        self._children_name_map["address_pool"] = "address-pool"

                        self.group = YList(self)
                        self._segment_path = lambda: "configuration"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/client/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration, ['browser_proxy'], name, value)


                    class AddressPool(Entity):
                        """
                        Set network address for client
                        
                        .. attribute:: local
                        
                        	Set a local address pool for clients
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Client.Configuration.AddressPool, self).__init__()

                            self.yang_name = "address-pool"
                            self.yang_parent_name = "configuration"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local', (YLeaf(YType.str, 'local'), ['str'])),
                            ])
                            self.local = None
                            self._segment_path = lambda: "address-pool"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/client/configuration/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.AddressPool, ['local'], name, value)


                    class Group(Entity):
                        """
                        Set group profile attributes for client
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: access_restrict
                        
                        	Restrict clients in this group to an interface
                        	**type**\: str
                        
                        .. attribute:: acl
                        
                        	Specify split tunneling inclusion access\-list number
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 100..199
                        
                        		**type**\: str
                        
                        			**pattern:** [a\-zA\-Z].\*
                        
                        .. attribute:: auto_update
                        
                        	Configure auto\-upgrade
                        	**type**\:  :py:class:`AutoUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.AutoUpdate>`
                        
                        .. attribute:: backup_gateway
                        
                        	Specify backup gateway
                        	**type**\: str
                        
                        .. attribute:: browser_proxy
                        
                        	Configure browser\-proxy
                        	**type**\: str
                        
                        .. attribute:: configuration
                        
                        	Push configuration to the client
                        	**type**\:  :py:class:`Configuration_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.Configuration_>`
                        
                        .. attribute:: crypto
                        
                        	Client group crypto aaa attribute list
                        	**type**\:  :py:class:`Crypto_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_>`
                        
                        .. attribute:: dhcp
                        
                        	Configure DHCP parameters
                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.Dhcp>`
                        
                        .. attribute:: dns
                        
                        	Specify DNS Addresses
                        	**type**\:  :py:class:`Dns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.Dns>`
                        
                        .. attribute:: domain
                        
                        	Set default domain name to send to client
                        	**type**\: str
                        
                        .. attribute:: firewall
                        
                        	Enforce group firewall feature
                        	**type**\:  :py:class:`Firewall <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.Firewall>`
                        
                        .. attribute:: group_lock
                        
                        	Enforce group lock feature
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: include_local_lan
                        
                        	Enable Local LAN Access with no split tunnel
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: key
                        
                        	pre\-shared key/IKE password
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.Key>`
                        
                        .. attribute:: max_logins
                        
                        	Set maximum simultaneous logins for users in this group
                        	**type**\: int
                        
                        	**range:** 1..10
                        
                        .. attribute:: max_users
                        
                        	Set maximum number of users for this group
                        	**type**\: int
                        
                        	**range:** 1..5000
                        
                        .. attribute:: netmask
                        
                        	netmask used by the client for local connectivity
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pfs
                        
                        	The client should propose PFS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pool
                        
                        	Set name of address pool
                        	**type**\: str
                        
                        .. attribute:: save_password
                        
                        	Allows remote client to save XAUTH password
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: smartcard_removal_disconnect
                        
                        	Enables smartcard\-removal\-disconnect
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: split_dns
                        
                        	DNS name to append for resolution
                        	**type**\: str
                        
                        .. attribute:: wins
                        
                        	Specify WINS Addresses
                        	**type**\:  :py:class:`Wins <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.Wins>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Client.Configuration.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "configuration"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("auto-update", ("auto_update", Native.Crypto.Isakmp.Client.Configuration.Group.AutoUpdate)), ("configuration", ("configuration", Native.Crypto.Isakmp.Client.Configuration.Group.Configuration_)), ("crypto", ("crypto", Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_)), ("dhcp", ("dhcp", Native.Crypto.Isakmp.Client.Configuration.Group.Dhcp)), ("dns", ("dns", Native.Crypto.Isakmp.Client.Configuration.Group.Dns)), ("firewall", ("firewall", Native.Crypto.Isakmp.Client.Configuration.Group.Firewall)), ("key", ("key", Native.Crypto.Isakmp.Client.Configuration.Group.Key)), ("wins", ("wins", Native.Crypto.Isakmp.Client.Configuration.Group.Wins))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('access_restrict', (YLeaf(YType.str, 'access-restrict'), ['str'])),
                                ('acl', (YLeaf(YType.str, 'acl'), ['int','str'])),
                                ('backup_gateway', (YLeaf(YType.str, 'backup-gateway'), ['str'])),
                                ('browser_proxy', (YLeaf(YType.str, 'browser-proxy'), ['str'])),
                                ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                ('group_lock', (YLeaf(YType.empty, 'group-lock'), ['Empty'])),
                                ('include_local_lan', (YLeaf(YType.empty, 'include-local-lan'), ['Empty'])),
                                ('max_logins', (YLeaf(YType.uint8, 'max-logins'), ['int'])),
                                ('max_users', (YLeaf(YType.uint32, 'max-users'), ['int'])),
                                ('netmask', (YLeaf(YType.str, 'netmask'), ['str'])),
                                ('pfs', (YLeaf(YType.empty, 'pfs'), ['Empty'])),
                                ('pool', (YLeaf(YType.str, 'pool'), ['str'])),
                                ('save_password', (YLeaf(YType.empty, 'save-password'), ['Empty'])),
                                ('smartcard_removal_disconnect', (YLeaf(YType.empty, 'smartcard-removal-disconnect'), ['Empty'])),
                                ('split_dns', (YLeaf(YType.str, 'split-dns'), ['str'])),
                            ])
                            self.name = None
                            self.access_restrict = None
                            self.acl = None
                            self.backup_gateway = None
                            self.browser_proxy = None
                            self.domain = None
                            self.group_lock = None
                            self.include_local_lan = None
                            self.max_logins = None
                            self.max_users = None
                            self.netmask = None
                            self.pfs = None
                            self.pool = None
                            self.save_password = None
                            self.smartcard_removal_disconnect = None
                            self.split_dns = None

                            self.auto_update = Native.Crypto.Isakmp.Client.Configuration.Group.AutoUpdate()
                            self.auto_update.parent = self
                            self._children_name_map["auto_update"] = "auto-update"

                            self.configuration = Native.Crypto.Isakmp.Client.Configuration.Group.Configuration_()
                            self.configuration.parent = self
                            self._children_name_map["configuration"] = "configuration"

                            self.crypto = Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_()
                            self.crypto.parent = self
                            self._children_name_map["crypto"] = "crypto"

                            self.dhcp = Native.Crypto.Isakmp.Client.Configuration.Group.Dhcp()
                            self.dhcp.parent = self
                            self._children_name_map["dhcp"] = "dhcp"

                            self.dns = Native.Crypto.Isakmp.Client.Configuration.Group.Dns()
                            self.dns.parent = self
                            self._children_name_map["dns"] = "dns"

                            self.firewall = Native.Crypto.Isakmp.Client.Configuration.Group.Firewall()
                            self.firewall.parent = self
                            self._children_name_map["firewall"] = "firewall"

                            self.key = Native.Crypto.Isakmp.Client.Configuration.Group.Key()
                            self.key.parent = self
                            self._children_name_map["key"] = "key"

                            self.wins = Native.Crypto.Isakmp.Client.Configuration.Group.Wins()
                            self.wins.parent = self
                            self._children_name_map["wins"] = "wins"
                            self._segment_path = lambda: "group" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/client/configuration/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.Group, ['name', 'access_restrict', 'acl', 'backup_gateway', 'browser_proxy', 'domain', 'group_lock', 'include_local_lan', 'max_logins', 'max_users', 'netmask', 'pfs', 'pool', 'save_password', 'smartcard_removal_disconnect', 'split_dns'], name, value)


                        class AutoUpdate(Entity):
                            """
                            Configure auto\-upgrade
                            
                            .. attribute:: client
                            
                            	Configure client
                            	**type**\: str
                            
                            .. attribute:: url
                            
                            	Configure URL to download from
                            	**type**\: str
                            
                            .. attribute:: rev
                            
                            	Use comma delimited list of revision strings only
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Client.Configuration.Group.AutoUpdate, self).__init__()

                                self.yang_name = "auto-update"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('client', (YLeaf(YType.str, 'client'), ['str'])),
                                    ('url', (YLeaf(YType.str, 'url'), ['str'])),
                                    ('rev', (YLeaf(YType.str, 'rev'), ['str'])),
                                ])
                                self.client = None
                                self.url = None
                                self.rev = None
                                self._segment_path = lambda: "auto-update"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.Group.AutoUpdate, ['client', 'url', 'rev'], name, value)


                        class Configuration_(Entity):
                            """
                            Push configuration to the client
                            
                            .. attribute:: url
                            
                            	URL for the client to fetch configuration
                            	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.Configuration_.Url>`
                            
                            .. attribute:: version
                            
                            	version of the configuration available at the URL
                            	**type**\: int
                            
                            	**range:** 1..32767
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Client.Configuration.Group.Configuration_, self).__init__()

                                self.yang_name = "configuration"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('url', (YLeaf(YType.enumeration, 'url'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Client.Configuration.Group.Configuration_.Url')])),
                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                ])
                                self.url = None
                                self.version = None
                                self._segment_path = lambda: "configuration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.Group.Configuration_, ['url', 'version'], name, value)

                            class Url(Enum):
                                """
                                Url (Enum Class)

                                URL for the client to fetch configuration

                                .. data:: bootflash__COLON__ = 0

                                .. data:: cns__COLON__ = 1

                                .. data:: flash__COLON__ = 2

                                .. data:: ftp__COLON__ = 3

                                .. data:: http__COLON__ = 4

                                .. data:: https__COLON__ = 5

                                .. data:: null__COLON__ = 6

                                .. data:: nvram__COLON__ = 7

                                .. data:: pram__COLON__ = 8

                                .. data:: rcp__COLON__ = 9

                                .. data:: scp__COLON__ = 10

                                .. data:: system__COLON__ = 11

                                .. data:: tar__COLON__ = 12

                                .. data:: tftp__COLON__ = 13

                                .. data:: tmpsys__COLON__ = 14

                                """

                                bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                                cns__COLON__ = Enum.YLeaf(1, "cns:")

                                flash__COLON__ = Enum.YLeaf(2, "flash:")

                                ftp__COLON__ = Enum.YLeaf(3, "ftp:")

                                http__COLON__ = Enum.YLeaf(4, "http:")

                                https__COLON__ = Enum.YLeaf(5, "https:")

                                null__COLON__ = Enum.YLeaf(6, "null:")

                                nvram__COLON__ = Enum.YLeaf(7, "nvram:")

                                pram__COLON__ = Enum.YLeaf(8, "pram:")

                                rcp__COLON__ = Enum.YLeaf(9, "rcp:")

                                scp__COLON__ = Enum.YLeaf(10, "scp:")

                                system__COLON__ = Enum.YLeaf(11, "system:")

                                tar__COLON__ = Enum.YLeaf(12, "tar:")

                                tftp__COLON__ = Enum.YLeaf(13, "tftp:")

                                tmpsys__COLON__ = Enum.YLeaf(14, "tmpsys:")



                        class Crypto_(Entity):
                            """
                            Client group crypto aaa attribute list
                            
                            .. attribute:: aaa
                            
                            	AAA directive
                            	**type**\:  :py:class:`Aaa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_.Aaa>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_, self).__init__()

                                self.yang_name = "crypto"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aaa", ("aaa", Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_.Aaa))])
                                self._leafs = OrderedDict()

                                self.aaa = Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_.Aaa()
                                self.aaa.parent = self
                                self._children_name_map["aaa"] = "aaa"
                                self._segment_path = lambda: "crypto"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_, [], name, value)


                            class Aaa(Entity):
                                """
                                AAA directive
                                
                                .. attribute:: attribute
                                
                                	AAA attribute directive
                                	**type**\:  :py:class:`Attribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_.Aaa.Attribute>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_.Aaa, self).__init__()

                                    self.yang_name = "aaa"
                                    self.yang_parent_name = "crypto"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("attribute", ("attribute", Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_.Aaa.Attribute))])
                                    self._leafs = OrderedDict()

                                    self.attribute = Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_.Aaa.Attribute()
                                    self.attribute.parent = self
                                    self._children_name_map["attribute"] = "attribute"
                                    self._segment_path = lambda: "aaa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_.Aaa, [], name, value)


                                class Attribute(Entity):
                                    """
                                    AAA attribute directive
                                    
                                    .. attribute:: list
                                    
                                    	AAA attribute list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_.Aaa.Attribute, self).__init__()

                                        self.yang_name = "attribute"
                                        self.yang_parent_name = "aaa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('list', (YLeaf(YType.str, 'list'), ['str'])),
                                        ])
                                        self.list = None
                                        self._segment_path = lambda: "attribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.Group.Crypto_.Aaa.Attribute, ['list'], name, value)


                        class Dhcp(Entity):
                            """
                            Configure DHCP parameters
                            
                            .. attribute:: giaddr
                            
                            	Specify giaddr for dhcp scope
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: server
                            
                            	Specify dhcp server
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            .. attribute:: timeout
                            
                            	Configure DHCP response timeout in seconds
                            	**type**\: int
                            
                            	**range:** 4..30
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Client.Configuration.Group.Dhcp, self).__init__()

                                self.yang_name = "dhcp"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('giaddr', (YLeaf(YType.str, 'giaddr'), ['str'])),
                                    ('server', (YLeaf(YType.str, 'server'), ['str','str'])),
                                    ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                                ])
                                self.giaddr = None
                                self.server = None
                                self.timeout = None
                                self._segment_path = lambda: "dhcp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.Group.Dhcp, ['giaddr', 'server', 'timeout'], name, value)


                        class Dns(Entity):
                            """
                            Specify DNS Addresses
                            
                            .. attribute:: primary
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Client.Configuration.Group.Dns, self).__init__()

                                self.yang_name = "dns"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary', (YLeaf(YType.str, 'primary'), ['str'])),
                                    ('secondary', (YLeaf(YType.str, 'secondary'), ['str'])),
                                ])
                                self.primary = None
                                self.secondary = None
                                self._segment_path = lambda: "dns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.Group.Dns, ['primary', 'secondary'], name, value)


                        class Firewall(Entity):
                            """
                            Enforce group firewall feature
                            
                            .. attribute:: are_u_there
                            
                            	firewall attribute, are\-u\-there
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: policy
                            
                            	Specify firewall policy
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Client.Configuration.Group.Firewall, self).__init__()

                                self.yang_name = "firewall"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('are_u_there', (YLeaf(YType.empty, 'are-u-there'), ['Empty'])),
                                    ('policy', (YLeaf(YType.str, 'policy'), ['str'])),
                                ])
                                self.are_u_there = None
                                self.policy = None
                                self._segment_path = lambda: "firewall"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.Group.Firewall, ['are_u_there', 'policy'], name, value)


                        class Key(Entity):
                            """
                            pre\-shared key/IKE password
                            
                            .. attribute:: encryption
                            
                            	
                            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Configuration.Group.Key.Encryption>`
                            
                            .. attribute:: key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Client.Configuration.Group.Key, self).__init__()

                                self.yang_name = "key"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Client.Configuration.Group.Key.Encryption')])),
                                    ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                ])
                                self.encryption = None
                                self.key = None
                                self._segment_path = lambda: "key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.Group.Key, ['encryption', 'key'], name, value)

                            class Encryption(Enum):
                                """
                                Encryption (Enum Class)

                                .. data:: Y_0 = 0

                                .. data:: Y_6 = 1

                                """

                                Y_0 = Enum.YLeaf(0, "0")

                                Y_6 = Enum.YLeaf(1, "6")



                        class Wins(Entity):
                            """
                            Specify WINS Addresses
                            
                            .. attribute:: primary
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: secondary
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Client.Configuration.Group.Wins, self).__init__()

                                self.yang_name = "wins"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('primary', (YLeaf(YType.str, 'primary'), ['str'])),
                                    ('secondary', (YLeaf(YType.str, 'secondary'), ['str'])),
                                ])
                                self.primary = None
                                self.secondary = None
                                self._segment_path = lambda: "wins"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Client.Configuration.Group.Wins, ['primary', 'secondary'], name, value)


                class Firewall(Entity):
                    """
                    Define client firewall
                    
                    .. attribute:: policy_name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: optional
                    
                    	firewall policy is optional
                    	**type**\:  :py:class:`Optional <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Firewall.Optional>`
                    
                    .. attribute:: required
                    
                    	firewall policy is mandatory
                    	**type**\:  :py:class:`Required <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Firewall.Required>`
                    
                    .. attribute:: policy
                    
                    	Define Cisco firewall Policy
                    	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Firewall.Policy>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Client.Firewall, self).__init__()

                        self.yang_name = "firewall"
                        self.yang_parent_name = "client"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['policy_name']
                        self._child_classes = OrderedDict([("policy", ("policy", Native.Crypto.Isakmp.Client.Firewall.Policy))])
                        self._leafs = OrderedDict([
                            ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                            ('optional', (YLeaf(YType.enumeration, 'optional'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Client.Firewall.Optional')])),
                            ('required', (YLeaf(YType.enumeration, 'required'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Client.Firewall.Required')])),
                        ])
                        self.policy_name = None
                        self.optional = None
                        self.required = None

                        self.policy = Native.Crypto.Isakmp.Client.Firewall.Policy()
                        self.policy.parent = self
                        self._children_name_map["policy"] = "policy"
                        self._segment_path = lambda: "firewall" + "[policy-name='" + str(self.policy_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/client/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Client.Firewall, ['policy_name', 'optional', 'required'], name, value)

                    class Optional(Enum):
                        """
                        Optional (Enum Class)

                        firewall policy is optional

                        .. data:: cisco_integrated_client_firewall = 0

                        .. data:: cisco_security_agent = 1

                        .. data:: zonelabs_zonealarm = 2

                        .. data:: zonelabs_zonealarmpro = 3

                        """

                        cisco_integrated_client_firewall = Enum.YLeaf(0, "cisco-integrated-client-firewall")

                        cisco_security_agent = Enum.YLeaf(1, "cisco-security-agent")

                        zonelabs_zonealarm = Enum.YLeaf(2, "zonelabs-zonealarm")

                        zonelabs_zonealarmpro = Enum.YLeaf(3, "zonelabs-zonealarmpro")


                    class Required(Enum):
                        """
                        Required (Enum Class)

                        firewall policy is mandatory

                        .. data:: cisco_integrated_client_firewall = 0

                        .. data:: cisco_security_agent = 1

                        .. data:: zonelabs_zonealarm = 2

                        .. data:: zonelabs_zonealarmpro = 3

                        """

                        cisco_integrated_client_firewall = Enum.YLeaf(0, "cisco-integrated-client-firewall")

                        cisco_security_agent = Enum.YLeaf(1, "cisco-security-agent")

                        zonelabs_zonealarm = Enum.YLeaf(2, "zonelabs-zonealarm")

                        zonelabs_zonealarmpro = Enum.YLeaf(3, "zonelabs-zonealarmpro")



                    class Policy(Entity):
                        """
                        Define Cisco firewall Policy
                        
                        .. attribute:: central_policy_push
                        
                        	Define Cisco Protection Policy
                        	**type**\:  :py:class:`CentralPolicyPush <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush>`
                        
                        .. attribute:: check_presence
                        
                        	Define firewall are\-you\-there policy
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Client.Firewall.Policy, self).__init__()

                            self.yang_name = "policy"
                            self.yang_parent_name = "firewall"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("central-policy-push", ("central_policy_push", Native.Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush))])
                            self._leafs = OrderedDict([
                                ('check_presence', (YLeaf(YType.empty, 'check-presence'), ['Empty'])),
                            ])
                            self.check_presence = None

                            self.central_policy_push = Native.Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush()
                            self.central_policy_push.parent = self
                            self._children_name_map["central_policy_push"] = "central-policy-push"
                            self._segment_path = lambda: "policy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Client.Firewall.Policy, ['check_presence'], name, value)


                        class CentralPolicyPush(Entity):
                            """
                            Define Cisco Protection Policy
                            
                            .. attribute:: access_list
                            
                            	Specify access list
                            	**type**\:  :py:class:`AccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush.AccessList>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush, self).__init__()

                                self.yang_name = "central-policy-push"
                                self.yang_parent_name = "policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("access-list", ("access_list", Native.Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush.AccessList))])
                                self._leafs = OrderedDict()

                                self.access_list = Native.Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush.AccessList()
                                self.access_list.parent = self
                                self._children_name_map["access_list"] = "access-list"
                                self._segment_path = lambda: "central-policy-push"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush, [], name, value)


                            class AccessList(Entity):
                                """
                                Specify access list
                                
                                .. attribute:: direction
                                
                                	
                                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush.AccessList.Direction>`
                                
                                .. attribute:: acl
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 100..199
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush.AccessList, self).__init__()

                                    self.yang_name = "access-list"
                                    self.yang_parent_name = "central-policy-push"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush.AccessList.Direction')])),
                                        ('acl', (YLeaf(YType.str, 'acl'), ['int','str'])),
                                    ])
                                    self.direction = None
                                    self.acl = None
                                    self._segment_path = lambda: "access-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Client.Firewall.Policy.CentralPolicyPush.AccessList, ['direction', 'acl'], name, value)

                                class Direction(Enum):
                                    """
                                    Direction (Enum Class)

                                    .. data:: in_ = 0

                                    .. data:: out = 1

                                    """

                                    in_ = Enum.YLeaf(0, "in")

                                    out = Enum.YLeaf(1, "out")



            class Default(Entity):
                """
                ISAKMP default policy
                
                .. attribute:: policy
                
                	Enable default policies for ISAKMP protection suite
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Isakmp.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "isakmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('policy', (YLeaf(YType.empty, 'policy'), ['Empty'])),
                    ])
                    self.policy = None
                    self._segment_path = lambda: "default"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Isakmp.Default, ['policy'], name, value)


            class Keepalive(Entity):
                """
                Set a keepalive interval for use with IOS peers
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 10..3600
                
                .. attribute:: retry_number
                
                	
                	**type**\: int
                
                	**range:** 2..60
                
                .. attribute:: send
                
                	
                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Keepalive.Send>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Isakmp.Keepalive, self).__init__()

                    self.yang_name = "keepalive"
                    self.yang_parent_name = "isakmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('retry_number', (YLeaf(YType.uint8, 'retry-number'), ['int'])),
                        ('send', (YLeaf(YType.enumeration, 'send'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Keepalive.Send')])),
                    ])
                    self.number = None
                    self.retry_number = None
                    self.send = None
                    self._segment_path = lambda: "keepalive"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Isakmp.Keepalive, ['number', 'retry_number', 'send'], name, value)

                class Send(Enum):
                    """
                    Send (Enum Class)

                    .. data:: on_demand = 0

                    .. data:: periodic = 1

                    """

                    on_demand = Enum.YLeaf(0, "on-demand")

                    periodic = Enum.YLeaf(1, "periodic")



            class Key(Entity):
                """
                Set pre\-shared key for remote peer
                
                .. attribute:: key_address
                
                	
                	**type**\:  :py:class:`KeyAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Key.KeyAddress>`
                
                .. attribute:: key_host
                
                	
                	**type**\:  :py:class:`KeyHost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Key.KeyHost>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Isakmp.Key, self).__init__()

                    self.yang_name = "key"
                    self.yang_parent_name = "isakmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("key-address", ("key_address", Native.Crypto.Isakmp.Key.KeyAddress)), ("key-host", ("key_host", Native.Crypto.Isakmp.Key.KeyHost))])
                    self._leafs = OrderedDict()

                    self.key_address = Native.Crypto.Isakmp.Key.KeyAddress()
                    self.key_address.parent = self
                    self._children_name_map["key_address"] = "key-address"

                    self.key_host = Native.Crypto.Isakmp.Key.KeyHost()
                    self.key_host.parent = self
                    self._children_name_map["key_host"] = "key-host"
                    self._segment_path = lambda: "key"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Isakmp.Key, [], name, value)


                class KeyAddress(Entity):
                    """
                    
                    
                    .. attribute:: encryption
                    
                    	
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Key.KeyAddress.Encryption>`
                    
                    .. attribute:: key
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: addr4_container
                    
                    	
                    	**type**\:  :py:class:`Addr4Container <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Key.KeyAddress.Addr4Container>`
                    
                    .. attribute:: addr6_container
                    
                    	
                    	**type**\:  :py:class:`Addr6Container <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Key.KeyAddress.Addr6Container>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Key.KeyAddress, self).__init__()

                        self.yang_name = "key-address"
                        self.yang_parent_name = "key"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("addr4-container", ("addr4_container", Native.Crypto.Isakmp.Key.KeyAddress.Addr4Container)), ("addr6-container", ("addr6_container", Native.Crypto.Isakmp.Key.KeyAddress.Addr6Container))])
                        self._leafs = OrderedDict([
                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Key.KeyAddress.Encryption')])),
                            ('key', (YLeaf(YType.str, 'key'), ['str'])),
                        ])
                        self.encryption = None
                        self.key = None

                        self.addr4_container = Native.Crypto.Isakmp.Key.KeyAddress.Addr4Container()
                        self.addr4_container.parent = self
                        self._children_name_map["addr4_container"] = "addr4-container"

                        self.addr6_container = Native.Crypto.Isakmp.Key.KeyAddress.Addr6Container()
                        self.addr6_container.parent = self
                        self._children_name_map["addr6_container"] = "addr6-container"
                        self._segment_path = lambda: "key-address"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/key/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Key.KeyAddress, ['encryption', 'key'], name, value)

                    class Encryption(Enum):
                        """
                        Encryption (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_6 = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_6 = Enum.YLeaf(1, "6")



                    class Addr4Container(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	define shared key with IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: no_xauth
                        
                        	Bypasses XAuth for this peer
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Key.KeyAddress.Addr4Container, self).__init__()

                            self.yang_name = "addr4-container"
                            self.yang_parent_name = "key-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('no_xauth', (YLeaf(YType.empty, 'no-xauth'), ['Empty'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.no_xauth = None
                            self._segment_path = lambda: "addr4-container"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/key/key-address/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Key.KeyAddress.Addr4Container, ['address', 'mask', 'no_xauth'], name, value)


                    class Addr6Container(Entity):
                        """
                        
                        
                        .. attribute:: address
                        
                        	define shared key with IP address
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Key.KeyAddress.Addr6Container.Address>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Key.KeyAddress.Addr6Container, self).__init__()

                            self.yang_name = "addr6-container"
                            self.yang_parent_name = "key-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Isakmp.Key.KeyAddress.Addr6Container.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Crypto.Isakmp.Key.KeyAddress.Addr6Container.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "addr6-container"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/key/key-address/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Key.KeyAddress.Addr6Container, [], name, value)


                        class Address(Entity):
                            """
                            define shared key with IP address
                            
                            .. attribute:: ipv6
                            
                            	define shared key with IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: no_xauth
                            
                            	Bypasses XAuth for this peer
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Key.KeyAddress.Addr6Container.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "addr6-container"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ('no_xauth', (YLeaf(YType.empty, 'no-xauth'), ['Empty'])),
                                ])
                                self.ipv6 = None
                                self.no_xauth = None
                                self._segment_path = lambda: "address"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/key/key-address/addr6-container/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Key.KeyAddress.Addr6Container.Address, ['ipv6', 'no_xauth'], name, value)


                class KeyHost(Entity):
                    """
                    
                    
                    .. attribute:: encryption
                    
                    	
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Key.KeyHost.Encryption>`
                    
                    .. attribute:: key
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: host_container
                    
                    	
                    	**type**\:  :py:class:`HostContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Key.KeyHost.HostContainer>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Key.KeyHost, self).__init__()

                        self.yang_name = "key-host"
                        self.yang_parent_name = "key"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("host-container", ("host_container", Native.Crypto.Isakmp.Key.KeyHost.HostContainer))])
                        self._leafs = OrderedDict([
                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Key.KeyHost.Encryption')])),
                            ('key', (YLeaf(YType.str, 'key'), ['str'])),
                        ])
                        self.encryption = None
                        self.key = None

                        self.host_container = Native.Crypto.Isakmp.Key.KeyHost.HostContainer()
                        self.host_container.parent = self
                        self._children_name_map["host_container"] = "host-container"
                        self._segment_path = lambda: "key-host"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/key/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Key.KeyHost, ['encryption', 'key'], name, value)

                    class Encryption(Enum):
                        """
                        Encryption (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_6 = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_6 = Enum.YLeaf(1, "6")



                    class HostContainer(Entity):
                        """
                        
                        
                        .. attribute:: hostname
                        
                        	define shared key with hostname
                        	**type**\: str
                        
                        .. attribute:: no_xauth
                        
                        	Bypasses XAuth for this peer
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Key.KeyHost.HostContainer, self).__init__()

                            self.yang_name = "host-container"
                            self.yang_parent_name = "key-host"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('hostname', (YLeaf(YType.str, 'hostname'), ['str'])),
                                ('no_xauth', (YLeaf(YType.empty, 'no-xauth'), ['Empty'])),
                            ])
                            self.hostname = None
                            self.no_xauth = None
                            self._segment_path = lambda: "host-container"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/key/key-host/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Key.KeyHost.HostContainer, ['hostname', 'no_xauth'], name, value)


            class Nat(Entity):
                """
                Set a nat  keepalive interval for use with IOS peers
                
                .. attribute:: keepalive
                
                	Set a nat keepalive interval for use with IOS peers
                	**type**\: int
                
                	**range:** 5..3600
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Isakmp.Nat, self).__init__()

                    self.yang_name = "nat"
                    self.yang_parent_name = "isakmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('keepalive', (YLeaf(YType.uint16, 'keepalive'), ['int'])),
                    ])
                    self.keepalive = None
                    self._segment_path = lambda: "nat"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Isakmp.Nat, ['keepalive'], name, value)


            class Peer(Entity):
                """
                Set Peer Policy
                
                .. attribute:: ipv4_addr
                
                	
                	**type**\:  :py:class:`Ipv4Addr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv4Addr>`
                
                .. attribute:: ipv6_addr
                
                	
                	**type**\:  :py:class:`Ipv6Addr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv6Addr>`
                
                .. attribute:: hostname
                
                	hostname  define peer policy for hostname
                	**type**\: list of  		 :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Hostname>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Isakmp.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "isakmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4-addr", ("ipv4_addr", Native.Crypto.Isakmp.Peer.Ipv4Addr)), ("ipv6-addr", ("ipv6_addr", Native.Crypto.Isakmp.Peer.Ipv6Addr)), ("hostname", ("hostname", Native.Crypto.Isakmp.Peer.Hostname))])
                    self._leafs = OrderedDict()

                    self.ipv4_addr = Native.Crypto.Isakmp.Peer.Ipv4Addr()
                    self.ipv4_addr.parent = self
                    self._children_name_map["ipv4_addr"] = "ipv4-addr"

                    self.ipv6_addr = Native.Crypto.Isakmp.Peer.Ipv6Addr()
                    self.ipv6_addr.parent = self
                    self._children_name_map["ipv6_addr"] = "ipv6-addr"

                    self.hostname = YList(self)
                    self._segment_path = lambda: "peer"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Isakmp.Peer, [], name, value)


                class Ipv4Addr(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	define peer policy for IP address
                    	**type**\: list of  		 :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv4Addr.Address>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Peer.Ipv4Addr, self).__init__()

                        self.yang_name = "ipv4-addr"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Isakmp.Peer.Ipv4Addr.Address))])
                        self._leafs = OrderedDict()

                        self.address = YList(self)
                        self._segment_path = lambda: "ipv4-addr"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/peer/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv4Addr, [], name, value)


                    class Address(Entity):
                        """
                        define peer policy for IP address
                        
                        .. attribute:: ipv4  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vrf
                        
                        	specify front door vrf of the peer
                        	**type**\: str
                        
                        .. attribute:: description
                        
                        	IKE peer specific description
                        	**type**\: str
                        
                        	**length:** 1..80
                        
                        .. attribute:: set
                        
                        	set peer policy attributes
                        	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Peer.Ipv4Addr.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ipv4-addr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ipv4']
                            self._child_classes = OrderedDict([("set", ("set", Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set))])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ])
                            self.ipv4 = None
                            self.vrf = None
                            self.description = None

                            self.set = Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set()
                            self.set.parent = self
                            self._children_name_map["set"] = "set"
                            self._segment_path = lambda: "address" + "[ipv4='" + str(self.ipv4) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/peer/ipv4-addr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv4Addr.Address, ['ipv4', 'vrf', 'description'], name, value)


                        class Set(Entity):
                            """
                            set peer policy attributes
                            
                            .. attribute:: aggressive_mode
                            
                            	aggressive mode attributes
                            	**type**\:  :py:class:`AggressiveMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set, self).__init__()

                                self.yang_name = "set"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aggressive-mode", ("aggressive_mode", Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode))])
                                self._leafs = OrderedDict()

                                self.aggressive_mode = Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode()
                                self.aggressive_mode.parent = self
                                self._children_name_map["aggressive_mode"] = "aggressive-mode"
                                self._segment_path = lambda: "set"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set, [], name, value)


                            class AggressiveMode(Entity):
                                """
                                aggressive mode attributes
                                
                                .. attribute:: client_endpoint
                                
                                	specify a tunnel\-client\-endpoint attribute
                                	**type**\:  :py:class:`ClientEndpoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.ClientEndpoint>`
                                
                                .. attribute:: password
                                
                                	specify a tunnel\-password attribute
                                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.Password>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode, self).__init__()

                                    self.yang_name = "aggressive-mode"
                                    self.yang_parent_name = "set"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("client-endpoint", ("client_endpoint", Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.ClientEndpoint)), ("password", ("password", Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.Password))])
                                    self._leafs = OrderedDict()

                                    self.client_endpoint = Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.ClientEndpoint()
                                    self.client_endpoint.parent = self
                                    self._children_name_map["client_endpoint"] = "client-endpoint"

                                    self.password = Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._segment_path = lambda: "aggressive-mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode, [], name, value)


                                class ClientEndpoint(Entity):
                                    """
                                    specify a tunnel\-client\-endpoint attribute
                                    
                                    .. attribute:: fqdn
                                    
                                    	Use the fqdn as tunnel\-client\-endpoint
                                    	**type**\: str
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	Use the IP address as tunnel\-client\-endpoint
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	Use the IPv6 address as tunnel\-client\-endpoint
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: user_fqdn
                                    
                                    	Use the user\-fqdn as tunnel\-client\-endpoint
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.ClientEndpoint, self).__init__()

                                        self.yang_name = "client-endpoint"
                                        self.yang_parent_name = "aggressive-mode"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fqdn', (YLeaf(YType.str, 'fqdn'), ['str'])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('user_fqdn', (YLeaf(YType.str, 'user-fqdn'), ['str'])),
                                        ])
                                        self.fqdn = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self.user_fqdn = None
                                        self._segment_path = lambda: "client-endpoint"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.ClientEndpoint, ['fqdn', 'ipv4_address', 'ipv6_address', 'user_fqdn'], name, value)


                                class Password(Entity):
                                    """
                                    specify a tunnel\-password attribute
                                    
                                    .. attribute:: encryption
                                    
                                    	
                                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.Password.Encryption>`
                                    
                                    .. attribute:: key
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "aggressive-mode"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.Password.Encryption')])),
                                            ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                        ])
                                        self.encryption = None
                                        self.key = None
                                        self._segment_path = lambda: "password"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv4Addr.Address.Set.AggressiveMode.Password, ['encryption', 'key'], name, value)

                                    class Encryption(Enum):
                                        """
                                        Encryption (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_6 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_6 = Enum.YLeaf(1, "6")



                class Ipv6Addr(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	define peer policy for IP address
                    	**type**\: list of  		 :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv6Addr.Address>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Peer.Ipv6Addr, self).__init__()

                        self.yang_name = "ipv6-addr"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Isakmp.Peer.Ipv6Addr.Address))])
                        self._leafs = OrderedDict()

                        self.address = YList(self)
                        self._segment_path = lambda: "ipv6-addr"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/peer/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv6Addr, [], name, value)


                    class Address(Entity):
                        """
                        define peer policy for IP address
                        
                        .. attribute:: ipv6  (key)
                        
                        	define peer policy for IPv6 address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vrf
                        
                        	specify front door vrf of the peer
                        	**type**\: str
                        
                        .. attribute:: description
                        
                        	IKE peer specific description
                        	**type**\: str
                        
                        	**length:** 1..80
                        
                        .. attribute:: set
                        
                        	set peer policy attributes
                        	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Peer.Ipv6Addr.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "ipv6-addr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ipv6']
                            self._child_classes = OrderedDict([("set", ("set", Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set))])
                            self._leafs = OrderedDict([
                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ])
                            self.ipv6 = None
                            self.vrf = None
                            self.description = None

                            self.set = Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set()
                            self.set.parent = self
                            self._children_name_map["set"] = "set"
                            self._segment_path = lambda: "address" + "[ipv6='" + str(self.ipv6) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/peer/ipv6-addr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv6Addr.Address, ['ipv6', 'vrf', 'description'], name, value)


                        class Set(Entity):
                            """
                            set peer policy attributes
                            
                            .. attribute:: aggressive_mode
                            
                            	aggressive mode attributes
                            	**type**\:  :py:class:`AggressiveMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set, self).__init__()

                                self.yang_name = "set"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aggressive-mode", ("aggressive_mode", Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode))])
                                self._leafs = OrderedDict()

                                self.aggressive_mode = Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode()
                                self.aggressive_mode.parent = self
                                self._children_name_map["aggressive_mode"] = "aggressive-mode"
                                self._segment_path = lambda: "set"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set, [], name, value)


                            class AggressiveMode(Entity):
                                """
                                aggressive mode attributes
                                
                                .. attribute:: client_endpoint
                                
                                	specify a tunnel\-client\-endpoint attribute
                                	**type**\:  :py:class:`ClientEndpoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.ClientEndpoint>`
                                
                                .. attribute:: password
                                
                                	specify a tunnel\-password attribute
                                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.Password>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode, self).__init__()

                                    self.yang_name = "aggressive-mode"
                                    self.yang_parent_name = "set"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("client-endpoint", ("client_endpoint", Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.ClientEndpoint)), ("password", ("password", Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.Password))])
                                    self._leafs = OrderedDict()

                                    self.client_endpoint = Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.ClientEndpoint()
                                    self.client_endpoint.parent = self
                                    self._children_name_map["client_endpoint"] = "client-endpoint"

                                    self.password = Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._segment_path = lambda: "aggressive-mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode, [], name, value)


                                class ClientEndpoint(Entity):
                                    """
                                    specify a tunnel\-client\-endpoint attribute
                                    
                                    .. attribute:: fqdn
                                    
                                    	Use the fqdn as tunnel\-client\-endpoint
                                    	**type**\: str
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	Use the IP address as tunnel\-client\-endpoint
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	Use the IPv6 address as tunnel\-client\-endpoint
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: user_fqdn
                                    
                                    	Use the user\-fqdn as tunnel\-client\-endpoint
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.ClientEndpoint, self).__init__()

                                        self.yang_name = "client-endpoint"
                                        self.yang_parent_name = "aggressive-mode"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fqdn', (YLeaf(YType.str, 'fqdn'), ['str'])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('user_fqdn', (YLeaf(YType.str, 'user-fqdn'), ['str'])),
                                        ])
                                        self.fqdn = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self.user_fqdn = None
                                        self._segment_path = lambda: "client-endpoint"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.ClientEndpoint, ['fqdn', 'ipv4_address', 'ipv6_address', 'user_fqdn'], name, value)


                                class Password(Entity):
                                    """
                                    specify a tunnel\-password attribute
                                    
                                    .. attribute:: encryption
                                    
                                    	
                                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.Password.Encryption>`
                                    
                                    .. attribute:: key
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "aggressive-mode"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.Password.Encryption')])),
                                            ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                        ])
                                        self.encryption = None
                                        self.key = None
                                        self._segment_path = lambda: "password"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Isakmp.Peer.Ipv6Addr.Address.Set.AggressiveMode.Password, ['encryption', 'key'], name, value)

                                    class Encryption(Enum):
                                        """
                                        Encryption (Enum Class)

                                        .. data:: Y_0 = 0

                                        .. data:: Y_6 = 1

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")

                                        Y_6 = Enum.YLeaf(1, "6")



                class Hostname(Entity):
                    """
                    hostname  define peer policy for hostname
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: vrf
                    
                    	specify front door vrf of the peer
                    	**type**\: str
                    
                    .. attribute:: description
                    
                    	IKE peer specific description
                    	**type**\: str
                    
                    	**length:** 1..80
                    
                    .. attribute:: set
                    
                    	set peer policy attributes
                    	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Hostname.Set>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Peer.Hostname, self).__init__()

                        self.yang_name = "hostname"
                        self.yang_parent_name = "peer"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("set", ("set", Native.Crypto.Isakmp.Peer.Hostname.Set))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ])
                        self.name = None
                        self.vrf = None
                        self.description = None

                        self.set = Native.Crypto.Isakmp.Peer.Hostname.Set()
                        self.set.parent = self
                        self._children_name_map["set"] = "set"
                        self._segment_path = lambda: "hostname" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/peer/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Peer.Hostname, ['name', 'vrf', 'description'], name, value)


                    class Set(Entity):
                        """
                        set peer policy attributes
                        
                        .. attribute:: aggressive_mode
                        
                        	aggressive mode attributes
                        	**type**\:  :py:class:`AggressiveMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Peer.Hostname.Set, self).__init__()

                            self.yang_name = "set"
                            self.yang_parent_name = "hostname"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("aggressive-mode", ("aggressive_mode", Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode))])
                            self._leafs = OrderedDict()

                            self.aggressive_mode = Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode()
                            self.aggressive_mode.parent = self
                            self._children_name_map["aggressive_mode"] = "aggressive-mode"
                            self._segment_path = lambda: "set"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Peer.Hostname.Set, [], name, value)


                        class AggressiveMode(Entity):
                            """
                            aggressive mode attributes
                            
                            .. attribute:: client_endpoint
                            
                            	specify a tunnel\-client\-endpoint attribute
                            	**type**\:  :py:class:`ClientEndpoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.ClientEndpoint>`
                            
                            .. attribute:: password
                            
                            	specify a tunnel\-password attribute
                            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.Password>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode, self).__init__()

                                self.yang_name = "aggressive-mode"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("client-endpoint", ("client_endpoint", Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.ClientEndpoint)), ("password", ("password", Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.Password))])
                                self._leafs = OrderedDict()

                                self.client_endpoint = Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.ClientEndpoint()
                                self.client_endpoint.parent = self
                                self._children_name_map["client_endpoint"] = "client-endpoint"

                                self.password = Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.Password()
                                self.password.parent = self
                                self._children_name_map["password"] = "password"
                                self._segment_path = lambda: "aggressive-mode"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode, [], name, value)


                            class ClientEndpoint(Entity):
                                """
                                specify a tunnel\-client\-endpoint attribute
                                
                                .. attribute:: fqdn
                                
                                	Use the fqdn as tunnel\-client\-endpoint
                                	**type**\: str
                                
                                .. attribute:: ipv4_address
                                
                                	Use the IP address as tunnel\-client\-endpoint
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	Use the IPv6 address as tunnel\-client\-endpoint
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: user_fqdn
                                
                                	Use the user\-fqdn as tunnel\-client\-endpoint
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.ClientEndpoint, self).__init__()

                                    self.yang_name = "client-endpoint"
                                    self.yang_parent_name = "aggressive-mode"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('fqdn', (YLeaf(YType.str, 'fqdn'), ['str'])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('user_fqdn', (YLeaf(YType.str, 'user-fqdn'), ['str'])),
                                    ])
                                    self.fqdn = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self.user_fqdn = None
                                    self._segment_path = lambda: "client-endpoint"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.ClientEndpoint, ['fqdn', 'ipv4_address', 'ipv6_address', 'user_fqdn'], name, value)


                            class Password(Entity):
                                """
                                specify a tunnel\-password attribute
                                
                                .. attribute:: encryption
                                
                                	
                                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.Password.Encryption>`
                                
                                .. attribute:: key
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.Password, self).__init__()

                                    self.yang_name = "password"
                                    self.yang_parent_name = "aggressive-mode"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.Password.Encryption')])),
                                        ('key', (YLeaf(YType.str, 'key'), ['str'])),
                                    ])
                                    self.encryption = None
                                    self.key = None
                                    self._segment_path = lambda: "password"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Peer.Hostname.Set.AggressiveMode.Password, ['encryption', 'key'], name, value)

                                class Encryption(Enum):
                                    """
                                    Encryption (Enum Class)

                                    .. data:: Y_0 = 0

                                    .. data:: Y_6 = 1

                                    """

                                    Y_0 = Enum.YLeaf(0, "0")

                                    Y_6 = Enum.YLeaf(1, "6")



            class Policy(Entity):
                """
                Set policy for an ISAKMP protection suite
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 1..10000
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Default>`
                
                .. attribute:: authentication
                
                	Set authentication method for protection suite
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Authentication>`
                
                .. attribute:: encryption
                
                	Set encryption algorithm for protection suite
                	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Encryption>`
                
                .. attribute:: group
                
                	Set the Diffie\-Hellman group
                	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Group>`
                
                .. attribute:: hash
                
                	Set hash algorithm for protection suite
                	**type**\:  :py:class:`Hash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Hash>`
                
                .. attribute:: lifetime
                
                	Set lifetime for ISAKMP security association
                	**type**\: int
                
                	**range:** 60..86400
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Isakmp.Policy, self).__init__()

                    self.yang_name = "policy"
                    self.yang_parent_name = "isakmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Isakmp.Policy.Default)), ("encryption", ("encryption", Native.Crypto.Isakmp.Policy.Encryption))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                        ('authentication', (YLeaf(YType.enumeration, 'authentication'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Policy.Authentication')])),
                        ('group', (YLeaf(YType.enumeration, 'group'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Policy.Group')])),
                        ('hash', (YLeaf(YType.enumeration, 'hash'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Policy.Hash')])),
                        ('lifetime', (YLeaf(YType.uint32, 'lifetime'), ['int'])),
                    ])
                    self.number = None
                    self.authentication = None
                    self.group = None
                    self.hash = None
                    self.lifetime = None

                    self.default = Native.Crypto.Isakmp.Policy.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.encryption = Native.Crypto.Isakmp.Policy.Encryption()
                    self.encryption.parent = self
                    self._children_name_map["encryption"] = "encryption"
                    self._segment_path = lambda: "policy" + "[number='" + str(self.number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Isakmp.Policy, ['number', 'authentication', 'group', 'hash', 'lifetime'], name, value)

                class Authentication(Enum):
                    """
                    Authentication (Enum Class)

                    Set authentication method for protection suite

                    .. data:: pre_share = 0

                    .. data:: rsa_encr = 1

                    .. data:: rsa_sig = 2

                    """

                    pre_share = Enum.YLeaf(0, "pre-share")

                    rsa_encr = Enum.YLeaf(1, "rsa-encr")

                    rsa_sig = Enum.YLeaf(2, "rsa-sig")


                class Group(Enum):
                    """
                    Group (Enum Class)

                    Set the Diffie\-Hellman group

                    .. data:: Y_1 = 0

                    .. data:: Y_14 = 1

                    .. data:: Y_15 = 2

                    .. data:: Y_16 = 3

                    .. data:: Y_19 = 4

                    .. data:: Y_2 = 5

                    .. data:: Y_20 = 6

                    .. data:: Y_21 = 7

                    .. data:: Y_24 = 8

                    .. data:: Y_5 = 9

                    """

                    Y_1 = Enum.YLeaf(0, "1")

                    Y_14 = Enum.YLeaf(1, "14")

                    Y_15 = Enum.YLeaf(2, "15")

                    Y_16 = Enum.YLeaf(3, "16")

                    Y_19 = Enum.YLeaf(4, "19")

                    Y_2 = Enum.YLeaf(5, "2")

                    Y_20 = Enum.YLeaf(6, "20")

                    Y_21 = Enum.YLeaf(7, "21")

                    Y_24 = Enum.YLeaf(8, "24")

                    Y_5 = Enum.YLeaf(9, "5")


                class Hash(Enum):
                    """
                    Hash (Enum Class)

                    Set hash algorithm for protection suite

                    .. data:: md5 = 0

                    .. data:: sha = 1

                    .. data:: sha256 = 2

                    .. data:: sha384 = 3

                    .. data:: sha512 = 4

                    """

                    md5 = Enum.YLeaf(0, "md5")

                    sha = Enum.YLeaf(1, "sha")

                    sha256 = Enum.YLeaf(2, "sha256")

                    sha384 = Enum.YLeaf(3, "sha384")

                    sha512 = Enum.YLeaf(4, "sha512")



                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: authentication
                    
                    	Set authentication method for protection suite
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Default.Authentication>`
                    
                    .. attribute:: encryption
                    
                    	Set encryption algorithm for protection suite
                    	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Default.Encryption>`
                    
                    .. attribute:: group
                    
                    	Set the Diffie\-Hellman group
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Default.Group>`
                    
                    .. attribute:: hash
                    
                    	Set hash algorithm for protection suite
                    	**type**\:  :py:class:`Hash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Default.Hash>`
                    
                    .. attribute:: lifetime
                    
                    	Set lifetime for ISAKMP security association
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Policy.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("encryption", ("encryption", Native.Crypto.Isakmp.Policy.Default.Encryption))])
                        self._leafs = OrderedDict([
                            ('authentication', (YLeaf(YType.enumeration, 'authentication'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Policy.Default.Authentication')])),
                            ('group', (YLeaf(YType.enumeration, 'group'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Policy.Default.Group')])),
                            ('hash', (YLeaf(YType.enumeration, 'hash'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Policy.Default.Hash')])),
                            ('lifetime', (YLeaf(YType.empty, 'lifetime'), ['Empty'])),
                        ])
                        self.authentication = None
                        self.group = None
                        self.hash = None
                        self.lifetime = None

                        self.encryption = Native.Crypto.Isakmp.Policy.Default.Encryption()
                        self.encryption.parent = self
                        self._children_name_map["encryption"] = "encryption"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Policy.Default, ['authentication', 'group', 'hash', 'lifetime'], name, value)

                    class Authentication(Enum):
                        """
                        Authentication (Enum Class)

                        Set authentication method for protection suite

                        .. data:: pre_share = 0

                        .. data:: rsa_encr = 1

                        .. data:: rsa_sig = 2

                        """

                        pre_share = Enum.YLeaf(0, "pre-share")

                        rsa_encr = Enum.YLeaf(1, "rsa-encr")

                        rsa_sig = Enum.YLeaf(2, "rsa-sig")


                    class Group(Enum):
                        """
                        Group (Enum Class)

                        Set the Diffie\-Hellman group

                        .. data:: Y_1 = 0

                        .. data:: Y_14 = 1

                        .. data:: Y_15 = 2

                        .. data:: Y_16 = 3

                        .. data:: Y_19 = 4

                        .. data:: Y_2 = 5

                        .. data:: Y_20 = 6

                        .. data:: Y_21 = 7

                        .. data:: Y_24 = 8

                        .. data:: Y_5 = 9

                        """

                        Y_1 = Enum.YLeaf(0, "1")

                        Y_14 = Enum.YLeaf(1, "14")

                        Y_15 = Enum.YLeaf(2, "15")

                        Y_16 = Enum.YLeaf(3, "16")

                        Y_19 = Enum.YLeaf(4, "19")

                        Y_2 = Enum.YLeaf(5, "2")

                        Y_20 = Enum.YLeaf(6, "20")

                        Y_21 = Enum.YLeaf(7, "21")

                        Y_24 = Enum.YLeaf(8, "24")

                        Y_5 = Enum.YLeaf(9, "5")


                    class Hash(Enum):
                        """
                        Hash (Enum Class)

                        Set hash algorithm for protection suite

                        .. data:: md5 = 0

                        .. data:: sha = 1

                        .. data:: sha256 = 2

                        .. data:: sha384 = 3

                        .. data:: sha512 = 4

                        """

                        md5 = Enum.YLeaf(0, "md5")

                        sha = Enum.YLeaf(1, "sha")

                        sha256 = Enum.YLeaf(2, "sha256")

                        sha384 = Enum.YLeaf(3, "sha384")

                        sha512 = Enum.YLeaf(4, "sha512")



                    class Encryption(Entity):
                        """
                        Set encryption algorithm for protection suite
                        
                        .. attribute:: a3des
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: aes
                        
                        	AES \- Advanced Encryption Standard
                        	**type**\:  :py:class:`Aes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Default.Encryption.Aes>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: des
                        
                        	DES \- Data Encryption Standard (56 bit keys)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Policy.Default.Encryption, self).__init__()

                            self.yang_name = "encryption"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("aes", ("aes", Native.Crypto.Isakmp.Policy.Default.Encryption.Aes))])
                            self._leafs = OrderedDict([
                                ('a3des', (YLeaf(YType.empty, 'a3des'), ['Empty'])),
                                ('des', (YLeaf(YType.empty, 'des'), ['Empty'])),
                            ])
                            self.a3des = None
                            self.des = None

                            self.aes = None
                            self._children_name_map["aes"] = "aes"
                            self._segment_path = lambda: "encryption"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Policy.Default.Encryption, ['a3des', 'des'], name, value)


                        class Aes(Entity):
                            """
                            AES \- Advanced Encryption Standard.
                            
                            .. attribute:: key
                            
                            	
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Default.Encryption.Aes.Key>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Policy.Default.Encryption.Aes, self).__init__()

                                self.yang_name = "aes"
                                self.yang_parent_name = "encryption"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Policy.Default.Encryption.Aes.Key')])),
                                ])
                                self.key = None
                                self._segment_path = lambda: "aes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Policy.Default.Encryption.Aes, ['key'], name, value)

                            class Key(Enum):
                                """
                                Key (Enum Class)

                                .. data:: Y_128 = 0

                                .. data:: Y_192 = 1

                                .. data:: Y_256 = 2

                                """

                                Y_128 = Enum.YLeaf(0, "128")

                                Y_192 = Enum.YLeaf(1, "192")

                                Y_256 = Enum.YLeaf(2, "256")



                class Encryption(Entity):
                    """
                    Set encryption algorithm for protection suite
                    
                    .. attribute:: a3des
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: aes
                    
                    	AES \- Advanced Encryption Standard
                    	**type**\:  :py:class:`Aes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Encryption.Aes>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: des
                    
                    	DES \- Data Encryption Standard (56 bit keys)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Policy.Encryption, self).__init__()

                        self.yang_name = "encryption"
                        self.yang_parent_name = "policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aes", ("aes", Native.Crypto.Isakmp.Policy.Encryption.Aes))])
                        self._leafs = OrderedDict([
                            ('a3des', (YLeaf(YType.empty, 'a3des'), ['Empty'])),
                            ('des', (YLeaf(YType.empty, 'des'), ['Empty'])),
                        ])
                        self.a3des = None
                        self.des = None

                        self.aes = None
                        self._children_name_map["aes"] = "aes"
                        self._segment_path = lambda: "encryption"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Policy.Encryption, ['a3des', 'des'], name, value)


                    class Aes(Entity):
                        """
                        AES \- Advanced Encryption Standard.
                        
                        .. attribute:: key
                        
                        	
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Policy.Encryption.Aes.Key>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Policy.Encryption.Aes, self).__init__()

                            self.yang_name = "aes"
                            self.yang_parent_name = "encryption"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.enumeration, 'key'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Policy.Encryption.Aes.Key')])),
                            ])
                            self.key = None
                            self._segment_path = lambda: "aes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Policy.Encryption.Aes, ['key'], name, value)

                        class Key(Enum):
                            """
                            Key (Enum Class)

                            .. data:: Y_128 = 0

                            .. data:: Y_192 = 1

                            .. data:: Y_256 = 2

                            """

                            Y_128 = Enum.YLeaf(0, "128")

                            Y_192 = Enum.YLeaf(1, "192")

                            Y_256 = Enum.YLeaf(2, "256")



            class Profile(Entity):
                """
                Define ISAKMP Profiles
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default>`
                
                .. attribute:: accounting
                
                	Enable AAA Accounting for IPSec Sessions
                	**type**\: str
                
                .. attribute:: ca
                
                	Specify certificate authorities to trust
                	**type**\:  :py:class:`Ca <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Ca>`
                
                .. attribute:: client
                
                	Specify client configuration settings
                	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Client>`
                
                .. attribute:: description
                
                	Specify a description of this profile
                	**type**\: str
                
                .. attribute:: initiate
                
                	Initiator property
                	**type**\:  :py:class:`Initiate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Initiate>`
                
                .. attribute:: isakmp
                
                	ISAKMP Authorization command
                	**type**\:  :py:class:`Isakmp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Isakmp_>`
                
                .. attribute:: keepalive
                
                	Set a keepalive interval for use with IOS peers
                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Keepalive>`
                
                .. attribute:: keyring
                
                	Specify keyring to use
                	**type**\: union of the below types:
                
                		**type**\: str
                
                		**type**\:  :py:class:`Keyring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Keyring>`
                
                .. attribute:: local_address
                
                	Interface to use for local address for this isakmp profile
                	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.LocalAddress>`
                
                .. attribute:: match
                
                	Match values of peer
                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Match>`
                
                .. attribute:: qos_group
                
                	Apply a Qos policy class map for this profile
                	**type**\: int
                
                	**range:** 1..1023
                
                .. attribute:: self_identity
                
                	Specify Identity to use
                	**type**\:  :py:class:`SelfIdentity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.SelfIdentity>`
                
                .. attribute:: virtual_template
                
                	Specify the virtual\-template for dynamic interface creation
                	**type**\: int
                
                	**range:** 1..4095
                
                .. attribute:: vrf
                
                	Specify the VRF it is related to
                	**type**\: str
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Isakmp.Profile, self).__init__()

                    self.yang_name = "profile"
                    self.yang_parent_name = "isakmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("default", ("default", Native.Crypto.Isakmp.Profile.Default)), ("ca", ("ca", Native.Crypto.Isakmp.Profile.Ca)), ("client", ("client", Native.Crypto.Isakmp.Profile.Client)), ("initiate", ("initiate", Native.Crypto.Isakmp.Profile.Initiate)), ("isakmp", ("isakmp", Native.Crypto.Isakmp.Profile.Isakmp_)), ("keepalive", ("keepalive", Native.Crypto.Isakmp.Profile.Keepalive)), ("local-address", ("local_address", Native.Crypto.Isakmp.Profile.LocalAddress)), ("match", ("match", Native.Crypto.Isakmp.Profile.Match)), ("self-identity", ("self_identity", Native.Crypto.Isakmp.Profile.SelfIdentity))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('accounting', (YLeaf(YType.str, 'accounting'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('keyring', (YLeaf(YType.str, 'keyring'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Profile.Keyring')])),
                        ('qos_group', (YLeaf(YType.uint16, 'qos-group'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'virtual-template'), ['int'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ])
                    self.name = None
                    self.accounting = None
                    self.description = None
                    self.keyring = None
                    self.qos_group = None
                    self.virtual_template = None
                    self.vrf = None

                    self.default = Native.Crypto.Isakmp.Profile.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.ca = Native.Crypto.Isakmp.Profile.Ca()
                    self.ca.parent = self
                    self._children_name_map["ca"] = "ca"

                    self.client = Native.Crypto.Isakmp.Profile.Client()
                    self.client.parent = self
                    self._children_name_map["client"] = "client"

                    self.initiate = Native.Crypto.Isakmp.Profile.Initiate()
                    self.initiate.parent = self
                    self._children_name_map["initiate"] = "initiate"

                    self.isakmp = Native.Crypto.Isakmp.Profile.Isakmp_()
                    self.isakmp.parent = self
                    self._children_name_map["isakmp"] = "isakmp"

                    self.keepalive = Native.Crypto.Isakmp.Profile.Keepalive()
                    self.keepalive.parent = self
                    self._children_name_map["keepalive"] = "keepalive"

                    self.local_address = Native.Crypto.Isakmp.Profile.LocalAddress()
                    self.local_address.parent = self
                    self._children_name_map["local_address"] = "local-address"

                    self.match = Native.Crypto.Isakmp.Profile.Match()
                    self.match.parent = self
                    self._children_name_map["match"] = "match"

                    self.self_identity = Native.Crypto.Isakmp.Profile.SelfIdentity()
                    self.self_identity.parent = self
                    self._children_name_map["self_identity"] = "self-identity"
                    self._segment_path = lambda: "profile" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Isakmp.Profile, ['name', 'accounting', 'description', 'keyring', 'qos_group', 'virtual_template', 'vrf'], name, value)

                class Keyring(Enum):
                    """
                    Keyring (Enum Class)

                    Specify keyring to use

                    .. data:: default = 0

                    """

                    default = Enum.YLeaf(0, "default")



                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: accounting
                    
                    	Enable AAA Accounting for IPSec Sessions
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ca
                    
                    	Specify certificate authorities to trust
                    	**type**\:  :py:class:`Ca <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Ca>`
                    
                    .. attribute:: client
                    
                    	Specify client configuration settings
                    	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Client>`
                    
                    .. attribute:: description
                    
                    	Specify a description of this profile
                    	**type**\: str
                    
                    .. attribute:: initiate
                    
                    	Initiator property
                    	**type**\:  :py:class:`Initiate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Initiate>`
                    
                    .. attribute:: isakmp
                    
                    	ISAKMP Authorization command
                    	**type**\:  :py:class:`Isakmp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Isakmp_>`
                    
                    .. attribute:: keepalive
                    
                    	Set a keepalive interval for use with IOS peers
                    	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Keepalive>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: keyring
                    
                    	Specify keyring to use
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Keyring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Keyring>`
                    
                    .. attribute:: local_address
                    
                    	Interface to use for local address for this isakmp profile
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: match
                    
                    	Match values of peer
                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Match>`
                    
                    .. attribute:: qos_group
                    
                    	Apply a Qos policy class map for this profile
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: self_identity
                    
                    	Specify Identity to use
                    	**type**\:  :py:class:`SelfIdentity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.SelfIdentity>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: virtual_template
                    
                    	Specify the virtual\-template for dynamic interface creation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	Specify the VRF it is related to
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Profile.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ca", ("ca", Native.Crypto.Isakmp.Profile.Default.Ca)), ("client", ("client", Native.Crypto.Isakmp.Profile.Default.Client)), ("initiate", ("initiate", Native.Crypto.Isakmp.Profile.Default.Initiate)), ("isakmp", ("isakmp", Native.Crypto.Isakmp.Profile.Default.Isakmp_)), ("keepalive", ("keepalive", Native.Crypto.Isakmp.Profile.Default.Keepalive)), ("match", ("match", Native.Crypto.Isakmp.Profile.Default.Match)), ("self-identity", ("self_identity", Native.Crypto.Isakmp.Profile.Default.SelfIdentity))])
                        self._leafs = OrderedDict([
                            ('accounting', (YLeaf(YType.empty, 'accounting'), ['Empty'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('keyring', (YLeaf(YType.str, 'keyring'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Profile.Default.Keyring')])),
                            ('local_address', (YLeaf(YType.empty, 'local-address'), ['Empty'])),
                            ('qos_group', (YLeaf(YType.empty, 'qos-group'), ['Empty'])),
                            ('virtual_template', (YLeaf(YType.empty, 'virtual-template'), ['Empty'])),
                            ('vrf', (YLeaf(YType.empty, 'vrf'), ['Empty'])),
                        ])
                        self.accounting = None
                        self.description = None
                        self.keyring = None
                        self.local_address = None
                        self.qos_group = None
                        self.virtual_template = None
                        self.vrf = None

                        self.ca = Native.Crypto.Isakmp.Profile.Default.Ca()
                        self.ca.parent = self
                        self._children_name_map["ca"] = "ca"

                        self.client = Native.Crypto.Isakmp.Profile.Default.Client()
                        self.client.parent = self
                        self._children_name_map["client"] = "client"

                        self.initiate = Native.Crypto.Isakmp.Profile.Default.Initiate()
                        self.initiate.parent = self
                        self._children_name_map["initiate"] = "initiate"

                        self.isakmp = Native.Crypto.Isakmp.Profile.Default.Isakmp_()
                        self.isakmp.parent = self
                        self._children_name_map["isakmp"] = "isakmp"

                        self.keepalive = None
                        self._children_name_map["keepalive"] = "keepalive"

                        self.match = Native.Crypto.Isakmp.Profile.Default.Match()
                        self.match.parent = self
                        self._children_name_map["match"] = "match"

                        self.self_identity = None
                        self._children_name_map["self_identity"] = "self-identity"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Profile.Default, ['accounting', 'description', 'keyring', 'local_address', 'qos_group', 'virtual_template', 'vrf'], name, value)

                    class Keyring(Enum):
                        """
                        Keyring (Enum Class)

                        Specify keyring to use

                        .. data:: default = 0

                        """

                        default = Enum.YLeaf(0, "default")



                    class Ca(Entity):
                        """
                        Specify certificate authorities to trust
                        
                        .. attribute:: trust_point
                        
                        	Cert authority trustpoint for RSA sig
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Default.Ca, self).__init__()

                            self.yang_name = "ca"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('trust_point', (YLeaf(YType.str, 'trust-point'), ['str'])),
                            ])
                            self.trust_point = None
                            self._segment_path = lambda: "ca"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Ca, ['trust_point'], name, value)


                    class Client(Entity):
                        """
                        Specify client configuration settings
                        
                        .. attribute:: authentication
                        
                        	Use Extended Authentication
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Client.Authentication>`
                        
                        .. attribute:: configuration
                        
                        	Specify client configuration settings
                        	**type**\:  :py:class:`Configuration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Client.Configuration>`
                        
                        .. attribute:: pki
                        
                        	Use username in the crypto certificate for authorization
                        	**type**\:  :py:class:`Pki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Client.Pki>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Default.Client, self).__init__()

                            self.yang_name = "client"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authentication", ("authentication", Native.Crypto.Isakmp.Profile.Default.Client.Authentication)), ("configuration", ("configuration", Native.Crypto.Isakmp.Profile.Default.Client.Configuration)), ("pki", ("pki", Native.Crypto.Isakmp.Profile.Default.Client.Pki))])
                            self._leafs = OrderedDict()

                            self.authentication = Native.Crypto.Isakmp.Profile.Default.Client.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.configuration = Native.Crypto.Isakmp.Profile.Default.Client.Configuration()
                            self.configuration.parent = self
                            self._children_name_map["configuration"] = "configuration"

                            self.pki = Native.Crypto.Isakmp.Profile.Default.Client.Pki()
                            self.pki.parent = self
                            self._children_name_map["pki"] = "pki"
                            self._segment_path = lambda: "client"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Client, [], name, value)


                        class Authentication(Entity):
                            """
                            Use Extended Authentication
                            
                            .. attribute:: list
                            
                            	AAA authentication list to use
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Profile.Default.Client.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                ])
                                self.list = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Client.Authentication, ['list'], name, value)


                        class Configuration(Entity):
                            """
                            Specify client configuration settings
                            
                            .. attribute:: address
                            
                            	Specify client network address configuration
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Client.Configuration.Address>`
                            
                            .. attribute:: group
                            
                            	Specify group profile attributes for client
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Profile.Default.Client.Configuration, self).__init__()

                                self.yang_name = "configuration"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.enumeration, 'address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Profile.Default.Client.Configuration.Address')])),
                                    ('group', (YLeaf(YType.str, 'group'), ['str'])),
                                ])
                                self.address = None
                                self.group = None
                                self._segment_path = lambda: "configuration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Client.Configuration, ['address', 'group'], name, value)

                            class Address(Enum):
                                """
                                Address (Enum Class)

                                Specify client network address configuration

                                .. data:: initiate = 0

                                .. data:: respond = 1

                                """

                                initiate = Enum.YLeaf(0, "initiate")

                                respond = Enum.YLeaf(1, "respond")



                        class Pki(Entity):
                            """
                            Use username in the crypto certificate for authorization
                            
                            .. attribute:: authorization
                            
                            	User authorization parameters
                            	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Client.Pki.Authorization>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Profile.Default.Client.Pki, self).__init__()

                                self.yang_name = "pki"
                                self.yang_parent_name = "client"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authorization", ("authorization", Native.Crypto.Isakmp.Profile.Default.Client.Pki.Authorization))])
                                self._leafs = OrderedDict()

                                self.authorization = None
                                self._children_name_map["authorization"] = "authorization"
                                self._segment_path = lambda: "pki"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Client.Pki, [], name, value)


                            class Authorization(Entity):
                                """
                                User authorization parameters
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Profile.Default.Client.Pki.Authorization, self).__init__()

                                    self.yang_name = "authorization"
                                    self.yang_parent_name = "pki"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "authorization"
                                    self._is_frozen = True


                    class Initiate(Entity):
                        """
                        Initiator property
                        
                        .. attribute:: mode
                        
                        	Phase 1 negotiation mode to use
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Initiate.Mode>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Default.Initiate, self).__init__()

                            self.yang_name = "initiate"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.Crypto.Isakmp.Profile.Default.Initiate.Mode))])
                            self._leafs = OrderedDict()

                            self.mode = None
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "initiate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Initiate, [], name, value)


                        class Mode(Entity):
                            """
                            Phase 1 negotiation mode to use
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Profile.Default.Initiate.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "initiate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "mode"
                                self._is_frozen = True


                    class Isakmp_(Entity):
                        """
                        ISAKMP Authorization command
                        
                        .. attribute:: authorization
                        
                        	Authorization parameters
                        	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Isakmp_.Authorization>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Default.Isakmp_, self).__init__()

                            self.yang_name = "isakmp"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authorization", ("authorization", Native.Crypto.Isakmp.Profile.Default.Isakmp_.Authorization))])
                            self._leafs = OrderedDict()

                            self.authorization = Native.Crypto.Isakmp.Profile.Default.Isakmp_.Authorization()
                            self.authorization.parent = self
                            self._children_name_map["authorization"] = "authorization"
                            self._segment_path = lambda: "isakmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Isakmp_, [], name, value)


                        class Authorization(Entity):
                            """
                            Authorization parameters.
                            
                            .. attribute:: list
                            
                            	AAA authorization list to use
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Profile.Default.Isakmp_.Authorization, self).__init__()

                                self.yang_name = "authorization"
                                self.yang_parent_name = "isakmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                ])
                                self.list = None
                                self._segment_path = lambda: "authorization"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Isakmp_.Authorization, ['list'], name, value)


                    class Keepalive(Entity):
                        """
                        Set a keepalive interval for use with IOS peers
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Default.Keepalive, self).__init__()

                            self.yang_name = "keepalive"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "keepalive"
                            self._is_frozen = True


                    class Match(Entity):
                        """
                        Match values of peer
                        
                        .. attribute:: certificate
                        
                        	Peer certificate attributes
                        	**type**\: str
                        
                        .. attribute:: identity
                        
                        	Peer identity
                        	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Match.Identity>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Default.Match, self).__init__()

                            self.yang_name = "match"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("identity", ("identity", Native.Crypto.Isakmp.Profile.Default.Match.Identity))])
                            self._leafs = OrderedDict([
                                ('certificate', (YLeaf(YType.str, 'certificate'), ['str'])),
                            ])
                            self.certificate = None

                            self.identity = Native.Crypto.Isakmp.Profile.Default.Match.Identity()
                            self.identity.parent = self
                            self._children_name_map["identity"] = "identity"
                            self._segment_path = lambda: "match"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Match, ['certificate'], name, value)


                        class Identity(Entity):
                            """
                            Peer identity
                            
                            .. attribute:: ipv4_address
                            
                            	
                            	**type**\:  :py:class:`Ipv4Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Match.Identity.Ipv4Address>`
                            
                            .. attribute:: address
                            
                            	IP Address(es)
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Match.Identity.Address>`
                            
                            .. attribute:: group
                            
                            	Group name
                            	**type**\: str
                            
                            .. attribute:: host
                            
                            	match a hostname/domain
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host>`
                            
                            .. attribute:: user_fqdn
                            
                            	match a hostname/domain
                            	**type**\:  :py:class:`UserFqdn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Profile.Default.Match.Identity, self).__init__()

                                self.yang_name = "identity"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4-address", ("ipv4_address", Native.Crypto.Isakmp.Profile.Default.Match.Identity.Ipv4Address)), ("address", ("address", Native.Crypto.Isakmp.Profile.Default.Match.Identity.Address)), ("host", ("host", Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host)), ("user-fqdn", ("user_fqdn", Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn))])
                                self._leafs = OrderedDict([
                                    ('group', (YLeaf(YType.str, 'group'), ['str'])),
                                ])
                                self.group = None

                                self.ipv4_address = Native.Crypto.Isakmp.Profile.Default.Match.Identity.Ipv4Address()
                                self.ipv4_address.parent = self
                                self._children_name_map["ipv4_address"] = "ipv4-address"

                                self.address = Native.Crypto.Isakmp.Profile.Default.Match.Identity.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"

                                self.host = Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.user_fqdn = Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn()
                                self.user_fqdn.parent = self
                                self._children_name_map["user_fqdn"] = "user-fqdn"
                                self._segment_path = lambda: "identity"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Match.Identity, ['group'], name, value)


                            class Ipv4Address(Entity):
                                """
                                
                                
                                .. attribute:: address
                                
                                	IP Address(es)
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vrf
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Profile.Default.Match.Identity.Ipv4Address, self).__init__()

                                    self.yang_name = "ipv4-address"
                                    self.yang_parent_name = "identity"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                        ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.address = None
                                    self.mask = None
                                    self.vrf = None
                                    self._segment_path = lambda: "ipv4-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Match.Identity.Ipv4Address, ['address', 'mask', 'vrf'], name, value)


                            class Address(Entity):
                                """
                                IP Address(es)
                                
                                .. attribute:: ipv6
                                
                                	IPv6 Address(es)
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: vrf
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Profile.Default.Match.Identity.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "identity"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.ipv6 = None
                                    self.vrf = None
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Match.Identity.Address, ['ipv6', 'vrf'], name, value)


                            class Host(Entity):
                                """
                                match a hostname/domain
                                
                                .. attribute:: domain_name
                                
                                	
                                	**type**\:  :py:class:`DomainName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host.DomainName>`
                                
                                .. attribute:: domain_match
                                
                                	
                                	**type**\:  :py:class:`DomainMatch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host.DomainMatch>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "identity"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("domain-name", ("domain_name", Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host.DomainName)), ("domain-match", ("domain_match", Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host.DomainMatch))])
                                    self._leafs = OrderedDict()

                                    self.domain_name = Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host.DomainName()
                                    self.domain_name.parent = self
                                    self._children_name_map["domain_name"] = "domain-name"

                                    self.domain_match = Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host.DomainMatch()
                                    self.domain_match.parent = self
                                    self._children_name_map["domain_match"] = "domain-match"
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host, [], name, value)


                                class DomainName(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host.DomainName, self).__init__()

                                        self.yang_name = "domain-name"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.name = None
                                        self.vrf = None
                                        self._segment_path = lambda: "domain-name"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host.DomainName, ['name', 'vrf'], name, value)


                                class DomainMatch(Entity):
                                    """
                                    
                                    
                                    .. attribute:: domain
                                    
                                    	match domain instead of exact
                                    	**type**\: str
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host.DomainMatch, self).__init__()

                                        self.yang_name = "domain-match"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.domain = None
                                        self.vrf = None
                                        self._segment_path = lambda: "domain-match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Match.Identity.Host.DomainMatch, ['domain', 'vrf'], name, value)


                            class UserFqdn(Entity):
                                """
                                match a hostname/domain
                                
                                .. attribute:: domain_name
                                
                                	
                                	**type**\:  :py:class:`DomainName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn.DomainName>`
                                
                                .. attribute:: domain_match
                                
                                	
                                	**type**\:  :py:class:`DomainMatch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn.DomainMatch>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn, self).__init__()

                                    self.yang_name = "user-fqdn"
                                    self.yang_parent_name = "identity"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("domain-name", ("domain_name", Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn.DomainName)), ("domain-match", ("domain_match", Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn.DomainMatch))])
                                    self._leafs = OrderedDict()

                                    self.domain_name = Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn.DomainName()
                                    self.domain_name.parent = self
                                    self._children_name_map["domain_name"] = "domain-name"

                                    self.domain_match = Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn.DomainMatch()
                                    self.domain_match.parent = self
                                    self._children_name_map["domain_match"] = "domain-match"
                                    self._segment_path = lambda: "user-fqdn"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn, [], name, value)


                                class DomainName(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn.DomainName, self).__init__()

                                        self.yang_name = "domain-name"
                                        self.yang_parent_name = "user-fqdn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.name = None
                                        self.vrf = None
                                        self._segment_path = lambda: "domain-name"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn.DomainName, ['name', 'vrf'], name, value)


                                class DomainMatch(Entity):
                                    """
                                    
                                    
                                    .. attribute:: domain
                                    
                                    	match domain instead of exact
                                    	**type**\: str
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-crypto'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn.DomainMatch, self).__init__()

                                        self.yang_name = "domain-match"
                                        self.yang_parent_name = "user-fqdn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.domain = None
                                        self.vrf = None
                                        self._segment_path = lambda: "domain-match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Crypto.Isakmp.Profile.Default.Match.Identity.UserFqdn.DomainMatch, ['domain', 'vrf'], name, value)


                    class SelfIdentity(Entity):
                        """
                        Specify Identity to use
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Default.SelfIdentity, self).__init__()

                            self.yang_name = "self-identity"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "self-identity"
                            self._is_frozen = True


                class Ca(Entity):
                    """
                    Specify certificate authorities to trust
                    
                    .. attribute:: trust_point
                    
                    	Cert authority trustpoint for RSA sig
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Profile.Ca, self).__init__()

                        self.yang_name = "ca"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trust_point', (YLeaf(YType.str, 'trust-point'), ['str'])),
                        ])
                        self.trust_point = None
                        self._segment_path = lambda: "ca"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Profile.Ca, ['trust_point'], name, value)


                class Client(Entity):
                    """
                    Specify client configuration settings
                    
                    .. attribute:: authentication
                    
                    	Use Extended Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Client.Authentication>`
                    
                    .. attribute:: configuration
                    
                    	Specify client configuration settings
                    	**type**\:  :py:class:`Configuration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Client.Configuration>`
                    
                    .. attribute:: pki
                    
                    	Use username in the crypto certificate for authorization
                    	**type**\:  :py:class:`Pki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Client.Pki>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Profile.Client, self).__init__()

                        self.yang_name = "client"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Crypto.Isakmp.Profile.Client.Authentication)), ("configuration", ("configuration", Native.Crypto.Isakmp.Profile.Client.Configuration)), ("pki", ("pki", Native.Crypto.Isakmp.Profile.Client.Pki))])
                        self._leafs = OrderedDict()

                        self.authentication = Native.Crypto.Isakmp.Profile.Client.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.configuration = Native.Crypto.Isakmp.Profile.Client.Configuration()
                        self.configuration.parent = self
                        self._children_name_map["configuration"] = "configuration"

                        self.pki = Native.Crypto.Isakmp.Profile.Client.Pki()
                        self.pki.parent = self
                        self._children_name_map["pki"] = "pki"
                        self._segment_path = lambda: "client"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Profile.Client, [], name, value)


                    class Authentication(Entity):
                        """
                        Use Extended Authentication
                        
                        .. attribute:: list
                        
                        	AAA authentication list to use
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Client.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.Client.Authentication, ['list'], name, value)


                    class Configuration(Entity):
                        """
                        Specify client configuration settings
                        
                        .. attribute:: address
                        
                        	Specify client network address configuration
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Client.Configuration.Address>`
                        
                        .. attribute:: group
                        
                        	Specify group profile attributes for client
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Client.Configuration, self).__init__()

                            self.yang_name = "configuration"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.enumeration, 'address'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Isakmp.Profile.Client.Configuration.Address')])),
                                ('group', (YLeaf(YType.str, 'group'), ['str'])),
                            ])
                            self.address = None
                            self.group = None
                            self._segment_path = lambda: "configuration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.Client.Configuration, ['address', 'group'], name, value)

                        class Address(Enum):
                            """
                            Address (Enum Class)

                            Specify client network address configuration

                            .. data:: initiate = 0

                            .. data:: respond = 1

                            """

                            initiate = Enum.YLeaf(0, "initiate")

                            respond = Enum.YLeaf(1, "respond")



                    class Pki(Entity):
                        """
                        Use username in the crypto certificate for authorization
                        
                        .. attribute:: authorization
                        
                        	User authorization parameters
                        	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Client.Pki.Authorization>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Client.Pki, self).__init__()

                            self.yang_name = "pki"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authorization", ("authorization", Native.Crypto.Isakmp.Profile.Client.Pki.Authorization))])
                            self._leafs = OrderedDict()

                            self.authorization = Native.Crypto.Isakmp.Profile.Client.Pki.Authorization()
                            self.authorization.parent = self
                            self._children_name_map["authorization"] = "authorization"
                            self._segment_path = lambda: "pki"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.Client.Pki, [], name, value)


                        class Authorization(Entity):
                            """
                            User authorization parameters
                            
                            .. attribute:: list
                            
                            	AAA user authorization list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Profile.Client.Pki.Authorization, self).__init__()

                                self.yang_name = "authorization"
                                self.yang_parent_name = "pki"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('list', (YLeaf(YType.str, 'list'), ['str'])),
                                ])
                                self.list = None
                                self._segment_path = lambda: "authorization"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Profile.Client.Pki.Authorization, ['list'], name, value)


                class Initiate(Entity):
                    """
                    Initiator property
                    
                    .. attribute:: mode
                    
                    	Phase 1 negotiation mode to use
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Initiate.Mode>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Profile.Initiate, self).__init__()

                        self.yang_name = "initiate"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Crypto.Isakmp.Profile.Initiate.Mode))])
                        self._leafs = OrderedDict()

                        self.mode = None
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "initiate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Profile.Initiate, [], name, value)


                    class Mode(Entity):
                        """
                        Phase 1 negotiation mode to use
                        
                        .. attribute:: aggressive
                        
                        	Start agressive mode negotiation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Initiate.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "initiate"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('aggressive', (YLeaf(YType.empty, 'aggressive'), ['Empty'])),
                            ])
                            self.aggressive = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.Initiate.Mode, ['aggressive'], name, value)


                class Isakmp_(Entity):
                    """
                    ISAKMP Authorization command
                    
                    .. attribute:: authorization
                    
                    	Authorization parameters
                    	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Isakmp_.Authorization>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Profile.Isakmp_, self).__init__()

                        self.yang_name = "isakmp"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authorization", ("authorization", Native.Crypto.Isakmp.Profile.Isakmp_.Authorization))])
                        self._leafs = OrderedDict()

                        self.authorization = Native.Crypto.Isakmp.Profile.Isakmp_.Authorization()
                        self.authorization.parent = self
                        self._children_name_map["authorization"] = "authorization"
                        self._segment_path = lambda: "isakmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Profile.Isakmp_, [], name, value)


                    class Authorization(Entity):
                        """
                        Authorization parameters.
                        
                        .. attribute:: list
                        
                        	AAA authorization list to use
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Isakmp_.Authorization, self).__init__()

                            self.yang_name = "authorization"
                            self.yang_parent_name = "isakmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "authorization"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.Isakmp_.Authorization, ['list'], name, value)


                class Keepalive(Entity):
                    """
                    Set a keepalive interval for use with IOS peers
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 10..3600
                    
                    .. attribute:: retry
                    
                    	Retry interval if keepalive fails
                    	**type**\: int
                    
                    	**range:** 2..60
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Profile.Keepalive, self).__init__()

                        self.yang_name = "keepalive"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                            ('retry', (YLeaf(YType.uint8, 'retry'), ['int'])),
                        ])
                        self.number = None
                        self.retry = None
                        self._segment_path = lambda: "keepalive"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Profile.Keepalive, ['number', 'retry'], name, value)


                class LocalAddress(Entity):
                    """
                    Interface to use for local address for this isakmp profile
                    
                    .. attribute:: bind_ip_address
                    
                    	Specify an IP address to bind to
                    	**type**\:  :py:class:`BindIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.LocalAddress.BindIpAddress>`
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.LocalAddress.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.LocalAddress.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.LocalAddress.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.LocalAddress.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Profile.LocalAddress, self).__init__()

                        self.yang_name = "local-address"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bind-ip-address", ("bind_ip_address", Native.Crypto.Isakmp.Profile.LocalAddress.BindIpAddress)), ("ATM-subinterface", ("atm_subinterface", Native.Crypto.Isakmp.Profile.LocalAddress.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Crypto.Isakmp.Profile.LocalAddress.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Crypto.Isakmp.Profile.LocalAddress.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Crypto.Isakmp.Profile.LocalAddress.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.bind_ip_address = Native.Crypto.Isakmp.Profile.LocalAddress.BindIpAddress()
                        self.bind_ip_address.parent = self
                        self._children_name_map["bind_ip_address"] = "bind-ip-address"

                        self.atm_subinterface = Native.Crypto.Isakmp.Profile.LocalAddress.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Crypto.Isakmp.Profile.LocalAddress.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Crypto.Isakmp.Profile.LocalAddress.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Crypto.Isakmp.Profile.LocalAddress.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "local-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Profile.LocalAddress, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class BindIpAddress(Entity):
                        """
                        Specify an IP address to bind to
                        
                        .. attribute:: ip_address
                        
                        	Specify an IP address to bind to
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: vrf
                        
                        	F\-VRF of the address
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.LocalAddress.BindIpAddress, self).__init__()

                            self.yang_name = "bind-ip-address"
                            self.yang_parent_name = "local-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.ip_address = None
                            self.vrf = None
                            self._segment_path = lambda: "bind-ip-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.LocalAddress.BindIpAddress, ['ip_address', 'vrf'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.LocalAddress.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "local-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.LocalAddress.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.LocalAddress.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "local-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.LocalAddress.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.LocalAddress.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "local-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.LocalAddress.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.LocalAddress.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "local-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.LocalAddress.PortChannelSubinterface, [u'port_channel'], name, value)


                class Match(Entity):
                    """
                    Match values of peer
                    
                    .. attribute:: certificate
                    
                    	Peer certificate attributes
                    	**type**\: str
                    
                    .. attribute:: identity
                    
                    	Peer identity
                    	**type**\:  :py:class:`Identity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Match.Identity>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Profile.Match, self).__init__()

                        self.yang_name = "match"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("identity", ("identity", Native.Crypto.Isakmp.Profile.Match.Identity))])
                        self._leafs = OrderedDict([
                            ('certificate', (YLeaf(YType.str, 'certificate'), ['str'])),
                        ])
                        self.certificate = None

                        self.identity = Native.Crypto.Isakmp.Profile.Match.Identity()
                        self.identity.parent = self
                        self._children_name_map["identity"] = "identity"
                        self._segment_path = lambda: "match"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Profile.Match, ['certificate'], name, value)


                    class Identity(Entity):
                        """
                        Peer identity
                        
                        .. attribute:: address
                        
                        	IP Address(es)
                        	**type**\: list of  		 :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Match.Identity.Address>`
                        
                        .. attribute:: ipv6_address
                        
                        	IP Address(es)
                        	**type**\: list of  		 :py:class:`Ipv6Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Match.Identity.Ipv6Address>`
                        
                        .. attribute:: group
                        
                        	Group name
                        	**type**\: str
                        
                        .. attribute:: host
                        
                        	match a hostname/domain
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Match.Identity.Host>`
                        
                        .. attribute:: user_fqdn
                        
                        	match a hostname/domain
                        	**type**\:  :py:class:`UserFqdn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.Match.Identity, self).__init__()

                            self.yang_name = "identity"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Isakmp.Profile.Match.Identity.Address)), ("ipv6-address", ("ipv6_address", Native.Crypto.Isakmp.Profile.Match.Identity.Ipv6Address)), ("host", ("host", Native.Crypto.Isakmp.Profile.Match.Identity.Host)), ("user-fqdn", ("user_fqdn", Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn))])
                            self._leafs = OrderedDict([
                                ('group', (YLeaf(YType.str, 'group'), ['str'])),
                            ])
                            self.group = None

                            self.host = Native.Crypto.Isakmp.Profile.Match.Identity.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.user_fqdn = Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn()
                            self.user_fqdn.parent = self
                            self._children_name_map["user_fqdn"] = "user-fqdn"

                            self.address = YList(self)
                            self.ipv6_address = YList(self)
                            self._segment_path = lambda: "identity"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.Match.Identity, ['group'], name, value)


                        class Address(Entity):
                            """
                            IP Address(es)
                            
                            .. attribute:: ip  (key)
                            
                            	IP Address(es)
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vrf
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Profile.Match.Identity.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "identity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip','mask']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.ip = None
                                self.mask = None
                                self.vrf = None
                                self._segment_path = lambda: "address" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Profile.Match.Identity.Address, ['ip', 'mask', 'vrf'], name, value)


                        class Ipv6Address(Entity):
                            """
                            IP Address(es)
                            
                            .. attribute:: ipv6  (key)
                            
                            	IPv6 Address(es)
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: vrf
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Profile.Match.Identity.Ipv6Address, self).__init__()

                                self.yang_name = "ipv6-address"
                                self.yang_parent_name = "identity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv6']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.ipv6 = None
                                self.vrf = None
                                self._segment_path = lambda: "ipv6-address" + "[ipv6='" + str(self.ipv6) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Profile.Match.Identity.Ipv6Address, ['ipv6', 'vrf'], name, value)


                        class Host(Entity):
                            """
                            match a hostname/domain
                            
                            .. attribute:: domain_name
                            
                            	
                            	**type**\:  :py:class:`DomainName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Match.Identity.Host.DomainName>`
                            
                            .. attribute:: domain_match
                            
                            	
                            	**type**\:  :py:class:`DomainMatch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Match.Identity.Host.DomainMatch>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Profile.Match.Identity.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "identity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("domain-name", ("domain_name", Native.Crypto.Isakmp.Profile.Match.Identity.Host.DomainName)), ("domain-match", ("domain_match", Native.Crypto.Isakmp.Profile.Match.Identity.Host.DomainMatch))])
                                self._leafs = OrderedDict()

                                self.domain_name = Native.Crypto.Isakmp.Profile.Match.Identity.Host.DomainName()
                                self.domain_name.parent = self
                                self._children_name_map["domain_name"] = "domain-name"

                                self.domain_match = Native.Crypto.Isakmp.Profile.Match.Identity.Host.DomainMatch()
                                self.domain_match.parent = self
                                self._children_name_map["domain_match"] = "domain-match"
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Profile.Match.Identity.Host, [], name, value)


                            class DomainName(Entity):
                                """
                                
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Profile.Match.Identity.Host.DomainName, self).__init__()

                                    self.yang_name = "domain-name"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.name = None
                                    self.vrf = None
                                    self._segment_path = lambda: "domain-name"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Profile.Match.Identity.Host.DomainName, ['name', 'vrf'], name, value)


                            class DomainMatch(Entity):
                                """
                                
                                
                                .. attribute:: domain
                                
                                	match domain instead of exact
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Profile.Match.Identity.Host.DomainMatch, self).__init__()

                                    self.yang_name = "domain-match"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.domain = None
                                    self.vrf = None
                                    self._segment_path = lambda: "domain-match"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Profile.Match.Identity.Host.DomainMatch, ['domain', 'vrf'], name, value)


                        class UserFqdn(Entity):
                            """
                            match a hostname/domain
                            
                            .. attribute:: domain_name
                            
                            	
                            	**type**\:  :py:class:`DomainName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn.DomainName>`
                            
                            .. attribute:: domain_match
                            
                            	
                            	**type**\:  :py:class:`DomainMatch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn.DomainMatch>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn, self).__init__()

                                self.yang_name = "user-fqdn"
                                self.yang_parent_name = "identity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("domain-name", ("domain_name", Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn.DomainName)), ("domain-match", ("domain_match", Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn.DomainMatch))])
                                self._leafs = OrderedDict()

                                self.domain_name = Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn.DomainName()
                                self.domain_name.parent = self
                                self._children_name_map["domain_name"] = "domain-name"

                                self.domain_match = Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn.DomainMatch()
                                self.domain_match.parent = self
                                self._children_name_map["domain_match"] = "domain-match"
                                self._segment_path = lambda: "user-fqdn"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn, [], name, value)


                            class DomainName(Entity):
                                """
                                
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn.DomainName, self).__init__()

                                    self.yang_name = "domain-name"
                                    self.yang_parent_name = "user-fqdn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.name = None
                                    self.vrf = None
                                    self._segment_path = lambda: "domain-name"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn.DomainName, ['name', 'vrf'], name, value)


                            class DomainMatch(Entity):
                                """
                                
                                
                                .. attribute:: domain
                                
                                	match domain instead of exact
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn.DomainMatch, self).__init__()

                                    self.yang_name = "domain-match"
                                    self.yang_parent_name = "user-fqdn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('domain', (YLeaf(YType.str, 'domain'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.domain = None
                                    self.vrf = None
                                    self._segment_path = lambda: "domain-match"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Isakmp.Profile.Match.Identity.UserFqdn.DomainMatch, ['domain', 'vrf'], name, value)


                class SelfIdentity(Entity):
                    """
                    Specify Identity to use
                    
                    .. attribute:: address
                    
                    	Use IPv4 address
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.SelfIdentity.Address>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fqdn
                    
                    	Use FQDN
                    	**type**\:  :py:class:`Fqdn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Isakmp.Profile.SelfIdentity.Fqdn>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: user_fqdn
                    
                    	Use user FQDN
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Isakmp.Profile.SelfIdentity, self).__init__()

                        self.yang_name = "self-identity"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.Crypto.Isakmp.Profile.SelfIdentity.Address)), ("fqdn", ("fqdn", Native.Crypto.Isakmp.Profile.SelfIdentity.Fqdn))])
                        self._leafs = OrderedDict([
                            ('user_fqdn', (YLeaf(YType.str, 'user-fqdn'), ['str'])),
                        ])
                        self.user_fqdn = None

                        self.address = None
                        self._children_name_map["address"] = "address"

                        self.fqdn = None
                        self._children_name_map["fqdn"] = "fqdn"
                        self._segment_path = lambda: "self-identity"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Isakmp.Profile.SelfIdentity, ['user_fqdn'], name, value)


                    class Address(Entity):
                        """
                        Use IPv4 address
                        
                        .. attribute:: ipv6
                        
                        	Use IPv6 address
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.SelfIdentity.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "self-identity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                            ])
                            self.ipv6 = None
                            self._segment_path = lambda: "address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.SelfIdentity.Address, ['ipv6'], name, value)


                    class Fqdn(Entity):
                        """
                        Use FQDN
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Isakmp.Profile.SelfIdentity.Fqdn, self).__init__()

                            self.yang_name = "fqdn"
                            self.yang_parent_name = "self-identity"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ])
                            self.id = None
                            self._segment_path = lambda: "fqdn"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Isakmp.Profile.SelfIdentity.Fqdn, ['id'], name, value)


            class Xauth(Entity):
                """
                Set Extended Authentication values
                
                .. attribute:: timeout
                
                	Set Extended Authentication timeout
                	**type**\: int
                
                	**range:** 5..90
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Isakmp.Xauth, self).__init__()

                    self.yang_name = "xauth"
                    self.yang_parent_name = "isakmp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('timeout', (YLeaf(YType.uint8, 'timeout'), ['int'])),
                    ])
                    self.timeout = None
                    self._segment_path = lambda: "xauth"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:isakmp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Isakmp.Xauth, ['timeout'], name, value)


        class Logging(Entity):
            """
            logging messages
            
            .. attribute:: ezvpn
            
            	ezvpn logging enable/disable
            	**type**\:  :py:class:`Ezvpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Logging.Ezvpn>`
            
            	**presence node**\: True
            
            .. attribute:: ikev2
            
            	logging IKEv2 sessions
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: session
            
            	logging up/down session
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Logging, self).__init__()

                self.yang_name = "logging"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ezvpn", ("ezvpn", Native.Crypto.Logging.Ezvpn))])
                self._leafs = OrderedDict([
                    ('ikev2', (YLeaf(YType.empty, 'ikev2'), ['Empty'])),
                    ('session', (YLeaf(YType.empty, 'session'), ['Empty'])),
                ])
                self.ikev2 = None
                self.session = None

                self.ezvpn = None
                self._children_name_map["ezvpn"] = "ezvpn"
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:logging"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Logging, ['ikev2', 'session'], name, value)


            class Ezvpn(Entity):
                """
                ezvpn logging enable/disable
                
                .. attribute:: group
                
                	ezvpn group
                	**type**\: str
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Logging.Ezvpn, self).__init__()

                    self.yang_name = "ezvpn"
                    self.yang_parent_name = "logging"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('group', (YLeaf(YType.str, 'group'), ['str'])),
                    ])
                    self.group = None
                    self._segment_path = lambda: "ezvpn"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:logging/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Logging.Ezvpn, ['group'], name, value)


        class CryptoMap(Entity):
            """
            
            
            .. attribute:: map
            
            	Enter a crypto map
            	**type**\: list of  		 :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.CryptoMap, self).__init__()

                self.yang_name = "crypto-map"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("map", ("map", Native.Crypto.CryptoMap.Map))])
                self._leafs = OrderedDict()

                self.map = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:crypto-map"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.CryptoMap, [], name, value)


            class Map(Entity):
                """
                Enter a crypto map
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: sequence_number  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: ipv6
                
                	IPv6 crypto map
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: keying
                
                	
                	**type**\:  :py:class:`Keying <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Keying>`
                
                .. attribute:: dynamic
                
                	Enable dynamic crypto map support
                	**type**\: str
                
                .. attribute:: profile
                
                	Enable crypto map as a crypto\-profile
                	**type**\: str
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default>`
                
                .. attribute:: description
                
                	Description of the crypto map statement policy
                	**type**\: str
                
                .. attribute:: dialer
                
                	Dialer related commands
                	**type**\:  :py:class:`Dialer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Dialer>`
                
                .. attribute:: match
                
                	Match values
                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Match>`
                
                .. attribute:: qos
                
                	Quality of Service related commands
                	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Qos>`
                
                .. attribute:: reverse_route
                
                	Reverse Route Injection
                	**type**\:  :py:class:`ReverseRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.ReverseRoute>`
                
                	**presence node**\: True
                
                .. attribute:: set
                
                	Set values for encryption/decryption
                	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.CryptoMap.Map, self).__init__()

                    self.yang_name = "map"
                    self.yang_parent_name = "crypto-map"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name','sequence_number']
                    self._child_classes = OrderedDict([("default", ("default", Native.Crypto.CryptoMap.Map.Default)), ("dialer", ("dialer", Native.Crypto.CryptoMap.Map.Dialer)), ("match", ("match", Native.Crypto.CryptoMap.Map.Match)), ("qos", ("qos", Native.Crypto.CryptoMap.Map.Qos)), ("reverse-route", ("reverse_route", Native.Crypto.CryptoMap.Map.ReverseRoute)), ("set", ("set", Native.Crypto.CryptoMap.Map.Set))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('sequence_number', (YLeaf(YType.uint16, 'sequence-number'), ['int'])),
                        ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                        ('keying', (YLeaf(YType.enumeration, 'keying'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.CryptoMap.Map.Keying')])),
                        ('dynamic', (YLeaf(YType.str, 'dynamic'), ['str'])),
                        ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.name = None
                    self.sequence_number = None
                    self.ipv6 = None
                    self.keying = None
                    self.dynamic = None
                    self.profile = None
                    self.description = None

                    self.default = Native.Crypto.CryptoMap.Map.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.dialer = Native.Crypto.CryptoMap.Map.Dialer()
                    self.dialer.parent = self
                    self._children_name_map["dialer"] = "dialer"

                    self.match = Native.Crypto.CryptoMap.Map.Match()
                    self.match.parent = self
                    self._children_name_map["match"] = "match"

                    self.qos = Native.Crypto.CryptoMap.Map.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"

                    self.reverse_route = None
                    self._children_name_map["reverse_route"] = "reverse-route"

                    self.set = Native.Crypto.CryptoMap.Map.Set()
                    self.set.parent = self
                    self._children_name_map["set"] = "set"
                    self._segment_path = lambda: "map" + "[name='" + str(self.name) + "']" + "[sequence-number='" + str(self.sequence_number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:crypto-map/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.CryptoMap.Map, ['name', 'sequence_number', 'ipv6', 'keying', 'dynamic', 'profile', 'description'], name, value)

                class Keying(Enum):
                    """
                    Keying (Enum Class)

                    .. data:: ipsec_isakmp = 0

                    .. data:: ipsec_manual = 1

                    .. data:: gdoi = 2

                    .. data:: ckm = 3

                    """

                    ipsec_isakmp = Enum.YLeaf(0, "ipsec-isakmp")

                    ipsec_manual = Enum.YLeaf(1, "ipsec-manual")

                    gdoi = Enum.YLeaf(2, "gdoi")

                    ckm = Enum.YLeaf(3, "ckm")



                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: description
                    
                    	Description of the crypto map statement policy
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dialer
                    
                    	Dialer related commands
                    	**type**\:  :py:class:`Dialer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Dialer>`
                    
                    .. attribute:: match
                    
                    	Match values
                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Match>`
                    
                    .. attribute:: qos
                    
                    	Quality of Service related commands
                    	**type**\:  :py:class:`Qos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Qos>`
                    
                    .. attribute:: reverse_route
                    
                    	Reverse Route Injection
                    	**type**\:  :py:class:`ReverseRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.ReverseRoute>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: set
                    
                    	Set values for encryption/decryption
                    	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Set>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.CryptoMap.Map.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dialer", ("dialer", Native.Crypto.CryptoMap.Map.Default.Dialer)), ("match", ("match", Native.Crypto.CryptoMap.Map.Default.Match)), ("qos", ("qos", Native.Crypto.CryptoMap.Map.Default.Qos)), ("reverse-route", ("reverse_route", Native.Crypto.CryptoMap.Map.Default.ReverseRoute)), ("set", ("set", Native.Crypto.CryptoMap.Map.Default.Set))])
                        self._leafs = OrderedDict([
                            ('description', (YLeaf(YType.empty, 'description'), ['Empty'])),
                        ])
                        self.description = None

                        self.dialer = Native.Crypto.CryptoMap.Map.Default.Dialer()
                        self.dialer.parent = self
                        self._children_name_map["dialer"] = "dialer"

                        self.match = Native.Crypto.CryptoMap.Map.Default.Match()
                        self.match.parent = self
                        self._children_name_map["match"] = "match"

                        self.qos = Native.Crypto.CryptoMap.Map.Default.Qos()
                        self.qos.parent = self
                        self._children_name_map["qos"] = "qos"

                        self.reverse_route = None
                        self._children_name_map["reverse_route"] = "reverse-route"

                        self.set = Native.Crypto.CryptoMap.Map.Default.Set()
                        self.set.parent = self
                        self._children_name_map["set"] = "set"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.CryptoMap.Map.Default, ['description'], name, value)


                    class Dialer(Entity):
                        """
                        Dialer related commands
                        
                        .. attribute:: pre_classify
                        
                        	Enable dialer list classification before initiating IKE
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.CryptoMap.Map.Default.Dialer, self).__init__()

                            self.yang_name = "dialer"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('pre_classify', (YLeaf(YType.empty, 'pre-classify'), ['Empty'])),
                            ])
                            self.pre_classify = None
                            self._segment_path = lambda: "dialer"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.CryptoMap.Map.Default.Dialer, ['pre_classify'], name, value)


                    class Match(Entity):
                        """
                        Match values
                        
                        .. attribute:: address
                        
                        	Match address of packets to encrypt
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.CryptoMap.Map.Default.Match, self).__init__()

                            self.yang_name = "match"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                            ])
                            self.address = None
                            self._segment_path = lambda: "match"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.CryptoMap.Map.Default.Match, ['address'], name, value)


                    class Qos(Entity):
                        """
                        Quality of Service related commands
                        
                        .. attribute:: pre_classify
                        
                        	Enable QOS classification before packets are tunnel encapsulated
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.CryptoMap.Map.Default.Qos, self).__init__()

                            self.yang_name = "qos"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('pre_classify', (YLeaf(YType.empty, 'pre-classify'), ['Empty'])),
                            ])
                            self.pre_classify = None
                            self._segment_path = lambda: "qos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.CryptoMap.Map.Default.Qos, ['pre_classify'], name, value)


                    class ReverseRoute(Entity):
                        """
                        Reverse Route Injection.
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.CryptoMap.Map.Default.ReverseRoute, self).__init__()

                            self.yang_name = "reverse-route"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "reverse-route"
                            self._is_frozen = True


                    class Set(Entity):
                        """
                        Set values for encryption/decryption
                        
                        .. attribute:: group
                        
                        	Set the san group parameters
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: identity
                        
                        	Identity restriction
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ikev2_profile
                        
                        	Specify ikev2 Profile
                        	**type**\: str
                        
                        .. attribute:: isakmp_profile
                        
                        	Specify isakmp Profile
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pfs
                        
                        	Specify pfs settings
                        	**type**\:  :py:class:`Pfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Set.Pfs>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: reverse_route
                        
                        	Reverse Route Injection
                        	**type**\:  :py:class:`ReverseRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Set.ReverseRoute>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: security_association
                        
                        	Security association parameters
                        	**type**\:  :py:class:`SecurityAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation>`
                        
                        .. attribute:: transform_set
                        
                        	Specify list of transform sets in priority order
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.CryptoMap.Map.Default.Set, self).__init__()

                            self.yang_name = "set"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pfs", ("pfs", Native.Crypto.CryptoMap.Map.Default.Set.Pfs)), ("reverse-route", ("reverse_route", Native.Crypto.CryptoMap.Map.Default.Set.ReverseRoute)), ("security-association", ("security_association", Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation))])
                            self._leafs = OrderedDict([
                                ('group', (YLeaf(YType.empty, 'group'), ['Empty'])),
                                ('identity', (YLeaf(YType.empty, 'identity'), ['Empty'])),
                                ('ikev2_profile', (YLeaf(YType.str, 'ikev2-profile'), ['str'])),
                                ('isakmp_profile', (YLeaf(YType.empty, 'isakmp-profile'), ['Empty'])),
                                ('transform_set', (YLeaf(YType.empty, 'transform-set'), ['Empty'])),
                            ])
                            self.group = None
                            self.identity = None
                            self.ikev2_profile = None
                            self.isakmp_profile = None
                            self.transform_set = None

                            self.pfs = None
                            self._children_name_map["pfs"] = "pfs"

                            self.reverse_route = None
                            self._children_name_map["reverse_route"] = "reverse-route"

                            self.security_association = Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation()
                            self.security_association.parent = self
                            self._children_name_map["security_association"] = "security-association"
                            self._segment_path = lambda: "set"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.CryptoMap.Map.Default.Set, ['group', 'identity', 'ikev2_profile', 'isakmp_profile', 'transform_set'], name, value)


                        class Pfs(Entity):
                            """
                            Specify pfs settings
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.CryptoMap.Map.Default.Set.Pfs, self).__init__()

                                self.yang_name = "pfs"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "pfs"
                                self._is_frozen = True


                        class ReverseRoute(Entity):
                            """
                            Reverse Route Injection
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.CryptoMap.Map.Default.Set.ReverseRoute, self).__init__()

                                self.yang_name = "reverse-route"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "reverse-route"
                                self._is_frozen = True


                        class SecurityAssociation(Entity):
                            """
                            Security association parameters
                            
                            .. attribute:: dfbit
                            
                            	Handling of encapsulated DF bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dummy
                            
                            	Enable transmitting dummy packets
                            	**type**\:  :py:class:`Dummy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Dummy>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ecn
                            
                            	Handling of ECN bit
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: idle_time_container
                            
                            	
                            	**type**\:  :py:class:`IdleTimeContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.IdleTimeContainer>`
                            
                            .. attribute:: level
                            
                            	specify a security association granularity level for identities
                            	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Level>`
                            
                            .. attribute:: lifetime
                            
                            	security association lifetime
                            	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Lifetime>`
                            
                            .. attribute:: replay
                            
                            	Set replay checking
                            	**type**\:  :py:class:`Replay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Replay>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation, self).__init__()

                                self.yang_name = "security-association"
                                self.yang_parent_name = "set"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dummy", ("dummy", Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Dummy)), ("idle-time-container", ("idle_time_container", Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.IdleTimeContainer)), ("lifetime", ("lifetime", Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Lifetime)), ("replay", ("replay", Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Replay))])
                                self._leafs = OrderedDict([
                                    ('dfbit', (YLeaf(YType.empty, 'dfbit'), ['Empty'])),
                                    ('ecn', (YLeaf(YType.empty, 'ecn'), ['Empty'])),
                                    ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Level')])),
                                ])
                                self.dfbit = None
                                self.ecn = None
                                self.level = None

                                self.dummy = None
                                self._children_name_map["dummy"] = "dummy"

                                self.idle_time_container = Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.IdleTimeContainer()
                                self.idle_time_container.parent = self
                                self._children_name_map["idle_time_container"] = "idle-time-container"

                                self.lifetime = Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Lifetime()
                                self.lifetime.parent = self
                                self._children_name_map["lifetime"] = "lifetime"

                                self.replay = Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Replay()
                                self.replay.parent = self
                                self._children_name_map["replay"] = "replay"
                                self._segment_path = lambda: "security-association"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation, ['dfbit', 'ecn', 'level'], name, value)

                            class Level(Enum):
                                """
                                Level (Enum Class)

                                specify a security association granularity level for identities

                                .. data:: per_host = 0

                                """

                                per_host = Enum.YLeaf(0, "per-host")



                            class Dummy(Entity):
                                """
                                Enable transmitting dummy packets
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Dummy, self).__init__()

                                    self.yang_name = "dummy"
                                    self.yang_parent_name = "security-association"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "dummy"
                                    self._is_frozen = True


                            class IdleTimeContainer(Entity):
                                """
                                
                                
                                .. attribute:: idle_time
                                
                                	Automatically delete IPSec SAs after a given idle period
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: default
                                
                                	All SAs idle\-out reset to default peer
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.IdleTimeContainer, self).__init__()

                                    self.yang_name = "idle-time-container"
                                    self.yang_parent_name = "security-association"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('idle_time', (YLeaf(YType.empty, 'idle-time'), ['Empty'])),
                                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ])
                                    self.idle_time = None
                                    self.default = None
                                    self._segment_path = lambda: "idle-time-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.IdleTimeContainer, ['idle_time', 'default'], name, value)


                            class Lifetime(Entity):
                                """
                                security association lifetime
                                
                                .. attribute:: days
                                
                                	Time\-based key duration in days
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: kilobytes
                                
                                	Volume\-based key duration
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: seconds
                                
                                	Time\-based key duration in seconds
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Lifetime, self).__init__()

                                    self.yang_name = "lifetime"
                                    self.yang_parent_name = "security-association"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('days', (YLeaf(YType.empty, 'days'), ['Empty'])),
                                        ('kilobytes', (YLeaf(YType.empty, 'kilobytes'), ['Empty'])),
                                        ('seconds', (YLeaf(YType.empty, 'seconds'), ['Empty'])),
                                    ])
                                    self.days = None
                                    self.kilobytes = None
                                    self.seconds = None
                                    self._segment_path = lambda: "lifetime"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Lifetime, ['days', 'kilobytes', 'seconds'], name, value)


                            class Replay(Entity):
                                """
                                Set replay checking.
                                
                                .. attribute:: disable
                                
                                	Disable replay checking
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: window_size
                                
                                	Set replay window size
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Replay, self).__init__()

                                    self.yang_name = "replay"
                                    self.yang_parent_name = "security-association"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ('window_size', (YLeaf(YType.empty, 'window-size'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self.window_size = None
                                    self._segment_path = lambda: "replay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.CryptoMap.Map.Default.Set.SecurityAssociation.Replay, ['disable', 'window_size'], name, value)


                class Dialer(Entity):
                    """
                    Dialer related commands
                    
                    .. attribute:: pre_classify
                    
                    	Enable dialer list classification before initiating IKE
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.CryptoMap.Map.Dialer, self).__init__()

                        self.yang_name = "dialer"
                        self.yang_parent_name = "map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pre_classify', (YLeaf(YType.empty, 'pre-classify'), ['Empty'])),
                        ])
                        self.pre_classify = None
                        self._segment_path = lambda: "dialer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.CryptoMap.Map.Dialer, ['pre_classify'], name, value)


                class Match(Entity):
                    """
                    Match values
                    
                    .. attribute:: address
                    
                    	Match address of packets to encrypt
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 100..199
                    
                    		**type**\: int
                    
                    			**range:** 2000..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.CryptoMap.Map.Match, self).__init__()

                        self.yang_name = "match"
                        self.yang_parent_name = "map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['int','int','str'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "match"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.CryptoMap.Map.Match, ['address'], name, value)


                class Qos(Entity):
                    """
                    Quality of Service related commands
                    
                    .. attribute:: pre_classify
                    
                    	Enable QOS classification before packets are tunnel encapsulated
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.CryptoMap.Map.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pre_classify', (YLeaf(YType.empty, 'pre-classify'), ['Empty'])),
                        ])
                        self.pre_classify = None
                        self._segment_path = lambda: "qos"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.CryptoMap.Map.Qos, ['pre_classify'], name, value)


                class ReverseRoute(Entity):
                    """
                    Reverse Route Injection.
                    
                    .. attribute:: remote_peer_conatiner
                    
                    	
                    	**type**\:  :py:class:`RemotePeerConatiner <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.ReverseRoute.RemotePeerConatiner>`
                    
                    .. attribute:: static
                    
                    	Create routes based on static ACLs permanently
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.CryptoMap.Map.ReverseRoute, self).__init__()

                        self.yang_name = "reverse-route"
                        self.yang_parent_name = "map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("remote-peer-conatiner", ("remote_peer_conatiner", Native.Crypto.CryptoMap.Map.ReverseRoute.RemotePeerConatiner))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                        ])
                        self.static = None

                        self.remote_peer_conatiner = Native.Crypto.CryptoMap.Map.ReverseRoute.RemotePeerConatiner()
                        self.remote_peer_conatiner.parent = self
                        self._children_name_map["remote_peer_conatiner"] = "remote-peer-conatiner"
                        self._segment_path = lambda: "reverse-route"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.CryptoMap.Map.ReverseRoute, ['static'], name, value)


                    class RemotePeerConatiner(Entity):
                        """
                        
                        
                        .. attribute:: remote_peer
                        
                        	Create route in route table for remote tunnel endpoint
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: gateway
                        
                        	Force encrypted traffic via this preferred gateway
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: static
                        
                        	Create routes based on static ACLs permanently
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.CryptoMap.Map.ReverseRoute.RemotePeerConatiner, self).__init__()

                            self.yang_name = "remote-peer-conatiner"
                            self.yang_parent_name = "reverse-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('remote_peer', (YLeaf(YType.str, 'remote-peer'), ['str','str'])),
                                ('gateway', (YLeaf(YType.empty, 'gateway'), ['Empty'])),
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                            ])
                            self.remote_peer = None
                            self.gateway = None
                            self.static = None
                            self._segment_path = lambda: "remote-peer-conatiner"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.CryptoMap.Map.ReverseRoute.RemotePeerConatiner, ['remote_peer', 'gateway', 'static'], name, value)


                class Set(Entity):
                    """
                    Set values for encryption/decryption
                    
                    .. attribute:: group
                    
                    	Set the san group parameters
                    	**type**\: str
                    
                    .. attribute:: identity
                    
                    	Identity restriction
                    	**type**\: str
                    
                    .. attribute:: ikev2_profile
                    
                    	Specify ikev2 Profile
                    	**type**\: str
                    
                    .. attribute:: isakmp_profile
                    
                    	Specify isakmp Profile
                    	**type**\: str
                    
                    .. attribute:: peer
                    
                    	Allowed Encryption/Decryption peer
                    	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.Peer>`
                    
                    .. attribute:: pfs
                    
                    	Specify pfs settings
                    	**type**\:  :py:class:`Pfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.Pfs>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: reverse_route
                    
                    	Reverse Route Injection
                    	**type**\:  :py:class:`ReverseRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.ReverseRoute>`
                    
                    .. attribute:: transform_set
                    
                    	Specify list of transform sets in priority order
                    	**type**\: list of str
                    
                    .. attribute:: security_association
                    
                    	Security association parameters
                    	**type**\:  :py:class:`SecurityAssociation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.CryptoMap.Map.Set, self).__init__()

                        self.yang_name = "set"
                        self.yang_parent_name = "map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peer", ("peer", Native.Crypto.CryptoMap.Map.Set.Peer)), ("pfs", ("pfs", Native.Crypto.CryptoMap.Map.Set.Pfs)), ("reverse-route", ("reverse_route", Native.Crypto.CryptoMap.Map.Set.ReverseRoute)), ("security-association", ("security_association", Native.Crypto.CryptoMap.Map.Set.SecurityAssociation))])
                        self._leafs = OrderedDict([
                            ('group', (YLeaf(YType.str, 'group'), ['str'])),
                            ('identity', (YLeaf(YType.str, 'identity'), ['str'])),
                            ('ikev2_profile', (YLeaf(YType.str, 'ikev2-profile'), ['str'])),
                            ('isakmp_profile', (YLeaf(YType.str, 'isakmp-profile'), ['str'])),
                            ('transform_set', (YLeafList(YType.str, 'transform-set'), ['str'])),
                        ])
                        self.group = None
                        self.identity = None
                        self.ikev2_profile = None
                        self.isakmp_profile = None
                        self.transform_set = []

                        self.peer = Native.Crypto.CryptoMap.Map.Set.Peer()
                        self.peer.parent = self
                        self._children_name_map["peer"] = "peer"

                        self.pfs = None
                        self._children_name_map["pfs"] = "pfs"

                        self.reverse_route = Native.Crypto.CryptoMap.Map.Set.ReverseRoute()
                        self.reverse_route.parent = self
                        self._children_name_map["reverse_route"] = "reverse-route"

                        self.security_association = Native.Crypto.CryptoMap.Map.Set.SecurityAssociation()
                        self.security_association.parent = self
                        self._children_name_map["security_association"] = "security-association"
                        self._segment_path = lambda: "set"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.CryptoMap.Map.Set, ['group', 'identity', 'ikev2_profile', 'isakmp_profile', 'transform_set'], name, value)


                    class Peer(Entity):
                        """
                        Allowed Encryption/Decryption peer.
                        
                        .. attribute:: address
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: default
                        
                        	Reset to default peer in list in the event of a failure
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dynamic
                        
                        	Resolve the peer address at the time of negotiation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.CryptoMap.Map.Set.Peer, self).__init__()

                            self.yang_name = "peer"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str','str','str'])),
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                            ])
                            self.address = None
                            self.default = None
                            self.dynamic = None
                            self._segment_path = lambda: "peer"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.CryptoMap.Map.Set.Peer, ['address', 'default', 'dynamic'], name, value)


                    class Pfs(Entity):
                        """
                        Specify pfs settings
                        
                        .. attribute:: group
                        
                        	
                        	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.Pfs.Group>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.CryptoMap.Map.Set.Pfs, self).__init__()

                            self.yang_name = "pfs"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('group', (YLeaf(YType.enumeration, 'group'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.CryptoMap.Map.Set.Pfs.Group')])),
                            ])
                            self.group = None
                            self._segment_path = lambda: "pfs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.CryptoMap.Map.Set.Pfs, ['group'], name, value)

                        class Group(Enum):
                            """
                            Group (Enum Class)

                            .. data:: group1 = 0

                            .. data:: group14 = 1

                            .. data:: group15 = 2

                            .. data:: group16 = 3

                            .. data:: group19 = 4

                            .. data:: group2 = 5

                            .. data:: group20 = 6

                            .. data:: group21 = 7

                            .. data:: group24 = 8

                            .. data:: group5 = 9

                            """

                            group1 = Enum.YLeaf(0, "group1")

                            group14 = Enum.YLeaf(1, "group14")

                            group15 = Enum.YLeaf(2, "group15")

                            group16 = Enum.YLeaf(3, "group16")

                            group19 = Enum.YLeaf(4, "group19")

                            group2 = Enum.YLeaf(5, "group2")

                            group20 = Enum.YLeaf(6, "group20")

                            group21 = Enum.YLeaf(7, "group21")

                            group24 = Enum.YLeaf(8, "group24")

                            group5 = Enum.YLeaf(9, "group5")



                    class ReverseRoute(Entity):
                        """
                        Reverse Route Injection
                        
                        .. attribute:: distance
                        
                        	Distance metric for this static route
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tag
                        
                        	Create route and tag it
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.CryptoMap.Map.Set.ReverseRoute, self).__init__()

                            self.yang_name = "reverse-route"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                ('tag', (YLeaf(YType.uint64, 'tag'), ['int'])),
                            ])
                            self.distance = None
                            self.tag = None
                            self._segment_path = lambda: "reverse-route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.CryptoMap.Map.Set.ReverseRoute, ['distance', 'tag'], name, value)


                    class SecurityAssociation(Entity):
                        """
                        Security association parameters
                        
                        .. attribute:: dfbit
                        
                        	Handling of encapsulated DF bit
                        	**type**\:  :py:class:`Dfbit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Dfbit>`
                        
                        .. attribute:: dummy
                        
                        	Enable transmitting dummy packets
                        	**type**\:  :py:class:`Dummy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Dummy>`
                        
                        .. attribute:: ecn
                        
                        	Handling of ECN bit
                        	**type**\:  :py:class:`Ecn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Ecn>`
                        
                        .. attribute:: idle_time_container
                        
                        	
                        	**type**\:  :py:class:`IdleTimeContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.IdleTimeContainer>`
                        
                        .. attribute:: lifetime
                        
                        	security association lifetime
                        	**type**\:  :py:class:`Lifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Lifetime>`
                        
                        .. attribute:: replay
                        
                        	Set replay checking
                        	**type**\:  :py:class:`Replay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Replay>`
                        
                        .. attribute:: level
                        
                        	specify a security association granularity level for identities
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Level>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.CryptoMap.Map.Set.SecurityAssociation, self).__init__()

                            self.yang_name = "security-association"
                            self.yang_parent_name = "set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dummy", ("dummy", Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Dummy)), ("idle-time-container", ("idle_time_container", Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.IdleTimeContainer)), ("lifetime", ("lifetime", Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Lifetime)), ("replay", ("replay", Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Replay))])
                            self._leafs = OrderedDict([
                                ('dfbit', (YLeaf(YType.enumeration, 'dfbit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.CryptoMap.Map.Set.SecurityAssociation.Dfbit')])),
                                ('ecn', (YLeaf(YType.enumeration, 'ecn'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.CryptoMap.Map.Set.SecurityAssociation.Ecn')])),
                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.CryptoMap.Map.Set.SecurityAssociation.Level')])),
                            ])
                            self.dfbit = None
                            self.ecn = None
                            self.level = None

                            self.dummy = Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Dummy()
                            self.dummy.parent = self
                            self._children_name_map["dummy"] = "dummy"

                            self.idle_time_container = Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.IdleTimeContainer()
                            self.idle_time_container.parent = self
                            self._children_name_map["idle_time_container"] = "idle-time-container"

                            self.lifetime = Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Lifetime()
                            self.lifetime.parent = self
                            self._children_name_map["lifetime"] = "lifetime"

                            self.replay = Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Replay()
                            self.replay.parent = self
                            self._children_name_map["replay"] = "replay"
                            self._segment_path = lambda: "security-association"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.CryptoMap.Map.Set.SecurityAssociation, ['dfbit', 'ecn', 'level'], name, value)

                        class Dfbit(Enum):
                            """
                            Dfbit (Enum Class)

                            Handling of encapsulated DF bit.

                            .. data:: clear = 0

                            .. data:: copy = 1

                            .. data:: set = 2

                            """

                            clear = Enum.YLeaf(0, "clear")

                            copy = Enum.YLeaf(1, "copy")

                            set = Enum.YLeaf(2, "set")


                        class Ecn(Enum):
                            """
                            Ecn (Enum Class)

                            Handling of ECN bit

                            .. data:: discard = 0

                            .. data:: propagate = 1

                            """

                            discard = Enum.YLeaf(0, "discard")

                            propagate = Enum.YLeaf(1, "propagate")


                        class Level(Enum):
                            """
                            Level (Enum Class)

                            specify a security association granularity level for identities

                            .. data:: per_host = 0

                            """

                            per_host = Enum.YLeaf(0, "per-host")



                        class Dummy(Entity):
                            """
                            Enable transmitting dummy packets
                            
                            .. attribute:: pps
                            
                            	Simulated traffic rate (in pps)
                            	**type**\: int
                            
                            	**range:** 0..25
                            
                            .. attribute:: seconds
                            
                            	Simulated traffic rate (in seconds)
                            	**type**\: int
                            
                            	**range:** 1..3600
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Dummy, self).__init__()

                                self.yang_name = "dummy"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pps', (YLeaf(YType.uint8, 'pps'), ['int'])),
                                    ('seconds', (YLeaf(YType.uint16, 'seconds'), ['int'])),
                                ])
                                self.pps = None
                                self.seconds = None
                                self._segment_path = lambda: "dummy"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Dummy, ['pps', 'seconds'], name, value)


                        class IdleTimeContainer(Entity):
                            """
                            
                            
                            .. attribute:: idle_time
                            
                            	Automatically delete IPSec SAs after a given idle period
                            	**type**\: int
                            
                            	**range:** 60..86400
                            
                            .. attribute:: default
                            
                            	All SAs idle\-out reset to default peer
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.IdleTimeContainer, self).__init__()

                                self.yang_name = "idle-time-container"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('idle_time', (YLeaf(YType.uint32, 'idle-time'), ['int'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ])
                                self.idle_time = None
                                self.default = None
                                self._segment_path = lambda: "idle-time-container"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.IdleTimeContainer, ['idle_time', 'default'], name, value)


                        class Lifetime(Entity):
                            """
                            security association lifetime
                            
                            .. attribute:: days
                            
                            	Time\-based key duration in days
                            	**type**\: int
                            
                            	**range:** 1..30
                            
                            .. attribute:: kilobytes
                            
                            	Volume\-based key duration
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 2560..4294967295
                            
                            		**type**\:  :py:class:`Kilobytes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Lifetime.Kilobytes>`
                            
                            .. attribute:: seconds
                            
                            	Time\-based key duration in seconds
                            	**type**\: int
                            
                            	**range:** 120..2592000
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Lifetime, self).__init__()

                                self.yang_name = "lifetime"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('days', (YLeaf(YType.uint8, 'days'), ['int'])),
                                    ('kilobytes', (YLeaf(YType.str, 'kilobytes'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.CryptoMap.Map.Set.SecurityAssociation.Lifetime.Kilobytes')])),
                                    ('seconds', (YLeaf(YType.uint64, 'seconds'), ['int'])),
                                ])
                                self.days = None
                                self.kilobytes = None
                                self.seconds = None
                                self._segment_path = lambda: "lifetime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Lifetime, ['days', 'kilobytes', 'seconds'], name, value)

                            class Kilobytes(Enum):
                                """
                                Kilobytes (Enum Class)

                                Volume\-based key duration

                                .. data:: disable = 0

                                """

                                disable = Enum.YLeaf(0, "disable")



                        class Replay(Entity):
                            """
                            Set replay checking.
                            
                            .. attribute:: disable
                            
                            	Disable replay checking
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: window_size
                            
                            	Set replay window size
                            	**type**\:  :py:class:`WindowSize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Replay.WindowSize>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Replay, self).__init__()

                                self.yang_name = "replay"
                                self.yang_parent_name = "security-association"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('window_size', (YLeaf(YType.enumeration, 'window-size'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.CryptoMap.Map.Set.SecurityAssociation.Replay.WindowSize')])),
                                ])
                                self.disable = None
                                self.window_size = None
                                self._segment_path = lambda: "replay"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.CryptoMap.Map.Set.SecurityAssociation.Replay, ['disable', 'window_size'], name, value)

                            class WindowSize(Enum):
                                """
                                WindowSize (Enum Class)

                                Set replay window size.

                                .. data:: Y_1024 = 0

                                .. data:: Y_128 = 1

                                .. data:: Y_256 = 2

                                .. data:: Y_512 = 3

                                .. data:: Y_64 = 4

                                """

                                Y_1024 = Enum.YLeaf(0, "1024")

                                Y_128 = Enum.YLeaf(1, "128")

                                Y_256 = Enum.YLeaf(2, "256")

                                Y_512 = Enum.YLeaf(3, "512")

                                Y_64 = Enum.YLeaf(4, "64")



        class MapIpv6Gdoi(Entity):
            """
            
            
            .. attribute:: map
            
            	Enter a crypto map
            	**type**\: list of  		 :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapIpv6Gdoi.Map>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.MapIpv6Gdoi, self).__init__()

                self.yang_name = "map-ipv6-gdoi"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("map", ("map", Native.Crypto.MapIpv6Gdoi.Map))])
                self._leafs = OrderedDict()

                self.map = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:map-ipv6-gdoi"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.MapIpv6Gdoi, [], name, value)


            class Map(Entity):
                """
                Enter a crypto map
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: ipv6
                
                	IPv6 crypto map
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: gdoi
                
                	Configure crypto map gdoi features
                	**type**\:  :py:class:`Gdoi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapIpv6Gdoi.Map.Gdoi>`
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapIpv6Gdoi.Map.Default>`
                
                .. attribute:: activate
                
                	Activate the crypto map to work in fail\-close mode
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: match
                
                	Match address of packets for fail\-close
                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapIpv6Gdoi.Map.Match>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.MapIpv6Gdoi.Map, self).__init__()

                    self.yang_name = "map"
                    self.yang_parent_name = "map-ipv6-gdoi"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("default", ("default", Native.Crypto.MapIpv6Gdoi.Map.Default)), ("match", ("match", Native.Crypto.MapIpv6Gdoi.Map.Match))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                        ('gdoi', (YLeaf(YType.enumeration, 'gdoi'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.MapIpv6Gdoi.Map.Gdoi')])),
                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                    ])
                    self.name = None
                    self.ipv6 = None
                    self.gdoi = None
                    self.activate = None

                    self.default = Native.Crypto.MapIpv6Gdoi.Map.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.match = Native.Crypto.MapIpv6Gdoi.Map.Match()
                    self.match.parent = self
                    self._children_name_map["match"] = "match"
                    self._segment_path = lambda: "map" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:map-ipv6-gdoi/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.MapIpv6Gdoi.Map, ['name', 'ipv6', 'gdoi', 'activate'], name, value)

                class Gdoi(Enum):
                    """
                    Gdoi (Enum Class)

                    Configure crypto map gdoi features

                    .. data:: fail_close = 0

                    """

                    fail_close = Enum.YLeaf(0, "fail-close")



                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: activate
                    
                    	Activate the crypto map to work in fail\-close mode
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: match
                    
                    	Match address of packets for fail\-close
                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapIpv6Gdoi.Map.Default.Match>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.MapIpv6Gdoi.Map.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("match", ("match", Native.Crypto.MapIpv6Gdoi.Map.Default.Match))])
                        self._leafs = OrderedDict([
                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                        ])
                        self.activate = None

                        self.match = Native.Crypto.MapIpv6Gdoi.Map.Default.Match()
                        self.match.parent = self
                        self._children_name_map["match"] = "match"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.MapIpv6Gdoi.Map.Default, ['activate'], name, value)


                    class Match(Entity):
                        """
                        Match address of packets for fail\-close
                        
                        .. attribute:: address
                        
                        	Match address of packets for fail\-close
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.MapIpv6Gdoi.Map.Default.Match, self).__init__()

                            self.yang_name = "match"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                            ])
                            self.address = None
                            self._segment_path = lambda: "match"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.MapIpv6Gdoi.Map.Default.Match, ['address'], name, value)


                class Match(Entity):
                    """
                    Match address of packets for fail\-close
                    
                    .. attribute:: address
                    
                    	Match address of packets for fail\-close
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 100..199
                    
                    		**type**\: int
                    
                    			**range:** 2000..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.MapIpv6Gdoi.Map.Match, self).__init__()

                        self.yang_name = "match"
                        self.yang_parent_name = "map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['int','int','str'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "match"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.MapIpv6Gdoi.Map.Match, ['address'], name, value)


        class MapClient(Entity):
            """
            
            
            .. attribute:: map
            
            	Enter a crypto map
            	**type**\: list of  		 :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapClient.Map>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.MapClient, self).__init__()

                self.yang_name = "map-client"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("map", ("map", Native.Crypto.MapClient.Map))])
                self._leafs = OrderedDict()

                self.map = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:map-client"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.MapClient, [], name, value)


            class Map(Entity):
                """
                Enter a crypto map
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: ipv6
                
                	IPv6 crypto map
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: client
                
                	Specify client configuration settings
                	**type**\:  :py:class:`Client <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapClient.Map.Client>`
                
                .. attribute:: isakmp
                
                	Specify isakmp configuration settings
                	**type**\:  :py:class:`Isakmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapClient.Map.Isakmp>`
                
                .. attribute:: isakmp_profile
                
                	Specify isakmp profile to use
                	**type**\: str
                
                .. attribute:: local_address
                
                	Interface to use for local address for this crypto map
                	**type**\: str
                
                .. attribute:: redundancy
                
                	High availability options for this map
                	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapClient.Map.Redundancy>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.MapClient.Map, self).__init__()

                    self.yang_name = "map"
                    self.yang_parent_name = "map-client"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("client", ("client", Native.Crypto.MapClient.Map.Client)), ("isakmp", ("isakmp", Native.Crypto.MapClient.Map.Isakmp)), ("redundancy", ("redundancy", Native.Crypto.MapClient.Map.Redundancy))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                        ('isakmp_profile', (YLeaf(YType.str, 'isakmp-profile'), ['str'])),
                        ('local_address', (YLeaf(YType.str, 'local-address'), ['str'])),
                    ])
                    self.name = None
                    self.ipv6 = None
                    self.isakmp_profile = None
                    self.local_address = None

                    self.client = Native.Crypto.MapClient.Map.Client()
                    self.client.parent = self
                    self._children_name_map["client"] = "client"

                    self.isakmp = Native.Crypto.MapClient.Map.Isakmp()
                    self.isakmp.parent = self
                    self._children_name_map["isakmp"] = "isakmp"

                    self.redundancy = Native.Crypto.MapClient.Map.Redundancy()
                    self.redundancy.parent = self
                    self._children_name_map["redundancy"] = "redundancy"
                    self._segment_path = lambda: "map" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:map-client/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.MapClient.Map, ['name', 'ipv6', 'isakmp_profile', 'local_address'], name, value)


                class Client(Entity):
                    """
                    Specify client configuration settings
                    
                    .. attribute:: accounting
                    
                    	Accounting parameters
                    	**type**\:  :py:class:`Accounting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapClient.Map.Client.Accounting>`
                    
                    .. attribute:: authentication
                    
                    	Use Extended Authentication
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapClient.Map.Client.Authentication>`
                    
                    .. attribute:: configuration
                    
                    	Specify client configuration settings
                    	**type**\:  :py:class:`Configuration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapClient.Map.Client.Configuration>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.MapClient.Map.Client, self).__init__()

                        self.yang_name = "client"
                        self.yang_parent_name = "map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("accounting", ("accounting", Native.Crypto.MapClient.Map.Client.Accounting)), ("authentication", ("authentication", Native.Crypto.MapClient.Map.Client.Authentication)), ("configuration", ("configuration", Native.Crypto.MapClient.Map.Client.Configuration))])
                        self._leafs = OrderedDict()

                        self.accounting = Native.Crypto.MapClient.Map.Client.Accounting()
                        self.accounting.parent = self
                        self._children_name_map["accounting"] = "accounting"

                        self.authentication = Native.Crypto.MapClient.Map.Client.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.configuration = Native.Crypto.MapClient.Map.Client.Configuration()
                        self.configuration.parent = self
                        self._children_name_map["configuration"] = "configuration"
                        self._segment_path = lambda: "client"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.MapClient.Map.Client, [], name, value)


                    class Accounting(Entity):
                        """
                        Accounting parameters.
                        
                        .. attribute:: list
                        
                        	AAA accounting list to use
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.MapClient.Map.Client.Accounting, self).__init__()

                            self.yang_name = "accounting"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "accounting"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.MapClient.Map.Client.Accounting, ['list'], name, value)


                    class Authentication(Entity):
                        """
                        Use Extended Authentication
                        
                        .. attribute:: list
                        
                        	AAA authentication list to use
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.MapClient.Map.Client.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('list', (YLeaf(YType.str, 'list'), ['str'])),
                            ])
                            self.list = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.MapClient.Map.Client.Authentication, ['list'], name, value)


                    class Configuration(Entity):
                        """
                        Specify client configuration settings
                        
                        .. attribute:: address
                        
                        	Specify client network address configuration
                        	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapClient.Map.Client.Configuration.Address>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.MapClient.Map.Client.Configuration, self).__init__()

                            self.yang_name = "configuration"
                            self.yang_parent_name = "client"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("address", ("address", Native.Crypto.MapClient.Map.Client.Configuration.Address))])
                            self._leafs = OrderedDict()

                            self.address = Native.Crypto.MapClient.Map.Client.Configuration.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._segment_path = lambda: "configuration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.MapClient.Map.Client.Configuration, [], name, value)


                        class Address(Entity):
                            """
                            Specify client network address configuration
                            
                            .. attribute:: initiate
                            
                            	Push the network address to the client
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: respond
                            
                            	Respond to network address requests from the client
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.MapClient.Map.Client.Configuration.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "configuration"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('initiate', (YLeaf(YType.empty, 'initiate'), ['Empty'])),
                                    ('respond', (YLeaf(YType.empty, 'respond'), ['Empty'])),
                                ])
                                self.initiate = None
                                self.respond = None
                                self._segment_path = lambda: "address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.MapClient.Map.Client.Configuration.Address, ['initiate', 'respond'], name, value)


                class Isakmp(Entity):
                    """
                    Specify isakmp configuration settings
                    
                    .. attribute:: authorization
                    
                    	Authorization parameters
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: list
                    
                    	AAA Authorization list to use
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.MapClient.Map.Isakmp, self).__init__()

                        self.yang_name = "isakmp"
                        self.yang_parent_name = "map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('authorization', (YLeaf(YType.empty, 'authorization'), ['Empty'])),
                            ('list', (YLeaf(YType.str, 'list'), ['str'])),
                        ])
                        self.authorization = None
                        self.list = None
                        self._segment_path = lambda: "isakmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.MapClient.Map.Isakmp, ['authorization', 'list'], name, value)


                class Redundancy(Entity):
                    """
                    High availability options for this map
                    
                    .. attribute:: replay_interval
                    
                    	HA replay counter interval
                    	**type**\:  :py:class:`ReplayInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.MapClient.Map.Redundancy.ReplayInterval>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.MapClient.Map.Redundancy, self).__init__()

                        self.yang_name = "redundancy"
                        self.yang_parent_name = "map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("replay-interval", ("replay_interval", Native.Crypto.MapClient.Map.Redundancy.ReplayInterval))])
                        self._leafs = OrderedDict()

                        self.replay_interval = Native.Crypto.MapClient.Map.Redundancy.ReplayInterval()
                        self.replay_interval.parent = self
                        self._children_name_map["replay_interval"] = "replay-interval"
                        self._segment_path = lambda: "redundancy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.MapClient.Map.Redundancy, [], name, value)


                    class ReplayInterval(Entity):
                        """
                        HA replay counter interval
                        
                        .. attribute:: inbound
                        
                        	HA inbound replay counter interval
                        	**type**\: int
                        
                        	**range:** 0..1000
                        
                        .. attribute:: outbound
                        
                        	HA outbound replay counter interval
                        	**type**\: int
                        
                        	**range:** 1000..10000
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.MapClient.Map.Redundancy.ReplayInterval, self).__init__()

                            self.yang_name = "replay-interval"
                            self.yang_parent_name = "redundancy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('inbound', (YLeaf(YType.uint32, 'inbound'), ['int'])),
                                ('outbound', (YLeaf(YType.uint32, 'outbound'), ['int'])),
                            ])
                            self.inbound = None
                            self.outbound = None
                            self._segment_path = lambda: "replay-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.MapClient.Map.Redundancy.ReplayInterval, ['inbound', 'outbound'], name, value)


        class Mib(Entity):
            """
            Configure Crypto\-related MIB Parameters
            
            .. attribute:: ipsec
            
            	onfigure MIB Parameters
            	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Mib.Ipsec>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Mib, self).__init__()

                self.yang_name = "mib"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ipsec", ("ipsec", Native.Crypto.Mib.Ipsec))])
                self._leafs = OrderedDict()

                self.ipsec = Native.Crypto.Mib.Ipsec()
                self.ipsec.parent = self
                self._children_name_map["ipsec"] = "ipsec"
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:mib"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Mib, [], name, value)


            class Ipsec(Entity):
                """
                onfigure MIB Parameters
                
                .. attribute:: flowmib
                
                	Configure IPSec Flow\-MIB Parameters
                	**type**\:  :py:class:`Flowmib <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Mib.Ipsec.Flowmib>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Mib.Ipsec, self).__init__()

                    self.yang_name = "ipsec"
                    self.yang_parent_name = "mib"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flowmib", ("flowmib", Native.Crypto.Mib.Ipsec.Flowmib))])
                    self._leafs = OrderedDict()

                    self.flowmib = Native.Crypto.Mib.Ipsec.Flowmib()
                    self.flowmib.parent = self
                    self._children_name_map["flowmib"] = "flowmib"
                    self._segment_path = lambda: "ipsec"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:mib/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Mib.Ipsec, [], name, value)


                class Flowmib(Entity):
                    """
                    Configure IPSec Flow\-MIB Parameters
                    
                    .. attribute:: history
                    
                    	Configure IPSEC Flow MIB History Parameters
                    	**type**\:  :py:class:`History <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Mib.Ipsec.Flowmib.History>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Mib.Ipsec.Flowmib, self).__init__()

                        self.yang_name = "flowmib"
                        self.yang_parent_name = "ipsec"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("history", ("history", Native.Crypto.Mib.Ipsec.Flowmib.History))])
                        self._leafs = OrderedDict()

                        self.history = Native.Crypto.Mib.Ipsec.Flowmib.History()
                        self.history.parent = self
                        self._children_name_map["history"] = "history"
                        self._segment_path = lambda: "flowmib"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:mib/ipsec/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Mib.Ipsec.Flowmib, [], name, value)


                    class History(Entity):
                        """
                        Configure IPSEC Flow MIB History Parameters
                        
                        .. attribute:: failure
                        
                        	Configure IPSEC Flow MIB Failure History Parameters
                        	**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Mib.Ipsec.Flowmib.History.Failure>`
                        
                        .. attribute:: tunnel
                        
                        	Configure IPSEC Flow MIB Tunnel History Parameters
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Mib.Ipsec.Flowmib.History.Tunnel>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Mib.Ipsec.Flowmib.History, self).__init__()

                            self.yang_name = "history"
                            self.yang_parent_name = "flowmib"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("failure", ("failure", Native.Crypto.Mib.Ipsec.Flowmib.History.Failure)), ("tunnel", ("tunnel", Native.Crypto.Mib.Ipsec.Flowmib.History.Tunnel))])
                            self._leafs = OrderedDict()

                            self.failure = Native.Crypto.Mib.Ipsec.Flowmib.History.Failure()
                            self.failure.parent = self
                            self._children_name_map["failure"] = "failure"

                            self.tunnel = Native.Crypto.Mib.Ipsec.Flowmib.History.Tunnel()
                            self.tunnel.parent = self
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "history"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:mib/ipsec/flowmib/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Mib.Ipsec.Flowmib.History, [], name, value)


                        class Failure(Entity):
                            """
                            Configure IPSEC Flow MIB Failure History Parameters
                            
                            .. attribute:: size
                            
                            	Configure IPSEC Flow MIB Tunnel Failure History Window Size
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Mib.Ipsec.Flowmib.History.Failure, self).__init__()

                                self.yang_name = "failure"
                                self.yang_parent_name = "history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('size', (YLeaf(YType.uint8, 'size'), ['int'])),
                                ])
                                self.size = None
                                self._segment_path = lambda: "failure"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:mib/ipsec/flowmib/history/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Mib.Ipsec.Flowmib.History.Failure, ['size'], name, value)


                        class Tunnel(Entity):
                            """
                            Configure IPSEC Flow MIB Tunnel History Parameters
                            
                            .. attribute:: size
                            
                            	Configure IPSEC Flow MIB Tunnel Failure History Window Size
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Mib.Ipsec.Flowmib.History.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('size', (YLeaf(YType.uint8, 'size'), ['int'])),
                                ])
                                self.size = None
                                self._segment_path = lambda: "tunnel"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:mib/ipsec/flowmib/history/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Mib.Ipsec.Flowmib.History.Tunnel, ['size'], name, value)


        class Pki(Entity):
            """
            Public Key components
            
            .. attribute:: authenticate
            
            	Get the CA certificate
            	**type**\: str
            
            .. attribute:: certificate
            
            	Actions on certificates
            	**type**\:  :py:class:`Certificate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate>`
            
            .. attribute:: crl
            
            	Actions on certificate revocation lists
            	**type**\:  :py:class:`Crl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Crl>`
            
            .. attribute:: enroll
            
            	Request a certificate from a CA
            	**type**\: str
            
            .. attribute:: export
            
            	Export certificate or PKCS12 file
            	**type**\: list of  		 :py:class:`Export <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Export>`
            
            .. attribute:: import_
            
            	Import certificate or PKCS12 file
            	**type**\: list of  		 :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Import>`
            
            .. attribute:: profile
            
            	Define a certificate profile
            	**type**\:  :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile>`
            
            .. attribute:: server
            
            	Enable IOS Certificate server
            	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Server>`
            
            .. attribute:: pki_server_no_submode
            
            	
            	**type**\:  :py:class:`PkiServerNoSubmode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.PkiServerNoSubmode>`
            
            .. attribute:: trustpoint
            
            	Define a CA trustpoint
            	**type**\: list of  		 :py:class:`Trustpoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpoint>`
            
            .. attribute:: token
            
            	Configure cryptographic token
            	**type**\:  :py:class:`Token <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Token>`
            
            .. attribute:: trustpool
            
            	Define CA trustpool
            	**type**\:  :py:class:`Trustpool <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpool>`
            
            .. attribute:: default
            
            	set default values for tokens
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Default>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Pki, self).__init__()

                self.yang_name = "pki"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("certificate", ("certificate", Native.Crypto.Pki.Certificate)), ("crl", ("crl", Native.Crypto.Pki.Crl)), ("export", ("export", Native.Crypto.Pki.Export)), ("import", ("import_", Native.Crypto.Pki.Import)), ("profile", ("profile", Native.Crypto.Pki.Profile)), ("server", ("server", Native.Crypto.Pki.Server)), ("pki-server-no-submode", ("pki_server_no_submode", Native.Crypto.Pki.PkiServerNoSubmode)), ("trustpoint", ("trustpoint", Native.Crypto.Pki.Trustpoint)), ("token", ("token", Native.Crypto.Pki.Token)), ("trustpool", ("trustpool", Native.Crypto.Pki.Trustpool)), ("default", ("default", Native.Crypto.Pki.Default))])
                self._leafs = OrderedDict([
                    ('authenticate', (YLeaf(YType.str, 'authenticate'), ['str'])),
                    ('enroll', (YLeaf(YType.str, 'enroll'), ['str'])),
                ])
                self.authenticate = None
                self.enroll = None

                self.certificate = Native.Crypto.Pki.Certificate()
                self.certificate.parent = self
                self._children_name_map["certificate"] = "certificate"

                self.crl = Native.Crypto.Pki.Crl()
                self.crl.parent = self
                self._children_name_map["crl"] = "crl"

                self.profile = Native.Crypto.Pki.Profile()
                self.profile.parent = self
                self._children_name_map["profile"] = "profile"

                self.server = Native.Crypto.Pki.Server()
                self.server.parent = self
                self._children_name_map["server"] = "server"

                self.pki_server_no_submode = Native.Crypto.Pki.PkiServerNoSubmode()
                self.pki_server_no_submode.parent = self
                self._children_name_map["pki_server_no_submode"] = "pki-server-no-submode"

                self.token = Native.Crypto.Pki.Token()
                self.token.parent = self
                self._children_name_map["token"] = "token"

                self.trustpool = Native.Crypto.Pki.Trustpool()
                self.trustpool.parent = self
                self._children_name_map["trustpool"] = "trustpool"

                self.default = Native.Crypto.Pki.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.export = YList(self)
                self.import_ = YList(self)
                self.trustpoint = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:pki"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Pki, ['authenticate', 'enroll'], name, value)


            class Certificate(Entity):
                """
                Actions on certificates
                
                .. attribute:: chain
                
                	Identify certificates
                	**type**\: list of  		 :py:class:`Chain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Chain>`
                
                .. attribute:: map
                
                	Define certificate attributes map
                	**type**\: list of  		 :py:class:`Map <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map>`
                
                .. attribute:: pool
                
                	Identify CA certificates in pool
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: query
                
                	Get certificates from the CA after reboot
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: storage
                
                	specify where to store certificates
                	**type**\:  :py:class:`Storage <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Storage>`
                
                .. attribute:: validate
                
                	Validate a certificate chain
                	**type**\: str
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Pki.Certificate, self).__init__()

                    self.yang_name = "certificate"
                    self.yang_parent_name = "pki"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("chain", ("chain", Native.Crypto.Pki.Certificate.Chain)), ("map", ("map", Native.Crypto.Pki.Certificate.Map)), ("storage", ("storage", Native.Crypto.Pki.Certificate.Storage))])
                    self._leafs = OrderedDict([
                        ('pool', (YLeaf(YType.empty, 'pool'), ['Empty'])),
                        ('query', (YLeaf(YType.empty, 'query'), ['Empty'])),
                        ('validate', (YLeaf(YType.str, 'validate'), ['str'])),
                    ])
                    self.pool = None
                    self.query = None
                    self.validate = None

                    self.storage = Native.Crypto.Pki.Certificate.Storage()
                    self.storage.parent = self
                    self._children_name_map["storage"] = "storage"

                    self.chain = YList(self)
                    self.map = YList(self)
                    self._segment_path = lambda: "certificate"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Pki.Certificate, ['pool', 'query', 'validate'], name, value)


                class Chain(Entity):
                    """
                    Identify certificates
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: certificate
                    
                    	Certificate issued by the CA
                    	**type**\: list of  		 :py:class:`Certificate_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Chain.Certificate_>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Certificate.Chain, self).__init__()

                        self.yang_name = "chain"
                        self.yang_parent_name = "certificate"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("certificate", ("certificate", Native.Crypto.Pki.Certificate.Chain.Certificate_))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.certificate = YList(self)
                        self._segment_path = lambda: "chain" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/certificate/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Certificate.Chain, ['name'], name, value)


                    class Certificate_(Entity):
                        """
                        Certificate issued by the CA
                        
                        .. attribute:: serial  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: certtype
                        
                        	
                        	**type**\:  :py:class:`Certtype <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Chain.Certificate_.Certtype>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Certificate.Chain.Certificate_, self).__init__()

                            self.yang_name = "certificate"
                            self.yang_parent_name = "chain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['serial']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('serial', (YLeaf(YType.str, 'serial'), ['str'])),
                                ('certtype', (YLeaf(YType.enumeration, 'certtype'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Pki.Certificate.Chain.Certificate_.Certtype')])),
                            ])
                            self.serial = None
                            self.certtype = None
                            self._segment_path = lambda: "certificate" + "[serial='" + str(self.serial) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Certificate.Chain.Certificate_, ['serial', 'certtype'], name, value)

                        class Certtype(Enum):
                            """
                            Certtype (Enum Class)

                            .. data:: ca = 0

                            .. data:: ra_encrypt = 1

                            .. data:: ra_general = 2

                            .. data:: ra_sign = 3

                            .. data:: rollover = 4

                            .. data:: self_signed = 5

                            """

                            ca = Enum.YLeaf(0, "ca")

                            ra_encrypt = Enum.YLeaf(1, "ra-encrypt")

                            ra_general = Enum.YLeaf(2, "ra-general")

                            ra_sign = Enum.YLeaf(3, "ra-sign")

                            rollover = Enum.YLeaf(4, "rollover")

                            self_signed = Enum.YLeaf(5, "self-signed")



                class Map(Entity):
                    """
                    Define certificate attributes map
                    
                    .. attribute:: tag  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: sequence
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: alt_subject_name
                    
                    	Alternate subject name
                    	**type**\:  :py:class:`AltSubjectName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.AltSubjectName>`
                    
                    .. attribute:: expires_on
                    
                    	Expiration date/time
                    	**type**\:  :py:class:`ExpiresOn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ExpiresOn>`
                    
                    .. attribute:: issuer_name
                    
                    	Certificate issuer name
                    	**type**\:  :py:class:`IssuerName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.IssuerName>`
                    
                    .. attribute:: name
                    
                    	Any subject name field
                    	**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.Name>`
                    
                    .. attribute:: serial_number
                    
                    	Certificate serial number (hexidecimal)
                    	**type**\:  :py:class:`SerialNumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.SerialNumber>`
                    
                    .. attribute:: subject_name
                    
                    	Certificate subject name
                    	**type**\:  :py:class:`SubjectName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.SubjectName>`
                    
                    .. attribute:: unstructured_subject_name
                    
                    	Unstructured subject name
                    	**type**\:  :py:class:`UnstructuredSubjectName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.UnstructuredSubjectName>`
                    
                    .. attribute:: valid_start
                    
                    	Valid after date/time
                    	**type**\:  :py:class:`ValidStart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ValidStart>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Certificate.Map, self).__init__()

                        self.yang_name = "map"
                        self.yang_parent_name = "certificate"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['tag']
                        self._child_classes = OrderedDict([("alt-subject-name", ("alt_subject_name", Native.Crypto.Pki.Certificate.Map.AltSubjectName)), ("expires-on", ("expires_on", Native.Crypto.Pki.Certificate.Map.ExpiresOn)), ("issuer-name", ("issuer_name", Native.Crypto.Pki.Certificate.Map.IssuerName)), ("name", ("name", Native.Crypto.Pki.Certificate.Map.Name)), ("serial-number", ("serial_number", Native.Crypto.Pki.Certificate.Map.SerialNumber)), ("subject-name", ("subject_name", Native.Crypto.Pki.Certificate.Map.SubjectName)), ("unstructured-subject-name", ("unstructured_subject_name", Native.Crypto.Pki.Certificate.Map.UnstructuredSubjectName)), ("valid-start", ("valid_start", Native.Crypto.Pki.Certificate.Map.ValidStart))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('sequence', (YLeaf(YType.uint16, 'sequence'), ['int'])),
                        ])
                        self.tag = None
                        self.sequence = None

                        self.alt_subject_name = Native.Crypto.Pki.Certificate.Map.AltSubjectName()
                        self.alt_subject_name.parent = self
                        self._children_name_map["alt_subject_name"] = "alt-subject-name"

                        self.expires_on = Native.Crypto.Pki.Certificate.Map.ExpiresOn()
                        self.expires_on.parent = self
                        self._children_name_map["expires_on"] = "expires-on"

                        self.issuer_name = Native.Crypto.Pki.Certificate.Map.IssuerName()
                        self.issuer_name.parent = self
                        self._children_name_map["issuer_name"] = "issuer-name"

                        self.name = Native.Crypto.Pki.Certificate.Map.Name()
                        self.name.parent = self
                        self._children_name_map["name"] = "name"

                        self.serial_number = Native.Crypto.Pki.Certificate.Map.SerialNumber()
                        self.serial_number.parent = self
                        self._children_name_map["serial_number"] = "serial-number"

                        self.subject_name = Native.Crypto.Pki.Certificate.Map.SubjectName()
                        self.subject_name.parent = self
                        self._children_name_map["subject_name"] = "subject-name"

                        self.unstructured_subject_name = Native.Crypto.Pki.Certificate.Map.UnstructuredSubjectName()
                        self.unstructured_subject_name.parent = self
                        self._children_name_map["unstructured_subject_name"] = "unstructured-subject-name"

                        self.valid_start = Native.Crypto.Pki.Certificate.Map.ValidStart()
                        self.valid_start.parent = self
                        self._children_name_map["valid_start"] = "valid-start"
                        self._segment_path = lambda: "map" + "[tag='" + str(self.tag) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/certificate/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Certificate.Map, ['tag', 'sequence'], name, value)


                    class AltSubjectName(Entity):
                        """
                        Alternate subject name
                        
                        .. attribute:: co
                        
                        	Contains
                        	**type**\: str
                        
                        .. attribute:: eq
                        
                        	Equal
                        	**type**\: str
                        
                        .. attribute:: nc
                        
                        	Does not contain
                        	**type**\: str
                        
                        .. attribute:: ne
                        
                        	Not Equal
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Certificate.Map.AltSubjectName, self).__init__()

                            self.yang_name = "alt-subject-name"
                            self.yang_parent_name = "map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('co', (YLeaf(YType.str, 'co'), ['str'])),
                                ('eq', (YLeaf(YType.str, 'eq'), ['str'])),
                                ('nc', (YLeaf(YType.str, 'nc'), ['str'])),
                                ('ne', (YLeaf(YType.str, 'ne'), ['str'])),
                            ])
                            self.co = None
                            self.eq = None
                            self.nc = None
                            self.ne = None
                            self._segment_path = lambda: "alt-subject-name"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Certificate.Map.AltSubjectName, ['co', 'eq', 'nc', 'ne'], name, value)


                    class ExpiresOn(Entity):
                        """
                        Expiration date/time
                        
                        .. attribute:: eq
                        
                        	Equal
                        	**type**\:  :py:class:`Eq <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ExpiresOn.Eq>`
                        
                        .. attribute:: ge
                        
                        	Greater than or equal
                        	**type**\:  :py:class:`Ge <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ge>`
                        
                        .. attribute:: lt
                        
                        	Less Than
                        	**type**\:  :py:class:`Lt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ExpiresOn.Lt>`
                        
                        .. attribute:: ne
                        
                        	Not Equal
                        	**type**\:  :py:class:`Ne <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ne>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Certificate.Map.ExpiresOn, self).__init__()

                            self.yang_name = "expires-on"
                            self.yang_parent_name = "map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("eq", ("eq", Native.Crypto.Pki.Certificate.Map.ExpiresOn.Eq)), ("ge", ("ge", Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ge)), ("lt", ("lt", Native.Crypto.Pki.Certificate.Map.ExpiresOn.Lt)), ("ne", ("ne", Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ne))])
                            self._leafs = OrderedDict()

                            self.eq = Native.Crypto.Pki.Certificate.Map.ExpiresOn.Eq()
                            self.eq.parent = self
                            self._children_name_map["eq"] = "eq"

                            self.ge = Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ge()
                            self.ge.parent = self
                            self._children_name_map["ge"] = "ge"

                            self.lt = Native.Crypto.Pki.Certificate.Map.ExpiresOn.Lt()
                            self.lt.parent = self
                            self._children_name_map["lt"] = "lt"

                            self.ne = Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ne()
                            self.ne.parent = self
                            self._children_name_map["ne"] = "ne"
                            self._segment_path = lambda: "expires-on"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ExpiresOn, [], name, value)


                        class Eq(Entity):
                            """
                            Equal
                            
                            .. attribute:: time
                            
                            	
                            	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ExpiresOn.Eq.Time>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Eq, self).__init__()

                                self.yang_name = "eq"
                                self.yang_parent_name = "expires-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("time", ("time", Native.Crypto.Pki.Certificate.Map.ExpiresOn.Eq.Time))])
                                self._leafs = OrderedDict()

                                self.time = Native.Crypto.Pki.Certificate.Map.ExpiresOn.Eq.Time()
                                self.time.parent = self
                                self._children_name_map["time"] = "time"
                                self._segment_path = lambda: "eq"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Eq, [], name, value)


                            class Time(Entity):
                                """
                                
                                
                                .. attribute:: date1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month1
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: date2
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month2
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: year
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1993..2035
                                
                                .. attribute:: clock
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: utc
                                
                                	Time is in UTC (not local Time Zone)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Eq.Time, self).__init__()

                                    self.yang_name = "time"
                                    self.yang_parent_name = "eq"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('date1', (YLeaf(YType.uint8, 'date1'), ['int'])),
                                        ('month1', (YLeaf(YType.str, 'month1'), ['str'])),
                                        ('date2', (YLeaf(YType.uint8, 'date2'), ['int'])),
                                        ('month2', (YLeaf(YType.str, 'month2'), ['str'])),
                                        ('year', (YLeaf(YType.uint16, 'year'), ['int'])),
                                        ('clock', (YLeaf(YType.str, 'clock'), ['str'])),
                                        ('utc', (YLeaf(YType.empty, 'utc'), ['Empty'])),
                                    ])
                                    self.date1 = None
                                    self.month1 = None
                                    self.date2 = None
                                    self.month2 = None
                                    self.year = None
                                    self.clock = None
                                    self.utc = None
                                    self._segment_path = lambda: "time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Eq.Time, ['date1', 'month1', 'date2', 'month2', 'year', 'clock', 'utc'], name, value)


                        class Ge(Entity):
                            """
                            Greater than or equal
                            
                            .. attribute:: time
                            
                            	
                            	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ge.Time>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ge, self).__init__()

                                self.yang_name = "ge"
                                self.yang_parent_name = "expires-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("time", ("time", Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ge.Time))])
                                self._leafs = OrderedDict()

                                self.time = Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ge.Time()
                                self.time.parent = self
                                self._children_name_map["time"] = "time"
                                self._segment_path = lambda: "ge"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ge, [], name, value)


                            class Time(Entity):
                                """
                                
                                
                                .. attribute:: date1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month1
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: date2
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month2
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: year
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1993..2035
                                
                                .. attribute:: clock
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: utc
                                
                                	Time is in UTC (not local Time Zone)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ge.Time, self).__init__()

                                    self.yang_name = "time"
                                    self.yang_parent_name = "ge"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('date1', (YLeaf(YType.uint8, 'date1'), ['int'])),
                                        ('month1', (YLeaf(YType.str, 'month1'), ['str'])),
                                        ('date2', (YLeaf(YType.uint8, 'date2'), ['int'])),
                                        ('month2', (YLeaf(YType.str, 'month2'), ['str'])),
                                        ('year', (YLeaf(YType.uint16, 'year'), ['int'])),
                                        ('clock', (YLeaf(YType.str, 'clock'), ['str'])),
                                        ('utc', (YLeaf(YType.empty, 'utc'), ['Empty'])),
                                    ])
                                    self.date1 = None
                                    self.month1 = None
                                    self.date2 = None
                                    self.month2 = None
                                    self.year = None
                                    self.clock = None
                                    self.utc = None
                                    self._segment_path = lambda: "time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ge.Time, ['date1', 'month1', 'date2', 'month2', 'year', 'clock', 'utc'], name, value)


                        class Lt(Entity):
                            """
                            Less Than
                            
                            .. attribute:: time
                            
                            	
                            	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ExpiresOn.Lt.Time>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Lt, self).__init__()

                                self.yang_name = "lt"
                                self.yang_parent_name = "expires-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("time", ("time", Native.Crypto.Pki.Certificate.Map.ExpiresOn.Lt.Time))])
                                self._leafs = OrderedDict()

                                self.time = Native.Crypto.Pki.Certificate.Map.ExpiresOn.Lt.Time()
                                self.time.parent = self
                                self._children_name_map["time"] = "time"
                                self._segment_path = lambda: "lt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Lt, [], name, value)


                            class Time(Entity):
                                """
                                
                                
                                .. attribute:: date1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month1
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: date2
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month2
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: year
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1993..2035
                                
                                .. attribute:: clock
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: utc
                                
                                	Time is in UTC (not local Time Zone)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Lt.Time, self).__init__()

                                    self.yang_name = "time"
                                    self.yang_parent_name = "lt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('date1', (YLeaf(YType.uint8, 'date1'), ['int'])),
                                        ('month1', (YLeaf(YType.str, 'month1'), ['str'])),
                                        ('date2', (YLeaf(YType.uint8, 'date2'), ['int'])),
                                        ('month2', (YLeaf(YType.str, 'month2'), ['str'])),
                                        ('year', (YLeaf(YType.uint16, 'year'), ['int'])),
                                        ('clock', (YLeaf(YType.str, 'clock'), ['str'])),
                                        ('utc', (YLeaf(YType.empty, 'utc'), ['Empty'])),
                                    ])
                                    self.date1 = None
                                    self.month1 = None
                                    self.date2 = None
                                    self.month2 = None
                                    self.year = None
                                    self.clock = None
                                    self.utc = None
                                    self._segment_path = lambda: "time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Lt.Time, ['date1', 'month1', 'date2', 'month2', 'year', 'clock', 'utc'], name, value)


                        class Ne(Entity):
                            """
                            Not Equal
                            
                            .. attribute:: time
                            
                            	
                            	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ne.Time>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ne, self).__init__()

                                self.yang_name = "ne"
                                self.yang_parent_name = "expires-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("time", ("time", Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ne.Time))])
                                self._leafs = OrderedDict()

                                self.time = Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ne.Time()
                                self.time.parent = self
                                self._children_name_map["time"] = "time"
                                self._segment_path = lambda: "ne"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ne, [], name, value)


                            class Time(Entity):
                                """
                                
                                
                                .. attribute:: date1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month1
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: date2
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month2
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: year
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1993..2035
                                
                                .. attribute:: clock
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: utc
                                
                                	Time is in UTC (not local Time Zone)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ne.Time, self).__init__()

                                    self.yang_name = "time"
                                    self.yang_parent_name = "ne"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('date1', (YLeaf(YType.uint8, 'date1'), ['int'])),
                                        ('month1', (YLeaf(YType.str, 'month1'), ['str'])),
                                        ('date2', (YLeaf(YType.uint8, 'date2'), ['int'])),
                                        ('month2', (YLeaf(YType.str, 'month2'), ['str'])),
                                        ('year', (YLeaf(YType.uint16, 'year'), ['int'])),
                                        ('clock', (YLeaf(YType.str, 'clock'), ['str'])),
                                        ('utc', (YLeaf(YType.empty, 'utc'), ['Empty'])),
                                    ])
                                    self.date1 = None
                                    self.month1 = None
                                    self.date2 = None
                                    self.month2 = None
                                    self.year = None
                                    self.clock = None
                                    self.utc = None
                                    self._segment_path = lambda: "time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ExpiresOn.Ne.Time, ['date1', 'month1', 'date2', 'month2', 'year', 'clock', 'utc'], name, value)


                    class IssuerName(Entity):
                        """
                        Certificate issuer name
                        
                        .. attribute:: co
                        
                        	Contains
                        	**type**\: str
                        
                        .. attribute:: eq
                        
                        	Equal
                        	**type**\: str
                        
                        .. attribute:: nc
                        
                        	Does not contain
                        	**type**\: str
                        
                        .. attribute:: ne
                        
                        	Not Equal
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Certificate.Map.IssuerName, self).__init__()

                            self.yang_name = "issuer-name"
                            self.yang_parent_name = "map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('co', (YLeaf(YType.str, 'co'), ['str'])),
                                ('eq', (YLeaf(YType.str, 'eq'), ['str'])),
                                ('nc', (YLeaf(YType.str, 'nc'), ['str'])),
                                ('ne', (YLeaf(YType.str, 'ne'), ['str'])),
                            ])
                            self.co = None
                            self.eq = None
                            self.nc = None
                            self.ne = None
                            self._segment_path = lambda: "issuer-name"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Certificate.Map.IssuerName, ['co', 'eq', 'nc', 'ne'], name, value)


                    class Name(Entity):
                        """
                        Any subject name field
                        
                        .. attribute:: co
                        
                        	Contains
                        	**type**\: str
                        
                        .. attribute:: eq
                        
                        	Equal
                        	**type**\: str
                        
                        .. attribute:: nc
                        
                        	Does not contain
                        	**type**\: str
                        
                        .. attribute:: ne
                        
                        	Not Equal
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Certificate.Map.Name, self).__init__()

                            self.yang_name = "name"
                            self.yang_parent_name = "map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('co', (YLeaf(YType.str, 'co'), ['str'])),
                                ('eq', (YLeaf(YType.str, 'eq'), ['str'])),
                                ('nc', (YLeaf(YType.str, 'nc'), ['str'])),
                                ('ne', (YLeaf(YType.str, 'ne'), ['str'])),
                            ])
                            self.co = None
                            self.eq = None
                            self.nc = None
                            self.ne = None
                            self._segment_path = lambda: "name"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Certificate.Map.Name, ['co', 'eq', 'nc', 'ne'], name, value)


                    class SerialNumber(Entity):
                        """
                        Certificate serial number (hexidecimal)
                        
                        .. attribute:: co
                        
                        	Contains
                        	**type**\: str
                        
                        .. attribute:: eq
                        
                        	Equal
                        	**type**\: str
                        
                        .. attribute:: nc
                        
                        	Does not contain
                        	**type**\: str
                        
                        .. attribute:: ne
                        
                        	Not Equal
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Certificate.Map.SerialNumber, self).__init__()

                            self.yang_name = "serial-number"
                            self.yang_parent_name = "map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('co', (YLeaf(YType.str, 'co'), ['str'])),
                                ('eq', (YLeaf(YType.str, 'eq'), ['str'])),
                                ('nc', (YLeaf(YType.str, 'nc'), ['str'])),
                                ('ne', (YLeaf(YType.str, 'ne'), ['str'])),
                            ])
                            self.co = None
                            self.eq = None
                            self.nc = None
                            self.ne = None
                            self._segment_path = lambda: "serial-number"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Certificate.Map.SerialNumber, ['co', 'eq', 'nc', 'ne'], name, value)


                    class SubjectName(Entity):
                        """
                        Certificate subject name
                        
                        .. attribute:: co
                        
                        	Contains
                        	**type**\: str
                        
                        .. attribute:: eq
                        
                        	Equal
                        	**type**\: str
                        
                        .. attribute:: nc
                        
                        	Does not contain
                        	**type**\: str
                        
                        .. attribute:: ne
                        
                        	Not Equal
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Certificate.Map.SubjectName, self).__init__()

                            self.yang_name = "subject-name"
                            self.yang_parent_name = "map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('co', (YLeaf(YType.str, 'co'), ['str'])),
                                ('eq', (YLeaf(YType.str, 'eq'), ['str'])),
                                ('nc', (YLeaf(YType.str, 'nc'), ['str'])),
                                ('ne', (YLeaf(YType.str, 'ne'), ['str'])),
                            ])
                            self.co = None
                            self.eq = None
                            self.nc = None
                            self.ne = None
                            self._segment_path = lambda: "subject-name"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Certificate.Map.SubjectName, ['co', 'eq', 'nc', 'ne'], name, value)


                    class UnstructuredSubjectName(Entity):
                        """
                        Unstructured subject name
                        
                        .. attribute:: co
                        
                        	Contains
                        	**type**\: str
                        
                        .. attribute:: eq
                        
                        	Equal
                        	**type**\: str
                        
                        .. attribute:: nc
                        
                        	Does not contain
                        	**type**\: str
                        
                        .. attribute:: ne
                        
                        	Not Equal
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Certificate.Map.UnstructuredSubjectName, self).__init__()

                            self.yang_name = "unstructured-subject-name"
                            self.yang_parent_name = "map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('co', (YLeaf(YType.str, 'co'), ['str'])),
                                ('eq', (YLeaf(YType.str, 'eq'), ['str'])),
                                ('nc', (YLeaf(YType.str, 'nc'), ['str'])),
                                ('ne', (YLeaf(YType.str, 'ne'), ['str'])),
                            ])
                            self.co = None
                            self.eq = None
                            self.nc = None
                            self.ne = None
                            self._segment_path = lambda: "unstructured-subject-name"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Certificate.Map.UnstructuredSubjectName, ['co', 'eq', 'nc', 'ne'], name, value)


                    class ValidStart(Entity):
                        """
                        Valid after date/time
                        
                        .. attribute:: eq
                        
                        	Equal
                        	**type**\:  :py:class:`Eq <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ValidStart.Eq>`
                        
                        .. attribute:: ge
                        
                        	Greater than or equal
                        	**type**\:  :py:class:`Ge <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ValidStart.Ge>`
                        
                        .. attribute:: lt
                        
                        	Less Than
                        	**type**\:  :py:class:`Lt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ValidStart.Lt>`
                        
                        .. attribute:: ne
                        
                        	Not Equal
                        	**type**\:  :py:class:`Ne <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ValidStart.Ne>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Certificate.Map.ValidStart, self).__init__()

                            self.yang_name = "valid-start"
                            self.yang_parent_name = "map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("eq", ("eq", Native.Crypto.Pki.Certificate.Map.ValidStart.Eq)), ("ge", ("ge", Native.Crypto.Pki.Certificate.Map.ValidStart.Ge)), ("lt", ("lt", Native.Crypto.Pki.Certificate.Map.ValidStart.Lt)), ("ne", ("ne", Native.Crypto.Pki.Certificate.Map.ValidStart.Ne))])
                            self._leafs = OrderedDict()

                            self.eq = Native.Crypto.Pki.Certificate.Map.ValidStart.Eq()
                            self.eq.parent = self
                            self._children_name_map["eq"] = "eq"

                            self.ge = Native.Crypto.Pki.Certificate.Map.ValidStart.Ge()
                            self.ge.parent = self
                            self._children_name_map["ge"] = "ge"

                            self.lt = Native.Crypto.Pki.Certificate.Map.ValidStart.Lt()
                            self.lt.parent = self
                            self._children_name_map["lt"] = "lt"

                            self.ne = Native.Crypto.Pki.Certificate.Map.ValidStart.Ne()
                            self.ne.parent = self
                            self._children_name_map["ne"] = "ne"
                            self._segment_path = lambda: "valid-start"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ValidStart, [], name, value)


                        class Eq(Entity):
                            """
                            Equal
                            
                            .. attribute:: time
                            
                            	
                            	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ValidStart.Eq.Time>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Certificate.Map.ValidStart.Eq, self).__init__()

                                self.yang_name = "eq"
                                self.yang_parent_name = "valid-start"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("time", ("time", Native.Crypto.Pki.Certificate.Map.ValidStart.Eq.Time))])
                                self._leafs = OrderedDict()

                                self.time = Native.Crypto.Pki.Certificate.Map.ValidStart.Eq.Time()
                                self.time.parent = self
                                self._children_name_map["time"] = "time"
                                self._segment_path = lambda: "eq"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ValidStart.Eq, [], name, value)


                            class Time(Entity):
                                """
                                
                                
                                .. attribute:: date1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month1
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: date2
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month2
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: year
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1993..2035
                                
                                .. attribute:: clock
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: utc
                                
                                	Time is in UTC (not local Time Zone)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Certificate.Map.ValidStart.Eq.Time, self).__init__()

                                    self.yang_name = "time"
                                    self.yang_parent_name = "eq"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('date1', (YLeaf(YType.uint8, 'date1'), ['int'])),
                                        ('month1', (YLeaf(YType.str, 'month1'), ['str'])),
                                        ('date2', (YLeaf(YType.uint8, 'date2'), ['int'])),
                                        ('month2', (YLeaf(YType.str, 'month2'), ['str'])),
                                        ('year', (YLeaf(YType.uint16, 'year'), ['int'])),
                                        ('clock', (YLeaf(YType.str, 'clock'), ['str'])),
                                        ('utc', (YLeaf(YType.empty, 'utc'), ['Empty'])),
                                    ])
                                    self.date1 = None
                                    self.month1 = None
                                    self.date2 = None
                                    self.month2 = None
                                    self.year = None
                                    self.clock = None
                                    self.utc = None
                                    self._segment_path = lambda: "time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ValidStart.Eq.Time, ['date1', 'month1', 'date2', 'month2', 'year', 'clock', 'utc'], name, value)


                        class Ge(Entity):
                            """
                            Greater than or equal
                            
                            .. attribute:: time
                            
                            	
                            	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ValidStart.Ge.Time>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Certificate.Map.ValidStart.Ge, self).__init__()

                                self.yang_name = "ge"
                                self.yang_parent_name = "valid-start"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("time", ("time", Native.Crypto.Pki.Certificate.Map.ValidStart.Ge.Time))])
                                self._leafs = OrderedDict()

                                self.time = Native.Crypto.Pki.Certificate.Map.ValidStart.Ge.Time()
                                self.time.parent = self
                                self._children_name_map["time"] = "time"
                                self._segment_path = lambda: "ge"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ValidStart.Ge, [], name, value)


                            class Time(Entity):
                                """
                                
                                
                                .. attribute:: date1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month1
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: date2
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month2
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: year
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1993..2035
                                
                                .. attribute:: clock
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: utc
                                
                                	Time is in UTC (not local Time Zone)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Certificate.Map.ValidStart.Ge.Time, self).__init__()

                                    self.yang_name = "time"
                                    self.yang_parent_name = "ge"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('date1', (YLeaf(YType.uint8, 'date1'), ['int'])),
                                        ('month1', (YLeaf(YType.str, 'month1'), ['str'])),
                                        ('date2', (YLeaf(YType.uint8, 'date2'), ['int'])),
                                        ('month2', (YLeaf(YType.str, 'month2'), ['str'])),
                                        ('year', (YLeaf(YType.uint16, 'year'), ['int'])),
                                        ('clock', (YLeaf(YType.str, 'clock'), ['str'])),
                                        ('utc', (YLeaf(YType.empty, 'utc'), ['Empty'])),
                                    ])
                                    self.date1 = None
                                    self.month1 = None
                                    self.date2 = None
                                    self.month2 = None
                                    self.year = None
                                    self.clock = None
                                    self.utc = None
                                    self._segment_path = lambda: "time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ValidStart.Ge.Time, ['date1', 'month1', 'date2', 'month2', 'year', 'clock', 'utc'], name, value)


                        class Lt(Entity):
                            """
                            Less Than
                            
                            .. attribute:: time
                            
                            	
                            	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ValidStart.Lt.Time>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Certificate.Map.ValidStart.Lt, self).__init__()

                                self.yang_name = "lt"
                                self.yang_parent_name = "valid-start"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("time", ("time", Native.Crypto.Pki.Certificate.Map.ValidStart.Lt.Time))])
                                self._leafs = OrderedDict()

                                self.time = Native.Crypto.Pki.Certificate.Map.ValidStart.Lt.Time()
                                self.time.parent = self
                                self._children_name_map["time"] = "time"
                                self._segment_path = lambda: "lt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ValidStart.Lt, [], name, value)


                            class Time(Entity):
                                """
                                
                                
                                .. attribute:: date1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month1
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: date2
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month2
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: year
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1993..2035
                                
                                .. attribute:: clock
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: utc
                                
                                	Time is in UTC (not local Time Zone)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Certificate.Map.ValidStart.Lt.Time, self).__init__()

                                    self.yang_name = "time"
                                    self.yang_parent_name = "lt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('date1', (YLeaf(YType.uint8, 'date1'), ['int'])),
                                        ('month1', (YLeaf(YType.str, 'month1'), ['str'])),
                                        ('date2', (YLeaf(YType.uint8, 'date2'), ['int'])),
                                        ('month2', (YLeaf(YType.str, 'month2'), ['str'])),
                                        ('year', (YLeaf(YType.uint16, 'year'), ['int'])),
                                        ('clock', (YLeaf(YType.str, 'clock'), ['str'])),
                                        ('utc', (YLeaf(YType.empty, 'utc'), ['Empty'])),
                                    ])
                                    self.date1 = None
                                    self.month1 = None
                                    self.date2 = None
                                    self.month2 = None
                                    self.year = None
                                    self.clock = None
                                    self.utc = None
                                    self._segment_path = lambda: "time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ValidStart.Lt.Time, ['date1', 'month1', 'date2', 'month2', 'year', 'clock', 'utc'], name, value)


                        class Ne(Entity):
                            """
                            Not Equal
                            
                            .. attribute:: time
                            
                            	
                            	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Map.ValidStart.Ne.Time>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Certificate.Map.ValidStart.Ne, self).__init__()

                                self.yang_name = "ne"
                                self.yang_parent_name = "valid-start"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("time", ("time", Native.Crypto.Pki.Certificate.Map.ValidStart.Ne.Time))])
                                self._leafs = OrderedDict()

                                self.time = Native.Crypto.Pki.Certificate.Map.ValidStart.Ne.Time()
                                self.time.parent = self
                                self._children_name_map["time"] = "time"
                                self._segment_path = lambda: "ne"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ValidStart.Ne, [], name, value)


                            class Time(Entity):
                                """
                                
                                
                                .. attribute:: date1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month1
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: date2
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..31
                                
                                .. attribute:: month2
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: year
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1993..2035
                                
                                .. attribute:: clock
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: utc
                                
                                	Time is in UTC (not local Time Zone)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Certificate.Map.ValidStart.Ne.Time, self).__init__()

                                    self.yang_name = "time"
                                    self.yang_parent_name = "ne"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('date1', (YLeaf(YType.uint8, 'date1'), ['int'])),
                                        ('month1', (YLeaf(YType.str, 'month1'), ['str'])),
                                        ('date2', (YLeaf(YType.uint8, 'date2'), ['int'])),
                                        ('month2', (YLeaf(YType.str, 'month2'), ['str'])),
                                        ('year', (YLeaf(YType.uint16, 'year'), ['int'])),
                                        ('clock', (YLeaf(YType.str, 'clock'), ['str'])),
                                        ('utc', (YLeaf(YType.empty, 'utc'), ['Empty'])),
                                    ])
                                    self.date1 = None
                                    self.month1 = None
                                    self.date2 = None
                                    self.month2 = None
                                    self.year = None
                                    self.clock = None
                                    self.utc = None
                                    self._segment_path = lambda: "time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Certificate.Map.ValidStart.Ne.Time, ['date1', 'month1', 'date2', 'month2', 'year', 'clock', 'utc'], name, value)


                class Storage(Entity):
                    """
                    specify where to store certificates
                    
                    .. attribute:: path
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Certificate.Storage.Path>`
                    
                    		**type**\: str
                    
                    .. attribute:: on
                    
                    	Create keypairs on device
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: with_keypair
                    
                    	Store certificates with keypair
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Certificate.Storage, self).__init__()

                        self.yang_name = "storage"
                        self.yang_parent_name = "certificate"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('path', (YLeaf(YType.str, 'path'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Pki.Certificate.Storage.Path'),'str'])),
                            ('on', (YLeaf(YType.empty, 'on'), ['Empty'])),
                            ('with_keypair', (YLeaf(YType.empty, 'with-keypair'), ['Empty'])),
                        ])
                        self.path = None
                        self.on = None
                        self.with_keypair = None
                        self._segment_path = lambda: "storage"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/certificate/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Certificate.Storage, ['path', 'on', 'with_keypair'], name, value)

                    class Path(Enum):
                        """
                        Path (Enum Class)

                        .. data:: bootflash__COLON__ = 0

                        .. data:: flash__COLON__ = 1

                        .. data:: nvram__COLON__ = 2

                        """

                        bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                        flash__COLON__ = Enum.YLeaf(1, "flash:")

                        nvram__COLON__ = Enum.YLeaf(2, "nvram:")



            class Crl(Entity):
                """
                Actions on certificate revocation lists
                
                .. attribute:: cache
                
                	Cache which holds recently parsed CRLs
                	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Crl.Cache>`
                
                .. attribute:: download
                
                	auto\-download CRL
                	**type**\:  :py:class:`Download <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Crl.Download>`
                
                .. attribute:: request
                
                	Requests a current CRL
                	**type**\: str
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Pki.Crl, self).__init__()

                    self.yang_name = "crl"
                    self.yang_parent_name = "pki"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cache", ("cache", Native.Crypto.Pki.Crl.Cache)), ("download", ("download", Native.Crypto.Pki.Crl.Download))])
                    self._leafs = OrderedDict([
                        ('request', (YLeaf(YType.str, 'request'), ['str'])),
                    ])
                    self.request = None

                    self.cache = Native.Crypto.Pki.Crl.Cache()
                    self.cache.parent = self
                    self._children_name_map["cache"] = "cache"

                    self.download = Native.Crypto.Pki.Crl.Download()
                    self.download.parent = self
                    self._children_name_map["download"] = "download"
                    self._segment_path = lambda: "crl"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Pki.Crl, ['request'], name, value)


                class Cache(Entity):
                    """
                    Cache which holds recently parsed CRLs
                    
                    .. attribute:: size
                    
                    	Size of the recently parsed CRL cache
                    	**type**\: int
                    
                    	**range:** 0..131072
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Crl.Cache, self).__init__()

                        self.yang_name = "cache"
                        self.yang_parent_name = "crl"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('size', (YLeaf(YType.uint32, 'size'), ['int'])),
                        ])
                        self.size = None
                        self._segment_path = lambda: "cache"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/crl/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Crl.Cache, ['size'], name, value)


                class Download(Entity):
                    """
                    auto\-download CRL
                    
                    .. attribute:: schedule
                    
                    	Schedule time to auto\-download CRL
                    	**type**\:  :py:class:`Schedule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Crl.Download.Schedule>`
                    
                    .. attribute:: trustpoint
                    
                    	Trustpoint to auto\-download CRL
                    	**type**\: str
                    
                    .. attribute:: url
                    
                    	URL to auto\-download CRL
                    	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Crl.Download.Url>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Crl.Download, self).__init__()

                        self.yang_name = "download"
                        self.yang_parent_name = "crl"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("schedule", ("schedule", Native.Crypto.Pki.Crl.Download.Schedule)), ("url", ("url", Native.Crypto.Pki.Crl.Download.Url))])
                        self._leafs = OrderedDict([
                            ('trustpoint', (YLeaf(YType.str, 'trustpoint'), ['str'])),
                        ])
                        self.trustpoint = None

                        self.schedule = Native.Crypto.Pki.Crl.Download.Schedule()
                        self.schedule.parent = self
                        self._children_name_map["schedule"] = "schedule"

                        self.url = Native.Crypto.Pki.Crl.Download.Url()
                        self.url.parent = self
                        self._children_name_map["url"] = "url"
                        self._segment_path = lambda: "download"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/crl/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Crl.Download, ['trustpoint'], name, value)


                    class Schedule(Entity):
                        """
                        Schedule time to auto\-download CRL
                        
                        .. attribute:: prepublish
                        
                        	Requests CRL at prepublish time
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: retries
                        
                        	Retry request for failed CDP locations
                        	**type**\:  :py:class:`Retries <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Crl.Download.Schedule.Retries>`
                        
                        .. attribute:: time
                        
                        	Request auto\-download CRL at this time
                        	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Crl.Download.Schedule.Time>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Crl.Download.Schedule, self).__init__()

                            self.yang_name = "schedule"
                            self.yang_parent_name = "download"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("retries", ("retries", Native.Crypto.Pki.Crl.Download.Schedule.Retries)), ("time", ("time", Native.Crypto.Pki.Crl.Download.Schedule.Time))])
                            self._leafs = OrderedDict([
                                ('prepublish', (YLeaf(YType.uint16, 'prepublish'), ['int'])),
                            ])
                            self.prepublish = None

                            self.retries = Native.Crypto.Pki.Crl.Download.Schedule.Retries()
                            self.retries.parent = self
                            self._children_name_map["retries"] = "retries"

                            self.time = Native.Crypto.Pki.Crl.Download.Schedule.Time()
                            self.time.parent = self
                            self._children_name_map["time"] = "time"
                            self._segment_path = lambda: "schedule"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/crl/download/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Crl.Download.Schedule, ['prepublish'], name, value)


                        class Retries(Entity):
                            """
                            Retry request for failed CDP locations
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..15
                            
                            .. attribute:: interval
                            
                            	retry time interval for each attempt
                            	**type**\: int
                            
                            	**range:** 15..600
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Crl.Download.Schedule.Retries, self).__init__()

                                self.yang_name = "retries"
                                self.yang_parent_name = "schedule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.number = None
                                self.interval = None
                                self._segment_path = lambda: "retries"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/crl/download/schedule/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Crl.Download.Schedule.Retries, ['number', 'interval'], name, value)


                        class Time(Entity):
                            """
                            Request auto\-download CRL at this time
                            
                            .. attribute:: date
                            
                            	
                            	**type**\:  :py:class:`Date <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Crl.Download.Schedule.Time.Date>`
                            
                            .. attribute:: clock
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Crl.Download.Schedule.Time, self).__init__()

                                self.yang_name = "time"
                                self.yang_parent_name = "schedule"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('date', (YLeaf(YType.enumeration, 'date'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Pki.Crl.Download.Schedule.Time.Date')])),
                                    ('clock', (YLeaf(YType.str, 'clock'), ['str'])),
                                ])
                                self.date = None
                                self.clock = None
                                self._segment_path = lambda: "time"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/crl/download/schedule/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Crl.Download.Schedule.Time, ['date', 'clock'], name, value)

                            class Date(Enum):
                                """
                                Date (Enum Class)

                                .. data:: Friday = 0

                                .. data:: Monday = 1

                                .. data:: Saturday = 2

                                .. data:: Sunday = 3

                                .. data:: Thursday = 4

                                .. data:: Tuesday = 5

                                .. data:: Wednesday = 6

                                """

                                Friday = Enum.YLeaf(0, "Friday")

                                Monday = Enum.YLeaf(1, "Monday")

                                Saturday = Enum.YLeaf(2, "Saturday")

                                Sunday = Enum.YLeaf(3, "Sunday")

                                Thursday = Enum.YLeaf(4, "Thursday")

                                Tuesday = Enum.YLeaf(5, "Tuesday")

                                Wednesday = Enum.YLeaf(6, "Wednesday")



                    class Url(Entity):
                        """
                        URL to auto\-download CRL
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: source_interface
                        
                        	Interface used as source address
                        	**type**\: str
                        
                        .. attribute:: vrf
                        
                        	VRF to use for CRL download
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Crl.Download.Url, self).__init__()

                            self.yang_name = "url"
                            self.yang_parent_name = "download"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.name = None
                            self.source_interface = None
                            self.vrf = None
                            self._segment_path = lambda: "url"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/crl/download/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Crl.Download.Url, ['name', 'source_interface', 'vrf'], name, value)


            class Export(Entity):
                """
                Export certificate or PKCS12 file
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: pem
                
                	Export to PEM files
                	**type**\:  :py:class:`Pem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Export.Pem>`
                
                .. attribute:: pkcs12
                
                	Export to PKCS12 file
                	**type**\:  :py:class:`Pkcs12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Export.Pkcs12>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Pki.Export, self).__init__()

                    self.yang_name = "export"
                    self.yang_parent_name = "pki"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("pem", ("pem", Native.Crypto.Pki.Export.Pem)), ("pkcs12", ("pkcs12", Native.Crypto.Pki.Export.Pkcs12))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.pem = Native.Crypto.Pki.Export.Pem()
                    self.pem.parent = self
                    self._children_name_map["pem"] = "pem"

                    self.pkcs12 = Native.Crypto.Pki.Export.Pkcs12()
                    self.pkcs12.parent = self
                    self._children_name_map["pkcs12"] = "pkcs12"
                    self._segment_path = lambda: "export" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Pki.Export, ['name'], name, value)


                class Pem(Entity):
                    """
                    Export to PEM files
                    
                    .. attribute:: terminal
                    
                    	Export via the terminal (cut\-and\-paste)
                    	**type**\:  :py:class:`Terminal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Export.Pem.Terminal>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: url
                    
                    	Export via the file systems
                    	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Export.Pem.Url>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Export.Pem, self).__init__()

                        self.yang_name = "pem"
                        self.yang_parent_name = "export"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("terminal", ("terminal", Native.Crypto.Pki.Export.Pem.Terminal)), ("url", ("url", Native.Crypto.Pki.Export.Pem.Url))])
                        self._leafs = OrderedDict()

                        self.terminal = None
                        self._children_name_map["terminal"] = "terminal"

                        self.url = Native.Crypto.Pki.Export.Pem.Url()
                        self.url.parent = self
                        self._children_name_map["url"] = "url"
                        self._segment_path = lambda: "pem"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Export.Pem, [], name, value)


                    class Terminal(Entity):
                        """
                        Export via the terminal (cut\-and\-paste)
                        
                        .. attribute:: pem_3des
                        
                        	Encrypt the private key with 3DES
                        	**type**\:  :py:class:`Pem3des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Export.Pem.Terminal.Pem3des>`
                        
                        .. attribute:: des
                        
                        	Encrypt the private key with DES
                        	**type**\:  :py:class:`Des <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Export.Pem.Terminal.Des>`
                        
                        .. attribute:: rollover
                        
                        	Export the rollover CA certificate
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Export.Pem.Terminal, self).__init__()

                            self.yang_name = "terminal"
                            self.yang_parent_name = "pem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pem-3des", ("pem_3des", Native.Crypto.Pki.Export.Pem.Terminal.Pem3des)), ("des", ("des", Native.Crypto.Pki.Export.Pem.Terminal.Des))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('rollover', (YLeaf(YType.empty, 'rollover'), ['Empty'])),
                            ])
                            self.rollover = None

                            self.pem_3des = Native.Crypto.Pki.Export.Pem.Terminal.Pem3des()
                            self.pem_3des.parent = self
                            self._children_name_map["pem_3des"] = "pem-3des"

                            self.des = Native.Crypto.Pki.Export.Pem.Terminal.Des()
                            self.des.parent = self
                            self._children_name_map["des"] = "des"
                            self._segment_path = lambda: "terminal"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Export.Pem.Terminal, ['rollover'], name, value)


                        class Pem3des(Entity):
                            """
                            Encrypt the private key with 3DES
                            
                            .. attribute:: password
                            
                            	Passphrase
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Export.Pem.Terminal.Pem3des, self).__init__()

                                self.yang_name = "pem-3des"
                                self.yang_parent_name = "terminal"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                ])
                                self.password = None
                                self._segment_path = lambda: "pem-3des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Export.Pem.Terminal.Pem3des, ['password'], name, value)


                        class Des(Entity):
                            """
                            Encrypt the private key with DES
                            
                            .. attribute:: password
                            
                            	Passphrase
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Export.Pem.Terminal.Des, self).__init__()

                                self.yang_name = "des"
                                self.yang_parent_name = "terminal"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                ])
                                self.password = None
                                self._segment_path = lambda: "des"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Export.Pem.Terminal.Des, ['password'], name, value)


                    class Url(Entity):
                        """
                        Export via the file systems
                        
                        .. attribute:: file
                        
                        	
                        	**type**\:  :py:class:`File <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Export.Pem.Url.File>`
                        
                        .. attribute:: encrypt
                        
                        	
                        	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Export.Pem.Url.Encrypt>`
                        
                        .. attribute:: password
                        
                        	Passphrase
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Export.Pem.Url, self).__init__()

                            self.yang_name = "url"
                            self.yang_parent_name = "pem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('file', (YLeaf(YType.enumeration, 'file'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Pki.Export.Pem.Url.File')])),
                                ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Pki.Export.Pem.Url.Encrypt')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.file = None
                            self.encrypt = None
                            self.password = None
                            self._segment_path = lambda: "url"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Export.Pem.Url, ['file', 'encrypt', 'password'], name, value)

                        class Encrypt(Enum):
                            """
                            Encrypt (Enum Class)

                            .. data:: Y_3des = 0

                            .. data:: des = 1

                            """

                            Y_3des = Enum.YLeaf(0, "3des")

                            des = Enum.YLeaf(1, "des")


                        class File(Enum):
                            """
                            File (Enum Class)

                            .. data:: bootflash__COLON__ = 0

                            .. data:: flash__COLON__ = 1

                            .. data:: ftp__COLON__ = 2

                            .. data:: http__COLON__ = 3

                            .. data:: https__COLON__ = 4

                            .. data:: null__COLON__ = 5

                            .. data:: nvram__COLON__ = 6

                            .. data:: pram__COLON__ = 7

                            .. data:: rcp__COLON__ = 8

                            .. data:: scp__COLON__ = 9

                            .. data:: system__COLON__ = 10

                            .. data:: tftp__COLON__ = 11

                            .. data:: tmpsys__COLON__ = 12

                            """

                            bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                            flash__COLON__ = Enum.YLeaf(1, "flash:")

                            ftp__COLON__ = Enum.YLeaf(2, "ftp:")

                            http__COLON__ = Enum.YLeaf(3, "http:")

                            https__COLON__ = Enum.YLeaf(4, "https:")

                            null__COLON__ = Enum.YLeaf(5, "null:")

                            nvram__COLON__ = Enum.YLeaf(6, "nvram:")

                            pram__COLON__ = Enum.YLeaf(7, "pram:")

                            rcp__COLON__ = Enum.YLeaf(8, "rcp:")

                            scp__COLON__ = Enum.YLeaf(9, "scp:")

                            system__COLON__ = Enum.YLeaf(10, "system:")

                            tftp__COLON__ = Enum.YLeaf(11, "tftp:")

                            tmpsys__COLON__ = Enum.YLeaf(12, "tmpsys:")



                class Pkcs12(Entity):
                    """
                    Export to PKCS12 file
                    
                    .. attribute:: file
                    
                    	
                    	**type**\:  :py:class:`File <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Export.Pkcs12.File>`
                    
                    .. attribute:: password
                    
                    	Passphrase
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Export.Pkcs12, self).__init__()

                        self.yang_name = "pkcs12"
                        self.yang_parent_name = "export"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('file', (YLeaf(YType.enumeration, 'file'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Pki.Export.Pkcs12.File')])),
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.file = None
                        self.password = None
                        self._segment_path = lambda: "pkcs12"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Export.Pkcs12, ['file', 'password'], name, value)

                    class File(Enum):
                        """
                        File (Enum Class)

                        .. data:: bootflash__COLON__ = 0

                        .. data:: flash__COLON__ = 1

                        .. data:: ftp__COLON__ = 2

                        .. data:: http__COLON__ = 3

                        .. data:: https__COLON__ = 4

                        .. data:: null__COLON__ = 5

                        .. data:: nvram__COLON__ = 6

                        .. data:: pram__COLON__ = 7

                        .. data:: rcp__COLON__ = 8

                        .. data:: scp__COLON__ = 9

                        .. data:: system__COLON__ = 10

                        .. data:: tftp__COLON__ = 11

                        .. data:: tmpsys__COLON__ = 12

                        """

                        bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                        flash__COLON__ = Enum.YLeaf(1, "flash:")

                        ftp__COLON__ = Enum.YLeaf(2, "ftp:")

                        http__COLON__ = Enum.YLeaf(3, "http:")

                        https__COLON__ = Enum.YLeaf(4, "https:")

                        null__COLON__ = Enum.YLeaf(5, "null:")

                        nvram__COLON__ = Enum.YLeaf(6, "nvram:")

                        pram__COLON__ = Enum.YLeaf(7, "pram:")

                        rcp__COLON__ = Enum.YLeaf(8, "rcp:")

                        scp__COLON__ = Enum.YLeaf(9, "scp:")

                        system__COLON__ = Enum.YLeaf(10, "system:")

                        tftp__COLON__ = Enum.YLeaf(11, "tftp:")

                        tmpsys__COLON__ = Enum.YLeaf(12, "tmpsys:")



            class Import(Entity):
                """
                Import certificate or PKCS12 file
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: certificate
                
                	Import a certificate from a TFTP server or the terminal
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pem
                
                	Import from PEM files
                	**type**\:  :py:class:`Pem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Import.Pem>`
                
                .. attribute:: pkcs12
                
                	Import from PKCS12 file
                	**type**\:  :py:class:`Pkcs12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Import.Pkcs12>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Pki.Import, self).__init__()

                    self.yang_name = "import"
                    self.yang_parent_name = "pki"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("pem", ("pem", Native.Crypto.Pki.Import.Pem)), ("pkcs12", ("pkcs12", Native.Crypto.Pki.Import.Pkcs12))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('certificate', (YLeaf(YType.empty, 'certificate'), ['Empty'])),
                    ])
                    self.name = None
                    self.certificate = None

                    self.pem = Native.Crypto.Pki.Import.Pem()
                    self.pem.parent = self
                    self._children_name_map["pem"] = "pem"

                    self.pkcs12 = Native.Crypto.Pki.Import.Pkcs12()
                    self.pkcs12.parent = self
                    self._children_name_map["pkcs12"] = "pkcs12"
                    self._segment_path = lambda: "import" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Pki.Import, ['name', 'certificate'], name, value)


                class Pem(Entity):
                    """
                    Import from PEM files
                    
                    .. attribute:: check
                    
                    	Validate certificate on input
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: exportable
                    
                    	Allow the key as to be exported
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: terminal
                    
                    	Import via the terminal (cut\-and\-paste)
                    	**type**\:  :py:class:`Terminal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Import.Pem.Terminal>`
                    
                    .. attribute:: url
                    
                    	Export via the file systems
                    	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Import.Pem.Url>`
                    
                    .. attribute:: usage_keys
                    
                    	Usage key pairs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Import.Pem, self).__init__()

                        self.yang_name = "pem"
                        self.yang_parent_name = "import"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("terminal", ("terminal", Native.Crypto.Pki.Import.Pem.Terminal)), ("url", ("url", Native.Crypto.Pki.Import.Pem.Url))])
                        self._leafs = OrderedDict([
                            ('check', (YLeaf(YType.empty, 'check'), ['Empty'])),
                            ('exportable', (YLeaf(YType.empty, 'exportable'), ['Empty'])),
                            ('usage_keys', (YLeaf(YType.empty, 'usage-keys'), ['Empty'])),
                        ])
                        self.check = None
                        self.exportable = None
                        self.usage_keys = None

                        self.terminal = Native.Crypto.Pki.Import.Pem.Terminal()
                        self.terminal.parent = self
                        self._children_name_map["terminal"] = "terminal"

                        self.url = Native.Crypto.Pki.Import.Pem.Url()
                        self.url.parent = self
                        self._children_name_map["url"] = "url"
                        self._segment_path = lambda: "pem"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Import.Pem, ['check', 'exportable', 'usage_keys'], name, value)


                    class Terminal(Entity):
                        """
                        Import via the terminal (cut\-and\-paste)
                        
                        .. attribute:: password
                        
                        	Passphrase
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Import.Pem.Terminal, self).__init__()

                            self.yang_name = "terminal"
                            self.yang_parent_name = "pem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.password = None
                            self._segment_path = lambda: "terminal"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Import.Pem.Terminal, ['password'], name, value)


                    class Url(Entity):
                        """
                        Export via the file systems
                        
                        .. attribute:: file
                        
                        	
                        	**type**\:  :py:class:`File <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Import.Pem.Url.File>`
                        
                        .. attribute:: password
                        
                        	Passphrase
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Import.Pem.Url, self).__init__()

                            self.yang_name = "url"
                            self.yang_parent_name = "pem"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('file', (YLeaf(YType.enumeration, 'file'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Pki.Import.Pem.Url.File')])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.file = None
                            self.password = None
                            self._segment_path = lambda: "url"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Import.Pem.Url, ['file', 'password'], name, value)

                        class File(Enum):
                            """
                            File (Enum Class)

                            .. data:: bootflash__COLON__ = 0

                            .. data:: flash__COLON__ = 1

                            .. data:: ftp__COLON__ = 2

                            .. data:: http__COLON__ = 3

                            .. data:: https__COLON__ = 4

                            .. data:: null__COLON__ = 5

                            .. data:: nvram__COLON__ = 6

                            .. data:: pram__COLON__ = 7

                            .. data:: rcp__COLON__ = 8

                            .. data:: scp__COLON__ = 9

                            .. data:: system__COLON__ = 10

                            .. data:: tftp__COLON__ = 11

                            .. data:: tmpsys__COLON__ = 12

                            """

                            bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                            flash__COLON__ = Enum.YLeaf(1, "flash:")

                            ftp__COLON__ = Enum.YLeaf(2, "ftp:")

                            http__COLON__ = Enum.YLeaf(3, "http:")

                            https__COLON__ = Enum.YLeaf(4, "https:")

                            null__COLON__ = Enum.YLeaf(5, "null:")

                            nvram__COLON__ = Enum.YLeaf(6, "nvram:")

                            pram__COLON__ = Enum.YLeaf(7, "pram:")

                            rcp__COLON__ = Enum.YLeaf(8, "rcp:")

                            scp__COLON__ = Enum.YLeaf(9, "scp:")

                            system__COLON__ = Enum.YLeaf(10, "system:")

                            tftp__COLON__ = Enum.YLeaf(11, "tftp:")

                            tmpsys__COLON__ = Enum.YLeaf(12, "tmpsys:")



                class Pkcs12(Entity):
                    """
                    Import from PKCS12 file
                    
                    .. attribute:: file
                    
                    	
                    	**type**\:  :py:class:`File <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Import.Pkcs12.File>`
                    
                    .. attribute:: password
                    
                    	Passphrase
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Import.Pkcs12, self).__init__()

                        self.yang_name = "pkcs12"
                        self.yang_parent_name = "import"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('file', (YLeaf(YType.enumeration, 'file'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Pki.Import.Pkcs12.File')])),
                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                        ])
                        self.file = None
                        self.password = None
                        self._segment_path = lambda: "pkcs12"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Import.Pkcs12, ['file', 'password'], name, value)

                    class File(Enum):
                        """
                        File (Enum Class)

                        .. data:: bootflash__COLON__ = 0

                        .. data:: flash__COLON__ = 1

                        .. data:: ftp__COLON__ = 2

                        .. data:: http__COLON__ = 3

                        .. data:: https__COLON__ = 4

                        .. data:: null__COLON__ = 5

                        .. data:: nvram__COLON__ = 6

                        .. data:: pram__COLON__ = 7

                        .. data:: rcp__COLON__ = 8

                        .. data:: scp__COLON__ = 9

                        .. data:: system__COLON__ = 10

                        .. data:: tftp__COLON__ = 11

                        .. data:: tmpsys__COLON__ = 12

                        """

                        bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                        flash__COLON__ = Enum.YLeaf(1, "flash:")

                        ftp__COLON__ = Enum.YLeaf(2, "ftp:")

                        http__COLON__ = Enum.YLeaf(3, "http:")

                        https__COLON__ = Enum.YLeaf(4, "https:")

                        null__COLON__ = Enum.YLeaf(5, "null:")

                        nvram__COLON__ = Enum.YLeaf(6, "nvram:")

                        pram__COLON__ = Enum.YLeaf(7, "pram:")

                        rcp__COLON__ = Enum.YLeaf(8, "rcp:")

                        scp__COLON__ = Enum.YLeaf(9, "scp:")

                        system__COLON__ = Enum.YLeaf(10, "system:")

                        tftp__COLON__ = Enum.YLeaf(11, "tftp:")

                        tmpsys__COLON__ = Enum.YLeaf(12, "tmpsys:")



            class Profile(Entity):
                """
                Define a certificate profile
                
                .. attribute:: enrollment
                
                	Define an enrollment profile
                	**type**\: list of  		 :py:class:`Enrollment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Pki.Profile, self).__init__()

                    self.yang_name = "profile"
                    self.yang_parent_name = "pki"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enrollment", ("enrollment", Native.Crypto.Pki.Profile.Enrollment))])
                    self._leafs = OrderedDict()

                    self.enrollment = YList(self)
                    self._segment_path = lambda: "profile"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Pki.Profile, [], name, value)


                class Enrollment(Entity):
                    """
                    Define an enrollment profile
                    
                    .. attribute:: tag  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: authentication
                    
                    	Retrieve CA certificate(s)
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Authentication>`
                    
                    .. attribute:: enrollment
                    
                    	Enroll router with a CA
                    	**type**\:  :py:class:`Enrollment_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Enrollment_>`
                    
                    .. attribute:: method_est
                    
                    	Use EST for this profile
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: parameter
                    
                    	Define a parameter value or prompt
                    	**type**\: list of  		 :py:class:`Parameter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Parameter>`
                    
                    .. attribute:: reenrollment
                    
                    	Re\-enroll router with a CA
                    	**type**\:  :py:class:`Reenrollment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Reenrollment>`
                    
                    .. attribute:: source_interface
                    
                    	Interface used as source address
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	Set a command to its defaults
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Default>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Profile.Enrollment, self).__init__()

                        self.yang_name = "enrollment"
                        self.yang_parent_name = "profile"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['tag']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Crypto.Pki.Profile.Enrollment.Authentication)), ("enrollment", ("enrollment", Native.Crypto.Pki.Profile.Enrollment.Enrollment_)), ("parameter", ("parameter", Native.Crypto.Pki.Profile.Enrollment.Parameter)), ("reenrollment", ("reenrollment", Native.Crypto.Pki.Profile.Enrollment.Reenrollment)), ("default", ("default", Native.Crypto.Pki.Profile.Enrollment.Default))])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                            ('method_est', (YLeaf(YType.empty, 'method-est'), ['Empty'])),
                            ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                        ])
                        self.tag = None
                        self.method_est = None
                        self.source_interface = None

                        self.authentication = Native.Crypto.Pki.Profile.Enrollment.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.enrollment = Native.Crypto.Pki.Profile.Enrollment.Enrollment_()
                        self.enrollment.parent = self
                        self._children_name_map["enrollment"] = "enrollment"

                        self.reenrollment = Native.Crypto.Pki.Profile.Enrollment.Reenrollment()
                        self.reenrollment.parent = self
                        self._children_name_map["reenrollment"] = "reenrollment"

                        self.default = Native.Crypto.Pki.Profile.Enrollment.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.parameter = YList(self)
                        self._segment_path = lambda: "enrollment" + "[tag='" + str(self.tag) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/profile/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment, ['tag', 'method_est', 'source_interface'], name, value)


                    class Authentication(Entity):
                        """
                        Retrieve CA certificate(s)
                        
                        .. attribute:: command
                        
                        	command to authenticate or enroll
                        	**type**\: str
                        
                        .. attribute:: terminal
                        
                        	authenticate or enroll using terminal
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: url
                        
                        	url to authenticate/enroll
                        	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Authentication.Url>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Profile.Enrollment.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "enrollment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("url", ("url", Native.Crypto.Pki.Profile.Enrollment.Authentication.Url))])
                            self._leafs = OrderedDict([
                                ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                ('terminal', (YLeaf(YType.empty, 'terminal'), ['Empty'])),
                            ])
                            self.command = None
                            self.terminal = None

                            self.url = Native.Crypto.Pki.Profile.Enrollment.Authentication.Url()
                            self.url.parent = self
                            self._children_name_map["url"] = "url"
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Authentication, ['command', 'terminal'], name, value)


                        class Url(Entity):
                            """
                            url to authenticate/enroll
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: vrf
                            
                            	VRF to use for certificate enrollment 
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Profile.Enrollment.Authentication.Url, self).__init__()

                                self.yang_name = "url"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.name = None
                                self.vrf = None
                                self._segment_path = lambda: "url"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Authentication.Url, ['name', 'vrf'], name, value)


                    class Enrollment_(Entity):
                        """
                        Enroll router with a CA
                        
                        .. attribute:: command
                        
                        	command to authenticate or enroll
                        	**type**\: str
                        
                        .. attribute:: terminal
                        
                        	authenticate or enroll using terminal
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: url
                        
                        	url to authenticate/enroll
                        	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Enrollment_.Url>`
                        
                        .. attribute:: credential
                        
                        	Use existing router cert for new enrollment
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Profile.Enrollment.Enrollment_, self).__init__()

                            self.yang_name = "enrollment"
                            self.yang_parent_name = "enrollment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("url", ("url", Native.Crypto.Pki.Profile.Enrollment.Enrollment_.Url))])
                            self._leafs = OrderedDict([
                                ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                ('terminal', (YLeaf(YType.empty, 'terminal'), ['Empty'])),
                                ('credential', (YLeaf(YType.str, 'credential'), ['str'])),
                            ])
                            self.command = None
                            self.terminal = None
                            self.credential = None

                            self.url = Native.Crypto.Pki.Profile.Enrollment.Enrollment_.Url()
                            self.url.parent = self
                            self._children_name_map["url"] = "url"
                            self._segment_path = lambda: "enrollment"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Enrollment_, ['command', 'terminal', 'credential'], name, value)


                        class Url(Entity):
                            """
                            url to authenticate/enroll
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: vrf
                            
                            	VRF to use for certificate enrollment 
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Profile.Enrollment.Enrollment_.Url, self).__init__()

                                self.yang_name = "url"
                                self.yang_parent_name = "enrollment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.name = None
                                self.vrf = None
                                self._segment_path = lambda: "url"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Enrollment_.Url, ['name', 'vrf'], name, value)


                    class Parameter(Entity):
                        """
                        Define a parameter value or prompt
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8
                        
                        .. attribute:: prompt
                        
                        	Define a parameter prompt
                        	**type**\: str
                        
                        .. attribute:: value
                        
                        	Define a parameter value
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Profile.Enrollment.Parameter, self).__init__()

                            self.yang_name = "parameter"
                            self.yang_parent_name = "enrollment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                ('prompt', (YLeaf(YType.str, 'prompt'), ['str'])),
                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                            ])
                            self.number = None
                            self.prompt = None
                            self.value = None
                            self._segment_path = lambda: "parameter" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Parameter, ['number', 'prompt', 'value'], name, value)


                    class Reenrollment(Entity):
                        """
                        Re\-enroll router with a CA
                        
                        .. attribute:: command
                        
                        	command to authenticate or enroll
                        	**type**\: str
                        
                        .. attribute:: terminal
                        
                        	authenticate or enroll using terminal
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: url
                        
                        	url to authenticate/enroll
                        	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Reenrollment.Url>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Profile.Enrollment.Reenrollment, self).__init__()

                            self.yang_name = "reenrollment"
                            self.yang_parent_name = "enrollment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("url", ("url", Native.Crypto.Pki.Profile.Enrollment.Reenrollment.Url))])
                            self._leafs = OrderedDict([
                                ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                ('terminal', (YLeaf(YType.empty, 'terminal'), ['Empty'])),
                            ])
                            self.command = None
                            self.terminal = None

                            self.url = Native.Crypto.Pki.Profile.Enrollment.Reenrollment.Url()
                            self.url.parent = self
                            self._children_name_map["url"] = "url"
                            self._segment_path = lambda: "reenrollment"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Reenrollment, ['command', 'terminal'], name, value)


                        class Url(Entity):
                            """
                            url to authenticate/enroll
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: vrf
                            
                            	VRF to use for certificate enrollment 
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Profile.Enrollment.Reenrollment.Url, self).__init__()

                                self.yang_name = "url"
                                self.yang_parent_name = "reenrollment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.name = None
                                self.vrf = None
                                self._segment_path = lambda: "url"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Reenrollment.Url, ['name', 'vrf'], name, value)


                    class Default(Entity):
                        """
                        Set a command to its defaults
                        
                        .. attribute:: authentication
                        
                        	Retrieve CA certificate(s)
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Default.Authentication>`
                        
                        .. attribute:: enrollment
                        
                        	Enroll router with a CA
                        	**type**\:  :py:class:`Enrollment_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Default.Enrollment_>`
                        
                        .. attribute:: method_est
                        
                        	Use EST for this profile
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: parameter
                        
                        	Define a parameter value or prompt
                        	**type**\: list of  		 :py:class:`Parameter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Default.Parameter>`
                        
                        .. attribute:: reenrollment
                        
                        	Re\-enroll router with a CA
                        	**type**\:  :py:class:`Reenrollment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Default.Reenrollment>`
                        
                        .. attribute:: source_interface
                        
                        	Interface used as source address
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Profile.Enrollment.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "enrollment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authentication", ("authentication", Native.Crypto.Pki.Profile.Enrollment.Default.Authentication)), ("enrollment", ("enrollment", Native.Crypto.Pki.Profile.Enrollment.Default.Enrollment_)), ("parameter", ("parameter", Native.Crypto.Pki.Profile.Enrollment.Default.Parameter)), ("reenrollment", ("reenrollment", Native.Crypto.Pki.Profile.Enrollment.Default.Reenrollment))])
                            self._leafs = OrderedDict([
                                ('method_est', (YLeaf(YType.empty, 'method-est'), ['Empty'])),
                                ('source_interface', (YLeaf(YType.str, 'source-interface'), ['str'])),
                            ])
                            self.method_est = None
                            self.source_interface = None

                            self.authentication = Native.Crypto.Pki.Profile.Enrollment.Default.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.enrollment = Native.Crypto.Pki.Profile.Enrollment.Default.Enrollment_()
                            self.enrollment.parent = self
                            self._children_name_map["enrollment"] = "enrollment"

                            self.reenrollment = Native.Crypto.Pki.Profile.Enrollment.Default.Reenrollment()
                            self.reenrollment.parent = self
                            self._children_name_map["reenrollment"] = "reenrollment"

                            self.parameter = YList(self)
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Default, ['method_est', 'source_interface'], name, value)


                        class Authentication(Entity):
                            """
                            Retrieve CA certificate(s)
                            
                            .. attribute:: command
                            
                            	command to authenticate or enroll
                            	**type**\: str
                            
                            .. attribute:: terminal
                            
                            	authenticate or enroll using terminal
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: url
                            
                            	url to authenticate/enroll
                            	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Default.Authentication.Url>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Profile.Enrollment.Default.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("url", ("url", Native.Crypto.Pki.Profile.Enrollment.Default.Authentication.Url))])
                                self._leafs = OrderedDict([
                                    ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                    ('terminal', (YLeaf(YType.empty, 'terminal'), ['Empty'])),
                                ])
                                self.command = None
                                self.terminal = None

                                self.url = Native.Crypto.Pki.Profile.Enrollment.Default.Authentication.Url()
                                self.url.parent = self
                                self._children_name_map["url"] = "url"
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Default.Authentication, ['command', 'terminal'], name, value)


                            class Url(Entity):
                                """
                                url to authenticate/enroll
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	VRF to use for certificate enrollment 
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Profile.Enrollment.Default.Authentication.Url, self).__init__()

                                    self.yang_name = "url"
                                    self.yang_parent_name = "authentication"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.name = None
                                    self.vrf = None
                                    self._segment_path = lambda: "url"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Default.Authentication.Url, ['name', 'vrf'], name, value)


                        class Enrollment_(Entity):
                            """
                            Enroll router with a CA
                            
                            .. attribute:: command
                            
                            	command to authenticate or enroll
                            	**type**\: str
                            
                            .. attribute:: terminal
                            
                            	authenticate or enroll using terminal
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: url
                            
                            	url to authenticate/enroll
                            	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Default.Enrollment_.Url>`
                            
                            .. attribute:: credential
                            
                            	Use existing router cert for new enrollment
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Profile.Enrollment.Default.Enrollment_, self).__init__()

                                self.yang_name = "enrollment"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("url", ("url", Native.Crypto.Pki.Profile.Enrollment.Default.Enrollment_.Url))])
                                self._leafs = OrderedDict([
                                    ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                    ('terminal', (YLeaf(YType.empty, 'terminal'), ['Empty'])),
                                    ('credential', (YLeaf(YType.str, 'credential'), ['str'])),
                                ])
                                self.command = None
                                self.terminal = None
                                self.credential = None

                                self.url = Native.Crypto.Pki.Profile.Enrollment.Default.Enrollment_.Url()
                                self.url.parent = self
                                self._children_name_map["url"] = "url"
                                self._segment_path = lambda: "enrollment"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Default.Enrollment_, ['command', 'terminal', 'credential'], name, value)


                            class Url(Entity):
                                """
                                url to authenticate/enroll
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	VRF to use for certificate enrollment 
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Profile.Enrollment.Default.Enrollment_.Url, self).__init__()

                                    self.yang_name = "url"
                                    self.yang_parent_name = "enrollment"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.name = None
                                    self.vrf = None
                                    self._segment_path = lambda: "url"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Default.Enrollment_.Url, ['name', 'vrf'], name, value)


                        class Parameter(Entity):
                            """
                            Define a parameter value or prompt
                            
                            .. attribute:: number  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..8
                            
                            .. attribute:: prompt
                            
                            	Define a parameter prompt
                            	**type**\: str
                            
                            .. attribute:: value
                            
                            	Define a parameter value
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Profile.Enrollment.Default.Parameter, self).__init__()

                                self.yang_name = "parameter"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['number']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                    ('prompt', (YLeaf(YType.str, 'prompt'), ['str'])),
                                    ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                ])
                                self.number = None
                                self.prompt = None
                                self.value = None
                                self._segment_path = lambda: "parameter" + "[number='" + str(self.number) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Default.Parameter, ['number', 'prompt', 'value'], name, value)


                        class Reenrollment(Entity):
                            """
                            Re\-enroll router with a CA
                            
                            .. attribute:: command
                            
                            	command to authenticate or enroll
                            	**type**\: str
                            
                            .. attribute:: terminal
                            
                            	authenticate or enroll using terminal
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: url
                            
                            	url to authenticate/enroll
                            	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Profile.Enrollment.Default.Reenrollment.Url>`
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Profile.Enrollment.Default.Reenrollment, self).__init__()

                                self.yang_name = "reenrollment"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("url", ("url", Native.Crypto.Pki.Profile.Enrollment.Default.Reenrollment.Url))])
                                self._leafs = OrderedDict([
                                    ('command', (YLeaf(YType.str, 'command'), ['str'])),
                                    ('terminal', (YLeaf(YType.empty, 'terminal'), ['Empty'])),
                                ])
                                self.command = None
                                self.terminal = None

                                self.url = Native.Crypto.Pki.Profile.Enrollment.Default.Reenrollment.Url()
                                self.url.parent = self
                                self._children_name_map["url"] = "url"
                                self._segment_path = lambda: "reenrollment"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Default.Reenrollment, ['command', 'terminal'], name, value)


                            class Url(Entity):
                                """
                                url to authenticate/enroll
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	VRF to use for certificate enrollment 
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Profile.Enrollment.Default.Reenrollment.Url, self).__init__()

                                    self.yang_name = "url"
                                    self.yang_parent_name = "reenrollment"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.name = None
                                    self.vrf = None
                                    self._segment_path = lambda: "url"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Profile.Enrollment.Default.Reenrollment.Url, ['name', 'vrf'], name, value)


            class Server(Entity):
                """
                Enable IOS Certificate server
                
                .. attribute:: name
                
                	Certificate Server Name
                	**type**\: str
                
                .. attribute:: database
                
                	Certificate Server database config parameters
                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Server.Database>`
                
                .. attribute:: issuer_name
                
                	Issuer name
                	**type**\: str
                
                .. attribute:: grant
                
                	Certificate granting options
                	**type**\:  :py:class:`Grant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Server.Grant>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Pki.Server, self).__init__()

                    self.yang_name = "server"
                    self.yang_parent_name = "pki"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("database", ("database", Native.Crypto.Pki.Server.Database))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('issuer_name', (YLeaf(YType.str, 'issuer-name'), ['str'])),
                        ('grant', (YLeaf(YType.enumeration, 'grant'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Pki.Server.Grant')])),
                    ])
                    self.name = None
                    self.issuer_name = None
                    self.grant = None

                    self.database = Native.Crypto.Pki.Server.Database()
                    self.database.parent = self
                    self._children_name_map["database"] = "database"
                    self._segment_path = lambda: "server"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Pki.Server, ['name', 'issuer_name', 'grant'], name, value)

                class Grant(Enum):
                    """
                    Grant (Enum Class)

                    Certificate granting options

                    .. data:: auto = 0

                    .. data:: none = 1

                    .. data:: ra_auto = 2

                    """

                    auto = Enum.YLeaf(0, "auto")

                    none = Enum.YLeaf(1, "none")

                    ra_auto = Enum.YLeaf(2, "ra-auto")



                class Database(Entity):
                    """
                    Certificate Server database config parameters
                    
                    .. attribute:: archive
                    
                    	Backup Certificate Server Signing Certificate and Keys
                    	**type**\:  :py:class:`Archive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Server.Database.Archive>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Server.Database, self).__init__()

                        self.yang_name = "database"
                        self.yang_parent_name = "server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("archive", ("archive", Native.Crypto.Pki.Server.Database.Archive))])
                        self._leafs = OrderedDict()

                        self.archive = Native.Crypto.Pki.Server.Database.Archive()
                        self.archive.parent = self
                        self._children_name_map["archive"] = "archive"
                        self._segment_path = lambda: "database"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Server.Database, [], name, value)


                    class Archive(Entity):
                        """
                        Backup Certificate Server Signing Certificate and Keys
                        
                        .. attribute:: pem
                        
                        	PEM format
                        	**type**\:  :py:class:`Pem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Server.Database.Archive.Pem>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: pkcs12
                        
                        	PKCS12 format
                        	**type**\:  :py:class:`Pkcs12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Server.Database.Archive.Pkcs12>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Server.Database.Archive, self).__init__()

                            self.yang_name = "archive"
                            self.yang_parent_name = "database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pem", ("pem", Native.Crypto.Pki.Server.Database.Archive.Pem)), ("pkcs12", ("pkcs12", Native.Crypto.Pki.Server.Database.Archive.Pkcs12))])
                            self._leafs = OrderedDict()

                            self.pem = None
                            self._children_name_map["pem"] = "pem"

                            self.pkcs12 = None
                            self._children_name_map["pkcs12"] = "pkcs12"
                            self._segment_path = lambda: "archive"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/server/database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Server.Database.Archive, [], name, value)


                        class Pem(Entity):
                            """
                            PEM format
                            
                            .. attribute:: password
                            
                            	Passphrase to protect the private key archive
                            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Server.Database.Archive.Pem.Password>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Server.Database.Archive.Pem, self).__init__()

                                self.yang_name = "pem"
                                self.yang_parent_name = "archive"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Pki.Server.Database.Archive.Pem.Password))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.password = Native.Crypto.Pki.Server.Database.Archive.Pem.Password()
                                self.password.parent = self
                                self._children_name_map["password"] = "password"
                                self._segment_path = lambda: "pem"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/server/database/archive/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Server.Database.Archive.Pem, [], name, value)


                            class Password(Entity):
                                """
                                Passphrase to protect the private key archive
                                
                                .. attribute:: encryption_type
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..9
                                
                                .. attribute:: passphrase
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Server.Database.Archive.Pem.Password, self).__init__()

                                    self.yang_name = "password"
                                    self.yang_parent_name = "pem"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encryption_type', (YLeaf(YType.uint8, 'encryption-type'), ['int'])),
                                        ('passphrase', (YLeaf(YType.str, 'passphrase'), ['str'])),
                                    ])
                                    self.encryption_type = None
                                    self.passphrase = None
                                    self._segment_path = lambda: "password"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/server/database/archive/pem/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Server.Database.Archive.Pem.Password, ['encryption_type', 'passphrase'], name, value)


                        class Pkcs12(Entity):
                            """
                            PKCS12 format
                            
                            .. attribute:: password
                            
                            	Passphrase to protect the private key archive
                            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Server.Database.Archive.Pkcs12.Password>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.Pki.Server.Database.Archive.Pkcs12, self).__init__()

                                self.yang_name = "pkcs12"
                                self.yang_parent_name = "archive"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("password", ("password", Native.Crypto.Pki.Server.Database.Archive.Pkcs12.Password))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.password = Native.Crypto.Pki.Server.Database.Archive.Pkcs12.Password()
                                self.password.parent = self
                                self._children_name_map["password"] = "password"
                                self._segment_path = lambda: "pkcs12"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/server/database/archive/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.Pki.Server.Database.Archive.Pkcs12, [], name, value)


                            class Password(Entity):
                                """
                                Passphrase to protect the private key archive
                                
                                .. attribute:: encryption_type
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..9
                                
                                .. attribute:: passphrase
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-crypto'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Crypto.Pki.Server.Database.Archive.Pkcs12.Password, self).__init__()

                                    self.yang_name = "password"
                                    self.yang_parent_name = "pkcs12"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('encryption_type', (YLeaf(YType.uint8, 'encryption-type'), ['int'])),
                                        ('passphrase', (YLeaf(YType.str, 'passphrase'), ['str'])),
                                    ])
                                    self.encryption_type = None
                                    self.passphrase = None
                                    self._segment_path = lambda: "password"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/server/database/archive/pkcs12/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Crypto.Pki.Server.Database.Archive.Pkcs12.Password, ['encryption_type', 'passphrase'], name, value)


            class PkiServerNoSubmode(Entity):
                """
                
                
                .. attribute:: server
                
                	Enable IOS Certificate server
                	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.PkiServerNoSubmode.Server>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Pki.PkiServerNoSubmode, self).__init__()

                    self.yang_name = "pki-server-no-submode"
                    self.yang_parent_name = "pki"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("server", ("server", Native.Crypto.Pki.PkiServerNoSubmode.Server))])
                    self._leafs = OrderedDict()

                    self.server = Native.Crypto.Pki.PkiServerNoSubmode.Server()
                    self.server.parent = self
                    self._children_name_map["server"] = "server"
                    self._segment_path = lambda: "pki-server-no-submode"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Pki.PkiServerNoSubmode, [], name, value)


                class Server(Entity):
                    """
                    Enable IOS Certificate server
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: rollover
                    
                    	Rollover the server's key and certificate
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cancel
                    
                    	Cancel a pending rollover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.PkiServerNoSubmode.Server, self).__init__()

                        self.yang_name = "server"
                        self.yang_parent_name = "pki-server-no-submode"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('rollover', (YLeaf(YType.empty, 'rollover'), ['Empty'])),
                            ('cancel', (YLeaf(YType.empty, 'cancel'), ['Empty'])),
                        ])
                        self.name = None
                        self.rollover = None
                        self.cancel = None
                        self._segment_path = lambda: "server"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/pki-server-no-submode/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.PkiServerNoSubmode.Server, ['name', 'rollover', 'cancel'], name, value)


            class Trustpoint(Entity):
                """
                Define a CA trustpoint
                
                .. attribute:: id  (key)
                
                	
                	**type**\: str
                
                .. attribute:: auto_enroll
                
                	Automatically enroll this router identity
                	**type**\:  :py:class:`AutoEnroll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpoint.AutoEnroll>`
                
                .. attribute:: enrollment
                
                	Enrollment parameters
                	**type**\:  :py:class:`Enrollment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpoint.Enrollment>`
                
                .. attribute:: fqdn
                
                	include fully\-qualified domain name
                	**type**\: str
                
                .. attribute:: password
                
                	revocation password
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpoint.Password>`
                
                	**presence node**\: True
                
                .. attribute:: revocation_check
                
                	Revocation checking options
                	**type**\:  :py:class:`RevocationCheck <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpoint.RevocationCheck>`
                
                .. attribute:: rsakeypair
                
                	Specify rsakeypair for this identity
                	**type**\:  :py:class:`Rsakeypair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpoint.Rsakeypair>`
                
                .. attribute:: serial_number
                
                	help
                	**type**\:  :py:class:`SerialNumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpoint.SerialNumber>`
                
                	**presence node**\: True
                
                .. attribute:: ip_address
                
                	include ip address
                	**type**\:  :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpoint.IpAddress>`
                
                .. attribute:: subject_name
                
                	Subject Name
                	**type**\: str
                
                .. attribute:: vrf
                
                	Name of VRF to use with trustpoint
                	**type**\: str
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Pki.Trustpoint, self).__init__()

                    self.yang_name = "trustpoint"
                    self.yang_parent_name = "pki"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("auto-enroll", ("auto_enroll", Native.Crypto.Pki.Trustpoint.AutoEnroll)), ("enrollment", ("enrollment", Native.Crypto.Pki.Trustpoint.Enrollment)), ("password", ("password", Native.Crypto.Pki.Trustpoint.Password)), ("rsakeypair", ("rsakeypair", Native.Crypto.Pki.Trustpoint.Rsakeypair)), ("serial-number", ("serial_number", Native.Crypto.Pki.Trustpoint.SerialNumber)), ("ip-address", ("ip_address", Native.Crypto.Pki.Trustpoint.IpAddress))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                        ('fqdn', (YLeaf(YType.str, 'fqdn'), ['str'])),
                        ('revocation_check', (YLeaf(YType.enumeration, 'revocation-check'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.Pki.Trustpoint.RevocationCheck')])),
                        ('subject_name', (YLeaf(YType.str, 'subject-name'), ['str'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ])
                    self.id = None
                    self.fqdn = None
                    self.revocation_check = None
                    self.subject_name = None
                    self.vrf = None

                    self.auto_enroll = Native.Crypto.Pki.Trustpoint.AutoEnroll()
                    self.auto_enroll.parent = self
                    self._children_name_map["auto_enroll"] = "auto-enroll"

                    self.enrollment = Native.Crypto.Pki.Trustpoint.Enrollment()
                    self.enrollment.parent = self
                    self._children_name_map["enrollment"] = "enrollment"

                    self.password = None
                    self._children_name_map["password"] = "password"

                    self.rsakeypair = Native.Crypto.Pki.Trustpoint.Rsakeypair()
                    self.rsakeypair.parent = self
                    self._children_name_map["rsakeypair"] = "rsakeypair"

                    self.serial_number = None
                    self._children_name_map["serial_number"] = "serial-number"

                    self.ip_address = Native.Crypto.Pki.Trustpoint.IpAddress()
                    self.ip_address.parent = self
                    self._children_name_map["ip_address"] = "ip-address"
                    self._segment_path = lambda: "trustpoint" + "[id='" + str(self.id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Pki.Trustpoint, ['id', 'fqdn', 'revocation_check', 'subject_name', 'vrf'], name, value)

                class RevocationCheck(Enum):
                    """
                    RevocationCheck (Enum Class)

                    Revocation checking options

                    .. data:: crl = 0

                    .. data:: none = 1

                    .. data:: ocsp = 2

                    """

                    crl = Enum.YLeaf(0, "crl")

                    none = Enum.YLeaf(1, "none")

                    ocsp = Enum.YLeaf(2, "ocsp")



                class AutoEnroll(Entity):
                    """
                    Automatically enroll this router identity
                    
                    .. attribute:: percent
                    
                    	renewal percentage
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    .. attribute:: regenerate
                    
                    	Regenerate keys on re\-enrollment
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Trustpoint.AutoEnroll, self).__init__()

                        self.yang_name = "auto-enroll"
                        self.yang_parent_name = "trustpoint"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                            ('regenerate', (YLeaf(YType.empty, 'regenerate'), ['Empty'])),
                        ])
                        self.percent = None
                        self.regenerate = None
                        self._segment_path = lambda: "auto-enroll"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Trustpoint.AutoEnroll, ['percent', 'regenerate'], name, value)


                class Enrollment(Entity):
                    """
                    Enrollment parameters
                    
                    .. attribute:: http_proxy
                    
                    	HTTP proxy server for enrollment
                    	**type**\: str
                    
                    .. attribute:: mode
                    
                    	Mode supported by the Certificate Authority
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpoint.Enrollment.Mode>`
                    
                    .. attribute:: pkcs12
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: profile
                    
                    	Specify an profile for enrollment
                    	**type**\: str
                    
                    .. attribute:: retry
                    
                    	Polling parameters
                    	**type**\:  :py:class:`Retry <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpoint.Enrollment.Retry>`
                    
                    .. attribute:: selfsigned
                    
                    	Generate a Self Signed Certificate
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: terminal
                    
                    	Enroll via the terminal (cut\-and\-paste)
                    	**type**\:  :py:class:`Terminal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpoint.Enrollment.Terminal>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: url
                    
                    	CA server enrollment URL
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Trustpoint.Enrollment, self).__init__()

                        self.yang_name = "enrollment"
                        self.yang_parent_name = "trustpoint"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Crypto.Pki.Trustpoint.Enrollment.Mode)), ("retry", ("retry", Native.Crypto.Pki.Trustpoint.Enrollment.Retry)), ("terminal", ("terminal", Native.Crypto.Pki.Trustpoint.Enrollment.Terminal))])
                        self._leafs = OrderedDict([
                            ('http_proxy', (YLeaf(YType.str, 'http-proxy'), ['str'])),
                            ('pkcs12', (YLeaf(YType.empty, 'pkcs12'), ['Empty'])),
                            ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ('selfsigned', (YLeaf(YType.empty, 'selfsigned'), ['Empty'])),
                            ('url', (YLeaf(YType.str, 'url'), ['str'])),
                        ])
                        self.http_proxy = None
                        self.pkcs12 = None
                        self.profile = None
                        self.selfsigned = None
                        self.url = None

                        self.mode = Native.Crypto.Pki.Trustpoint.Enrollment.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.retry = Native.Crypto.Pki.Trustpoint.Enrollment.Retry()
                        self.retry.parent = self
                        self._children_name_map["retry"] = "retry"

                        self.terminal = None
                        self._children_name_map["terminal"] = "terminal"
                        self._segment_path = lambda: "enrollment"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Trustpoint.Enrollment, ['http_proxy', 'pkcs12', 'profile', 'selfsigned', 'url'], name, value)


                    class Mode(Entity):
                        """
                        Mode supported by the Certificate Authority
                        
                        .. attribute:: ra
                        
                        	Registration Authority mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Trustpoint.Enrollment.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "enrollment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ra', (YLeaf(YType.empty, 'ra'), ['Empty'])),
                            ])
                            self.ra = None
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Trustpoint.Enrollment.Mode, ['ra'], name, value)


                    class Retry(Entity):
                        """
                        Polling parameters
                        
                        .. attribute:: count
                        
                        	How many times to poll CA for our certificate
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: period
                        
                        	How long to wait between requests to CA for our certificate
                        	**type**\: int
                        
                        	**range:** 1..60
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Trustpoint.Enrollment.Retry, self).__init__()

                            self.yang_name = "retry"
                            self.yang_parent_name = "enrollment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('count', (YLeaf(YType.uint8, 'count'), ['int'])),
                                ('period', (YLeaf(YType.uint8, 'period'), ['int'])),
                            ])
                            self.count = None
                            self.period = None
                            self._segment_path = lambda: "retry"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Trustpoint.Enrollment.Retry, ['count', 'period'], name, value)


                    class Terminal(Entity):
                        """
                        Enroll via the terminal (cut\-and\-paste)
                        
                        .. attribute:: pem
                        
                        	Include PEM encapsulation boundaries
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Trustpoint.Enrollment.Terminal, self).__init__()

                            self.yang_name = "terminal"
                            self.yang_parent_name = "enrollment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('pem', (YLeaf(YType.empty, 'pem'), ['Empty'])),
                            ])
                            self.pem = None
                            self._segment_path = lambda: "terminal"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Trustpoint.Enrollment.Terminal, ['pem'], name, value)


                class Password(Entity):
                    """
                    revocation password
                    
                    .. attribute:: encryption_type
                    
                    	Encryption type
                    	**type**\: int
                    
                    	**range:** 0..9
                    
                    .. attribute:: clear_password
                    
                    	revocation password
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Trustpoint.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "trustpoint"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('encryption_type', (YLeaf(YType.uint8, 'encryption-type'), ['int'])),
                            ('clear_password', (YLeaf(YType.str, 'clear-password'), ['str'])),
                        ])
                        self.encryption_type = None
                        self.clear_password = None
                        self._segment_path = lambda: "password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Trustpoint.Password, ['encryption_type', 'clear_password'], name, value)


                class Rsakeypair(Entity):
                    """
                    Specify rsakeypair for this identity
                    
                    .. attribute:: key_label
                    
                    	RSA keypair label
                    	**type**\: str
                    
                    .. attribute:: gen_key
                    
                    	General Purpose or Signature Key length
                    	**type**\: int
                    
                    	**range:** 360..4096
                    
                    .. attribute:: encrypt_key
                    
                    	Encryption Key length
                    	**type**\: int
                    
                    	**range:** 360..4096
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Trustpoint.Rsakeypair, self).__init__()

                        self.yang_name = "rsakeypair"
                        self.yang_parent_name = "trustpoint"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('key_label', (YLeaf(YType.str, 'key-label'), ['str'])),
                            ('gen_key', (YLeaf(YType.uint16, 'gen-key'), ['int'])),
                            ('encrypt_key', (YLeaf(YType.uint16, 'encrypt-key'), ['int'])),
                        ])
                        self.key_label = None
                        self.gen_key = None
                        self.encrypt_key = None
                        self._segment_path = lambda: "rsakeypair"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Trustpoint.Rsakeypair, ['key_label', 'gen_key', 'encrypt_key'], name, value)


                class SerialNumber(Entity):
                    """
                    help
                    
                    .. attribute:: none
                    
                    	do not include serial number
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Trustpoint.SerialNumber, self).__init__()

                        self.yang_name = "serial-number"
                        self.yang_parent_name = "trustpoint"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ])
                        self.none = None
                        self._segment_path = lambda: "serial-number"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Trustpoint.SerialNumber, ['none'], name, value)


                class IpAddress(Entity):
                    """
                    include ip address
                    
                    .. attribute:: address_line
                    
                    	interface name or ip address
                    	**type**\: str
                    
                    .. attribute:: none
                    
                    	do not include ip address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Trustpoint.IpAddress, self).__init__()

                        self.yang_name = "ip-address"
                        self.yang_parent_name = "trustpoint"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address_line', (YLeaf(YType.str, 'address-line'), ['str'])),
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ])
                        self.address_line = None
                        self.none = None
                        self._segment_path = lambda: "ip-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Trustpoint.IpAddress, ['address_line', 'none'], name, value)


            class Token(Entity):
                """
                Configure cryptographic token
                
                .. attribute:: token_name
                
                	
                	**type**\: list of  		 :py:class:`TokenName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Token.TokenName>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Pki.Token, self).__init__()

                    self.yang_name = "token"
                    self.yang_parent_name = "pki"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("token-name", ("token_name", Native.Crypto.Pki.Token.TokenName))])
                    self._leafs = OrderedDict()

                    self.token_name = YList(self)
                    self._segment_path = lambda: "token"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Pki.Token, [], name, value)


                class TokenName(Entity):
                    """
                    
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: removal
                    
                    	actions to take after token removal
                    	**type**\:  :py:class:`Removal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Token.TokenName.Removal>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Token.TokenName, self).__init__()

                        self.yang_name = "token-name"
                        self.yang_parent_name = "token"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("removal", ("removal", Native.Crypto.Pki.Token.TokenName.Removal))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.removal = Native.Crypto.Pki.Token.TokenName.Removal()
                        self.removal.parent = self
                        self._children_name_map["removal"] = "removal"
                        self._segment_path = lambda: "token-name" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/token/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Token.TokenName, ['name'], name, value)


                    class Removal(Entity):
                        """
                        actions to take after token removal
                        
                        .. attribute:: timeout
                        
                        	seconds after token removal at which keys from the token are cleared
                        	**type**\: int
                        
                        	**range:** 0..480
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.Pki.Token.TokenName.Removal, self).__init__()

                            self.yang_name = "removal"
                            self.yang_parent_name = "token-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                            ])
                            self.timeout = None
                            self._segment_path = lambda: "removal"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.Pki.Token.TokenName.Removal, ['timeout'], name, value)


            class Trustpool(Entity):
                """
                Define CA trustpool
                
                .. attribute:: import_
                
                	Import a trustpool bundle
                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Trustpool.Import>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Pki.Trustpool, self).__init__()

                    self.yang_name = "trustpool"
                    self.yang_parent_name = "pki"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("import", ("import_", Native.Crypto.Pki.Trustpool.Import))])
                    self._leafs = OrderedDict()

                    self.import_ = None
                    self._children_name_map["import_"] = "import"
                    self._segment_path = lambda: "trustpool"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Pki.Trustpool, [], name, value)


                class Import(Entity):
                    """
                    Import a trustpool bundle
                    
                    .. attribute:: clean
                    
                    	Remove all downloaded trustpool certificates prior to import
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: terminal
                    
                    	Import bundle via the terminal (cut\-and\-paste) in PEM format
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: url
                    
                    	Import via the file systems
                    	**type**\: str
                    
                    	**pattern:** (((bootflash\:)\|(harddisk\:)\|(flash\:)\|(nvram\:)\|(ftp\:)\|(http\:)\|(https\:)\|(scp\:)\|(tftp\:)\|(webui\:)).\*)
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Trustpool.Import, self).__init__()

                        self.yang_name = "import"
                        self.yang_parent_name = "trustpool"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('clean', (YLeaf(YType.empty, 'clean'), ['Empty'])),
                            ('terminal', (YLeaf(YType.empty, 'terminal'), ['Empty'])),
                            ('url', (YLeaf(YType.str, 'url'), ['str'])),
                        ])
                        self.clean = None
                        self.terminal = None
                        self.url = None
                        self._segment_path = lambda: "import"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/trustpool/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Trustpool.Import, ['clean', 'terminal', 'url'], name, value)


            class Default(Entity):
                """
                set default values for tokens
                
                .. attribute:: removal
                
                	actions to take after token removal
                	**type**\:  :py:class:`Removal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Pki.Default.Removal>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Pki.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "pki"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("removal", ("removal", Native.Crypto.Pki.Default.Removal))])
                    self._leafs = OrderedDict()

                    self.removal = Native.Crypto.Pki.Default.Removal()
                    self.removal.parent = self
                    self._children_name_map["removal"] = "removal"
                    self._segment_path = lambda: "default"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Pki.Default, [], name, value)


                class Removal(Entity):
                    """
                    actions to take after token removal
                    
                    .. attribute:: timeout
                    
                    	seconds after token removal at which keys from the token are cleared
                    	**type**\: int
                    
                    	**range:** 0..480
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Pki.Default.Removal, self).__init__()

                        self.yang_name = "removal"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                        ])
                        self.timeout = None
                        self._segment_path = lambda: "removal"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:pki/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Pki.Default.Removal, ['timeout'], name, value)


        class TlsTunnel(Entity):
            """
            
            
            .. attribute:: tls_tunnel_list
            
            	Configure Crypto TLS\-Tunnel Options
            	**type**\: list of  		 :py:class:`TlsTunnelList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.TlsTunnel, self).__init__()

                self.yang_name = "tls-tunnel"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("tls-tunnel-list", ("tls_tunnel_list", Native.Crypto.TlsTunnel.TlsTunnelList))])
                self._leafs = OrderedDict()

                self.tls_tunnel_list = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:tls-tunnel"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.TlsTunnel, [], name, value)


            class TlsTunnelList(Entity):
                """
                Configure Crypto TLS\-Tunnel Options
                
                .. attribute:: tunnel_name  (key)
                
                	Name of TLS\-Tunnel
                	**type**\: str
                
                .. attribute:: local_interface
                
                	Specify the WAN interfaces
                	**type**\: list of  		 :py:class:`LocalInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList.LocalInterface>`
                
                .. attribute:: overlay_address
                
                	Specify the Overlay Address
                	**type**\:  :py:class:`OverlayAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList.OverlayAddress>`
                
                .. attribute:: protection
                
                	Cipher\-Suite
                	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList.Protection>`
                
                .. attribute:: psk
                
                	Specify the Pre\-Shared Key
                	**type**\:  :py:class:`Psk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList.Psk>`
                
                .. attribute:: server
                
                	Specify the Server Address
                	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList.Server>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.TlsTunnel.TlsTunnelList, self).__init__()

                    self.yang_name = "tls-tunnel-list"
                    self.yang_parent_name = "tls-tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['tunnel_name']
                    self._child_classes = OrderedDict([("local-interface", ("local_interface", Native.Crypto.TlsTunnel.TlsTunnelList.LocalInterface)), ("overlay-address", ("overlay_address", Native.Crypto.TlsTunnel.TlsTunnelList.OverlayAddress)), ("protection", ("protection", Native.Crypto.TlsTunnel.TlsTunnelList.Protection)), ("psk", ("psk", Native.Crypto.TlsTunnel.TlsTunnelList.Psk)), ("server", ("server", Native.Crypto.TlsTunnel.TlsTunnelList.Server))])
                    self._leafs = OrderedDict([
                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                    ])
                    self.tunnel_name = None

                    self.overlay_address = Native.Crypto.TlsTunnel.TlsTunnelList.OverlayAddress()
                    self.overlay_address.parent = self
                    self._children_name_map["overlay_address"] = "overlay-address"

                    self.protection = Native.Crypto.TlsTunnel.TlsTunnelList.Protection()
                    self.protection.parent = self
                    self._children_name_map["protection"] = "protection"

                    self.psk = Native.Crypto.TlsTunnel.TlsTunnelList.Psk()
                    self.psk.parent = self
                    self._children_name_map["psk"] = "psk"

                    self.server = Native.Crypto.TlsTunnel.TlsTunnelList.Server()
                    self.server.parent = self
                    self._children_name_map["server"] = "server"

                    self.local_interface = YList(self)
                    self._segment_path = lambda: "tls-tunnel-list" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:tls-tunnel/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.TlsTunnel.TlsTunnelList, ['tunnel_name'], name, value)


                class LocalInterface(Entity):
                    """
                    Specify the WAN interfaces
                    
                    .. attribute:: interface_name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: priority
                    
                    	priority level
                    	**type**\: int
                    
                    	**range:** 1..3
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.TlsTunnel.TlsTunnelList.LocalInterface, self).__init__()

                        self.yang_name = "local-interface"
                        self.yang_parent_name = "tls-tunnel-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.interface_name = None
                        self.priority = None
                        self._segment_path = lambda: "local-interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.TlsTunnel.TlsTunnelList.LocalInterface, ['interface_name', 'priority'], name, value)


                class OverlayAddress(Entity):
                    """
                    Specify the Overlay Address
                    
                    .. attribute:: addresses
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vrf
                    
                    	VRF name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.TlsTunnel.TlsTunnelList.OverlayAddress, self).__init__()

                        self.yang_name = "overlay-address"
                        self.yang_parent_name = "tls-tunnel-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('addresses', (YLeaf(YType.str, 'addresses'), ['str','str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.addresses = None
                        self.vrf = None
                        self._segment_path = lambda: "overlay-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.TlsTunnel.TlsTunnelList.OverlayAddress, ['addresses', 'vrf'], name, value)


                class Protection(Entity):
                    """
                    Cipher\-Suite
                    
                    .. attribute:: protection
                    
                    	
                    	**type**\:  :py:class:`Protection_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList.Protection.Protection_>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.TlsTunnel.TlsTunnelList.Protection, self).__init__()

                        self.yang_name = "protection"
                        self.yang_parent_name = "tls-tunnel-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protection', (YLeaf(YType.enumeration, 'protection'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.TlsTunnel.TlsTunnelList.Protection.Protection_')])),
                        ])
                        self.protection = None
                        self._segment_path = lambda: "protection"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.TlsTunnel.TlsTunnelList.Protection, ['protection'], name, value)

                    class Protection_(Enum):
                        """
                        Protection\_ (Enum Class)

                        .. data:: dhe_psk_aes128_cbc_sha1 = 0

                        .. data:: dhe_psk_aes256_cbc_sha1 = 1

                        .. data:: psk_aes128_cbc_sha1 = 2

                        .. data:: psk_aes256_cbc_sha1 = 3

                        """

                        dhe_psk_aes128_cbc_sha1 = Enum.YLeaf(0, "dhe-psk-aes128-cbc-sha1")

                        dhe_psk_aes256_cbc_sha1 = Enum.YLeaf(1, "dhe-psk-aes256-cbc-sha1")

                        psk_aes128_cbc_sha1 = Enum.YLeaf(2, "psk-aes128-cbc-sha1")

                        psk_aes256_cbc_sha1 = Enum.YLeaf(3, "psk-aes256-cbc-sha1")



                class Psk(Entity):
                    """
                    Specify the Pre\-Shared Key
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: list of  		 :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList.Psk.Id>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.TlsTunnel.TlsTunnelList.Psk, self).__init__()

                        self.yang_name = "psk"
                        self.yang_parent_name = "tls-tunnel-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("id", ("id", Native.Crypto.TlsTunnel.TlsTunnelList.Psk.Id))])
                        self._leafs = OrderedDict()

                        self.id = YList(self)
                        self._segment_path = lambda: "psk"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.TlsTunnel.TlsTunnelList.Psk, [], name, value)


                    class Id(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: key
                        
                        	
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList.Psk.Id.Key>`
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.TlsTunnel.TlsTunnelList.Psk.Id, self).__init__()

                            self.yang_name = "id"
                            self.yang_parent_name = "psk"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("key", ("key", Native.Crypto.TlsTunnel.TlsTunnelList.Psk.Id.Key))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ])
                            self.id = None

                            self.key = Native.Crypto.TlsTunnel.TlsTunnelList.Psk.Id.Key()
                            self.key.parent = self
                            self._children_name_map["key"] = "key"
                            self._segment_path = lambda: "id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.TlsTunnel.TlsTunnelList.Psk.Id, ['id'], name, value)


                        class Key(Entity):
                            """
                            
                            
                            .. attribute:: key
                            
                            	specify the key
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: encryption
                            
                            	
                            	**type**\:  :py:class:`Encryption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList.Psk.Id.Key.Encryption>`
                            
                            .. attribute:: unencryt_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-crypto'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Crypto.TlsTunnel.TlsTunnelList.Psk.Id.Key, self).__init__()

                                self.yang_name = "key"
                                self.yang_parent_name = "id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key', (YLeaf(YType.empty, 'key'), ['Empty'])),
                                    ('encryption', (YLeaf(YType.enumeration, 'encryption'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Crypto.TlsTunnel.TlsTunnelList.Psk.Id.Key.Encryption')])),
                                    ('unencryt_key', (YLeaf(YType.str, 'unencryt-key'), ['str'])),
                                ])
                                self.key = None
                                self.encryption = None
                                self.unencryt_key = None
                                self._segment_path = lambda: "key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Crypto.TlsTunnel.TlsTunnelList.Psk.Id.Key, ['key', 'encryption', 'unencryt_key'], name, value)

                            class Encryption(Enum):
                                """
                                Encryption (Enum Class)

                                .. data:: Y_0 = 0

                                .. data:: Y_6 = 1

                                """

                                Y_0 = Enum.YLeaf(0, "0")

                                Y_6 = Enum.YLeaf(1, "6")



                class Server(Entity):
                    """
                    Specify the Server Address
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList.Server.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.TlsTunnel.TlsTunnelList.Server.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.TlsTunnel.TlsTunnelList.Server, self).__init__()

                        self.yang_name = "server"
                        self.yang_parent_name = "tls-tunnel-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Crypto.TlsTunnel.TlsTunnelList.Server.Ipv4)), ("ipv6", ("ipv6", Native.Crypto.TlsTunnel.TlsTunnelList.Server.Ipv6))])
                        self._leafs = OrderedDict()

                        self.ipv4 = YList(self)
                        self.ipv6 = YList(self)
                        self._segment_path = lambda: "server"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.TlsTunnel.TlsTunnelList.Server, [], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: ipv4  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: port
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.TlsTunnel.TlsTunnelList.Server.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv4']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('port', (YLeaf(YType.uint32, 'port'), ['int'])),
                            ])
                            self.ipv4 = None
                            self.port = None
                            self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.TlsTunnel.TlsTunnelList.Server.Ipv4, ['ipv4', 'port'], name, value)


                    class Ipv6(Entity):
                        """
                        
                        
                        .. attribute:: ipv6  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: port
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-crypto'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Crypto.TlsTunnel.TlsTunnelList.Server.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv6']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ('port', (YLeaf(YType.uint32, 'port'), ['int'])),
                            ])
                            self.ipv6 = None
                            self.port = None
                            self._segment_path = lambda: "ipv6" + "[ipv6='" + str(self.ipv6) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Crypto.TlsTunnel.TlsTunnelList.Server.Ipv6, ['ipv6', 'port'], name, value)


        class Ssl(Entity):
            """
            Configure Crypto SSL Options
            
            .. attribute:: authorization
            
            	ssl authorization
            	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ssl.Authorization>`
            
            .. attribute:: diagnose
            
            	SSLVPN diagnose
            	**type**\:  :py:class:`Diagnose <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ssl.Diagnose>`
            
            .. attribute:: policy
            
            	Define SSL policies
            	**type**\: str
            
            .. attribute:: profile
            
            	Define SSL profiles
            	**type**\: str
            
            .. attribute:: proposal
            
            	Define ssl Proposal
            	**type**\:  :py:class:`Proposal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ssl.Proposal>`
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Ssl, self).__init__()

                self.yang_name = "ssl"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("authorization", ("authorization", Native.Crypto.Ssl.Authorization)), ("diagnose", ("diagnose", Native.Crypto.Ssl.Diagnose)), ("proposal", ("proposal", Native.Crypto.Ssl.Proposal))])
                self._leafs = OrderedDict([
                    ('policy', (YLeaf(YType.str, 'policy'), ['str'])),
                    ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                ])
                self.policy = None
                self.profile = None

                self.authorization = Native.Crypto.Ssl.Authorization()
                self.authorization.parent = self
                self._children_name_map["authorization"] = "authorization"

                self.diagnose = Native.Crypto.Ssl.Diagnose()
                self.diagnose.parent = self
                self._children_name_map["diagnose"] = "diagnose"

                self.proposal = Native.Crypto.Ssl.Proposal()
                self.proposal.parent = self
                self._children_name_map["proposal"] = "proposal"
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:ssl"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Ssl, ['policy', 'profile'], name, value)


            class Authorization(Entity):
                """
                ssl authorization
                
                .. attribute:: policy
                
                	Crypto SSL authorization policy
                	**type**\: str
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ssl.Authorization, self).__init__()

                    self.yang_name = "authorization"
                    self.yang_parent_name = "ssl"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('policy', (YLeaf(YType.str, 'policy'), ['str'])),
                    ])
                    self.policy = None
                    self._segment_path = lambda: "authorization"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ssl/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ssl.Authorization, ['policy'], name, value)


            class Diagnose(Entity):
                """
                SSLVPN diagnose
                
                .. attribute:: error
                
                	Start error trace debug
                	**type**\: int
                
                	**range:** 1..1000
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ssl.Diagnose, self).__init__()

                    self.yang_name = "diagnose"
                    self.yang_parent_name = "ssl"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('error', (YLeaf(YType.uint16, 'error'), ['int'])),
                    ])
                    self.error = None
                    self._segment_path = lambda: "diagnose"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ssl/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ssl.Diagnose, ['error'], name, value)


            class Proposal(Entity):
                """
                Define ssl Proposal
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: protection
                
                	Specify the protection algorithms
                	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Ssl.Proposal.Protection>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Ssl.Proposal, self).__init__()

                    self.yang_name = "proposal"
                    self.yang_parent_name = "ssl"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("protection", ("protection", Native.Crypto.Ssl.Proposal.Protection))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.protection = Native.Crypto.Ssl.Proposal.Protection()
                    self.protection.parent = self
                    self._children_name_map["protection"] = "protection"
                    self._segment_path = lambda: "proposal"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ssl/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Ssl.Proposal, ['name'], name, value)


                class Protection(Entity):
                    """
                    Specify the protection algorithms
                    
                    .. attribute:: rsa_3des_ede_sha1
                    
                    	RSA, 3DES and SHA1
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: rsa_aes128_sha1
                    
                    	RSA, AES128 and SHA1
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: rsa_aes256_sha1
                    
                    	RSA, AES256 and SHA1
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: rsa_rc4128_md5
                    
                    	RSA, RC4 and MD5
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Ssl.Proposal.Protection, self).__init__()

                        self.yang_name = "protection"
                        self.yang_parent_name = "proposal"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('rsa_3des_ede_sha1', (YLeaf(YType.empty, 'rsa-3des-ede-sha1'), ['Empty'])),
                            ('rsa_aes128_sha1', (YLeaf(YType.empty, 'rsa-aes128-sha1'), ['Empty'])),
                            ('rsa_aes256_sha1', (YLeaf(YType.empty, 'rsa-aes256-sha1'), ['Empty'])),
                            ('rsa_rc4128_md5', (YLeaf(YType.empty, 'rsa-rc4128-md5'), ['Empty'])),
                        ])
                        self.rsa_3des_ede_sha1 = None
                        self.rsa_aes128_sha1 = None
                        self.rsa_aes256_sha1 = None
                        self.rsa_rc4128_md5 = None
                        self._segment_path = lambda: "protection"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:ssl/proposal/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Ssl.Proposal.Protection, ['rsa_3des_ede_sha1', 'rsa_aes128_sha1', 'rsa_aes256_sha1', 'rsa_rc4128_md5'], name, value)


        class Vpn(Entity):
            """
            Configure crypto vpn commands
            
            .. attribute:: anyconnect
            
            	Configure anyconnect client package
            	**type**\:  :py:class:`Anyconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Vpn.Anyconnect>`
            
            .. attribute:: csd
            
            	Configure Secure Desktop package
            	**type**\: str
            
            

            """

            _prefix = 'ios-crypto'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Crypto.Vpn, self).__init__()

                self.yang_name = "vpn"
                self.yang_parent_name = "crypto"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("anyconnect", ("anyconnect", Native.Crypto.Vpn.Anyconnect))])
                self._leafs = OrderedDict([
                    ('csd', (YLeaf(YType.str, 'csd'), ['str'])),
                ])
                self.csd = None

                self.anyconnect = Native.Crypto.Vpn.Anyconnect()
                self.anyconnect.parent = self
                self._children_name_map["anyconnect"] = "anyconnect"
                self._segment_path = lambda: "Cisco-IOS-XE-crypto:vpn"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Crypto.Vpn, ['csd'], name, value)


            class Anyconnect(Entity):
                """
                Configure anyconnect client package
                
                .. attribute:: file
                
                	
                	**type**\:  :py:class:`File <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Vpn.Anyconnect.File>`
                
                .. attribute:: profile_container
                
                	
                	**type**\:  :py:class:`ProfileContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Crypto.Vpn.Anyconnect.ProfileContainer>`
                
                

                """

                _prefix = 'ios-crypto'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Crypto.Vpn.Anyconnect, self).__init__()

                    self.yang_name = "anyconnect"
                    self.yang_parent_name = "vpn"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("file", ("file", Native.Crypto.Vpn.Anyconnect.File)), ("profile-container", ("profile_container", Native.Crypto.Vpn.Anyconnect.ProfileContainer))])
                    self._leafs = OrderedDict()

                    self.file = Native.Crypto.Vpn.Anyconnect.File()
                    self.file.parent = self
                    self._children_name_map["file"] = "file"

                    self.profile_container = Native.Crypto.Vpn.Anyconnect.ProfileContainer()
                    self.profile_container.parent = self
                    self._children_name_map["profile_container"] = "profile-container"
                    self._segment_path = lambda: "anyconnect"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:vpn/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Crypto.Vpn.Anyconnect, [], name, value)


                class File(Entity):
                    """
                    
                    
                    .. attribute:: filename
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: sequence
                    
                    	client\-side download sequence num (priority) of this package
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Vpn.Anyconnect.File, self).__init__()

                        self.yang_name = "file"
                        self.yang_parent_name = "anyconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('filename', (YLeaf(YType.str, 'filename'), ['str'])),
                            ('sequence', (YLeaf(YType.uint8, 'sequence'), ['int'])),
                        ])
                        self.filename = None
                        self.sequence = None
                        self._segment_path = lambda: "file"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:vpn/anyconnect/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Vpn.Anyconnect.File, ['filename', 'sequence'], name, value)


                class ProfileContainer(Entity):
                    """
                    
                    
                    .. attribute:: profile
                    
                    	Configure anyconnect client profile
                    	**type**\: str
                    
                    .. attribute:: filename
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-crypto'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Crypto.Vpn.Anyconnect.ProfileContainer, self).__init__()

                        self.yang_name = "profile-container"
                        self.yang_parent_name = "anyconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                            ('filename', (YLeaf(YType.str, 'filename'), ['str'])),
                        ])
                        self.profile = None
                        self.filename = None
                        self._segment_path = lambda: "profile-container"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/crypto/Cisco-IOS-XE-crypto:vpn/anyconnect/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Crypto.Vpn.Anyconnect.ProfileContainer, ['profile', 'filename'], name, value)


    class Cts(Entity):
        """
        Configures Cisco TrustSec
        
        .. attribute:: cache
        
        	CTS cache configuration
        	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Cache>`
        
        .. attribute:: critical_authentication_conf
        
        	
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: critical_authentication
        
        	Critical\-Auth configuration commands
        	**type**\:  :py:class:`CriticalAuthentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.CriticalAuthentication>`
        
        	**presence node**\: True
        
        .. attribute:: authorization
        
        	CTS global authorization configuration
        	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Authorization>`
        
        .. attribute:: dot1x_server_timeout
        
        	Timeout for Radius Retries
        	**type**\: int
        
        	**range:** 30..65535
        
        .. attribute:: dot1x_supp_timeout
        
        	Timeout for supplicant reply
        	**type**\: int
        
        	**range:** 30..65535
        
        .. attribute:: logging
        
        	Set logging parameters
        	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Logging>`
        
        .. attribute:: role_based
        
        	Role\-based Access Control configuration commands
        	**type**\:  :py:class:`RoleBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased>`
        
        .. attribute:: server
        
        	CTS server list configuration
        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Server>`
        
        .. attribute:: sgt
        
        	Local device security group
        	**type**\: int
        
        	**range:** 2..65519
        
        .. attribute:: sg_epg
        
        	Security\-Group and Endpoint\-Group Configuration commands
        	**type**\:  :py:class:`SgEpg <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.SgEpg>`
        
        .. attribute:: sxp
        
        	CTS sxp configuration
        	**type**\:  :py:class:`Sxp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Cts, self).__init__()

            self.yang_name = "cts"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-cts:cache", ("cache", Native.Cts.Cache)), ("Cisco-IOS-XE-cts:critical-authentication", ("critical_authentication", Native.Cts.CriticalAuthentication)), ("Cisco-IOS-XE-cts:authorization", ("authorization", Native.Cts.Authorization)), ("Cisco-IOS-XE-cts:role-based", ("role_based", Native.Cts.RoleBased)), ("Cisco-IOS-XE-cts:server", ("server", Native.Cts.Server)), ("Cisco-IOS-XE-cts:sxp", ("sxp", Native.Cts.Sxp))])
            self._leafs = OrderedDict([
                ('critical_authentication_conf', (YLeaf(YType.empty, 'Cisco-IOS-XE-cts:critical-authentication-conf'), ['Empty'])),
                ('dot1x_server_timeout', (YLeaf(YType.uint16, 'Cisco-IOS-XE-cts:dot1x-server-timeout'), ['int'])),
                ('dot1x_supp_timeout', (YLeaf(YType.uint16, 'Cisco-IOS-XE-cts:dot1x-supp-timeout'), ['int'])),
                ('logging', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-cts:logging'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Cts.Logging')])),
                ('sgt', (YLeaf(YType.uint16, 'Cisco-IOS-XE-cts:sgt'), ['int'])),
                ('sg_epg', (YLeaf(YType.enumeration, 'Cisco-IOS-XE-cts:sg-epg'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Cts.SgEpg')])),
            ])
            self.critical_authentication_conf = None
            self.dot1x_server_timeout = None
            self.dot1x_supp_timeout = None
            self.logging = None
            self.sgt = None
            self.sg_epg = None

            self.cache = Native.Cts.Cache()
            self.cache.parent = self
            self._children_name_map["cache"] = "Cisco-IOS-XE-cts:cache"

            self.critical_authentication = None
            self._children_name_map["critical_authentication"] = "Cisco-IOS-XE-cts:critical-authentication"

            self.authorization = Native.Cts.Authorization()
            self.authorization.parent = self
            self._children_name_map["authorization"] = "Cisco-IOS-XE-cts:authorization"

            self.role_based = Native.Cts.RoleBased()
            self.role_based.parent = self
            self._children_name_map["role_based"] = "Cisco-IOS-XE-cts:role-based"

            self.server = Native.Cts.Server()
            self.server.parent = self
            self._children_name_map["server"] = "Cisco-IOS-XE-cts:server"

            self.sxp = Native.Cts.Sxp()
            self.sxp.parent = self
            self._children_name_map["sxp"] = "Cisco-IOS-XE-cts:sxp"
            self._segment_path = lambda: "cts"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Cts, ['critical_authentication_conf', 'dot1x_server_timeout', 'dot1x_supp_timeout', 'logging', 'sgt', 'sg_epg'], name, value)

        class Logging(Enum):
            """
            Logging (Enum Class)

            Set logging parameters

            .. data:: verbose = 0

            """

            verbose = Enum.YLeaf(0, "verbose")


        class SgEpg(Enum):
            """
            SgEpg (Enum Class)

            Security\-Group and Endpoint\-Group Configuration commands

            .. data:: translation = 0

            """

            translation = Enum.YLeaf(0, "translation")



        class Cache(Entity):
            """
            CTS cache configuration
            
            .. attribute:: enable
            
            	Enable CTS cache support
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: nv_storage
            
            	CTS nv\-storage options
            	**type**\:  :py:class:`NvStorage <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Cache.NvStorage>`
            
            

            """

            _prefix = 'ios-cts'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Cts.Cache, self).__init__()

                self.yang_name = "cache"
                self.yang_parent_name = "cts"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("nv-storage", ("nv_storage", Native.Cts.Cache.NvStorage))])
                self._leafs = OrderedDict([
                    ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                ])
                self.enable = None

                self.nv_storage = Native.Cts.Cache.NvStorage()
                self.nv_storage.parent = self
                self._children_name_map["nv_storage"] = "nv-storage"
                self._segment_path = lambda: "Cisco-IOS-XE-cts:cache"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Cts.Cache, ['enable'], name, value)


            class NvStorage(Entity):
                """
                CTS nv\-storage options
                
                .. attribute:: nv_storage
                
                	
                	**type**\:  :py:class:`NvStorage_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Cache.NvStorage.NvStorage_>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.Cache.NvStorage, self).__init__()

                    self.yang_name = "nv-storage"
                    self.yang_parent_name = "cache"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('nv_storage', (YLeaf(YType.enumeration, 'nv-storage'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Cts.Cache.NvStorage.NvStorage_')])),
                    ])
                    self.nv_storage = None
                    self._segment_path = lambda: "nv-storage"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:cache/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.Cache.NvStorage, ['nv_storage'], name, value)

                class NvStorage_(Enum):
                    """
                    NvStorage\_ (Enum Class)

                    .. data:: bootflash__COLON__ = 0

                    .. data:: crashinfo__COLON__ = 1

                    .. data:: kinfo__COLON__ = 2

                    .. data:: slot0__COLON__ = 3

                    .. data:: usb0__COLON__ = 4

                    """

                    bootflash__COLON__ = Enum.YLeaf(0, "bootflash:")

                    crashinfo__COLON__ = Enum.YLeaf(1, "crashinfo:")

                    kinfo__COLON__ = Enum.YLeaf(2, "kinfo:")

                    slot0__COLON__ = Enum.YLeaf(3, "slot0:")

                    usb0__COLON__ = Enum.YLeaf(4, "usb0:")



        class CriticalAuthentication(Entity):
            """
            Critical\-Auth configuration commands
            
            .. attribute:: default
            
            	Enter default value
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.CriticalAuthentication.Default>`
            
            .. attribute:: fallback
            
            	Access policy to be applied in Critical\-Auth
            	**type**\:  :py:class:`Fallback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.CriticalAuthentication.Fallback>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-cts'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Cts.CriticalAuthentication, self).__init__()

                self.yang_name = "critical-authentication"
                self.yang_parent_name = "cts"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("default", ("default", Native.Cts.CriticalAuthentication.Default)), ("fallback", ("fallback", Native.Cts.CriticalAuthentication.Fallback))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.default = Native.Cts.CriticalAuthentication.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.fallback = Native.Cts.CriticalAuthentication.Fallback()
                self.fallback.parent = self
                self._children_name_map["fallback"] = "fallback"
                self._segment_path = lambda: "Cisco-IOS-XE-cts:critical-authentication"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Cts.CriticalAuthentication, [], name, value)


            class Default(Entity):
                """
                Enter default value
                
                .. attribute:: peer_sgt
                
                	Default Peer SGT value
                	**type**\:  :py:class:`PeerSgt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.CriticalAuthentication.Default.PeerSgt>`
                
                .. attribute:: pmk
                
                	Default PMK value to be used for all SAP
                	**type**\:  :py:class:`Pmk <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.CriticalAuthentication.Default.Pmk>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.CriticalAuthentication.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "critical-authentication"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("peer-sgt", ("peer_sgt", Native.Cts.CriticalAuthentication.Default.PeerSgt)), ("pmk", ("pmk", Native.Cts.CriticalAuthentication.Default.Pmk))])
                    self._leafs = OrderedDict()

                    self.peer_sgt = Native.Cts.CriticalAuthentication.Default.PeerSgt()
                    self.peer_sgt.parent = self
                    self._children_name_map["peer_sgt"] = "peer-sgt"

                    self.pmk = Native.Cts.CriticalAuthentication.Default.Pmk()
                    self.pmk.parent = self
                    self._children_name_map["pmk"] = "pmk"
                    self._segment_path = lambda: "default"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:critical-authentication/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.CriticalAuthentication.Default, [], name, value)


                class PeerSgt(Entity):
                    """
                    Default Peer SGT value
                    
                    .. attribute:: range
                    
                    	
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.CriticalAuthentication.Default.PeerSgt.Range>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Cts.CriticalAuthentication.Default.PeerSgt, self).__init__()

                        self.yang_name = "peer-sgt"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Native.Cts.CriticalAuthentication.Default.PeerSgt.Range))])
                        self._leafs = OrderedDict()

                        self.range = YList(self)
                        self._segment_path = lambda: "peer-sgt"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:critical-authentication/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cts.CriticalAuthentication.Default.PeerSgt, [], name, value)


                    class Range(Entity):
                        """
                        
                        
                        .. attribute:: range  (key)
                        
                        	Enter default peer\-sgt value
                        	**type**\: int
                        
                        	**range:** 2..65519
                        
                        .. attribute:: trusted
                        
                        	Trust the Source Group Tags that peer uses for sending
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Cts.CriticalAuthentication.Default.PeerSgt.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "peer-sgt"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['range']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ('trusted', (YLeaf(YType.empty, 'trusted'), ['Empty'])),
                            ])
                            self.range = None
                            self.trusted = None
                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:critical-authentication/default/peer-sgt/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cts.CriticalAuthentication.Default.PeerSgt.Range, ['range', 'trusted'], name, value)


                class Pmk(Entity):
                    """
                    Default PMK value to be used for all SAP
                    
                    .. attribute:: type
                    
                    	
                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.CriticalAuthentication.Default.Pmk.Type>`
                    
                    .. attribute:: secret
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Cts.CriticalAuthentication.Default.Pmk, self).__init__()

                        self.yang_name = "pmk"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Cts.CriticalAuthentication.Default.Pmk.Type')])),
                            ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                        ])
                        self.type = None
                        self.secret = None
                        self._segment_path = lambda: "pmk"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:critical-authentication/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cts.CriticalAuthentication.Default.Pmk, ['type', 'secret'], name, value)

                    class Type(Enum):
                        """
                        Type (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_6 = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_6 = Enum.YLeaf(1, "6")



            class Fallback(Entity):
                """
                Access policy to be applied in Critical\-Auth
                
                .. attribute:: cached
                
                	Cached values to be used for existing sessions
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: default
                
                	Configured values to be applied for existing sessions
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.CriticalAuthentication.Fallback, self).__init__()

                    self.yang_name = "fallback"
                    self.yang_parent_name = "critical-authentication"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('cached', (YLeaf(YType.empty, 'Cached'), ['Empty'])),
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                    ])
                    self.cached = None
                    self.default = None
                    self._segment_path = lambda: "fallback"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:critical-authentication/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.CriticalAuthentication.Fallback, ['cached', 'default'], name, value)


        class Authorization(Entity):
            """
            CTS global authorization configuration
            
            .. attribute:: list
            
            	Local authorization list to use for CTS
            	**type**\: str
            
            

            """

            _prefix = 'ios-cts'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Cts.Authorization, self).__init__()

                self.yang_name = "authorization"
                self.yang_parent_name = "cts"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('list', (YLeaf(YType.str, 'list'), ['str'])),
                ])
                self.list = None
                self._segment_path = lambda: "Cisco-IOS-XE-cts:authorization"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Cts.Authorization, ['list'], name, value)


        class RoleBased(Entity):
            """
            Role\-based Access Control configuration commands
            
            .. attribute:: sgt_caching
            
            	Enable SGT caching
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: permissions
            
            	Permissions from a source group to a destination group
            	**type**\:  :py:class:`Permissions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.Permissions>`
            
            .. attribute:: enforcement_only
            
            	
            	**type**\:  :py:class:`EnforcementOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.EnforcementOnly>`
            
            .. attribute:: enforcement
            
            	Enable Role\-based Access Control enforcement
            	**type**\:  :py:class:`Enforcement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.Enforcement>`
            
            .. attribute:: monitor
            
            	Role\-based Access List Monitor Commands
            	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.Monitor>`
            
            .. attribute:: sgt_map
            
            	Assign Security Group Tag (SGT) to IP host or network address
            	**type**\: list of  		 :py:class:`SgtMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.SgtMap>`
            
            .. attribute:: sgt_map_vlan_list
            
            	VLANs on which Role\-based ACLs are enforced
            	**type**\:  :py:class:`SgtMapVlanList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.SgtMapVlanList>`
            
            

            """

            _prefix = 'ios-cts'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Cts.RoleBased, self).__init__()

                self.yang_name = "role-based"
                self.yang_parent_name = "cts"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("permissions", ("permissions", Native.Cts.RoleBased.Permissions)), ("enforcement-only", ("enforcement_only", Native.Cts.RoleBased.EnforcementOnly)), ("enforcement", ("enforcement", Native.Cts.RoleBased.Enforcement)), ("monitor", ("monitor", Native.Cts.RoleBased.Monitor)), ("sgt-map", ("sgt_map", Native.Cts.RoleBased.SgtMap)), ("sgt-map-vlan-list", ("sgt_map_vlan_list", Native.Cts.RoleBased.SgtMapVlanList))])
                self._leafs = OrderedDict([
                    ('sgt_caching', (YLeaf(YType.empty, 'sgt-caching'), ['Empty'])),
                ])
                self.sgt_caching = None

                self.permissions = Native.Cts.RoleBased.Permissions()
                self.permissions.parent = self
                self._children_name_map["permissions"] = "permissions"

                self.enforcement_only = Native.Cts.RoleBased.EnforcementOnly()
                self.enforcement_only.parent = self
                self._children_name_map["enforcement_only"] = "enforcement-only"

                self.enforcement = Native.Cts.RoleBased.Enforcement()
                self.enforcement.parent = self
                self._children_name_map["enforcement"] = "enforcement"

                self.monitor = Native.Cts.RoleBased.Monitor()
                self.monitor.parent = self
                self._children_name_map["monitor"] = "monitor"

                self.sgt_map_vlan_list = Native.Cts.RoleBased.SgtMapVlanList()
                self.sgt_map_vlan_list.parent = self
                self._children_name_map["sgt_map_vlan_list"] = "sgt-map-vlan-list"

                self.sgt_map = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-cts:role-based"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Cts.RoleBased, ['sgt_caching'], name, value)


            class Permissions(Entity):
                """
                Permissions from a source group to a destination group
                
                .. attribute:: default
                
                	Default Permission list
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.Permissions.Default>`
                
                .. attribute:: from_
                
                	Source Group Tag (SGT) of filtered traffic
                	**type**\:  :py:class:`From <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.Permissions.From>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.RoleBased.Permissions, self).__init__()

                    self.yang_name = "permissions"
                    self.yang_parent_name = "role-based"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Cts.RoleBased.Permissions.Default)), ("from", ("from_", Native.Cts.RoleBased.Permissions.From))])
                    self._leafs = OrderedDict()

                    self.default = Native.Cts.RoleBased.Permissions.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.from_ = Native.Cts.RoleBased.Permissions.From()
                    self.from_.parent = self
                    self._children_name_map["from_"] = "from"
                    self._segment_path = lambda: "permissions"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:role-based/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.RoleBased.Permissions, [], name, value)


                class Default(Entity):
                    """
                    Default Permission list
                    
                    .. attribute:: name
                    
                    	Role\-based Access\-list name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Cts.RoleBased.Permissions.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "permissions"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:role-based/permissions/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cts.RoleBased.Permissions.Default, ['name'], name, value)


                class From(Entity):
                    """
                    Source Group Tag (SGT) of filtered traffic
                    
                    .. attribute:: range
                    
                    	
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.Permissions.From.Range>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Cts.RoleBased.Permissions.From, self).__init__()

                        self.yang_name = "from"
                        self.yang_parent_name = "permissions"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Native.Cts.RoleBased.Permissions.From.Range))])
                        self._leafs = OrderedDict()

                        self.range = YList(self)
                        self._segment_path = lambda: "from"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:role-based/permissions/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cts.RoleBased.Permissions.From, [], name, value)


                    class Range(Entity):
                        """
                        
                        
                        .. attribute:: range  (key)
                        
                        	Security Group Tag
                        	**type**\: int
                        
                        	**range:** 0..65519
                        
                        .. attribute:: to
                        
                        	Destination Group Tag (DGT) of filtered traffic
                        	**type**\:  :py:class:`To <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.Permissions.From.Range.To>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Cts.RoleBased.Permissions.From.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "from"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['range']
                            self._child_classes = OrderedDict([("to", ("to", Native.Cts.RoleBased.Permissions.From.Range.To))])
                            self._leafs = OrderedDict([
                                ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                            ])
                            self.range = None

                            self.to = Native.Cts.RoleBased.Permissions.From.Range.To()
                            self.to.parent = self
                            self._children_name_map["to"] = "to"
                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:role-based/permissions/from/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cts.RoleBased.Permissions.From.Range, ['range'], name, value)


                        class To(Entity):
                            """
                            Destination Group Tag (DGT) of filtered traffic
                            
                            .. attribute:: range
                            
                            	
                            	**type**\: list of  		 :py:class:`Range_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.Permissions.From.Range.To.Range_>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Cts.RoleBased.Permissions.From.Range.To, self).__init__()

                                self.yang_name = "to"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("range", ("range", Native.Cts.RoleBased.Permissions.From.Range.To.Range_))])
                                self._leafs = OrderedDict()

                                self.range = YList(self)
                                self._segment_path = lambda: "to"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Cts.RoleBased.Permissions.From.Range.To, [], name, value)


                            class Range_(Entity):
                                """
                                
                                
                                .. attribute:: range  (key)
                                
                                	Security Group Tag
                                	**type**\: int
                                
                                	**range:** 0..65519
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Cts.RoleBased.Permissions.From.Range.To.Range_, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "to"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['range']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.range = None
                                    self.name = None
                                    self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Cts.RoleBased.Permissions.From.Range.To.Range_, ['range', 'name'], name, value)


            class EnforcementOnly(Entity):
                """
                
                
                .. attribute:: enforcement
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.RoleBased.EnforcementOnly, self).__init__()

                    self.yang_name = "enforcement-only"
                    self.yang_parent_name = "role-based"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enforcement', (YLeaf(YType.empty, 'enforcement'), ['Empty'])),
                    ])
                    self.enforcement = None
                    self._segment_path = lambda: "enforcement-only"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:role-based/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.RoleBased.EnforcementOnly, ['enforcement'], name, value)


            class Enforcement(Entity):
                """
                Enable Role\-based Access Control enforcement
                
                .. attribute:: logging_interval
                
                	Configure sgacl logging interval
                	**type**\: int
                
                	**range:** 5..86400
                
                .. attribute:: vlan_list
                
                	VLANs on which Role\-based ACLs are enforced
                	**type**\: list of  		 :py:class:`VlanList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.Enforcement.VlanList>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.RoleBased.Enforcement, self).__init__()

                    self.yang_name = "enforcement"
                    self.yang_parent_name = "role-based"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vlan-list", ("vlan_list", Native.Cts.RoleBased.Enforcement.VlanList))])
                    self._leafs = OrderedDict([
                        ('logging_interval', (YLeaf(YType.uint32, 'logging-interval'), ['int'])),
                    ])
                    self.logging_interval = None

                    self.vlan_list = YList(self)
                    self._segment_path = lambda: "enforcement"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:role-based/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.RoleBased.Enforcement, ['logging_interval'], name, value)


                class VlanList(Entity):
                    """
                    VLANs on which Role\-based ACLs are enforced
                    
                    .. attribute:: id  (key)
                    
                    	VLAN id
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.Enforcement.VlanList.Id>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Cts.RoleBased.Enforcement.VlanList, self).__init__()

                        self.yang_name = "vlan-list"
                        self.yang_parent_name = "enforcement"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Cts.RoleBased.Enforcement.VlanList.Id')])),
                        ])
                        self.id = None
                        self._segment_path = lambda: "vlan-list" + "[id='" + str(self.id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:role-based/enforcement/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cts.RoleBased.Enforcement.VlanList, ['id'], name, value)

                    class Id(Enum):
                        """
                        Id (Enum Class)

                        VLAN id

                        .. data:: all = 0

                        """

                        all = Enum.YLeaf(0, "all")



            class Monitor(Entity):
                """
                Role\-based Access List Monitor Commands
                
                .. attribute:: all
                
                	Monitoring permissions for all source group to all destination group
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.RoleBased.Monitor, self).__init__()

                    self.yang_name = "monitor"
                    self.yang_parent_name = "role-based"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                    ])
                    self.all = None
                    self._segment_path = lambda: "monitor"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:role-based/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.RoleBased.Monitor, ['all'], name, value)


            class SgtMap(Entity):
                """
                Assign Security Group Tag (SGT) to IP host or network address
                
                .. attribute:: ip  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                
                .. attribute:: sgt  (key)
                
                	Security Group Tag (SGT)
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vrf
                
                	Select VPN Routing/Forwarding instance for the binding
                	**type**\: str
                
                .. attribute:: host
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.RoleBased.SgtMap, self).__init__()

                    self.yang_name = "sgt-map"
                    self.yang_parent_name = "role-based"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['ip','sgt']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.str, 'ip'), ['str','str','str','str'])),
                        ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                    ])
                    self.ip = None
                    self.sgt = None
                    self.vrf = None
                    self.host = None
                    self._segment_path = lambda: "sgt-map" + "[ip='" + str(self.ip) + "']" + "[sgt='" + str(self.sgt) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:role-based/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.RoleBased.SgtMap, ['ip', 'sgt', 'vrf', 'host'], name, value)


            class SgtMapVlanList(Entity):
                """
                VLANs on which Role\-based ACLs are enforced
                
                .. attribute:: sgt_map
                
                	
                	**type**\: list of  		 :py:class:`SgtMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.SgtMapVlanList.SgtMap>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.RoleBased.SgtMapVlanList, self).__init__()

                    self.yang_name = "sgt-map-vlan-list"
                    self.yang_parent_name = "role-based"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("sgt-map", ("sgt_map", Native.Cts.RoleBased.SgtMapVlanList.SgtMap))])
                    self._leafs = OrderedDict()

                    self.sgt_map = YList(self)
                    self._segment_path = lambda: "sgt-map-vlan-list"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:role-based/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.RoleBased.SgtMapVlanList, [], name, value)


                class SgtMap(Entity):
                    """
                    
                    
                    .. attribute:: vlan_list  (key)
                    
                    	VLANs id
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    		**type**\:  :py:class:`VlanList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.RoleBased.SgtMapVlanList.SgtMap.VlanList>`
                    
                    .. attribute:: sgt
                    
                    	Security Group Tag value
                    	**type**\: int
                    
                    	**range:** \-32768..32767
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Cts.RoleBased.SgtMapVlanList.SgtMap, self).__init__()

                        self.yang_name = "sgt-map"
                        self.yang_parent_name = "sgt-map-vlan-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['vlan_list']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_list', (YLeaf(YType.str, 'vlan-list'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Cts.RoleBased.SgtMapVlanList.SgtMap.VlanList')])),
                            ('sgt', (YLeaf(YType.int16, 'sgt'), ['int'])),
                        ])
                        self.vlan_list = None
                        self.sgt = None
                        self._segment_path = lambda: "sgt-map" + "[vlan-list='" + str(self.vlan_list) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:role-based/sgt-map-vlan-list/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cts.RoleBased.SgtMapVlanList.SgtMap, ['vlan_list', 'sgt'], name, value)

                    class VlanList(Enum):
                        """
                        VlanList (Enum Class)

                        VLANs id

                        .. data:: all = 0

                        """

                        all = Enum.YLeaf(0, "all")



        class Server(Entity):
            """
            CTS server list configuration
            
            .. attribute:: deadtime
            
            	Configure server group deadtime to specify how long a servermarked as dead should not be used
            	**type**\: int
            
            	**range:** 0..864000
            
            .. attribute:: key_wrap
            
            	CTS key\-wrap configuration
            	**type**\:  :py:class:`KeyWrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Server.KeyWrap>`
            
            .. attribute:: load_balance
            
            	CTS Server group load\-balancing options
            	**type**\:  :py:class:`LoadBalance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Server.LoadBalance>`
            
            .. attribute:: test
            
            	Configure server automated test for liveness check
            	**type**\:  :py:class:`Test <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Server.Test>`
            
            

            """

            _prefix = 'ios-cts'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Cts.Server, self).__init__()

                self.yang_name = "server"
                self.yang_parent_name = "cts"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("key-wrap", ("key_wrap", Native.Cts.Server.KeyWrap)), ("load-balance", ("load_balance", Native.Cts.Server.LoadBalance)), ("test", ("test", Native.Cts.Server.Test))])
                self._leafs = OrderedDict([
                    ('deadtime', (YLeaf(YType.uint32, 'deadtime'), ['int'])),
                ])
                self.deadtime = None

                self.key_wrap = Native.Cts.Server.KeyWrap()
                self.key_wrap.parent = self
                self._children_name_map["key_wrap"] = "key-wrap"

                self.load_balance = Native.Cts.Server.LoadBalance()
                self.load_balance.parent = self
                self._children_name_map["load_balance"] = "load-balance"

                self.test = Native.Cts.Server.Test()
                self.test.parent = self
                self._children_name_map["test"] = "test"
                self._segment_path = lambda: "Cisco-IOS-XE-cts:server"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Cts.Server, ['deadtime'], name, value)


            class KeyWrap(Entity):
                """
                CTS key\-wrap configuration
                
                .. attribute:: enable
                
                	Enable CTS key\-wrap for Private server\-list
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.Server.KeyWrap, self).__init__()

                    self.yang_name = "key-wrap"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None
                    self._segment_path = lambda: "key-wrap"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:server/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.Server.KeyWrap, ['enable'], name, value)


            class LoadBalance(Entity):
                """
                CTS Server group load\-balancing options
                
                .. attribute:: method
                
                	Method by which the next server will be picked
                	**type**\:  :py:class:`Method <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Server.LoadBalance.Method>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.Server.LoadBalance, self).__init__()

                    self.yang_name = "load-balance"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("method", ("method", Native.Cts.Server.LoadBalance.Method))])
                    self._leafs = OrderedDict()

                    self.method = Native.Cts.Server.LoadBalance.Method()
                    self.method.parent = self
                    self._children_name_map["method"] = "method"
                    self._segment_path = lambda: "load-balance"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:server/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.Server.LoadBalance, [], name, value)


                class Method(Entity):
                    """
                    Method by which the next server will be picked
                    
                    .. attribute:: least_outstanding
                    
                    	Pick the server with the least transactions outstanding
                    	**type**\:  :py:class:`LeastOutstanding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Server.LoadBalance.Method.LeastOutstanding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Cts.Server.LoadBalance.Method, self).__init__()

                        self.yang_name = "method"
                        self.yang_parent_name = "load-balance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("least-outstanding", ("least_outstanding", Native.Cts.Server.LoadBalance.Method.LeastOutstanding))])
                        self._leafs = OrderedDict()

                        self.least_outstanding = None
                        self._children_name_map["least_outstanding"] = "least-outstanding"
                        self._segment_path = lambda: "method"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:server/load-balance/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cts.Server.LoadBalance.Method, [], name, value)


                    class LeastOutstanding(Entity):
                        """
                        Pick the server with the least transactions outstanding
                        
                        .. attribute:: batch_size
                        
                        	Size of the transaction batch that should be load\-balanced
                        	**type**\: int
                        
                        	**range:** 1..2147483647
                        
                        .. attribute:: ignore_preferred_server
                        
                        	Do not attempt to stick with the same server throughout a session
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Cts.Server.LoadBalance.Method.LeastOutstanding, self).__init__()

                            self.yang_name = "least-outstanding"
                            self.yang_parent_name = "method"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('batch_size', (YLeaf(YType.uint32, 'batch-size'), ['int'])),
                                ('ignore_preferred_server', (YLeaf(YType.empty, 'ignore-preferred-server'), ['Empty'])),
                            ])
                            self.batch_size = None
                            self.ignore_preferred_server = None
                            self._segment_path = lambda: "least-outstanding"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:server/load-balance/method/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cts.Server.LoadBalance.Method.LeastOutstanding, ['batch_size', 'ignore_preferred_server'], name, value)


            class Test(Entity):
                """
                Configure server automated test for liveness check
                
                .. attribute:: server
                
                	
                	**type**\: list of  		 :py:class:`Server_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Server.Test.Server_>`
                
                .. attribute:: all
                
                	Configure for all servers
                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Server.Test.All>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.Server.Test, self).__init__()

                    self.yang_name = "test"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("server", ("server", Native.Cts.Server.Test.Server_)), ("all", ("all", Native.Cts.Server.Test.All))])
                    self._leafs = OrderedDict()

                    self.all = Native.Cts.Server.Test.All()
                    self.all.parent = self
                    self._children_name_map["all"] = "all"

                    self.server = YList(self)
                    self._segment_path = lambda: "test"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:server/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.Server.Test, [], name, value)


                class Server_(Entity):
                    """
                    
                    
                    .. attribute:: ip  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: deadtime
                    
                    	Configure how long a server marked as dead should not be used
                    	**type**\: int
                    
                    	**range:** 0..864000
                    
                    .. attribute:: enable
                    
                    	Enable server liveness automated test
                    	**type**\: bool
                    
                    .. attribute:: idle_time
                    
                    	Configure how often to send an automated test message
                    	**type**\: int
                    
                    	**range:** 0..14400
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Cts.Server.Test.Server_, self).__init__()

                        self.yang_name = "server"
                        self.yang_parent_name = "test"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['ip']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                            ('deadtime', (YLeaf(YType.uint32, 'deadtime'), ['int'])),
                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                            ('idle_time', (YLeaf(YType.uint32, 'idle-time'), ['int'])),
                        ])
                        self.ip = None
                        self.deadtime = None
                        self.enable = None
                        self.idle_time = None
                        self._segment_path = lambda: "server" + "[ip='" + str(self.ip) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:server/test/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cts.Server.Test.Server_, ['ip', 'deadtime', 'enable', 'idle_time'], name, value)


                class All(Entity):
                    """
                    Configure for all servers
                    
                    .. attribute:: deadtime
                    
                    	Configure how long a server marked as dead should not be used
                    	**type**\: int
                    
                    	**range:** 0..864000
                    
                    .. attribute:: enable
                    
                    	Enable server liveness automated test
                    	**type**\: bool
                    
                    .. attribute:: idle_time
                    
                    	Configure how often to send an automated test message
                    	**type**\: int
                    
                    	**range:** 0..14400
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Cts.Server.Test.All, self).__init__()

                        self.yang_name = "all"
                        self.yang_parent_name = "test"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('deadtime', (YLeaf(YType.uint32, 'deadtime'), ['int'])),
                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                            ('idle_time', (YLeaf(YType.uint32, 'idle-time'), ['int'])),
                        ])
                        self.deadtime = None
                        self.enable = None
                        self.idle_time = None
                        self._segment_path = lambda: "all"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:server/test/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cts.Server.Test.All, ['deadtime', 'enable', 'idle_time'], name, value)


        class Sxp(Entity):
            """
            CTS sxp configuration
            
            .. attribute:: default
            
            	Enter default value
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Default>`
            
            .. attribute:: connection
            
            	CTS SXP Connection Configuration
            	**type**\:  :py:class:`Connection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection>`
            
            .. attribute:: enable
            
            	Enable CTS SXP support
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-cts'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Cts.Sxp, self).__init__()

                self.yang_name = "sxp"
                self.yang_parent_name = "cts"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("default", ("default", Native.Cts.Sxp.Default)), ("connection", ("connection", Native.Cts.Sxp.Connection))])
                self._leafs = OrderedDict([
                    ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                ])
                self.enable = None

                self.default = Native.Cts.Sxp.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.connection = Native.Cts.Sxp.Connection()
                self.connection.parent = self
                self._children_name_map["connection"] = "connection"
                self._segment_path = lambda: "Cisco-IOS-XE-cts:sxp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Cts.Sxp, ['enable'], name, value)


            class Default(Entity):
                """
                Enter default value
                
                .. attribute:: password
                
                	
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Default.Password>`
                
                .. attribute:: source_ip
                
                	Enter Source IPv4 Address
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.Sxp.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "sxp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("password", ("password", Native.Cts.Sxp.Default.Password))])
                    self._leafs = OrderedDict([
                        ('source_ip', (YLeaf(YType.str, 'source-ip'), ['str'])),
                    ])
                    self.source_ip = None

                    self.password = Native.Cts.Sxp.Default.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "password"
                    self._segment_path = lambda: "default"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:sxp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.Sxp.Default, ['source_ip'], name, value)


                class Password(Entity):
                    """
                    
                    
                    .. attribute:: type
                    
                    	
                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Default.Password.Type>`
                    
                    .. attribute:: secret
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Cts.Sxp.Default.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Cts.Sxp.Default.Password.Type')])),
                            ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                        ])
                        self.type = None
                        self.secret = None
                        self._segment_path = lambda: "password"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:sxp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cts.Sxp.Default.Password, ['type', 'secret'], name, value)

                    class Type(Enum):
                        """
                        Type (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_6 = 1

                        .. data:: Y_7 = 2

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_6 = Enum.YLeaf(1, "6")

                        Y_7 = Enum.YLeaf(2, "7")



            class Connection(Entity):
                """
                CTS SXP Connection Configuration
                
                .. attribute:: peer
                
                	SXP Peer IP address
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer>`
                
                

                """

                _prefix = 'ios-cts'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Cts.Sxp.Connection, self).__init__()

                    self.yang_name = "connection"
                    self.yang_parent_name = "sxp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("peer", ("peer", Native.Cts.Sxp.Connection.Peer))])
                    self._leafs = OrderedDict()

                    self.peer = Native.Cts.Sxp.Connection.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"
                    self._segment_path = lambda: "connection"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:sxp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cts.Sxp.Connection, [], name, value)


                class Peer(Entity):
                    """
                    SXP Peer IP address
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4>`
                    
                    

                    """

                    _prefix = 'ios-cts'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Cts.Sxp.Connection.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "connection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Cts.Sxp.Connection.Peer.Ipv4))])
                        self._leafs = OrderedDict()

                        self.ipv4 = YList(self)
                        self._segment_path = lambda: "peer"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:sxp/connection/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cts.Sxp.Connection.Peer, [], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: ipv4  (key)
                        
                        	Enter SXP Peer IP address (IPv4)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	Source IP address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source>`
                        
                        .. attribute:: password
                        
                        	password details
                        	**type**\: list of  		 :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password>`
                        
                        

                        """

                        _prefix = 'ios-cts'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Cts.Sxp.Connection.Peer.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ipv4']
                            self._child_classes = OrderedDict([("source", ("source", Native.Cts.Sxp.Connection.Peer.Ipv4.Source)), ("password", ("password", Native.Cts.Sxp.Connection.Peer.Ipv4.Password))])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                            ])
                            self.ipv4 = None

                            self.source = Native.Cts.Sxp.Connection.Peer.Ipv4.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"

                            self.password = YList(self)
                            self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/cts/Cisco-IOS-XE-cts:sxp/connection/peer/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4, ['ipv4'], name, value)


                        class Source(Entity):
                            """
                            Source IP address
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\: list of  		 :py:class:`Ipv4_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_))])
                                self._leafs = OrderedDict()

                                self.ipv4 = YList(self)
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source, [], name, value)


                            class Ipv4_(Entity):
                                """
                                
                                
                                .. attribute:: ipv4  (key)
                                
                                	Enter SXP Source IP address (IPv4)
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: password
                                
                                	password details
                                	**type**\: list of  		 :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password>`
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv4']
                                    self._child_classes = OrderedDict([("password", ("password", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password))])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ])
                                    self.ipv4 = None

                                    self.password = YList(self)
                                    self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_, ['ipv4'], name, value)


                                class Password(Entity):
                                    """
                                    password details
                                    
                                    .. attribute:: password_type  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`PasswordType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.PasswordType>`
                                    
                                    .. attribute:: mode
                                    
                                    	Specify SXP connection mode
                                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['password_type']
                                        self._child_classes = OrderedDict([("mode", ("mode", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode))])
                                        self._leafs = OrderedDict([
                                            ('password_type', (YLeaf(YType.enumeration, 'password-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.PasswordType')])),
                                        ])
                                        self.password_type = None

                                        self.mode = Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode()
                                        self.mode.parent = self
                                        self._children_name_map["mode"] = "mode"
                                        self._segment_path = lambda: "password" + "[password-type='" + str(self.password_type) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password, ['password_type'], name, value)

                                    class PasswordType(Enum):
                                        """
                                        PasswordType (Enum Class)

                                        .. data:: default = 0

                                        .. data:: none = 1

                                        """

                                        default = Enum.YLeaf(0, "default")

                                        none = Enum.YLeaf(1, "none")



                                    class Mode(Entity):
                                        """
                                        Specify SXP connection mode
                                        
                                        .. attribute:: local
                                        
                                        	Configure the mode on the local device
                                        	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: peer
                                        
                                        	Configure the mode on the peer device
                                        	**type**\:  :py:class:`Peer_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode, self).__init__()

                                            self.yang_name = "mode"
                                            self.yang_parent_name = "password"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local", ("local", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local)), ("peer", ("peer", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_))])
                                            self._leafs = OrderedDict()

                                            self.local = None
                                            self._children_name_map["local"] = "local"

                                            self.peer = None
                                            self._children_name_map["peer"] = "peer"
                                            self._segment_path = lambda: "mode"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode, [], name, value)


                                        class Local(Entity):
                                            """
                                            Configure the mode on the local device
                                            
                                            .. attribute:: both
                                            
                                            	Configure the mode as both
                                            	**type**\:  :py:class:`Both <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Both>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: listener
                                            
                                            	Receive SXP messages on the conn
                                            	**type**\:  :py:class:`Listener <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Listener>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: speaker
                                            
                                            	Send SXP messages on the conn
                                            	**type**\:  :py:class:`Speaker <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Speaker>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-cts'
                                            _revision = '2017-11-27'

                                            def __init__(self):
                                                super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local, self).__init__()

                                                self.yang_name = "local"
                                                self.yang_parent_name = "mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("both", ("both", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Both)), ("listener", ("listener", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Listener)), ("speaker", ("speaker", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Speaker))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.both = None
                                                self._children_name_map["both"] = "both"

                                                self.listener = None
                                                self._children_name_map["listener"] = "listener"

                                                self.speaker = None
                                                self._children_name_map["speaker"] = "speaker"
                                                self._segment_path = lambda: "local"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local, [], name, value)


                                            class Both(Entity):
                                                """
                                                Configure the mode as both
                                                
                                                .. attribute:: vrf
                                                
                                                	Name of the vrf this connection is in
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-cts'
                                                _revision = '2017-11-27'

                                                def __init__(self):
                                                    super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Both, self).__init__()

                                                    self.yang_name = "both"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                    ])
                                                    self.vrf = None
                                                    self._segment_path = lambda: "both"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Both, ['vrf'], name, value)


                                            class Listener(Entity):
                                                """
                                                Receive SXP messages on the conn
                                                
                                                .. attribute:: hold_time
                                                
                                                	Connection hold time period
                                                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Listener.HoldTime>`
                                                
                                                .. attribute:: vrf
                                                
                                                	Name of the vrf this connection is in
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-cts'
                                                _revision = '2017-11-27'

                                                def __init__(self):
                                                    super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Listener, self).__init__()

                                                    self.yang_name = "listener"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("hold-time", ("hold_time", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Listener.HoldTime))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                    ])
                                                    self.vrf = None

                                                    self.hold_time = Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Listener.HoldTime()
                                                    self.hold_time.parent = self
                                                    self._children_name_map["hold_time"] = "hold-time"
                                                    self._segment_path = lambda: "listener"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Listener, ['vrf'], name, value)


                                                class HoldTime(Entity):
                                                    """
                                                    Connection hold time period
                                                    
                                                    .. attribute:: min_time
                                                    
                                                    	Enter minimum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: max_time
                                                    
                                                    	Enter maximum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vrf
                                                    
                                                    	Name of the vrf this connection is in
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-cts'
                                                    _revision = '2017-11-27'

                                                    def __init__(self):
                                                        super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Listener.HoldTime, self).__init__()

                                                        self.yang_name = "hold-time"
                                                        self.yang_parent_name = "listener"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('min_time', (YLeaf(YType.uint16, 'min-time'), ['int'])),
                                                            ('max_time', (YLeaf(YType.uint16, 'max-time'), ['int'])),
                                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                        ])
                                                        self.min_time = None
                                                        self.max_time = None
                                                        self.vrf = None
                                                        self._segment_path = lambda: "hold-time"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Listener.HoldTime, ['min_time', 'max_time', 'vrf'], name, value)


                                            class Speaker(Entity):
                                                """
                                                Send SXP messages on the conn
                                                
                                                .. attribute:: hold_time
                                                
                                                	Connection hold time period
                                                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Speaker.HoldTime>`
                                                
                                                .. attribute:: vrf
                                                
                                                	Name of the vrf this connection is in
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-cts'
                                                _revision = '2017-11-27'

                                                def __init__(self):
                                                    super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Speaker, self).__init__()

                                                    self.yang_name = "speaker"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("hold-time", ("hold_time", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Speaker.HoldTime))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                    ])
                                                    self.vrf = None

                                                    self.hold_time = Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Speaker.HoldTime()
                                                    self.hold_time.parent = self
                                                    self._children_name_map["hold_time"] = "hold-time"
                                                    self._segment_path = lambda: "speaker"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Speaker, ['vrf'], name, value)


                                                class HoldTime(Entity):
                                                    """
                                                    Connection hold time period
                                                    
                                                    .. attribute:: min_time
                                                    
                                                    	Enter minimum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vrf
                                                    
                                                    	Name of the vrf this connection is in
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-cts'
                                                    _revision = '2017-11-27'

                                                    def __init__(self):
                                                        super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Speaker.HoldTime, self).__init__()

                                                        self.yang_name = "hold-time"
                                                        self.yang_parent_name = "speaker"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('min_time', (YLeaf(YType.uint16, 'min-time'), ['int'])),
                                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                        ])
                                                        self.min_time = None
                                                        self.vrf = None
                                                        self._segment_path = lambda: "hold-time"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Local.Speaker.HoldTime, ['min_time', 'vrf'], name, value)


                                        class Peer_(Entity):
                                            """
                                            Configure the mode on the peer device
                                            
                                            .. attribute:: both
                                            
                                            	Configure the mode as both
                                            	**type**\:  :py:class:`Both <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Both>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: listener
                                            
                                            	Receive SXP messages on the conn
                                            	**type**\:  :py:class:`Listener <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Listener>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: speaker
                                            
                                            	Send SXP messages on the conn
                                            	**type**\:  :py:class:`Speaker <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Speaker>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-cts'
                                            _revision = '2017-11-27'

                                            def __init__(self):
                                                super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_, self).__init__()

                                                self.yang_name = "peer"
                                                self.yang_parent_name = "mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("both", ("both", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Both)), ("listener", ("listener", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Listener)), ("speaker", ("speaker", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Speaker))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.both = None
                                                self._children_name_map["both"] = "both"

                                                self.listener = None
                                                self._children_name_map["listener"] = "listener"

                                                self.speaker = None
                                                self._children_name_map["speaker"] = "speaker"
                                                self._segment_path = lambda: "peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_, [], name, value)


                                            class Both(Entity):
                                                """
                                                Configure the mode as both
                                                
                                                .. attribute:: vrf
                                                
                                                	Name of the vrf this connection is in
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-cts'
                                                _revision = '2017-11-27'

                                                def __init__(self):
                                                    super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Both, self).__init__()

                                                    self.yang_name = "both"
                                                    self.yang_parent_name = "peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                    ])
                                                    self.vrf = None
                                                    self._segment_path = lambda: "both"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Both, ['vrf'], name, value)


                                            class Listener(Entity):
                                                """
                                                Receive SXP messages on the conn
                                                
                                                .. attribute:: hold_time
                                                
                                                	Connection hold time period
                                                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Listener.HoldTime>`
                                                
                                                .. attribute:: vrf
                                                
                                                	Name of the vrf this connection is in
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-cts'
                                                _revision = '2017-11-27'

                                                def __init__(self):
                                                    super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Listener, self).__init__()

                                                    self.yang_name = "listener"
                                                    self.yang_parent_name = "peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("hold-time", ("hold_time", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Listener.HoldTime))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                    ])
                                                    self.vrf = None

                                                    self.hold_time = Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Listener.HoldTime()
                                                    self.hold_time.parent = self
                                                    self._children_name_map["hold_time"] = "hold-time"
                                                    self._segment_path = lambda: "listener"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Listener, ['vrf'], name, value)


                                                class HoldTime(Entity):
                                                    """
                                                    Connection hold time period
                                                    
                                                    .. attribute:: min_time
                                                    
                                                    	Enter minimum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vrf
                                                    
                                                    	Name of the vrf this connection is in
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-cts'
                                                    _revision = '2017-11-27'

                                                    def __init__(self):
                                                        super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Listener.HoldTime, self).__init__()

                                                        self.yang_name = "hold-time"
                                                        self.yang_parent_name = "listener"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('min_time', (YLeaf(YType.uint16, 'min-time'), ['int'])),
                                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                        ])
                                                        self.min_time = None
                                                        self.vrf = None
                                                        self._segment_path = lambda: "hold-time"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Listener.HoldTime, ['min_time', 'vrf'], name, value)


                                            class Speaker(Entity):
                                                """
                                                Send SXP messages on the conn
                                                
                                                .. attribute:: hold_time
                                                
                                                	Connection hold time period
                                                	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Speaker.HoldTime>`
                                                
                                                .. attribute:: vrf
                                                
                                                	Name of the vrf this connection is in
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-cts'
                                                _revision = '2017-11-27'

                                                def __init__(self):
                                                    super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Speaker, self).__init__()

                                                    self.yang_name = "speaker"
                                                    self.yang_parent_name = "peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("hold-time", ("hold_time", Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Speaker.HoldTime))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                    ])
                                                    self.vrf = None

                                                    self.hold_time = Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Speaker.HoldTime()
                                                    self.hold_time.parent = self
                                                    self._children_name_map["hold_time"] = "hold-time"
                                                    self._segment_path = lambda: "speaker"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Speaker, ['vrf'], name, value)


                                                class HoldTime(Entity):
                                                    """
                                                    Connection hold time period
                                                    
                                                    .. attribute:: min_time
                                                    
                                                    	Enter minimum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: max_time
                                                    
                                                    	Enter maximum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vrf
                                                    
                                                    	Name of the vrf this connection is in
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-cts'
                                                    _revision = '2017-11-27'

                                                    def __init__(self):
                                                        super(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Speaker.HoldTime, self).__init__()

                                                        self.yang_name = "hold-time"
                                                        self.yang_parent_name = "speaker"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('min_time', (YLeaf(YType.uint16, 'min-time'), ['int'])),
                                                            ('max_time', (YLeaf(YType.uint16, 'max-time'), ['int'])),
                                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                        ])
                                                        self.min_time = None
                                                        self.max_time = None
                                                        self.vrf = None
                                                        self._segment_path = lambda: "hold-time"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Source.Ipv4_.Password.Mode.Peer_.Speaker.HoldTime, ['min_time', 'max_time', 'vrf'], name, value)


                        class Password(Entity):
                            """
                            password details
                            
                            .. attribute:: password_type  (key)
                            
                            	
                            	**type**\:  :py:class:`PasswordType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.PasswordType>`
                            
                            .. attribute:: mode
                            
                            	Specify SXP connection mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode>`
                            
                            

                            """

                            _prefix = 'ios-cts'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password, self).__init__()

                                self.yang_name = "password"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['password_type']
                                self._child_classes = OrderedDict([("mode", ("mode", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode))])
                                self._leafs = OrderedDict([
                                    ('password_type', (YLeaf(YType.enumeration, 'password-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Cts.Sxp.Connection.Peer.Ipv4.Password.PasswordType')])),
                                ])
                                self.password_type = None

                                self.mode = Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode()
                                self.mode.parent = self
                                self._children_name_map["mode"] = "mode"
                                self._segment_path = lambda: "password" + "[password-type='" + str(self.password_type) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password, ['password_type'], name, value)

                            class PasswordType(Enum):
                                """
                                PasswordType (Enum Class)

                                .. data:: default = 0

                                .. data:: none = 1

                                """

                                default = Enum.YLeaf(0, "default")

                                none = Enum.YLeaf(1, "none")



                            class Mode(Entity):
                                """
                                Specify SXP connection mode
                                
                                .. attribute:: local
                                
                                	Configure the mode on the local device
                                	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: peer
                                
                                	Configure the mode on the peer device
                                	**type**\:  :py:class:`Peer_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-cts'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode, self).__init__()

                                    self.yang_name = "mode"
                                    self.yang_parent_name = "password"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local", ("local", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local)), ("peer", ("peer", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_))])
                                    self._leafs = OrderedDict()

                                    self.local = None
                                    self._children_name_map["local"] = "local"

                                    self.peer = None
                                    self._children_name_map["peer"] = "peer"
                                    self._segment_path = lambda: "mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode, [], name, value)


                                class Local(Entity):
                                    """
                                    Configure the mode on the local device
                                    
                                    .. attribute:: both
                                    
                                    	Configure the mode as both
                                    	**type**\:  :py:class:`Both <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Both>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: listener
                                    
                                    	Receive SXP messages on the conn
                                    	**type**\:  :py:class:`Listener <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Listener>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: speaker
                                    
                                    	Send SXP messages on the conn
                                    	**type**\:  :py:class:`Speaker <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Speaker>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local, self).__init__()

                                        self.yang_name = "local"
                                        self.yang_parent_name = "mode"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("both", ("both", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Both)), ("listener", ("listener", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Listener)), ("speaker", ("speaker", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Speaker))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.both = None
                                        self._children_name_map["both"] = "both"

                                        self.listener = None
                                        self._children_name_map["listener"] = "listener"

                                        self.speaker = None
                                        self._children_name_map["speaker"] = "speaker"
                                        self._segment_path = lambda: "local"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local, [], name, value)


                                    class Both(Entity):
                                        """
                                        Configure the mode as both
                                        
                                        .. attribute:: vrf
                                        
                                        	Name of the vrf this connection is in
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Both, self).__init__()

                                            self.yang_name = "both"
                                            self.yang_parent_name = "local"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf = None
                                            self._segment_path = lambda: "both"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Both, ['vrf'], name, value)


                                    class Listener(Entity):
                                        """
                                        Receive SXP messages on the conn
                                        
                                        .. attribute:: hold_time
                                        
                                        	Connection hold time period
                                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Listener.HoldTime>`
                                        
                                        .. attribute:: vrf
                                        
                                        	Name of the vrf this connection is in
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Listener, self).__init__()

                                            self.yang_name = "listener"
                                            self.yang_parent_name = "local"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("hold-time", ("hold_time", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Listener.HoldTime))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf = None

                                            self.hold_time = Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Listener.HoldTime()
                                            self.hold_time.parent = self
                                            self._children_name_map["hold_time"] = "hold-time"
                                            self._segment_path = lambda: "listener"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Listener, ['vrf'], name, value)


                                        class HoldTime(Entity):
                                            """
                                            Connection hold time period
                                            
                                            .. attribute:: min_time
                                            
                                            	Enter minimum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: max_time
                                            
                                            	Enter maximum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vrf
                                            
                                            	Name of the vrf this connection is in
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-cts'
                                            _revision = '2017-11-27'

                                            def __init__(self):
                                                super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Listener.HoldTime, self).__init__()

                                                self.yang_name = "hold-time"
                                                self.yang_parent_name = "listener"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('min_time', (YLeaf(YType.uint16, 'min-time'), ['int'])),
                                                    ('max_time', (YLeaf(YType.uint16, 'max-time'), ['int'])),
                                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                ])
                                                self.min_time = None
                                                self.max_time = None
                                                self.vrf = None
                                                self._segment_path = lambda: "hold-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Listener.HoldTime, ['min_time', 'max_time', 'vrf'], name, value)


                                    class Speaker(Entity):
                                        """
                                        Send SXP messages on the conn
                                        
                                        .. attribute:: hold_time
                                        
                                        	Connection hold time period
                                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Speaker.HoldTime>`
                                        
                                        .. attribute:: vrf
                                        
                                        	Name of the vrf this connection is in
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Speaker, self).__init__()

                                            self.yang_name = "speaker"
                                            self.yang_parent_name = "local"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("hold-time", ("hold_time", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Speaker.HoldTime))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf = None

                                            self.hold_time = Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Speaker.HoldTime()
                                            self.hold_time.parent = self
                                            self._children_name_map["hold_time"] = "hold-time"
                                            self._segment_path = lambda: "speaker"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Speaker, ['vrf'], name, value)


                                        class HoldTime(Entity):
                                            """
                                            Connection hold time period
                                            
                                            .. attribute:: min_time
                                            
                                            	Enter minimum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vrf
                                            
                                            	Name of the vrf this connection is in
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-cts'
                                            _revision = '2017-11-27'

                                            def __init__(self):
                                                super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Speaker.HoldTime, self).__init__()

                                                self.yang_name = "hold-time"
                                                self.yang_parent_name = "speaker"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('min_time', (YLeaf(YType.uint16, 'min-time'), ['int'])),
                                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                ])
                                                self.min_time = None
                                                self.vrf = None
                                                self._segment_path = lambda: "hold-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Local.Speaker.HoldTime, ['min_time', 'vrf'], name, value)


                                class Peer_(Entity):
                                    """
                                    Configure the mode on the peer device
                                    
                                    .. attribute:: both
                                    
                                    	Configure the mode as both
                                    	**type**\:  :py:class:`Both <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Both>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: listener
                                    
                                    	Receive SXP messages on the conn
                                    	**type**\:  :py:class:`Listener <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Listener>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: speaker
                                    
                                    	Send SXP messages on the conn
                                    	**type**\:  :py:class:`Speaker <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Speaker>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-cts'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_, self).__init__()

                                        self.yang_name = "peer"
                                        self.yang_parent_name = "mode"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("both", ("both", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Both)), ("listener", ("listener", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Listener)), ("speaker", ("speaker", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Speaker))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.both = None
                                        self._children_name_map["both"] = "both"

                                        self.listener = None
                                        self._children_name_map["listener"] = "listener"

                                        self.speaker = None
                                        self._children_name_map["speaker"] = "speaker"
                                        self._segment_path = lambda: "peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_, [], name, value)


                                    class Both(Entity):
                                        """
                                        Configure the mode as both
                                        
                                        .. attribute:: vrf
                                        
                                        	Name of the vrf this connection is in
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Both, self).__init__()

                                            self.yang_name = "both"
                                            self.yang_parent_name = "peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf = None
                                            self._segment_path = lambda: "both"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Both, ['vrf'], name, value)


                                    class Listener(Entity):
                                        """
                                        Receive SXP messages on the conn
                                        
                                        .. attribute:: hold_time
                                        
                                        	Connection hold time period
                                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Listener.HoldTime>`
                                        
                                        .. attribute:: vrf
                                        
                                        	Name of the vrf this connection is in
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Listener, self).__init__()

                                            self.yang_name = "listener"
                                            self.yang_parent_name = "peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("hold-time", ("hold_time", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Listener.HoldTime))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf = None

                                            self.hold_time = Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Listener.HoldTime()
                                            self.hold_time.parent = self
                                            self._children_name_map["hold_time"] = "hold-time"
                                            self._segment_path = lambda: "listener"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Listener, ['vrf'], name, value)


                                        class HoldTime(Entity):
                                            """
                                            Connection hold time period
                                            
                                            .. attribute:: min_time
                                            
                                            	Enter minimum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vrf
                                            
                                            	Name of the vrf this connection is in
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-cts'
                                            _revision = '2017-11-27'

                                            def __init__(self):
                                                super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Listener.HoldTime, self).__init__()

                                                self.yang_name = "hold-time"
                                                self.yang_parent_name = "listener"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('min_time', (YLeaf(YType.uint16, 'min-time'), ['int'])),
                                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                ])
                                                self.min_time = None
                                                self.vrf = None
                                                self._segment_path = lambda: "hold-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Listener.HoldTime, ['min_time', 'vrf'], name, value)


                                    class Speaker(Entity):
                                        """
                                        Send SXP messages on the conn
                                        
                                        .. attribute:: hold_time
                                        
                                        	Connection hold time period
                                        	**type**\:  :py:class:`HoldTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Speaker.HoldTime>`
                                        
                                        .. attribute:: vrf
                                        
                                        	Name of the vrf this connection is in
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-cts'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Speaker, self).__init__()

                                            self.yang_name = "speaker"
                                            self.yang_parent_name = "peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("hold-time", ("hold_time", Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Speaker.HoldTime))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf = None

                                            self.hold_time = Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Speaker.HoldTime()
                                            self.hold_time.parent = self
                                            self._children_name_map["hold_time"] = "hold-time"
                                            self._segment_path = lambda: "speaker"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Speaker, ['vrf'], name, value)


                                        class HoldTime(Entity):
                                            """
                                            Connection hold time period
                                            
                                            .. attribute:: min_time
                                            
                                            	Enter minimum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: max_time
                                            
                                            	Enter maximum allowed Hold Time in seconds (0\: apply global, 65535\: no keepalive)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vrf
                                            
                                            	Name of the vrf this connection is in
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-cts'
                                            _revision = '2017-11-27'

                                            def __init__(self):
                                                super(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Speaker.HoldTime, self).__init__()

                                                self.yang_name = "hold-time"
                                                self.yang_parent_name = "speaker"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('min_time', (YLeaf(YType.uint16, 'min-time'), ['int'])),
                                                    ('max_time', (YLeaf(YType.uint16, 'max-time'), ['int'])),
                                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                ])
                                                self.min_time = None
                                                self.max_time = None
                                                self.vrf = None
                                                self._segment_path = lambda: "hold-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Cts.Sxp.Connection.Peer.Ipv4.Password.Mode.Peer_.Speaker.HoldTime, ['min_time', 'max_time', 'vrf'], name, value)


    class BfdTemplate(Entity):
        """
        BFD\-template
        
        .. attribute:: single_hop
        
        	Single\-hop template
        	**type**\: list of  		 :py:class:`SingleHop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BfdTemplate.SingleHop>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.BfdTemplate, self).__init__()

            self.yang_name = "bfd-template"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-bfd:single-hop", ("single_hop", Native.BfdTemplate.SingleHop))])
            self._leafs = OrderedDict()

            self.single_hop = YList(self)
            self._segment_path = lambda: "bfd-template"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.BfdTemplate, [], name, value)


        class SingleHop(Entity):
            """
            Single\-hop template
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: interval
            
            	Transmit interval between BFD packets
            	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BfdTemplate.SingleHop.Interval>`
            
            

            """

            _prefix = 'ios-bfd'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.BfdTemplate.SingleHop, self).__init__()

                self.yang_name = "single-hop"
                self.yang_parent_name = "bfd-template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("interval", ("interval", Native.BfdTemplate.SingleHop.Interval))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.interval = Native.BfdTemplate.SingleHop.Interval()
                self.interval.parent = self
                self._children_name_map["interval"] = "interval"
                self._segment_path = lambda: "Cisco-IOS-XE-bfd:single-hop" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/bfd-template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.BfdTemplate.SingleHop, ['name'], name, value)


            class Interval(Entity):
                """
                Transmit interval between BFD packets
                
                .. attribute:: microseconds
                
                	Specify BFD timers in microseconds
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: both
                
                	Minimum transmit and receive interval capability
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 4..9999
                
                		**type**\: int
                
                			**range:** 3300..9999000
                
                .. attribute:: min_tx
                
                	Minimum transmit interval capability
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 4..9999
                
                		**type**\: int
                
                			**range:** 3300..9999000
                
                .. attribute:: min_rx
                
                	Minimum receive interval capability
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 4..9999
                
                		**type**\: int
                
                			**range:** 3300..9999000
                
                .. attribute:: multiplier
                
                	Multiplier value used to compute holddown
                	**type**\: int
                
                	**range:** 3..50
                
                

                """

                _prefix = 'ios-bfd'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.BfdTemplate.SingleHop.Interval, self).__init__()

                    self.yang_name = "interval"
                    self.yang_parent_name = "single-hop"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('microseconds', (YLeaf(YType.empty, 'microseconds'), ['Empty'])),
                        ('both', (YLeaf(YType.str, 'both'), ['int','int'])),
                        ('min_tx', (YLeaf(YType.str, 'min-tx'), ['int','int'])),
                        ('min_rx', (YLeaf(YType.str, 'min-rx'), ['int','int'])),
                        ('multiplier', (YLeaf(YType.uint8, 'multiplier'), ['int'])),
                    ])
                    self.microseconds = None
                    self.both = None
                    self.min_tx = None
                    self.min_rx = None
                    self.multiplier = None
                    self._segment_path = lambda: "interval"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.BfdTemplate.SingleHop.Interval, ['microseconds', 'both', 'min_tx', 'min_rx', 'multiplier'], name, value)


    class Pfr(Entity):
        """
        Performance Routing configuration submodes
        
        .. attribute:: border
        
        	Enter PfR border router configuration submode
        	**type**\:  :py:class:`Border <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border>`
        
        	**presence node**\: True
        
        .. attribute:: master
        
        	Enter PfR master controller configuration submode
        	**type**\:  :py:class:`Master <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Pfr, self).__init__()

            self.yang_name = "pfr"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-pfr:border", ("border", Native.Pfr.Border)), ("Cisco-IOS-XE-pfr:master", ("master", Native.Pfr.Master))])
            self._leafs = OrderedDict()

            self.border = None
            self._children_name_map["border"] = "Cisco-IOS-XE-pfr:border"

            self.master = None
            self._children_name_map["master"] = "Cisco-IOS-XE-pfr:master"
            self._segment_path = lambda: "pfr"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Pfr, [], name, value)


        class Border(Entity):
            """
            Enter PfR border router configuration submode
            
            .. attribute:: pfr_mode__config_pfr_br
            
            	
            	**type**\:  :py:class:`PfrModeConfigPfrBr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-pfr'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Pfr.Border, self).__init__()

                self.yang_name = "border"
                self.yang_parent_name = "pfr"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("pfr-Mode__config-pfr-br", ("pfr_mode__config_pfr_br", Native.Pfr.Border.PfrModeConfigPfrBr))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.pfr_mode__config_pfr_br = Native.Pfr.Border.PfrModeConfigPfrBr()
                self.pfr_mode__config_pfr_br.parent = self
                self._children_name_map["pfr_mode__config_pfr_br"] = "pfr-Mode__config-pfr-br"
                self._segment_path = lambda: "Cisco-IOS-XE-pfr:border"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Pfr.Border, [], name, value)


            class PfrModeConfigPfrBr(Entity):
                """
                
                
                .. attribute:: active_probe
                
                	Specify active probe parameters
                	**type**\:  :py:class:`ActiveProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe>`
                
                .. attribute:: local
                
                	Specify the local interface for PfR connection
                	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.Local>`
                
                .. attribute:: logging
                
                	Event logging
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: master
                
                	Specify the PfR master controller IP address
                	**type**\:  :py:class:`Master <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.Master>`
                
                .. attribute:: port
                
                	Specify PfR port number
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: shutdown
                
                	Disable PfR border router functionality
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-pfr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Pfr.Border.PfrModeConfigPfrBr, self).__init__()

                    self.yang_name = "pfr-Mode__config-pfr-br"
                    self.yang_parent_name = "border"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("active-probe", ("active_probe", Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe)), ("local", ("local", Native.Pfr.Border.PfrModeConfigPfrBr.Local)), ("master", ("master", Native.Pfr.Border.PfrModeConfigPfrBr.Master))])
                    self._leafs = OrderedDict([
                        ('logging', (YLeaf(YType.empty, 'logging'), ['Empty'])),
                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ])
                    self.logging = None
                    self.port = None
                    self.shutdown = None

                    self.active_probe = Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe()
                    self.active_probe.parent = self
                    self._children_name_map["active_probe"] = "active-probe"

                    self.local = Native.Pfr.Border.PfrModeConfigPfrBr.Local()
                    self.local.parent = self
                    self._children_name_map["local"] = "local"

                    self.master = Native.Pfr.Border.PfrModeConfigPfrBr.Master()
                    self.master.parent = self
                    self._children_name_map["master"] = "master"
                    self._segment_path = lambda: "pfr-Mode__config-pfr-br"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr, ['logging', 'port', 'shutdown'], name, value)


                class ActiveProbe(Entity):
                    """
                    Specify active probe parameters
                    
                    .. attribute:: address
                    
                    	Identify probe address parameters
                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe, self).__init__()

                        self.yang_name = "active-probe"
                        self.yang_parent_name = "pfr-Mode__config-pfr-br"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address", ("address", Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address))])
                        self._leafs = OrderedDict()

                        self.address = Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._segment_path = lambda: "active-probe"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe, [], name, value)


                    class Address(Entity):
                        """
                        Identify probe address parameters
                        
                        .. attribute:: source
                        
                        	Identify probe source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "active-probe"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source", ("source", Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source))])
                            self._leafs = OrderedDict()

                            self.source = Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "address"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/active-probe/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address, [], name, value)


                        class Source(Entity):
                            """
                            Identify probe source address
                            
                            .. attribute:: interface
                            
                            	Identify probe source address from interface
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface))])
                                self._leafs = OrderedDict()

                                self.interface = Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._segment_path = lambda: "source"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/active-probe/address/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source, [], name, value)


                            class Interface(Entity):
                                """
                                Identify probe source address from interface
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "interface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/active-probe/address/source/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-pfr'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/active-probe/address/source/interface/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-pfr'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/active-probe/address/source/interface/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-pfr'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/active-probe/address/source/interface/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-pfr'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/active-probe/address/source/interface/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.ActiveProbe.Address.Source.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                class Local(Entity):
                    """
                    Specify the local interface for PfR connection
                    
                    .. attribute:: interface
                    
                    	
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Border.PfrModeConfigPfrBr.Local, self).__init__()

                        self.yang_name = "local"
                        self.yang_parent_name = "pfr-Mode__config-pfr-br"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface))])
                        self._leafs = OrderedDict()

                        self.interface = Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._segment_path = lambda: "local"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.Local, [], name, value)


                    class Interface(Entity):
                        """
                        
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "local"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/local/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/local/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/local/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/local/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/local/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.Local.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                class Master(Entity):
                    """
                    Specify the PfR master controller IP address
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Border.PfrModeConfigPfrBr.Master.Ipv4>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Border.PfrModeConfigPfrBr.Master, self).__init__()

                        self.yang_name = "master"
                        self.yang_parent_name = "pfr-Mode__config-pfr-br"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Pfr.Border.PfrModeConfigPfrBr.Master.Ipv4))])
                        self._leafs = OrderedDict()

                        self.ipv4 = YList(self)
                        self._segment_path = lambda: "master"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.Master, [], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: ipv4  (key)
                        
                        	IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: key_chain
                        
                        	name of key\-chain
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Border.PfrModeConfigPfrBr.Master.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "master"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ipv4']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ])
                            self.ipv4 = None
                            self.key_chain = None
                            self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:border/pfr-Mode__config-pfr-br/master/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Border.PfrModeConfigPfrBr.Master.Ipv4, ['ipv4', 'key_chain'], name, value)


        class Master(Entity):
            """
            Enter PfR master controller configuration submode
            
            .. attribute:: icmp_mode_config_pfr_mc
            
            	
            	**type**\:  :py:class:`IcmpModeConfigPfrMc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-pfr'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Pfr.Master, self).__init__()

                self.yang_name = "master"
                self.yang_parent_name = "pfr"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("icmp-Mode-config-pfr-mc", ("icmp_mode_config_pfr_mc", Native.Pfr.Master.IcmpModeConfigPfrMc))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.icmp_mode_config_pfr_mc = Native.Pfr.Master.IcmpModeConfigPfrMc()
                self.icmp_mode_config_pfr_mc.parent = self
                self._children_name_map["icmp_mode_config_pfr_mc"] = "icmp-Mode-config-pfr-mc"
                self._segment_path = lambda: "Cisco-IOS-XE-pfr:master"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Pfr.Master, [], name, value)


            class IcmpModeConfigPfrMc(Entity):
                """
                
                
                .. attribute:: active_probe
                
                	Manually create an active probe for a known target
                	**type**\:  :py:class:`ActiveProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe>`
                
                .. attribute:: application
                
                	Define application
                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Application>`
                
                .. attribute:: backoff
                
                	Specify backoff timer parameters
                	**type**\:  :py:class:`Backoff <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff>`
                
                .. attribute:: bandwidth_resolution
                
                	Enable/configure Bandwidth Resolution
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: border
                
                	Enter PfR managed border router configuration submode
                	**type**\:  :py:class:`Border <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Border>`
                
                .. attribute:: delay
                
                	Specify delay parameters
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Delay>`
                
                .. attribute:: exporter
                
                	name of flow exporter
                	**type**\: str
                
                .. attribute:: holddown
                
                	Specify hold\-down timer parameter (secs)
                	**type**\: int
                
                	**range:** 90..65535
                
                .. attribute:: jitter
                
                	Specify jitter parameters
                	**type**\:  :py:class:`Jitter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Jitter>`
                
                .. attribute:: keepalive
                
                	Specify keepalive interval in seconds
                	**type**\: int
                
                	**range:** 0..1000
                
                .. attribute:: learn
                
                	Enter prefix and traffic class learning submode
                	**type**\:  :py:class:`Learn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn>`
                
                	**presence node**\: True
                
                .. attribute:: logging
                
                	Event Logging
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: loss
                
                	Specify loss parameters
                	**type**\:  :py:class:`Loss <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Loss>`
                
                .. attribute:: max
                
                	Specify the upper limit
                	**type**\:  :py:class:`Max <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Max>`
                
                .. attribute:: max_range_utilization
                
                	Configure the maximum range for utilization of all exits
                	**type**\:  :py:class:`MaxRangeUtilization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.MaxRangeUtilization>`
                
                .. attribute:: mc_peer
                
                	Enable MC\-to\-MC peering
                	**type**\:  :py:class:`McPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer>`
                
                	**presence node**\: True
                
                .. attribute:: mode
                
                	Specify PfR operating mode settings
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mode>`
                
                .. attribute:: mos
                
                	Specify mos parameters
                	**type**\:  :py:class:`Mos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mos>`
                
                .. attribute:: periodic
                
                	Specify periodic rotation timer value (secs)
                	**type**\: int
                
                	**range:** 90..7200
                
                .. attribute:: policy_rules
                
                	pfr\-map name
                	**type**\: str
                
                .. attribute:: port
                
                	Specify tcp port number for PfR communication
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: probe
                
                	Specify number of packets for jitter probe
                	**type**\:  :py:class:`Probe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Probe>`
                
                .. attribute:: resolve
                
                	Specify PfR policy resolver settings
                	**type**\:  :py:class:`Resolve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve>`
                
                .. attribute:: rsvp
                
                	Specify rsvp parameters
                	**type**\:  :py:class:`Rsvp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Rsvp>`
                
                .. attribute:: shutdown
                
                	Disable PfR master controller functionality
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: target_discovery
                
                	Enable/configure Target Discovery
                	**type**\:  :py:class:`TargetDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery>`
                
                	**presence node**\: True
                
                .. attribute:: traceroute
                
                	Configure Traceroute global parameters
                	**type**\:  :py:class:`Traceroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Traceroute>`
                
                .. attribute:: trigger_log_percentage
                
                	Specify the percentage of out\-of\-policy TCs that will trigger a syslog
                	**type**\: int
                
                	**range:** 0..100
                
                .. attribute:: unreachable
                
                	Specify unreachable parameters
                	**type**\:  :py:class:`Unreachable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Unreachable>`
                
                

                """

                _prefix = 'ios-pfr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Pfr.Master.IcmpModeConfigPfrMc, self).__init__()

                    self.yang_name = "icmp-Mode-config-pfr-mc"
                    self.yang_parent_name = "master"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("active-probe", ("active_probe", Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe)), ("application", ("application", Native.Pfr.Master.IcmpModeConfigPfrMc.Application)), ("backoff", ("backoff", Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff)), ("border", ("border", Native.Pfr.Master.IcmpModeConfigPfrMc.Border)), ("delay", ("delay", Native.Pfr.Master.IcmpModeConfigPfrMc.Delay)), ("jitter", ("jitter", Native.Pfr.Master.IcmpModeConfigPfrMc.Jitter)), ("learn", ("learn", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn)), ("loss", ("loss", Native.Pfr.Master.IcmpModeConfigPfrMc.Loss)), ("max", ("max", Native.Pfr.Master.IcmpModeConfigPfrMc.Max)), ("max-range-utilization", ("max_range_utilization", Native.Pfr.Master.IcmpModeConfigPfrMc.MaxRangeUtilization)), ("mc-peer", ("mc_peer", Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer)), ("mode", ("mode", Native.Pfr.Master.IcmpModeConfigPfrMc.Mode)), ("mos", ("mos", Native.Pfr.Master.IcmpModeConfigPfrMc.Mos)), ("probe", ("probe", Native.Pfr.Master.IcmpModeConfigPfrMc.Probe)), ("resolve", ("resolve", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve)), ("rsvp", ("rsvp", Native.Pfr.Master.IcmpModeConfigPfrMc.Rsvp)), ("target-discovery", ("target_discovery", Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery)), ("traceroute", ("traceroute", Native.Pfr.Master.IcmpModeConfigPfrMc.Traceroute)), ("unreachable", ("unreachable", Native.Pfr.Master.IcmpModeConfigPfrMc.Unreachable))])
                    self._leafs = OrderedDict([
                        ('bandwidth_resolution', (YLeaf(YType.empty, 'bandwidth-resolution'), ['Empty'])),
                        ('exporter', (YLeaf(YType.str, 'exporter'), ['str'])),
                        ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                        ('keepalive', (YLeaf(YType.uint16, 'keepalive'), ['int'])),
                        ('logging', (YLeaf(YType.empty, 'logging'), ['Empty'])),
                        ('periodic', (YLeaf(YType.uint16, 'periodic'), ['int'])),
                        ('policy_rules', (YLeaf(YType.str, 'policy-rules'), ['str'])),
                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('trigger_log_percentage', (YLeaf(YType.uint8, 'trigger-log-percentage'), ['int'])),
                    ])
                    self.bandwidth_resolution = None
                    self.exporter = None
                    self.holddown = None
                    self.keepalive = None
                    self.logging = None
                    self.periodic = None
                    self.policy_rules = None
                    self.port = None
                    self.shutdown = None
                    self.trigger_log_percentage = None

                    self.active_probe = Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe()
                    self.active_probe.parent = self
                    self._children_name_map["active_probe"] = "active-probe"

                    self.application = Native.Pfr.Master.IcmpModeConfigPfrMc.Application()
                    self.application.parent = self
                    self._children_name_map["application"] = "application"

                    self.backoff = Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff()
                    self.backoff.parent = self
                    self._children_name_map["backoff"] = "backoff"

                    self.border = Native.Pfr.Master.IcmpModeConfigPfrMc.Border()
                    self.border.parent = self
                    self._children_name_map["border"] = "border"

                    self.delay = Native.Pfr.Master.IcmpModeConfigPfrMc.Delay()
                    self.delay.parent = self
                    self._children_name_map["delay"] = "delay"

                    self.jitter = Native.Pfr.Master.IcmpModeConfigPfrMc.Jitter()
                    self.jitter.parent = self
                    self._children_name_map["jitter"] = "jitter"

                    self.learn = None
                    self._children_name_map["learn"] = "learn"

                    self.loss = Native.Pfr.Master.IcmpModeConfigPfrMc.Loss()
                    self.loss.parent = self
                    self._children_name_map["loss"] = "loss"

                    self.max = Native.Pfr.Master.IcmpModeConfigPfrMc.Max()
                    self.max.parent = self
                    self._children_name_map["max"] = "max"

                    self.max_range_utilization = Native.Pfr.Master.IcmpModeConfigPfrMc.MaxRangeUtilization()
                    self.max_range_utilization.parent = self
                    self._children_name_map["max_range_utilization"] = "max-range-utilization"

                    self.mc_peer = None
                    self._children_name_map["mc_peer"] = "mc-peer"

                    self.mode = Native.Pfr.Master.IcmpModeConfigPfrMc.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.mos = Native.Pfr.Master.IcmpModeConfigPfrMc.Mos()
                    self.mos.parent = self
                    self._children_name_map["mos"] = "mos"

                    self.probe = Native.Pfr.Master.IcmpModeConfigPfrMc.Probe()
                    self.probe.parent = self
                    self._children_name_map["probe"] = "probe"

                    self.resolve = Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve()
                    self.resolve.parent = self
                    self._children_name_map["resolve"] = "resolve"

                    self.rsvp = Native.Pfr.Master.IcmpModeConfigPfrMc.Rsvp()
                    self.rsvp.parent = self
                    self._children_name_map["rsvp"] = "rsvp"

                    self.target_discovery = None
                    self._children_name_map["target_discovery"] = "target-discovery"

                    self.traceroute = Native.Pfr.Master.IcmpModeConfigPfrMc.Traceroute()
                    self.traceroute.parent = self
                    self._children_name_map["traceroute"] = "traceroute"

                    self.unreachable = Native.Pfr.Master.IcmpModeConfigPfrMc.Unreachable()
                    self.unreachable.parent = self
                    self._children_name_map["unreachable"] = "unreachable"
                    self._segment_path = lambda: "icmp-Mode-config-pfr-mc"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc, ['bandwidth_resolution', 'exporter', 'holddown', 'keepalive', 'logging', 'periodic', 'policy_rules', 'port', 'shutdown', 'trigger_log_percentage'], name, value)


                class ActiveProbe(Entity):
                    """
                    Manually create an active probe for a known target
                    
                    .. attribute:: echo
                    
                    	IP address of probe target
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                    
                    .. attribute:: jitter
                    
                    	Perform jitter probe operations (requires a responder)
                    	**type**\:  :py:class:`Jitter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.Jitter>`
                    
                    .. attribute:: tcp_conn
                    
                    	Perform TCP Connection / Disconnect probe operations
                    	**type**\:  :py:class:`TcpConn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.TcpConn>`
                    
                    .. attribute:: udp_echo
                    
                    	Perform UDP Echo probe operations (requires a responder)
                    	**type**\:  :py:class:`UdpEcho <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.UdpEcho>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe, self).__init__()

                        self.yang_name = "active-probe"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("jitter", ("jitter", Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.Jitter)), ("tcp-conn", ("tcp_conn", Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.TcpConn)), ("udp-echo", ("udp_echo", Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.UdpEcho))])
                        self._leafs = OrderedDict([
                            ('echo', (YLeaf(YType.str, 'echo'), ['str','str','str'])),
                        ])
                        self.echo = None

                        self.jitter = Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.Jitter()
                        self.jitter.parent = self
                        self._children_name_map["jitter"] = "jitter"

                        self.tcp_conn = Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.TcpConn()
                        self.tcp_conn.parent = self
                        self._children_name_map["tcp_conn"] = "tcp-conn"

                        self.udp_echo = Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.UdpEcho()
                        self.udp_echo.parent = self
                        self._children_name_map["udp_echo"] = "udp-echo"
                        self._segment_path = lambda: "active-probe"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe, ['echo'], name, value)


                    class Jitter(Entity):
                        """
                        Perform jitter probe operations (requires a responder)
                        
                        .. attribute:: ipv4_or_hostname
                        
                        	
                        	**type**\: list of  		 :py:class:`Ipv4OrHostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.Jitter.Ipv4OrHostname>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.Jitter, self).__init__()

                            self.yang_name = "jitter"
                            self.yang_parent_name = "active-probe"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4-or-hostname", ("ipv4_or_hostname", Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.Jitter.Ipv4OrHostname))])
                            self._leafs = OrderedDict()

                            self.ipv4_or_hostname = YList(self)
                            self._segment_path = lambda: "jitter"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/active-probe/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.Jitter, [], name, value)


                        class Ipv4OrHostname(Entity):
                            """
                            
                            
                            .. attribute:: ipv4_or_hostname  (key)
                            
                            	IP address of probe target
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: target_port
                            
                            	Target Port Number
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.Jitter.Ipv4OrHostname, self).__init__()

                                self.yang_name = "ipv4-or-hostname"
                                self.yang_parent_name = "jitter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ipv4_or_hostname']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_or_hostname', (YLeaf(YType.str, 'ipv4-or-hostname'), ['str','str','str'])),
                                    ('target_port', (YLeaf(YType.uint16, 'target-port'), ['int'])),
                                ])
                                self.ipv4_or_hostname = None
                                self.target_port = None
                                self._segment_path = lambda: "ipv4-or-hostname" + "[ipv4-or-hostname='" + str(self.ipv4_or_hostname) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/active-probe/jitter/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.Jitter.Ipv4OrHostname, ['ipv4_or_hostname', 'target_port'], name, value)


                    class TcpConn(Entity):
                        """
                        Perform TCP Connection / Disconnect probe operations
                        
                        .. attribute:: ipv4_or_hostname
                        
                        	
                        	**type**\: list of  		 :py:class:`Ipv4OrHostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.TcpConn.Ipv4OrHostname>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.TcpConn, self).__init__()

                            self.yang_name = "tcp-conn"
                            self.yang_parent_name = "active-probe"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4-or-hostname", ("ipv4_or_hostname", Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.TcpConn.Ipv4OrHostname))])
                            self._leafs = OrderedDict()

                            self.ipv4_or_hostname = YList(self)
                            self._segment_path = lambda: "tcp-conn"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/active-probe/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.TcpConn, [], name, value)


                        class Ipv4OrHostname(Entity):
                            """
                            
                            
                            .. attribute:: ipv4_or_hostname  (key)
                            
                            	IP address of probe target
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: target_port
                            
                            	Target Port Number
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.TcpConn.Ipv4OrHostname, self).__init__()

                                self.yang_name = "ipv4-or-hostname"
                                self.yang_parent_name = "tcp-conn"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ipv4_or_hostname']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_or_hostname', (YLeaf(YType.str, 'ipv4-or-hostname'), ['str','str','str'])),
                                    ('target_port', (YLeaf(YType.uint16, 'target-port'), ['int'])),
                                ])
                                self.ipv4_or_hostname = None
                                self.target_port = None
                                self._segment_path = lambda: "ipv4-or-hostname" + "[ipv4-or-hostname='" + str(self.ipv4_or_hostname) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/active-probe/tcp-conn/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.TcpConn.Ipv4OrHostname, ['ipv4_or_hostname', 'target_port'], name, value)


                    class UdpEcho(Entity):
                        """
                        Perform UDP Echo probe operations (requires a responder)
                        
                        .. attribute:: ipv4_or_hostname
                        
                        	
                        	**type**\: list of  		 :py:class:`Ipv4OrHostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.UdpEcho.Ipv4OrHostname>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.UdpEcho, self).__init__()

                            self.yang_name = "udp-echo"
                            self.yang_parent_name = "active-probe"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4-or-hostname", ("ipv4_or_hostname", Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.UdpEcho.Ipv4OrHostname))])
                            self._leafs = OrderedDict()

                            self.ipv4_or_hostname = YList(self)
                            self._segment_path = lambda: "udp-echo"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/active-probe/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.UdpEcho, [], name, value)


                        class Ipv4OrHostname(Entity):
                            """
                            
                            
                            .. attribute:: ipv4_or_hostname  (key)
                            
                            	IP address of probe target
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                            
                            .. attribute:: target_port
                            
                            	Target Port Number
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.UdpEcho.Ipv4OrHostname, self).__init__()

                                self.yang_name = "ipv4-or-hostname"
                                self.yang_parent_name = "udp-echo"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ipv4_or_hostname']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_or_hostname', (YLeaf(YType.str, 'ipv4-or-hostname'), ['str','str','str'])),
                                    ('target_port', (YLeaf(YType.uint16, 'target-port'), ['int'])),
                                ])
                                self.ipv4_or_hostname = None
                                self.target_port = None
                                self._segment_path = lambda: "ipv4-or-hostname" + "[ipv4-or-hostname='" + str(self.ipv4_or_hostname) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/active-probe/udp-echo/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.ActiveProbe.UdpEcho.Ipv4OrHostname, ['ipv4_or_hostname', 'target_port'], name, value)


                class Application(Entity):
                    """
                    Define application
                    
                    .. attribute:: define
                    
                    	Define application
                    	**type**\:  :py:class:`Define <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Application.Define>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Application, self).__init__()

                        self.yang_name = "application"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("define", ("define", Native.Pfr.Master.IcmpModeConfigPfrMc.Application.Define))])
                        self._leafs = OrderedDict()

                        self.define = Native.Pfr.Master.IcmpModeConfigPfrMc.Application.Define()
                        self.define.parent = self
                        self._children_name_map["define"] = "define"
                        self._segment_path = lambda: "application"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Application, [], name, value)


                    class Define(Entity):
                        """
                        Define application
                        
                        .. attribute:: app_def
                        
                        	
                        	**type**\: list of  		 :py:class:`AppDef <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Application.Define.AppDef>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Application.Define, self).__init__()

                            self.yang_name = "define"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("app-def", ("app_def", Native.Pfr.Master.IcmpModeConfigPfrMc.Application.Define.AppDef))])
                            self._leafs = OrderedDict()

                            self.app_def = YList(self)
                            self._segment_path = lambda: "define"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/application/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Application.Define, [], name, value)


                        class AppDef(Entity):
                            """
                            
                            
                            .. attribute:: app_def  (key)
                            
                            	Application definition name
                            	**type**\: str
                            
                            .. attribute:: access_list
                            
                            	Application definition access\-list name
                            	**type**\: str
                            
                            .. attribute:: nbar
                            
                            	Define nbar application
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Application.Define.AppDef, self).__init__()

                                self.yang_name = "app-def"
                                self.yang_parent_name = "define"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['app_def']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('app_def', (YLeaf(YType.str, 'app-def'), ['str'])),
                                    ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                    ('nbar', (YLeaf(YType.empty, 'nbar'), ['Empty'])),
                                ])
                                self.app_def = None
                                self.access_list = None
                                self.nbar = None
                                self._segment_path = lambda: "app-def" + "[app-def='" + str(self.app_def) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/application/define/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Application.Define.AppDef, ['app_def', 'access_list', 'nbar'], name, value)


                class Backoff(Entity):
                    """
                    Specify backoff timer parameters
                    
                    .. attribute:: boff
                    
                    	
                    	**type**\: list of  		 :py:class:`Boff <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff.Boff>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff, self).__init__()

                        self.yang_name = "backoff"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("boff", ("boff", Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff.Boff))])
                        self._leafs = OrderedDict()

                        self.boff = YList(self)
                        self._segment_path = lambda: "backoff"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff, [], name, value)


                    class Boff(Entity):
                        """
                        
                        
                        .. attribute:: boff  (key)
                        
                        	Specify minimum value of backoff timer (secs)
                        	**type**\: int
                        
                        	**range:** 90..7200
                        
                        .. attribute:: boff0
                        
                        	
                        	**type**\: list of  		 :py:class:`Boff0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff.Boff.Boff0>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff.Boff, self).__init__()

                            self.yang_name = "boff"
                            self.yang_parent_name = "backoff"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['boff']
                            self._child_classes = OrderedDict([("boff0", ("boff0", Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff.Boff.Boff0))])
                            self._leafs = OrderedDict([
                                ('boff', (YLeaf(YType.uint16, 'boff'), ['int'])),
                            ])
                            self.boff = None

                            self.boff0 = YList(self)
                            self._segment_path = lambda: "boff" + "[boff='" + str(self.boff) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/backoff/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff.Boff, ['boff'], name, value)


                        class Boff0(Entity):
                            """
                            
                            
                            .. attribute:: boff0  (key)
                            
                            	Specify maximum value of backoff timer (secs)
                            	**type**\: int
                            
                            	**range:** 90..7200
                            
                            .. attribute:: bstep
                            
                            	Specify optional backoff timer step (secs)
                            	**type**\: int
                            
                            	**range:** 90..7110
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff.Boff.Boff0, self).__init__()

                                self.yang_name = "boff0"
                                self.yang_parent_name = "boff"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['boff0']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('boff0', (YLeaf(YType.uint16, 'boff0'), ['int'])),
                                    ('bstep', (YLeaf(YType.uint16, 'bstep'), ['int'])),
                                ])
                                self.boff0 = None
                                self.bstep = None
                                self._segment_path = lambda: "boff0" + "[boff0='" + str(self.boff0) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Backoff.Boff.Boff0, ['boff0', 'bstep'], name, value)


                class Border(Entity):
                    """
                    Enter PfR managed border router configuration submode
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Border.Ipv4>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Border, self).__init__()

                        self.yang_name = "border"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Pfr.Master.IcmpModeConfigPfrMc.Border.Ipv4))])
                        self._leafs = OrderedDict()

                        self.ipv4 = YList(self)
                        self._segment_path = lambda: "border"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Border, [], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: ipv4  (key)
                        
                        	IP address of border router
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: key_chain
                        
                        	Specify a key\-chain
                        	**type**\: list of  		 :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Border.Ipv4.KeyChain>`
                        
                        .. attribute:: interface
                        
                        	Specify an PfR managed border router interface
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Border.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "border"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ipv4']
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Pfr.Master.IcmpModeConfigPfrMc.Border.Ipv4.KeyChain))])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                            ])
                            self.ipv4 = None
                            self.interface = None

                            self.key_chain = YList(self)
                            self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/border/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Border.Ipv4, ['ipv4', 'interface'], name, value)


                        class KeyChain(Entity):
                            """
                            Specify a key\-chain
                            
                            .. attribute:: kc_name  (key)
                            
                            	name of key\-chain
                            	**type**\: str
                            
                            .. attribute:: interface
                            
                            	Specify an PfR managed border router interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Border.Ipv4.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['kc_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('kc_name', (YLeaf(YType.str, 'kc-name'), ['str'])),
                                    ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                                ])
                                self.kc_name = None
                                self.interface = None
                                self._segment_path = lambda: "key-chain" + "[kc-name='" + str(self.kc_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Border.Ipv4.KeyChain, ['kc_name', 'interface'], name, value)


                class Delay(Entity):
                    """
                    Specify delay parameters
                    
                    .. attribute:: relative
                    
                    	short/long term in percentage. e.g. 125 is short/long = 1.25
                    	**type**\: int
                    
                    	**range:** 1..1000
                    
                    .. attribute:: threshold
                    
                    	Maximum absolute delay threshold (msecs)
                    	**type**\: int
                    
                    	**range:** 1..10000
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('relative', (YLeaf(YType.uint16, 'relative'), ['int'])),
                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                        ])
                        self.relative = None
                        self.threshold = None
                        self._segment_path = lambda: "delay"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Delay, ['relative', 'threshold'], name, value)


                class Jitter(Entity):
                    """
                    Specify jitter parameters
                    
                    .. attribute:: threshold
                    
                    	Maximum absolute jitter threshold (ms)
                    	**type**\: int
                    
                    	**range:** 1..1000
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Jitter, self).__init__()

                        self.yang_name = "jitter"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                        ])
                        self.threshold = None
                        self._segment_path = lambda: "jitter"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Jitter, ['threshold'], name, value)


                class Learn(Entity):
                    """
                    Enter prefix and traffic class learning submode
                    
                    .. attribute:: lrn_mode__config_pfr_mc_learn
                    
                    	
                    	**type**\:  :py:class:`LrnModeConfigPfrMcLearn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn, self).__init__()

                        self.yang_name = "learn"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("lrn-Mode__config-pfr-mc-learn", ("lrn_mode__config_pfr_mc_learn", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.lrn_mode__config_pfr_mc_learn = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn()
                        self.lrn_mode__config_pfr_mc_learn.parent = self
                        self._children_name_map["lrn_mode__config_pfr_mc_learn"] = "lrn-Mode__config-pfr-mc-learn"
                        self._segment_path = lambda: "learn"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn, [], name, value)


                    class LrnModeConfigPfrMcLearn(Entity):
                        """
                        
                        
                        .. attribute:: aggregation_type
                        
                        	Type of prefix to aggregate
                        	**type**\:  :py:class:`AggregationType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.AggregationType>`
                        
                        .. attribute:: delay
                        
                        	Learn top prefixes based on delay
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: expire
                        
                        	Set expiry criteria for learn prefixes
                        	**type**\:  :py:class:`Expire <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Expire>`
                        
                        .. attribute:: inside
                        
                        	Learn prefixes inside the network
                        	**type**\:  :py:class:`Inside <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Inside>`
                        
                        .. attribute:: list
                        
                        	Create PfR Learn Traffic Class List and enter the sub\-mode
                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List>`
                        
                        .. attribute:: monitor_period
                        
                        	Specify the period in minutes
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: periodic_interval
                        
                        	Specify the interval in minutes
                        	**type**\: int
                        
                        	**range:** 0..10080
                        
                        .. attribute:: prefixes
                        
                        	Number of prefixes to learn
                        	**type**\:  :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Prefixes>`
                        
                        .. attribute:: throughput
                        
                        	Learn top prefixes based on throughput
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: traffic_class
                        
                        	Set traffic class filters
                        	**type**\:  :py:class:`TrafficClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn, self).__init__()

                            self.yang_name = "lrn-Mode__config-pfr-mc-learn"
                            self.yang_parent_name = "learn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("aggregation-type", ("aggregation_type", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.AggregationType)), ("expire", ("expire", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Expire)), ("inside", ("inside", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Inside)), ("list", ("list", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List)), ("prefixes", ("prefixes", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Prefixes)), ("traffic-class", ("traffic_class", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass))])
                            self._leafs = OrderedDict([
                                ('delay', (YLeaf(YType.empty, 'delay'), ['Empty'])),
                                ('monitor_period', (YLeaf(YType.uint16, 'monitor-period'), ['int'])),
                                ('periodic_interval', (YLeaf(YType.uint16, 'periodic-interval'), ['int'])),
                                ('throughput', (YLeaf(YType.empty, 'throughput'), ['Empty'])),
                            ])
                            self.delay = None
                            self.monitor_period = None
                            self.periodic_interval = None
                            self.throughput = None

                            self.aggregation_type = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.AggregationType()
                            self.aggregation_type.parent = self
                            self._children_name_map["aggregation_type"] = "aggregation-type"

                            self.expire = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Expire()
                            self.expire.parent = self
                            self._children_name_map["expire"] = "expire"

                            self.inside = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Inside()
                            self.inside.parent = self
                            self._children_name_map["inside"] = "inside"

                            self.list = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List()
                            self.list.parent = self
                            self._children_name_map["list"] = "list"

                            self.prefixes = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Prefixes()
                            self.prefixes.parent = self
                            self._children_name_map["prefixes"] = "prefixes"

                            self.traffic_class = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass()
                            self.traffic_class.parent = self
                            self._children_name_map["traffic_class"] = "traffic-class"
                            self._segment_path = lambda: "lrn-Mode__config-pfr-mc-learn"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn, ['delay', 'monitor_period', 'periodic_interval', 'throughput'], name, value)


                        class AggregationType(Entity):
                            """
                            Type of prefix to aggregate
                            
                            .. attribute:: bgp
                            
                            	Aggregate prefixes learned via BGP
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: non_bgp
                            
                            	Aggregate prefixes not learned via BGP
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: prefix_length
                            
                            	Specify the prefix mask
                            	**type**\: int
                            
                            	**range:** 1..32
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.AggregationType, self).__init__()

                                self.yang_name = "aggregation-type"
                                self.yang_parent_name = "lrn-Mode__config-pfr-mc-learn"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                                    ('non_bgp', (YLeaf(YType.empty, 'non-bgp'), ['Empty'])),
                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                ])
                                self.bgp = None
                                self.non_bgp = None
                                self.prefix_length = None
                                self._segment_path = lambda: "aggregation-type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.AggregationType, ['bgp', 'non_bgp', 'prefix_length'], name, value)


                        class Expire(Entity):
                            """
                            Set expiry criteria for learn prefixes
                            
                            .. attribute:: after
                            
                            	Specify expiry criteria for learn prefixes
                            	**type**\:  :py:class:`After <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Expire.After>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Expire, self).__init__()

                                self.yang_name = "expire"
                                self.yang_parent_name = "lrn-Mode__config-pfr-mc-learn"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("after", ("after", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Expire.After))])
                                self._leafs = OrderedDict()

                                self.after = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Expire.After()
                                self.after.parent = self
                                self._children_name_map["after"] = "after"
                                self._segment_path = lambda: "expire"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Expire, [], name, value)


                            class After(Entity):
                                """
                                Specify expiry criteria for learn prefixes
                                
                                .. attribute:: session
                                
                                	Specify the value
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: time
                                
                                	Specify the value
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Expire.After, self).__init__()

                                    self.yang_name = "after"
                                    self.yang_parent_name = "expire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('session', (YLeaf(YType.uint16, 'session'), ['int'])),
                                        ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                                    ])
                                    self.session = None
                                    self.time = None
                                    self._segment_path = lambda: "after"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/expire/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Expire.After, ['session', 'time'], name, value)


                        class Inside(Entity):
                            """
                            Learn prefixes inside the network
                            
                            .. attribute:: bgp
                            
                            	Learn inside prefixes advertised by BGP out PfR External Interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Inside, self).__init__()

                                self.yang_name = "inside"
                                self.yang_parent_name = "lrn-Mode__config-pfr-mc-learn"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                                ])
                                self.bgp = None
                                self._segment_path = lambda: "inside"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Inside, ['bgp'], name, value)


                        class List(Entity):
                            """
                            Create PfR Learn Traffic Class List and enter the sub\-mode
                            
                            .. attribute:: seq
                            
                            	PfR Learn Traffic Class List sequence number
                            	**type**\:  :py:class:`Seq <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List.Seq>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List, self).__init__()

                                self.yang_name = "list"
                                self.yang_parent_name = "lrn-Mode__config-pfr-mc-learn"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("seq", ("seq", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List.Seq))])
                                self._leafs = OrderedDict()

                                self.seq = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List.Seq()
                                self.seq.parent = self
                                self._children_name_map["seq"] = "seq"
                                self._segment_path = lambda: "list"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List, [], name, value)


                            class Seq(Entity):
                                """
                                PfR Learn Traffic Class List sequence number
                                
                                .. attribute:: pfr_tc
                                
                                	
                                	**type**\: list of  		 :py:class:`PfrTc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List.Seq.PfrTc>`
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List.Seq, self).__init__()

                                    self.yang_name = "seq"
                                    self.yang_parent_name = "list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pfr-tc", ("pfr_tc", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List.Seq.PfrTc))])
                                    self._leafs = OrderedDict()

                                    self.pfr_tc = YList(self)
                                    self._segment_path = lambda: "seq"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/list/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List.Seq, [], name, value)


                                class PfrTc(Entity):
                                    """
                                    
                                    
                                    .. attribute:: pfr_tc  (key)
                                    
                                    	PfR Learn Traffic Class List sequence number
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: refname
                                    
                                    	PfR Learn Traffic Class List reference name
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-pfr'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List.Seq.PfrTc, self).__init__()

                                        self.yang_name = "pfr-tc"
                                        self.yang_parent_name = "seq"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['pfr_tc']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pfr_tc', (YLeaf(YType.uint16, 'pfr-tc'), ['int'])),
                                            ('refname', (YLeaf(YType.empty, 'refname'), ['Empty'])),
                                        ])
                                        self.pfr_tc = None
                                        self.refname = None
                                        self._segment_path = lambda: "pfr-tc" + "[pfr-tc='" + str(self.pfr_tc) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/list/seq/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.List.Seq.PfrTc, ['pfr_tc', 'refname'], name, value)


                        class Prefixes(Entity):
                            """
                            Number of prefixes to learn
                            
                            .. attribute:: prnum
                            
                            	
                            	**type**\: list of  		 :py:class:`Prnum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Prefixes.Prnum>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "lrn-Mode__config-pfr-mc-learn"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prnum", ("prnum", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Prefixes.Prnum))])
                                self._leafs = OrderedDict()

                                self.prnum = YList(self)
                                self._segment_path = lambda: "prefixes"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Prefixes, [], name, value)


                            class Prnum(Entity):
                                """
                                
                                
                                .. attribute:: prnum  (key)
                                
                                	Specify the number of prefixes
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: applications
                                
                                	Specify the number of appl
                                	**type**\: int
                                
                                	**range:** 0..50000
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Prefixes.Prnum, self).__init__()

                                    self.yang_name = "prnum"
                                    self.yang_parent_name = "prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['prnum']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prnum', (YLeaf(YType.uint32, 'prnum'), ['int'])),
                                        ('applications', (YLeaf(YType.uint16, 'applications'), ['int'])),
                                    ])
                                    self.prnum = None
                                    self.applications = None
                                    self._segment_path = lambda: "prnum" + "[prnum='" + str(self.prnum) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/prefixes/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.Prefixes.Prnum, ['prnum', 'applications'], name, value)


                        class TrafficClass(Entity):
                            """
                            Set traffic class filters
                            
                            .. attribute:: aggregate
                            
                            	Traffic class aggregation specification
                            	**type**\:  :py:class:`Aggregate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Aggregate>`
                            
                            .. attribute:: filter
                            
                            	Traffic class filter specification
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Filter>`
                            
                            .. attribute:: keys
                            
                            	Specify Learn keys for applications
                            	**type**\:  :py:class:`Keys <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass, self).__init__()

                                self.yang_name = "traffic-class"
                                self.yang_parent_name = "lrn-Mode__config-pfr-mc-learn"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aggregate", ("aggregate", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Aggregate)), ("filter", ("filter", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Filter)), ("keys", ("keys", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys))])
                                self._leafs = OrderedDict()

                                self.aggregate = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Aggregate()
                                self.aggregate.parent = self
                                self._children_name_map["aggregate"] = "aggregate"

                                self.filter = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"

                                self.keys = Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys()
                                self.keys.parent = self
                                self._children_name_map["keys"] = "keys"
                                self._segment_path = lambda: "traffic-class"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass, [], name, value)


                            class Aggregate(Entity):
                                """
                                Traffic class aggregation specification
                                
                                .. attribute:: access_list
                                
                                	IP access\-list name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Aggregate, self).__init__()

                                    self.yang_name = "aggregate"
                                    self.yang_parent_name = "traffic-class"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                    ])
                                    self.access_list = None
                                    self._segment_path = lambda: "aggregate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/traffic-class/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Aggregate, ['access_list'], name, value)


                            class Filter(Entity):
                                """
                                Traffic class filter specification
                                
                                .. attribute:: access_list
                                
                                	IP access\-list name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "traffic-class"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('access_list', (YLeaf(YType.str, 'access-list'), ['str'])),
                                    ])
                                    self.access_list = None
                                    self._segment_path = lambda: "filter"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/traffic-class/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Filter, ['access_list'], name, value)


                            class Keys(Entity):
                                """
                                Specify Learn keys for applications
                                
                                .. attribute:: dport
                                
                                	Learn top appls based on destination port
                                	**type**\:  :py:class:`Dport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Dport>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dscp
                                
                                	Learn top appls based on DSCP
                                	**type**\:  :py:class:`Dscp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Dscp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: protocol
                                
                                	Learn top appls based on protocol
                                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Protocol>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: sport
                                
                                	Learn top appls based on source port
                                	**type**\:  :py:class:`Sport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Sport>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys, self).__init__()

                                    self.yang_name = "keys"
                                    self.yang_parent_name = "traffic-class"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dport", ("dport", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Dport)), ("dscp", ("dscp", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Dscp)), ("protocol", ("protocol", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Protocol)), ("sport", ("sport", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Sport))])
                                    self._leafs = OrderedDict()

                                    self.dport = None
                                    self._children_name_map["dport"] = "dport"

                                    self.dscp = None
                                    self._children_name_map["dscp"] = "dscp"

                                    self.protocol = None
                                    self._children_name_map["protocol"] = "protocol"

                                    self.sport = None
                                    self._children_name_map["sport"] = "sport"
                                    self._segment_path = lambda: "keys"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/traffic-class/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys, [], name, value)


                                class Dport(Entity):
                                    """
                                    Learn top appls based on destination port
                                    
                                    .. attribute:: dscp
                                    
                                    	Learn top appls based on DSCP
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Learn top appls based on protocol
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sport
                                    
                                    	Learn top appls based on source port
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-pfr'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Dport, self).__init__()

                                        self.yang_name = "dport"
                                        self.yang_parent_name = "keys"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                                            ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                                            ('sport', (YLeaf(YType.empty, 'sport'), ['Empty'])),
                                        ])
                                        self.dscp = None
                                        self.protocol = None
                                        self.sport = None
                                        self._segment_path = lambda: "dport"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/traffic-class/keys/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Dport, ['dscp', 'protocol', 'sport'], name, value)


                                class Dscp(Entity):
                                    """
                                    Learn top appls based on DSCP
                                    
                                    .. attribute:: dport
                                    
                                    	Learn top appls based on destination port
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Learn top appls based on protocol
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sport
                                    
                                    	Learn top appls based on source port
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-pfr'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Dscp, self).__init__()

                                        self.yang_name = "dscp"
                                        self.yang_parent_name = "keys"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('dport', (YLeaf(YType.empty, 'dport'), ['Empty'])),
                                            ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                                            ('sport', (YLeaf(YType.empty, 'sport'), ['Empty'])),
                                        ])
                                        self.dport = None
                                        self.protocol = None
                                        self.sport = None
                                        self._segment_path = lambda: "dscp"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/traffic-class/keys/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Dscp, ['dport', 'protocol', 'sport'], name, value)


                                class Protocol(Entity):
                                    """
                                    Learn top appls based on protocol
                                    
                                    .. attribute:: dport
                                    
                                    	Learn top appls based on destination port
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dscp
                                    
                                    	Learn top appls based on DSCP
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sport
                                    
                                    	Learn top appls based on source port
                                    	**type**\:  :py:class:`Sport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Protocol.Sport>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-pfr'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Protocol, self).__init__()

                                        self.yang_name = "protocol"
                                        self.yang_parent_name = "keys"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sport", ("sport", Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Protocol.Sport))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('dport', (YLeaf(YType.empty, 'dport'), ['Empty'])),
                                            ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                                        ])
                                        self.dport = None
                                        self.dscp = None

                                        self.sport = None
                                        self._children_name_map["sport"] = "sport"
                                        self._segment_path = lambda: "protocol"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/traffic-class/keys/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Protocol, ['dport', 'dscp'], name, value)


                                    class Sport(Entity):
                                        """
                                        Learn top appls based on source port
                                        
                                        .. attribute:: dport
                                        
                                        	Learn top appls based on destination port
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: dscp
                                        
                                        	Learn top appls based on DSCP
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-pfr'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Protocol.Sport, self).__init__()

                                            self.yang_name = "sport"
                                            self.yang_parent_name = "protocol"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('dport', (YLeaf(YType.empty, 'dport'), ['Empty'])),
                                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                                            ])
                                            self.dport = None
                                            self.dscp = None
                                            self._segment_path = lambda: "sport"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/traffic-class/keys/protocol/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Protocol.Sport, ['dport', 'dscp'], name, value)


                                class Sport(Entity):
                                    """
                                    Learn top appls based on source port
                                    
                                    .. attribute:: dport
                                    
                                    	Learn top appls based on destination port
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dscp
                                    
                                    	Learn top appls based on DSCP
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Learn top appls based on protocol
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-pfr'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Sport, self).__init__()

                                        self.yang_name = "sport"
                                        self.yang_parent_name = "keys"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('dport', (YLeaf(YType.empty, 'dport'), ['Empty'])),
                                            ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                                            ('protocol', (YLeaf(YType.empty, 'protocol'), ['Empty'])),
                                        ])
                                        self.dport = None
                                        self.dscp = None
                                        self.protocol = None
                                        self._segment_path = lambda: "sport"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/learn/lrn-Mode__config-pfr-mc-learn/traffic-class/keys/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Learn.LrnModeConfigPfrMcLearn.TrafficClass.Keys.Sport, ['dport', 'dscp', 'protocol'], name, value)


                class Loss(Entity):
                    """
                    Specify loss parameters
                    
                    .. attribute:: relative
                    
                    	short/long term in percentage. e.g. 125 is short/long = 1.25
                    	**type**\: int
                    
                    	**range:** 1..1000
                    
                    .. attribute:: threshold
                    
                    	Maximum absolute lost packet threshold in percentage e.g., 1 is 0.0001 percent
                    	**type**\: int
                    
                    	**range:** 1..1000000
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Loss, self).__init__()

                        self.yang_name = "loss"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('relative', (YLeaf(YType.uint16, 'relative'), ['int'])),
                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                        ])
                        self.relative = None
                        self.threshold = None
                        self._segment_path = lambda: "loss"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Loss, ['relative', 'threshold'], name, value)


                class Max(Entity):
                    """
                    Specify the upper limit
                    
                    .. attribute:: prefix
                    
                    	Specify prefix upper limit
                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix>`
                    
                    .. attribute:: range
                    
                    	Specify range value
                    	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Range>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Max, self).__init__()

                        self.yang_name = "max"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix", ("prefix", Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix)), ("range", ("range", Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Range))])
                        self._leafs = OrderedDict()

                        self.prefix = Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"

                        self.range = Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Range()
                        self.range.parent = self
                        self._children_name_map["range"] = "range"
                        self._segment_path = lambda: "max"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Max, [], name, value)


                    class Prefix(Entity):
                        """
                        Specify prefix upper limit
                        
                        .. attribute:: total
                        
                        	Specify max total prefix limit
                        	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix.Total>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "max"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("total", ("total", Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix.Total))])
                            self._leafs = OrderedDict()

                            self.total = Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix.Total()
                            self.total.parent = self
                            self._children_name_map["total"] = "total"
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/max/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix, [], name, value)


                        class Total(Entity):
                            """
                            Specify max total prefix limit
                            
                            .. attribute:: maxpr
                            
                            	
                            	**type**\: list of  		 :py:class:`Maxpr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix.Total.Maxpr>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix.Total, self).__init__()

                                self.yang_name = "total"
                                self.yang_parent_name = "prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maxpr", ("maxpr", Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix.Total.Maxpr))])
                                self._leafs = OrderedDict()

                                self.maxpr = YList(self)
                                self._segment_path = lambda: "total"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/max/prefix/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix.Total, [], name, value)


                            class Maxpr(Entity):
                                """
                                
                                
                                .. attribute:: maxpr  (key)
                                
                                	Specify the max total prefix limit value
                                	**type**\: int
                                
                                	**range:** 1..100000
                                
                                .. attribute:: learn
                                
                                	Specify max learn prefix limit value
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix.Total.Maxpr, self).__init__()

                                    self.yang_name = "maxpr"
                                    self.yang_parent_name = "total"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['maxpr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('maxpr', (YLeaf(YType.uint32, 'maxpr'), ['int'])),
                                        ('learn', (YLeaf(YType.uint32, 'learn'), ['int'])),
                                    ])
                                    self.maxpr = None
                                    self.learn = None
                                    self._segment_path = lambda: "maxpr" + "[maxpr='" + str(self.maxpr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/max/prefix/total/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Prefix.Total.Maxpr, ['maxpr', 'learn'], name, value)


                    class Range(Entity):
                        """
                        Specify range value
                        
                        .. attribute:: receive
                        
                        	Specify receive range
                        	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Range.Receive>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "max"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("receive", ("receive", Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Range.Receive))])
                            self._leafs = OrderedDict()

                            self.receive = Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Range.Receive()
                            self.receive.parent = self
                            self._children_name_map["receive"] = "receive"
                            self._segment_path = lambda: "range"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/max/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Range, [], name, value)


                        class Receive(Entity):
                            """
                            Specify receive range
                            
                            .. attribute:: percent
                            
                            	Specify the percentage range
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Range.Receive, self).__init__()

                                self.yang_name = "receive"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                ])
                                self.percent = None
                                self._segment_path = lambda: "receive"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/max/range/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Max.Range.Receive, ['percent'], name, value)


                class MaxRangeUtilization(Entity):
                    """
                    Configure the maximum range for utilization of all exits
                    
                    .. attribute:: percent
                    
                    	Specify the percentage range
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.MaxRangeUtilization, self).__init__()

                        self.yang_name = "max-range-utilization"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                        ])
                        self.percent = None
                        self._segment_path = lambda: "max-range-utilization"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.MaxRangeUtilization, ['percent'], name, value)


                class McPeer(Entity):
                    """
                    Enable MC\-to\-MC peering
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Ipv4>`
                    
                    .. attribute:: description
                    
                    	MC site description (max 40 char)
                    	**type**\: str
                    
                    .. attribute:: domain
                    
                    	SAF domain ID to be used for MC\-to\-MC peering
                    	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain>`
                    
                    .. attribute:: eigrp
                    
                    	Use explicit EIGRP configuration instead of auto\-config
                    	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Eigrp>`
                    
                    .. attribute:: head_end
                    
                    	Specify this router as head\-end MC\-peer
                    	**type**\:  :py:class:`HeadEnd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.HeadEnd>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer, self).__init__()

                        self.yang_name = "mc-peer"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Ipv4)), ("domain", ("domain", Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain)), ("eigrp", ("eigrp", Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Eigrp)), ("head-end", ("head_end", Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.HeadEnd))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ])
                        self.description = None

                        self.domain = Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain()
                        self.domain.parent = self
                        self._children_name_map["domain"] = "domain"

                        self.eigrp = Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Eigrp()
                        self.eigrp.parent = self
                        self._children_name_map["eigrp"] = "eigrp"

                        self.head_end = Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.HeadEnd()
                        self.head_end.parent = self
                        self._children_name_map["head_end"] = "head-end"

                        self.ipv4 = YList(self)
                        self._segment_path = lambda: "mc-peer"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer, ['description'], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: ipv4  (key)
                        
                        	IP address of head\-end MC peer
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface
                        
                        	
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Ipv4.Interface>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "mc-peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ipv4']
                            self._child_classes = OrderedDict([("interface", ("interface", Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Ipv4.Interface))])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                            ])
                            self.ipv4 = None

                            self.interface = YList(self)
                            self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mc-peer/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Ipv4, ['ipv4'], name, value)


                        class Interface(Entity):
                            """
                            
                            
                            .. attribute:: interface  (key)
                            
                            	Loopback interface
                            	**type**\: str
                            
                            .. attribute:: description
                            
                            	MC site description (max 40 char)
                            	**type**\: str
                            
                            .. attribute:: domain
                            
                            	Domain value
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Ipv4.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('domain', (YLeaf(YType.uint16, 'domain'), ['int'])),
                                ])
                                self.interface = None
                                self.description = None
                                self.domain = None
                                self._segment_path = lambda: "interface" + "[interface='" + str(self.interface) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Ipv4.Interface, ['interface', 'description', 'domain'], name, value)


                    class Domain(Entity):
                        """
                        SAF domain ID to be used for MC\-to\-MC peering
                        
                        .. attribute:: dmval
                        
                        	
                        	**type**\: list of  		 :py:class:`Dmval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain.Dmval>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain, self).__init__()

                            self.yang_name = "domain"
                            self.yang_parent_name = "mc-peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dmval", ("dmval", Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain.Dmval))])
                            self._leafs = OrderedDict()

                            self.dmval = YList(self)
                            self._segment_path = lambda: "domain"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mc-peer/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain, [], name, value)


                        class Dmval(Entity):
                            """
                            
                            
                            .. attribute:: dmval  (key)
                            
                            	Domain value
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain.Dmval.Ipv4>`
                            
                            .. attribute:: description
                            
                            	MC site description (max 40 char)
                            	**type**\: str
                            
                            .. attribute:: eigrp
                            
                            	Loopback interface
                            	**type**\: str
                            
                            .. attribute:: head_end
                            
                            	Loopback interface
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain.Dmval, self).__init__()

                                self.yang_name = "dmval"
                                self.yang_parent_name = "domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['dmval']
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain.Dmval.Ipv4))])
                                self._leafs = OrderedDict([
                                    ('dmval', (YLeaf(YType.uint16, 'dmval'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('eigrp', (YLeaf(YType.str, 'eigrp'), ['str'])),
                                    ('head_end', (YLeaf(YType.str, 'head-end'), ['str'])),
                                ])
                                self.dmval = None
                                self.description = None
                                self.eigrp = None
                                self.head_end = None

                                self.ipv4 = YList(self)
                                self._segment_path = lambda: "dmval" + "[dmval='" + str(self.dmval) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mc-peer/domain/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain.Dmval, ['dmval', 'description', 'eigrp', 'head_end'], name, value)


                            class Ipv4(Entity):
                                """
                                
                                
                                .. attribute:: ipv4  (key)
                                
                                	IP address of head\-end MC peer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface
                                
                                	Loopback interface
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain.Dmval.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "dmval"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv4']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ])
                                    self.ipv4 = None
                                    self.interface = None
                                    self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Domain.Dmval.Ipv4, ['ipv4', 'interface'], name, value)


                    class Eigrp(Entity):
                        """
                        Use explicit EIGRP configuration instead of auto\-config
                        
                        .. attribute:: interface
                        
                        	
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Eigrp.Interface>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "mc-peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Eigrp.Interface))])
                            self._leafs = OrderedDict()

                            self.interface = YList(self)
                            self._segment_path = lambda: "eigrp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mc-peer/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Eigrp, [], name, value)


                        class Interface(Entity):
                            """
                            
                            
                            .. attribute:: interface  (key)
                            
                            	Loopback interface
                            	**type**\: str
                            
                            .. attribute:: description
                            
                            	MC site description (max 40 char)
                            	**type**\: str
                            
                            .. attribute:: domain
                            
                            	Domain value
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Eigrp.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "eigrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['interface']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('domain', (YLeaf(YType.uint16, 'domain'), ['int'])),
                                ])
                                self.interface = None
                                self.description = None
                                self.domain = None
                                self._segment_path = lambda: "interface" + "[interface='" + str(self.interface) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mc-peer/eigrp/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.Eigrp.Interface, ['interface', 'description', 'domain'], name, value)


                    class HeadEnd(Entity):
                        """
                        Specify this router as head\-end MC\-peer
                        
                        .. attribute:: interface
                        
                        	
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.HeadEnd.Interface>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.HeadEnd, self).__init__()

                            self.yang_name = "head-end"
                            self.yang_parent_name = "mc-peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.HeadEnd.Interface))])
                            self._leafs = OrderedDict()

                            self.interface = YList(self)
                            self._segment_path = lambda: "head-end"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mc-peer/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.HeadEnd, [], name, value)


                        class Interface(Entity):
                            """
                            
                            
                            .. attribute:: interface  (key)
                            
                            	Loopback interface
                            	**type**\: str
                            
                            .. attribute:: description
                            
                            	MC site description (max 40 char)
                            	**type**\: str
                            
                            .. attribute:: domain
                            
                            	Domain value
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.HeadEnd.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "head-end"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['interface']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('domain', (YLeaf(YType.uint16, 'domain'), ['int'])),
                                ])
                                self.interface = None
                                self.description = None
                                self.domain = None
                                self._segment_path = lambda: "interface" + "[interface='" + str(self.interface) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mc-peer/head-end/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.McPeer.HeadEnd.Interface, ['interface', 'description', 'domain'], name, value)


                class Mode(Entity):
                    """
                    Specify PfR operating mode settings
                    
                    .. attribute:: monitor
                    
                    	Specify PfR prefix monitoring policy settings
                    	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Monitor>`
                    
                    .. attribute:: route
                    
                    	Specify PfR route control policy settings
                    	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route>`
                    
                    .. attribute:: verify
                    
                    	Specify verification behavior
                    	**type**\:  :py:class:`Verify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Verify>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("monitor", ("monitor", Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Monitor)), ("route", ("route", Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route)), ("verify", ("verify", Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Verify))])
                        self._leafs = OrderedDict()

                        self.monitor = Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Monitor()
                        self.monitor.parent = self
                        self._children_name_map["monitor"] = "monitor"

                        self.route = Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route()
                        self.route.parent = self
                        self._children_name_map["route"] = "route"

                        self.verify = Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Verify()
                        self.verify.parent = self
                        self._children_name_map["verify"] = "verify"
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode, [], name, value)


                    class Monitor(Entity):
                        """
                        Specify PfR prefix monitoring policy settings
                        
                        .. attribute:: active
                        
                        	Enable active monitoring mode
                        	**type**\:  :py:class:`Active <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Monitor.Active>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: both
                        
                        	Enable active and passive monitoring modes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: fast
                        
                        	Enable fast monitoring mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: passive
                        
                        	Enable passive monitoring mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Monitor, self).__init__()

                            self.yang_name = "monitor"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("active", ("active", Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Monitor.Active))])
                            self._leafs = OrderedDict([
                                ('both', (YLeaf(YType.empty, 'both'), ['Empty'])),
                                ('fast', (YLeaf(YType.empty, 'fast'), ['Empty'])),
                                ('passive', (YLeaf(YType.empty, 'passive'), ['Empty'])),
                            ])
                            self.both = None
                            self.fast = None
                            self.passive = None

                            self.active = None
                            self._children_name_map["active"] = "active"
                            self._segment_path = lambda: "monitor"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mode/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Monitor, ['both', 'fast', 'passive'], name, value)


                        class Active(Entity):
                            """
                            Enable active monitoring mode
                            
                            .. attribute:: throughput
                            
                            	Enable active monitoring with throughput from passive mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Monitor.Active, self).__init__()

                                self.yang_name = "active"
                                self.yang_parent_name = "monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('throughput', (YLeaf(YType.empty, 'throughput'), ['Empty'])),
                                ])
                                self.throughput = None
                                self._segment_path = lambda: "active"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mode/monitor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Monitor.Active, ['throughput'], name, value)


                    class Route(Entity):
                        """
                        Specify PfR route control policy settings
                        
                        .. attribute:: control
                        
                        	Enable PfR to control routes automatically
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: metric
                        
                        	Specify PfR route protocol related settings
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric>`
                        
                        .. attribute:: observe
                        
                        	PfR offers route control advice, but does not take any action
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: protocol
                        
                        	Specify OER route control protocol
                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Protocol>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route, self).__init__()

                            self.yang_name = "route"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric", ("metric", Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric)), ("protocol", ("protocol", Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Protocol))])
                            self._leafs = OrderedDict([
                                ('control', (YLeaf(YType.empty, 'control'), ['Empty'])),
                                ('observe', (YLeaf(YType.empty, 'observe'), ['Empty'])),
                            ])
                            self.control = None
                            self.observe = None

                            self.metric = Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"

                            self.protocol = Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Protocol()
                            self.protocol.parent = self
                            self._children_name_map["protocol"] = "protocol"
                            self._segment_path = lambda: "route"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mode/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route, ['control', 'observe'], name, value)


                        class Metric(Entity):
                            """
                            Specify PfR route protocol related settings
                            
                            .. attribute:: bgp
                            
                            	Specify PfR bgp protocol settings
                            	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Bgp>`
                            
                            .. attribute:: eigrp
                            
                            	Specify PfR eigrp routes related settings
                            	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Eigrp>`
                            
                            .. attribute:: static
                            
                            	Specify PfR static routes related settings
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Static>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Bgp)), ("eigrp", ("eigrp", Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Eigrp)), ("static", ("static", Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Static))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Bgp()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.eigrp = Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Eigrp()
                                self.eigrp.parent = self
                                self._children_name_map["eigrp"] = "eigrp"

                                self.static = Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Static()
                                self.static.parent = self
                                self._children_name_map["static"] = "static"
                                self._segment_path = lambda: "metric"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mode/route/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric, [], name, value)


                            class Bgp(Entity):
                                """
                                Specify PfR bgp protocol settings
                                
                                .. attribute:: local_pref
                                
                                	Specify the local preference for bgp controlled routes
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "metric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local_pref', (YLeaf(YType.uint16, 'local-pref'), ['int'])),
                                    ])
                                    self.local_pref = None
                                    self._segment_path = lambda: "bgp"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mode/route/metric/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Bgp, ['local_pref'], name, value)


                            class Eigrp(Entity):
                                """
                                Specify PfR eigrp routes related settings
                                
                                .. attribute:: tag
                                
                                	Specify a tag value for PfR controlled eigrp routes
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "metric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('tag', (YLeaf(YType.uint16, 'tag'), ['int'])),
                                    ])
                                    self.tag = None
                                    self._segment_path = lambda: "eigrp"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mode/route/metric/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Eigrp, ['tag'], name, value)


                            class Static(Entity):
                                """
                                Specify PfR static routes related settings
                                
                                .. attribute:: tag
                                
                                	Specify a tag value for PfR controlled static routes
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "metric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('tag', (YLeaf(YType.uint16, 'tag'), ['int'])),
                                    ])
                                    self.tag = None
                                    self._segment_path = lambda: "static"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mode/route/metric/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Metric.Static, ['tag'], name, value)


                        class Protocol(Entity):
                            """
                            Specify OER route control protocol
                            
                            .. attribute:: pbr
                            
                            	Specify OER route control protocol Policy\-Based\-Routing
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Protocol, self).__init__()

                                self.yang_name = "protocol"
                                self.yang_parent_name = "route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pbr', (YLeaf(YType.empty, 'pbr'), ['Empty'])),
                                ])
                                self.pbr = None
                                self._segment_path = lambda: "protocol"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mode/route/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Route.Protocol, ['pbr'], name, value)


                    class Verify(Entity):
                        """
                        Specify verification behavior
                        
                        .. attribute:: bidirectional
                        
                        	Verify bidirectional traffic of applications
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Verify, self).__init__()

                            self.yang_name = "verify"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bidirectional', (YLeaf(YType.empty, 'bidirectional'), ['Empty'])),
                            ])
                            self.bidirectional = None
                            self._segment_path = lambda: "verify"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mode/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mode.Verify, ['bidirectional'], name, value)


                class Mos(Entity):
                    """
                    Specify mos parameters
                    
                    .. attribute:: threshold
                    
                    	Minimum MOS threshold
                    	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mos.Threshold>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mos, self).__init__()

                        self.yang_name = "mos"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("threshold", ("threshold", Native.Pfr.Master.IcmpModeConfigPfrMc.Mos.Threshold))])
                        self._leafs = OrderedDict()

                        self.threshold = Native.Pfr.Master.IcmpModeConfigPfrMc.Mos.Threshold()
                        self.threshold.parent = self
                        self._children_name_map["threshold"] = "threshold"
                        self._segment_path = lambda: "mos"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mos, [], name, value)


                    class Threshold(Entity):
                        """
                        Minimum MOS threshold
                        
                        .. attribute:: mos_thresh
                        
                        	
                        	**type**\: list of  		 :py:class:`MosThresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Mos.Threshold.MosThresh>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mos.Threshold, self).__init__()

                            self.yang_name = "threshold"
                            self.yang_parent_name = "mos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mos-thresh", ("mos_thresh", Native.Pfr.Master.IcmpModeConfigPfrMc.Mos.Threshold.MosThresh))])
                            self._leafs = OrderedDict()

                            self.mos_thresh = YList(self)
                            self._segment_path = lambda: "threshold"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mos/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mos.Threshold, [], name, value)


                        class MosThresh(Entity):
                            """
                            
                            
                            .. attribute:: mos_thresh  (key)
                            
                            	Minimum absolute MOS threshold 1.00 \- 5.00
                            	**type**\: str
                            
                            .. attribute:: percent
                            
                            	Maximum percentage probe with MOS below threshold
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Mos.Threshold.MosThresh, self).__init__()

                                self.yang_name = "mos-thresh"
                                self.yang_parent_name = "threshold"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['mos_thresh']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mos_thresh', (YLeaf(YType.str, 'mos-thresh'), ['str'])),
                                    ('percent', (YLeaf(YType.uint8, 'percent'), ['int'])),
                                ])
                                self.mos_thresh = None
                                self.percent = None
                                self._segment_path = lambda: "mos-thresh" + "[mos-thresh='" + str(self.mos_thresh) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/mos/threshold/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Mos.Threshold.MosThresh, ['mos_thresh', 'percent'], name, value)


                class Probe(Entity):
                    """
                    Specify number of packets for jitter probe
                    
                    .. attribute:: packets
                    
                    	probe packets <number>
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Probe, self).__init__()

                        self.yang_name = "probe"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('packets', (YLeaf(YType.uint8, 'packets'), ['int'])),
                        ])
                        self.packets = None
                        self._segment_path = lambda: "probe"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Probe, ['packets'], name, value)


                class Resolve(Entity):
                    """
                    Specify PfR policy resolver settings
                    
                    .. attribute:: cost
                    
                    	Specify PfR cost policy resolver settings
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: delay
                    
                    	Specify PfR delay policy resolver settings
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay>`
                    
                    .. attribute:: equivalent_path_round_robin
                    
                    	Specify equivalent\-path round\-robin resolver
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: jitter
                    
                    	Specify PfR jitter policy resolver settings
                    	**type**\:  :py:class:`Jitter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter>`
                    
                    .. attribute:: loss
                    
                    	Specify PfR loss policy resolver settings
                    	**type**\:  :py:class:`Loss <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss>`
                    
                    .. attribute:: mos
                    
                    	Specify PfR MOS policy resolver settings
                    	**type**\:  :py:class:`Mos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve, self).__init__()

                        self.yang_name = "resolve"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("delay", ("delay", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay)), ("jitter", ("jitter", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter)), ("loss", ("loss", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss)), ("mos", ("mos", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos))])
                        self._leafs = OrderedDict([
                            ('cost', (YLeaf(YType.empty, 'cost'), ['Empty'])),
                            ('equivalent_path_round_robin', (YLeaf(YType.empty, 'equivalent-path-round-robin'), ['Empty'])),
                        ])
                        self.cost = None
                        self.equivalent_path_round_robin = None

                        self.delay = Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"

                        self.jitter = Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter()
                        self.jitter.parent = self
                        self._children_name_map["jitter"] = "jitter"

                        self.loss = Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss()
                        self.loss.parent = self
                        self._children_name_map["loss"] = "loss"

                        self.mos = Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos()
                        self.mos.parent = self
                        self._children_name_map["mos"] = "mos"
                        self._segment_path = lambda: "resolve"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve, ['cost', 'equivalent_path_round_robin'], name, value)


                    class Delay(Entity):
                        """
                        Specify PfR delay policy resolver settings
                        
                        .. attribute:: priority
                        
                        	Specify the order in which resolver will consider this policy
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay.Priority>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "resolve"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("priority", ("priority", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay.Priority))])
                            self._leafs = OrderedDict()

                            self.priority = Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay.Priority()
                            self.priority.parent = self
                            self._children_name_map["priority"] = "priority"
                            self._segment_path = lambda: "delay"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay, [], name, value)


                        class Priority(Entity):
                            """
                            Specify the order in which resolver will consider this policy
                            
                            .. attribute:: del_pol
                            
                            	
                            	**type**\: list of  		 :py:class:`DelPol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay.Priority.DelPol>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "delay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("del-pol", ("del_pol", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay.Priority.DelPol))])
                                self._leafs = OrderedDict()

                                self.del_pol = YList(self)
                                self._segment_path = lambda: "priority"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/delay/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay.Priority, [], name, value)


                            class DelPol(Entity):
                                """
                                
                                
                                .. attribute:: del_pol  (key)
                                
                                	Specify this policy's priority; 1 being highest
                                	**type**\: int
                                
                                	**range:** 1..9
                                
                                .. attribute:: variance
                                
                                	Specify range; e.g. 25 means all exits measuring up to 25% worse than the best exit are considered equivalent
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay.Priority.DelPol, self).__init__()

                                    self.yang_name = "del-pol"
                                    self.yang_parent_name = "priority"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['del_pol']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('del_pol', (YLeaf(YType.uint8, 'del-pol'), ['int'])),
                                        ('variance', (YLeaf(YType.uint8, 'variance'), ['int'])),
                                    ])
                                    self.del_pol = None
                                    self.variance = None
                                    self._segment_path = lambda: "del-pol" + "[del-pol='" + str(self.del_pol) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/delay/priority/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Delay.Priority.DelPol, ['del_pol', 'variance'], name, value)


                    class Jitter(Entity):
                        """
                        Specify PfR jitter policy resolver settings
                        
                        .. attribute:: priority
                        
                        	Specify the order in which resolver will consider this policy
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter.Priority>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter, self).__init__()

                            self.yang_name = "jitter"
                            self.yang_parent_name = "resolve"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("priority", ("priority", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter.Priority))])
                            self._leafs = OrderedDict()

                            self.priority = Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter.Priority()
                            self.priority.parent = self
                            self._children_name_map["priority"] = "priority"
                            self._segment_path = lambda: "jitter"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter, [], name, value)


                        class Priority(Entity):
                            """
                            Specify the order in which resolver will consider this policy
                            
                            .. attribute:: jit_pol
                            
                            	
                            	**type**\: list of  		 :py:class:`JitPol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter.Priority.JitPol>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "jitter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("jit-pol", ("jit_pol", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter.Priority.JitPol))])
                                self._leafs = OrderedDict()

                                self.jit_pol = YList(self)
                                self._segment_path = lambda: "priority"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/jitter/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter.Priority, [], name, value)


                            class JitPol(Entity):
                                """
                                
                                
                                .. attribute:: jit_pol  (key)
                                
                                	Specify this policy's priority; 1 being highest
                                	**type**\: int
                                
                                	**range:** 1..9
                                
                                .. attribute:: variance
                                
                                	Specify range; e.g. 25 means all exits measuring up to 25% worse than the best exit are considered equivalent
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter.Priority.JitPol, self).__init__()

                                    self.yang_name = "jit-pol"
                                    self.yang_parent_name = "priority"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['jit_pol']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('jit_pol', (YLeaf(YType.uint8, 'jit-pol'), ['int'])),
                                        ('variance', (YLeaf(YType.uint8, 'variance'), ['int'])),
                                    ])
                                    self.jit_pol = None
                                    self.variance = None
                                    self._segment_path = lambda: "jit-pol" + "[jit-pol='" + str(self.jit_pol) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/jitter/priority/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Jitter.Priority.JitPol, ['jit_pol', 'variance'], name, value)


                    class Loss(Entity):
                        """
                        Specify PfR loss policy resolver settings
                        
                        .. attribute:: priority
                        
                        	Specify the order in which resolver will consider this policy
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss.Priority>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss, self).__init__()

                            self.yang_name = "loss"
                            self.yang_parent_name = "resolve"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("priority", ("priority", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss.Priority))])
                            self._leafs = OrderedDict()

                            self.priority = Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss.Priority()
                            self.priority.parent = self
                            self._children_name_map["priority"] = "priority"
                            self._segment_path = lambda: "loss"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss, [], name, value)


                        class Priority(Entity):
                            """
                            Specify the order in which resolver will consider this policy
                            
                            .. attribute:: loss_pol
                            
                            	
                            	**type**\: list of  		 :py:class:`LossPol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss.Priority.LossPol>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "loss"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("loss-pol", ("loss_pol", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss.Priority.LossPol))])
                                self._leafs = OrderedDict()

                                self.loss_pol = YList(self)
                                self._segment_path = lambda: "priority"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/loss/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss.Priority, [], name, value)


                            class LossPol(Entity):
                                """
                                
                                
                                .. attribute:: loss_pol  (key)
                                
                                	Specify this policy's priority; 1 being highest
                                	**type**\: int
                                
                                	**range:** 1..9
                                
                                .. attribute:: variance
                                
                                	Specify range; e.g. 25 means all exits measuring up to 25% worse than the best exit are considered equivalent
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss.Priority.LossPol, self).__init__()

                                    self.yang_name = "loss-pol"
                                    self.yang_parent_name = "priority"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['loss_pol']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('loss_pol', (YLeaf(YType.uint8, 'loss-pol'), ['int'])),
                                        ('variance', (YLeaf(YType.uint8, 'variance'), ['int'])),
                                    ])
                                    self.loss_pol = None
                                    self.variance = None
                                    self._segment_path = lambda: "loss-pol" + "[loss-pol='" + str(self.loss_pol) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/loss/priority/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Loss.Priority.LossPol, ['loss_pol', 'variance'], name, value)


                    class Mos(Entity):
                        """
                        Specify PfR MOS policy resolver settings
                        
                        .. attribute:: priority
                        
                        	Specify the order in which resolver will consider this policy
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos.Priority>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos, self).__init__()

                            self.yang_name = "mos"
                            self.yang_parent_name = "resolve"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("priority", ("priority", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos.Priority))])
                            self._leafs = OrderedDict()

                            self.priority = Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos.Priority()
                            self.priority.parent = self
                            self._children_name_map["priority"] = "priority"
                            self._segment_path = lambda: "mos"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos, [], name, value)


                        class Priority(Entity):
                            """
                            Specify the order in which resolver will consider this policy
                            
                            .. attribute:: mos_pol
                            
                            	
                            	**type**\: list of  		 :py:class:`MosPol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos.Priority.MosPol>`
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "mos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mos-pol", ("mos_pol", Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos.Priority.MosPol))])
                                self._leafs = OrderedDict()

                                self.mos_pol = YList(self)
                                self._segment_path = lambda: "priority"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/mos/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos.Priority, [], name, value)


                            class MosPol(Entity):
                                """
                                
                                
                                .. attribute:: mos_pol  (key)
                                
                                	Specify this policy's priority; 1 being highest
                                	**type**\: int
                                
                                	**range:** 1..9
                                
                                .. attribute:: variance
                                
                                	Specify range; e.g. 25 means all exits measuring up to 25% worse than the best exit are considered equivalent
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-pfr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos.Priority.MosPol, self).__init__()

                                    self.yang_name = "mos-pol"
                                    self.yang_parent_name = "priority"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['mos_pol']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mos_pol', (YLeaf(YType.uint8, 'mos-pol'), ['int'])),
                                        ('variance', (YLeaf(YType.uint8, 'variance'), ['int'])),
                                    ])
                                    self.mos_pol = None
                                    self.variance = None
                                    self._segment_path = lambda: "mos-pol" + "[mos-pol='" + str(self.mos_pol) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/resolve/mos/priority/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Resolve.Mos.Priority.MosPol, ['mos_pol', 'variance'], name, value)


                class Rsvp(Entity):
                    """
                    Specify rsvp parameters
                    
                    .. attribute:: post_dial_delay
                    
                    	RSVP post\-dial\-delay in msecs
                    	**type**\: int
                    
                    	**range:** 0..500
                    
                    .. attribute:: signaling_retries
                    
                    	Number of signaling\-retries
                    	**type**\: int
                    
                    	**range:** 0..1
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Rsvp, self).__init__()

                        self.yang_name = "rsvp"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('post_dial_delay', (YLeaf(YType.uint16, 'post-dial-delay'), ['int'])),
                            ('signaling_retries', (YLeaf(YType.uint8, 'signaling-retries'), ['int'])),
                        ])
                        self.post_dial_delay = None
                        self.signaling_retries = None
                        self._segment_path = lambda: "rsvp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Rsvp, ['post_dial_delay', 'signaling_retries'], name, value)


                class TargetDiscovery(Entity):
                    """
                    Enable/configure Target Discovery
                    
                    .. attribute:: responder_list
                    
                    	Specify static list of responders
                    	**type**\:  :py:class:`ResponderList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery.ResponderList>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery, self).__init__()

                        self.yang_name = "target-discovery"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("responder-list", ("responder_list", Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery.ResponderList))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.responder_list = Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery.ResponderList()
                        self.responder_list.parent = self
                        self._children_name_map["responder_list"] = "responder-list"
                        self._segment_path = lambda: "target-discovery"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery, [], name, value)


                    class ResponderList(Entity):
                        """
                        Specify static list of responders
                        
                        .. attribute:: td_num
                        
                        	
                        	**type**\: list of  		 :py:class:`TdNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery.ResponderList.TdNum>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery.ResponderList, self).__init__()

                            self.yang_name = "responder-list"
                            self.yang_parent_name = "target-discovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("td-num", ("td_num", Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery.ResponderList.TdNum))])
                            self._leafs = OrderedDict()

                            self.td_num = YList(self)
                            self._segment_path = lambda: "responder-list"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/target-discovery/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery.ResponderList, [], name, value)


                        class TdNum(Entity):
                            """
                            
                            
                            .. attribute:: td_num  (key)
                            
                            	Prefix\-list containing list of responders
                            	**type**\: str
                            
                            .. attribute:: inside_prefixes
                            
                            	Prefix\-list containing list of inside prefixes
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-pfr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery.ResponderList.TdNum, self).__init__()

                                self.yang_name = "td-num"
                                self.yang_parent_name = "responder-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['td_num']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('td_num', (YLeaf(YType.str, 'td-num'), ['str'])),
                                    ('inside_prefixes', (YLeaf(YType.str, 'inside-prefixes'), ['str'])),
                                ])
                                self.td_num = None
                                self.inside_prefixes = None
                                self._segment_path = lambda: "td-num" + "[td-num='" + str(self.td_num) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/target-discovery/responder-list/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.TargetDiscovery.ResponderList.TdNum, ['td_num', 'inside_prefixes'], name, value)


                class Traceroute(Entity):
                    """
                    Configure Traceroute global parameters
                    
                    .. attribute:: probe_delay
                    
                    	Specify the time between two probes in msec
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Traceroute, self).__init__()

                        self.yang_name = "traceroute"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('probe_delay', (YLeaf(YType.uint16, 'probe-delay'), ['int'])),
                        ])
                        self.probe_delay = None
                        self._segment_path = lambda: "traceroute"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Traceroute, ['probe_delay'], name, value)


                class Unreachable(Entity):
                    """
                    Specify unreachable parameters
                    
                    .. attribute:: relative
                    
                    	short/long term in percentage. e.g. 125 is short/long = 1.25
                    	**type**\: int
                    
                    	**range:** 1..1000
                    
                    .. attribute:: threshold
                    
                    	Maximum absolute unreachable threshold (flows\-per\-million)
                    	**type**\: int
                    
                    	**range:** 1..1000000
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Pfr.Master.IcmpModeConfigPfrMc.Unreachable, self).__init__()

                        self.yang_name = "unreachable"
                        self.yang_parent_name = "icmp-Mode-config-pfr-mc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('relative', (YLeaf(YType.uint16, 'relative'), ['int'])),
                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                        ])
                        self.relative = None
                        self.threshold = None
                        self._segment_path = lambda: "unreachable"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/pfr/Cisco-IOS-XE-pfr:master/icmp-Mode-config-pfr-mc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Pfr.Master.IcmpModeConfigPfrMc.Unreachable, ['relative', 'threshold'], name, value)


    class PfrMap(Entity):
        """
        Create pfr\-map and enter pfr\-map command mode
        
        .. attribute:: pfr_tg  (key)
        
        	pfr\-map tag
        	**type**\: str
        
        .. attribute:: match
        
        	Match values for PfR policy
        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Match>`
        
        .. attribute:: set
        
        	Set values for PfR policy
        	**type**\:  :py:class:`Set <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.PfrMap, self).__init__()

            self.yang_name = "pfr-map"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['pfr_tg']
            self._child_classes = OrderedDict([("Cisco-IOS-XE-pfr:match", ("match", Native.PfrMap.Match)), ("Cisco-IOS-XE-pfr:set", ("set", Native.PfrMap.Set))])
            self._leafs = OrderedDict([
                ('pfr_tg', (YLeaf(YType.str, 'pfr-tg'), ['str'])),
            ])
            self.pfr_tg = None

            self.match = Native.PfrMap.Match()
            self.match.parent = self
            self._children_name_map["match"] = "Cisco-IOS-XE-pfr:match"

            self.set = Native.PfrMap.Set()
            self.set.parent = self
            self._children_name_map["set"] = "Cisco-IOS-XE-pfr:set"
            self._segment_path = lambda: "pfr-map" + "[pfr-tg='" + str(self.pfr_tg) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.PfrMap, [u'pfr_tg'], name, value)


        class Match(Entity):
            """
            Match values for PfR policy
            
            .. attribute:: ip
            
            	IP specific information
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Match.Ip>`
            
            .. attribute:: pfr
            
            	Match PfR prefixes
            	**type**\:  :py:class:`Pfr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Match.Pfr>`
            
            .. attribute:: traffic_class
            
            	Specify Traffic class
            	**type**\:  :py:class:`TrafficClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Match.TrafficClass>`
            
            

            """

            _prefix = 'ios-pfr'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.PfrMap.Match, self).__init__()

                self.yang_name = "match"
                self.yang_parent_name = "pfr-map"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ip", ("ip", Native.PfrMap.Match.Ip)), ("pfr", ("pfr", Native.PfrMap.Match.Pfr)), ("traffic-class", ("traffic_class", Native.PfrMap.Match.TrafficClass))])
                self._leafs = OrderedDict()

                self.ip = Native.PfrMap.Match.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.pfr = Native.PfrMap.Match.Pfr()
                self.pfr.parent = self
                self._children_name_map["pfr"] = "pfr"

                self.traffic_class = Native.PfrMap.Match.TrafficClass()
                self.traffic_class.parent = self
                self._children_name_map["traffic_class"] = "traffic-class"
                self._segment_path = lambda: "Cisco-IOS-XE-pfr:match"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PfrMap.Match, [], name, value)


            class Ip(Entity):
                """
                IP specific information
                
                .. attribute:: address
                
                	Match address
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-pfr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PfrMap.Match.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "match"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.empty, 'address'), ['Empty'])),
                    ])
                    self.address = None
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PfrMap.Match.Ip, ['address'], name, value)


            class Pfr(Entity):
                """
                Match PfR prefixes
                
                .. attribute:: learn
                
                	Match PfR learned prefixes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-pfr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PfrMap.Match.Pfr, self).__init__()

                    self.yang_name = "pfr"
                    self.yang_parent_name = "match"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('learn', (YLeaf(YType.empty, 'learn'), ['Empty'])),
                    ])
                    self.learn = None
                    self._segment_path = lambda: "pfr"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PfrMap.Match.Pfr, ['learn'], name, value)


            class TrafficClass(Entity):
                """
                Specify Traffic class
                
                .. attribute:: access_list
                
                	Specify Traffic class(es) using access\-list
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: application
                
                	Specify the application to learn
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: prefix_list
                
                	Specify Traffic class(es) using prefix\-list
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-pfr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PfrMap.Match.TrafficClass, self).__init__()

                    self.yang_name = "traffic-class"
                    self.yang_parent_name = "match"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('access_list', (YLeaf(YType.empty, 'access-list'), ['Empty'])),
                        ('application', (YLeaf(YType.empty, 'application'), ['Empty'])),
                        ('prefix_list', (YLeaf(YType.empty, 'prefix-list'), ['Empty'])),
                    ])
                    self.access_list = None
                    self.application = None
                    self.prefix_list = None
                    self._segment_path = lambda: "traffic-class"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PfrMap.Match.TrafficClass, ['access_list', 'application', 'prefix_list'], name, value)


        class Set(Entity):
            """
            Set values for PfR policy
            
            .. attribute:: active_probe
            
            	Manually create an active probe for a known target
            	**type**\:  :py:class:`ActiveProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.ActiveProbe>`
            
            .. attribute:: backoff
            
            	Specify backoff timer parameters
            	**type**\:  :py:class:`Backoff <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.Backoff>`
            
            .. attribute:: delay
            
            	Specify delay parameters
            	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.Delay>`
            
            .. attribute:: holddown
            
            	Specify hold\-down timer parameter (secs)
            	**type**\: int
            
            	**range:** 90..65535
            
            .. attribute:: interface
            
            	Set the forwarding interface to Null0
            	**type**\: str
            
            .. attribute:: jitter
            
            	Specify jitter parameters
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: link_group
            
            	Specify the link group
            	**type**\:  :py:class:`LinkGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.LinkGroup>`
            
            .. attribute:: loss
            
            	Specify loss parameters
            	**type**\:  :py:class:`Loss <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.Loss>`
            
            .. attribute:: mode
            
            	Specify PfR operating mode settings
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: mos
            
            	Specify mos parameters
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: next_hop
            
            	Specify the next\-hop ip address
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: periodic
            
            	Specify periodic rotation timer value
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: probe
            
            	Specify active probe parameter
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: resolve
            
            	Specify PfR policy resolver settings
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: traceroute
            
            	Enable traceroute
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: trap_enable
            
            	Enable PfR MIB Traps
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: trigger_log_percentage
            
            	Specify the percentage of out\-of\-policy TCs that will trigger a syslog
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: unreachable
            
            	Specify unreachable parameters
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-pfr'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.PfrMap.Set, self).__init__()

                self.yang_name = "set"
                self.yang_parent_name = "pfr-map"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("active-probe", ("active_probe", Native.PfrMap.Set.ActiveProbe)), ("backoff", ("backoff", Native.PfrMap.Set.Backoff)), ("delay", ("delay", Native.PfrMap.Set.Delay)), ("link-group", ("link_group", Native.PfrMap.Set.LinkGroup)), ("loss", ("loss", Native.PfrMap.Set.Loss))])
                self._leafs = OrderedDict([
                    ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                    ('jitter', (YLeaf(YType.empty, 'jitter'), ['Empty'])),
                    ('mode', (YLeaf(YType.empty, 'mode'), ['Empty'])),
                    ('mos', (YLeaf(YType.empty, 'mos'), ['Empty'])),
                    ('next_hop', (YLeaf(YType.empty, 'next-hop'), ['Empty'])),
                    ('periodic', (YLeaf(YType.empty, 'periodic'), ['Empty'])),
                    ('probe', (YLeaf(YType.empty, 'probe'), ['Empty'])),
                    ('resolve', (YLeaf(YType.empty, 'resolve'), ['Empty'])),
                    ('traceroute', (YLeaf(YType.empty, 'traceroute'), ['Empty'])),
                    ('trap_enable', (YLeaf(YType.empty, 'trap-enable'), ['Empty'])),
                    ('trigger_log_percentage', (YLeaf(YType.empty, 'trigger-log-percentage'), ['Empty'])),
                    ('unreachable', (YLeaf(YType.empty, 'unreachable'), ['Empty'])),
                ])
                self.holddown = None
                self.interface = None
                self.jitter = None
                self.mode = None
                self.mos = None
                self.next_hop = None
                self.periodic = None
                self.probe = None
                self.resolve = None
                self.traceroute = None
                self.trap_enable = None
                self.trigger_log_percentage = None
                self.unreachable = None

                self.active_probe = Native.PfrMap.Set.ActiveProbe()
                self.active_probe.parent = self
                self._children_name_map["active_probe"] = "active-probe"

                self.backoff = Native.PfrMap.Set.Backoff()
                self.backoff.parent = self
                self._children_name_map["backoff"] = "backoff"

                self.delay = Native.PfrMap.Set.Delay()
                self.delay.parent = self
                self._children_name_map["delay"] = "delay"

                self.link_group = Native.PfrMap.Set.LinkGroup()
                self.link_group.parent = self
                self._children_name_map["link_group"] = "link-group"

                self.loss = Native.PfrMap.Set.Loss()
                self.loss.parent = self
                self._children_name_map["loss"] = "loss"
                self._segment_path = lambda: "Cisco-IOS-XE-pfr:set"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PfrMap.Set, ['holddown', 'interface', 'jitter', 'mode', 'mos', 'next_hop', 'periodic', 'probe', 'resolve', 'traceroute', 'trap_enable', 'trigger_log_percentage', 'unreachable'], name, value)


            class ActiveProbe(Entity):
                """
                Manually create an active probe for a known target
                
                .. attribute:: echo
                
                	Perform ICMP echo probe operations
                	**type**\:  :py:class:`Echo <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.ActiveProbe.Echo>`
                
                .. attribute:: jitter
                
                	Perform jitter probe operations (requires a responder)
                	**type**\:  :py:class:`Jitter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.ActiveProbe.Jitter>`
                
                .. attribute:: tcp_conn
                
                	Perform TCP Connection / Disconnect probe operations
                	**type**\:  :py:class:`TcpConn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.ActiveProbe.TcpConn>`
                
                .. attribute:: udp_echo
                
                	Perform UDP Echo probe operations (requires a responder)
                	**type**\:  :py:class:`UdpEcho <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.ActiveProbe.UdpEcho>`
                
                

                """

                _prefix = 'ios-pfr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PfrMap.Set.ActiveProbe, self).__init__()

                    self.yang_name = "active-probe"
                    self.yang_parent_name = "set"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("echo", ("echo", Native.PfrMap.Set.ActiveProbe.Echo)), ("jitter", ("jitter", Native.PfrMap.Set.ActiveProbe.Jitter)), ("tcp-conn", ("tcp_conn", Native.PfrMap.Set.ActiveProbe.TcpConn)), ("udp-echo", ("udp_echo", Native.PfrMap.Set.ActiveProbe.UdpEcho))])
                    self._leafs = OrderedDict()

                    self.echo = Native.PfrMap.Set.ActiveProbe.Echo()
                    self.echo.parent = self
                    self._children_name_map["echo"] = "echo"

                    self.jitter = Native.PfrMap.Set.ActiveProbe.Jitter()
                    self.jitter.parent = self
                    self._children_name_map["jitter"] = "jitter"

                    self.tcp_conn = Native.PfrMap.Set.ActiveProbe.TcpConn()
                    self.tcp_conn.parent = self
                    self._children_name_map["tcp_conn"] = "tcp-conn"

                    self.udp_echo = Native.PfrMap.Set.ActiveProbe.UdpEcho()
                    self.udp_echo.parent = self
                    self._children_name_map["udp_echo"] = "udp-echo"
                    self._segment_path = lambda: "active-probe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PfrMap.Set.ActiveProbe, [], name, value)


                class Echo(Entity):
                    """
                    Perform ICMP echo probe operations
                    
                    .. attribute:: ipv4_or_hostname
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4OrHostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.ActiveProbe.Echo.Ipv4OrHostname>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PfrMap.Set.ActiveProbe.Echo, self).__init__()

                        self.yang_name = "echo"
                        self.yang_parent_name = "active-probe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4-or-hostname", ("ipv4_or_hostname", Native.PfrMap.Set.ActiveProbe.Echo.Ipv4OrHostname))])
                        self._leafs = OrderedDict()

                        self.ipv4_or_hostname = YList(self)
                        self._segment_path = lambda: "echo"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PfrMap.Set.ActiveProbe.Echo, [], name, value)


                    class Ipv4OrHostname(Entity):
                        """
                        
                        
                        .. attribute:: ipv4_or_hostname  (key)
                        
                        	IP address of probe target
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: dscp
                        
                        	Specify the DSCP value
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PfrMap.Set.ActiveProbe.Echo.Ipv4OrHostname, self).__init__()

                            self.yang_name = "ipv4-or-hostname"
                            self.yang_parent_name = "echo"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv4_or_hostname']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_or_hostname', (YLeaf(YType.str, 'ipv4-or-hostname'), ['str','str','str'])),
                                ('dscp', (YLeaf(YType.empty, 'dscp'), ['Empty'])),
                            ])
                            self.ipv4_or_hostname = None
                            self.dscp = None
                            self._segment_path = lambda: "ipv4-or-hostname" + "[ipv4-or-hostname='" + str(self.ipv4_or_hostname) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PfrMap.Set.ActiveProbe.Echo.Ipv4OrHostname, ['ipv4_or_hostname', 'dscp'], name, value)


                class Jitter(Entity):
                    """
                    Perform jitter probe operations (requires a responder)
                    
                    .. attribute:: ipv4_or_hostname
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4OrHostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.ActiveProbe.Jitter.Ipv4OrHostname>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PfrMap.Set.ActiveProbe.Jitter, self).__init__()

                        self.yang_name = "jitter"
                        self.yang_parent_name = "active-probe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4-or-hostname", ("ipv4_or_hostname", Native.PfrMap.Set.ActiveProbe.Jitter.Ipv4OrHostname))])
                        self._leafs = OrderedDict()

                        self.ipv4_or_hostname = YList(self)
                        self._segment_path = lambda: "jitter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PfrMap.Set.ActiveProbe.Jitter, [], name, value)


                    class Ipv4OrHostname(Entity):
                        """
                        
                        
                        .. attribute:: ipv4_or_hostname  (key)
                        
                        	IP address of probe target
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: target_port
                        
                        	Required Target Port for udp\-echo or tcp\-conn or jitter
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PfrMap.Set.ActiveProbe.Jitter.Ipv4OrHostname, self).__init__()

                            self.yang_name = "ipv4-or-hostname"
                            self.yang_parent_name = "jitter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv4_or_hostname']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_or_hostname', (YLeaf(YType.str, 'ipv4-or-hostname'), ['str','str','str'])),
                                ('target_port', (YLeaf(YType.empty, 'target-port'), ['Empty'])),
                            ])
                            self.ipv4_or_hostname = None
                            self.target_port = None
                            self._segment_path = lambda: "ipv4-or-hostname" + "[ipv4-or-hostname='" + str(self.ipv4_or_hostname) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PfrMap.Set.ActiveProbe.Jitter.Ipv4OrHostname, ['ipv4_or_hostname', 'target_port'], name, value)


                class TcpConn(Entity):
                    """
                    Perform TCP Connection / Disconnect probe operations
                    
                    .. attribute:: ipv4_or_hostname
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4OrHostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.ActiveProbe.TcpConn.Ipv4OrHostname>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PfrMap.Set.ActiveProbe.TcpConn, self).__init__()

                        self.yang_name = "tcp-conn"
                        self.yang_parent_name = "active-probe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4-or-hostname", ("ipv4_or_hostname", Native.PfrMap.Set.ActiveProbe.TcpConn.Ipv4OrHostname))])
                        self._leafs = OrderedDict()

                        self.ipv4_or_hostname = YList(self)
                        self._segment_path = lambda: "tcp-conn"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PfrMap.Set.ActiveProbe.TcpConn, [], name, value)


                    class Ipv4OrHostname(Entity):
                        """
                        
                        
                        .. attribute:: ipv4_or_hostname  (key)
                        
                        	IP address of probe target
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: target_port
                        
                        	Required Target Port for udp\-echo or tcp\-conn or jitter
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PfrMap.Set.ActiveProbe.TcpConn.Ipv4OrHostname, self).__init__()

                            self.yang_name = "ipv4-or-hostname"
                            self.yang_parent_name = "tcp-conn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv4_or_hostname']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_or_hostname', (YLeaf(YType.str, 'ipv4-or-hostname'), ['str','str','str'])),
                                ('target_port', (YLeaf(YType.empty, 'target-port'), ['Empty'])),
                            ])
                            self.ipv4_or_hostname = None
                            self.target_port = None
                            self._segment_path = lambda: "ipv4-or-hostname" + "[ipv4-or-hostname='" + str(self.ipv4_or_hostname) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PfrMap.Set.ActiveProbe.TcpConn.Ipv4OrHostname, ['ipv4_or_hostname', 'target_port'], name, value)


                class UdpEcho(Entity):
                    """
                    Perform UDP Echo probe operations (requires a responder)
                    
                    .. attribute:: ipv4_or_hostname
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4OrHostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.ActiveProbe.UdpEcho.Ipv4OrHostname>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PfrMap.Set.ActiveProbe.UdpEcho, self).__init__()

                        self.yang_name = "udp-echo"
                        self.yang_parent_name = "active-probe"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4-or-hostname", ("ipv4_or_hostname", Native.PfrMap.Set.ActiveProbe.UdpEcho.Ipv4OrHostname))])
                        self._leafs = OrderedDict()

                        self.ipv4_or_hostname = YList(self)
                        self._segment_path = lambda: "udp-echo"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PfrMap.Set.ActiveProbe.UdpEcho, [], name, value)


                    class Ipv4OrHostname(Entity):
                        """
                        
                        
                        .. attribute:: ipv4_or_hostname  (key)
                        
                        	IP address of probe target
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
                        
                        .. attribute:: target_port
                        
                        	Required Target Port for udp\-echo or tcp\-conn or jitter
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PfrMap.Set.ActiveProbe.UdpEcho.Ipv4OrHostname, self).__init__()

                            self.yang_name = "ipv4-or-hostname"
                            self.yang_parent_name = "udp-echo"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv4_or_hostname']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_or_hostname', (YLeaf(YType.str, 'ipv4-or-hostname'), ['str','str','str'])),
                                ('target_port', (YLeaf(YType.empty, 'target-port'), ['Empty'])),
                            ])
                            self.ipv4_or_hostname = None
                            self.target_port = None
                            self._segment_path = lambda: "ipv4-or-hostname" + "[ipv4-or-hostname='" + str(self.ipv4_or_hostname) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PfrMap.Set.ActiveProbe.UdpEcho.Ipv4OrHostname, ['ipv4_or_hostname', 'target_port'], name, value)


            class Backoff(Entity):
                """
                Specify backoff timer parameters
                
                .. attribute:: boff_t
                
                	
                	**type**\: list of  		 :py:class:`BoffT <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.Backoff.BoffT>`
                
                

                """

                _prefix = 'ios-pfr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PfrMap.Set.Backoff, self).__init__()

                    self.yang_name = "backoff"
                    self.yang_parent_name = "set"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("boff-t", ("boff_t", Native.PfrMap.Set.Backoff.BoffT))])
                    self._leafs = OrderedDict()

                    self.boff_t = YList(self)
                    self._segment_path = lambda: "backoff"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PfrMap.Set.Backoff, [], name, value)


                class BoffT(Entity):
                    """
                    
                    
                    .. attribute:: boff_t  (key)
                    
                    	Specify minimum value of backoff timer (secs)
                    	**type**\: int
                    
                    	**range:** 90..7200
                    
                    .. attribute:: boff_t0
                    
                    	
                    	**type**\: list of  		 :py:class:`BoffT0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.Backoff.BoffT.BoffT0>`
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PfrMap.Set.Backoff.BoffT, self).__init__()

                        self.yang_name = "boff-t"
                        self.yang_parent_name = "backoff"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['boff_t']
                        self._child_classes = OrderedDict([("boff-t0", ("boff_t0", Native.PfrMap.Set.Backoff.BoffT.BoffT0))])
                        self._leafs = OrderedDict([
                            ('boff_t', (YLeaf(YType.uint16, 'boff-t'), ['int'])),
                        ])
                        self.boff_t = None

                        self.boff_t0 = YList(self)
                        self._segment_path = lambda: "boff-t" + "[boff-t='" + str(self.boff_t) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PfrMap.Set.Backoff.BoffT, ['boff_t'], name, value)


                    class BoffT0(Entity):
                        """
                        
                        
                        .. attribute:: boff_t0  (key)
                        
                        	Specify maximum value of backoff timer (secs)
                        	**type**\: int
                        
                        	**range:** 90..7200
                        
                        .. attribute:: boff_rng
                        
                        	Specify optional backoff timer step (secs)
                        	**type**\: int
                        
                        	**range:** 90..7110
                        
                        

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PfrMap.Set.Backoff.BoffT.BoffT0, self).__init__()

                            self.yang_name = "boff-t0"
                            self.yang_parent_name = "boff-t"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['boff_t0']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('boff_t0', (YLeaf(YType.uint16, 'boff-t0'), ['int'])),
                                ('boff_rng', (YLeaf(YType.uint16, 'boff-rng'), ['int'])),
                            ])
                            self.boff_t0 = None
                            self.boff_rng = None
                            self._segment_path = lambda: "boff-t0" + "[boff-t0='" + str(self.boff_t0) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PfrMap.Set.Backoff.BoffT.BoffT0, ['boff_t0', 'boff_rng'], name, value)


            class Delay(Entity):
                """
                Specify delay parameters
                
                .. attribute:: relative
                
                	Maximum allowable relative change from short to long term
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: threshold
                
                	Maximum allowable absolute delay
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-pfr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PfrMap.Set.Delay, self).__init__()

                    self.yang_name = "delay"
                    self.yang_parent_name = "set"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('relative', (YLeaf(YType.empty, 'relative'), ['Empty'])),
                        ('threshold', (YLeaf(YType.empty, 'threshold'), ['Empty'])),
                    ])
                    self.relative = None
                    self.threshold = None
                    self._segment_path = lambda: "delay"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PfrMap.Set.Delay, ['relative', 'threshold'], name, value)


            class LinkGroup(Entity):
                """
                Specify the link group
                
                .. attribute:: lg_name
                
                	
                	**type**\: list of  		 :py:class:`LgName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.LinkGroup.LgName>`
                
                

                """

                _prefix = 'ios-pfr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PfrMap.Set.LinkGroup, self).__init__()

                    self.yang_name = "link-group"
                    self.yang_parent_name = "set"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("lg-name", ("lg_name", Native.PfrMap.Set.LinkGroup.LgName))])
                    self._leafs = OrderedDict()

                    self.lg_name = YList(self)
                    self._segment_path = lambda: "link-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PfrMap.Set.LinkGroup, [], name, value)


                class LgName(Entity):
                    """
                    
                    
                    .. attribute:: lg_name  (key)
                    
                    	Specify primary link group name
                    	**type**\: str
                    
                    .. attribute:: fallback
                    
                    	Specify the fallback link group
                    	**type**\:  :py:class:`Fallback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PfrMap.Set.LinkGroup.LgName.Fallback>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-pfr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PfrMap.Set.LinkGroup.LgName, self).__init__()

                        self.yang_name = "lg-name"
                        self.yang_parent_name = "link-group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['lg_name']
                        self._child_classes = OrderedDict([("fallback", ("fallback", Native.PfrMap.Set.LinkGroup.LgName.Fallback))])
                        self._leafs = OrderedDict([
                            ('lg_name', (YLeaf(YType.str, 'lg-name'), ['str'])),
                        ])
                        self.lg_name = None

                        self.fallback = None
                        self._children_name_map["fallback"] = "fallback"
                        self._segment_path = lambda: "lg-name" + "[lg-name='" + str(self.lg_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PfrMap.Set.LinkGroup.LgName, ['lg_name'], name, value)


                    class Fallback(Entity):
                        """
                        Specify the fallback link group
                        
                        .. attribute:: fall_name
                        
                        	Specify Fallback link group name
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-pfr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PfrMap.Set.LinkGroup.LgName.Fallback, self).__init__()

                            self.yang_name = "fallback"
                            self.yang_parent_name = "lg-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('fall_name', (YLeaf(YType.str, 'fall-name'), ['str'])),
                            ])
                            self.fall_name = None
                            self._segment_path = lambda: "fallback"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PfrMap.Set.LinkGroup.LgName.Fallback, ['fall_name'], name, value)


            class Loss(Entity):
                """
                Specify loss parameters
                
                .. attribute:: relative
                
                	short/long term in percentage. e.g. 125 is short/long = 1.25
                	**type**\: int
                
                	**range:** 1..1000
                
                .. attribute:: threshold
                
                	Maximum absolute lost packet threshold in percentage e.g., 1 is 0.0001 percent
                	**type**\: int
                
                	**range:** 1..1000000
                
                

                """

                _prefix = 'ios-pfr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PfrMap.Set.Loss, self).__init__()

                    self.yang_name = "loss"
                    self.yang_parent_name = "set"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('relative', (YLeaf(YType.uint16, 'relative'), ['int'])),
                        ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                    ])
                    self.relative = None
                    self.threshold = None
                    self._segment_path = lambda: "loss"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PfrMap.Set.Loss, ['relative', 'threshold'], name, value)


    class FacilityAlarm(Entity):
        """
        Configure facility alarms
        
        .. attribute:: severity
        
        	
        	**type**\:  :py:class:`Severity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FacilityAlarm.Severity>`
        
        .. attribute:: exceed_action
        
        	Behavior on critical threshold exceed
        	**type**\:  :py:class:`ExceedAction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FacilityAlarm.ExceedAction>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.FacilityAlarm, self).__init__()

            self.yang_name = "facility-alarm"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('severity', (YLeaf(YType.enumeration, 'severity'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'FacilityAlarm.Severity')])),
                ('exceed_action', (YLeaf(YType.enumeration, 'exceed-action'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'FacilityAlarm.ExceedAction')])),
            ])
            self.severity = None
            self.exceed_action = None
            self._segment_path = lambda: "facility-alarm"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.FacilityAlarm, [u'severity', u'exceed_action'], name, value)

        class ExceedAction(Enum):
            """
            ExceedAction (Enum Class)

            Behavior on critical threshold exceed

            .. data:: shutdown = 0

            """

            shutdown = Enum.YLeaf(0, "shutdown")


        class Severity(Enum):
            """
            Severity (Enum Class)

            .. data:: critical = 0

            """

            critical = Enum.YLeaf(0, "critical")



    class Setup(Entity):
        """
        Configure setup options
        
        .. attribute:: express
        
        	Configure whether express setup mode is enabled
        	**type**\: bool
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Setup, self).__init__()

            self.yang_name = "setup"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('express', (YLeaf(YType.boolean, 'Cisco-IOS-XE-switch:express'), ['bool'])),
            ])
            self.express = None
            self._segment_path = lambda: "setup"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Setup, [u'express'], name, value)


    class TodClock(Entity):
        """
        Tod clock config commands
        
        .. attribute:: input_source
        
        	Synchronization Input Source
        	**type**\:  :py:class:`InputSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TodClock.InputSource>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.TodClock, self).__init__()

            self.yang_name = "tod-clock"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("input-source", ("input_source", Native.TodClock.InputSource))])
            self._leafs = OrderedDict()

            self.input_source = Native.TodClock.InputSource()
            self.input_source.parent = self
            self._children_name_map["input_source"] = "input-source"
            self._segment_path = lambda: "tod-clock"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.TodClock, [], name, value)


        class InputSource(Entity):
            """
            Synchronization Input Source
            
            .. attribute:: priority
            
            	
            	**type**\: int
            
            	**range:** 1..250
            
            .. attribute:: ptp
            
            	
            	**type**\:  :py:class:`Ptp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TodClock.InputSource.Ptp>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.TodClock.InputSource, self).__init__()

                self.yang_name = "input-source"
                self.yang_parent_name = "tod-clock"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ptp", ("ptp", Native.TodClock.InputSource.Ptp))])
                self._leafs = OrderedDict([
                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                ])
                self.priority = None

                self.ptp = Native.TodClock.InputSource.Ptp()
                self.ptp.parent = self
                self._children_name_map["ptp"] = "ptp"
                self._segment_path = lambda: "input-source"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/tod-clock/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.TodClock.InputSource, [u'priority'], name, value)


            class Ptp(Entity):
                """
                
                
                .. attribute:: domain
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.TodClock.InputSource.Ptp, self).__init__()

                    self.yang_name = "ptp"
                    self.yang_parent_name = "input-source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('domain', (YLeaf(YType.uint8, 'domain'), ['int'])),
                    ])
                    self.domain = None
                    self._segment_path = lambda: "ptp"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/tod-clock/input-source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.TodClock.InputSource.Ptp, [u'domain'], name, value)


    class NetworkClock(Entity):
        """
        Network clock config commands
        
        .. attribute:: synchronization
        
        	Network clock synchronization selection process
        	**type**\:  :py:class:`Synchronization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkClock.Synchronization>`
        
        .. attribute:: wait_to_restore
        
        	Wait\-to\-Restore timer
        	**type**\:  :py:class:`WaitToRestore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkClock.WaitToRestore>`
        
        .. attribute:: input_source
        
        	Synchronization Input Source
        	**type**\:  :py:class:`InputSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkClock.InputSource>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.NetworkClock, self).__init__()

            self.yang_name = "network-clock"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("synchronization", ("synchronization", Native.NetworkClock.Synchronization)), ("wait-to-restore", ("wait_to_restore", Native.NetworkClock.WaitToRestore)), ("input-source", ("input_source", Native.NetworkClock.InputSource))])
            self._leafs = OrderedDict()

            self.synchronization = Native.NetworkClock.Synchronization()
            self.synchronization.parent = self
            self._children_name_map["synchronization"] = "synchronization"

            self.wait_to_restore = Native.NetworkClock.WaitToRestore()
            self.wait_to_restore.parent = self
            self._children_name_map["wait_to_restore"] = "wait-to-restore"

            self.input_source = Native.NetworkClock.InputSource()
            self.input_source.parent = self
            self._children_name_map["input_source"] = "input-source"
            self._segment_path = lambda: "network-clock"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.NetworkClock, [], name, value)


        class Synchronization(Entity):
            """
            Network clock synchronization selection process
            
            .. attribute:: automatic
            
            	ITU\-T G.781/Telcordia standard based
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: mode
            
            	synchronization networking mode
            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkClock.Synchronization.Mode>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.NetworkClock.Synchronization, self).__init__()

                self.yang_name = "synchronization"
                self.yang_parent_name = "network-clock"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('automatic', (YLeaf(YType.empty, 'automatic'), ['Empty'])),
                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'NetworkClock.Synchronization.Mode')])),
                ])
                self.automatic = None
                self.mode = None
                self._segment_path = lambda: "synchronization"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/network-clock/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.NetworkClock.Synchronization, [u'automatic', u'mode'], name, value)

            class Mode(Enum):
                """
                Mode (Enum Class)

                synchronization networking mode

                .. data:: QL_enabled = 0

                """

                QL_enabled = Enum.YLeaf(0, "QL-enabled")



        class WaitToRestore(Entity):
            """
            Wait\-to\-Restore timer
            
            .. attribute:: time
            
            	Wait\-to\-Restore time
            	**type**\: int
            
            	**range:** 0..86400
            
            .. attribute:: global_
            
            	Global
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.NetworkClock.WaitToRestore, self).__init__()

                self.yang_name = "wait-to-restore"
                self.yang_parent_name = "network-clock"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                    ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                ])
                self.time = None
                self.global_ = None
                self._segment_path = lambda: "wait-to-restore"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/network-clock/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.NetworkClock.WaitToRestore, [u'time', u'global_'], name, value)


        class InputSource(Entity):
            """
            Synchronization Input Source
            
            .. attribute:: priority
            
            	
            	**type**\: int
            
            	**range:** 1..250
            
            .. attribute:: interface
            
            	
            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkClock.InputSource.Interface>`
            
            .. attribute:: ptp
            
            	
            	**type**\:  :py:class:`Ptp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkClock.InputSource.Ptp>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.NetworkClock.InputSource, self).__init__()

                self.yang_name = "input-source"
                self.yang_parent_name = "network-clock"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("interface", ("interface", Native.NetworkClock.InputSource.Interface)), ("ptp", ("ptp", Native.NetworkClock.InputSource.Ptp))])
                self._leafs = OrderedDict([
                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                ])
                self.priority = None

                self.interface = Native.NetworkClock.InputSource.Interface()
                self.interface.parent = self
                self._children_name_map["interface"] = "interface"

                self.ptp = Native.NetworkClock.InputSource.Ptp()
                self.ptp.parent = self
                self._children_name_map["ptp"] = "ptp"
                self._segment_path = lambda: "input-source"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/network-clock/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.NetworkClock.InputSource, [u'priority'], name, value)


            class Interface(Entity):
                """
                
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkClock.InputSource.Interface.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkClock.InputSource.Interface.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkClock.InputSource.Interface.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.NetworkClock.InputSource.Interface.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.NetworkClock.InputSource.Interface, self).__init__()

                    self.yang_name = "interface"
                    self.yang_parent_name = "input-source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.NetworkClock.InputSource.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.NetworkClock.InputSource.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.NetworkClock.InputSource.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.NetworkClock.InputSource.Interface.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.NetworkClock.InputSource.Interface.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.NetworkClock.InputSource.Interface.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.NetworkClock.InputSource.Interface.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.NetworkClock.InputSource.Interface.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/network-clock/input-source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.NetworkClock.InputSource.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.NetworkClock.InputSource.Interface.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/network-clock/input-source/interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.NetworkClock.InputSource.Interface.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.NetworkClock.InputSource.Interface.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/network-clock/input-source/interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.NetworkClock.InputSource.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.NetworkClock.InputSource.Interface.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/network-clock/input-source/interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.NetworkClock.InputSource.Interface.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.NetworkClock.InputSource.Interface.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/network-clock/input-source/interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.NetworkClock.InputSource.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


            class Ptp(Entity):
                """
                
                
                .. attribute:: domain
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.NetworkClock.InputSource.Ptp, self).__init__()

                    self.yang_name = "ptp"
                    self.yang_parent_name = "input-source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('domain', (YLeaf(YType.uint8, 'domain'), ['int'])),
                    ])
                    self.domain = None
                    self._segment_path = lambda: "ptp"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/network-clock/input-source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.NetworkClock.InputSource.Ptp, [u'domain'], name, value)


    class L2vpn(Entity):
        """
        Layer2 VPN commands
        
        .. attribute:: pseudowire
        
        	Global pseudowire parameters
        	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire>`
        
        .. attribute:: vfi
        
        	Configure a Virtual Forwarding Instance (VFI)
        	**type**\:  :py:class:`Vfi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Vfi>`
        
        .. attribute:: xconnect
        
        	Configure a cross connect
        	**type**\:  :py:class:`Xconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect>`
        
        .. attribute:: evpn_cont
        
        	
        	**type**\:  :py:class:`EvpnCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.L2vpn, self).__init__()

            self.yang_name = "l2vpn"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-l2vpn:pseudowire", ("pseudowire", Native.L2vpn.Pseudowire)), ("Cisco-IOS-XE-l2vpn:vfi", ("vfi", Native.L2vpn.Vfi)), ("Cisco-IOS-XE-l2vpn:xconnect", ("xconnect", Native.L2vpn.Xconnect)), ("Cisco-IOS-XE-l2vpn:evpn_cont", ("evpn_cont", Native.L2vpn.EvpnCont))])
            self._leafs = OrderedDict()

            self.pseudowire = Native.L2vpn.Pseudowire()
            self.pseudowire.parent = self
            self._children_name_map["pseudowire"] = "Cisco-IOS-XE-l2vpn:pseudowire"

            self.vfi = Native.L2vpn.Vfi()
            self.vfi.parent = self
            self._children_name_map["vfi"] = "Cisco-IOS-XE-l2vpn:vfi"

            self.xconnect = Native.L2vpn.Xconnect()
            self.xconnect.parent = self
            self._children_name_map["xconnect"] = "Cisco-IOS-XE-l2vpn:xconnect"

            self.evpn_cont = Native.L2vpn.EvpnCont()
            self.evpn_cont.parent = self
            self._children_name_map["evpn_cont"] = "Cisco-IOS-XE-l2vpn:evpn_cont"
            self._segment_path = lambda: "l2vpn"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.L2vpn, [], name, value)


        class Pseudowire(Entity):
            """
            Global pseudowire parameters
            
            .. attribute:: static_oam
            
            	Static PW OAM configuration
            	**type**\:  :py:class:`StaticOam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire.StaticOam>`
            
            .. attribute:: tlv
            
            	Global PW TLV configuration
            	**type**\:  :py:class:`Tlv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire.Tlv>`
            
            .. attribute:: group
            
            	Configure pseudowire group parameters
            	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire.Group>`
            
            .. attribute:: routing
            
            	Configure l2vpn pseudowire routing
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.L2vpn.Pseudowire, self).__init__()

                self.yang_name = "pseudowire"
                self.yang_parent_name = "l2vpn"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("static-oam", ("static_oam", Native.L2vpn.Pseudowire.StaticOam)), ("tlv", ("tlv", Native.L2vpn.Pseudowire.Tlv)), ("group", ("group", Native.L2vpn.Pseudowire.Group))])
                self._leafs = OrderedDict([
                    ('routing', (YLeaf(YType.empty, 'routing'), ['Empty'])),
                ])
                self.routing = None

                self.static_oam = Native.L2vpn.Pseudowire.StaticOam()
                self.static_oam.parent = self
                self._children_name_map["static_oam"] = "static-oam"

                self.tlv = Native.L2vpn.Pseudowire.Tlv()
                self.tlv.parent = self
                self._children_name_map["tlv"] = "tlv"

                self.group = Native.L2vpn.Pseudowire.Group()
                self.group.parent = self
                self._children_name_map["group"] = "group"
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:pseudowire"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.L2vpn.Pseudowire, ['routing'], name, value)


            class StaticOam(Entity):
                """
                Static PW OAM configuration
                
                .. attribute:: class_
                
                	Static PW OAM class configuration
                	**type**\: list of  		 :py:class:`Class <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire.StaticOam.Class>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.L2vpn.Pseudowire.StaticOam, self).__init__()

                    self.yang_name = "static-oam"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("class", ("class_", Native.L2vpn.Pseudowire.StaticOam.Class))])
                    self._leafs = OrderedDict()

                    self.class_ = YList(self)
                    self._segment_path = lambda: "static-oam"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:pseudowire/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L2vpn.Pseudowire.StaticOam, [], name, value)


                class Class(Entity):
                    """
                    Static PW OAM class configuration
                    
                    .. attribute:: pw_nm  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: timeout
                    
                    	timeout configurations
                    	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire.StaticOam.Class.Timeout>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.Pseudowire.StaticOam.Class, self).__init__()

                        self.yang_name = "class"
                        self.yang_parent_name = "static-oam"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['pw_nm']
                        self._child_classes = OrderedDict([("timeout", ("timeout", Native.L2vpn.Pseudowire.StaticOam.Class.Timeout))])
                        self._leafs = OrderedDict([
                            ('pw_nm', (YLeaf(YType.str, 'pw-nm'), ['str'])),
                        ])
                        self.pw_nm = None

                        self.timeout = Native.L2vpn.Pseudowire.StaticOam.Class.Timeout()
                        self.timeout.parent = self
                        self._children_name_map["timeout"] = "timeout"
                        self._segment_path = lambda: "class" + "[pw-nm='" + str(self.pw_nm) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:pseudowire/static-oam/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.Pseudowire.StaticOam.Class, ['pw_nm'], name, value)


                    class Timeout(Entity):
                        """
                        timeout configurations
                        
                        .. attribute:: refresh
                        
                        	refresh timeout configurations
                        	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire.StaticOam.Class.Timeout.Refresh>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.Pseudowire.StaticOam.Class.Timeout, self).__init__()

                            self.yang_name = "timeout"
                            self.yang_parent_name = "class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("refresh", ("refresh", Native.L2vpn.Pseudowire.StaticOam.Class.Timeout.Refresh))])
                            self._leafs = OrderedDict()

                            self.refresh = Native.L2vpn.Pseudowire.StaticOam.Class.Timeout.Refresh()
                            self.refresh.parent = self
                            self._children_name_map["refresh"] = "refresh"
                            self._segment_path = lambda: "timeout"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.Pseudowire.StaticOam.Class.Timeout, [], name, value)


                        class Refresh(Entity):
                            """
                            refresh timeout configurations
                            
                            .. attribute:: send
                            
                            	refresh send timeout configuration
                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire.StaticOam.Class.Timeout.Refresh.Send>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.Pseudowire.StaticOam.Class.Timeout.Refresh, self).__init__()

                                self.yang_name = "refresh"
                                self.yang_parent_name = "timeout"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("send", ("send", Native.L2vpn.Pseudowire.StaticOam.Class.Timeout.Refresh.Send))])
                                self._leafs = OrderedDict()

                                self.send = Native.L2vpn.Pseudowire.StaticOam.Class.Timeout.Refresh.Send()
                                self.send.parent = self
                                self._children_name_map["send"] = "send"
                                self._segment_path = lambda: "refresh"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.Pseudowire.StaticOam.Class.Timeout.Refresh, [], name, value)


                            class Send(Entity):
                                """
                                refresh send timeout configuration
                                
                                .. attribute:: interval
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4095
                                
                                

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.L2vpn.Pseudowire.StaticOam.Class.Timeout.Refresh.Send, self).__init__()

                                    self.yang_name = "send"
                                    self.yang_parent_name = "refresh"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "send"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.L2vpn.Pseudowire.StaticOam.Class.Timeout.Refresh.Send, ['interval'], name, value)


            class Tlv(Entity):
                """
                Global PW TLV configuration
                
                .. attribute:: template
                
                	PW TLV Template Keyword
                	**type**\: list of  		 :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire.Tlv.Template>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.L2vpn.Pseudowire.Tlv, self).__init__()

                    self.yang_name = "tlv"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("template", ("template", Native.L2vpn.Pseudowire.Tlv.Template))])
                    self._leafs = OrderedDict()

                    self.template = YList(self)
                    self._segment_path = lambda: "tlv"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:pseudowire/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L2vpn.Pseudowire.Tlv, [], name, value)


                class Template(Entity):
                    """
                    PW TLV Template Keyword
                    
                    .. attribute:: tlv_nm  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: tlv
                    
                    	TLV config command
                    	**type**\:  :py:class:`Tlv_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire.Tlv.Template.Tlv_>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.Pseudowire.Tlv.Template, self).__init__()

                        self.yang_name = "template"
                        self.yang_parent_name = "tlv"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['tlv_nm']
                        self._child_classes = OrderedDict([("tlv", ("tlv", Native.L2vpn.Pseudowire.Tlv.Template.Tlv_))])
                        self._leafs = OrderedDict([
                            ('tlv_nm', (YLeaf(YType.str, 'tlv-nm'), ['str'])),
                        ])
                        self.tlv_nm = None

                        self.tlv = Native.L2vpn.Pseudowire.Tlv.Template.Tlv_()
                        self.tlv.parent = self
                        self._children_name_map["tlv"] = "tlv"
                        self._segment_path = lambda: "template" + "[tlv-nm='" + str(self.tlv_nm) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:pseudowire/tlv/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.Pseudowire.Tlv.Template, ['tlv_nm'], name, value)


                    class Tlv_(Entity):
                        """
                        TLV config command
                        
                        .. attribute:: tlv_type
                        
                        	
                        	**type**\:  :py:class:`TlvType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire.Tlv.Template.Tlv_.TlvType>`
                        
                        .. attribute:: tlv_description
                        
                        	
                        	**type**\:  :py:class:`TlvDescription <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Pseudowire.Tlv.Template.Tlv_.TlvDescription>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.Pseudowire.Tlv.Template.Tlv_, self).__init__()

                            self.yang_name = "tlv"
                            self.yang_parent_name = "template"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("tlv-type", ("tlv_type", Native.L2vpn.Pseudowire.Tlv.Template.Tlv_.TlvType)), ("tlv-description", ("tlv_description", Native.L2vpn.Pseudowire.Tlv.Template.Tlv_.TlvDescription))])
                            self._leafs = OrderedDict()

                            self.tlv_type = Native.L2vpn.Pseudowire.Tlv.Template.Tlv_.TlvType()
                            self.tlv_type.parent = self
                            self._children_name_map["tlv_type"] = "tlv-type"

                            self.tlv_description = Native.L2vpn.Pseudowire.Tlv.Template.Tlv_.TlvDescription()
                            self.tlv_description.parent = self
                            self._children_name_map["tlv_description"] = "tlv-description"
                            self._segment_path = lambda: "tlv"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.Pseudowire.Tlv.Template.Tlv_, [], name, value)


                        class TlvType(Entity):
                            """
                            
                            
                            .. attribute:: type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..40
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.Pseudowire.Tlv.Template.Tlv_.TlvType, self).__init__()

                                self.yang_name = "tlv-type"
                                self.yang_parent_name = "tlv"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                ])
                                self.type = None
                                self._segment_path = lambda: "tlv-type"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.Pseudowire.Tlv.Template.Tlv_.TlvType, ['type'], name, value)


                        class TlvDescription(Entity):
                            """
                            
                            
                            .. attribute:: description
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.Pseudowire.Tlv.Template.Tlv_.TlvDescription, self).__init__()

                                self.yang_name = "tlv-description"
                                self.yang_parent_name = "tlv"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                ])
                                self.description = None
                                self._segment_path = lambda: "tlv-description"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.Pseudowire.Tlv.Template.Tlv_.TlvDescription, ['description'], name, value)


            class Group(Entity):
                """
                Configure pseudowire group parameters
                
                .. attribute:: status
                
                	Send pseudowire group status messages
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.L2vpn.Pseudowire.Group, self).__init__()

                    self.yang_name = "group"
                    self.yang_parent_name = "pseudowire"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                    ])
                    self.status = None
                    self._segment_path = lambda: "group"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:pseudowire/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L2vpn.Pseudowire.Group, ['status'], name, value)


        class Vfi(Entity):
            """
            Configure a Virtual Forwarding Instance (VFI)
            
            .. attribute:: context
            
            	Layer2 VPN Context
            	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Vfi.Context>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.L2vpn.Vfi, self).__init__()

                self.yang_name = "vfi"
                self.yang_parent_name = "l2vpn"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("context", ("context", Native.L2vpn.Vfi.Context))])
                self._leafs = OrderedDict()

                self.context = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:vfi"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.L2vpn.Vfi, [], name, value)


            class Context(Entity):
                """
                Layer2 VPN Context
                
                .. attribute:: vfi_nm  (key)
                
                	Virtual Forwarding Instance (VFI) name
                	**type**\: str
                
                .. attribute:: autodiscovery
                
                	Auto Discovery mode
                	**type**\:  :py:class:`Autodiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Vfi.Context.Autodiscovery>`
                
                .. attribute:: vpn
                
                	VPN configuration
                	**type**\:  :py:class:`Vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Vfi.Context.Vpn>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.L2vpn.Vfi.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "vfi"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['vfi_nm']
                    self._child_classes = OrderedDict([("autodiscovery", ("autodiscovery", Native.L2vpn.Vfi.Context.Autodiscovery)), ("vpn", ("vpn", Native.L2vpn.Vfi.Context.Vpn))])
                    self._leafs = OrderedDict([
                        ('vfi_nm', (YLeaf(YType.str, 'vfi-nm'), ['str'])),
                    ])
                    self.vfi_nm = None

                    self.autodiscovery = Native.L2vpn.Vfi.Context.Autodiscovery()
                    self.autodiscovery.parent = self
                    self._children_name_map["autodiscovery"] = "autodiscovery"

                    self.vpn = Native.L2vpn.Vfi.Context.Vpn()
                    self.vpn.parent = self
                    self._children_name_map["vpn"] = "vpn"
                    self._segment_path = lambda: "context" + "[vfi-nm='" + str(self.vfi_nm) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:vfi/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L2vpn.Vfi.Context, ['vfi_nm'], name, value)


                class Autodiscovery(Entity):
                    """
                    Auto Discovery mode
                    
                    .. attribute:: bgp
                    
                    	Use BGP for neighbor discovery
                    	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Vfi.Context.Autodiscovery.Bgp>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.Vfi.Context.Autodiscovery, self).__init__()

                        self.yang_name = "autodiscovery"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.L2vpn.Vfi.Context.Autodiscovery.Bgp))])
                        self._leafs = OrderedDict()

                        self.bgp = Native.L2vpn.Vfi.Context.Autodiscovery.Bgp()
                        self.bgp.parent = self
                        self._children_name_map["bgp"] = "bgp"
                        self._segment_path = lambda: "autodiscovery"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.Vfi.Context.Autodiscovery, [], name, value)


                    class Bgp(Entity):
                        """
                        Use BGP for neighbor discovery
                        
                        .. attribute:: signaling
                        
                        	Signaling protocol to use
                        	**type**\:  :py:class:`Signaling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.Vfi.Context.Autodiscovery.Bgp, self).__init__()

                            self.yang_name = "bgp"
                            self.yang_parent_name = "autodiscovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("signaling", ("signaling", Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling))])
                            self._leafs = OrderedDict()

                            self.signaling = Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling()
                            self.signaling.parent = self
                            self._children_name_map["signaling"] = "signaling"
                            self._segment_path = lambda: "bgp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.Vfi.Context.Autodiscovery.Bgp, [], name, value)


                        class Signaling(Entity):
                            """
                            Signaling protocol to use
                            
                            .. attribute:: bgp
                            
                            	Use BGP signaling and discovery
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling.Bgp_>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ldp
                            
                            	Use LDP signaling
                            	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling.Ldp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling, self).__init__()

                                self.yang_name = "signaling"
                                self.yang_parent_name = "bgp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling.Bgp_)), ("ldp", ("ldp", Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling.Ldp))])
                                self._leafs = OrderedDict()

                                self.bgp = None
                                self._children_name_map["bgp"] = "bgp"

                                self.ldp = None
                                self._children_name_map["ldp"] = "ldp"
                                self._segment_path = lambda: "signaling"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling, [], name, value)


                            class Bgp_(Entity):
                                """
                                Use BGP signaling and discovery
                                
                                .. attribute:: template
                                
                                	Template to be used for autodiscovered pseudowires
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "signaling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('template', (YLeaf(YType.str, 'template'), ['str'])),
                                    ])
                                    self.template = None
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling.Bgp_, ['template'], name, value)


                            class Ldp(Entity):
                                """
                                Use LDP signaling
                                
                                .. attribute:: template
                                
                                	Template to be used for autodiscovered pseudowires
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling.Ldp, self).__init__()

                                    self.yang_name = "ldp"
                                    self.yang_parent_name = "signaling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('template', (YLeaf(YType.str, 'template'), ['str'])),
                                    ])
                                    self.template = None
                                    self._segment_path = lambda: "ldp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.L2vpn.Vfi.Context.Autodiscovery.Bgp.Signaling.Ldp, ['template'], name, value)


                class Vpn(Entity):
                    """
                    VPN configuration
                    
                    .. attribute:: id
                    
                    	VPN id value
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.Vfi.Context.Vpn, self).__init__()

                        self.yang_name = "vpn"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.id = None
                        self._segment_path = lambda: "vpn"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.Vfi.Context.Vpn, ['id'], name, value)


        class Xconnect(Entity):
            """
            Configure a cross connect
            
            .. attribute:: context
            
            	Layer2 VPN Context
            	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.L2vpn.Xconnect, self).__init__()

                self.yang_name = "xconnect"
                self.yang_parent_name = "l2vpn"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("context", ("context", Native.L2vpn.Xconnect.Context))])
                self._leafs = OrderedDict()

                self.context = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:xconnect"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.L2vpn.Xconnect, [], name, value)


            class Context(Entity):
                """
                Layer2 VPN Context
                
                .. attribute:: xc_name  (key)
                
                	Configure the cross connect name
                	**type**\: str
                
                .. attribute:: xc_mode_config_xconnect
                
                	
                	**type**\:  :py:class:`XcModeConfigXconnect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.L2vpn.Xconnect.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "xconnect"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['xc_name']
                    self._child_classes = OrderedDict([("xc-Mode-config-xconnect", ("xc_mode_config_xconnect", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect))])
                    self._leafs = OrderedDict([
                        ('xc_name', (YLeaf(YType.str, 'xc-name'), ['str'])),
                    ])
                    self.xc_name = None

                    self.xc_mode_config_xconnect = Native.L2vpn.Xconnect.Context.XcModeConfigXconnect()
                    self.xc_mode_config_xconnect.parent = self
                    self._children_name_map["xc_mode_config_xconnect"] = "xc-Mode-config-xconnect"
                    self._segment_path = lambda: "context" + "[xc-name='" + str(self.xc_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:xconnect/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L2vpn.Xconnect.Context, ['xc_name'], name, value)


                class XcModeConfigXconnect(Entity):
                    """
                    
                    
                    .. attribute:: description
                    
                    	Description string
                    	**type**\: str
                    
                    .. attribute:: interworking
                    
                    	Interworking options for the cross connect
                    	**type**\:  :py:class:`Interworking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Interworking>`
                    
                    .. attribute:: match
                    
                    	Set Xconnect packet matching criteria
                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Match>`
                    
                    .. attribute:: member
                    
                    	Configure the cross connect member
                    	**type**\:  :py:class:`Member <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member>`
                    
                    .. attribute:: redundancy
                    
                    	Xconnect redundancy information
                    	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Redundancy>`
                    
                    .. attribute:: remote
                    
                    	L2VPN remote peer configuration commands
                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown Xconnect
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect, self).__init__()

                        self.yang_name = "xc-Mode-config-xconnect"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interworking", ("interworking", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Interworking)), ("match", ("match", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Match)), ("member", ("member", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member)), ("redundancy", ("redundancy", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Redundancy)), ("remote", ("remote", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote))])
                        self._leafs = OrderedDict([
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.description = None
                        self.shutdown = None

                        self.interworking = Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Interworking()
                        self.interworking.parent = self
                        self._children_name_map["interworking"] = "interworking"

                        self.match = Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Match()
                        self.match.parent = self
                        self._children_name_map["match"] = "match"

                        self.member = Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member()
                        self.member.parent = self
                        self._children_name_map["member"] = "member"

                        self.redundancy = Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"

                        self.remote = Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote()
                        self.remote.parent = self
                        self._children_name_map["remote"] = "remote"
                        self._segment_path = lambda: "xc-Mode-config-xconnect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect, ['description', 'shutdown'], name, value)


                    class Interworking(Entity):
                        """
                        Interworking options for the cross connect
                        
                        .. attribute:: ethernet
                        
                        	Ethernet interworking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ip
                        
                        	IP interworking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vlan
                        
                        	VLAN interworking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Interworking, self).__init__()

                            self.yang_name = "interworking"
                            self.yang_parent_name = "xc-Mode-config-xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ethernet', (YLeaf(YType.empty, 'ethernet'), ['Empty'])),
                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                            ])
                            self.ethernet = None
                            self.ip = None
                            self.vlan = None
                            self._segment_path = lambda: "interworking"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Interworking, ['ethernet', 'ip', 'vlan'], name, value)


                    class Match(Entity):
                        """
                        Set Xconnect packet matching criteria
                        
                        .. attribute:: protocol
                        
                        	Protocol matching criterion
                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Match.Protocol>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Match, self).__init__()

                            self.yang_name = "match"
                            self.yang_parent_name = "xc-Mode-config-xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol", ("protocol", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Match.Protocol))])
                            self._leafs = OrderedDict()

                            self.protocol = Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Match.Protocol()
                            self.protocol.parent = self
                            self._children_name_map["protocol"] = "protocol"
                            self._segment_path = lambda: "match"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Match, [], name, value)


                        class Protocol(Entity):
                            """
                            Protocol matching criterion
                            
                            .. attribute:: ipv6
                            
                            	IPV6
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Match.Protocol, self).__init__()

                                self.yang_name = "protocol"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                                ])
                                self.ipv6 = None
                                self._segment_path = lambda: "protocol"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Match.Protocol, ['ipv6'], name, value)


                    class Member(Entity):
                        """
                        Configure the cross connect member
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member.Ipv4>`
                        
                        .. attribute:: interface
                        
                        	
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member.Interface>`
                        
                        .. attribute:: vlan
                        
                        	Vlan interface number
                        	**type**\: int
                        
                        	**range:** 1..4094
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member, self).__init__()

                            self.yang_name = "member"
                            self.yang_parent_name = "xc-Mode-config-xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member.Ipv4)), ("interface", ("interface", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member.Interface))])
                            self._leafs = OrderedDict([
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ])
                            self.vlan = None

                            self.ipv4 = YList(self)
                            self.interface = YList(self)
                            self._segment_path = lambda: "member"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member, ['vlan'], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	IP address of the peer
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mem_vcid
                            
                            	Enter VC ID value
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "member"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('mem_vcid', (YLeaf(YType.uint32, 'mem-vcid'), ['int'])),
                                ])
                                self.ipv4 = None
                                self.mem_vcid = None
                                self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member.Ipv4, ['ipv4', 'mem_vcid'], name, value)


                        class Interface(Entity):
                            """
                            
                            
                            .. attribute:: interface  (key)
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: group
                            
                            	Configure the cross connect member redundancy group
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: service_instance
                            
                            	Ethernet Service Instance
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "member"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ('group', (YLeaf(YType.empty, 'group'), ['Empty'])),
                                    ('service_instance', (YLeaf(YType.empty, 'service-instance'), ['Empty'])),
                                ])
                                self.interface = None
                                self.group = None
                                self.service_instance = None
                                self._segment_path = lambda: "interface" + "[interface='" + str(self.interface) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Member.Interface, ['interface', 'group', 'service_instance'], name, value)


                    class Redundancy(Entity):
                        """
                        Xconnect redundancy information
                        
                        .. attribute:: delay
                        
                        	Enable delay
                        	**type**\: int
                        
                        	**range:** 0..180
                        
                        .. attribute:: predictive
                        
                        	Switch over to backup member without waiting for UP status
                        	**type**\:  :py:class:`Predictive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Redundancy.Predictive>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Redundancy, self).__init__()

                            self.yang_name = "redundancy"
                            self.yang_parent_name = "xc-Mode-config-xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("predictive", ("predictive", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Redundancy.Predictive))])
                            self._leafs = OrderedDict([
                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                            ])
                            self.delay = None

                            self.predictive = Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Redundancy.Predictive()
                            self.predictive.parent = self
                            self._children_name_map["predictive"] = "predictive"
                            self._segment_path = lambda: "redundancy"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Redundancy, ['delay'], name, value)


                        class Predictive(Entity):
                            """
                            Switch over to backup member without waiting for UP status
                            
                            .. attribute:: disabled
                            
                            	Disable predictive switchover capability for this xconnect
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: enabled
                            
                            	Enable predictive switchover capability for this xconnect
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Redundancy.Predictive, self).__init__()

                                self.yang_name = "predictive"
                                self.yang_parent_name = "redundancy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('disabled', (YLeaf(YType.empty, 'disabled'), ['Empty'])),
                                    ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                                ])
                                self.disabled = None
                                self.enabled = None
                                self._segment_path = lambda: "predictive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Redundancy.Predictive, ['disabled', 'enabled'], name, value)


                    class Remote(Entity):
                        """
                        L2VPN remote peer configuration commands
                        
                        .. attribute:: circuit
                        
                        	Remote peer circuit configuration
                        	**type**\:  :py:class:`Circuit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote.Circuit>`
                        
                        .. attribute:: link
                        
                        	Link information
                        	**type**\:  :py:class:`Link <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote.Link>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote, self).__init__()

                            self.yang_name = "remote"
                            self.yang_parent_name = "xc-Mode-config-xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("circuit", ("circuit", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote.Circuit)), ("link", ("link", Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote.Link))])
                            self._leafs = OrderedDict()

                            self.circuit = Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote.Circuit()
                            self.circuit.parent = self
                            self._children_name_map["circuit"] = "circuit"

                            self.link = Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote.Link()
                            self.link.parent = self
                            self._children_name_map["link"] = "link"
                            self._segment_path = lambda: "remote"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote, [], name, value)


                        class Circuit(Entity):
                            """
                            Remote peer circuit configuration
                            
                            .. attribute:: id
                            
                            	Remote peer circuit ID
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote.Circuit, self).__init__()

                                self.yang_name = "circuit"
                                self.yang_parent_name = "remote"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.empty, 'id'), ['Empty'])),
                                ])
                                self.id = None
                                self._segment_path = lambda: "circuit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote.Circuit, ['id'], name, value)


                        class Link(Entity):
                            """
                            Link information
                            
                            .. attribute:: failure
                            
                            	Failure information
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote.Link, self).__init__()

                                self.yang_name = "link"
                                self.yang_parent_name = "remote"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('failure', (YLeaf(YType.empty, 'failure'), ['Empty'])),
                                ])
                                self.failure = None
                                self._segment_path = lambda: "link"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.Xconnect.Context.XcModeConfigXconnect.Remote.Link, ['failure'], name, value)


        class EvpnCont(Entity):
            """
            
            
            .. attribute:: evpn
            
            	Ethernet Virtual Private Network (EVPN) configuration
            	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn>`
            
            .. attribute:: evpn_instance
            
            	
            	**type**\:  :py:class:`EvpnInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance>`
            
            

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.L2vpn.EvpnCont, self).__init__()

                self.yang_name = "evpn_cont"
                self.yang_parent_name = "l2vpn"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("evpn", ("evpn", Native.L2vpn.EvpnCont.Evpn)), ("evpn-instance", ("evpn_instance", Native.L2vpn.EvpnCont.EvpnInstance))])
                self._leafs = OrderedDict()

                self.evpn = Native.L2vpn.EvpnCont.Evpn()
                self.evpn.parent = self
                self._children_name_map["evpn"] = "evpn"

                self.evpn_instance = Native.L2vpn.EvpnCont.EvpnInstance()
                self.evpn_instance.parent = self
                self._children_name_map["evpn_instance"] = "evpn-instance"
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:evpn_cont"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.L2vpn.EvpnCont, [], name, value)


            class Evpn(Entity):
                """
                Ethernet Virtual Private Network (EVPN) configuration
                
                .. attribute:: replication_type
                
                	Specify method for replicating BUM traffic
                	**type**\:  :py:class:`ReplicationType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.ReplicationType>`
                
                .. attribute:: arp
                
                	arp parameters
                	**type**\:  :py:class:`Arp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.Arp>`
                
                .. attribute:: mac
                
                	MAC parameters
                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.Mac>`
                
                .. attribute:: ip
                
                	IP parameters
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.Ip>`
                
                .. attribute:: mpls
                
                	MPLS label config
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.Mpls>`
                
                .. attribute:: multihoming
                
                	Evpn multihoming config
                	**type**\:  :py:class:`Multihoming <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.Multihoming>`
                
                .. attribute:: router_id
                
                	Select interface to prefer for evpn router\-id
                	**type**\:  :py:class:`RouterId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.RouterId>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.L2vpn.EvpnCont.Evpn, self).__init__()

                    self.yang_name = "evpn"
                    self.yang_parent_name = "evpn_cont"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("replication-type", ("replication_type", Native.L2vpn.EvpnCont.Evpn.ReplicationType)), ("arp", ("arp", Native.L2vpn.EvpnCont.Evpn.Arp)), ("mac", ("mac", Native.L2vpn.EvpnCont.Evpn.Mac)), ("ip", ("ip", Native.L2vpn.EvpnCont.Evpn.Ip)), ("mpls", ("mpls", Native.L2vpn.EvpnCont.Evpn.Mpls)), ("multihoming", ("multihoming", Native.L2vpn.EvpnCont.Evpn.Multihoming)), ("router-id", ("router_id", Native.L2vpn.EvpnCont.Evpn.RouterId))])
                    self._leafs = OrderedDict()

                    self.replication_type = Native.L2vpn.EvpnCont.Evpn.ReplicationType()
                    self.replication_type.parent = self
                    self._children_name_map["replication_type"] = "replication-type"

                    self.arp = Native.L2vpn.EvpnCont.Evpn.Arp()
                    self.arp.parent = self
                    self._children_name_map["arp"] = "arp"

                    self.mac = Native.L2vpn.EvpnCont.Evpn.Mac()
                    self.mac.parent = self
                    self._children_name_map["mac"] = "mac"

                    self.ip = Native.L2vpn.EvpnCont.Evpn.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.mpls = Native.L2vpn.EvpnCont.Evpn.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"

                    self.multihoming = Native.L2vpn.EvpnCont.Evpn.Multihoming()
                    self.multihoming.parent = self
                    self._children_name_map["multihoming"] = "multihoming"

                    self.router_id = Native.L2vpn.EvpnCont.Evpn.RouterId()
                    self.router_id.parent = self
                    self._children_name_map["router_id"] = "router-id"
                    self._segment_path = lambda: "evpn"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L2vpn.EvpnCont.Evpn, [], name, value)


                class ReplicationType(Entity):
                    """
                    Specify method for replicating BUM traffic
                    
                    .. attribute:: ingress
                    
                    	Ingress replication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: static
                    
                    	Static replication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: p2mp
                    
                    	p2mp replication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mp2mp
                    
                    	mp2mp replication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.EvpnCont.Evpn.ReplicationType, self).__init__()

                        self.yang_name = "replication-type"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                            ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                            ('p2mp', (YLeaf(YType.empty, 'p2mp'), ['Empty'])),
                            ('mp2mp', (YLeaf(YType.empty, 'mp2mp'), ['Empty'])),
                        ])
                        self.ingress = None
                        self.static = None
                        self.p2mp = None
                        self.mp2mp = None
                        self._segment_path = lambda: "replication-type"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.ReplicationType, ['ingress', 'static', 'p2mp', 'mp2mp'], name, value)


                class Arp(Entity):
                    """
                    arp parameters
                    
                    .. attribute:: flooding_suppression
                    
                    	
                    	**type**\:  :py:class:`FloodingSuppression <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.Arp.FloodingSuppression>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.EvpnCont.Evpn.Arp, self).__init__()

                        self.yang_name = "arp"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("flooding-suppression", ("flooding_suppression", Native.L2vpn.EvpnCont.Evpn.Arp.FloodingSuppression))])
                        self._leafs = OrderedDict()

                        self.flooding_suppression = Native.L2vpn.EvpnCont.Evpn.Arp.FloodingSuppression()
                        self.flooding_suppression.parent = self
                        self._children_name_map["flooding_suppression"] = "flooding-suppression"
                        self._segment_path = lambda: "arp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.Arp, [], name, value)


                    class FloodingSuppression(Entity):
                        """
                        
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.EvpnCont.Evpn.Arp.FloodingSuppression, self).__init__()

                            self.yang_name = "flooding-suppression"
                            self.yang_parent_name = "arp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "flooding-suppression"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/arp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.Arp.FloodingSuppression, ['disable'], name, value)


                class Mac(Entity):
                    """
                    MAC parameters
                    
                    .. attribute:: duplication
                    
                    	MAC duplication detection
                    	**type**\:  :py:class:`Duplication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.Mac.Duplication>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.EvpnCont.Evpn.Mac, self).__init__()

                        self.yang_name = "mac"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("duplication", ("duplication", Native.L2vpn.EvpnCont.Evpn.Mac.Duplication))])
                        self._leafs = OrderedDict()

                        self.duplication = Native.L2vpn.EvpnCont.Evpn.Mac.Duplication()
                        self.duplication.parent = self
                        self._children_name_map["duplication"] = "duplication"
                        self._segment_path = lambda: "mac"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.Mac, [], name, value)


                    class Duplication(Entity):
                        """
                        MAC duplication detection
                        
                        .. attribute:: limit
                        
                        	Number of MAC moves within specified time interval
                        	**type**\: int
                        
                        	**range:** 2..1000
                        
                        .. attribute:: time
                        
                        	MAC duplication timer
                        	**type**\: int
                        
                        	**range:** 10..36000
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.EvpnCont.Evpn.Mac.Duplication, self).__init__()

                            self.yang_name = "duplication"
                            self.yang_parent_name = "mac"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint16, 'limit'), ['int'])),
                                ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                            ])
                            self.limit = None
                            self.time = None
                            self._segment_path = lambda: "duplication"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/mac/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.Mac.Duplication, ['limit', 'time'], name, value)


                class Ip(Entity):
                    """
                    IP parameters
                    
                    .. attribute:: duplication
                    
                    	IP duplication detection
                    	**type**\:  :py:class:`Duplication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.Ip.Duplication>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.EvpnCont.Evpn.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("duplication", ("duplication", Native.L2vpn.EvpnCont.Evpn.Ip.Duplication))])
                        self._leafs = OrderedDict()

                        self.duplication = Native.L2vpn.EvpnCont.Evpn.Ip.Duplication()
                        self.duplication.parent = self
                        self._children_name_map["duplication"] = "duplication"
                        self._segment_path = lambda: "ip"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.Ip, [], name, value)


                    class Duplication(Entity):
                        """
                        IP duplication detection
                        
                        .. attribute:: limit
                        
                        	Number of IP moves within specified time interval
                        	**type**\: int
                        
                        	**range:** 2..1000
                        
                        .. attribute:: time
                        
                        	IP duplication timer
                        	**type**\: int
                        
                        	**range:** 10..36000
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.EvpnCont.Evpn.Ip.Duplication, self).__init__()

                            self.yang_name = "duplication"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint16, 'limit'), ['int'])),
                                ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                            ])
                            self.limit = None
                            self.time = None
                            self._segment_path = lambda: "duplication"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/ip/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.Ip.Duplication, ['limit', 'time'], name, value)


                class Mpls(Entity):
                    """
                    MPLS label config
                    
                    .. attribute:: label
                    
                    	
                    	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.Mpls.Label>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.EvpnCont.Evpn.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("label", ("label", Native.L2vpn.EvpnCont.Evpn.Mpls.Label))])
                        self._leafs = OrderedDict()

                        self.label = Native.L2vpn.EvpnCont.Evpn.Mpls.Label()
                        self.label.parent = self
                        self._children_name_map["label"] = "label"
                        self._segment_path = lambda: "mpls"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.Mpls, [], name, value)


                    class Label(Entity):
                        """
                        
                        
                        .. attribute:: mode
                        
                        	
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.Mpls.Label.Mode>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.EvpnCont.Evpn.Mpls.Label, self).__init__()

                            self.yang_name = "label"
                            self.yang_parent_name = "mpls"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mode", ("mode", Native.L2vpn.EvpnCont.Evpn.Mpls.Label.Mode))])
                            self._leafs = OrderedDict()

                            self.mode = Native.L2vpn.EvpnCont.Evpn.Mpls.Label.Mode()
                            self.mode.parent = self
                            self._children_name_map["mode"] = "mode"
                            self._segment_path = lambda: "label"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/mpls/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.Mpls.Label, [], name, value)


                        class Mode(Entity):
                            """
                            
                            
                            .. attribute:: per_ce
                            
                            	Allocate one MPLS label per Customer Edge device
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: per_evi
                            
                            	Allocate one MPLS label per EVPN Instance
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: per_bd
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.EvpnCont.Evpn.Mpls.Label.Mode, self).__init__()

                                self.yang_name = "mode"
                                self.yang_parent_name = "label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('per_ce', (YLeaf(YType.empty, 'per-ce'), ['Empty'])),
                                    ('per_evi', (YLeaf(YType.empty, 'per-evi'), ['Empty'])),
                                    ('per_bd', (YLeaf(YType.empty, 'per-bd'), ['Empty'])),
                                ])
                                self.per_ce = None
                                self.per_evi = None
                                self.per_bd = None
                                self._segment_path = lambda: "mode"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/mpls/label/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.Mpls.Label.Mode, ['per_ce', 'per_evi', 'per_bd'], name, value)


                class Multihoming(Entity):
                    """
                    Evpn multihoming config
                    
                    .. attribute:: aliasing
                    
                    	
                    	**type**\:  :py:class:`Aliasing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.Multihoming.Aliasing>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.EvpnCont.Evpn.Multihoming, self).__init__()

                        self.yang_name = "multihoming"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aliasing", ("aliasing", Native.L2vpn.EvpnCont.Evpn.Multihoming.Aliasing))])
                        self._leafs = OrderedDict()

                        self.aliasing = Native.L2vpn.EvpnCont.Evpn.Multihoming.Aliasing()
                        self.aliasing.parent = self
                        self._children_name_map["aliasing"] = "aliasing"
                        self._segment_path = lambda: "multihoming"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.Multihoming, [], name, value)


                    class Aliasing(Entity):
                        """
                        
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.EvpnCont.Evpn.Multihoming.Aliasing, self).__init__()

                            self.yang_name = "aliasing"
                            self.yang_parent_name = "multihoming"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "aliasing"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/multihoming/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.Multihoming.Aliasing, ['disable'], name, value)


                class RouterId(Entity):
                    """
                    Select interface to prefer for evpn router\-id
                    
                    .. attribute:: interface
                    
                    	
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.RouterId.Interface>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.EvpnCont.Evpn.RouterId, self).__init__()

                        self.yang_name = "router-id"
                        self.yang_parent_name = "evpn"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Native.L2vpn.EvpnCont.Evpn.RouterId.Interface))])
                        self._leafs = OrderedDict()

                        self.interface = Native.L2vpn.EvpnCont.Evpn.RouterId.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._segment_path = lambda: "router-id"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.RouterId, [], name, value)


                    class Interface(Entity):
                        """
                        
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.EvpnCont.Evpn.RouterId.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "router-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/router-id/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.RouterId.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/router-id/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/router-id/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/router-id/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn/router-id/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.EvpnCont.Evpn.RouterId.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


            class EvpnInstance(Entity):
                """
                
                
                .. attribute:: evpn
                
                	
                	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.L2vpn.EvpnCont.EvpnInstance, self).__init__()

                    self.yang_name = "evpn-instance"
                    self.yang_parent_name = "evpn_cont"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("evpn", ("evpn", Native.L2vpn.EvpnCont.EvpnInstance.Evpn))])
                    self._leafs = OrderedDict()

                    self.evpn = Native.L2vpn.EvpnCont.EvpnInstance.Evpn()
                    self.evpn.parent = self
                    self._children_name_map["evpn"] = "evpn"
                    self._segment_path = lambda: "evpn-instance"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance, [], name, value)


                class Evpn(Entity):
                    """
                    
                    
                    .. attribute:: instance
                    
                    	
                    	**type**\:  :py:class:`Instance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn, self).__init__()

                        self.yang_name = "evpn"
                        self.yang_parent_name = "evpn-instance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("instance", ("instance", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance))])
                        self._leafs = OrderedDict()

                        self.instance = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance()
                        self.instance.parent = self
                        self._children_name_map["instance"] = "instance"
                        self._segment_path = lambda: "evpn"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn-instance/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn, [], name, value)


                    class Instance(Entity):
                        """
                        
                        
                        .. attribute:: instance
                        
                        	evpn instance
                        	**type**\: list of  		 :py:class:`Instance_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_>`
                        
                        

                        """

                        _prefix = 'ios-l2vpn'
                        _revision = '2018-02-13'

                        def __init__(self):
                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance, self).__init__()

                            self.yang_name = "instance"
                            self.yang_parent_name = "evpn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("instance", ("instance", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_))])
                            self._leafs = OrderedDict()

                            self.instance = YList(self)
                            self._segment_path = lambda: "instance"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn-instance/evpn/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance, [], name, value)


                        class Instance_(Entity):
                            """
                            evpn instance
                            
                            .. attribute:: evpn_instance_num  (key)
                            
                            	evpn instance number
                            	**type**\: str
                            
                            .. attribute:: point_to_point
                            
                            	
                            	**type**\:  :py:class:`PointToPoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: vlan_aware
                            
                            	
                            	**type**\:  :py:class:`VlanAware <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: vlan_based
                            
                            	
                            	**type**\:  :py:class:`VlanBased <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: vlan_bundle
                            
                            	
                            	**type**\:  :py:class:`VlanBundle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-l2vpn'
                            _revision = '2018-02-13'

                            def __init__(self):
                                super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_, self).__init__()

                                self.yang_name = "instance"
                                self.yang_parent_name = "instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['evpn_instance_num']
                                self._child_classes = OrderedDict([("point-to-point", ("point_to_point", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint)), ("vlan-aware", ("vlan_aware", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware)), ("vlan-based", ("vlan_based", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased)), ("vlan-bundle", ("vlan_bundle", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle))])
                                self._leafs = OrderedDict([
                                    ('evpn_instance_num', (YLeaf(YType.str, 'evpn-instance-num'), ['str'])),
                                ])
                                self.evpn_instance_num = None

                                self.point_to_point = None
                                self._children_name_map["point_to_point"] = "point-to-point"

                                self.vlan_aware = None
                                self._children_name_map["vlan_aware"] = "vlan-aware"

                                self.vlan_based = None
                                self._children_name_map["vlan_based"] = "vlan-based"

                                self.vlan_bundle = None
                                self._children_name_map["vlan_bundle"] = "vlan-bundle"
                                self._segment_path = lambda: "instance" + "[evpn-instance-num='" + str(self.evpn_instance_num) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn/Cisco-IOS-XE-l2vpn:evpn_cont/evpn-instance/evpn/instance/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_, ['evpn_instance_num'], name, value)


                            class PointToPoint(Entity):
                                """
                                
                                
                                .. attribute:: encapsulation
                                
                                	Data encapsulation method
                                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.Encapsulation>`
                                
                                .. attribute:: auto_route_target_cont
                                
                                	
                                	**type**\:  :py:class:`AutoRouteTargetCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.AutoRouteTargetCont>`
                                
                                .. attribute:: rd
                                
                                	EVPN Route Distinguisher
                                	**type**\:  :py:class:`Rd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.Rd>`
                                
                                .. attribute:: route_target
                                
                                	Route Target VPN Extended Communities
                                	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint, self).__init__()

                                    self.yang_name = "point-to-point"
                                    self.yang_parent_name = "instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto-route-target_cont", ("auto_route_target_cont", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.AutoRouteTargetCont)), ("rd", ("rd", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.Rd)), ("route-target", ("route_target", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.Encapsulation')])),
                                    ])
                                    self.encapsulation = None

                                    self.auto_route_target_cont = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.AutoRouteTargetCont()
                                    self.auto_route_target_cont.parent = self
                                    self._children_name_map["auto_route_target_cont"] = "auto-route-target_cont"

                                    self.rd = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.Rd()
                                    self.rd.parent = self
                                    self._children_name_map["rd"] = "rd"

                                    self.route_target = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget()
                                    self.route_target.parent = self
                                    self._children_name_map["route_target"] = "route-target"
                                    self._segment_path = lambda: "point-to-point"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint, ['encapsulation'], name, value)

                                class Encapsulation(Enum):
                                    """
                                    Encapsulation (Enum Class)

                                    Data encapsulation method

                                    .. data:: vxlan = 0

                                    .. data:: mpls = 1

                                    """

                                    vxlan = Enum.YLeaf(0, "vxlan")

                                    mpls = Enum.YLeaf(1, "mpls")



                                class AutoRouteTargetCont(Entity):
                                    """
                                    
                                    
                                    .. attribute:: auto_route_target
                                    
                                    	Automatically set a route\-target
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.AutoRouteTargetCont, self).__init__()

                                        self.yang_name = "auto-route-target_cont"
                                        self.yang_parent_name = "point-to-point"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auto_route_target', (YLeaf(YType.empty, 'auto-route-target'), ['Empty'])),
                                        ])
                                        self.auto_route_target = None
                                        self._segment_path = lambda: "auto-route-target_cont"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.AutoRouteTargetCont, ['auto_route_target'], name, value)


                                class Rd(Entity):
                                    """
                                    EVPN Route Distinguisher
                                    
                                    .. attribute:: rd_value
                                    
                                    	ASN\:nn or IP\-address\:nn
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.Rd, self).__init__()

                                        self.yang_name = "rd"
                                        self.yang_parent_name = "point-to-point"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rd_value', (YLeaf(YType.str, 'rd-value'), ['str'])),
                                        ])
                                        self.rd_value = None
                                        self._segment_path = lambda: "rd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.Rd, ['rd_value'], name, value)


                                class RouteTarget(Entity):
                                    """
                                    Route Target VPN Extended Communities
                                    
                                    .. attribute:: rt_value
                                    
                                    	ASN\:nn or IP\-address\:nn
                                    	**type**\: str
                                    
                                    .. attribute:: both
                                    
                                    	Both import and export Target\-VPN community
                                    	**type**\:  :py:class:`Both <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Both>`
                                    
                                    .. attribute:: export
                                    
                                    	
                                    	**type**\:  :py:class:`Export <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Export>`
                                    
                                    .. attribute:: import_
                                    
                                    	Import Target\-VPN community
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Import>`
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget, self).__init__()

                                        self.yang_name = "route-target"
                                        self.yang_parent_name = "point-to-point"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("both", ("both", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Both)), ("export", ("export", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Export)), ("import", ("import_", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Import))])
                                        self._leafs = OrderedDict([
                                            ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                        ])
                                        self.rt_value = None

                                        self.both = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Both()
                                        self.both.parent = self
                                        self._children_name_map["both"] = "both"

                                        self.export = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Export()
                                        self.export.parent = self
                                        self._children_name_map["export"] = "export"

                                        self.import_ = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"
                                        self._segment_path = lambda: "route-target"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget, ['rt_value'], name, value)


                                    class Both(Entity):
                                        """
                                        Both import and export Target\-VPN community
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Both, self).__init__()

                                            self.yang_name = "both"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "both"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Both, ['rt_value'], name, value)


                                    class Export(Entity):
                                        """
                                        
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Export, self).__init__()

                                            self.yang_name = "export"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Export, ['rt_value'], name, value)


                                    class Import(Entity):
                                        """
                                        Import Target\-VPN community
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.PointToPoint.RouteTarget.Import, ['rt_value'], name, value)


                            class VlanAware(Entity):
                                """
                                
                                
                                .. attribute:: encapsulation
                                
                                	Data encapsulation method
                                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.Encapsulation>`
                                
                                .. attribute:: auto_route_target_cont
                                
                                	
                                	**type**\:  :py:class:`AutoRouteTargetCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.AutoRouteTargetCont>`
                                
                                .. attribute:: rd
                                
                                	EVPN Route Distinguisher
                                	**type**\:  :py:class:`Rd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.Rd>`
                                
                                .. attribute:: route_target
                                
                                	Route Target VPN Extended Communities
                                	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware, self).__init__()

                                    self.yang_name = "vlan-aware"
                                    self.yang_parent_name = "instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto-route-target_cont", ("auto_route_target_cont", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.AutoRouteTargetCont)), ("rd", ("rd", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.Rd)), ("route-target", ("route_target", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.Encapsulation')])),
                                    ])
                                    self.encapsulation = None

                                    self.auto_route_target_cont = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.AutoRouteTargetCont()
                                    self.auto_route_target_cont.parent = self
                                    self._children_name_map["auto_route_target_cont"] = "auto-route-target_cont"

                                    self.rd = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.Rd()
                                    self.rd.parent = self
                                    self._children_name_map["rd"] = "rd"

                                    self.route_target = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget()
                                    self.route_target.parent = self
                                    self._children_name_map["route_target"] = "route-target"
                                    self._segment_path = lambda: "vlan-aware"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware, ['encapsulation'], name, value)

                                class Encapsulation(Enum):
                                    """
                                    Encapsulation (Enum Class)

                                    Data encapsulation method

                                    .. data:: vxlan = 0

                                    .. data:: mpls = 1

                                    """

                                    vxlan = Enum.YLeaf(0, "vxlan")

                                    mpls = Enum.YLeaf(1, "mpls")



                                class AutoRouteTargetCont(Entity):
                                    """
                                    
                                    
                                    .. attribute:: auto_route_target
                                    
                                    	Automatically set a route\-target
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.AutoRouteTargetCont, self).__init__()

                                        self.yang_name = "auto-route-target_cont"
                                        self.yang_parent_name = "vlan-aware"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auto_route_target', (YLeaf(YType.empty, 'auto-route-target'), ['Empty'])),
                                        ])
                                        self.auto_route_target = None
                                        self._segment_path = lambda: "auto-route-target_cont"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.AutoRouteTargetCont, ['auto_route_target'], name, value)


                                class Rd(Entity):
                                    """
                                    EVPN Route Distinguisher
                                    
                                    .. attribute:: rd_value
                                    
                                    	ASN\:nn or IP\-address\:nn
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.Rd, self).__init__()

                                        self.yang_name = "rd"
                                        self.yang_parent_name = "vlan-aware"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rd_value', (YLeaf(YType.str, 'rd-value'), ['str'])),
                                        ])
                                        self.rd_value = None
                                        self._segment_path = lambda: "rd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.Rd, ['rd_value'], name, value)


                                class RouteTarget(Entity):
                                    """
                                    Route Target VPN Extended Communities
                                    
                                    .. attribute:: rt_value
                                    
                                    	ASN\:nn or IP\-address\:nn
                                    	**type**\: str
                                    
                                    .. attribute:: both
                                    
                                    	Both import and export Target\-VPN community
                                    	**type**\:  :py:class:`Both <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Both>`
                                    
                                    .. attribute:: export
                                    
                                    	
                                    	**type**\:  :py:class:`Export <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Export>`
                                    
                                    .. attribute:: import_
                                    
                                    	Import Target\-VPN community
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Import>`
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget, self).__init__()

                                        self.yang_name = "route-target"
                                        self.yang_parent_name = "vlan-aware"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("both", ("both", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Both)), ("export", ("export", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Export)), ("import", ("import_", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Import))])
                                        self._leafs = OrderedDict([
                                            ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                        ])
                                        self.rt_value = None

                                        self.both = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Both()
                                        self.both.parent = self
                                        self._children_name_map["both"] = "both"

                                        self.export = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Export()
                                        self.export.parent = self
                                        self._children_name_map["export"] = "export"

                                        self.import_ = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"
                                        self._segment_path = lambda: "route-target"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget, ['rt_value'], name, value)


                                    class Both(Entity):
                                        """
                                        Both import and export Target\-VPN community
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Both, self).__init__()

                                            self.yang_name = "both"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "both"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Both, ['rt_value'], name, value)


                                    class Export(Entity):
                                        """
                                        
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Export, self).__init__()

                                            self.yang_name = "export"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Export, ['rt_value'], name, value)


                                    class Import(Entity):
                                        """
                                        Import Target\-VPN community
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanAware.RouteTarget.Import, ['rt_value'], name, value)


                            class VlanBased(Entity):
                                """
                                
                                
                                .. attribute:: encapsulation
                                
                                	Data encapsulation method
                                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.Encapsulation>`
                                
                                .. attribute:: auto_route_target_cont
                                
                                	
                                	**type**\:  :py:class:`AutoRouteTargetCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.AutoRouteTargetCont>`
                                
                                .. attribute:: rd
                                
                                	EVPN Route Distinguisher
                                	**type**\:  :py:class:`Rd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.Rd>`
                                
                                .. attribute:: route_target
                                
                                	Route Target VPN Extended Communities
                                	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased, self).__init__()

                                    self.yang_name = "vlan-based"
                                    self.yang_parent_name = "instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto-route-target_cont", ("auto_route_target_cont", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.AutoRouteTargetCont)), ("rd", ("rd", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.Rd)), ("route-target", ("route_target", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.Encapsulation')])),
                                    ])
                                    self.encapsulation = None

                                    self.auto_route_target_cont = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.AutoRouteTargetCont()
                                    self.auto_route_target_cont.parent = self
                                    self._children_name_map["auto_route_target_cont"] = "auto-route-target_cont"

                                    self.rd = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.Rd()
                                    self.rd.parent = self
                                    self._children_name_map["rd"] = "rd"

                                    self.route_target = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget()
                                    self.route_target.parent = self
                                    self._children_name_map["route_target"] = "route-target"
                                    self._segment_path = lambda: "vlan-based"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased, ['encapsulation'], name, value)

                                class Encapsulation(Enum):
                                    """
                                    Encapsulation (Enum Class)

                                    Data encapsulation method

                                    .. data:: vxlan = 0

                                    .. data:: mpls = 1

                                    """

                                    vxlan = Enum.YLeaf(0, "vxlan")

                                    mpls = Enum.YLeaf(1, "mpls")



                                class AutoRouteTargetCont(Entity):
                                    """
                                    
                                    
                                    .. attribute:: auto_route_target
                                    
                                    	Automatically set a route\-target
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.AutoRouteTargetCont, self).__init__()

                                        self.yang_name = "auto-route-target_cont"
                                        self.yang_parent_name = "vlan-based"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auto_route_target', (YLeaf(YType.empty, 'auto-route-target'), ['Empty'])),
                                        ])
                                        self.auto_route_target = None
                                        self._segment_path = lambda: "auto-route-target_cont"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.AutoRouteTargetCont, ['auto_route_target'], name, value)


                                class Rd(Entity):
                                    """
                                    EVPN Route Distinguisher
                                    
                                    .. attribute:: rd_value
                                    
                                    	ASN\:nn or IP\-address\:nn
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.Rd, self).__init__()

                                        self.yang_name = "rd"
                                        self.yang_parent_name = "vlan-based"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rd_value', (YLeaf(YType.str, 'rd-value'), ['str'])),
                                        ])
                                        self.rd_value = None
                                        self._segment_path = lambda: "rd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.Rd, ['rd_value'], name, value)


                                class RouteTarget(Entity):
                                    """
                                    Route Target VPN Extended Communities
                                    
                                    .. attribute:: rt_value
                                    
                                    	ASN\:nn or IP\-address\:nn
                                    	**type**\: str
                                    
                                    .. attribute:: both
                                    
                                    	Both import and export Target\-VPN community
                                    	**type**\:  :py:class:`Both <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Both>`
                                    
                                    .. attribute:: export
                                    
                                    	
                                    	**type**\:  :py:class:`Export <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Export>`
                                    
                                    .. attribute:: import_
                                    
                                    	Import Target\-VPN community
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Import>`
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget, self).__init__()

                                        self.yang_name = "route-target"
                                        self.yang_parent_name = "vlan-based"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("both", ("both", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Both)), ("export", ("export", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Export)), ("import", ("import_", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Import))])
                                        self._leafs = OrderedDict([
                                            ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                        ])
                                        self.rt_value = None

                                        self.both = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Both()
                                        self.both.parent = self
                                        self._children_name_map["both"] = "both"

                                        self.export = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Export()
                                        self.export.parent = self
                                        self._children_name_map["export"] = "export"

                                        self.import_ = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"
                                        self._segment_path = lambda: "route-target"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget, ['rt_value'], name, value)


                                    class Both(Entity):
                                        """
                                        Both import and export Target\-VPN community
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Both, self).__init__()

                                            self.yang_name = "both"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "both"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Both, ['rt_value'], name, value)


                                    class Export(Entity):
                                        """
                                        
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Export, self).__init__()

                                            self.yang_name = "export"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Export, ['rt_value'], name, value)


                                    class Import(Entity):
                                        """
                                        Import Target\-VPN community
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBased.RouteTarget.Import, ['rt_value'], name, value)


                            class VlanBundle(Entity):
                                """
                                
                                
                                .. attribute:: encapsulation
                                
                                	Data encapsulation method
                                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.Encapsulation>`
                                
                                .. attribute:: auto_route_target_cont
                                
                                	
                                	**type**\:  :py:class:`AutoRouteTargetCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.AutoRouteTargetCont>`
                                
                                .. attribute:: rd
                                
                                	EVPN Route Distinguisher
                                	**type**\:  :py:class:`Rd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.Rd>`
                                
                                .. attribute:: route_target
                                
                                	Route Target VPN Extended Communities
                                	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-l2vpn'
                                _revision = '2018-02-13'

                                def __init__(self):
                                    super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle, self).__init__()

                                    self.yang_name = "vlan-bundle"
                                    self.yang_parent_name = "instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto-route-target_cont", ("auto_route_target_cont", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.AutoRouteTargetCont)), ("rd", ("rd", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.Rd)), ("route-target", ("route_target", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.Encapsulation')])),
                                    ])
                                    self.encapsulation = None

                                    self.auto_route_target_cont = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.AutoRouteTargetCont()
                                    self.auto_route_target_cont.parent = self
                                    self._children_name_map["auto_route_target_cont"] = "auto-route-target_cont"

                                    self.rd = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.Rd()
                                    self.rd.parent = self
                                    self._children_name_map["rd"] = "rd"

                                    self.route_target = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget()
                                    self.route_target.parent = self
                                    self._children_name_map["route_target"] = "route-target"
                                    self._segment_path = lambda: "vlan-bundle"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle, ['encapsulation'], name, value)

                                class Encapsulation(Enum):
                                    """
                                    Encapsulation (Enum Class)

                                    Data encapsulation method

                                    .. data:: vxlan = 0

                                    .. data:: mpls = 1

                                    """

                                    vxlan = Enum.YLeaf(0, "vxlan")

                                    mpls = Enum.YLeaf(1, "mpls")



                                class AutoRouteTargetCont(Entity):
                                    """
                                    
                                    
                                    .. attribute:: auto_route_target
                                    
                                    	Automatically set a route\-target
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.AutoRouteTargetCont, self).__init__()

                                        self.yang_name = "auto-route-target_cont"
                                        self.yang_parent_name = "vlan-bundle"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auto_route_target', (YLeaf(YType.empty, 'auto-route-target'), ['Empty'])),
                                        ])
                                        self.auto_route_target = None
                                        self._segment_path = lambda: "auto-route-target_cont"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.AutoRouteTargetCont, ['auto_route_target'], name, value)


                                class Rd(Entity):
                                    """
                                    EVPN Route Distinguisher
                                    
                                    .. attribute:: rd_value
                                    
                                    	ASN\:nn or IP\-address\:nn
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.Rd, self).__init__()

                                        self.yang_name = "rd"
                                        self.yang_parent_name = "vlan-bundle"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rd_value', (YLeaf(YType.str, 'rd-value'), ['str'])),
                                        ])
                                        self.rd_value = None
                                        self._segment_path = lambda: "rd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.Rd, ['rd_value'], name, value)


                                class RouteTarget(Entity):
                                    """
                                    Route Target VPN Extended Communities
                                    
                                    .. attribute:: rt_value
                                    
                                    	ASN\:nn or IP\-address\:nn
                                    	**type**\: str
                                    
                                    .. attribute:: both
                                    
                                    	Both import and export Target\-VPN community
                                    	**type**\:  :py:class:`Both <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Both>`
                                    
                                    .. attribute:: export
                                    
                                    	
                                    	**type**\:  :py:class:`Export <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Export>`
                                    
                                    .. attribute:: import_
                                    
                                    	Import Target\-VPN community
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Import>`
                                    
                                    

                                    """

                                    _prefix = 'ios-l2vpn'
                                    _revision = '2018-02-13'

                                    def __init__(self):
                                        super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget, self).__init__()

                                        self.yang_name = "route-target"
                                        self.yang_parent_name = "vlan-bundle"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("both", ("both", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Both)), ("export", ("export", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Export)), ("import", ("import_", Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Import))])
                                        self._leafs = OrderedDict([
                                            ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                        ])
                                        self.rt_value = None

                                        self.both = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Both()
                                        self.both.parent = self
                                        self._children_name_map["both"] = "both"

                                        self.export = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Export()
                                        self.export.parent = self
                                        self._children_name_map["export"] = "export"

                                        self.import_ = Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"
                                        self._segment_path = lambda: "route-target"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget, ['rt_value'], name, value)


                                    class Both(Entity):
                                        """
                                        Both import and export Target\-VPN community
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Both, self).__init__()

                                            self.yang_name = "both"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "both"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Both, ['rt_value'], name, value)


                                    class Export(Entity):
                                        """
                                        
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Export, self).__init__()

                                            self.yang_name = "export"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Export, ['rt_value'], name, value)


                                    class Import(Entity):
                                        """
                                        Import Target\-VPN community
                                        
                                        .. attribute:: rt_value
                                        
                                        	ASN\:nn or IP\-address\:nn
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-l2vpn'
                                        _revision = '2018-02-13'

                                        def __init__(self):
                                            super(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "route-target"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rt_value', (YLeaf(YType.str, 'rt-value'), ['str'])),
                                            ])
                                            self.rt_value = None
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.L2vpn.EvpnCont.EvpnInstance.Evpn.Instance.Instance_.VlanBundle.RouteTarget.Import, ['rt_value'], name, value)


    class L2vpnConfig(Entity):
        """
        
        
        .. attribute:: l2vpn
        
        	Layer2 VPN commands
        	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpnConfig.L2vpn>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.L2vpnConfig, self).__init__()

            self.yang_name = "l2vpn-config"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-l2vpn:l2vpn", ("l2vpn", Native.L2vpnConfig.L2vpn))])
            self._leafs = OrderedDict()

            self.l2vpn = None
            self._children_name_map["l2vpn"] = "Cisco-IOS-XE-l2vpn:l2vpn"
            self._segment_path = lambda: "l2vpn-config"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.L2vpnConfig, [], name, value)


        class L2vpn(Entity):
            """
            Layer2 VPN commands
            
            .. attribute:: logging
            
            	Configure logging flags
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpnConfig.L2vpn.Logging>`
            
            .. attribute:: redundancy
            
            	Configure L2VPN redundancy parameters
            	**type**\:  :py:class:`Redundancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpnConfig.L2vpn.Redundancy>`
            
            .. attribute:: router_id
            
            	Layer2 router\-id value
            	**type**\: str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: shutdown
            
            	Shutdown Layer2 VPN
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-l2vpn'
            _revision = '2018-02-13'

            def __init__(self):
                super(Native.L2vpnConfig.L2vpn, self).__init__()

                self.yang_name = "l2vpn"
                self.yang_parent_name = "l2vpn-config"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("logging", ("logging", Native.L2vpnConfig.L2vpn.Logging)), ("redundancy", ("redundancy", Native.L2vpnConfig.L2vpn.Redundancy))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                ])
                self.router_id = None
                self.shutdown = None

                self.logging = Native.L2vpnConfig.L2vpn.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.redundancy = Native.L2vpnConfig.L2vpn.Redundancy()
                self.redundancy.parent = self
                self._children_name_map["redundancy"] = "redundancy"
                self._segment_path = lambda: "Cisco-IOS-XE-l2vpn:l2vpn"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn-config/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.L2vpnConfig.L2vpn, ['router_id', 'shutdown'], name, value)


            class Logging(Entity):
                """
                Configure logging flags
                
                .. attribute:: pseudowire
                
                	pseudowire status transition logging
                	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpnConfig.L2vpn.Logging.Pseudowire>`
                
                .. attribute:: redundancy
                
                	xconnect redundancy events
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.L2vpnConfig.L2vpn.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "l2vpn"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("pseudowire", ("pseudowire", Native.L2vpnConfig.L2vpn.Logging.Pseudowire))])
                    self._leafs = OrderedDict([
                        ('redundancy', (YLeaf(YType.empty, 'redundancy'), ['Empty'])),
                    ])
                    self.redundancy = None

                    self.pseudowire = Native.L2vpnConfig.L2vpn.Logging.Pseudowire()
                    self.pseudowire.parent = self
                    self._children_name_map["pseudowire"] = "pseudowire"
                    self._segment_path = lambda: "logging"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn-config/Cisco-IOS-XE-l2vpn:l2vpn/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L2vpnConfig.L2vpn.Logging, ['redundancy'], name, value)


                class Pseudowire(Entity):
                    """
                    pseudowire status transition logging
                    
                    .. attribute:: status
                    
                    	pseudowire status up/down logging
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpnConfig.L2vpn.Logging.Pseudowire, self).__init__()

                        self.yang_name = "pseudowire"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                        ])
                        self.status = None
                        self._segment_path = lambda: "pseudowire"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn-config/Cisco-IOS-XE-l2vpn:l2vpn/logging/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpnConfig.L2vpn.Logging.Pseudowire, ['status'], name, value)


            class Redundancy(Entity):
                """
                Configure L2VPN redundancy parameters
                
                .. attribute:: predictive
                
                	Switch over to backup member without waiting for UP status
                	**type**\:  :py:class:`Predictive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2vpnConfig.L2vpn.Redundancy.Predictive>`
                
                

                """

                _prefix = 'ios-l2vpn'
                _revision = '2018-02-13'

                def __init__(self):
                    super(Native.L2vpnConfig.L2vpn.Redundancy, self).__init__()

                    self.yang_name = "redundancy"
                    self.yang_parent_name = "l2vpn"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("predictive", ("predictive", Native.L2vpnConfig.L2vpn.Redundancy.Predictive))])
                    self._leafs = OrderedDict()

                    self.predictive = Native.L2vpnConfig.L2vpn.Redundancy.Predictive()
                    self.predictive.parent = self
                    self._children_name_map["predictive"] = "predictive"
                    self._segment_path = lambda: "redundancy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn-config/Cisco-IOS-XE-l2vpn:l2vpn/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L2vpnConfig.L2vpn.Redundancy, [], name, value)


                class Predictive(Entity):
                    """
                    Switch over to backup member without waiting for UP status
                    
                    .. attribute:: enabled
                    
                    	Enable predictive switchover capability for all xconnects
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-l2vpn'
                    _revision = '2018-02-13'

                    def __init__(self):
                        super(Native.L2vpnConfig.L2vpn.Redundancy.Predictive, self).__init__()

                        self.yang_name = "predictive"
                        self.yang_parent_name = "redundancy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enabled', (YLeaf(YType.empty, 'enabled'), ['Empty'])),
                        ])
                        self.enabled = None
                        self._segment_path = lambda: "predictive"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l2vpn-config/Cisco-IOS-XE-l2vpn:l2vpn/redundancy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L2vpnConfig.L2vpn.Redundancy.Predictive, ['enabled'], name, value)


    class L3vpn(Entity):
        """
        l3vpn encapsulation ip commands
        
        .. attribute:: encapsulation
        
        	l3vpn encapsulation ip
        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L3vpn.Encapsulation>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.L3vpn, self).__init__()

            self.yang_name = "l3vpn"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-l3vpn:encapsulation", ("encapsulation", Native.L3vpn.Encapsulation))])
            self._leafs = OrderedDict()

            self.encapsulation = Native.L3vpn.Encapsulation()
            self.encapsulation.parent = self
            self._children_name_map["encapsulation"] = "Cisco-IOS-XE-l3vpn:encapsulation"
            self._segment_path = lambda: "l3vpn"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.L3vpn, [], name, value)


        class Encapsulation(Entity):
            """
            l3vpn encapsulation ip
            
            .. attribute:: ip
            
            	l3vpn encapsulation ip
            	**type**\: list of  		 :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L3vpn.Encapsulation.Ip>`
            
            

            """

            _prefix = 'ios-l3vpn'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.L3vpn.Encapsulation, self).__init__()

                self.yang_name = "encapsulation"
                self.yang_parent_name = "l3vpn"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ip", ("ip", Native.L3vpn.Encapsulation.Ip))])
                self._leafs = OrderedDict()

                self.ip = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-l3vpn:encapsulation"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l3vpn/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.L3vpn.Encapsulation, [], name, value)


            class Ip(Entity):
                """
                l3vpn encapsulation ip
                
                .. attribute:: profile_name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: transport
                
                	transport mode
                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L3vpn.Encapsulation.Ip.Transport>`
                
                .. attribute:: protocol
                
                	protocol mode
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L3vpn.Encapsulation.Ip.Protocol>`
                
                .. attribute:: mpls
                
                	Configure MPLS interface parameters
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L3vpn.Encapsulation.Ip.Mpls>`
                
                

                """

                _prefix = 'ios-l3vpn'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.L3vpn.Encapsulation.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "encapsulation"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['profile_name']
                    self._child_classes = OrderedDict([("transport", ("transport", Native.L3vpn.Encapsulation.Ip.Transport)), ("protocol", ("protocol", Native.L3vpn.Encapsulation.Ip.Protocol)), ("mpls", ("mpls", Native.L3vpn.Encapsulation.Ip.Mpls))])
                    self._leafs = OrderedDict([
                        ('profile_name', (YLeaf(YType.str, 'profile-name'), ['str'])),
                    ])
                    self.profile_name = None

                    self.transport = Native.L3vpn.Encapsulation.Ip.Transport()
                    self.transport.parent = self
                    self._children_name_map["transport"] = "transport"

                    self.protocol = Native.L3vpn.Encapsulation.Ip.Protocol()
                    self.protocol.parent = self
                    self._children_name_map["protocol"] = "protocol"

                    self.mpls = Native.L3vpn.Encapsulation.Ip.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"
                    self._segment_path = lambda: "ip" + "[profile-name='" + str(self.profile_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/l3vpn/Cisco-IOS-XE-l3vpn:encapsulation/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.L3vpn.Encapsulation.Ip, ['profile_name'], name, value)


                class Transport(Entity):
                    """
                    transport mode
                    
                    .. attribute:: ipv4
                    
                    	transport ipv4 mode
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L3vpn.Encapsulation.Ip.Transport.Ipv4>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-l3vpn'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.L3vpn.Encapsulation.Ip.Transport, self).__init__()

                        self.yang_name = "transport"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.L3vpn.Encapsulation.Ip.Transport.Ipv4))])
                        self._leafs = OrderedDict()

                        self.ipv4 = None
                        self._children_name_map["ipv4"] = "ipv4"
                        self._segment_path = lambda: "transport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L3vpn.Encapsulation.Ip.Transport, [], name, value)


                    class Ipv4(Entity):
                        """
                        transport ipv4 mode
                        
                        .. attribute:: source
                        
                        	transport source
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-l3vpn'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.L3vpn.Encapsulation.Ip.Transport.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ])
                            self.source = None
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L3vpn.Encapsulation.Ip.Transport.Ipv4, ['source'], name, value)


                class Protocol(Entity):
                    """
                    protocol mode
                    
                    .. attribute:: gre
                    
                    	protocol gre
                    	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L3vpn.Encapsulation.Ip.Protocol.Gre>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-l3vpn'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.L3vpn.Encapsulation.Ip.Protocol, self).__init__()

                        self.yang_name = "protocol"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre", ("gre", Native.L3vpn.Encapsulation.Ip.Protocol.Gre))])
                        self._leafs = OrderedDict()

                        self.gre = None
                        self._children_name_map["gre"] = "gre"
                        self._segment_path = lambda: "protocol"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L3vpn.Encapsulation.Ip.Protocol, [], name, value)


                    class Gre(Entity):
                        """
                        protocol gre
                        
                        .. attribute:: key
                        
                        	gre key
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-l3vpn'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.L3vpn.Encapsulation.Ip.Protocol.Gre, self).__init__()

                            self.yang_name = "gre"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                            ])
                            self.key = None
                            self._segment_path = lambda: "gre"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.L3vpn.Encapsulation.Ip.Protocol.Gre, ['key'], name, value)


                class Mpls(Entity):
                    """
                    Configure MPLS interface parameters
                    
                    .. attribute:: mtu
                    
                    	Set MPLS Maximum Transmission Unit
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 64..17916
                    
                    		**type**\:  :py:class:`Mtu <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L3vpn.Encapsulation.Ip.Mpls.Mtu>`
                    
                    

                    """

                    _prefix = 'ios-l3vpn'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.L3vpn.Encapsulation.Ip.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mtu', (YLeaf(YType.str, 'mtu'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'L3vpn.Encapsulation.Ip.Mpls.Mtu')])),
                        ])
                        self.mtu = None
                        self._segment_path = lambda: "mpls"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.L3vpn.Encapsulation.Ip.Mpls, ['mtu'], name, value)

                    class Mtu(Enum):
                        """
                        Mtu (Enum Class)

                        Set MPLS Maximum Transmission Unit

                        .. data:: max = 0

                        """

                        max = Enum.YLeaf(0, "max")



    class Mpls(Entity):
        """
        Configure MPLS parameters
        
        .. attribute:: atm
        
        	Configure ATM options
        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Atm>`
        
        .. attribute:: cos_map
        
        	Configure MPLS CoS ATM Multi\-VC CoS Map
        	**type**\: int
        
        	**range:** 1..255
        
        .. attribute:: ip
        
        	Dynamic MPLS forwarding for IP
        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ip>`
        
        .. attribute:: label
        
        	Label properties
        	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label>`
        
        .. attribute:: ldp
        
        	Label Distribution Protocol
        	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp>`
        
        .. attribute:: prefix_map
        
        	Configure MPLS CoS Tag\-VC Multi\-VC Prefix Map
        	**type**\:  :py:class:`PrefixMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.PrefixMap>`
        
        .. attribute:: static
        
        	MPLS static application
        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Static>`
        
        	**presence node**\: True
        
        .. attribute:: traffic_eng
        
        	Configure Traffic Engineering parameters
        	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng>`
        
        .. attribute:: tp
        
        	Configure MPLS Transport Profile parameters
        	**type**\:  :py:class:`Tp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Tp>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Mpls, self).__init__()

            self.yang_name = "mpls"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-mpls:atm", ("atm", Native.Mpls.Atm)), ("Cisco-IOS-XE-mpls:ip", ("ip", Native.Mpls.Ip)), ("Cisco-IOS-XE-mpls:label", ("label", Native.Mpls.Label)), ("Cisco-IOS-XE-mpls:ldp", ("ldp", Native.Mpls.Ldp)), ("Cisco-IOS-XE-mpls:prefix-map", ("prefix_map", Native.Mpls.PrefixMap)), ("Cisco-IOS-XE-mpls:static", ("static", Native.Mpls.Static)), ("Cisco-IOS-XE-mpls:traffic-eng", ("traffic_eng", Native.Mpls.TrafficEng)), ("Cisco-IOS-XE-mpls:tp", ("tp", Native.Mpls.Tp))])
            self._leafs = OrderedDict([
                ('cos_map', (YLeaf(YType.uint8, 'Cisco-IOS-XE-mpls:cos-map'), ['int'])),
            ])
            self.cos_map = None

            self.atm = Native.Mpls.Atm()
            self.atm.parent = self
            self._children_name_map["atm"] = "Cisco-IOS-XE-mpls:atm"

            self.ip = Native.Mpls.Ip()
            self.ip.parent = self
            self._children_name_map["ip"] = "Cisco-IOS-XE-mpls:ip"

            self.label = Native.Mpls.Label()
            self.label.parent = self
            self._children_name_map["label"] = "Cisco-IOS-XE-mpls:label"

            self.ldp = Native.Mpls.Ldp()
            self.ldp.parent = self
            self._children_name_map["ldp"] = "Cisco-IOS-XE-mpls:ldp"

            self.prefix_map = Native.Mpls.PrefixMap()
            self.prefix_map.parent = self
            self._children_name_map["prefix_map"] = "Cisco-IOS-XE-mpls:prefix-map"

            self.static = None
            self._children_name_map["static"] = "Cisco-IOS-XE-mpls:static"

            self.traffic_eng = Native.Mpls.TrafficEng()
            self.traffic_eng.parent = self
            self._children_name_map["traffic_eng"] = "Cisco-IOS-XE-mpls:traffic-eng"

            self.tp = None
            self._children_name_map["tp"] = "Cisco-IOS-XE-mpls:tp"
            self._segment_path = lambda: "mpls"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Mpls, [u'cos_map'], name, value)


        class Atm(Entity):
            """
            Configure ATM options
            
            .. attribute:: disable_headend_vc
            
            	Dedicated lsc capability\: In this mode headend Tag VCs are disabled
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-mpls'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Mpls.Atm, self).__init__()

                self.yang_name = "atm"
                self.yang_parent_name = "mpls"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('disable_headend_vc', (YLeaf(YType.empty, 'disable-headend-vc'), ['Empty'])),
                ])
                self.disable_headend_vc = None
                self._segment_path = lambda: "Cisco-IOS-XE-mpls:atm"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mpls.Atm, [u'disable_headend_vc'], name, value)


        class Ip(Entity):
            """
            Dynamic MPLS forwarding for IP
            
            .. attribute:: default_route
            
            	Allow MPLS forwarding for ip default route
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: conf
            
            	
            	**type**\:  :py:class:`Conf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ip.Conf>`
            
            .. attribute:: conf_arg
            
            	
            	**type**\:  :py:class:`ConfArg <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ip.ConfArg>`
            
            .. attribute:: ttl_expiration
            
            	Control MPLS TTL expiration behavior
            	**type**\:  :py:class:`TtlExpiration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ip.TtlExpiration>`
            
            

            """

            _prefix = 'ios-mpls'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Mpls.Ip, self).__init__()

                self.yang_name = "ip"
                self.yang_parent_name = "mpls"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("conf", ("conf", Native.Mpls.Ip.Conf)), ("conf-arg", ("conf_arg", Native.Mpls.Ip.ConfArg)), ("ttl-expiration", ("ttl_expiration", Native.Mpls.Ip.TtlExpiration))])
                self._leafs = OrderedDict([
                    ('default_route', (YLeaf(YType.empty, 'default-route'), ['Empty'])),
                ])
                self.default_route = None

                self.conf = Native.Mpls.Ip.Conf()
                self.conf.parent = self
                self._children_name_map["conf"] = "conf"

                self.conf_arg = Native.Mpls.Ip.ConfArg()
                self.conf_arg.parent = self
                self._children_name_map["conf_arg"] = "conf-arg"

                self.ttl_expiration = Native.Mpls.Ip.TtlExpiration()
                self.ttl_expiration.parent = self
                self._children_name_map["ttl_expiration"] = "ttl-expiration"
                self._segment_path = lambda: "Cisco-IOS-XE-mpls:ip"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mpls.Ip, [u'default_route'], name, value)


            class Conf(Entity):
                """
                
                
                .. attribute:: propagate_ttl
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.Ip.Conf, self).__init__()

                    self.yang_name = "conf"
                    self.yang_parent_name = "ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('propagate_ttl', (YLeaf(YType.boolean, 'propagate-ttl'), ['bool'])),
                    ])
                    self.propagate_ttl = None
                    self._segment_path = lambda: "conf"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.Ip.Conf, [u'propagate_ttl'], name, value)


            class ConfArg(Entity):
                """
                
                
                .. attribute:: propagate_ttl
                
                	
                	**type**\:  :py:class:`PropagateTtl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ip.ConfArg.PropagateTtl>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.Ip.ConfArg, self).__init__()

                    self.yang_name = "conf-arg"
                    self.yang_parent_name = "ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("propagate-ttl", ("propagate_ttl", Native.Mpls.Ip.ConfArg.PropagateTtl))])
                    self._leafs = OrderedDict()

                    self.propagate_ttl = Native.Mpls.Ip.ConfArg.PropagateTtl()
                    self.propagate_ttl.parent = self
                    self._children_name_map["propagate_ttl"] = "propagate-ttl"
                    self._segment_path = lambda: "conf-arg"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.Ip.ConfArg, [], name, value)


                class PropagateTtl(Entity):
                    """
                    
                    
                    .. attribute:: forwarded
                    
                    	
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ip.ConfArg.PropagateTtl, self).__init__()

                        self.yang_name = "propagate-ttl"
                        self.yang_parent_name = "conf-arg"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('forwarded', (YLeaf(YType.boolean, 'forwarded'), ['bool'])),
                        ])
                        self.forwarded = None
                        self._segment_path = lambda: "propagate-ttl"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ip/conf-arg/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ip.ConfArg.PropagateTtl, [u'forwarded'], name, value)


            class TtlExpiration(Entity):
                """
                Control MPLS TTL expiration behavior
                
                .. attribute:: pop
                
                	Popping labels on TTL expiration
                	**type**\: int
                
                	**range:** 1..6
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.Ip.TtlExpiration, self).__init__()

                    self.yang_name = "ttl-expiration"
                    self.yang_parent_name = "ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('pop', (YLeaf(YType.uint8, 'pop'), ['int'])),
                    ])
                    self.pop = None
                    self._segment_path = lambda: "ttl-expiration"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.Ip.TtlExpiration, [u'pop'], name, value)


        class Label(Entity):
            """
            Label properties
            
            .. attribute:: atm
            
            	Configure ATM options
            	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Atm>`
            
            .. attribute:: mode
            
            	MPLS Label allocation mode
            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode>`
            
            .. attribute:: protocol
            
            	Set platform default label distribution protocol
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Protocol>`
            
            .. attribute:: range
            
            	Label range
            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Range>`
            
            

            """

            _prefix = 'ios-mpls'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Mpls.Label, self).__init__()

                self.yang_name = "label"
                self.yang_parent_name = "mpls"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("atm", ("atm", Native.Mpls.Label.Atm)), ("mode", ("mode", Native.Mpls.Label.Mode)), ("range", ("range", Native.Mpls.Label.Range))])
                self._leafs = OrderedDict([
                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.Label.Protocol')])),
                ])
                self.protocol = None

                self.atm = Native.Mpls.Label.Atm()
                self.atm.parent = self
                self._children_name_map["atm"] = "atm"

                self.mode = Native.Mpls.Label.Mode()
                self.mode.parent = self
                self._children_name_map["mode"] = "mode"

                self.range = Native.Mpls.Label.Range()
                self.range.parent = self
                self._children_name_map["range"] = "range"
                self._segment_path = lambda: "Cisco-IOS-XE-mpls:label"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mpls.Label, [u'protocol'], name, value)

            class Protocol(Enum):
                """
                Protocol (Enum Class)

                Set platform default label distribution protocol

                .. data:: ldp = 0

                .. data:: tdp = 1

                """

                ldp = Enum.YLeaf(0, "ldp")

                tdp = Enum.YLeaf(1, "tdp")



            class Atm(Entity):
                """
                Configure ATM options
                
                .. attribute:: disable_headend_vc
                
                	Dedicated lsc capability\: In this mode headend Tag VCs are disabled
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.Label.Atm, self).__init__()

                    self.yang_name = "atm"
                    self.yang_parent_name = "label"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('disable_headend_vc', (YLeaf(YType.empty, 'disable-headend-vc'), ['Empty'])),
                    ])
                    self.disable_headend_vc = None
                    self._segment_path = lambda: "atm"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:label/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.Label.Atm, [u'disable_headend_vc'], name, value)


            class Mode(Entity):
                """
                MPLS Label allocation mode
                
                .. attribute:: all_vrfs
                
                	MPLS Label allocation mode for all VRFs
                	**type**\:  :py:class:`AllVrfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode.AllVrfs>`
                
                .. attribute:: vrf
                
                	MPLS Label allocation mode for a specific VRF
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode.Vrf>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.Label.Mode, self).__init__()

                    self.yang_name = "mode"
                    self.yang_parent_name = "label"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("all-vrfs", ("all_vrfs", Native.Mpls.Label.Mode.AllVrfs)), ("vrf", ("vrf", Native.Mpls.Label.Mode.Vrf))])
                    self._leafs = OrderedDict()

                    self.all_vrfs = Native.Mpls.Label.Mode.AllVrfs()
                    self.all_vrfs.parent = self
                    self._children_name_map["all_vrfs"] = "all-vrfs"

                    self.vrf = Native.Mpls.Label.Mode.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._segment_path = lambda: "mode"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:label/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.Label.Mode, [], name, value)


                class AllVrfs(Entity):
                    """
                    MPLS Label allocation mode for all VRFs
                    
                    .. attribute:: protocol
                    
                    	MPLS Label allocation protocol
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode.AllVrfs.Protocol>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Label.Mode.AllVrfs, self).__init__()

                        self.yang_name = "all-vrfs"
                        self.yang_parent_name = "mode"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol", ("protocol", Native.Mpls.Label.Mode.AllVrfs.Protocol))])
                        self._leafs = OrderedDict()

                        self.protocol = Native.Mpls.Label.Mode.AllVrfs.Protocol()
                        self.protocol.parent = self
                        self._children_name_map["protocol"] = "protocol"
                        self._segment_path = lambda: "all-vrfs"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:label/mode/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Label.Mode.AllVrfs, [], name, value)


                    class Protocol(Entity):
                        """
                        MPLS Label allocation protocol
                        
                        .. attribute:: all_afs
                        
                        	All VRF (IPv4 and IPv6) address families
                        	**type**\:  :py:class:`AllAfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode.AllVrfs.Protocol.AllAfs>`
                        
                        .. attribute:: bgp_vpnv4
                        
                        	VRF IPv4 address family
                        	**type**\:  :py:class:`BgpVpnv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode.AllVrfs.Protocol.BgpVpnv4>`
                        
                        .. attribute:: bgp_vpnv6
                        
                        	VRF IPv6 address family
                        	**type**\:  :py:class:`BgpVpnv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode.AllVrfs.Protocol.BgpVpnv6>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Label.Mode.AllVrfs.Protocol, self).__init__()

                            self.yang_name = "protocol"
                            self.yang_parent_name = "all-vrfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("all-afs", ("all_afs", Native.Mpls.Label.Mode.AllVrfs.Protocol.AllAfs)), ("bgp-vpnv4", ("bgp_vpnv4", Native.Mpls.Label.Mode.AllVrfs.Protocol.BgpVpnv4)), ("bgp-vpnv6", ("bgp_vpnv6", Native.Mpls.Label.Mode.AllVrfs.Protocol.BgpVpnv6))])
                            self._leafs = OrderedDict()

                            self.all_afs = Native.Mpls.Label.Mode.AllVrfs.Protocol.AllAfs()
                            self.all_afs.parent = self
                            self._children_name_map["all_afs"] = "all-afs"

                            self.bgp_vpnv4 = Native.Mpls.Label.Mode.AllVrfs.Protocol.BgpVpnv4()
                            self.bgp_vpnv4.parent = self
                            self._children_name_map["bgp_vpnv4"] = "bgp-vpnv4"

                            self.bgp_vpnv6 = Native.Mpls.Label.Mode.AllVrfs.Protocol.BgpVpnv6()
                            self.bgp_vpnv6.parent = self
                            self._children_name_map["bgp_vpnv6"] = "bgp-vpnv6"
                            self._segment_path = lambda: "protocol"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:label/mode/all-vrfs/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Label.Mode.AllVrfs.Protocol, [], name, value)


                        class AllAfs(Entity):
                            """
                            All VRF (IPv4 and IPv6) address families
                            
                            .. attribute:: per_ce
                            
                            	Per CE label
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: per_prefix
                            
                            	Per prefix label (default)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: per_vrf
                            
                            	Per VRF label for entire VRF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vrf_conn_aggr
                            
                            	Per VRF label for connected and BGP aggregates in VRF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Label.Mode.AllVrfs.Protocol.AllAfs, self).__init__()

                                self.yang_name = "all-afs"
                                self.yang_parent_name = "protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('per_ce', (YLeaf(YType.empty, 'per-ce'), ['Empty'])),
                                    ('per_prefix', (YLeaf(YType.empty, 'per-prefix'), ['Empty'])),
                                    ('per_vrf', (YLeaf(YType.empty, 'per-vrf'), ['Empty'])),
                                    ('vrf_conn_aggr', (YLeaf(YType.empty, 'vrf-conn-aggr'), ['Empty'])),
                                ])
                                self.per_ce = None
                                self.per_prefix = None
                                self.per_vrf = None
                                self.vrf_conn_aggr = None
                                self._segment_path = lambda: "all-afs"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:label/mode/all-vrfs/protocol/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Label.Mode.AllVrfs.Protocol.AllAfs, [u'per_ce', u'per_prefix', u'per_vrf', u'vrf_conn_aggr'], name, value)


                        class BgpVpnv4(Entity):
                            """
                            VRF IPv4 address family
                            
                            .. attribute:: per_ce
                            
                            	Per CE label
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: per_prefix
                            
                            	Per prefix label (default)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: per_vrf
                            
                            	Per VRF label for entire VRF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vrf_conn_aggr
                            
                            	Per VRF label for connected and BGP aggregates in VRF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Label.Mode.AllVrfs.Protocol.BgpVpnv4, self).__init__()

                                self.yang_name = "bgp-vpnv4"
                                self.yang_parent_name = "protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('per_ce', (YLeaf(YType.empty, 'per-ce'), ['Empty'])),
                                    ('per_prefix', (YLeaf(YType.empty, 'per-prefix'), ['Empty'])),
                                    ('per_vrf', (YLeaf(YType.empty, 'per-vrf'), ['Empty'])),
                                    ('vrf_conn_aggr', (YLeaf(YType.empty, 'vrf-conn-aggr'), ['Empty'])),
                                ])
                                self.per_ce = None
                                self.per_prefix = None
                                self.per_vrf = None
                                self.vrf_conn_aggr = None
                                self._segment_path = lambda: "bgp-vpnv4"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:label/mode/all-vrfs/protocol/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Label.Mode.AllVrfs.Protocol.BgpVpnv4, [u'per_ce', u'per_prefix', u'per_vrf', u'vrf_conn_aggr'], name, value)


                        class BgpVpnv6(Entity):
                            """
                            VRF IPv6 address family
                            
                            .. attribute:: per_ce
                            
                            	Per CE label
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: per_prefix
                            
                            	Per prefix label (default)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: per_vrf
                            
                            	Per VRF label for entire VRF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vrf_conn_aggr
                            
                            	Per VRF label for connected and BGP aggregates in VRF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Label.Mode.AllVrfs.Protocol.BgpVpnv6, self).__init__()

                                self.yang_name = "bgp-vpnv6"
                                self.yang_parent_name = "protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('per_ce', (YLeaf(YType.empty, 'per-ce'), ['Empty'])),
                                    ('per_prefix', (YLeaf(YType.empty, 'per-prefix'), ['Empty'])),
                                    ('per_vrf', (YLeaf(YType.empty, 'per-vrf'), ['Empty'])),
                                    ('vrf_conn_aggr', (YLeaf(YType.empty, 'vrf-conn-aggr'), ['Empty'])),
                                ])
                                self.per_ce = None
                                self.per_prefix = None
                                self.per_vrf = None
                                self.vrf_conn_aggr = None
                                self._segment_path = lambda: "bgp-vpnv6"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:label/mode/all-vrfs/protocol/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Label.Mode.AllVrfs.Protocol.BgpVpnv6, [u'per_ce', u'per_prefix', u'per_vrf', u'vrf_conn_aggr'], name, value)


                class Vrf(Entity):
                    """
                    MPLS Label allocation mode for a specific VRF
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode.Vrf.Vrf_>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Label.Mode.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "mode"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Mpls.Label.Mode.Vrf.Vrf_))])
                        self._leafs = OrderedDict()

                        self.vrf = YList(self)
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:label/mode/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Label.Mode.Vrf, [], name, value)


                    class Vrf_(Entity):
                        """
                        
                        
                        .. attribute:: vrf_name  (key)
                        
                        	VPN Routing/Forwarding instance name
                        	**type**\: str
                        
                        .. attribute:: protocol
                        
                        	MPLS Label allocation protocol
                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Label.Mode.Vrf.Vrf_, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['vrf_name']
                            self._child_classes = OrderedDict([("protocol", ("protocol", Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol))])
                            self._leafs = OrderedDict([
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.vrf_name = None

                            self.protocol = Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol()
                            self.protocol.parent = self
                            self._children_name_map["protocol"] = "protocol"
                            self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:label/mode/vrf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Label.Mode.Vrf.Vrf_, [u'vrf_name'], name, value)


                        class Protocol(Entity):
                            """
                            MPLS Label allocation protocol
                            
                            .. attribute:: all_afs
                            
                            	All VRF (IPv4 and IPv6) address families
                            	**type**\:  :py:class:`AllAfs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.AllAfs>`
                            
                            .. attribute:: bgp_vpnv4
                            
                            	VRF IPv4 address family
                            	**type**\:  :py:class:`BgpVpnv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.BgpVpnv4>`
                            
                            .. attribute:: bgp_vpnv6
                            
                            	VRF IPv6 address family
                            	**type**\:  :py:class:`BgpVpnv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.BgpVpnv6>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol, self).__init__()

                                self.yang_name = "protocol"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("all-afs", ("all_afs", Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.AllAfs)), ("bgp-vpnv4", ("bgp_vpnv4", Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.BgpVpnv4)), ("bgp-vpnv6", ("bgp_vpnv6", Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.BgpVpnv6))])
                                self._leafs = OrderedDict()

                                self.all_afs = Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.AllAfs()
                                self.all_afs.parent = self
                                self._children_name_map["all_afs"] = "all-afs"

                                self.bgp_vpnv4 = Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.BgpVpnv4()
                                self.bgp_vpnv4.parent = self
                                self._children_name_map["bgp_vpnv4"] = "bgp-vpnv4"

                                self.bgp_vpnv6 = Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.BgpVpnv6()
                                self.bgp_vpnv6.parent = self
                                self._children_name_map["bgp_vpnv6"] = "bgp-vpnv6"
                                self._segment_path = lambda: "protocol"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol, [], name, value)


                            class AllAfs(Entity):
                                """
                                All VRF (IPv4 and IPv6) address families
                                
                                .. attribute:: per_ce
                                
                                	Per CE label
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: per_prefix
                                
                                	Per prefix label (default)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: per_vrf
                                
                                	Per VRF label for entire VRF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: vrf_conn_aggr
                                
                                	Per VRF label for connected and BGP aggregates in VRF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.AllAfs, self).__init__()

                                    self.yang_name = "all-afs"
                                    self.yang_parent_name = "protocol"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('per_ce', (YLeaf(YType.empty, 'per-ce'), ['Empty'])),
                                        ('per_prefix', (YLeaf(YType.empty, 'per-prefix'), ['Empty'])),
                                        ('per_vrf', (YLeaf(YType.empty, 'per-vrf'), ['Empty'])),
                                        ('vrf_conn_aggr', (YLeaf(YType.empty, 'vrf-conn-aggr'), ['Empty'])),
                                    ])
                                    self.per_ce = None
                                    self.per_prefix = None
                                    self.per_vrf = None
                                    self.vrf_conn_aggr = None
                                    self._segment_path = lambda: "all-afs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.AllAfs, [u'per_ce', u'per_prefix', u'per_vrf', u'vrf_conn_aggr'], name, value)


                            class BgpVpnv4(Entity):
                                """
                                VRF IPv4 address family
                                
                                .. attribute:: per_ce
                                
                                	Per CE label
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: per_prefix
                                
                                	Per prefix label (default)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: per_vrf
                                
                                	Per VRF label for entire VRF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: vrf_conn_aggr
                                
                                	Per VRF label for connected and BGP aggregates in VRF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.BgpVpnv4, self).__init__()

                                    self.yang_name = "bgp-vpnv4"
                                    self.yang_parent_name = "protocol"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('per_ce', (YLeaf(YType.empty, 'per-ce'), ['Empty'])),
                                        ('per_prefix', (YLeaf(YType.empty, 'per-prefix'), ['Empty'])),
                                        ('per_vrf', (YLeaf(YType.empty, 'per-vrf'), ['Empty'])),
                                        ('vrf_conn_aggr', (YLeaf(YType.empty, 'vrf-conn-aggr'), ['Empty'])),
                                    ])
                                    self.per_ce = None
                                    self.per_prefix = None
                                    self.per_vrf = None
                                    self.vrf_conn_aggr = None
                                    self._segment_path = lambda: "bgp-vpnv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.BgpVpnv4, [u'per_ce', u'per_prefix', u'per_vrf', u'vrf_conn_aggr'], name, value)


                            class BgpVpnv6(Entity):
                                """
                                VRF IPv6 address family
                                
                                .. attribute:: per_ce
                                
                                	Per CE label
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: per_prefix
                                
                                	Per prefix label (default)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: per_vrf
                                
                                	Per VRF label for entire VRF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: vrf_conn_aggr
                                
                                	Per VRF label for connected and BGP aggregates in VRF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.BgpVpnv6, self).__init__()

                                    self.yang_name = "bgp-vpnv6"
                                    self.yang_parent_name = "protocol"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('per_ce', (YLeaf(YType.empty, 'per-ce'), ['Empty'])),
                                        ('per_prefix', (YLeaf(YType.empty, 'per-prefix'), ['Empty'])),
                                        ('per_vrf', (YLeaf(YType.empty, 'per-vrf'), ['Empty'])),
                                        ('vrf_conn_aggr', (YLeaf(YType.empty, 'vrf-conn-aggr'), ['Empty'])),
                                    ])
                                    self.per_ce = None
                                    self.per_prefix = None
                                    self.per_vrf = None
                                    self.vrf_conn_aggr = None
                                    self._segment_path = lambda: "bgp-vpnv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Label.Mode.Vrf.Vrf_.Protocol.BgpVpnv6, [u'per_ce', u'per_prefix', u'per_vrf', u'vrf_conn_aggr'], name, value)


            class Range(Entity):
                """
                Label range
                
                .. attribute:: min
                
                	
                	**type**\: int
                
                	**range:** 16..1048575
                
                .. attribute:: max
                
                	
                	**type**\: int
                
                	**range:** 16..1048575
                
                .. attribute:: static
                
                	Specify block of labels for static bindings
                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Label.Range.Static>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.Label.Range, self).__init__()

                    self.yang_name = "range"
                    self.yang_parent_name = "label"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("static", ("static", Native.Mpls.Label.Range.Static))])
                    self._leafs = OrderedDict([
                        ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                        ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                    ])
                    self.min = None
                    self.max = None

                    self.static = Native.Mpls.Label.Range.Static()
                    self.static.parent = self
                    self._children_name_map["static"] = "static"
                    self._segment_path = lambda: "range"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:label/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.Label.Range, [u'min', u'max'], name, value)


                class Static(Entity):
                    """
                    Specify block of labels for static bindings
                    
                    .. attribute:: min
                    
                    	
                    	**type**\: int
                    
                    	**range:** 16..1048575
                    
                    .. attribute:: max
                    
                    	
                    	**type**\: int
                    
                    	**range:** 16..1048575
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Label.Range.Static, self).__init__()

                        self.yang_name = "static"
                        self.yang_parent_name = "range"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('min', (YLeaf(YType.uint32, 'min'), ['int'])),
                            ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                        ])
                        self.min = None
                        self.max = None
                        self._segment_path = lambda: "static"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:label/range/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Label.Range.Static, [u'min', u'max'], name, value)


        class Ldp(Entity):
            """
            Label Distribution Protocol
            
            .. attribute:: enable
            
            	
            	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable>`
            
            .. attribute:: enable2
            
            	
            	**type**\:  :py:class:`Enable2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2>`
            
            .. attribute:: session
            
            	Configure session parameters
            	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Session>`
            
            

            """

            _prefix = 'ios-mpls'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Mpls.Ldp, self).__init__()

                self.yang_name = "ldp"
                self.yang_parent_name = "mpls"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("enable", ("enable", Native.Mpls.Ldp.Enable)), ("enable2", ("enable2", Native.Mpls.Ldp.Enable2)), ("session", ("session", Native.Mpls.Ldp.Session))])
                self._leafs = OrderedDict()

                self.enable = Native.Mpls.Ldp.Enable()
                self.enable.parent = self
                self._children_name_map["enable"] = "enable"

                self.enable2 = Native.Mpls.Ldp.Enable2()
                self.enable2.parent = self
                self._children_name_map["enable2"] = "enable2"

                self.session = Native.Mpls.Ldp.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._segment_path = lambda: "Cisco-IOS-XE-mpls:ldp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mpls.Ldp, [], name, value)


            class Enable(Entity):
                """
                
                
                .. attribute:: advertise_labels
                
                	
                	**type**\: bool
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.Ldp.Enable, self).__init__()

                    self.yang_name = "enable"
                    self.yang_parent_name = "ldp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('advertise_labels', (YLeaf(YType.boolean, 'advertise-labels'), ['bool'])),
                    ])
                    self.advertise_labels = None
                    self._segment_path = lambda: "enable"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.Ldp.Enable, [u'advertise_labels'], name, value)


            class Enable2(Entity):
                """
                
                
                .. attribute:: advertise_labels
                
                	Label advertisements
                	**type**\:  :py:class:`AdvertiseLabels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.AdvertiseLabels>`
                
                .. attribute:: atm
                
                	Configure ATM MPLS options
                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Atm>`
                
                .. attribute:: backoff
                
                	Set LDP session backoff parameters
                	**type**\:  :py:class:`Backoff <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Backoff>`
                
                .. attribute:: discovery
                
                	LDP discovery
                	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Discovery>`
                
                .. attribute:: entropy_label
                
                	Enable Entropy Label for LDP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: explicit_null
                
                	Advertise Explicit Null label in place of Implicit Null
                	**type**\:  :py:class:`ExplicitNull <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.ExplicitNull>`
                
                	**presence node**\: True
                
                .. attribute:: graceful_restart
                
                	Configure Graceful Restart timers
                	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.GracefulRestart>`
                
                	**presence node**\: True
                
                .. attribute:: holdtime
                
                	LDP session holdtime
                	**type**\: int
                
                	**range:** 15..2147483
                
                .. attribute:: igp
                
                	Configure IGP\-related LDP parameters
                	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Igp>`
                
                .. attribute:: label
                
                	LDP label mode
                	**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Label>`
                
                	**presence node**\: True
                
                .. attribute:: logging
                
                	Enable LDP logging
                	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Logging>`
                
                .. attribute:: loop_detection
                
                	Enable LDP Loop Detection
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: maxhops
                
                	Limit hop count for LDP LSP setup
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: neighbor
                
                	
                	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor>`
                
                .. attribute:: nsr
                
                	Enable Non Stop Routing for LDP
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: password
                
                	Configure LDP MD5 password
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Password>`
                
                .. attribute:: request_labels
                
                	Access list to specify valid downstream on demand destinations
                	**type**\:  :py:class:`RequestLabels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RequestLabels>`
                
                .. attribute:: router_id
                
                	Select interface to prefer for LDP identifier address
                	**type**\:  :py:class:`RouterId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId>`
                
                .. attribute:: tcp
                
                	Set TCP parameters for LDP
                	**type**\:  :py:class:`Tcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Tcp>`
                
                .. attribute:: vrf
                
                	
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.Ldp.Enable2, self).__init__()

                    self.yang_name = "enable2"
                    self.yang_parent_name = "ldp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("advertise-labels", ("advertise_labels", Native.Mpls.Ldp.Enable2.AdvertiseLabels)), ("atm", ("atm", Native.Mpls.Ldp.Enable2.Atm)), ("backoff", ("backoff", Native.Mpls.Ldp.Enable2.Backoff)), ("discovery", ("discovery", Native.Mpls.Ldp.Enable2.Discovery)), ("explicit-null", ("explicit_null", Native.Mpls.Ldp.Enable2.ExplicitNull)), ("graceful-restart", ("graceful_restart", Native.Mpls.Ldp.Enable2.GracefulRestart)), ("igp", ("igp", Native.Mpls.Ldp.Enable2.Igp)), ("label", ("label", Native.Mpls.Ldp.Enable2.Label)), ("logging", ("logging", Native.Mpls.Ldp.Enable2.Logging)), ("neighbor", ("neighbor", Native.Mpls.Ldp.Enable2.Neighbor)), ("password", ("password", Native.Mpls.Ldp.Enable2.Password)), ("request-labels", ("request_labels", Native.Mpls.Ldp.Enable2.RequestLabels)), ("router-id", ("router_id", Native.Mpls.Ldp.Enable2.RouterId)), ("tcp", ("tcp", Native.Mpls.Ldp.Enable2.Tcp)), ("vrf", ("vrf", Native.Mpls.Ldp.Enable2.Vrf))])
                    self._leafs = OrderedDict([
                        ('entropy_label', (YLeaf(YType.empty, 'entropy-label'), ['Empty'])),
                        ('holdtime', (YLeaf(YType.uint32, 'holdtime'), ['int'])),
                        ('loop_detection', (YLeaf(YType.empty, 'loop-detection'), ['Empty'])),
                        ('maxhops', (YLeaf(YType.uint8, 'maxhops'), ['int'])),
                        ('nsr', (YLeaf(YType.empty, 'nsr'), ['Empty'])),
                    ])
                    self.entropy_label = None
                    self.holdtime = None
                    self.loop_detection = None
                    self.maxhops = None
                    self.nsr = None

                    self.advertise_labels = Native.Mpls.Ldp.Enable2.AdvertiseLabels()
                    self.advertise_labels.parent = self
                    self._children_name_map["advertise_labels"] = "advertise-labels"

                    self.atm = Native.Mpls.Ldp.Enable2.Atm()
                    self.atm.parent = self
                    self._children_name_map["atm"] = "atm"

                    self.backoff = Native.Mpls.Ldp.Enable2.Backoff()
                    self.backoff.parent = self
                    self._children_name_map["backoff"] = "backoff"

                    self.discovery = Native.Mpls.Ldp.Enable2.Discovery()
                    self.discovery.parent = self
                    self._children_name_map["discovery"] = "discovery"

                    self.explicit_null = None
                    self._children_name_map["explicit_null"] = "explicit-null"

                    self.graceful_restart = None
                    self._children_name_map["graceful_restart"] = "graceful-restart"

                    self.igp = Native.Mpls.Ldp.Enable2.Igp()
                    self.igp.parent = self
                    self._children_name_map["igp"] = "igp"

                    self.label = None
                    self._children_name_map["label"] = "label"

                    self.logging = Native.Mpls.Ldp.Enable2.Logging()
                    self.logging.parent = self
                    self._children_name_map["logging"] = "logging"

                    self.neighbor = Native.Mpls.Ldp.Enable2.Neighbor()
                    self.neighbor.parent = self
                    self._children_name_map["neighbor"] = "neighbor"

                    self.password = Native.Mpls.Ldp.Enable2.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "password"

                    self.request_labels = Native.Mpls.Ldp.Enable2.RequestLabels()
                    self.request_labels.parent = self
                    self._children_name_map["request_labels"] = "request-labels"

                    self.router_id = Native.Mpls.Ldp.Enable2.RouterId()
                    self.router_id.parent = self
                    self._children_name_map["router_id"] = "router-id"

                    self.tcp = Native.Mpls.Ldp.Enable2.Tcp()
                    self.tcp.parent = self
                    self._children_name_map["tcp"] = "tcp"

                    self.vrf = Native.Mpls.Ldp.Enable2.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._segment_path = lambda: "enable2"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.Ldp.Enable2, [u'entropy_label', u'holdtime', u'loop_detection', u'maxhops', u'nsr'], name, value)


                class AdvertiseLabels(Entity):
                    """
                    Label advertisements
                    
                    .. attribute:: for_
                    
                    	Access\-list specifying controls on destination prefixes
                    	**type**\:  :py:class:`For <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.AdvertiseLabels.For>`
                    
                    .. attribute:: interface
                    
                    	Advertise /32 interface address
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.AdvertiseLabels.Interface>`
                    
                    .. attribute:: oldstyle
                    
                    	Use old style (TDP) method for matching prefix acl
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.AdvertiseLabels, self).__init__()

                        self.yang_name = "advertise-labels"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("for", ("for_", Native.Mpls.Ldp.Enable2.AdvertiseLabels.For)), ("interface", ("interface", Native.Mpls.Ldp.Enable2.AdvertiseLabels.Interface)), ("vrf", ("vrf", Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf))])
                        self._leafs = OrderedDict([
                            ('oldstyle', (YLeaf(YType.empty, 'oldstyle'), ['Empty'])),
                        ])
                        self.oldstyle = None

                        self.for_ = Native.Mpls.Ldp.Enable2.AdvertiseLabels.For()
                        self.for_.parent = self
                        self._children_name_map["for_"] = "for"

                        self.vrf = Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.interface = YList(self)
                        self._segment_path = lambda: "advertise-labels"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.AdvertiseLabels, [u'oldstyle'], name, value)


                    class For(Entity):
                        """
                        Access\-list specifying controls on destination prefixes
                        
                        .. attribute:: from_
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: to
                        
                        	Access\-list specifying controls on LDP peers
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.AdvertiseLabels.For, self).__init__()

                            self.yang_name = "for"
                            self.yang_parent_name = "advertise-labels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('from_', (YLeaf(YType.str, 'from'), ['str'])),
                                ('to', (YLeaf(YType.str, 'to'), ['str'])),
                            ])
                            self.from_ = None
                            self.to = None
                            self._segment_path = lambda: "for"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/advertise-labels/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.AdvertiseLabels.For, [u'from_', u'to'], name, value)


                    class Interface(Entity):
                        """
                        Advertise /32 interface address
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "advertise-labels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "interface" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/advertise-labels/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Interface, [u'name'], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: vrf
                        
                        	
                        	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "advertise-labels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_))])
                            self._leafs = OrderedDict()

                            self.vrf = YList(self)
                            self._segment_path = lambda: "vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/advertise-labels/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf, [], name, value)


                        class Vrf_(Entity):
                            """
                            
                            
                            .. attribute:: vrf_name  (key)
                            
                            	VPN Routing/Forwarding instance name
                            	**type**\: str
                            
                            .. attribute:: for_
                            
                            	Access\-list specifying controls on destination prefixes
                            	**type**\:  :py:class:`For <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.For>`
                            
                            .. attribute:: interface
                            
                            	
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface>`
                            
                            .. attribute:: oldstyle
                            
                            	Use old style (TDP) method for matching prefix acl
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['vrf_name']
                                self._child_classes = OrderedDict([("for", ("for_", Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.For)), ("interface", ("interface", Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface))])
                                self._leafs = OrderedDict([
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('oldstyle', (YLeaf(YType.empty, 'oldstyle'), ['Empty'])),
                                ])
                                self.vrf_name = None
                                self.oldstyle = None

                                self.for_ = Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.For()
                                self.for_.parent = self
                                self._children_name_map["for_"] = "for"

                                self.interface = Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/advertise-labels/vrf/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_, [u'vrf_name', u'oldstyle'], name, value)


                            class For(Entity):
                                """
                                Access\-list specifying controls on destination prefixes
                                
                                .. attribute:: from_
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: to
                                
                                	Access\-list specifying controls on LDP peers
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.For, self).__init__()

                                    self.yang_name = "for"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('from_', (YLeaf(YType.str, 'from'), ['str'])),
                                        ('to', (YLeaf(YType.str, 'to'), ['str'])),
                                    ])
                                    self.from_ = None
                                    self.to = None
                                    self._segment_path = lambda: "for"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.For, [u'from_', u'to'], name, value)


                            class Interface(Entity):
                                """
                                
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.Ldp.Enable2.AdvertiseLabels.Vrf.Vrf_.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                class Atm(Entity):
                    """
                    Configure ATM MPLS options
                    
                    .. attribute:: control_mode
                    
                    	Select LSP setup control mode for MPLS VCs
                    	**type**\:  :py:class:`ControlMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Atm.ControlMode>`
                    
                    .. attribute:: vc_merge
                    
                    	Select VC merge capability
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.Atm, self).__init__()

                        self.yang_name = "atm"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('control_mode', (YLeaf(YType.enumeration, 'control-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.Ldp.Enable2.Atm.ControlMode')])),
                            ('vc_merge', (YLeaf(YType.boolean, 'vc-merge'), ['bool'])),
                        ])
                        self.control_mode = None
                        self.vc_merge = None
                        self._segment_path = lambda: "atm"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Atm, [u'control_mode', u'vc_merge'], name, value)

                    class ControlMode(Enum):
                        """
                        ControlMode (Enum Class)

                        Select LSP setup control mode for MPLS VCs

                        .. data:: independent = 0

                        .. data:: ordered = 1

                        """

                        independent = Enum.YLeaf(0, "independent")

                        ordered = Enum.YLeaf(1, "ordered")



                class Backoff(Entity):
                    """
                    Set LDP session backoff parameters
                    
                    .. attribute:: initial
                    
                    	
                    	**type**\: int
                    
                    	**range:** 5..2147483
                    
                    .. attribute:: max
                    
                    	
                    	**type**\: int
                    
                    	**range:** 5..2147483
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.Backoff, self).__init__()

                        self.yang_name = "backoff"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('initial', (YLeaf(YType.uint32, 'initial'), ['int'])),
                            ('max', (YLeaf(YType.uint32, 'max'), ['int'])),
                        ])
                        self.initial = None
                        self.max = None
                        self._segment_path = lambda: "backoff"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Backoff, [u'initial', u'max'], name, value)


                class Discovery(Entity):
                    """
                    LDP discovery
                    
                    .. attribute:: hello
                    
                    	LDP discovery Hello
                    	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Discovery.Hello>`
                    
                    .. attribute:: targeted_hello
                    
                    	LDP discovery Targeted Hello
                    	**type**\:  :py:class:`TargetedHello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Discovery.TargetedHello>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.Discovery, self).__init__()

                        self.yang_name = "discovery"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("hello", ("hello", Native.Mpls.Ldp.Enable2.Discovery.Hello)), ("targeted-hello", ("targeted_hello", Native.Mpls.Ldp.Enable2.Discovery.TargetedHello))])
                        self._leafs = OrderedDict()

                        self.hello = Native.Mpls.Ldp.Enable2.Discovery.Hello()
                        self.hello.parent = self
                        self._children_name_map["hello"] = "hello"

                        self.targeted_hello = Native.Mpls.Ldp.Enable2.Discovery.TargetedHello()
                        self.targeted_hello.parent = self
                        self._children_name_map["targeted_hello"] = "targeted-hello"
                        self._segment_path = lambda: "discovery"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Discovery, [], name, value)


                    class Hello(Entity):
                        """
                        LDP discovery Hello
                        
                        .. attribute:: holdtime
                        
                        	LDP discovery Hello holdtime
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: interval
                        
                        	LDP discovery Hello interval
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Discovery.Hello, self).__init__()

                            self.yang_name = "hello"
                            self.yang_parent_name = "discovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.holdtime = None
                            self.interval = None
                            self._segment_path = lambda: "hello"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/discovery/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Discovery.Hello, [u'holdtime', u'interval'], name, value)


                    class TargetedHello(Entity):
                        """
                        LDP discovery Targeted Hello
                        
                        .. attribute:: accept
                        
                        	Accept targeted hellos
                        	**type**\:  :py:class:`Accept <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Discovery.TargetedHello.Accept>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: holdtime
                        
                        	LDP discovery Hello holdtime
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: interval
                        
                        	LDP discovery Hello interval
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Discovery.TargetedHello, self).__init__()

                            self.yang_name = "targeted-hello"
                            self.yang_parent_name = "discovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("accept", ("accept", Native.Mpls.Ldp.Enable2.Discovery.TargetedHello.Accept))])
                            self._leafs = OrderedDict([
                                ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.holdtime = None
                            self.interval = None

                            self.accept = None
                            self._children_name_map["accept"] = "accept"
                            self._segment_path = lambda: "targeted-hello"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/discovery/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Discovery.TargetedHello, [u'holdtime', u'interval'], name, value)


                        class Accept(Entity):
                            """
                            Accept targeted hellos
                            
                            .. attribute:: from_
                            
                            	Access list to specify acceptable targeted hello sources
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Discovery.TargetedHello.Accept, self).__init__()

                                self.yang_name = "accept"
                                self.yang_parent_name = "targeted-hello"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('from_', (YLeaf(YType.str, 'from'), ['str'])),
                                ])
                                self.from_ = None
                                self._segment_path = lambda: "accept"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/discovery/targeted-hello/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Discovery.TargetedHello.Accept, [u'from_'], name, value)


                class ExplicitNull(Entity):
                    """
                    Advertise Explicit Null label in place of Implicit Null
                    
                    .. attribute:: for_
                    
                    	Access\-list specifying controls on destination prefixes
                    	**type**\: str
                    
                    .. attribute:: to
                    
                    	Access\-list specifying controls on LDP peers
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.ExplicitNull, self).__init__()

                        self.yang_name = "explicit-null"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('for_', (YLeaf(YType.str, 'for'), ['str'])),
                            ('to', (YLeaf(YType.str, 'to'), ['str'])),
                        ])
                        self.for_ = None
                        self.to = None
                        self._segment_path = lambda: "explicit-null"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.ExplicitNull, [u'for_', u'to'], name, value)


                class GracefulRestart(Entity):
                    """
                    Configure Graceful Restart timers
                    
                    .. attribute:: timers
                    
                    	Configure Graceful Restart timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.GracefulRestart.Timers>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.GracefulRestart, self).__init__()

                        self.yang_name = "graceful-restart"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("timers", ("timers", Native.Mpls.Ldp.Enable2.GracefulRestart.Timers))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.timers = Native.Mpls.Ldp.Enable2.GracefulRestart.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"
                        self._segment_path = lambda: "graceful-restart"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.GracefulRestart, [], name, value)


                    class Timers(Entity):
                        """
                        Configure Graceful Restart timers
                        
                        .. attribute:: forwarding_holding
                        
                        	Forwarding State Holding time
                        	**type**\: int
                        
                        	**range:** 30..600
                        
                        .. attribute:: max_recovery
                        
                        	Max\-Recovery time
                        	**type**\: int
                        
                        	**range:** 15..600
                        
                        .. attribute:: neighbor_liveness
                        
                        	Neighbor\-Liveness time
                        	**type**\: int
                        
                        	**range:** 5..600
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.GracefulRestart.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('forwarding_holding', (YLeaf(YType.uint16, 'forwarding-holding'), ['int'])),
                                ('max_recovery', (YLeaf(YType.uint16, 'max-recovery'), ['int'])),
                                ('neighbor_liveness', (YLeaf(YType.uint16, 'neighbor-liveness'), ['int'])),
                            ])
                            self.forwarding_holding = None
                            self.max_recovery = None
                            self.neighbor_liveness = None
                            self._segment_path = lambda: "timers"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/graceful-restart/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.GracefulRestart.Timers, [u'forwarding_holding', u'max_recovery', u'neighbor_liveness'], name, value)


                class Igp(Entity):
                    """
                    Configure IGP\-related LDP parameters
                    
                    .. attribute:: sync
                    
                    	Configure LDP\-IGP Synchronization parameters
                    	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Igp.Sync>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.Igp, self).__init__()

                        self.yang_name = "igp"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sync", ("sync", Native.Mpls.Ldp.Enable2.Igp.Sync))])
                        self._leafs = OrderedDict()

                        self.sync = Native.Mpls.Ldp.Enable2.Igp.Sync()
                        self.sync.parent = self
                        self._children_name_map["sync"] = "sync"
                        self._segment_path = lambda: "igp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Igp, [], name, value)


                    class Sync(Entity):
                        """
                        Configure LDP\-IGP Synchronization parameters
                        
                        .. attribute:: holddown
                        
                        	Hold down time in milliseconds
                        	**type**\: int
                        
                        	**range:** 1..2147483647
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Igp.Sync, self).__init__()

                            self.yang_name = "sync"
                            self.yang_parent_name = "igp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('holddown', (YLeaf(YType.uint32, 'holddown'), ['int'])),
                            ])
                            self.holddown = None
                            self._segment_path = lambda: "sync"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/igp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Igp.Sync, [u'holddown'], name, value)


                class Label(Entity):
                    """
                    LDP label mode
                    
                    .. attribute:: label_mode__config_ldp_lbl
                    
                    	
                    	**type**\:  :py:class:`LabelModeConfigLdpLbl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.Label, self).__init__()

                        self.yang_name = "label"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("label-Mode__config-ldp-lbl", ("label_mode__config_ldp_lbl", Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.label_mode__config_ldp_lbl = Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl()
                        self.label_mode__config_ldp_lbl.parent = self
                        self._children_name_map["label_mode__config_ldp_lbl"] = "label-Mode__config-ldp-lbl"
                        self._segment_path = lambda: "label"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Label, [], name, value)


                    class LabelModeConfigLdpLbl(Entity):
                        """
                        
                        
                        .. attribute:: allocate
                        
                        	Allocate local labels for specified destination prefixes
                        	**type**\:  :py:class:`Allocate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl.Allocate>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl, self).__init__()

                            self.yang_name = "label-Mode__config-ldp-lbl"
                            self.yang_parent_name = "label"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("allocate", ("allocate", Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl.Allocate))])
                            self._leafs = OrderedDict()

                            self.allocate = Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl.Allocate()
                            self.allocate.parent = self
                            self._children_name_map["allocate"] = "allocate"
                            self._segment_path = lambda: "label-Mode__config-ldp-lbl"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/label/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl, [], name, value)


                        class Allocate(Entity):
                            """
                            Allocate local labels for specified destination prefixes
                            
                            .. attribute:: global_
                            
                            	Specify global Routing/Forwarding instance
                            	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl.Allocate.Global>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl.Allocate, self).__init__()

                                self.yang_name = "allocate"
                                self.yang_parent_name = "label-Mode__config-ldp-lbl"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("global", ("global_", Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl.Allocate.Global))])
                                self._leafs = OrderedDict()

                                self.global_ = None
                                self._children_name_map["global_"] = "global"
                                self._segment_path = lambda: "allocate"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/label/label-Mode__config-ldp-lbl/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl.Allocate, [], name, value)


                            class Global(Entity):
                                """
                                Specify global Routing/Forwarding instance
                                
                                .. attribute:: host_routes
                                
                                	allocate local label for host routes only
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	IP prefix\-list for destination prefixes
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl.Allocate.Global, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "allocate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('host_routes', (YLeaf(YType.empty, 'host-routes'), ['Empty'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.host_routes = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "global"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/label/label-Mode__config-ldp-lbl/allocate/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.Label.LabelModeConfigLdpLbl.Allocate.Global, [u'host_routes', u'prefix_list'], name, value)


                class Logging(Entity):
                    """
                    Enable LDP logging
                    
                    .. attribute:: neighbor_changes
                    
                    	Log LDP neighbor state changes
                    	**type**\: bool
                    
                    .. attribute:: password
                    
                    	Log LDP password events
                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Logging.Password>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.Logging, self).__init__()

                        self.yang_name = "logging"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("password", ("password", Native.Mpls.Ldp.Enable2.Logging.Password))])
                        self._leafs = OrderedDict([
                            ('neighbor_changes', (YLeaf(YType.boolean, 'neighbor-changes'), ['bool'])),
                        ])
                        self.neighbor_changes = None

                        self.password = Native.Mpls.Ldp.Enable2.Logging.Password()
                        self.password.parent = self
                        self._children_name_map["password"] = "password"
                        self._segment_path = lambda: "logging"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Logging, [u'neighbor_changes'], name, value)


                    class Password(Entity):
                        """
                        Log LDP password events
                        
                        .. attribute:: configuration_conf
                        
                        	
                        	**type**\:  :py:class:`ConfigurationConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Logging.Password.ConfigurationConf>`
                        
                        .. attribute:: rollover_conf
                        
                        	
                        	**type**\:  :py:class:`RolloverConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Logging.Password.RolloverConf>`
                        
                        .. attribute:: configuration
                        
                        	Log LDP password configuration changes
                        	**type**\:  :py:class:`Configuration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Logging.Password.Configuration>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: rollover
                        
                        	Log LDP password rollover events
                        	**type**\:  :py:class:`Rollover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Logging.Password.Rollover>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Logging.Password, self).__init__()

                            self.yang_name = "password"
                            self.yang_parent_name = "logging"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("configuration-conf", ("configuration_conf", Native.Mpls.Ldp.Enable2.Logging.Password.ConfigurationConf)), ("rollover-conf", ("rollover_conf", Native.Mpls.Ldp.Enable2.Logging.Password.RolloverConf)), ("configuration", ("configuration", Native.Mpls.Ldp.Enable2.Logging.Password.Configuration)), ("rollover", ("rollover", Native.Mpls.Ldp.Enable2.Logging.Password.Rollover))])
                            self._leafs = OrderedDict()

                            self.configuration_conf = Native.Mpls.Ldp.Enable2.Logging.Password.ConfigurationConf()
                            self.configuration_conf.parent = self
                            self._children_name_map["configuration_conf"] = "configuration-conf"

                            self.rollover_conf = Native.Mpls.Ldp.Enable2.Logging.Password.RolloverConf()
                            self.rollover_conf.parent = self
                            self._children_name_map["rollover_conf"] = "rollover-conf"

                            self.configuration = None
                            self._children_name_map["configuration"] = "configuration"

                            self.rollover = None
                            self._children_name_map["rollover"] = "rollover"
                            self._segment_path = lambda: "password"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/logging/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Logging.Password, [], name, value)


                        class ConfigurationConf(Entity):
                            """
                            
                            
                            .. attribute:: configuration
                            
                            	
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Logging.Password.ConfigurationConf, self).__init__()

                                self.yang_name = "configuration-conf"
                                self.yang_parent_name = "password"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('configuration', (YLeaf(YType.boolean, 'configuration'), ['bool'])),
                                ])
                                self.configuration = None
                                self._segment_path = lambda: "configuration-conf"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/logging/password/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Logging.Password.ConfigurationConf, [u'configuration'], name, value)


                        class RolloverConf(Entity):
                            """
                            
                            
                            .. attribute:: rollover
                            
                            	
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Logging.Password.RolloverConf, self).__init__()

                                self.yang_name = "rollover-conf"
                                self.yang_parent_name = "password"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rollover', (YLeaf(YType.boolean, 'rollover'), ['bool'])),
                                ])
                                self.rollover = None
                                self._segment_path = lambda: "rollover-conf"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/logging/password/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Logging.Password.RolloverConf, [u'rollover'], name, value)


                        class Configuration(Entity):
                            """
                            Log LDP password configuration changes
                            
                            .. attribute:: rate_limit
                            
                            	Messages per minute
                            	**type**\: int
                            
                            	**range:** 1..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Logging.Password.Configuration, self).__init__()

                                self.yang_name = "configuration"
                                self.yang_parent_name = "password"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('rate_limit', (YLeaf(YType.uint8, 'rate-limit'), ['int'])),
                                ])
                                self.rate_limit = None
                                self._segment_path = lambda: "configuration"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/logging/password/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Logging.Password.Configuration, [u'rate_limit'], name, value)


                        class Rollover(Entity):
                            """
                            Log LDP password rollover events
                            
                            .. attribute:: rate_limit
                            
                            	Messages per minute
                            	**type**\: int
                            
                            	**range:** 1..60
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Logging.Password.Rollover, self).__init__()

                                self.yang_name = "rollover"
                                self.yang_parent_name = "password"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('rate_limit', (YLeaf(YType.uint8, 'rate-limit'), ['int'])),
                                ])
                                self.rate_limit = None
                                self._segment_path = lambda: "rollover"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/logging/password/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Logging.Password.Rollover, [u'rate_limit'], name, value)


                class Neighbor(Entity):
                    """
                    
                    
                    .. attribute:: neighbor_content
                    
                    	Configure neighbor parameters
                    	**type**\: list of  		 :py:class:`NeighborContent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent>`
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-content", ("neighbor_content", Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent)), ("vrf", ("vrf", Native.Mpls.Ldp.Enable2.Neighbor.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = Native.Mpls.Ldp.Enable2.Neighbor.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.neighbor_content = YList(self)
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Neighbor, [], name, value)


                    class NeighborContent(Entity):
                        """
                        Configure neighbor parameters
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: implicit_withdraw
                        
                        	Enable LDP Implicit Withdraw Label
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: labels
                        
                        	Configure label binding exchange controls
                        	**type**\:  :py:class:`Labels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Labels>`
                        
                        .. attribute:: password
                        
                        	Set a password
                        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Password>`
                        
                        .. attribute:: targeted
                        
                        	Establish targeted session
                        	**type**\:  :py:class:`Targeted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Targeted>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent, self).__init__()

                            self.yang_name = "neighbor-content"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([("labels", ("labels", Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Labels)), ("password", ("password", Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Password)), ("targeted", ("targeted", Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Targeted))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('implicit_withdraw', (YLeaf(YType.empty, 'implicit-withdraw'), ['Empty'])),
                            ])
                            self.address = None
                            self.implicit_withdraw = None

                            self.labels = Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Labels()
                            self.labels.parent = self
                            self._children_name_map["labels"] = "labels"

                            self.password = Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Password()
                            self.password.parent = self
                            self._children_name_map["password"] = "password"

                            self.targeted = None
                            self._children_name_map["targeted"] = "targeted"
                            self._segment_path = lambda: "neighbor-content" + "[address='" + str(self.address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/neighbor/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent, [u'address', u'implicit_withdraw'], name, value)


                        class Labels(Entity):
                            """
                            Configure label binding exchange controls
                            
                            .. attribute:: accept
                            
                            	Specify label bindings to accept
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Labels, self).__init__()

                                self.yang_name = "labels"
                                self.yang_parent_name = "neighbor-content"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('accept', (YLeaf(YType.str, 'accept'), ['str'])),
                                ])
                                self.accept = None
                                self._segment_path = lambda: "labels"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Labels, [u'accept'], name, value)


                        class Password(Entity):
                            """
                            Set a password
                            
                            .. attribute:: enctype
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: text
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z].\*
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Password, self).__init__()

                                self.yang_name = "password"
                                self.yang_parent_name = "neighbor-content"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                ])
                                self.enctype = None
                                self.text = None
                                self._segment_path = lambda: "password"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Password, [u'enctype', u'text'], name, value)


                        class Targeted(Entity):
                            """
                            Establish targeted session
                            
                            .. attribute:: protocol
                            
                            	
                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Targeted.Protocol>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Targeted, self).__init__()

                                self.yang_name = "targeted"
                                self.yang_parent_name = "neighbor-content"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.Ldp.Enable2.Neighbor.NeighborContent.Targeted.Protocol')])),
                                ])
                                self.protocol = None
                                self._segment_path = lambda: "targeted"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Neighbor.NeighborContent.Targeted, [u'protocol'], name, value)

                            class Protocol(Enum):
                                """
                                Protocol (Enum Class)

                                .. data:: ldp = 0

                                .. data:: tdp = 1

                                """

                                ldp = Enum.YLeaf(0, "ldp")

                                tdp = Enum.YLeaf(1, "tdp")



                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: vrf
                        
                        	
                        	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Neighbor.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_))])
                            self._leafs = OrderedDict()

                            self.vrf = YList(self)
                            self._segment_path = lambda: "vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/neighbor/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Neighbor.Vrf, [], name, value)


                        class Vrf_(Entity):
                            """
                            
                            
                            .. attribute:: vrf_name  (key)
                            
                            	VPN Routing/Forwarding instance name
                            	**type**\: str
                            
                            .. attribute:: neighbor_content
                            
                            	Configure neighbor parameters
                            	**type**\: list of  		 :py:class:`NeighborContent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['vrf_name']
                                self._child_classes = OrderedDict([("neighbor-content", ("neighbor_content", Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent))])
                                self._leafs = OrderedDict([
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ])
                                self.vrf_name = None

                                self.neighbor_content = YList(self)
                                self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/neighbor/vrf/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_, [u'vrf_name'], name, value)


                            class NeighborContent(Entity):
                                """
                                Configure neighbor parameters
                                
                                .. attribute:: address  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: implicit_withdraw
                                
                                	Enable LDP Implicit Withdraw Label
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: labels
                                
                                	Configure label binding exchange controls
                                	**type**\:  :py:class:`Labels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Labels>`
                                
                                .. attribute:: password
                                
                                	Set a password
                                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Password>`
                                
                                .. attribute:: targeted
                                
                                	Establish targeted session
                                	**type**\:  :py:class:`Targeted <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Targeted>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent, self).__init__()

                                    self.yang_name = "neighbor-content"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['address']
                                    self._child_classes = OrderedDict([("labels", ("labels", Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Labels)), ("password", ("password", Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Password)), ("targeted", ("targeted", Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Targeted))])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                        ('implicit_withdraw', (YLeaf(YType.empty, 'implicit-withdraw'), ['Empty'])),
                                    ])
                                    self.address = None
                                    self.implicit_withdraw = None

                                    self.labels = Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Labels()
                                    self.labels.parent = self
                                    self._children_name_map["labels"] = "labels"

                                    self.password = Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"

                                    self.targeted = None
                                    self._children_name_map["targeted"] = "targeted"
                                    self._segment_path = lambda: "neighbor-content" + "[address='" + str(self.address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent, [u'address', u'implicit_withdraw'], name, value)


                                class Labels(Entity):
                                    """
                                    Configure label binding exchange controls
                                    
                                    .. attribute:: accept
                                    
                                    	Specify label bindings to accept
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Labels, self).__init__()

                                        self.yang_name = "labels"
                                        self.yang_parent_name = "neighbor-content"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept', (YLeaf(YType.str, 'accept'), ['str'])),
                                        ])
                                        self.accept = None
                                        self._segment_path = lambda: "labels"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Labels, [u'accept'], name, value)


                                class Password(Entity):
                                    """
                                    Set a password
                                    
                                    .. attribute:: enctype
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: text
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z].\*
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "neighbor-content"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                            ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                        ])
                                        self.enctype = None
                                        self.text = None
                                        self._segment_path = lambda: "password"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Password, [u'enctype', u'text'], name, value)


                                class Targeted(Entity):
                                    """
                                    Establish targeted session
                                    
                                    .. attribute:: protocol
                                    
                                    	
                                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Targeted.Protocol>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Targeted, self).__init__()

                                        self.yang_name = "targeted"
                                        self.yang_parent_name = "neighbor-content"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Targeted.Protocol')])),
                                        ])
                                        self.protocol = None
                                        self._segment_path = lambda: "targeted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Neighbor.Vrf.Vrf_.NeighborContent.Targeted, [u'protocol'], name, value)

                                    class Protocol(Enum):
                                        """
                                        Protocol (Enum Class)

                                        .. data:: ldp = 0

                                        .. data:: tdp = 1

                                        """

                                        ldp = Enum.YLeaf(0, "ldp")

                                        tdp = Enum.YLeaf(1, "tdp")



                class Password(Entity):
                    """
                    Configure LDP MD5 password
                    
                    .. attribute:: fallback
                    
                    	Specifies a fallback password will follow
                    	**type**\:  :py:class:`Fallback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Password.Fallback>`
                    
                    .. attribute:: option
                    
                    	LDP password options
                    	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Password.Option>`
                    
                    .. attribute:: required
                    
                    	MD5 password is required for the peer
                    	**type**\:  :py:class:`Required <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Password.Required>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: rollover
                    
                    	LDP password rollover parameters
                    	**type**\:  :py:class:`Rollover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Password.Rollover>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("fallback", ("fallback", Native.Mpls.Ldp.Enable2.Password.Fallback)), ("option", ("option", Native.Mpls.Ldp.Enable2.Password.Option)), ("required", ("required", Native.Mpls.Ldp.Enable2.Password.Required)), ("rollover", ("rollover", Native.Mpls.Ldp.Enable2.Password.Rollover))])
                        self._leafs = OrderedDict()

                        self.fallback = Native.Mpls.Ldp.Enable2.Password.Fallback()
                        self.fallback.parent = self
                        self._children_name_map["fallback"] = "fallback"

                        self.option = Native.Mpls.Ldp.Enable2.Password.Option()
                        self.option.parent = self
                        self._children_name_map["option"] = "option"

                        self.required = None
                        self._children_name_map["required"] = "required"

                        self.rollover = Native.Mpls.Ldp.Enable2.Password.Rollover()
                        self.rollover.parent = self
                        self._children_name_map["rollover"] = "rollover"
                        self._segment_path = lambda: "password"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Password, [], name, value)


                    class Fallback(Entity):
                        """
                        Specifies a fallback password will follow
                        
                        .. attribute:: encryption_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: line
                        
                        	The UNENCRYPTED (cleartext) password
                        	**type**\: str
                        
                        .. attribute:: key_chain
                        
                        	Specifies a key\-chain name will follow
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Password.Fallback.KeyChain>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Password.Fallback, self).__init__()

                            self.yang_name = "fallback"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Mpls.Ldp.Enable2.Password.Fallback.KeyChain))])
                            self._leafs = OrderedDict([
                                ('encryption_type', (YLeaf(YType.uint8, 'encryption-type'), ['int'])),
                                ('line', (YLeaf(YType.str, 'LINE'), ['str'])),
                            ])
                            self.encryption_type = None
                            self.line = None

                            self.key_chain = None
                            self._children_name_map["key_chain"] = "key-chain"
                            self._segment_path = lambda: "fallback"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/password/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Password.Fallback, [u'encryption_type', u'line'], name, value)


                        class KeyChain(Entity):
                            """
                            Specifies a key\-chain name will follow
                            
                            .. attribute:: line
                            
                            	help
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Password.Fallback.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "fallback"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('line', (YLeaf(YType.str, 'LINE'), ['str'])),
                                ])
                                self.line = None
                                self._segment_path = lambda: "key-chain"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/password/fallback/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Password.Fallback.KeyChain, [u'line'], name, value)


                    class Option(Entity):
                        """
                        LDP password options
                        
                        .. attribute:: seq_num
                        
                        	
                        	**type**\: list of  		 :py:class:`SeqNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Password.Option.SeqNum>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Password.Option, self).__init__()

                            self.yang_name = "option"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("seq-num", ("seq_num", Native.Mpls.Ldp.Enable2.Password.Option.SeqNum))])
                            self._leafs = OrderedDict()

                            self.seq_num = YList(self)
                            self._segment_path = lambda: "option"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/password/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Password.Option, [], name, value)


                        class SeqNum(Entity):
                            """
                            
                            
                            .. attribute:: seq_num  (key)
                            
                            	Sequence number of the LDP password option
                            	**type**\: int
                            
                            	**range:** 1..32767
                            
                            .. attribute:: for_
                            
                            	IP access\-list specifying control on LDP peers
                            	**type**\:  :py:class:`For <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Password.Option.SeqNum, self).__init__()

                                self.yang_name = "seq-num"
                                self.yang_parent_name = "option"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['seq_num']
                                self._child_classes = OrderedDict([("for", ("for_", Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For))])
                                self._leafs = OrderedDict([
                                    ('seq_num', (YLeaf(YType.uint16, 'seq-num'), ['int'])),
                                ])
                                self.seq_num = None

                                self.for_ = Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For()
                                self.for_.parent = self
                                self._children_name_map["for_"] = "for"
                                self._segment_path = lambda: "seq-num" + "[seq-num='" + str(self.seq_num) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/password/option/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Password.Option.SeqNum, [u'seq_num'], name, value)


                            class For(Entity):
                                """
                                IP access\-list specifying control on LDP peers
                                
                                .. attribute:: line
                                
                                	
                                	**type**\: list of  		 :py:class:`LINE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For.LINE>`
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For, self).__init__()

                                    self.yang_name = "for"
                                    self.yang_parent_name = "seq-num"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("LINE", ("line", Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For.LINE))])
                                    self._leafs = OrderedDict()

                                    self.line = YList(self)
                                    self._segment_path = lambda: "for"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For, [], name, value)


                                class LINE(Entity):
                                    """
                                    
                                    
                                    .. attribute:: acl_name  (key)
                                    
                                    	IP standard access\-list for LDP peers; name or number (1\-99)
                                    	**type**\: str
                                    
                                    .. attribute:: encryption_type
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: line
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_chain
                                    
                                    	Specifies a key\-chain name will follow
                                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For.LINE.KeyChain>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For.LINE, self).__init__()

                                        self.yang_name = "LINE"
                                        self.yang_parent_name = "for"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['acl_name']
                                        self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For.LINE.KeyChain))])
                                        self._leafs = OrderedDict([
                                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                            ('encryption_type', (YLeaf(YType.uint8, 'encryption-type'), ['int'])),
                                            ('line', (YLeaf(YType.str, 'LINE'), ['str'])),
                                        ])
                                        self.acl_name = None
                                        self.encryption_type = None
                                        self.line = None

                                        self.key_chain = None
                                        self._children_name_map["key_chain"] = "key-chain"
                                        self._segment_path = lambda: "LINE" + "[acl-name='" + str(self.acl_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For.LINE, [u'acl_name', u'encryption_type', u'line'], name, value)


                                    class KeyChain(Entity):
                                        """
                                        Specifies a key\-chain name will follow
                                        
                                        .. attribute:: line
                                        
                                        	help
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-mpls'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For.LINE.KeyChain, self).__init__()

                                            self.yang_name = "key-chain"
                                            self.yang_parent_name = "LINE"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('line', (YLeaf(YType.str, 'LINE'), ['str'])),
                                            ])
                                            self.line = None
                                            self._segment_path = lambda: "key-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Password.Option.SeqNum.For.LINE.KeyChain, [u'line'], name, value)


                    class Required(Entity):
                        """
                        MD5 password is required for the peer
                        
                        .. attribute:: for_
                        
                        	IP access\-list specifying control on LDP peers
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Password.Required, self).__init__()

                            self.yang_name = "required"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('for_', (YLeaf(YType.str, 'for'), ['str'])),
                            ])
                            self.for_ = None
                            self._segment_path = lambda: "required"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/password/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Password.Required, [u'for_'], name, value)


                    class Rollover(Entity):
                        """
                        LDP password rollover parameters
                        
                        .. attribute:: duration
                        
                        	Configure LDP password rollover duration in minutes
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Password.Rollover, self).__init__()

                            self.yang_name = "rollover"
                            self.yang_parent_name = "password"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('duration', (YLeaf(YType.uint16, 'duration'), ['int'])),
                            ])
                            self.duration = None
                            self._segment_path = lambda: "rollover"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/password/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Password.Rollover, [u'duration'], name, value)


                class RequestLabels(Entity):
                    """
                    Access list to specify valid downstream on demand destinations.
                    
                    .. attribute:: for_
                    
                    	Access list to specify acceptable downstream on demand destinations
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.RequestLabels, self).__init__()

                        self.yang_name = "request-labels"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('for_', (YLeaf(YType.str, 'for'), ['str'])),
                        ])
                        self.for_ = None
                        self._segment_path = lambda: "request-labels"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.RequestLabels, [u'for_'], name, value)


                class RouterId(Entity):
                    """
                    Select interface to prefer for LDP identifier address
                    
                    .. attribute:: interface
                    
                    	
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId.Interface>`
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.RouterId, self).__init__()

                        self.yang_name = "router-id"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Native.Mpls.Ldp.Enable2.RouterId.Interface)), ("vrf", ("vrf", Native.Mpls.Ldp.Enable2.RouterId.Vrf))])
                        self._leafs = OrderedDict()

                        self.interface = Native.Mpls.Ldp.Enable2.RouterId.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"

                        self.vrf = YList(self)
                        self._segment_path = lambda: "router-id"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId, [], name, value)


                    class Interface(Entity):
                        """
                        
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId.Interface.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId.Interface.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId.Interface.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId.Interface.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: force
                        
                        	Forcibly change the LDP router id
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.RouterId.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "router-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Mpls.Ldp.Enable2.RouterId.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Mpls.Ldp.Enable2.RouterId.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Mpls.Ldp.Enable2.RouterId.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Mpls.Ldp.Enable2.RouterId.Interface.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ('force', (YLeaf(YType.empty, 'force'), ['Empty'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None
                            self.force = None

                            self.atm_subinterface = Native.Mpls.Ldp.Enable2.RouterId.Interface.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Mpls.Ldp.Enable2.RouterId.Interface.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Mpls.Ldp.Enable2.RouterId.Interface.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Mpls.Ldp.Enable2.RouterId.Interface.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/router-id/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright', u'force'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.RouterId.Interface.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/router-id/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId.Interface.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.RouterId.Interface.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/router-id/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.RouterId.Interface.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/router-id/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId.Interface.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.RouterId.Interface.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/router-id/interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: vrf_name  (key)
                        
                        	VPN Routing/Forwarding instance name
                        	**type**\: str
                        
                        .. attribute:: interface
                        
                        	
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.RouterId.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "router-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['vrf_name']
                            self._child_classes = OrderedDict([("interface", ("interface", Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface))])
                            self._leafs = OrderedDict([
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.vrf_name = None

                            self.interface = Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/router-id/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId.Vrf, [u'vrf_name'], name, value)


                        class Interface(Entity):
                            """
                            
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: force
                            
                            	Forcibly change the LDP router id
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ('force', (YLeaf(YType.empty, 'force'), ['Empty'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None
                                self.force = None

                                self.atm_subinterface = Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright', u'force'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.RouterId.Vrf.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                class Tcp(Entity):
                    """
                    Set TCP parameters for LDP
                    
                    .. attribute:: pak_priority
                    
                    	Set (local) priority for LDP session TCP connection
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.Tcp, self).__init__()

                        self.yang_name = "tcp"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pak_priority', (YLeaf(YType.empty, 'pak-priority'), ['Empty'])),
                        ])
                        self.pak_priority = None
                        self._segment_path = lambda: "tcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Tcp, [u'pak_priority'], name, value)


                class Vrf(Entity):
                    """
                    
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf.Vrf_>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Enable2.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "enable2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Mpls.Ldp.Enable2.Vrf.Vrf_))])
                        self._leafs = OrderedDict()

                        self.vrf = YList(self)
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf, [], name, value)


                    class Vrf_(Entity):
                        """
                        
                        
                        .. attribute:: vrf_name  (key)
                        
                        	VPN Routing/Forwarding instance name
                        	**type**\: str
                        
                        .. attribute:: password
                        
                        	Configure LDP MD5 password
                        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Enable2.Vrf.Vrf_, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['vrf_name']
                            self._child_classes = OrderedDict([("password", ("password", Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password))])
                            self._leafs = OrderedDict([
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.vrf_name = None

                            self.password = Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password()
                            self.password.parent = self
                            self._children_name_map["password"] = "password"
                            self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/enable2/vrf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf.Vrf_, [u'vrf_name'], name, value)


                        class Password(Entity):
                            """
                            Configure LDP MD5 password
                            
                            .. attribute:: fallback
                            
                            	Specifies a fallback password will follow
                            	**type**\:  :py:class:`Fallback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Fallback>`
                            
                            .. attribute:: option
                            
                            	LDP password options
                            	**type**\:  :py:class:`Option <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option>`
                            
                            .. attribute:: required
                            
                            	MD5 password is required for the peer
                            	**type**\:  :py:class:`Required <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Required>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: rollover
                            
                            	LDP password rollover parameters
                            	**type**\:  :py:class:`Rollover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Rollover>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password, self).__init__()

                                self.yang_name = "password"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("fallback", ("fallback", Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Fallback)), ("option", ("option", Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option)), ("required", ("required", Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Required)), ("rollover", ("rollover", Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Rollover))])
                                self._leafs = OrderedDict()

                                self.fallback = Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Fallback()
                                self.fallback.parent = self
                                self._children_name_map["fallback"] = "fallback"

                                self.option = Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option()
                                self.option.parent = self
                                self._children_name_map["option"] = "option"

                                self.required = None
                                self._children_name_map["required"] = "required"

                                self.rollover = Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Rollover()
                                self.rollover.parent = self
                                self._children_name_map["rollover"] = "rollover"
                                self._segment_path = lambda: "password"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password, [], name, value)


                            class Fallback(Entity):
                                """
                                Specifies a fallback password will follow
                                
                                .. attribute:: encryption_type
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: line
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: key_chain
                                
                                	Specifies a key\-chain name will follow
                                	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Fallback.KeyChain>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Fallback, self).__init__()

                                    self.yang_name = "fallback"
                                    self.yang_parent_name = "password"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Fallback.KeyChain))])
                                    self._leafs = OrderedDict([
                                        ('encryption_type', (YLeaf(YType.uint8, 'encryption-type'), ['int'])),
                                        ('line', (YLeaf(YType.str, 'LINE'), ['str'])),
                                    ])
                                    self.encryption_type = None
                                    self.line = None

                                    self.key_chain = None
                                    self._children_name_map["key_chain"] = "key-chain"
                                    self._segment_path = lambda: "fallback"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Fallback, [u'encryption_type', u'line'], name, value)


                                class KeyChain(Entity):
                                    """
                                    Specifies a key\-chain name will follow
                                    
                                    .. attribute:: line
                                    
                                    	help
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Fallback.KeyChain, self).__init__()

                                        self.yang_name = "key-chain"
                                        self.yang_parent_name = "fallback"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('line', (YLeaf(YType.str, 'LINE'), ['str'])),
                                        ])
                                        self.line = None
                                        self._segment_path = lambda: "key-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Fallback.KeyChain, [u'line'], name, value)


                            class Option(Entity):
                                """
                                LDP password options
                                
                                .. attribute:: seq_num
                                
                                	
                                	**type**\: list of  		 :py:class:`SeqNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum>`
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option, self).__init__()

                                    self.yang_name = "option"
                                    self.yang_parent_name = "password"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("seq-num", ("seq_num", Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum))])
                                    self._leafs = OrderedDict()

                                    self.seq_num = YList(self)
                                    self._segment_path = lambda: "option"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option, [], name, value)


                                class SeqNum(Entity):
                                    """
                                    
                                    
                                    .. attribute:: seq_num  (key)
                                    
                                    	Sequence number of the LDP password option
                                    	**type**\: int
                                    
                                    	**range:** 1..32767
                                    
                                    .. attribute:: for_
                                    
                                    	IP access\-list specifying control on LDP peers
                                    	**type**\:  :py:class:`For <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For>`
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum, self).__init__()

                                        self.yang_name = "seq-num"
                                        self.yang_parent_name = "option"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['seq_num']
                                        self._child_classes = OrderedDict([("for", ("for_", Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For))])
                                        self._leafs = OrderedDict([
                                            ('seq_num', (YLeaf(YType.uint16, 'seq-num'), ['int'])),
                                        ])
                                        self.seq_num = None

                                        self.for_ = Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For()
                                        self.for_.parent = self
                                        self._children_name_map["for_"] = "for"
                                        self._segment_path = lambda: "seq-num" + "[seq-num='" + str(self.seq_num) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum, [u'seq_num'], name, value)


                                    class For(Entity):
                                        """
                                        IP access\-list specifying control on LDP peers
                                        
                                        .. attribute:: line
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`LINE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For.LINE>`
                                        
                                        

                                        """

                                        _prefix = 'ios-mpls'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For, self).__init__()

                                            self.yang_name = "for"
                                            self.yang_parent_name = "seq-num"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("LINE", ("line", Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For.LINE))])
                                            self._leafs = OrderedDict()

                                            self.line = YList(self)
                                            self._segment_path = lambda: "for"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For, [], name, value)


                                        class LINE(Entity):
                                            """
                                            
                                            
                                            .. attribute:: acl_name  (key)
                                            
                                            	IP standard access\-list for LDP peers; name or number (1\-99)
                                            	**type**\: str
                                            
                                            .. attribute:: encryption_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: line
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: key_chain
                                            
                                            	Specifies a key\-chain name will follow
                                            	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For.LINE.KeyChain>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-mpls'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For.LINE, self).__init__()

                                                self.yang_name = "LINE"
                                                self.yang_parent_name = "for"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['acl_name']
                                                self._child_classes = OrderedDict([("key-chain", ("key_chain", Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For.LINE.KeyChain))])
                                                self._leafs = OrderedDict([
                                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                    ('encryption_type', (YLeaf(YType.uint8, 'encryption-type'), ['int'])),
                                                    ('line', (YLeaf(YType.str, 'LINE'), ['str'])),
                                                ])
                                                self.acl_name = None
                                                self.encryption_type = None
                                                self.line = None

                                                self.key_chain = None
                                                self._children_name_map["key_chain"] = "key-chain"
                                                self._segment_path = lambda: "LINE" + "[acl-name='" + str(self.acl_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For.LINE, [u'acl_name', u'encryption_type', u'line'], name, value)


                                            class KeyChain(Entity):
                                                """
                                                Specifies a key\-chain name will follow
                                                
                                                .. attribute:: line
                                                
                                                	help
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-mpls'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For.LINE.KeyChain, self).__init__()

                                                    self.yang_name = "key-chain"
                                                    self.yang_parent_name = "LINE"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('line', (YLeaf(YType.str, 'LINE'), ['str'])),
                                                    ])
                                                    self.line = None
                                                    self._segment_path = lambda: "key-chain"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Option.SeqNum.For.LINE.KeyChain, [u'line'], name, value)


                            class Required(Entity):
                                """
                                MD5 password is required for the peer
                                
                                .. attribute:: for_
                                
                                	IP access\-list specifying control on LDP peers
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Required, self).__init__()

                                    self.yang_name = "required"
                                    self.yang_parent_name = "password"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('for_', (YLeaf(YType.str, 'for'), ['str'])),
                                    ])
                                    self.for_ = None
                                    self._segment_path = lambda: "required"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Required, [u'for_'], name, value)


                            class Rollover(Entity):
                                """
                                LDP password rollover parameters
                                
                                .. attribute:: duration
                                
                                	Configure LDP password rollover duration in minutes
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Rollover, self).__init__()

                                    self.yang_name = "rollover"
                                    self.yang_parent_name = "password"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('duration', (YLeaf(YType.uint16, 'duration'), ['int'])),
                                    ])
                                    self.duration = None
                                    self._segment_path = lambda: "rollover"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Enable2.Vrf.Vrf_.Password.Rollover, [u'duration'], name, value)


            class Session(Entity):
                """
                Configure session parameters
                
                .. attribute:: protection
                
                	Configure session protection parameters
                	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Session.Protection>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.Ldp.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "ldp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("protection", ("protection", Native.Mpls.Ldp.Session.Protection))])
                    self._leafs = OrderedDict()

                    self.protection = None
                    self._children_name_map["protection"] = "protection"
                    self._segment_path = lambda: "session"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.Ldp.Session, [], name, value)


                class Protection(Entity):
                    """
                    Configure session protection parameters
                    
                    .. attribute:: duration
                    
                    	Period to sustain session protection after loss of link discovery
                    	**type**\:  :py:class:`Duration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Session.Protection.Duration>`
                    
                    .. attribute:: for_
                    
                    	Access\-list to specify LDP peers
                    	**type**\:  :py:class:`For <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Session.Protection.For>`
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding instance name
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Session.Protection.Vrf>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Ldp.Session.Protection, self).__init__()

                        self.yang_name = "protection"
                        self.yang_parent_name = "session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("duration", ("duration", Native.Mpls.Ldp.Session.Protection.Duration)), ("for", ("for_", Native.Mpls.Ldp.Session.Protection.For)), ("vrf", ("vrf", Native.Mpls.Ldp.Session.Protection.Vrf))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.duration = Native.Mpls.Ldp.Session.Protection.Duration()
                        self.duration.parent = self
                        self._children_name_map["duration"] = "duration"

                        self.for_ = Native.Mpls.Ldp.Session.Protection.For()
                        self.for_.parent = self
                        self._children_name_map["for_"] = "for"

                        self.vrf = Native.Mpls.Ldp.Session.Protection.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._segment_path = lambda: "protection"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/session/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Ldp.Session.Protection, [], name, value)


                    class Duration(Entity):
                        """
                        Period to sustain session protection after loss of link discovery
                        
                        .. attribute:: holdup_time
                        
                        	Holdup time in seconds
                        	**type**\: int
                        
                        	**range:** 30..2147483
                        
                        .. attribute:: infinite
                        
                        	Protect session forever after loss of link discovery
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Session.Protection.Duration, self).__init__()

                            self.yang_name = "duration"
                            self.yang_parent_name = "protection"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('holdup_time', (YLeaf(YType.uint32, 'holdup-time'), ['int'])),
                                ('infinite', (YLeaf(YType.empty, 'infinite'), ['Empty'])),
                            ])
                            self.holdup_time = None
                            self.infinite = None
                            self._segment_path = lambda: "duration"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/session/protection/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Session.Protection.Duration, [u'holdup_time', u'infinite'], name, value)


                    class For(Entity):
                        """
                        Access\-list to specify LDP peers
                        
                        .. attribute:: acl_name
                        
                        	IP access\-list for LDP peers; name or number (1\-99)
                        	**type**\: str
                        
                        .. attribute:: duration
                        
                        	Period to sustain session protection after loss of link discovery
                        	**type**\:  :py:class:`Duration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Session.Protection.For.Duration>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Session.Protection.For, self).__init__()

                            self.yang_name = "for"
                            self.yang_parent_name = "protection"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("duration", ("duration", Native.Mpls.Ldp.Session.Protection.For.Duration))])
                            self._leafs = OrderedDict([
                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                            ])
                            self.acl_name = None

                            self.duration = Native.Mpls.Ldp.Session.Protection.For.Duration()
                            self.duration.parent = self
                            self._children_name_map["duration"] = "duration"
                            self._segment_path = lambda: "for"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/session/protection/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Session.Protection.For, [u'acl_name'], name, value)


                        class Duration(Entity):
                            """
                            Period to sustain session protection after loss of link discovery
                            
                            .. attribute:: holdup_time
                            
                            	Holdup time in seconds
                            	**type**\: int
                            
                            	**range:** 30..2147483
                            
                            .. attribute:: infinite
                            
                            	Protect session forever after loss of link discovery
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Session.Protection.For.Duration, self).__init__()

                                self.yang_name = "duration"
                                self.yang_parent_name = "for"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('holdup_time', (YLeaf(YType.uint32, 'holdup-time'), ['int'])),
                                    ('infinite', (YLeaf(YType.empty, 'infinite'), ['Empty'])),
                                ])
                                self.holdup_time = None
                                self.infinite = None
                                self._segment_path = lambda: "duration"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/session/protection/for/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Session.Protection.For.Duration, [u'holdup_time', u'infinite'], name, value)


                    class Vrf(Entity):
                        """
                        VPN Routing/Forwarding instance name
                        
                        .. attribute:: vrf
                        
                        	
                        	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Ldp.Session.Protection.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "protection"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_))])
                            self._leafs = OrderedDict()

                            self.vrf = YList(self)
                            self._segment_path = lambda: "vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/session/protection/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Ldp.Session.Protection.Vrf, [], name, value)


                        class Vrf_(Entity):
                            """
                            
                            
                            .. attribute:: vrf_name  (key)
                            
                            	VPN Routing/Forwarding instance name
                            	**type**\: str
                            
                            .. attribute:: for_
                            
                            	Access\-list to specify LDP peers
                            	**type**\:  :py:class:`For <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.For>`
                            
                            .. attribute:: duration
                            
                            	Period to sustain session protection after loss of link discovery
                            	**type**\:  :py:class:`Duration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.Duration>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['vrf_name']
                                self._child_classes = OrderedDict([("for", ("for_", Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.For)), ("duration", ("duration", Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.Duration))])
                                self._leafs = OrderedDict([
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ])
                                self.vrf_name = None

                                self.for_ = Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.For()
                                self.for_.parent = self
                                self._children_name_map["for_"] = "for"

                                self.duration = Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.Duration()
                                self.duration.parent = self
                                self._children_name_map["duration"] = "duration"
                                self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:ldp/session/protection/vrf/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_, [u'vrf_name'], name, value)


                            class For(Entity):
                                """
                                Access\-list to specify LDP peers
                                
                                .. attribute:: acl_name
                                
                                	IP access\-list for LDP peers; name or number (1\-99)
                                	**type**\: str
                                
                                .. attribute:: duration
                                
                                	Period to sustain session protection after loss of link discovery
                                	**type**\:  :py:class:`Duration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.For.Duration>`
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.For, self).__init__()

                                    self.yang_name = "for"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("duration", ("duration", Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.For.Duration))])
                                    self._leafs = OrderedDict([
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ])
                                    self.acl_name = None

                                    self.duration = Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.For.Duration()
                                    self.duration.parent = self
                                    self._children_name_map["duration"] = "duration"
                                    self._segment_path = lambda: "for"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.For, [u'acl_name'], name, value)


                                class Duration(Entity):
                                    """
                                    Period to sustain session protection after loss of link discovery
                                    
                                    .. attribute:: holdup_time
                                    
                                    	Holdup time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 30..2147483
                                    
                                    .. attribute:: infinite
                                    
                                    	Protect session forever after loss of link discovery
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.For.Duration, self).__init__()

                                        self.yang_name = "duration"
                                        self.yang_parent_name = "for"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('holdup_time', (YLeaf(YType.uint32, 'holdup-time'), ['int'])),
                                            ('infinite', (YLeaf(YType.empty, 'infinite'), ['Empty'])),
                                        ])
                                        self.holdup_time = None
                                        self.infinite = None
                                        self._segment_path = lambda: "duration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.For.Duration, [u'holdup_time', u'infinite'], name, value)


                            class Duration(Entity):
                                """
                                Period to sustain session protection after loss of link discovery
                                
                                .. attribute:: holdup_time
                                
                                	Holdup time in seconds
                                	**type**\: int
                                
                                	**range:** 30..2147483
                                
                                .. attribute:: infinite
                                
                                	Protect session forever after loss of link discovery
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.Duration, self).__init__()

                                    self.yang_name = "duration"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('holdup_time', (YLeaf(YType.uint32, 'holdup-time'), ['int'])),
                                        ('infinite', (YLeaf(YType.empty, 'infinite'), ['Empty'])),
                                    ])
                                    self.holdup_time = None
                                    self.infinite = None
                                    self._segment_path = lambda: "duration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.Ldp.Session.Protection.Vrf.Vrf_.Duration, [u'holdup_time', u'infinite'], name, value)


        class PrefixMap(Entity):
            """
            Configure MPLS CoS Tag\-VC Multi\-VC Prefix Map
            
            .. attribute:: nr
            
            	
            	**type**\: int
            
            	**range:** 1..255
            
            .. attribute:: access_list
            
            	Configure access\-list for this prefix\-map
            	**type**\: int
            
            	**range:** 1..255
            
            .. attribute:: cos_map
            
            	Configure cos\-map for this prefix\-map
            	**type**\: int
            
            	**range:** 1..255
            
            

            """

            _prefix = 'ios-mpls'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Mpls.PrefixMap, self).__init__()

                self.yang_name = "prefix-map"
                self.yang_parent_name = "mpls"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('nr', (YLeaf(YType.uint8, 'nr'), ['int'])),
                    ('access_list', (YLeaf(YType.uint8, 'access-list'), ['int'])),
                    ('cos_map', (YLeaf(YType.uint8, 'cos-map'), ['int'])),
                ])
                self.nr = None
                self.access_list = None
                self.cos_map = None
                self._segment_path = lambda: "Cisco-IOS-XE-mpls:prefix-map"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mpls.PrefixMap, [u'nr', u'access_list', u'cos_map'], name, value)


        class Static(Entity):
            """
            MPLS static application
            
            .. attribute:: binding
            
            	Establish static label bindings
            	**type**\:  :py:class:`Binding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Static.Binding>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-mpls'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Mpls.Static, self).__init__()

                self.yang_name = "static"
                self.yang_parent_name = "mpls"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("binding", ("binding", Native.Mpls.Static.Binding))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.binding = Native.Mpls.Static.Binding()
                self.binding.parent = self
                self._children_name_map["binding"] = "binding"
                self._segment_path = lambda: "Cisco-IOS-XE-mpls:static"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mpls.Static, [], name, value)


            class Binding(Entity):
                """
                Establish static label bindings
                
                .. attribute:: ipv4
                
                	Bind IPv4 destination with label
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Static.Binding.Ipv4>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.Static.Binding, self).__init__()

                    self.yang_name = "binding"
                    self.yang_parent_name = "static"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Mpls.Static.Binding.Ipv4))])
                    self._leafs = OrderedDict()

                    self.ipv4 = Native.Mpls.Static.Binding.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._segment_path = lambda: "binding"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:static/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.Static.Binding, [], name, value)


                class Ipv4(Entity):
                    """
                    Bind IPv4 destination with label
                    
                    .. attribute:: global_
                    
                    	
                    	**type**\: list of  		 :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Static.Binding.Ipv4.Global>`
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Static.Binding.Ipv4.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.Static.Binding.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "binding"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("global", ("global_", Native.Mpls.Static.Binding.Ipv4.Global)), ("vrf", ("vrf", Native.Mpls.Static.Binding.Ipv4.Vrf))])
                        self._leafs = OrderedDict()

                        self.global_ = YList(self)
                        self.vrf = YList(self)
                        self._segment_path = lambda: "ipv4"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:static/binding/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.Static.Binding.Ipv4, [], name, value)


                    class Global(Entity):
                        """
                        
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input
                        
                        	Incoming (local) label
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Static.Binding.Ipv4.Global.Input>`
                        
                        .. attribute:: output
                        
                        	Outgoing (remote) label
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Static.Binding.Ipv4.Global.Output>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Static.Binding.Ipv4.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['address','mask']
                            self._child_classes = OrderedDict([("input", ("input", Native.Mpls.Static.Binding.Ipv4.Global.Input)), ("output", ("output", Native.Mpls.Static.Binding.Ipv4.Global.Output))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                            ])
                            self.address = None
                            self.mask = None
                            self.label = None

                            self.input = Native.Mpls.Static.Binding.Ipv4.Global.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Mpls.Static.Binding.Ipv4.Global.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "global" + "[address='" + str(self.address) + "']" + "[mask='" + str(self.mask) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:static/binding/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Static.Binding.Ipv4.Global, [u'address', u'mask', u'label'], name, value)


                        class Input(Entity):
                            """
                            Incoming (local) label
                            
                            .. attribute:: label
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Static.Binding.Ipv4.Global.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                ])
                                self.label = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Static.Binding.Ipv4.Global.Input, [u'label'], name, value)


                        class Output(Entity):
                            """
                            Outgoing (remote) label
                            
                            .. attribute:: dst_next_hop
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Static.Binding.Ipv4.Vrf.Output.Label>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Static.Binding.Ipv4.Global.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dst_next_hop', (YLeaf(YType.str, 'dst-next-hop'), ['str'])),
                                    ('label', (YLeaf(YType.str, 'label'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.Static.Binding.Ipv4.Vrf.Output.Label')])),
                                ])
                                self.dst_next_hop = None
                                self.label = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Static.Binding.Ipv4.Global.Output, [u'dst_next_hop', u'label'], name, value)

                            class Label(Enum):
                                """
                                Label (Enum Class)

                                .. data:: explicit_null = 0

                                .. data:: implicit_null = 1

                                """

                                explicit_null = Enum.YLeaf(0, "explicit-null")

                                implicit_null = Enum.YLeaf(1, "implicit-null")



                    class Vrf(Entity):
                        """
                        
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input
                        
                        	Incoming (local) label
                        	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Static.Binding.Ipv4.Vrf.Input>`
                        
                        .. attribute:: output
                        
                        	Outgoing (remote) label
                        	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Static.Binding.Ipv4.Vrf.Output>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.Static.Binding.Ipv4.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name','address','mask']
                            self._child_classes = OrderedDict([("input", ("input", Native.Mpls.Static.Binding.Ipv4.Vrf.Input)), ("output", ("output", Native.Mpls.Static.Binding.Ipv4.Vrf.Output))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                            ])
                            self.name = None
                            self.address = None
                            self.mask = None
                            self.label = None

                            self.input = Native.Mpls.Static.Binding.Ipv4.Vrf.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"

                            self.output = Native.Mpls.Static.Binding.Ipv4.Vrf.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']" + "[address='" + str(self.address) + "']" + "[mask='" + str(self.mask) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:static/binding/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.Static.Binding.Ipv4.Vrf, [u'name', u'address', u'mask', u'label'], name, value)


                        class Input(Entity):
                            """
                            Incoming (local) label
                            
                            .. attribute:: label
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Static.Binding.Ipv4.Vrf.Input, self).__init__()

                                self.yang_name = "input"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                ])
                                self.label = None
                                self._segment_path = lambda: "input"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Static.Binding.Ipv4.Vrf.Input, [u'label'], name, value)


                        class Output(Entity):
                            """
                            Outgoing (remote) label
                            
                            .. attribute:: dst_next_hop
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\:  :py:class:`Label <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.Static.Binding.Ipv4.Vrf.Output.Label>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.Static.Binding.Ipv4.Vrf.Output, self).__init__()

                                self.yang_name = "output"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dst_next_hop', (YLeaf(YType.str, 'dst-next-hop'), ['str'])),
                                    ('label', (YLeaf(YType.str, 'label'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.Static.Binding.Ipv4.Vrf.Output.Label')])),
                                ])
                                self.dst_next_hop = None
                                self.label = None
                                self._segment_path = lambda: "output"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.Static.Binding.Ipv4.Vrf.Output, [u'dst_next_hop', u'label'], name, value)

                            class Label(Enum):
                                """
                                Label (Enum Class)

                                .. data:: explicit_null = 0

                                .. data:: implicit_null = 1

                                """

                                explicit_null = Enum.YLeaf(0, "explicit-null")

                                implicit_null = Enum.YLeaf(1, "implicit-null")



        class TrafficEng(Entity):
            """
            Configure Traffic Engineering parameters
            
            .. attribute:: auto_bw
            
            	auto\-bw parameters
            	**type**\:  :py:class:`AutoBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoBw>`
            
            .. attribute:: auto_tunnel
            
            	Configure automatic TE tunnels
            	**type**\:  :py:class:`AutoTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel>`
            
            .. attribute:: ds_te
            
            	Configure standard DS\-TE parameters
            	**type**\:  :py:class:`DsTe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.DsTe>`
            
            .. attribute:: fault_oam
            
            	Node level fault OAM configuration
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: fast_reroute
            
            	fast\-reroute parameters
            	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.FastReroute>`
            
            .. attribute:: link_management
            
            	Link Management configuration
            	**type**\:  :py:class:`LinkManagement <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.LinkManagement>`
            
            .. attribute:: logging
            
            	Trap logging configuration
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging>`
            
            .. attribute:: lsp
            
            	Configure LSP parameters
            	**type**\:  :py:class:`Lsp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp>`
            
            .. attribute:: nsr
            
            	TE NSR configuration
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: path_option
            
            	Configure path\-option
            	**type**\:  :py:class:`PathOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption>`
            
            .. attribute:: path_selection
            
            	Path Selection Configuration
            	**type**\:  :py:class:`PathSelection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathSelection>`
            
            .. attribute:: pcc
            
            	Path Computation Client form MPLS\-TE
            	**type**\:  :py:class:`Pcc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Pcc>`
            
            .. attribute:: reoptimize
            
            	Reoptimization parameters
            	**type**\:  :py:class:`Reoptimize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Reoptimize>`
            
            .. attribute:: signalling
            
            	Traffic Engineering Signalling Parameters
            	**type**\:  :py:class:`Signalling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Signalling>`
            
            .. attribute:: topology
            
            	Topology Database Configuration
            	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Topology>`
            
            .. attribute:: trace
            
            	Trace configuration
            	**type**\:  :py:class:`Trace <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Trace>`
            
            .. attribute:: tunnels
            
            	Traffic Engineering tunnels
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-mpls'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Mpls.TrafficEng, self).__init__()

                self.yang_name = "traffic-eng"
                self.yang_parent_name = "mpls"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("auto-bw", ("auto_bw", Native.Mpls.TrafficEng.AutoBw)), ("auto-tunnel", ("auto_tunnel", Native.Mpls.TrafficEng.AutoTunnel)), ("ds-te", ("ds_te", Native.Mpls.TrafficEng.DsTe)), ("fast-reroute", ("fast_reroute", Native.Mpls.TrafficEng.FastReroute)), ("link-management", ("link_management", Native.Mpls.TrafficEng.LinkManagement)), ("logging", ("logging", Native.Mpls.TrafficEng.Logging)), ("lsp", ("lsp", Native.Mpls.TrafficEng.Lsp)), ("path-option", ("path_option", Native.Mpls.TrafficEng.PathOption)), ("path-selection", ("path_selection", Native.Mpls.TrafficEng.PathSelection)), ("pcc", ("pcc", Native.Mpls.TrafficEng.Pcc)), ("reoptimize", ("reoptimize", Native.Mpls.TrafficEng.Reoptimize)), ("signalling", ("signalling", Native.Mpls.TrafficEng.Signalling)), ("topology", ("topology", Native.Mpls.TrafficEng.Topology)), ("trace", ("trace", Native.Mpls.TrafficEng.Trace))])
                self._leafs = OrderedDict([
                    ('fault_oam', (YLeaf(YType.empty, 'fault-oam'), ['Empty'])),
                    ('nsr', (YLeaf(YType.empty, 'nsr'), ['Empty'])),
                    ('tunnels', (YLeaf(YType.empty, 'tunnels'), ['Empty'])),
                ])
                self.fault_oam = None
                self.nsr = None
                self.tunnels = None

                self.auto_bw = Native.Mpls.TrafficEng.AutoBw()
                self.auto_bw.parent = self
                self._children_name_map["auto_bw"] = "auto-bw"

                self.auto_tunnel = Native.Mpls.TrafficEng.AutoTunnel()
                self.auto_tunnel.parent = self
                self._children_name_map["auto_tunnel"] = "auto-tunnel"

                self.ds_te = Native.Mpls.TrafficEng.DsTe()
                self.ds_te.parent = self
                self._children_name_map["ds_te"] = "ds-te"

                self.fast_reroute = Native.Mpls.TrafficEng.FastReroute()
                self.fast_reroute.parent = self
                self._children_name_map["fast_reroute"] = "fast-reroute"

                self.link_management = Native.Mpls.TrafficEng.LinkManagement()
                self.link_management.parent = self
                self._children_name_map["link_management"] = "link-management"

                self.logging = Native.Mpls.TrafficEng.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.lsp = Native.Mpls.TrafficEng.Lsp()
                self.lsp.parent = self
                self._children_name_map["lsp"] = "lsp"

                self.path_option = Native.Mpls.TrafficEng.PathOption()
                self.path_option.parent = self
                self._children_name_map["path_option"] = "path-option"

                self.path_selection = Native.Mpls.TrafficEng.PathSelection()
                self.path_selection.parent = self
                self._children_name_map["path_selection"] = "path-selection"

                self.pcc = Native.Mpls.TrafficEng.Pcc()
                self.pcc.parent = self
                self._children_name_map["pcc"] = "pcc"

                self.reoptimize = Native.Mpls.TrafficEng.Reoptimize()
                self.reoptimize.parent = self
                self._children_name_map["reoptimize"] = "reoptimize"

                self.signalling = Native.Mpls.TrafficEng.Signalling()
                self.signalling.parent = self
                self._children_name_map["signalling"] = "signalling"

                self.topology = Native.Mpls.TrafficEng.Topology()
                self.topology.parent = self
                self._children_name_map["topology"] = "topology"

                self.trace = Native.Mpls.TrafficEng.Trace()
                self.trace.parent = self
                self._children_name_map["trace"] = "trace"
                self._segment_path = lambda: "Cisco-IOS-XE-mpls:traffic-eng"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Mpls.TrafficEng, [u'fault_oam', u'nsr', u'tunnels'], name, value)


            class AutoBw(Entity):
                """
                auto\-bw parameters
                
                .. attribute:: timers
                
                	Enable auto\-bw Timers Collection and Application
                	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoBw.Timers>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.AutoBw, self).__init__()

                    self.yang_name = "auto-bw"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("timers", ("timers", Native.Mpls.TrafficEng.AutoBw.Timers))])
                    self._leafs = OrderedDict()

                    self.timers = None
                    self._children_name_map["timers"] = "timers"
                    self._segment_path = lambda: "auto-bw"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.AutoBw, [], name, value)


                class Timers(Entity):
                    """
                    Enable auto\-bw Timers Collection and Application
                    
                    .. attribute:: frequency
                    
                    	Interval between auto\-bw data collection\: <1..604800> seconds
                    	**type**\: int
                    
                    	**range:** 1..604800
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.AutoBw.Timers, self).__init__()

                        self.yang_name = "timers"
                        self.yang_parent_name = "auto-bw"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('frequency', (YLeaf(YType.uint32, 'frequency'), ['int'])),
                        ])
                        self.frequency = None
                        self._segment_path = lambda: "timers"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-bw/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.AutoBw.Timers, [u'frequency'], name, value)


            class AutoTunnel(Entity):
                """
                Configure automatic TE tunnels
                
                .. attribute:: backup
                
                	Configure auto\-tunnel backup tunnel
                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup>`
                
                	**presence node**\: True
                
                .. attribute:: mesh
                
                	Automatically create mesh tunnels
                	**type**\:  :py:class:`Mesh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Mesh>`
                
                	**presence node**\: True
                
                .. attribute:: p2p
                
                	Enable and configure TE service P2P auto tunnels
                	**type**\:  :py:class:`P2p <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.P2p>`
                
                	**presence node**\: True
                
                .. attribute:: primary
                
                	Automatically create one\-hop primary tunnels
                	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.AutoTunnel, self).__init__()

                    self.yang_name = "auto-tunnel"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("backup", ("backup", Native.Mpls.TrafficEng.AutoTunnel.Backup)), ("mesh", ("mesh", Native.Mpls.TrafficEng.AutoTunnel.Mesh)), ("p2p", ("p2p", Native.Mpls.TrafficEng.AutoTunnel.P2p)), ("primary", ("primary", Native.Mpls.TrafficEng.AutoTunnel.Primary))])
                    self._leafs = OrderedDict()

                    self.backup = None
                    self._children_name_map["backup"] = "backup"

                    self.mesh = None
                    self._children_name_map["mesh"] = "mesh"

                    self.p2p = None
                    self._children_name_map["p2p"] = "p2p"

                    self.primary = Native.Mpls.TrafficEng.AutoTunnel.Primary()
                    self.primary.parent = self
                    self._children_name_map["primary"] = "primary"
                    self._segment_path = lambda: "auto-tunnel"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel, [], name, value)


                class Backup(Entity):
                    """
                    Configure auto\-tunnel backup tunnel
                    
                    .. attribute:: config
                    
                    	Config commands to apply to all backup auto\-tunnels
                    	**type**\:  :py:class:`Config <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Config>`
                    
                    .. attribute:: nhop_only
                    
                    	Automatically create n\-hop backup tunnels only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: srlg
                    
                    	Shared Risk Link Groups influence backup tunnel path selection
                    	**type**\:  :py:class:`Srlg <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Srlg>`
                    
                    .. attribute:: timers
                    
                    	Configure timers for backup auto\-tunnels
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers>`
                    
                    .. attribute:: tunnel_num
                    
                    	Configure tunnel I/F numbers for backup auto\-tunnels
                    	**type**\:  :py:class:`TunnelNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.TunnelNum>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.AutoTunnel.Backup, self).__init__()

                        self.yang_name = "backup"
                        self.yang_parent_name = "auto-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("config", ("config", Native.Mpls.TrafficEng.AutoTunnel.Backup.Config)), ("srlg", ("srlg", Native.Mpls.TrafficEng.AutoTunnel.Backup.Srlg)), ("timers", ("timers", Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers)), ("tunnel-num", ("tunnel_num", Native.Mpls.TrafficEng.AutoTunnel.Backup.TunnelNum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('nhop_only', (YLeaf(YType.empty, 'nhop-only'), ['Empty'])),
                        ])
                        self.nhop_only = None

                        self.config = Native.Mpls.TrafficEng.AutoTunnel.Backup.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.srlg = Native.Mpls.TrafficEng.AutoTunnel.Backup.Srlg()
                        self.srlg.parent = self
                        self._children_name_map["srlg"] = "srlg"

                        self.timers = Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.tunnel_num = Native.Mpls.TrafficEng.AutoTunnel.Backup.TunnelNum()
                        self.tunnel_num.parent = self
                        self._children_name_map["tunnel_num"] = "tunnel-num"
                        self._segment_path = lambda: "backup"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup, [u'nhop_only'], name, value)


                    class Config(Entity):
                        """
                        Config commands to apply to all backup auto\-tunnels
                        
                        .. attribute:: affinity_mask
                        
                        	desired link affinity attributes
                        	**type**\:  :py:class:`AffinityMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.AffinityMask>`
                        
                        .. attribute:: unnumbered_interface
                        
                        	Configure the interface to use for unnumbered
                        	**type**\:  :py:class:`UnnumberedInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("affinity-mask", ("affinity_mask", Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.AffinityMask)), ("unnumbered-interface", ("unnumbered_interface", Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface))])
                            self._leafs = OrderedDict()

                            self.affinity_mask = Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.AffinityMask()
                            self.affinity_mask.parent = self
                            self._children_name_map["affinity_mask"] = "affinity-mask"

                            self.unnumbered_interface = Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface()
                            self.unnumbered_interface.parent = self
                            self._children_name_map["unnumbered_interface"] = "unnumbered-interface"
                            self._segment_path = lambda: "config"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config, [], name, value)


                        class AffinityMask(Entity):
                            """
                            desired link affinity attributes
                            
                            .. attribute:: affinity
                            
                            	Desired link attributes for links comprising tunnel\: <0x0\-0xFFFFFFFF>
                            	**type**\: str
                            
                            	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                            
                            .. attribute:: mask
                            
                            	Mask on desired link attributes\: <0x0\-0xFFFFFFFF>
                            	**type**\: str
                            
                            	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.AffinityMask, self).__init__()

                                self.yang_name = "affinity-mask"
                                self.yang_parent_name = "config"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('affinity', (YLeaf(YType.str, 'affinity'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.affinity = None
                                self.mask = None
                                self._segment_path = lambda: "affinity-mask"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/config/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.AffinityMask, [u'affinity', u'mask'], name, value)


                        class UnnumberedInterface(Entity):
                            """
                            Configure the interface to use for unnumbered
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface, self).__init__()

                                self.yang_name = "unnumbered-interface"
                                self.yang_parent_name = "config"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "unnumbered-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/config/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.Config.UnnumberedInterface.PortChannelSubinterface, [u'port_channel'], name, value)


                    class Srlg(Entity):
                        """
                        Shared Risk Link Groups influence backup tunnel path selection
                        
                        .. attribute:: exclude
                        
                        	Backup tunnels avoid SRLGs of protected interfaces\: < force \| preferred >
                        	**type**\:  :py:class:`Exclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Srlg.Exclude>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.AutoTunnel.Backup.Srlg, self).__init__()

                            self.yang_name = "srlg"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('exclude', (YLeaf(YType.enumeration, 'exclude'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.TrafficEng.AutoTunnel.Backup.Srlg.Exclude')])),
                            ])
                            self.exclude = None
                            self._segment_path = lambda: "srlg"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.Srlg, [u'exclude'], name, value)

                        class Exclude(Enum):
                            """
                            Exclude (Enum Class)

                            Backup tunnels avoid SRLGs of protected interfaces\: < force \| preferred >

                            .. data:: force = 0

                            	Backup tunnels MUST not use SRLGs of protected interfaces

                            .. data:: preferred = 1

                            	Backup tunnels try to avoid using SRLGs of protected interfaces

                            """

                            force = Enum.YLeaf(0, "force")

                            preferred = Enum.YLeaf(1, "preferred")



                    class Timers(Entity):
                        """
                        Configure timers for backup auto\-tunnels
                        
                        .. attribute:: removal
                        
                        	Configure timer for removal of backup tunnel
                        	**type**\:  :py:class:`Removal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers.Removal>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("removal", ("removal", Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers.Removal))])
                            self._leafs = OrderedDict()

                            self.removal = Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers.Removal()
                            self.removal.parent = self
                            self._children_name_map["removal"] = "removal"
                            self._segment_path = lambda: "timers"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers, [], name, value)


                        class Removal(Entity):
                            """
                            Configure timer for removal of backup tunnel
                            
                            .. attribute:: unused
                            
                            	seconds between scanning to remove not in use tunnels
                            	**type**\:  :py:class:`Unused <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers.Removal.Unused>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers.Removal, self).__init__()

                                self.yang_name = "removal"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("unused", ("unused", Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers.Removal.Unused))])
                                self._leafs = OrderedDict()

                                self.unused = Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers.Removal.Unused()
                                self.unused.parent = self
                                self._children_name_map["unused"] = "unused"
                                self._segment_path = lambda: "removal"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/timers/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers.Removal, [], name, value)


                            class Unused(Entity):
                                """
                                seconds between scanning to remove not in use tunnels
                                
                                .. attribute:: interval
                                
                                	Seconds between scanning to remove not in use tunnels\: <0..604800> seconds
                                	**type**\: int
                                
                                	**range:** 0..604800
                                
                                .. attribute:: duration
                                
                                	 How long auto backup is unused before removal\: <0..604800> seconds, 0 = never remove
                                	**type**\: int
                                
                                	**range:** 0..604800
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers.Removal.Unused, self).__init__()

                                    self.yang_name = "unused"
                                    self.yang_parent_name = "removal"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                        ('duration', (YLeaf(YType.uint32, 'duration'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.duration = None
                                    self._segment_path = lambda: "unused"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/timers/removal/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.Timers.Removal.Unused, [u'interval', u'duration'], name, value)


                    class TunnelNum(Entity):
                        """
                        Configure tunnel I/F numbers for backup auto\-tunnels
                        
                        .. attribute:: min_max
                        
                        	Configure the starting id\-range
                        	**type**\:  :py:class:`MinMax <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Backup.TunnelNum.MinMax>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.AutoTunnel.Backup.TunnelNum, self).__init__()

                            self.yang_name = "tunnel-num"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("min-max", ("min_max", Native.Mpls.TrafficEng.AutoTunnel.Backup.TunnelNum.MinMax))])
                            self._leafs = OrderedDict()

                            self.min_max = Native.Mpls.TrafficEng.AutoTunnel.Backup.TunnelNum.MinMax()
                            self.min_max.parent = self
                            self._children_name_map["min_max"] = "min-max"
                            self._segment_path = lambda: "tunnel-num"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.TunnelNum, [], name, value)


                        class MinMax(Entity):
                            """
                            Configure the starting id\-range
                            
                            .. attribute:: min
                            
                            	starting tunnel number range
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: max
                            
                            	Configure the ending id\-range\: <0..65535>
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.AutoTunnel.Backup.TunnelNum.MinMax, self).__init__()

                                self.yang_name = "min-max"
                                self.yang_parent_name = "tunnel-num"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "min-max"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/backup/tunnel-num/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Backup.TunnelNum.MinMax, [u'min', u'max'], name, value)


                class Mesh(Entity):
                    """
                    Automatically create mesh tunnels
                    
                    .. attribute:: tunnel_num
                    
                    	Configure tunnel I/F numbers for mesh auto\-tunnels
                    	**type**\:  :py:class:`TunnelNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Mesh.TunnelNum>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.AutoTunnel.Mesh, self).__init__()

                        self.yang_name = "mesh"
                        self.yang_parent_name = "auto-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tunnel-num", ("tunnel_num", Native.Mpls.TrafficEng.AutoTunnel.Mesh.TunnelNum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.tunnel_num = Native.Mpls.TrafficEng.AutoTunnel.Mesh.TunnelNum()
                        self.tunnel_num.parent = self
                        self._children_name_map["tunnel_num"] = "tunnel-num"
                        self._segment_path = lambda: "mesh"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Mesh, [], name, value)


                    class TunnelNum(Entity):
                        """
                        Configure tunnel I/F numbers for mesh auto\-tunnels
                        
                        .. attribute:: min_max
                        
                        	Configure the starting id\-range
                        	**type**\:  :py:class:`MinMax <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Mesh.TunnelNum.MinMax>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.AutoTunnel.Mesh.TunnelNum, self).__init__()

                            self.yang_name = "tunnel-num"
                            self.yang_parent_name = "mesh"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("min-max", ("min_max", Native.Mpls.TrafficEng.AutoTunnel.Mesh.TunnelNum.MinMax))])
                            self._leafs = OrderedDict()

                            self.min_max = Native.Mpls.TrafficEng.AutoTunnel.Mesh.TunnelNum.MinMax()
                            self.min_max.parent = self
                            self._children_name_map["min_max"] = "min-max"
                            self._segment_path = lambda: "tunnel-num"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/mesh/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Mesh.TunnelNum, [], name, value)


                        class MinMax(Entity):
                            """
                            Configure the starting id\-range
                            
                            .. attribute:: min
                            
                            	starting tunnel number range
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: max
                            
                            	Configure the ending id\-range\: <0..65535>
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.AutoTunnel.Mesh.TunnelNum.MinMax, self).__init__()

                                self.yang_name = "min-max"
                                self.yang_parent_name = "tunnel-num"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "min-max"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/mesh/tunnel-num/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Mesh.TunnelNum.MinMax, [u'min', u'max'], name, value)


                class P2p(Entity):
                    """
                    Enable and configure TE service P2P auto tunnels
                    
                    .. attribute:: config
                    
                    	Config commands to apply to all TE service P2P auto\-tunnels
                    	**type**\:  :py:class:`Config <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.P2p.Config>`
                    
                    .. attribute:: tunnel_num
                    
                    	Configure tunnel I/F numbers for TE service P2P auto\-tunnels
                    	**type**\:  :py:class:`TunnelNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.P2p.TunnelNum>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.AutoTunnel.P2p, self).__init__()

                        self.yang_name = "p2p"
                        self.yang_parent_name = "auto-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("config", ("config", Native.Mpls.TrafficEng.AutoTunnel.P2p.Config)), ("tunnel-num", ("tunnel_num", Native.Mpls.TrafficEng.AutoTunnel.P2p.TunnelNum))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.config = Native.Mpls.TrafficEng.AutoTunnel.P2p.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.tunnel_num = Native.Mpls.TrafficEng.AutoTunnel.P2p.TunnelNum()
                        self.tunnel_num.parent = self
                        self._children_name_map["tunnel_num"] = "tunnel-num"
                        self._segment_path = lambda: "p2p"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.P2p, [], name, value)


                    class Config(Entity):
                        """
                        Config commands to apply to all TE service P2P auto\-tunnels
                        
                        .. attribute:: unnumbered_interface
                        
                        	Configure the interface to use for unnumbered
                        	**type**\:  :py:class:`UnnumberedInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "p2p"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("unnumbered-interface", ("unnumbered_interface", Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface))])
                            self._leafs = OrderedDict()

                            self.unnumbered_interface = Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface()
                            self.unnumbered_interface.parent = self
                            self._children_name_map["unnumbered_interface"] = "unnumbered-interface"
                            self._segment_path = lambda: "config"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/p2p/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config, [], name, value)


                        class UnnumberedInterface(Entity):
                            """
                            Configure the interface to use for unnumbered
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface, self).__init__()

                                self.yang_name = "unnumbered-interface"
                                self.yang_parent_name = "config"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "unnumbered-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/p2p/config/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/p2p/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/p2p/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/p2p/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/p2p/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.P2p.Config.UnnumberedInterface.PortChannelSubinterface, [u'port_channel'], name, value)


                    class TunnelNum(Entity):
                        """
                        Configure tunnel I/F numbers for TE service P2P auto\-tunnels
                        
                        .. attribute:: min_max
                        
                        	Configure the starting id\-range
                        	**type**\:  :py:class:`MinMax <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.P2p.TunnelNum.MinMax>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.AutoTunnel.P2p.TunnelNum, self).__init__()

                            self.yang_name = "tunnel-num"
                            self.yang_parent_name = "p2p"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("min-max", ("min_max", Native.Mpls.TrafficEng.AutoTunnel.P2p.TunnelNum.MinMax))])
                            self._leafs = OrderedDict()

                            self.min_max = Native.Mpls.TrafficEng.AutoTunnel.P2p.TunnelNum.MinMax()
                            self.min_max.parent = self
                            self._children_name_map["min_max"] = "min-max"
                            self._segment_path = lambda: "tunnel-num"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/p2p/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.P2p.TunnelNum, [], name, value)


                        class MinMax(Entity):
                            """
                            Configure the starting id\-range
                            
                            .. attribute:: min
                            
                            	starting tunnel number range
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: max
                            
                            	Configure the ending id\-range\: <0..65535>
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.AutoTunnel.P2p.TunnelNum.MinMax, self).__init__()

                                self.yang_name = "min-max"
                                self.yang_parent_name = "tunnel-num"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "min-max"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/p2p/tunnel-num/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.P2p.TunnelNum.MinMax, [u'min', u'max'], name, value)


                class Primary(Entity):
                    """
                    Automatically create one\-hop primary tunnels
                    
                    .. attribute:: config
                    
                    	Config commands to apply to all primary auto\-tunnels
                    	**type**\:  :py:class:`Config <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary.Config>`
                    
                    .. attribute:: onehop
                    
                    	Automatically create tunnel to all next\-hops
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: timers
                    
                    	Configure timers for primary auto\-tunnels
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary.Timers>`
                    
                    .. attribute:: tunnel_num
                    
                    	Configure tunnel I/F numbers for primary auto\-tunnels
                    	**type**\:  :py:class:`TunnelNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary.TunnelNum>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.AutoTunnel.Primary, self).__init__()

                        self.yang_name = "primary"
                        self.yang_parent_name = "auto-tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("config", ("config", Native.Mpls.TrafficEng.AutoTunnel.Primary.Config)), ("timers", ("timers", Native.Mpls.TrafficEng.AutoTunnel.Primary.Timers)), ("tunnel-num", ("tunnel_num", Native.Mpls.TrafficEng.AutoTunnel.Primary.TunnelNum))])
                        self._leafs = OrderedDict([
                            ('onehop', (YLeaf(YType.empty, 'onehop'), ['Empty'])),
                        ])
                        self.onehop = None

                        self.config = Native.Mpls.TrafficEng.AutoTunnel.Primary.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.timers = Native.Mpls.TrafficEng.AutoTunnel.Primary.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.tunnel_num = Native.Mpls.TrafficEng.AutoTunnel.Primary.TunnelNum()
                        self.tunnel_num.parent = self
                        self._children_name_map["tunnel_num"] = "tunnel-num"
                        self._segment_path = lambda: "primary"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary, [u'onehop'], name, value)


                    class Config(Entity):
                        """
                        Config commands to apply to all primary auto\-tunnels
                        
                        .. attribute:: mpls
                        
                        	Configure dynamic MPLS forwarding
                        	**type**\:  :py:class:`Mpls_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.Mpls_>`
                        
                        .. attribute:: unnumbered_interface
                        
                        	Configure the interface to use for unnumbered
                        	**type**\:  :py:class:`UnnumberedInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "primary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mpls", ("mpls", Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.Mpls_)), ("unnumbered-interface", ("unnumbered_interface", Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface))])
                            self._leafs = OrderedDict()

                            self.mpls = Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.Mpls_()
                            self.mpls.parent = self
                            self._children_name_map["mpls"] = "mpls"

                            self.unnumbered_interface = Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface()
                            self.unnumbered_interface.parent = self
                            self._children_name_map["unnumbered_interface"] = "unnumbered-interface"
                            self._segment_path = lambda: "config"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/primary/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config, [], name, value)


                        class Mpls_(Entity):
                            """
                            Configure dynamic MPLS forwarding
                            
                            .. attribute:: ip
                            
                            	Configure dynamic MPLS forwarding for ip
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.Mpls_, self).__init__()

                                self.yang_name = "mpls"
                                self.yang_parent_name = "config"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                ])
                                self.ip = None
                                self._segment_path = lambda: "mpls"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/primary/config/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.Mpls_, [u'ip'], name, value)


                        class UnnumberedInterface(Entity):
                            """
                            Configure the interface to use for unnumbered
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface, self).__init__()

                                self.yang_name = "unnumbered-interface"
                                self.yang_parent_name = "config"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "unnumbered-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/primary/config/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/primary/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/primary/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/primary/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "unnumbered-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/primary/config/unnumbered-interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary.Config.UnnumberedInterface.PortChannelSubinterface, [u'port_channel'], name, value)


                    class Timers(Entity):
                        """
                        Configure timers for primary auto\-tunnels
                        
                        .. attribute:: removal
                        
                        	Configure removal of primary tunnels
                        	**type**\:  :py:class:`Removal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary.Timers.Removal>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.AutoTunnel.Primary.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "primary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("removal", ("removal", Native.Mpls.TrafficEng.AutoTunnel.Primary.Timers.Removal))])
                            self._leafs = OrderedDict()

                            self.removal = Native.Mpls.TrafficEng.AutoTunnel.Primary.Timers.Removal()
                            self.removal.parent = self
                            self._children_name_map["removal"] = "removal"
                            self._segment_path = lambda: "timers"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/primary/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary.Timers, [], name, value)


                        class Removal(Entity):
                            """
                            Configure removal of primary tunnels
                            
                            .. attribute:: rerouted
                            
                            	How long auto\-tunnel primary can stay frr active\: <30..604800> seconds
                            	**type**\: int
                            
                            	**range:** 30..604800
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.AutoTunnel.Primary.Timers.Removal, self).__init__()

                                self.yang_name = "removal"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rerouted', (YLeaf(YType.uint32, 'rerouted'), ['int'])),
                                ])
                                self.rerouted = None
                                self._segment_path = lambda: "removal"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/primary/timers/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary.Timers.Removal, [u'rerouted'], name, value)


                    class TunnelNum(Entity):
                        """
                        Configure tunnel I/F numbers for primary auto\-tunnels
                        
                        .. attribute:: min_max
                        
                        	Configure the starting id\-range
                        	**type**\:  :py:class:`MinMax <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.AutoTunnel.Primary.TunnelNum.MinMax>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.AutoTunnel.Primary.TunnelNum, self).__init__()

                            self.yang_name = "tunnel-num"
                            self.yang_parent_name = "primary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("min-max", ("min_max", Native.Mpls.TrafficEng.AutoTunnel.Primary.TunnelNum.MinMax))])
                            self._leafs = OrderedDict()

                            self.min_max = Native.Mpls.TrafficEng.AutoTunnel.Primary.TunnelNum.MinMax()
                            self.min_max.parent = self
                            self._children_name_map["min_max"] = "min-max"
                            self._segment_path = lambda: "tunnel-num"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/primary/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary.TunnelNum, [], name, value)


                        class MinMax(Entity):
                            """
                            Configure the starting id\-range
                            
                            .. attribute:: min
                            
                            	starting tunnel number range
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: max
                            
                            	Configure the ending id\-range\: <0..65535>
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.AutoTunnel.Primary.TunnelNum.MinMax, self).__init__()

                                self.yang_name = "min-max"
                                self.yang_parent_name = "tunnel-num"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                ])
                                self.min = None
                                self.max = None
                                self._segment_path = lambda: "min-max"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/auto-tunnel/primary/tunnel-num/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.AutoTunnel.Primary.TunnelNum.MinMax, [u'min', u'max'], name, value)


            class DsTe(Entity):
                """
                Configure standard DS\-TE parameters
                
                .. attribute:: bc_model
                
                	Configure BC model\: < mam >
                	**type**\:  :py:class:`BcModel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.DsTe.BcModel>`
                
                .. attribute:: mode
                
                	Configure DS\-TE mode\: < ietf \| migration >
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.DsTe.Mode>`
                
                .. attribute:: te_classes
                
                	Specify TE\-Class parameters
                	**type**\:  :py:class:`TeClasses <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.DsTe.TeClasses>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.DsTe, self).__init__()

                    self.yang_name = "ds-te"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("te-classes", ("te_classes", Native.Mpls.TrafficEng.DsTe.TeClasses))])
                    self._leafs = OrderedDict([
                        ('bc_model', (YLeaf(YType.enumeration, 'bc-model'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.TrafficEng.DsTe.BcModel')])),
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.TrafficEng.DsTe.Mode')])),
                    ])
                    self.bc_model = None
                    self.mode = None

                    self.te_classes = None
                    self._children_name_map["te_classes"] = "te-classes"
                    self._segment_path = lambda: "ds-te"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.DsTe, [u'bc_model', u'mode'], name, value)

                class BcModel(Enum):
                    """
                    BcModel (Enum Class)

                    Configure BC model\: < mam >

                    .. data:: mam = 0

                    	BC Maximum allocation model

                    """

                    mam = Enum.YLeaf(0, "mam")


                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Configure DS\-TE mode\: < ietf \| migration >

                    .. data:: ietf = 0

                    	Configure DS-TE standard mode

                    .. data:: migration = 1

                    	Configure DS-TE migration mode

                    """

                    ietf = Enum.YLeaf(0, "ietf")

                    migration = Enum.YLeaf(1, "migration")



                class TeClasses(Entity):
                    """
                    Specify TE\-Class parameters
                    
                    .. attribute:: te_class
                    
                    	Configure a TE\-Class
                    	**type**\: list of  		 :py:class:`TeClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.DsTe.TeClasses.TeClass>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.DsTe.TeClasses, self).__init__()

                        self.yang_name = "te-classes"
                        self.yang_parent_name = "ds-te"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("te-class", ("te_class", Native.Mpls.TrafficEng.DsTe.TeClasses.TeClass))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.te_class = YList(self)
                        self._segment_path = lambda: "te-classes"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/ds-te/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.DsTe.TeClasses, [], name, value)


                    class TeClass(Entity):
                        """
                        Configure a TE\-Class
                        
                        .. attribute:: te_idx  (key)
                        
                        	Specify the TE\-Class index\: <0..7>
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: class_type
                        
                        	Specify the Class\-Type for this TE\-Class
                        	**type**\:  :py:class:`ClassType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.DsTe.TeClasses.TeClass.ClassType>`
                        
                        .. attribute:: unused
                        
                        	Specify that this TE\-Class index is unused
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.DsTe.TeClasses.TeClass, self).__init__()

                            self.yang_name = "te-class"
                            self.yang_parent_name = "te-classes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['te_idx']
                            self._child_classes = OrderedDict([("class-type", ("class_type", Native.Mpls.TrafficEng.DsTe.TeClasses.TeClass.ClassType))])
                            self._leafs = OrderedDict([
                                ('te_idx', (YLeaf(YType.uint8, 'te-idx'), ['int'])),
                                ('unused', (YLeaf(YType.empty, 'unused'), ['Empty'])),
                            ])
                            self.te_idx = None
                            self.unused = None

                            self.class_type = Native.Mpls.TrafficEng.DsTe.TeClasses.TeClass.ClassType()
                            self.class_type.parent = self
                            self._children_name_map["class_type"] = "class-type"
                            self._segment_path = lambda: "te-class" + "[te-idx='" + str(self.te_idx) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/ds-te/te-classes/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.DsTe.TeClasses.TeClass, [u'te_idx', u'unused'], name, value)


                        class ClassType(Entity):
                            """
                            Specify the Class\-Type for this TE\-Class
                            
                            .. attribute:: type
                            
                            	Specify Class\-Type value (0 for Global and 1 for Sub\-Pool)
                            	**type**\: int
                            
                            	**range:** 0..1
                            
                            .. attribute:: priority
                            
                            	Specify preemption priority value for this TE Class\-Type\: <0..7>
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.DsTe.TeClasses.TeClass.ClassType, self).__init__()

                                self.yang_name = "class-type"
                                self.yang_parent_name = "te-class"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ])
                                self.type = None
                                self.priority = None
                                self._segment_path = lambda: "class-type"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.DsTe.TeClasses.TeClass.ClassType, [u'type', u'priority'], name, value)


            class FastReroute(Entity):
                """
                fast\-reroute parameters
                
                .. attribute:: backup_prot_preempt
                
                	Preemption algorithm for backup tunnels
                	**type**\:  :py:class:`BackupProtPreempt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.FastReroute.BackupProtPreempt>`
                
                .. attribute:: timers
                
                	configure fast\-reroute timer
                	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.FastReroute.Timers>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.FastReroute, self).__init__()

                    self.yang_name = "fast-reroute"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("backup-prot-preempt", ("backup_prot_preempt", Native.Mpls.TrafficEng.FastReroute.BackupProtPreempt)), ("timers", ("timers", Native.Mpls.TrafficEng.FastReroute.Timers))])
                    self._leafs = OrderedDict()

                    self.backup_prot_preempt = Native.Mpls.TrafficEng.FastReroute.BackupProtPreempt()
                    self.backup_prot_preempt.parent = self
                    self._children_name_map["backup_prot_preempt"] = "backup-prot-preempt"

                    self.timers = Native.Mpls.TrafficEng.FastReroute.Timers()
                    self.timers.parent = self
                    self._children_name_map["timers"] = "timers"
                    self._segment_path = lambda: "fast-reroute"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.FastReroute, [], name, value)


                class BackupProtPreempt(Entity):
                    """
                    Preemption algorithm for backup tunnels
                    
                    .. attribute:: optimize_bw
                    
                    	Reduce bandwidth wastage (default\: minimize LSPs preempted)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.FastReroute.BackupProtPreempt, self).__init__()

                        self.yang_name = "backup-prot-preempt"
                        self.yang_parent_name = "fast-reroute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('optimize_bw', (YLeaf(YType.empty, 'optimize-bw'), ['Empty'])),
                        ])
                        self.optimize_bw = None
                        self._segment_path = lambda: "backup-prot-preempt"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/fast-reroute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.FastReroute.BackupProtPreempt, [u'optimize_bw'], name, value)


                class Timers(Entity):
                    """
                    configure fast\-reroute timer
                    
                    .. attribute:: promotion
                    
                    	Time between promotions\: <0..604800> seconds, (0 disables promotion)
                    	**type**\: int
                    
                    	**range:** 0..604800
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.FastReroute.Timers, self).__init__()

                        self.yang_name = "timers"
                        self.yang_parent_name = "fast-reroute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('promotion', (YLeaf(YType.uint32, 'promotion'), ['int'])),
                        ])
                        self.promotion = None
                        self._segment_path = lambda: "timers"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/fast-reroute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.FastReroute.Timers, [u'promotion'], name, value)


            class LinkManagement(Entity):
                """
                Link Management configuration
                
                .. attribute:: timers
                
                	Link Management timers configuration
                	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.LinkManagement.Timers>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.LinkManagement, self).__init__()

                    self.yang_name = "link-management"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("timers", ("timers", Native.Mpls.TrafficEng.LinkManagement.Timers))])
                    self._leafs = OrderedDict()

                    self.timers = Native.Mpls.TrafficEng.LinkManagement.Timers()
                    self.timers.parent = self
                    self._children_name_map["timers"] = "timers"
                    self._segment_path = lambda: "link-management"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.LinkManagement, [], name, value)


                class Timers(Entity):
                    """
                    Link Management timers configuration
                    
                    .. attribute:: bandwidth_hold
                    
                    	Link Management bandwidth hold timer\: <1..300> seconds
                    	**type**\: int
                    
                    	**range:** 1..300
                    
                    .. attribute:: periodic_flooding
                    
                    	Link Management periodic flooding interval\: <0..3600> seconds
                    	**type**\: int
                    
                    	**range:** 0..3600
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.LinkManagement.Timers, self).__init__()

                        self.yang_name = "timers"
                        self.yang_parent_name = "link-management"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('bandwidth_hold', (YLeaf(YType.uint16, 'bandwidth-hold'), ['int'])),
                            ('periodic_flooding', (YLeaf(YType.uint16, 'periodic-flooding'), ['int'])),
                        ])
                        self.bandwidth_hold = None
                        self.periodic_flooding = None
                        self._segment_path = lambda: "timers"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/link-management/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.LinkManagement.Timers, [u'bandwidth_hold', u'periodic_flooding'], name, value)


            class Logging(Entity):
                """
                Trap logging configuration
                
                .. attribute:: lsp
                
                	LSP\-specific traps logging configuration
                	**type**\:  :py:class:`Lsp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging.Lsp>`
                
                .. attribute:: tunnel
                
                	Tunnel\-specific traps logging configuration
                	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging.Tunnel>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("lsp", ("lsp", Native.Mpls.TrafficEng.Logging.Lsp)), ("tunnel", ("tunnel", Native.Mpls.TrafficEng.Logging.Tunnel))])
                    self._leafs = OrderedDict()

                    self.lsp = Native.Mpls.TrafficEng.Logging.Lsp()
                    self.lsp.parent = self
                    self._children_name_map["lsp"] = "lsp"

                    self.tunnel = Native.Mpls.TrafficEng.Logging.Tunnel()
                    self.tunnel.parent = self
                    self._children_name_map["tunnel"] = "tunnel"
                    self._segment_path = lambda: "logging"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.Logging, [], name, value)


                class Lsp(Entity):
                    """
                    LSP\-specific traps logging configuration
                    
                    .. attribute:: path_errors
                    
                    	Log LSP Path Error traps
                    	**type**\:  :py:class:`PathErrors <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging.Lsp.PathErrors>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: preemption
                    
                    	Log LSP Preemption traps
                    	**type**\:  :py:class:`Preemption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging.Lsp.Preemption>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: reservation_errors
                    
                    	Log LSP Reservation Error traps
                    	**type**\:  :py:class:`ReservationErrors <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging.Lsp.ReservationErrors>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: setups
                    
                    	Log LSP Establishment Traps
                    	**type**\:  :py:class:`Setups <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging.Lsp.Setups>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: teardowns
                    
                    	Log LSP Teardown Traps
                    	**type**\:  :py:class:`Teardowns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging.Lsp.Teardowns>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.Logging.Lsp, self).__init__()

                        self.yang_name = "lsp"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("path-errors", ("path_errors", Native.Mpls.TrafficEng.Logging.Lsp.PathErrors)), ("preemption", ("preemption", Native.Mpls.TrafficEng.Logging.Lsp.Preemption)), ("reservation-errors", ("reservation_errors", Native.Mpls.TrafficEng.Logging.Lsp.ReservationErrors)), ("setups", ("setups", Native.Mpls.TrafficEng.Logging.Lsp.Setups)), ("teardowns", ("teardowns", Native.Mpls.TrafficEng.Logging.Lsp.Teardowns))])
                        self._leafs = OrderedDict()

                        self.path_errors = None
                        self._children_name_map["path_errors"] = "path-errors"

                        self.preemption = None
                        self._children_name_map["preemption"] = "preemption"

                        self.reservation_errors = None
                        self._children_name_map["reservation_errors"] = "reservation-errors"

                        self.setups = None
                        self._children_name_map["setups"] = "setups"

                        self.teardowns = None
                        self._children_name_map["teardowns"] = "teardowns"
                        self._segment_path = lambda: "lsp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/logging/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.Logging.Lsp, [], name, value)


                    class PathErrors(Entity):
                        """
                        Log LSP Path Error traps
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199
                        
                        		**type**\: int
                        
                        			**range:** 1300..2699
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Logging.Lsp.PathErrors, self).__init__()

                            self.yang_name = "path-errors"
                            self.yang_parent_name = "lsp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                            ])
                            self.access_list = None
                            self._segment_path = lambda: "path-errors"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/logging/lsp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Logging.Lsp.PathErrors, [u'access_list'], name, value)


                    class Preemption(Entity):
                        """
                        Log LSP Preemption traps
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199
                        
                        		**type**\: int
                        
                        			**range:** 1300..2699
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Logging.Lsp.Preemption, self).__init__()

                            self.yang_name = "preemption"
                            self.yang_parent_name = "lsp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                            ])
                            self.access_list = None
                            self._segment_path = lambda: "preemption"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/logging/lsp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Logging.Lsp.Preemption, [u'access_list'], name, value)


                    class ReservationErrors(Entity):
                        """
                        Log LSP Reservation Error traps
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199
                        
                        		**type**\: int
                        
                        			**range:** 1300..2699
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Logging.Lsp.ReservationErrors, self).__init__()

                            self.yang_name = "reservation-errors"
                            self.yang_parent_name = "lsp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                            ])
                            self.access_list = None
                            self._segment_path = lambda: "reservation-errors"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/logging/lsp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Logging.Lsp.ReservationErrors, [u'access_list'], name, value)


                    class Setups(Entity):
                        """
                        Log LSP Establishment Traps
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199
                        
                        		**type**\: int
                        
                        			**range:** 1300..2699
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Logging.Lsp.Setups, self).__init__()

                            self.yang_name = "setups"
                            self.yang_parent_name = "lsp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                            ])
                            self.access_list = None
                            self._segment_path = lambda: "setups"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/logging/lsp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Logging.Lsp.Setups, [u'access_list'], name, value)


                    class Teardowns(Entity):
                        """
                        Log LSP Teardown Traps
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199
                        
                        		**type**\: int
                        
                        			**range:** 1300..2699
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Logging.Lsp.Teardowns, self).__init__()

                            self.yang_name = "teardowns"
                            self.yang_parent_name = "lsp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                            ])
                            self.access_list = None
                            self._segment_path = lambda: "teardowns"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/logging/lsp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Logging.Lsp.Teardowns, [u'access_list'], name, value)


                class Tunnel(Entity):
                    """
                    Tunnel\-specific traps logging configuration
                    
                    .. attribute:: lsp_selection
                    
                    	Log Tunnel LSP Selection traps
                    	**type**\:  :py:class:`LspSelection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging.Tunnel.LspSelection>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: lsp_switchover
                    
                    	Log Tunnel LSP Switchover traps
                    	**type**\:  :py:class:`LspSwitchover <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging.Tunnel.LspSwitchover>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: path
                    
                    	Log Tunnel Path\-related traps
                    	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging.Tunnel.Path>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.Logging.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("lsp-selection", ("lsp_selection", Native.Mpls.TrafficEng.Logging.Tunnel.LspSelection)), ("lsp-switchover", ("lsp_switchover", Native.Mpls.TrafficEng.Logging.Tunnel.LspSwitchover)), ("path", ("path", Native.Mpls.TrafficEng.Logging.Tunnel.Path))])
                        self._leafs = OrderedDict()

                        self.lsp_selection = None
                        self._children_name_map["lsp_selection"] = "lsp-selection"

                        self.lsp_switchover = None
                        self._children_name_map["lsp_switchover"] = "lsp-switchover"

                        self.path = Native.Mpls.TrafficEng.Logging.Tunnel.Path()
                        self.path.parent = self
                        self._children_name_map["path"] = "path"
                        self._segment_path = lambda: "tunnel"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/logging/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.Logging.Tunnel, [], name, value)


                    class LspSelection(Entity):
                        """
                        Log Tunnel LSP Selection traps
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199
                        
                        		**type**\: int
                        
                        			**range:** 1300..2699
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Logging.Tunnel.LspSelection, self).__init__()

                            self.yang_name = "lsp-selection"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                            ])
                            self.access_list = None
                            self._segment_path = lambda: "lsp-selection"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/logging/tunnel/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Logging.Tunnel.LspSelection, [u'access_list'], name, value)


                    class LspSwitchover(Entity):
                        """
                        Log Tunnel LSP Switchover traps
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199
                        
                        		**type**\: int
                        
                        			**range:** 1300..2699
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Logging.Tunnel.LspSwitchover, self).__init__()

                            self.yang_name = "lsp-switchover"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                            ])
                            self.access_list = None
                            self._segment_path = lambda: "lsp-switchover"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/logging/tunnel/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Logging.Tunnel.LspSwitchover, [u'access_list'], name, value)


                    class Path(Entity):
                        """
                        Log Tunnel Path\-related traps
                        
                        .. attribute:: change
                        
                        	Log Tunnel Path change traps
                        	**type**\:  :py:class:`Change <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Logging.Tunnel.Path.Change>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Logging.Tunnel.Path, self).__init__()

                            self.yang_name = "path"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("change", ("change", Native.Mpls.TrafficEng.Logging.Tunnel.Path.Change))])
                            self._leafs = OrderedDict()

                            self.change = None
                            self._children_name_map["change"] = "change"
                            self._segment_path = lambda: "path"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/logging/tunnel/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Logging.Tunnel.Path, [], name, value)


                        class Change(Entity):
                            """
                            Log Tunnel Path change traps
                            
                            .. attribute:: access_list
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199
                            
                            		**type**\: int
                            
                            			**range:** 1300..2699
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.Logging.Tunnel.Path.Change, self).__init__()

                                self.yang_name = "change"
                                self.yang_parent_name = "path"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                                ])
                                self.access_list = None
                                self._segment_path = lambda: "change"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/logging/tunnel/path/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.Logging.Tunnel.Path.Change, [u'access_list'], name, value)


            class Lsp(Entity):
                """
                Configure LSP parameters
                
                .. attribute:: attributes
                
                	Configure LSP attributes
                	**type**\: list of  		 :py:class:`Attributes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.Lsp, self).__init__()

                    self.yang_name = "lsp"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("attributes", ("attributes", Native.Mpls.TrafficEng.Lsp.Attributes))])
                    self._leafs = OrderedDict()

                    self.attributes = YList(self)
                    self._segment_path = lambda: "lsp"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.Lsp, [], name, value)


                class Attributes(Entity):
                    """
                    Configure LSP attributes
                    
                    .. attribute:: name  (key)
                    
                    	Name of LSP attribute list
                    	**type**\: str
                    
                    .. attribute:: mpls_te_mode_config_lsp_attr
                    
                    	
                    	**type**\:  :py:class:`MplsTeModeConfigLspAttr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.Lsp.Attributes, self).__init__()

                        self.yang_name = "attributes"
                        self.yang_parent_name = "lsp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("mpls-te-mode-config-lsp-attr", ("mpls_te_mode_config_lsp_attr", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.mpls_te_mode_config_lsp_attr = Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr()
                        self.mpls_te_mode_config_lsp_attr.parent = self
                        self._children_name_map["mpls_te_mode_config_lsp_attr"] = "mpls-te-mode-config-lsp-attr"
                        self._segment_path = lambda: "attributes" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/lsp/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes, [u'name'], name, value)


                    class MplsTeModeConfigLspAttr(Entity):
                        """
                        
                        
                        .. attribute:: affinity_mask
                        
                        	desired link affinity attributes
                        	**type**\:  :py:class:`AffinityMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AffinityMask>`
                        
                        .. attribute:: auto_bw
                        
                        	Specify automatic bandwidth configuration
                        	**type**\:  :py:class:`AutoBw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AutoBw>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: bandwidth
                        
                        	Specify LSP bandwidth
                        	**type**\:  :py:class:`Bandwidth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Bandwidth>`
                        
                        .. attribute:: bfd_reverse_path
                        
                        	Specify bfd reverse path
                        	**type**\:  :py:class:`BfdReversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.BfdReversePath>`
                        
                        .. attribute:: lockdown
                        
                        	Lockdown the LSP\-\-disable reoptimization
                        	**type**\:  :py:class:`Lockdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Lockdown>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: path_selection
                        
                        	Path Selection Configuration
                        	**type**\:  :py:class:`PathSelection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection>`
                        
                        .. attribute:: pce
                        
                        	Specify PCE Configuration
                        	**type**\:  :py:class:`Pce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Pce>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: priority
                        
                        	Specify LSP priority
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Priority>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: protection
                        
                        	Enable failure protection
                        	**type**\:  :py:class:`Protection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Protection>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: record_route
                        
                        	Record the route used by the LSP
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr, self).__init__()

                            self.yang_name = "mpls-te-mode-config-lsp-attr"
                            self.yang_parent_name = "attributes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("affinity-mask", ("affinity_mask", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AffinityMask)), ("auto-bw", ("auto_bw", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AutoBw)), ("bandwidth", ("bandwidth", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Bandwidth)), ("bfd-reverse-path", ("bfd_reverse_path", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.BfdReversePath)), ("lockdown", ("lockdown", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Lockdown)), ("path-selection", ("path_selection", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection)), ("pce", ("pce", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Pce)), ("priority", ("priority", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Priority)), ("protection", ("protection", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Protection))])
                            self._leafs = OrderedDict([
                                ('record_route', (YLeaf(YType.empty, 'record-route'), ['Empty'])),
                            ])
                            self.record_route = None

                            self.affinity_mask = Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AffinityMask()
                            self.affinity_mask.parent = self
                            self._children_name_map["affinity_mask"] = "affinity-mask"

                            self.auto_bw = None
                            self._children_name_map["auto_bw"] = "auto-bw"

                            self.bandwidth = Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Bandwidth()
                            self.bandwidth.parent = self
                            self._children_name_map["bandwidth"] = "bandwidth"

                            self.bfd_reverse_path = Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.BfdReversePath()
                            self.bfd_reverse_path.parent = self
                            self._children_name_map["bfd_reverse_path"] = "bfd-reverse-path"

                            self.lockdown = None
                            self._children_name_map["lockdown"] = "lockdown"

                            self.path_selection = Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection()
                            self.path_selection.parent = self
                            self._children_name_map["path_selection"] = "path-selection"

                            self.pce = None
                            self._children_name_map["pce"] = "pce"

                            self.priority = None
                            self._children_name_map["priority"] = "priority"

                            self.protection = None
                            self._children_name_map["protection"] = "protection"
                            self._segment_path = lambda: "mpls-te-mode-config-lsp-attr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr, [u'record_route'], name, value)


                        class AffinityMask(Entity):
                            """
                            desired link affinity attributes
                            
                            .. attribute:: affinity
                            
                            	Specify attribute flags for links comprising LSP\: <0x0\-0xFFFFFFFF>
                            	**type**\: str
                            
                            	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                            
                            .. attribute:: mask
                            
                            	Mask on desired link attributes\: <0x0\-0xFFFFFFFF>
                            	**type**\: str
                            
                            	**pattern:** 0[xX][0\-9a\-fA\-F]{1,8}
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AffinityMask, self).__init__()

                                self.yang_name = "affinity-mask"
                                self.yang_parent_name = "mpls-te-mode-config-lsp-attr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('affinity', (YLeaf(YType.str, 'affinity'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.affinity = None
                                self.mask = None
                                self._segment_path = lambda: "affinity-mask"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AffinityMask, [u'affinity', u'mask'], name, value)


                        class AutoBw(Entity):
                            """
                            Specify automatic bandwidth configuration
                            
                            .. attribute:: frequency
                            
                            	Seconds between applying auto\-bw\: <300..604800>
                            	**type**\: int
                            
                            	**range:** 300..604800
                            
                            .. attribute:: collect_bw
                            
                            	Just collect bandwidth info
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: adjustment_threshold
                            
                            	Percent bandwidth change to trigger adjustment\: <1..99>
                            	**type**\: int
                            
                            	**range:** 1..99
                            
                            .. attribute:: overflow_limit
                            
                            	Number of consecutive samples exceeding threshold\: <1..10>
                            	**type**\:  :py:class:`OverflowLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AutoBw.OverflowLimit>`
                            
                            .. attribute:: max_bw
                            
                            	Maximum bandwidth to apply\: <0..4294967295> (kbps)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_bw
                            
                            	Minimum bandwidth to apply\: <0..4294967294> (kbps)
                            	**type**\: int
                            
                            	**range:** 0..4294967294
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AutoBw, self).__init__()

                                self.yang_name = "auto-bw"
                                self.yang_parent_name = "mpls-te-mode-config-lsp-attr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("overflow-limit", ("overflow_limit", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AutoBw.OverflowLimit))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('frequency', (YLeaf(YType.uint32, 'frequency'), ['int'])),
                                    ('collect_bw', (YLeaf(YType.empty, 'collect-bw'), ['Empty'])),
                                    ('adjustment_threshold', (YLeaf(YType.uint8, 'adjustment-threshold'), ['int'])),
                                    ('max_bw', (YLeaf(YType.uint32, 'max-bw'), ['int'])),
                                    ('min_bw', (YLeaf(YType.uint32, 'min-bw'), ['int'])),
                                ])
                                self.frequency = None
                                self.collect_bw = None
                                self.adjustment_threshold = None
                                self.max_bw = None
                                self.min_bw = None

                                self.overflow_limit = Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AutoBw.OverflowLimit()
                                self.overflow_limit.parent = self
                                self._children_name_map["overflow_limit"] = "overflow-limit"
                                self._segment_path = lambda: "auto-bw"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AutoBw, [u'frequency', u'collect_bw', u'adjustment_threshold', u'max_bw', u'min_bw'], name, value)


                            class OverflowLimit(Entity):
                                """
                                Number of consecutive samples exceeding threshold\: <1..10>
                                
                                .. attribute:: limit
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                .. attribute:: overflow_threshold
                                
                                	Set the bandwidth change threshold to trigger overflow adjustment\: <1..99> %
                                	**type**\: int
                                
                                	**range:** 1..99
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AutoBw.OverflowLimit, self).__init__()

                                    self.yang_name = "overflow-limit"
                                    self.yang_parent_name = "auto-bw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                                        ('overflow_threshold', (YLeaf(YType.uint8, 'overflow-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.overflow_threshold = None
                                    self._segment_path = lambda: "overflow-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.AutoBw.OverflowLimit, [u'limit', u'overflow_threshold'], name, value)


                        class Bandwidth(Entity):
                            """
                            Specify LSP bandwidth
                            
                            .. attribute:: bw
                            
                            	Bandwidth requirement\: <0..4294967295> (kbps)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sub_pool
                            
                            	Sub\-pool Bandwidth requirement\: <1..4294967295> (kbps)
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Bandwidth, self).__init__()

                                self.yang_name = "bandwidth"
                                self.yang_parent_name = "mpls-te-mode-config-lsp-attr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bw', (YLeaf(YType.uint32, 'bw'), ['int'])),
                                    ('sub_pool', (YLeaf(YType.uint32, 'sub-pool'), ['int'])),
                                ])
                                self.bw = None
                                self.sub_pool = None
                                self._segment_path = lambda: "bandwidth"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Bandwidth, [u'bw', u'sub_pool'], name, value)


                        class BfdReversePath(Entity):
                            """
                            Specify bfd reverse path
                            
                            .. attribute:: binding_label
                            
                            	MPLS binding\-label value\: <16..1048575>
                            	**type**\: int
                            
                            	**range:** 16..1048575
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.BfdReversePath, self).__init__()

                                self.yang_name = "bfd-reverse-path"
                                self.yang_parent_name = "mpls-te-mode-config-lsp-attr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                ])
                                self.binding_label = None
                                self._segment_path = lambda: "bfd-reverse-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.BfdReversePath, [u'binding_label'], name, value)


                        class Lockdown(Entity):
                            """
                            Lockdown the LSP\-\-disable reoptimization
                            
                            .. attribute:: sticky
                            
                            	stay on the same path after change in required resources
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Lockdown, self).__init__()

                                self.yang_name = "lockdown"
                                self.yang_parent_name = "mpls-te-mode-config-lsp-attr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('sticky', (YLeaf(YType.empty, 'sticky'), ['Empty'])),
                                ])
                                self.sticky = None
                                self._segment_path = lambda: "lockdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Lockdown, [u'sticky'], name, value)


                        class PathSelection(Entity):
                            """
                            Path Selection Configuration
                            
                            .. attribute:: metric
                            
                            	Metric Type Configuration\: < te \| igp >
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.Metric>`
                            
                            .. attribute:: invalidation
                            
                            	Path invalidation configuration
                            	**type**\:  :py:class:`Invalidation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.Invalidation>`
                            
                            .. attribute:: segment_routing
                            
                            	Segment\-routing path\-selection options
                            	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.SegmentRouting>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection, self).__init__()

                                self.yang_name = "path-selection"
                                self.yang_parent_name = "mpls-te-mode-config-lsp-attr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("invalidation", ("invalidation", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.Invalidation)), ("segment-routing", ("segment_routing", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.SegmentRouting))])
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.enumeration, 'metric'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.Metric')])),
                                ])
                                self.metric = None

                                self.invalidation = Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.Invalidation()
                                self.invalidation.parent = self
                                self._children_name_map["invalidation"] = "invalidation"

                                self.segment_routing = Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.SegmentRouting()
                                self.segment_routing.parent = self
                                self._children_name_map["segment_routing"] = "segment-routing"
                                self._segment_path = lambda: "path-selection"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection, [u'metric'], name, value)

                            class Metric(Enum):
                                """
                                Metric (Enum Class)

                                Metric Type Configuration\: < te \| igp >

                                .. data:: igp = 0

                                .. data:: te = 1

                                """

                                igp = Enum.YLeaf(0, "igp")

                                te = Enum.YLeaf(1, "te")



                            class Invalidation(Entity):
                                """
                                Path invalidation configuration
                                
                                .. attribute:: value
                                
                                	Path invalidation timer value\: <0..60000> milliseconds, (default 10000)
                                	**type**\: int
                                
                                	**range:** 0..60000
                                
                                .. attribute:: drop
                                
                                	Drop Tunnel Traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.Invalidation, self).__init__()

                                    self.yang_name = "invalidation"
                                    self.yang_parent_name = "path-selection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('value', (YLeaf(YType.int32, 'value'), ['int'])),
                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                    ])
                                    self.value = None
                                    self.drop = None
                                    self._segment_path = lambda: "invalidation"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.Invalidation, [u'value', u'drop'], name, value)


                            class SegmentRouting(Entity):
                                """
                                Segment\-routing path\-selection options
                                
                                .. attribute:: adjacency
                                
                                	Segment\-routing adjacency path\-selection type
                                	**type**\:  :py:class:`Adjacency <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.SegmentRouting.Adjacency>`
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.SegmentRouting, self).__init__()

                                    self.yang_name = "segment-routing"
                                    self.yang_parent_name = "path-selection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('adjacency', (YLeaf(YType.enumeration, 'adjacency'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.SegmentRouting.Adjacency')])),
                                    ])
                                    self.adjacency = None
                                    self._segment_path = lambda: "segment-routing"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.PathSelection.SegmentRouting, [u'adjacency'], name, value)

                                class Adjacency(Enum):
                                    """
                                    Adjacency (Enum Class)

                                    Segment\-routing adjacency path\-selection type

                                    .. data:: protected = 0

                                    .. data:: unprotected = 1

                                    """

                                    protected = Enum.YLeaf(0, "protected")

                                    unprotected = Enum.YLeaf(1, "unprotected")



                        class Pce(Entity):
                            """
                            Specify PCE Configuration
                            
                            .. attribute:: disjoint_path
                            
                            	Disjoint Path Configuration
                            	**type**\:  :py:class:`DisjointPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Pce.DisjointPath>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Pce, self).__init__()

                                self.yang_name = "pce"
                                self.yang_parent_name = "mpls-te-mode-config-lsp-attr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("disjoint-path", ("disjoint_path", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Pce.DisjointPath))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.disjoint_path = Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Pce.DisjointPath()
                                self.disjoint_path.parent = self
                                self._children_name_map["disjoint_path"] = "disjoint-path"
                                self._segment_path = lambda: "pce"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Pce, [], name, value)


                            class DisjointPath(Entity):
                                """
                                Disjoint Path Configuration
                                
                                .. attribute:: source
                                
                                	Source IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	Disjointness type\: <link \| node \| srlg>
                                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Pce.DisjointPath.Type>`
                                
                                .. attribute:: group_id
                                
                                	Group ID\: <1..4294967295>
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Pce.DisjointPath, self).__init__()

                                    self.yang_name = "disjoint-path"
                                    self.yang_parent_name = "pce"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('source', (YLeaf(YType.str, 'source'), ['str'])),
                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Pce.DisjointPath.Type')])),
                                        ('group_id', (YLeaf(YType.uint32, 'group-id'), ['int'])),
                                    ])
                                    self.source = None
                                    self.type = None
                                    self.group_id = None
                                    self._segment_path = lambda: "disjoint-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Pce.DisjointPath, [u'source', u'type', u'group_id'], name, value)

                                class Type(Enum):
                                    """
                                    Type (Enum Class)

                                    Disjointness type\: <link \| node \| srlg>

                                    .. data:: link = 0

                                    	Link Disjointness

                                    .. data:: node = 1

                                    	Node Disjointness

                                    .. data:: srlg = 2

                                    	SRLG Disjointness

                                    """

                                    link = Enum.YLeaf(0, "link")

                                    node = Enum.YLeaf(1, "node")

                                    srlg = Enum.YLeaf(2, "srlg")



                        class Priority(Entity):
                            """
                            Specify LSP priority
                            
                            .. attribute:: setup_priority
                            
                            	Setup priority\: <0..7>
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            	**mandatory**\: True
                            
                            .. attribute:: hold_priority
                            
                            	Hold priority\: <0..7>
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "mpls-te-mode-config-lsp-attr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('setup_priority', (YLeaf(YType.uint8, 'setup-priority'), ['int'])),
                                    ('hold_priority', (YLeaf(YType.uint8, 'hold-priority'), ['int'])),
                                ])
                                self.setup_priority = None
                                self.hold_priority = None
                                self._segment_path = lambda: "priority"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Priority, [u'setup_priority', u'hold_priority'], name, value)


                        class Protection(Entity):
                            """
                            Enable failure protection
                            
                            .. attribute:: fast_reroute
                            
                            	Enable fast\-reroute failure protection
                            	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Protection.FastReroute>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Protection, self).__init__()

                                self.yang_name = "protection"
                                self.yang_parent_name = "mpls-te-mode-config-lsp-attr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("fast-reroute", ("fast_reroute", Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Protection.FastReroute))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.fast_reroute = None
                                self._children_name_map["fast_reroute"] = "fast-reroute"
                                self._segment_path = lambda: "protection"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Protection, [], name, value)


                            class FastReroute(Entity):
                                """
                                Enable fast\-reroute failure protection
                                
                                .. attribute:: bw_protect
                                
                                	Enable BW protection
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Protection.FastReroute, self).__init__()

                                    self.yang_name = "fast-reroute"
                                    self.yang_parent_name = "protection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('bw_protect', (YLeaf(YType.empty, 'bw-protect'), ['Empty'])),
                                    ])
                                    self.bw_protect = None
                                    self._segment_path = lambda: "fast-reroute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.Lsp.Attributes.MplsTeModeConfigLspAttr.Protection.FastReroute, [u'bw_protect'], name, value)


            class PathOption(Entity):
                """
                Configure path\-option
                
                .. attribute:: list
                
                	Configure path\-option list
                	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption.List>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.PathOption, self).__init__()

                    self.yang_name = "path-option"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("list", ("list", Native.Mpls.TrafficEng.PathOption.List))])
                    self._leafs = OrderedDict()

                    self.list = Native.Mpls.TrafficEng.PathOption.List()
                    self.list.parent = self
                    self._children_name_map["list"] = "list"
                    self._segment_path = lambda: "path-option"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.PathOption, [], name, value)


                class List(Entity):
                    """
                    Configure path\-option list
                    
                    .. attribute:: identifier
                    
                    	Specify path\-option list by number
                    	**type**\: list of  		 :py:class:`Identifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption.List.Identifier>`
                    
                    .. attribute:: name
                    
                    	Specify path\-option list by name
                    	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption.List.Name>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.PathOption.List, self).__init__()

                        self.yang_name = "list"
                        self.yang_parent_name = "path-option"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("identifier", ("identifier", Native.Mpls.TrafficEng.PathOption.List.Identifier)), ("name", ("name", Native.Mpls.TrafficEng.PathOption.List.Name))])
                        self._leafs = OrderedDict()

                        self.identifier = YList(self)
                        self.name = YList(self)
                        self._segment_path = lambda: "list"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/path-option/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.PathOption.List, [], name, value)


                    class Identifier(Entity):
                        """
                        Specify path\-option list by number
                        
                        .. attribute:: pol_num  (key)
                        
                        	Path option list identifier\: <1..65535>
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: path_option
                        
                        	Specify the path\-option to add, edit (or delete)
                        	**type**\: list of  		 :py:class:`PathOption_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.PathOption.List.Identifier, self).__init__()

                            self.yang_name = "identifier"
                            self.yang_parent_name = "list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['pol_num']
                            self._child_classes = OrderedDict([("path-option", ("path_option", Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_))])
                            self._leafs = OrderedDict([
                                ('pol_num', (YLeaf(YType.uint16, 'pol-num'), ['int'])),
                            ])
                            self.pol_num = None

                            self.path_option = YList(self)
                            self._segment_path = lambda: "identifier" + "[pol-num='" + str(self.pol_num) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/path-option/list/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.PathOption.List.Identifier, [u'pol_num'], name, value)


                        class PathOption_(Entity):
                            """
                            Specify the path\-option to add, edit (or delete)
                            
                            .. attribute:: po_num  (key)
                            
                            	Entry path\-option number
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: explicit
                            
                            	setup based on preconfigured path
                            	**type**\:  :py:class:`Explicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_, self).__init__()

                                self.yang_name = "path-option"
                                self.yang_parent_name = "identifier"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['po_num']
                                self._child_classes = OrderedDict([("explicit", ("explicit", Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit))])
                                self._leafs = OrderedDict([
                                    ('po_num', (YLeaf(YType.uint16, 'po-num'), ['int'])),
                                ])
                                self.po_num = None

                                self.explicit = Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit()
                                self.explicit.parent = self
                                self._children_name_map["explicit"] = "explicit"
                                self._segment_path = lambda: "path-option" + "[po-num='" + str(self.po_num) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_, [u'po_num'], name, value)


                            class Explicit(Entity):
                                """
                                setup based on preconfigured path
                                
                                .. attribute:: identifier
                                
                                	Specify path by number
                                	**type**\:  :py:class:`Identifier_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit.Identifier_>`
                                
                                .. attribute:: name
                                
                                	Specify path by name
                                	**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit.Name>`
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit, self).__init__()

                                    self.yang_name = "explicit"
                                    self.yang_parent_name = "path-option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("identifier", ("identifier", Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit.Identifier_)), ("name", ("name", Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit.Name))])
                                    self._leafs = OrderedDict()

                                    self.identifier = Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit.Identifier_()
                                    self.identifier.parent = self
                                    self._children_name_map["identifier"] = "identifier"

                                    self.name = Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit.Name()
                                    self.name.parent = self
                                    self._children_name_map["name"] = "name"
                                    self._segment_path = lambda: "explicit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit, [], name, value)


                                class Identifier_(Entity):
                                    """
                                    Specify path by number
                                    
                                    .. attribute:: pnum
                                    
                                    	Path number\: <1..65535>
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: verbatim
                                    
                                    	Send out path as is, with no checking
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit.Identifier_, self).__init__()

                                        self.yang_name = "identifier"
                                        self.yang_parent_name = "explicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pnum', (YLeaf(YType.uint16, 'pnum'), ['int'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                        ])
                                        self.pnum = None
                                        self.verbatim = None
                                        self._segment_path = lambda: "identifier"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit.Identifier_, [u'pnum', u'verbatim'], name, value)


                                class Name(Entity):
                                    """
                                    Specify path by name
                                    
                                    .. attribute:: pname
                                    
                                    	Path name
                                    	**type**\: str
                                    
                                    .. attribute:: verbatim
                                    
                                    	Send out path as is, with no checking
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit.Name, self).__init__()

                                        self.yang_name = "name"
                                        self.yang_parent_name = "explicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pname', (YLeaf(YType.str, 'pname'), ['str'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                        ])
                                        self.pname = None
                                        self.verbatim = None
                                        self._segment_path = lambda: "name"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.TrafficEng.PathOption.List.Identifier.PathOption_.Explicit.Name, [u'pname', u'verbatim'], name, value)


                    class Name(Entity):
                        """
                        Specify path\-option list by name
                        
                        .. attribute:: pol_name  (key)
                        
                        	Path option list name
                        	**type**\: str
                        
                        .. attribute:: path_option
                        
                        	Specify the path\-option to add, edit (or delete)
                        	**type**\: list of  		 :py:class:`PathOption_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.PathOption.List.Name, self).__init__()

                            self.yang_name = "name"
                            self.yang_parent_name = "list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['pol_name']
                            self._child_classes = OrderedDict([("path-option", ("path_option", Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_))])
                            self._leafs = OrderedDict([
                                ('pol_name', (YLeaf(YType.str, 'pol-name'), ['str'])),
                            ])
                            self.pol_name = None

                            self.path_option = YList(self)
                            self._segment_path = lambda: "name" + "[pol-name='" + str(self.pol_name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/path-option/list/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.PathOption.List.Name, [u'pol_name'], name, value)


                        class PathOption_(Entity):
                            """
                            Specify the path\-option to add, edit (or delete)
                            
                            .. attribute:: po_num  (key)
                            
                            	Entry path\-option number
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: explicit
                            
                            	setup based on preconfigured path
                            	**type**\:  :py:class:`Explicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit>`
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_, self).__init__()

                                self.yang_name = "path-option"
                                self.yang_parent_name = "name"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['po_num']
                                self._child_classes = OrderedDict([("explicit", ("explicit", Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit))])
                                self._leafs = OrderedDict([
                                    ('po_num', (YLeaf(YType.uint16, 'po-num'), ['int'])),
                                ])
                                self.po_num = None

                                self.explicit = Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit()
                                self.explicit.parent = self
                                self._children_name_map["explicit"] = "explicit"
                                self._segment_path = lambda: "path-option" + "[po-num='" + str(self.po_num) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_, [u'po_num'], name, value)


                            class Explicit(Entity):
                                """
                                setup based on preconfigured path
                                
                                .. attribute:: identifier
                                
                                	Specify path by number
                                	**type**\:  :py:class:`Identifier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit.Identifier>`
                                
                                .. attribute:: name
                                
                                	Specify path by name
                                	**type**\:  :py:class:`Name_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit.Name_>`
                                
                                

                                """

                                _prefix = 'ios-mpls'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit, self).__init__()

                                    self.yang_name = "explicit"
                                    self.yang_parent_name = "path-option"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("identifier", ("identifier", Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit.Identifier)), ("name", ("name", Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit.Name_))])
                                    self._leafs = OrderedDict()

                                    self.identifier = Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit.Identifier()
                                    self.identifier.parent = self
                                    self._children_name_map["identifier"] = "identifier"

                                    self.name = Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit.Name_()
                                    self.name.parent = self
                                    self._children_name_map["name"] = "name"
                                    self._segment_path = lambda: "explicit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit, [], name, value)


                                class Identifier(Entity):
                                    """
                                    Specify path by number
                                    
                                    .. attribute:: pnum
                                    
                                    	Path number\: <1..65535>
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: verbatim
                                    
                                    	Send out path as is, with no checking
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit.Identifier, self).__init__()

                                        self.yang_name = "identifier"
                                        self.yang_parent_name = "explicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pnum', (YLeaf(YType.uint16, 'pnum'), ['int'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                        ])
                                        self.pnum = None
                                        self.verbatim = None
                                        self._segment_path = lambda: "identifier"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit.Identifier, [u'pnum', u'verbatim'], name, value)


                                class Name_(Entity):
                                    """
                                    Specify path by name
                                    
                                    .. attribute:: pname
                                    
                                    	Path name
                                    	**type**\: str
                                    
                                    .. attribute:: verbatim
                                    
                                    	Send out path as is, with no checking
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-mpls'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit.Name_, self).__init__()

                                        self.yang_name = "name"
                                        self.yang_parent_name = "explicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pname', (YLeaf(YType.str, 'pname'), ['str'])),
                                            ('verbatim', (YLeaf(YType.empty, 'verbatim'), ['Empty'])),
                                        ])
                                        self.pname = None
                                        self.verbatim = None
                                        self._segment_path = lambda: "name"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Mpls.TrafficEng.PathOption.List.Name.PathOption_.Explicit.Name_, [u'pname', u'verbatim'], name, value)


            class PathSelection(Entity):
                """
                Path Selection Configuration
                
                .. attribute:: metric
                
                	Metric Type Configuration\: < te \| igp >
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathSelection.Metric>`
                
                .. attribute:: invalidation
                
                	Path invalidation configuration
                	**type**\:  :py:class:`Invalidation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathSelection.Invalidation>`
                
                .. attribute:: overload
                
                	Overload Node Configuration
                	**type**\:  :py:class:`Overload <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathSelection.Overload>`
                
                .. attribute:: tiebreaker
                
                	Tiebreaker Configuration\: < max\-fill \| min\-fill \| random >
                	**type**\:  :py:class:`MplsTeTiebreakerType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls.MplsTeTiebreakerType>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.PathSelection, self).__init__()

                    self.yang_name = "path-selection"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("invalidation", ("invalidation", Native.Mpls.TrafficEng.PathSelection.Invalidation)), ("overload", ("overload", Native.Mpls.TrafficEng.PathSelection.Overload))])
                    self._leafs = OrderedDict([
                        ('metric', (YLeaf(YType.enumeration, 'metric'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Mpls.TrafficEng.PathSelection.Metric')])),
                        ('tiebreaker', (YLeaf(YType.enumeration, 'tiebreaker'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_mpls', 'MplsTeTiebreakerType', '')])),
                    ])
                    self.metric = None
                    self.tiebreaker = None

                    self.invalidation = Native.Mpls.TrafficEng.PathSelection.Invalidation()
                    self.invalidation.parent = self
                    self._children_name_map["invalidation"] = "invalidation"

                    self.overload = Native.Mpls.TrafficEng.PathSelection.Overload()
                    self.overload.parent = self
                    self._children_name_map["overload"] = "overload"
                    self._segment_path = lambda: "path-selection"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.PathSelection, [u'metric', u'tiebreaker'], name, value)

                class Metric(Enum):
                    """
                    Metric (Enum Class)

                    Metric Type Configuration\: < te \| igp >

                    .. data:: igp = 0

                    .. data:: te = 1

                    """

                    igp = Enum.YLeaf(0, "igp")

                    te = Enum.YLeaf(1, "te")



                class Invalidation(Entity):
                    """
                    Path invalidation configuration
                    
                    .. attribute:: value
                    
                    	Path invalidation timer value\: <0..60000> milliseconds, (default 10000)
                    	**type**\: int
                    
                    	**range:** 0..60000
                    
                    .. attribute:: drop
                    
                    	Drop Tunnel Traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.PathSelection.Invalidation, self).__init__()

                        self.yang_name = "invalidation"
                        self.yang_parent_name = "path-selection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('value', (YLeaf(YType.int32, 'value'), ['int'])),
                            ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                        ])
                        self.value = None
                        self.drop = None
                        self._segment_path = lambda: "invalidation"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/path-selection/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.PathSelection.Invalidation, [u'value', u'drop'], name, value)


                class Overload(Entity):
                    """
                    Overload Node Configuration
                    
                    .. attribute:: allow
                    
                    	Allow overloaded nodes in CSPFs
                    	**type**\:  :py:class:`Allow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.PathSelection.Overload.Allow>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.PathSelection.Overload, self).__init__()

                        self.yang_name = "overload"
                        self.yang_parent_name = "path-selection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("allow", ("allow", Native.Mpls.TrafficEng.PathSelection.Overload.Allow))])
                        self._leafs = OrderedDict()

                        self.allow = Native.Mpls.TrafficEng.PathSelection.Overload.Allow()
                        self.allow.parent = self
                        self._children_name_map["allow"] = "allow"
                        self._segment_path = lambda: "overload"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/path-selection/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.PathSelection.Overload, [], name, value)


                    class Allow(Entity):
                        """
                        Allow overloaded nodes in CSPFs
                        
                        .. attribute:: head
                        
                        	Allow overloaded head node in TE CSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: middle
                        
                        	Allow overloaded middle node in TE CSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: tail
                        
                        	Allow overloaded tail node in TE CSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.PathSelection.Overload.Allow, self).__init__()

                            self.yang_name = "allow"
                            self.yang_parent_name = "overload"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('head', (YLeaf(YType.empty, 'head'), ['Empty'])),
                                ('middle', (YLeaf(YType.empty, 'middle'), ['Empty'])),
                                ('tail', (YLeaf(YType.empty, 'tail'), ['Empty'])),
                            ])
                            self.head = None
                            self.middle = None
                            self.tail = None
                            self._segment_path = lambda: "allow"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/path-selection/overload/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.PathSelection.Overload.Allow, [u'head', u'middle', u'tail'], name, value)


            class Pcc(Entity):
                """
                Path Computation Client form MPLS\-TE
                
                .. attribute:: report_all
                
                	Force reporting of all MPLS\-TE LSPs
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: peer
                
                	Specify a PCEP peer
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Pcc.Peer>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.Pcc, self).__init__()

                    self.yang_name = "pcc"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("peer", ("peer", Native.Mpls.TrafficEng.Pcc.Peer))])
                    self._leafs = OrderedDict([
                        ('report_all', (YLeaf(YType.empty, 'report-all'), ['Empty'])),
                    ])
                    self.report_all = None

                    self.peer = Native.Mpls.TrafficEng.Pcc.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"
                    self._segment_path = lambda: "pcc"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.Pcc, [u'report_all'], name, value)


                class Peer(Entity):
                    """
                    Specify a PCEP peer
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Pcc.Peer.Ipv4>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.Pcc.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "pcc"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Mpls.TrafficEng.Pcc.Peer.Ipv4))])
                        self._leafs = OrderedDict()

                        self.ipv4 = YList(self)
                        self._segment_path = lambda: "peer"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/pcc/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.Pcc.Peer, [], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: ipv4  (key)
                        
                        	PCE server IPv4 address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	Source IPv4 address to use
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: precedence
                        
                        	Specify Precedence for this PCE\: <0..255>, (default is 0)
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: keychain
                        
                        	Use key\-chain\: <password text> \| <keychain name>
                        	**type**\: str
                        
                        .. attribute:: password
                        
                        	Configure PCE MD5 pasword
                        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Pcc.Peer.Ipv4.Password>`
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Pcc.Peer.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ipv4']
                            self._child_classes = OrderedDict([("password", ("password", Native.Mpls.TrafficEng.Pcc.Peer.Ipv4.Password))])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                                ('precedence', (YLeaf(YType.uint8, 'precedence'), ['int'])),
                                ('keychain', (YLeaf(YType.str, 'keychain'), ['str'])),
                            ])
                            self.ipv4 = None
                            self.source = None
                            self.precedence = None
                            self.keychain = None

                            self.password = Native.Mpls.TrafficEng.Pcc.Peer.Ipv4.Password()
                            self.password.parent = self
                            self._children_name_map["password"] = "password"
                            self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/pcc/peer/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Pcc.Peer.Ipv4, [u'ipv4', u'source', u'precedence', u'keychain'], name, value)


                        class Password(Entity):
                            """
                            Configure PCE MD5 pasword
                            
                            .. attribute:: clear
                            
                            	Unencrypted password\: <password text> \| <keychain name>
                            	**type**\: str
                            
                            .. attribute:: encrypted
                            
                            	Hidden password\: <password text> \| <keychain name>
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-mpls'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Mpls.TrafficEng.Pcc.Peer.Ipv4.Password, self).__init__()

                                self.yang_name = "password"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('clear', (YLeaf(YType.str, 'clear'), ['str'])),
                                    ('encrypted', (YLeaf(YType.str, 'encrypted'), ['str'])),
                                ])
                                self.clear = None
                                self.encrypted = None
                                self._segment_path = lambda: "password"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Mpls.TrafficEng.Pcc.Peer.Ipv4.Password, [u'clear', u'encrypted'], name, value)


            class Reoptimize(Entity):
                """
                Reoptimization parameters
                
                .. attribute:: events
                
                	Reoptimization triggers
                	**type**\:  :py:class:`Events <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Reoptimize.Events>`
                
                .. attribute:: timers
                
                	Reoptimization timers
                	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Reoptimize.Timers>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.Reoptimize, self).__init__()

                    self.yang_name = "reoptimize"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("events", ("events", Native.Mpls.TrafficEng.Reoptimize.Events)), ("timers", ("timers", Native.Mpls.TrafficEng.Reoptimize.Timers))])
                    self._leafs = OrderedDict()

                    self.events = Native.Mpls.TrafficEng.Reoptimize.Events()
                    self.events.parent = self
                    self._children_name_map["events"] = "events"

                    self.timers = Native.Mpls.TrafficEng.Reoptimize.Timers()
                    self.timers.parent = self
                    self._children_name_map["timers"] = "timers"
                    self._segment_path = lambda: "reoptimize"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.Reoptimize, [], name, value)


                class Events(Entity):
                    """
                    Reoptimization triggers
                    
                    .. attribute:: link_up
                    
                    	Reoptimize tunnels on link up events
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.Reoptimize.Events, self).__init__()

                        self.yang_name = "events"
                        self.yang_parent_name = "reoptimize"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('link_up', (YLeaf(YType.empty, 'link-up'), ['Empty'])),
                        ])
                        self.link_up = None
                        self._segment_path = lambda: "events"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/reoptimize/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.Reoptimize.Events, [u'link_up'], name, value)


                class Timers(Entity):
                    """
                    Reoptimization timers
                    
                    .. attribute:: delay
                    
                    	Delay reoptimization action
                    	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Reoptimize.Timers.Delay>`
                    
                    .. attribute:: frequency
                    
                    	Interval between reoptimization scans\: <0..604800> seconds
                    	**type**\: int
                    
                    	**range:** 0..604800
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.Reoptimize.Timers, self).__init__()

                        self.yang_name = "timers"
                        self.yang_parent_name = "reoptimize"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("delay", ("delay", Native.Mpls.TrafficEng.Reoptimize.Timers.Delay))])
                        self._leafs = OrderedDict([
                            ('frequency', (YLeaf(YType.uint32, 'frequency'), ['int'])),
                        ])
                        self.frequency = None

                        self.delay = Native.Mpls.TrafficEng.Reoptimize.Timers.Delay()
                        self.delay.parent = self
                        self._children_name_map["delay"] = "delay"
                        self._segment_path = lambda: "timers"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/reoptimize/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.Reoptimize.Timers, [u'frequency'], name, value)


                    class Delay(Entity):
                        """
                        Delay reoptimization action
                        
                        .. attribute:: after_frr
                        
                        	Delay LSP reoptimization in the event of FRR\: <0..120> seconds
                        	**type**\: int
                        
                        	**range:** 0..120
                        
                        .. attribute:: cleanup
                        
                        	Delay cleanup of reoptimized LSP\: <0..60> seconds
                        	**type**\: int
                        
                        	**range:** 0..60
                        
                        .. attribute:: installation
                        
                        	Delay replacement of current LSP by reoptimized LSP\: <0..3600> seconds
                        	**type**\: int
                        
                        	**range:** 0..3600
                        
                        

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Reoptimize.Timers.Delay, self).__init__()

                            self.yang_name = "delay"
                            self.yang_parent_name = "timers"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('after_frr', (YLeaf(YType.uint8, 'after-frr'), ['int'])),
                                ('cleanup', (YLeaf(YType.uint8, 'cleanup'), ['int'])),
                                ('installation', (YLeaf(YType.uint16, 'installation'), ['int'])),
                            ])
                            self.after_frr = None
                            self.cleanup = None
                            self.installation = None
                            self._segment_path = lambda: "delay"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/reoptimize/timers/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Reoptimize.Timers.Delay, [u'after_frr', u'cleanup', u'installation'], name, value)


            class Signalling(Entity):
                """
                Traffic Engineering Signalling Parameters
                
                .. attribute:: advertise
                
                	Signalling advertisement parameters
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Signalling.Advertise>`
                
                .. attribute:: forwarding
                
                	Control interaction of LSP signalling and LFIB maintenance
                	**type**\:  :py:class:`Forwarding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Signalling.Forwarding>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.Signalling, self).__init__()

                    self.yang_name = "signalling"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("advertise", ("advertise", Native.Mpls.TrafficEng.Signalling.Advertise)), ("forwarding", ("forwarding", Native.Mpls.TrafficEng.Signalling.Forwarding))])
                    self._leafs = OrderedDict()

                    self.advertise = Native.Mpls.TrafficEng.Signalling.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "advertise"

                    self.forwarding = Native.Mpls.TrafficEng.Signalling.Forwarding()
                    self.forwarding.parent = self
                    self._children_name_map["forwarding"] = "forwarding"
                    self._segment_path = lambda: "signalling"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.Signalling, [], name, value)


                class Advertise(Entity):
                    """
                    Signalling advertisement parameters
                    
                    .. attribute:: explicit_null
                    
                    	Use MPLS encoding for Explicit\-Null Label in signalling messages
                    	**type**\:  :py:class:`ExplicitNull <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Signalling.Advertise.ExplicitNull>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.Signalling.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "signalling"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("explicit-null", ("explicit_null", Native.Mpls.TrafficEng.Signalling.Advertise.ExplicitNull))])
                        self._leafs = OrderedDict()

                        self.explicit_null = None
                        self._children_name_map["explicit_null"] = "explicit-null"
                        self._segment_path = lambda: "advertise"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/signalling/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.Signalling.Advertise, [], name, value)


                    class ExplicitNull(Entity):
                        """
                        Use MPLS encoding for Explicit\-Null Label in signalling messages
                        
                        .. attribute:: access_list
                        
                        	IP access\-list to determine applicable signalling peers. Either a string or number\: <1..99>
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..99
                        
                        		**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-mpls'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Mpls.TrafficEng.Signalling.Advertise.ExplicitNull, self).__init__()

                            self.yang_name = "explicit-null"
                            self.yang_parent_name = "advertise"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['int','str'])),
                            ])
                            self.access_list = None
                            self._segment_path = lambda: "explicit-null"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/signalling/advertise/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Mpls.TrafficEng.Signalling.Advertise.ExplicitNull, [u'access_list'], name, value)


                class Forwarding(Entity):
                    """
                    Control interaction of LSP signalling and LFIB maintenance
                    
                    .. attribute:: sync
                    
                    	Program linecard LFIBs before signalling LSP label upstream
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.Signalling.Forwarding, self).__init__()

                        self.yang_name = "forwarding"
                        self.yang_parent_name = "signalling"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync', (YLeaf(YType.empty, 'sync'), ['Empty'])),
                        ])
                        self.sync = None
                        self._segment_path = lambda: "forwarding"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/signalling/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.Signalling.Forwarding, [u'sync'], name, value)


            class Topology(Entity):
                """
                Topology Database Configuration
                
                .. attribute:: holddown
                
                	Topology Database hold down timers
                	**type**\:  :py:class:`Holddown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Topology.Holddown>`
                
                .. attribute:: mesh_group
                
                	mesh\-group commands
                	**type**\:  :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Topology.MeshGroup>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.Topology, self).__init__()

                    self.yang_name = "topology"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("holddown", ("holddown", Native.Mpls.TrafficEng.Topology.Holddown)), ("mesh-group", ("mesh_group", Native.Mpls.TrafficEng.Topology.MeshGroup))])
                    self._leafs = OrderedDict()

                    self.holddown = Native.Mpls.TrafficEng.Topology.Holddown()
                    self.holddown.parent = self
                    self._children_name_map["holddown"] = "holddown"

                    self.mesh_group = Native.Mpls.TrafficEng.Topology.MeshGroup()
                    self.mesh_group.parent = self
                    self._children_name_map["mesh_group"] = "mesh-group"
                    self._segment_path = lambda: "topology"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.Topology, [], name, value)


                class Holddown(Entity):
                    """
                    Topology Database hold down timers
                    
                    .. attribute:: sigerr
                    
                    	Link hold down time for signalling errors\: <0..300> seconds
                    	**type**\: int
                    
                    	**range:** 0..300
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.Topology.Holddown, self).__init__()

                        self.yang_name = "holddown"
                        self.yang_parent_name = "topology"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sigerr', (YLeaf(YType.uint16, 'sigerr'), ['int'])),
                        ])
                        self.sigerr = None
                        self._segment_path = lambda: "holddown"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/topology/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.Topology.Holddown, [u'sigerr'], name, value)


                class MeshGroup(Entity):
                    """
                    mesh\-group commands
                    
                    .. attribute:: accept_domain
                    
                    	accept receipt of Domain Scope
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.Topology.MeshGroup, self).__init__()

                        self.yang_name = "mesh-group"
                        self.yang_parent_name = "topology"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('accept_domain', (YLeaf(YType.empty, 'accept-domain'), ['Empty'])),
                        ])
                        self.accept_domain = None
                        self._segment_path = lambda: "mesh-group"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/topology/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.Topology.MeshGroup, [u'accept_domain'], name, value)


            class Trace(Entity):
                """
                Trace configuration
                
                .. attribute:: buffer_size
                
                	Trace buffer size configuration
                	**type**\:  :py:class:`BufferSize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Mpls.TrafficEng.Trace.BufferSize>`
                
                

                """

                _prefix = 'ios-mpls'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Mpls.TrafficEng.Trace, self).__init__()

                    self.yang_name = "trace"
                    self.yang_parent_name = "traffic-eng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("buffer-size", ("buffer_size", Native.Mpls.TrafficEng.Trace.BufferSize))])
                    self._leafs = OrderedDict()

                    self.buffer_size = Native.Mpls.TrafficEng.Trace.BufferSize()
                    self.buffer_size.parent = self
                    self._children_name_map["buffer_size"] = "buffer-size"
                    self._segment_path = lambda: "trace"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Mpls.TrafficEng.Trace, [], name, value)


                class BufferSize(Entity):
                    """
                    Trace buffer size configuration
                    
                    .. attribute:: error
                    
                    	Trace error buffer size\: <1..500> kB, (default 32kB)
                    	**type**\: int
                    
                    	**range:** 1..500
                    
                    .. attribute:: event
                    
                    	Trace event buffer size\: <1..2500> kB, (default 1% of system memory)
                    	**type**\: int
                    
                    	**range:** 1..2500
                    
                    .. attribute:: warning
                    
                    	Trace warning buffer size\: <1..250> kB (default 32kB)
                    	**type**\: int
                    
                    	**range:** 1..250
                    
                    

                    """

                    _prefix = 'ios-mpls'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Mpls.TrafficEng.Trace.BufferSize, self).__init__()

                        self.yang_name = "buffer-size"
                        self.yang_parent_name = "trace"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('error', (YLeaf(YType.uint16, 'error'), ['int'])),
                            ('event', (YLeaf(YType.uint16, 'event'), ['int'])),
                            ('warning', (YLeaf(YType.uint8, 'warning'), ['int'])),
                        ])
                        self.error = None
                        self.event = None
                        self.warning = None
                        self._segment_path = lambda: "buffer-size"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/Cisco-IOS-XE-mpls:traffic-eng/trace/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Mpls.TrafficEng.Trace.BufferSize, [u'error', u'event', u'warning'], name, value)


        class Tp(Entity):
            """
            Configure MPLS Transport Profile parameters
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-mpls'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Mpls.Tp, self).__init__()

                self.yang_name = "tp"
                self.yang_parent_name = "mpls"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict()
                self._segment_path = lambda: "Cisco-IOS-XE-mpls:tp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/mpls/%s" % self._segment_path()
                self._is_frozen = True


    class Router(Entity):
        """
        
        
        .. attribute:: isis
        
        	ISO IS\-IS
        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis>`
        
        	**presence node**\: True
        
        .. attribute:: isis_container
        
        	
        	**type**\:  :py:class:`IsisContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer>`
        
        .. attribute:: ospf
        
        	Open Shortest Path First (OSPF)
        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf>`
        
        .. attribute:: lisp
        
        	Locator/ID Separation Protocol
        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp>`
        
        	**presence node**\: True
        
        .. attribute:: lisp_list
        
        	Locator/ID Separation Protocol
        	**type**\: list of  		 :py:class:`LispList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList>`
        
        .. attribute:: ospfv3
        
        	OSPFv3
        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3>`
        
        .. attribute:: bgp
        
        	Border Gateway Protocol (BGP)
        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp>`
        
        .. attribute:: eigrp
        
        	Enhanced Interior Gateway Routing Protocol (EIGRP)
        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp>`
        
        .. attribute:: rip
        
        	Routing Information Protocol (RIP)
        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Router, self).__init__()

            self.yang_name = "router"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-isis:isis", ("isis", Native.Router.Isis)), ("Cisco-IOS-XE-isis:isis-container", ("isis_container", Native.Router.IsisContainer)), ("Cisco-IOS-XE-ospf:ospf", ("ospf", Native.Router.Ospf)), ("Cisco-IOS-XE-lisp:lisp", ("lisp", Native.Router.Lisp)), ("Cisco-IOS-XE-lisp:lisp-list", ("lisp_list", Native.Router.LispList)), ("Cisco-IOS-XE-ospfv3:ospfv3", ("ospfv3", Native.Router.Ospfv3)), ("Cisco-IOS-XE-bgp:bgp", ("bgp", Native.Router.Bgp)), ("Cisco-IOS-XE-eigrp:eigrp", ("eigrp", Native.Router.Eigrp)), ("Cisco-IOS-XE-rip:rip", ("rip", Native.Router.Rip))])
            self._leafs = OrderedDict()

            self.isis = None
            self._children_name_map["isis"] = "Cisco-IOS-XE-isis:isis"

            self.isis_container = Native.Router.IsisContainer()
            self.isis_container.parent = self
            self._children_name_map["isis_container"] = "Cisco-IOS-XE-isis:isis-container"

            self.lisp = None
            self._children_name_map["lisp"] = "Cisco-IOS-XE-lisp:lisp"

            self.rip = None
            self._children_name_map["rip"] = "Cisco-IOS-XE-rip:rip"

            self.ospf = YList(self)
            self.lisp_list = YList(self)
            self.ospfv3 = YList(self)
            self.bgp = YList(self)
            self.eigrp = YList(self)
            self._segment_path = lambda: "router"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Router, [], name, value)


        class Isis(Entity):
            """
            ISO IS\-IS
            
            .. attribute:: metric_style
            
            	Use old\-style (ISO 10589) or new\-style packet formats
            	**type**\:  :py:class:`MetricStyle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.MetricStyle>`
            
            .. attribute:: address_family
            
            	Enter Address Family command mode
            	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily>`
            
            .. attribute:: distance
            
            	Define an administrative distance
            	**type**\: list of  		 :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Distance>`
            
            .. attribute:: ip
            
            	IP specific commands
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Ip>`
            
            .. attribute:: priority
            
            	priority value
            	**type**\: int
            
            	**range:** 0..127
            
            .. attribute:: redistribute
            
            	Redistribute information from another routing protocol
            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute>`
            
            .. attribute:: set_attached_bit
            
            	Conditionally advertise us as attached to L2
            	**type**\:  :py:class:`SetAttachedBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SetAttachedBit>`
            
            .. attribute:: snmp
            
            	Modify snmp parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Snmp>`
            
            .. attribute:: summary_address
            
            	Configure IP address summaries
            	**type**\: list of  		 :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SummaryAddress>`
            
            .. attribute:: traffic_share
            
            	How to compute traffic share over alternate paths
            	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.TrafficShare>`
            
            .. attribute:: advertise
            
            	Control which IP routes flow in L1 and L2 LSPs
            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Advertise>`
            
            .. attribute:: default_information
            
            	Control distribution of default information
            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.DefaultInformation>`
            
            .. attribute:: help
            
            	Description of the interactive help system
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: maximum_paths
            
            	Forward packets over multiple paths
            	**type**\: int
            
            	**range:** 1..32
            
            .. attribute:: metric
            
            	Set ISIS metric for all interfaces
            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Metric>`
            
            .. attribute:: prc_interval
            
            	Minimum interval between partial route calculations
            	**type**\:  :py:class:`PrcInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.PrcInterval>`
            
            .. attribute:: set_overload_bit
            
            	Signal other routers not to use us in SPF
            	**type**\:  :py:class:`SetOverloadBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SetOverloadBit>`
            
            	**presence node**\: True
            
            .. attribute:: spf_interval
            
            	Minimum interval between SPF calculations
            	**type**\:  :py:class:`SpfInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SpfInterval>`
            
            .. attribute:: area_password
            
            	Configure the authentication password for an area
            	**type**\:  :py:class:`AreaPassword <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AreaPassword>`
            
            .. attribute:: authentication
            
            	ISIS authentication for LSPs
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Authentication>`
            
            .. attribute:: distribute_list
            
            	Filter networks in routing updates
            	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.DistributeList>`
            
            .. attribute:: domain_password
            
            	Set the authentication password for a routing domain
            	**type**\:  :py:class:`DomainPassword <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.DomainPassword>`
            
            .. attribute:: fast_flood
            
            	Flood LSPs (that triggered SPF) before running SPF
            	**type**\:  :py:class:`FastFlood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastFlood>`
            
            	**presence node**\: True
            
            .. attribute:: fast_reroute
            
            	Configure Fast\-Reroute
            	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute>`
            
            .. attribute:: ti_lfa
            
            	
            	**type**\:  :py:class:`TiLfa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.TiLfa>`
            
            .. attribute:: hello
            
            	Pad ISIS hello PDUs to full MTU
            	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Hello>`
            
            .. attribute:: hostname
            
            	Dynamic hostname for IS\-IS
            	**type**\:  :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Hostname>`
            
            .. attribute:: ignore_lsp_errors
            
            	Ignore LSPs with bad checksums
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: is_type
            
            	IS Level for this routing process (OSI only)
            	**type**\:  :py:class:`IsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.IsType>`
            
            .. attribute:: ispf
            
            	Configure execution of incremental SPF
            	**type**\:  :py:class:`Ispf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Ispf>`
            
            .. attribute:: log_adjacency_changes
            
            	Log changes in adjacency state
            	**type**\:  :py:class:`LogAdjacencyChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.LogAdjacencyChanges>`
            
            	**presence node**\: True
            
            .. attribute:: lsp_full
            
            	If we run out of LSP fragments
            	**type**\:  :py:class:`LspFull <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.LspFull>`
            
            .. attribute:: lsp_gen_interval
            
            	Minimum interval between regenerating same LSP
            	**type**\:  :py:class:`LspGenInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.LspGenInterval>`
            
            .. attribute:: lsp_mtu
            
            	Set maximum LSP size
            	**type**\: int
            
            	**range:** 128..4352
            
            .. attribute:: lsp_refresh_interval
            
            	Set LSP refresh interval
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: max_area_addresses
            
            	Allow configuration of more manual area addresses
            	**type**\: int
            
            	**range:** 3..254
            
            .. attribute:: max_lsp_lifetime
            
            	Set maximum LSP lifetime
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: microloop
            
            	Enable microloop protection configuration commands
            	**type**\:  :py:class:`Microloop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Microloop>`
            
            .. attribute:: mpls
            
            	Configure MPLS routing protocol parameters
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Mpls>`
            
            .. attribute:: net
            
            	A Network Entity Title for this process (OSI only)
            	**type**\: list of  		 :py:class:`Net <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Net>`
            
            .. attribute:: nsf
            
            	Non\-stop forwarding
            	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Nsf>`
            
            .. attribute:: partition
            
            	CLNS area partition
            	**type**\:  :py:class:`Partition <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Partition>`
            
            .. attribute:: passive_interface
            
            	Suppress routing updates on an interface
            	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.PassiveInterface>`
            
            .. attribute:: disable
            
            	
            	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Disable>`
            
            .. attribute:: protocol
            
            	Set protocol's administrative state
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Protocol>`
            
            .. attribute:: segment_routing
            
            	Enable Segment Routing Feature
            	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SegmentRouting>`
            
            .. attribute:: skeptical
            
            	Be a cautious NSF helper when refresh adjacency
            	**type**\:  :py:class:`Skeptical <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Skeptical>`
            
            .. attribute:: update_queue_depth
            
            	Set Update process queue depth
            	**type**\: int
            
            	**range:** 1..2147483647
            
            .. attribute:: use
            
            	Use different algorithms during SPF
            	**type**\:  :py:class:`Use <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Use>`
            
            .. attribute:: vrf
            
            	VRF name for this process
            	**type**\: str
            
            .. attribute:: adjacency_check
            
            	Check ISIS neighbor protocol support
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: bfd
            
            	BFD configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Bfd>`
            
            .. attribute:: router_id
            
            	Interface of stable IP address for system
            	**type**\: str
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-isis'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Router.Isis, self).__init__()

                self.yang_name = "isis"
                self.yang_parent_name = "router"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("metric-style", ("metric_style", Native.Router.Isis.MetricStyle)), ("address-family", ("address_family", Native.Router.Isis.AddressFamily)), ("distance", ("distance", Native.Router.Isis.Distance)), ("ip", ("ip", Native.Router.Isis.Ip)), ("redistribute", ("redistribute", Native.Router.Isis.Redistribute)), ("set-attached-bit", ("set_attached_bit", Native.Router.Isis.SetAttachedBit)), ("snmp", ("snmp", Native.Router.Isis.Snmp)), ("summary-address", ("summary_address", Native.Router.Isis.SummaryAddress)), ("traffic-share", ("traffic_share", Native.Router.Isis.TrafficShare)), ("advertise", ("advertise", Native.Router.Isis.Advertise)), ("default-information", ("default_information", Native.Router.Isis.DefaultInformation)), ("metric", ("metric", Native.Router.Isis.Metric)), ("prc-interval", ("prc_interval", Native.Router.Isis.PrcInterval)), ("set-overload-bit", ("set_overload_bit", Native.Router.Isis.SetOverloadBit)), ("spf-interval", ("spf_interval", Native.Router.Isis.SpfInterval)), ("area-password", ("area_password", Native.Router.Isis.AreaPassword)), ("authentication", ("authentication", Native.Router.Isis.Authentication)), ("distribute-list", ("distribute_list", Native.Router.Isis.DistributeList)), ("domain-password", ("domain_password", Native.Router.Isis.DomainPassword)), ("fast-flood", ("fast_flood", Native.Router.Isis.FastFlood)), ("fast-reroute", ("fast_reroute", Native.Router.Isis.FastReroute)), ("ti-lfa", ("ti_lfa", Native.Router.Isis.TiLfa)), ("hello", ("hello", Native.Router.Isis.Hello)), ("hostname", ("hostname", Native.Router.Isis.Hostname)), ("ispf", ("ispf", Native.Router.Isis.Ispf)), ("log-adjacency-changes", ("log_adjacency_changes", Native.Router.Isis.LogAdjacencyChanges)), ("lsp-full", ("lsp_full", Native.Router.Isis.LspFull)), ("lsp-gen-interval", ("lsp_gen_interval", Native.Router.Isis.LspGenInterval)), ("microloop", ("microloop", Native.Router.Isis.Microloop)), ("mpls", ("mpls", Native.Router.Isis.Mpls)), ("net", ("net", Native.Router.Isis.Net)), ("nsf", ("nsf", Native.Router.Isis.Nsf)), ("partition", ("partition", Native.Router.Isis.Partition)), ("passive-interface", ("passive_interface", Native.Router.Isis.PassiveInterface)), ("disable", ("disable", Native.Router.Isis.Disable)), ("protocol", ("protocol", Native.Router.Isis.Protocol)), ("segment-routing", ("segment_routing", Native.Router.Isis.SegmentRouting)), ("skeptical", ("skeptical", Native.Router.Isis.Skeptical)), ("use", ("use", Native.Router.Isis.Use)), ("bfd", ("bfd", Native.Router.Isis.Bfd))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                    ('help', (YLeaf(YType.empty, 'help'), ['Empty'])),
                    ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                    ('ignore_lsp_errors', (YLeaf(YType.empty, 'ignore-lsp-errors'), ['Empty'])),
                    ('is_type', (YLeaf(YType.enumeration, 'is-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.IsType')])),
                    ('lsp_mtu', (YLeaf(YType.uint32, 'lsp-mtu'), ['int'])),
                    ('lsp_refresh_interval', (YLeaf(YType.uint32, 'lsp-refresh-interval'), ['int'])),
                    ('max_area_addresses', (YLeaf(YType.uint32, 'max-area-addresses'), ['int'])),
                    ('max_lsp_lifetime', (YLeaf(YType.uint32, 'max-lsp-lifetime'), ['int'])),
                    ('update_queue_depth', (YLeaf(YType.uint32, 'update-queue-depth'), ['int'])),
                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ('adjacency_check', (YLeaf(YType.empty, 'adjacency-check'), ['Empty'])),
                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                ])
                self.priority = None
                self.help = None
                self.maximum_paths = None
                self.ignore_lsp_errors = None
                self.is_type = None
                self.lsp_mtu = None
                self.lsp_refresh_interval = None
                self.max_area_addresses = None
                self.max_lsp_lifetime = None
                self.update_queue_depth = None
                self.vrf = None
                self.adjacency_check = None
                self.router_id = None

                self.metric_style = Native.Router.Isis.MetricStyle()
                self.metric_style.parent = self
                self._children_name_map["metric_style"] = "metric-style"

                self.address_family = Native.Router.Isis.AddressFamily()
                self.address_family.parent = self
                self._children_name_map["address_family"] = "address-family"

                self.ip = Native.Router.Isis.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.redistribute = Native.Router.Isis.Redistribute()
                self.redistribute.parent = self
                self._children_name_map["redistribute"] = "redistribute"

                self.set_attached_bit = Native.Router.Isis.SetAttachedBit()
                self.set_attached_bit.parent = self
                self._children_name_map["set_attached_bit"] = "set-attached-bit"

                self.snmp = Native.Router.Isis.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "snmp"

                self.traffic_share = Native.Router.Isis.TrafficShare()
                self.traffic_share.parent = self
                self._children_name_map["traffic_share"] = "traffic-share"

                self.advertise = Native.Router.Isis.Advertise()
                self.advertise.parent = self
                self._children_name_map["advertise"] = "advertise"

                self.default_information = Native.Router.Isis.DefaultInformation()
                self.default_information.parent = self
                self._children_name_map["default_information"] = "default-information"

                self.metric = Native.Router.Isis.Metric()
                self.metric.parent = self
                self._children_name_map["metric"] = "metric"

                self.prc_interval = Native.Router.Isis.PrcInterval()
                self.prc_interval.parent = self
                self._children_name_map["prc_interval"] = "prc-interval"

                self.set_overload_bit = None
                self._children_name_map["set_overload_bit"] = "set-overload-bit"

                self.spf_interval = Native.Router.Isis.SpfInterval()
                self.spf_interval.parent = self
                self._children_name_map["spf_interval"] = "spf-interval"

                self.area_password = Native.Router.Isis.AreaPassword()
                self.area_password.parent = self
                self._children_name_map["area_password"] = "area-password"

                self.authentication = Native.Router.Isis.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "authentication"

                self.distribute_list = Native.Router.Isis.DistributeList()
                self.distribute_list.parent = self
                self._children_name_map["distribute_list"] = "distribute-list"

                self.domain_password = Native.Router.Isis.DomainPassword()
                self.domain_password.parent = self
                self._children_name_map["domain_password"] = "domain-password"

                self.fast_flood = None
                self._children_name_map["fast_flood"] = "fast-flood"

                self.fast_reroute = Native.Router.Isis.FastReroute()
                self.fast_reroute.parent = self
                self._children_name_map["fast_reroute"] = "fast-reroute"

                self.ti_lfa = Native.Router.Isis.TiLfa()
                self.ti_lfa.parent = self
                self._children_name_map["ti_lfa"] = "ti-lfa"

                self.hello = Native.Router.Isis.Hello()
                self.hello.parent = self
                self._children_name_map["hello"] = "hello"

                self.hostname = Native.Router.Isis.Hostname()
                self.hostname.parent = self
                self._children_name_map["hostname"] = "hostname"

                self.ispf = Native.Router.Isis.Ispf()
                self.ispf.parent = self
                self._children_name_map["ispf"] = "ispf"

                self.log_adjacency_changes = None
                self._children_name_map["log_adjacency_changes"] = "log-adjacency-changes"

                self.lsp_full = Native.Router.Isis.LspFull()
                self.lsp_full.parent = self
                self._children_name_map["lsp_full"] = "lsp-full"

                self.lsp_gen_interval = Native.Router.Isis.LspGenInterval()
                self.lsp_gen_interval.parent = self
                self._children_name_map["lsp_gen_interval"] = "lsp-gen-interval"

                self.microloop = Native.Router.Isis.Microloop()
                self.microloop.parent = self
                self._children_name_map["microloop"] = "microloop"

                self.mpls = Native.Router.Isis.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.nsf = Native.Router.Isis.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"

                self.partition = Native.Router.Isis.Partition()
                self.partition.parent = self
                self._children_name_map["partition"] = "partition"

                self.passive_interface = Native.Router.Isis.PassiveInterface()
                self.passive_interface.parent = self
                self._children_name_map["passive_interface"] = "passive-interface"

                self.disable = Native.Router.Isis.Disable()
                self.disable.parent = self
                self._children_name_map["disable"] = "disable"

                self.protocol = Native.Router.Isis.Protocol()
                self.protocol.parent = self
                self._children_name_map["protocol"] = "protocol"

                self.segment_routing = Native.Router.Isis.SegmentRouting()
                self.segment_routing.parent = self
                self._children_name_map["segment_routing"] = "segment-routing"

                self.skeptical = Native.Router.Isis.Skeptical()
                self.skeptical.parent = self
                self._children_name_map["skeptical"] = "skeptical"

                self.use = Native.Router.Isis.Use()
                self.use.parent = self
                self._children_name_map["use"] = "use"

                self.bfd = Native.Router.Isis.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.distance = YList(self)
                self.summary_address = YList(self)
                self.net = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-isis:isis"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Router.Isis, [u'priority', u'help', u'maximum_paths', u'ignore_lsp_errors', u'is_type', u'lsp_mtu', u'lsp_refresh_interval', u'max_area_addresses', u'max_lsp_lifetime', u'update_queue_depth', u'vrf', u'adjacency_check', u'router_id'], name, value)

            class IsType(Enum):
                """
                IsType (Enum Class)

                IS Level for this routing process (OSI only)

                .. data:: level_1 = 0

                .. data:: level_1_2 = 1

                .. data:: level_2_only = 2

                """

                level_1 = Enum.YLeaf(0, "level-1")

                level_1_2 = Enum.YLeaf(1, "level-1-2")

                level_2_only = Enum.YLeaf(2, "level-2-only")



            class MetricStyle(Entity):
                """
                Use old\-style (ISO 10589) or new\-style packet formats
                
                .. attribute:: narrow
                
                	Use old style of TLVs with narrow metric
                	**type**\:  :py:class:`Narrow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.MetricStyle.Narrow>`
                
                	**presence node**\: True
                
                .. attribute:: transition
                
                	Send and accept both styles of TLVs during transition
                	**type**\:  :py:class:`Transition <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.MetricStyle.Transition>`
                
                	**presence node**\: True
                
                .. attribute:: wide
                
                	Use new style of TLVs to carry wider metric
                	**type**\:  :py:class:`Wide <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.MetricStyle.Wide>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.MetricStyle, self).__init__()

                    self.yang_name = "metric-style"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("narrow", ("narrow", Native.Router.Isis.MetricStyle.Narrow)), ("transition", ("transition", Native.Router.Isis.MetricStyle.Transition)), ("wide", ("wide", Native.Router.Isis.MetricStyle.Wide))])
                    self._leafs = OrderedDict()

                    self.narrow = None
                    self._children_name_map["narrow"] = "narrow"

                    self.transition = None
                    self._children_name_map["transition"] = "transition"

                    self.wide = None
                    self._children_name_map["wide"] = "wide"
                    self._segment_path = lambda: "metric-style"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.MetricStyle, [], name, value)


                class Narrow(Entity):
                    """
                    Use old style of TLVs with narrow metric
                    
                    .. attribute:: narrow_wide
                    
                    	
                    	**type**\:  :py:class:`IsisLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisLevelType>`
                    
                    .. attribute:: transition
                    
                    	Accept both styles of TLVs during transition
                    	**type**\:  :py:class:`IsisLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisLevelType>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.MetricStyle.Narrow, self).__init__()

                        self.yang_name = "narrow"
                        self.yang_parent_name = "metric-style"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('narrow_wide', (YLeaf(YType.enumeration, 'narrow-wide'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisLevelType', '')])),
                            ('transition', (YLeaf(YType.enumeration, 'transition'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisLevelType', '')])),
                        ])
                        self.narrow_wide = None
                        self.transition = None
                        self._segment_path = lambda: "narrow"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/metric-style/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.MetricStyle.Narrow, [u'narrow_wide', u'transition'], name, value)


                class Transition(Entity):
                    """
                    Send and accept both styles of TLVs during transition
                    
                    .. attribute:: transition
                    
                    	
                    	**type**\:  :py:class:`IsisLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisLevelType>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.MetricStyle.Transition, self).__init__()

                        self.yang_name = "transition"
                        self.yang_parent_name = "metric-style"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('transition', (YLeaf(YType.enumeration, 'transition'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisLevelType', '')])),
                        ])
                        self.transition = None
                        self._segment_path = lambda: "transition"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/metric-style/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.MetricStyle.Transition, [u'transition'], name, value)


                class Wide(Entity):
                    """
                    Use new style of TLVs to carry wider metric
                    
                    .. attribute:: narrow_wide
                    
                    	
                    	**type**\:  :py:class:`IsisLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisLevelType>`
                    
                    .. attribute:: transition
                    
                    	Accept both styles of TLVs during transition
                    	**type**\:  :py:class:`IsisLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisLevelType>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.MetricStyle.Wide, self).__init__()

                        self.yang_name = "wide"
                        self.yang_parent_name = "metric-style"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('narrow_wide', (YLeaf(YType.enumeration, 'narrow-wide'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisLevelType', '')])),
                            ('transition', (YLeaf(YType.enumeration, 'transition'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisLevelType', '')])),
                        ])
                        self.narrow_wide = None
                        self.transition = None
                        self._segment_path = lambda: "wide"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/metric-style/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.MetricStyle.Wide, [u'narrow_wide', u'transition'], name, value)


            class AddressFamily(Entity):
                """
                Enter Address Family command mode
                
                .. attribute:: ipv4
                
                	Address family
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4>`
                
                .. attribute:: ipv6
                
                	Address family
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Isis.AddressFamily.Ipv4)), ("ipv6", ("ipv6", Native.Router.Isis.AddressFamily.Ipv6))])
                    self._leafs = OrderedDict()

                    self.ipv4 = Native.Router.Isis.AddressFamily.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = Native.Router.Isis.AddressFamily.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._segment_path = lambda: "address-family"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.AddressFamily, [], name, value)


                class Ipv4(Entity):
                    """
                    Address family
                    
                    .. attribute:: unicast_multicast
                    
                    	
                    	**type**\:  :py:class:`UnicastMulticast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.UnicastMulticast>`
                    
                    .. attribute:: help
                    
                    	Description of the interactive help system
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: snmp
                    
                    	Modify snmp parameters
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Snmp>`
                    
                    .. attribute:: topology
                    
                    	Associate the routing protocol to a topology instance
                    	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.AddressFamily.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snmp", ("snmp", Native.Router.Isis.AddressFamily.Ipv4.Snmp)), ("topology", ("topology", Native.Router.Isis.AddressFamily.Ipv4.Topology))])
                        self._leafs = OrderedDict([
                            ('unicast_multicast', (YLeaf(YType.enumeration, 'unicast-multicast'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.UnicastMulticast')])),
                            ('help', (YLeaf(YType.empty, 'help'), ['Empty'])),
                        ])
                        self.unicast_multicast = None
                        self.help = None

                        self.snmp = Native.Router.Isis.AddressFamily.Ipv4.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.topology = YList(self)
                        self._segment_path = lambda: "ipv4"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4, [u'unicast_multicast', u'help'], name, value)

                    class UnicastMulticast(Enum):
                        """
                        UnicastMulticast (Enum Class)

                        .. data:: unicast = 0

                        .. data:: multicast = 1

                        """

                        unicast = Enum.YLeaf(0, "unicast")

                        multicast = Enum.YLeaf(1, "multicast")



                    class Snmp(Entity):
                        """
                        Modify snmp parameters
                        
                        .. attribute:: context
                        
                        	Configure a SNMP context
                        	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv4.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context))])
                            self._leafs = OrderedDict()

                            self.context = YList(self)
                            self._segment_path = lambda: "snmp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Snmp, [], name, value)


                        class Context(Entity):
                            """
                            Configure a SNMP context
                            
                            .. attribute:: name  (key)
                            
                            	Context Name
                            	**type**\: str
                            
                            .. attribute:: community
                            
                            	Configure a SNMP v2c Community string and access privs
                            	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.Community>`
                            
                            .. attribute:: user
                            
                            	Configure a SNMP v3 user
                            	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context, self).__init__()

                                self.yang_name = "context"
                                self.yang_parent_name = "snmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("community", ("community", Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.Community)), ("user", ("user", Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.community = Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.Community()
                                self.community.parent = self
                                self._children_name_map["community"] = "community"

                                self.user = Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User()
                                self.user.parent = self
                                self._children_name_map["user"] = "user"
                                self._segment_path = lambda: "context" + "[name='" + str(self.name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv4/snmp/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context, [u'name'], name, value)


                            class Community(Entity):
                                """
                                Configure a SNMP v2c Community string and access privs
                                
                                .. attribute:: community_string
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: access
                                
                                	
                                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.Community.Access>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.Community, self).__init__()

                                    self.yang_name = "community"
                                    self.yang_parent_name = "context"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("access", ("access", Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.Community.Access))])
                                    self._leafs = OrderedDict([
                                        ('community_string', (YLeaf(YType.str, 'community-string'), ['str'])),
                                    ])
                                    self.community_string = None

                                    self.access = Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.Community.Access()
                                    self.access.parent = self
                                    self._children_name_map["access"] = "access"
                                    self._segment_path = lambda: "community"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.Community, [u'community_string'], name, value)


                                class Access(Entity):
                                    """
                                    
                                    
                                    .. attribute:: standard_acl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..99
                                    
                                    .. attribute:: expanded_acl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1300..1999
                                    
                                    .. attribute:: acl_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: ipv6
                                    
                                    	Specify IPv6 Named Access\-List
                                    	**type**\: str
                                    
                                    .. attribute:: ro
                                    
                                    	Read\-only access with this community string
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: rw
                                    
                                    	Read\-write access with this community string
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.Community.Access, self).__init__()

                                        self.yang_name = "access"
                                        self.yang_parent_name = "community"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                            ('expanded_acl', (YLeaf(YType.uint32, 'expanded-acl'), ['int'])),
                                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ('ro', (YLeaf(YType.empty, 'ro'), ['Empty'])),
                                            ('rw', (YLeaf(YType.empty, 'rw'), ['Empty'])),
                                        ])
                                        self.standard_acl = None
                                        self.expanded_acl = None
                                        self.acl_name = None
                                        self.ipv6 = None
                                        self.ro = None
                                        self.rw = None
                                        self._segment_path = lambda: "access"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.Community.Access, [u'standard_acl', u'expanded_acl', u'acl_name', u'ipv6', u'ro', u'rw'], name, value)


                            class User(Entity):
                                """
                                Configure a SNMP v3 user
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: permisssion
                                
                                	
                                	**type**\:  :py:class:`Permisssion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User, self).__init__()

                                    self.yang_name = "user"
                                    self.yang_parent_name = "context"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("permisssion", ("permisssion", Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.permisssion = Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion()
                                    self.permisssion.parent = self
                                    self._children_name_map["permisssion"] = "permisssion"
                                    self._segment_path = lambda: "user"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User, [u'name'], name, value)


                                class Permisssion(Entity):
                                    """
                                    
                                    
                                    .. attribute:: access
                                    
                                    	specify an access\-list associated with this group
                                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Access>`
                                    
                                    .. attribute:: auth
                                    
                                    	authentication parameters for the user
                                    	**type**\:  :py:class:`Auth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Auth>`
                                    
                                    .. attribute:: credential
                                    
                                    	If the user password is already configured and saved
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: encrypted
                                    
                                    	specifying passwords as MD5 or SHA digests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion, self).__init__()

                                        self.yang_name = "permisssion"
                                        self.yang_parent_name = "user"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("access", ("access", Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Access)), ("auth", ("auth", Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Auth))])
                                        self._leafs = OrderedDict([
                                            ('credential', (YLeaf(YType.empty, 'credential'), ['Empty'])),
                                            ('encrypted', (YLeaf(YType.empty, 'encrypted'), ['Empty'])),
                                        ])
                                        self.credential = None
                                        self.encrypted = None

                                        self.access = Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Access()
                                        self.access.parent = self
                                        self._children_name_map["access"] = "access"

                                        self.auth = Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Auth()
                                        self.auth.parent = self
                                        self._children_name_map["auth"] = "auth"
                                        self._segment_path = lambda: "permisssion"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion, [u'credential', u'encrypted'], name, value)


                                    class Access(Entity):
                                        """
                                        specify an access\-list associated with this group
                                        
                                        .. attribute:: standard_acl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: acl_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Access, self).__init__()

                                            self.yang_name = "access"
                                            self.yang_parent_name = "permisssion"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.standard_acl = None
                                            self.acl_name = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "access"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Access, [u'standard_acl', u'acl_name', u'ipv6'], name, value)


                                    class Auth(Entity):
                                        """
                                        authentication parameters for the user
                                        
                                        .. attribute:: md5
                                        
                                        	Use HMAC MD5 algorithm for authentication
                                        	**type**\: str
                                        
                                        .. attribute:: sha
                                        
                                        	Use HMAC SHA algorithm for authentication
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Auth, self).__init__()

                                            self.yang_name = "auth"
                                            self.yang_parent_name = "permisssion"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('md5', (YLeaf(YType.str, 'md5'), ['str'])),
                                                ('sha', (YLeaf(YType.str, 'sha'), ['str'])),
                                            ])
                                            self.md5 = None
                                            self.sha = None
                                            self._segment_path = lambda: "auth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Auth, [u'md5', u'sha'], name, value)


                    class Topology(Entity):
                        """
                        Associate the routing protocol to a topology instance
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: tid
                        
                        	Configuring the routing protocol topology tid
                        	**type**\: int
                        
                        	**range:** 5..4095
                        
                        .. attribute:: ignore_attached_bit
                        
                        	Never install default route to closest L2 router
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: distance
                        
                        	Define an administrative distance
                        	**type**\: list of  		 :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance>`
                        
                        .. attribute:: ip
                        
                        	IP specific commands
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip>`
                        
                        .. attribute:: priority
                        
                        	priority value
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        .. attribute:: redistribute
                        
                        	Redistribute information from another routing protocol
                        	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute>`
                        
                        .. attribute:: set_attached_bit
                        
                        	Conditionally advertise us as attached to L2
                        	**type**\:  :py:class:`SetAttachedBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SetAttachedBit>`
                        
                        .. attribute:: snmp
                        
                        	Modify snmp parameters
                        	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp>`
                        
                        .. attribute:: summary_address
                        
                        	Configure IP address summaries
                        	**type**\: list of  		 :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress>`
                        
                        .. attribute:: traffic_share
                        
                        	How to compute traffic share over alternate paths
                        	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.TrafficShare>`
                        
                        .. attribute:: advertise
                        
                        	Control which IP routes flow in L1 and L2 LSPs
                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Advertise>`
                        
                        .. attribute:: default_information
                        
                        	Control distribution of default information
                        	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.DefaultInformation>`
                        
                        .. attribute:: help
                        
                        	Description of the interactive help system
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: maximum_paths
                        
                        	Forward packets over multiple paths
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: metric
                        
                        	Set ISIS metric for all interfaces
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Metric>`
                        
                        .. attribute:: prc_interval
                        
                        	Minimum interval between partial route calculations
                        	**type**\:  :py:class:`PrcInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.PrcInterval>`
                        
                        .. attribute:: set_overload_bit
                        
                        	Signal other routers not to use us in SPF
                        	**type**\:  :py:class:`SetOverloadBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: spf_interval
                        
                        	Minimum interval between SPF calculations
                        	**type**\:  :py:class:`SpfInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("distance", ("distance", Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance)), ("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip)), ("redistribute", ("redistribute", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute)), ("set-attached-bit", ("set_attached_bit", Native.Router.Isis.AddressFamily.Ipv4.Topology.SetAttachedBit)), ("snmp", ("snmp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp)), ("summary-address", ("summary_address", Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress)), ("traffic-share", ("traffic_share", Native.Router.Isis.AddressFamily.Ipv4.Topology.TrafficShare)), ("advertise", ("advertise", Native.Router.Isis.AddressFamily.Ipv4.Topology.Advertise)), ("default-information", ("default_information", Native.Router.Isis.AddressFamily.Ipv4.Topology.DefaultInformation)), ("metric", ("metric", Native.Router.Isis.AddressFamily.Ipv4.Topology.Metric)), ("prc-interval", ("prc_interval", Native.Router.Isis.AddressFamily.Ipv4.Topology.PrcInterval)), ("set-overload-bit", ("set_overload_bit", Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit)), ("spf-interval", ("spf_interval", Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('tid', (YLeaf(YType.uint32, 'tid'), ['int'])),
                                ('ignore_attached_bit', (YLeaf(YType.empty, 'ignore-attached-bit'), ['Empty'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('help', (YLeaf(YType.empty, 'help'), ['Empty'])),
                                ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                            ])
                            self.name = None
                            self.tid = None
                            self.ignore_attached_bit = None
                            self.priority = None
                            self.help = None
                            self.maximum_paths = None

                            self.ip = Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"

                            self.redistribute = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute()
                            self.redistribute.parent = self
                            self._children_name_map["redistribute"] = "redistribute"

                            self.set_attached_bit = Native.Router.Isis.AddressFamily.Ipv4.Topology.SetAttachedBit()
                            self.set_attached_bit.parent = self
                            self._children_name_map["set_attached_bit"] = "set-attached-bit"

                            self.snmp = Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp()
                            self.snmp.parent = self
                            self._children_name_map["snmp"] = "snmp"

                            self.traffic_share = Native.Router.Isis.AddressFamily.Ipv4.Topology.TrafficShare()
                            self.traffic_share.parent = self
                            self._children_name_map["traffic_share"] = "traffic-share"

                            self.advertise = Native.Router.Isis.AddressFamily.Ipv4.Topology.Advertise()
                            self.advertise.parent = self
                            self._children_name_map["advertise"] = "advertise"

                            self.default_information = Native.Router.Isis.AddressFamily.Ipv4.Topology.DefaultInformation()
                            self.default_information.parent = self
                            self._children_name_map["default_information"] = "default-information"

                            self.metric = Native.Router.Isis.AddressFamily.Ipv4.Topology.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"

                            self.prc_interval = Native.Router.Isis.AddressFamily.Ipv4.Topology.PrcInterval()
                            self.prc_interval.parent = self
                            self._children_name_map["prc_interval"] = "prc-interval"

                            self.set_overload_bit = None
                            self._children_name_map["set_overload_bit"] = "set-overload-bit"

                            self.spf_interval = Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval()
                            self.spf_interval.parent = self
                            self._children_name_map["spf_interval"] = "spf-interval"

                            self.distance = YList(self)
                            self.summary_address = YList(self)
                            self._segment_path = lambda: "topology" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology, [u'name', u'tid', u'ignore_attached_bit', u'priority', u'help', u'maximum_paths'], name, value)


                        class Distance(Entity):
                            """
                            Define an administrative distance
                            
                            .. attribute:: number  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: ip_list
                            
                            	
                            	**type**\: list of  		 :py:class:`IpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance.IpList>`
                            
                            .. attribute:: clns
                            
                            	Distance applied for CLNS derived routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ip
                            
                            	Distance applied for IP derived routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['number']
                                self._child_classes = OrderedDict([("ip-list", ("ip_list", Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance.IpList))])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                    ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                ])
                                self.number = None
                                self.clns = None
                                self.ip = None

                                self.ip_list = YList(self)
                                self._segment_path = lambda: "distance" + "[number='" + str(self.number) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance, [u'number', u'clns', u'ip'], name, value)


                            class IpList(Entity):
                                """
                                
                                
                                .. attribute:: ip  (key)
                                
                                	IP Source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: wildcard_bits
                                
                                	
                                	**type**\: list of  		 :py:class:`WildcardBits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance.IpList.WildcardBits>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance.IpList, self).__init__()

                                    self.yang_name = "ip-list"
                                    self.yang_parent_name = "distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip']
                                    self._child_classes = OrderedDict([("wildcard-bits", ("wildcard_bits", Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance.IpList.WildcardBits))])
                                    self._leafs = OrderedDict([
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                    ])
                                    self.ip = None

                                    self.wildcard_bits = YList(self)
                                    self._segment_path = lambda: "ip-list" + "[ip='" + str(self.ip) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance.IpList, [u'ip'], name, value)


                                class WildcardBits(Entity):
                                    """
                                    
                                    
                                    .. attribute:: w_bits  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: access_list
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..99
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..1999
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance.IpList.WildcardBits, self).__init__()

                                        self.yang_name = "wildcard-bits"
                                        self.yang_parent_name = "ip-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['w_bits']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('w_bits', (YLeaf(YType.str, 'w-bits'), ['str'])),
                                            ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                                        ])
                                        self.w_bits = None
                                        self.access_list = None
                                        self._segment_path = lambda: "wildcard-bits" + "[w-bits='" + str(self.w_bits) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Distance.IpList.WildcardBits, [u'w_bits', u'access_list'], name, value)


                        class Ip(Entity):
                            """
                            IP specific commands
                            
                            .. attribute:: route
                            
                            	ISIS IP routes
                            	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("route", ("route", Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route))])
                                self._leafs = OrderedDict()

                                self.route = Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route()
                                self.route.parent = self
                                self._children_name_map["route"] = "route"
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip, [], name, value)


                            class Route(Entity):
                                """
                                ISIS IP routes
                                
                                .. attribute:: priority
                                
                                	Assign priority to IP prefixes
                                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route, self).__init__()

                                    self.yang_name = "route"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority))])
                                    self._leafs = OrderedDict()

                                    self.priority = Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority()
                                    self.priority.parent = self
                                    self._children_name_map["priority"] = "priority"
                                    self._segment_path = lambda: "route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route, [], name, value)


                                class Priority(Entity):
                                    """
                                    Assign priority to IP prefixes
                                    
                                    .. attribute:: high
                                    
                                    	Assign high priority to important IP prefixes in ISIS IP local RIB
                                    	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority.High>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority, self).__init__()

                                        self.yang_name = "priority"
                                        self.yang_parent_name = "route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("high", ("high", Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority.High))])
                                        self._leafs = OrderedDict()

                                        self.high = Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority.High()
                                        self.high.parent = self
                                        self._children_name_map["high"] = "high"
                                        self._segment_path = lambda: "priority"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority, [], name, value)


                                    class High(Entity):
                                        """
                                        Assign high priority to important IP prefixes in ISIS IP local RIB
                                        
                                        .. attribute:: tag
                                        
                                        	Assign high priority to IP prefixes with a specific route tag
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority.High, self).__init__()

                                            self.yang_name = "high"
                                            self.yang_parent_name = "priority"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.tag = None
                                            self._segment_path = lambda: "high"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority.High, [u'tag'], name, value)


                        class Redistribute(Entity):
                            """
                            Redistribute information from another routing protocol
                            
                            .. attribute:: application
                            
                            	Application
                            	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application>`
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_>`
                            
                            .. attribute:: iso_igrp
                            
                            	IGRP for OSI networks
                            	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: lisp
                            
                            	Locator ID Separation Protocol (LISP)
                            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes redistributed to protocol
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.MaximumPrefix>`
                            
                            .. attribute:: mobile
                            
                            	Mobile routes
                            	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: odr
                            
                            	On Demand stub Routes
                            	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: vrf
                            
                            	Specify a source VRF
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute, self).__init__()

                                self.yang_name = "redistribute"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp)), ("connected", ("connected", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected)), ("eigrp", ("eigrp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp)), ("lisp", ("lisp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp)), ("maximum-prefix", ("maximum_prefix", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.MaximumPrefix)), ("mobile", ("mobile", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip)), ("static", ("static", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static)), ("vrf", ("vrf", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.isis = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_()
                                self.isis.parent = self
                                self._children_name_map["isis"] = "isis"

                                self.iso_igrp = None
                                self._children_name_map["iso_igrp"] = "iso-igrp"

                                self.lisp = None
                                self._children_name_map["lisp"] = "lisp"

                                self.maximum_prefix = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.mobile = None
                                self._children_name_map["mobile"] = "mobile"

                                self.odr = None
                                self._children_name_map["odr"] = "odr"

                                self.rip = None
                                self._children_name_map["rip"] = "rip"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.vrf = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.application = YList(self)
                                self.eigrp = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self._segment_path = lambda: "redistribute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute, [], name, value)


                            class Application(Entity):
                                """
                                Application
                                
                                .. attribute:: name  (key)
                                
                                	Application name
                                	**type**\: str
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application, self).__init__()

                                    self.yang_name = "application"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.name = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application, [u'name', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: as_number
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: clns
                                
                                	Redistribution of BGP NSAP routes
                                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ip
                                
                                	Redistribution of BGP IP routes
                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns)), ("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.as_number = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None

                                    self.clns = None
                                    self._children_name_map["clns"] = "clns"

                                    self.ip = None
                                    self._children_name_map["ip"] = "ip"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp, [u'as_number', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Clns(Entity):
                                    """
                                    Redistribution of BGP NSAP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns, self).__init__()

                                        self.yang_name = "clns"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "clns"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Ip(Entity):
                                    """
                                    Redistribution of BGP IP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip, self).__init__()

                                        self.yang_name = "ip"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "ip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.uint32, 'as-number'), ['int'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.as_number = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp, [u'as_number', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Isis_(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: isis_redistribute
                                
                                	
                                	**type**\: list of  		 :py:class:`IsisRedistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute>`
                                
                                .. attribute:: ip
                                
                                	Redistribution of IP routes between levels
                                	**type**\: list of  		 :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isis-redistribute", ("isis_redistribute", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute)), ("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip))])
                                    self._leafs = OrderedDict()

                                    self.isis_redistribute = YList(self)
                                    self.ip = YList(self)
                                    self._segment_path = lambda: "isis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_, [], name, value)


                                class IsisRedistribute(Entity):
                                    """
                                    
                                    
                                    .. attribute:: area_tag  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: ip
                                    
                                    	Redistribution of IP routes between levels or processes
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute, self).__init__()

                                        self.yang_name = "isis-redistribute"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['area_tag']
                                        self._child_classes = OrderedDict([("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip))])
                                        self._leafs = OrderedDict([
                                            ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                        ])
                                        self.area_tag = None

                                        self.ip = None
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "isis-redistribute" + "[area-tag='" + str(self.area_tag) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute, [u'area_tag'], name, value)


                                    class Ip(Entity):
                                        """
                                        Redistribution of IP routes between levels or processes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "isis-redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Ip(Entity):
                                    """
                                    Redistribution of IP routes between levels
                                    
                                    .. attribute:: isis_redist_levels1  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRedistLevels1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip.IsisRedistLevels1>`
                                    
                                    .. attribute:: isis_redist_levels2  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRedistLevels2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip.IsisRedistLevels2>`
                                    
                                    .. attribute:: into
                                    
                                    	from level\-n into level\-m
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	select routes
                                    	**type**\: int
                                    
                                    	**range:** 100..199
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route matching
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip, self).__init__()

                                        self.yang_name = "ip"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['isis_redist_levels1','isis_redist_levels2']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('isis_redist_levels1', (YLeaf(YType.enumeration, 'isis-redist-levels1'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip.IsisRedistLevels1')])),
                                            ('isis_redist_levels2', (YLeaf(YType.enumeration, 'isis-redist-levels2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip.IsisRedistLevels2')])),
                                            ('into', (YLeaf(YType.empty, 'into'), ['Empty'])),
                                            ('distribute_list', (YLeaf(YType.uint32, 'distribute-list'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.isis_redist_levels1 = None
                                        self.isis_redist_levels2 = None
                                        self.into = None
                                        self.distribute_list = None
                                        self.route_map = None
                                        self._segment_path = lambda: "ip" + "[isis-redist-levels1='" + str(self.isis_redist_levels1) + "']" + "[isis-redist-levels2='" + str(self.isis_redist_levels2) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip, [u'isis_redist_levels1', u'isis_redist_levels2', u'into', u'distribute_list', u'route_map'], name, value)

                                    class IsisRedistLevels1(Enum):
                                        """
                                        IsisRedistLevels1 (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")


                                    class IsisRedistLevels2(Enum):
                                        """
                                        IsisRedistLevels2 (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")



                            class IsoIgrp(Entity):
                                """
                                IGRP for OSI networks
                                
                                .. attribute:: area_tag_route_map_container
                                
                                	
                                	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.AreaTagRouteMapContainer>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.MetricType>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp, self).__init__()

                                    self.yang_name = "iso-igrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.AreaTagRouteMapContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.MetricType')])),
                                    ])
                                    self.route_map = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None

                                    self.area_tag_route_map_container = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.AreaTagRouteMapContainer()
                                    self.area_tag_route_map_container.parent = self
                                    self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"
                                    self._segment_path = lambda: "iso-igrp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp, [u'route_map', u'levels', u'metric', u'metric_type'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class AreaTagRouteMapContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: area_tag
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                        self.yang_name = "area-tag-route-map-container"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.area_tag = None
                                        self.route_map = None
                                        self._segment_path = lambda: "area-tag-route-map-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.AreaTagRouteMapContainer, [u'area_tag', u'route_map'], name, value)


                            class Lisp(Entity):
                                """
                                Locator ID Separation Protocol (LISP)
                                
                                .. attribute:: include_connected
                                
                                	Include connected
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp, self).__init__()

                                    self.yang_name = "lisp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.include_connected = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "lisp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes redistributed to protocol
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: threshold_value
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: warning_only
                                
                                	Only give warning message when limit is exceeded
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: withdraw
                                
                                	Withdraw redistibuted prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('threshold_value', (YLeaf(YType.uint32, 'threshold-value'), ['int'])),
                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ('withdraw', (YLeaf(YType.empty, 'withdraw'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.threshold_value = None
                                    self.warning_only = None
                                    self.withdraw = None
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.MaximumPrefix, [u'number', u'threshold_value', u'warning_only', u'withdraw'], name, value)


                            class Mobile(Entity):
                                """
                                Mobile routes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile, self).__init__()

                                    self.yang_name = "mobile"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "mobile"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Odr(Entity):
                                """
                                On Demand stub Routes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr, self).__init__()

                                    self.yang_name = "odr"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "odr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: process_id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match>`
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['process_id']
                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match))])
                                    self._leafs = OrderedDict([
                                        ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.process_id = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self.vrf = None

                                    self.match = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"
                                    self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf, [u'process_id', u'levels', u'metric', u'metric_type', u'route_map', u'vrf'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.external_routes = None
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External, [u'external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.nssa_external_routes = None
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal, [u'nssa_external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Ospfv3(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: process_id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match>`
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['process_id']
                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match))])
                                    self._leafs = OrderedDict([
                                        ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.process_id = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self.vrf = None

                                    self.match = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"
                                    self._segment_path = lambda: "ospfv3" + "[process-id='" + str(self.process_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3, [u'process_id', u'levels', u'metric', u'metric_type', u'route_map', u'vrf'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal)), ("external", ("external", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.external_routes = None
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External, [u'external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.nssa_external_routes = None
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal, [u'nssa_external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "rip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: clns
                                
                                	Redistribution of BGP NSAP routes
                                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ip
                                
                                	Redistribution of BGP IP routes
                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.clns = None
                                    self._children_name_map["clns"] = "clns"

                                    self.ip = None
                                    self._children_name_map["ip"] = "ip"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static, [], name, value)


                                class Clns(Entity):
                                    """
                                    Redistribution of BGP NSAP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns, self).__init__()

                                        self.yang_name = "clns"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "clns"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Ip(Entity):
                                    """
                                    Redistribution of BGP IP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip, self).__init__()

                                        self.yang_name = "ip"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "ip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Vrf(Entity):
                                """
                                Specify a source VRF
                                
                                .. attribute:: vrf_nm
                                
                                	
                                	**type**\: list of  		 :py:class:`VrfNm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm>`
                                
                                .. attribute:: global_
                                
                                	global VRF
                                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf-nm", ("vrf_nm", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm)), ("global", ("global_", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global))])
                                    self._leafs = OrderedDict()

                                    self.global_ = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"

                                    self.vrf_nm = YList(self)
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf, [], name, value)


                                class VrfNm(Entity):
                                    """
                                    
                                    
                                    .. attribute:: vrf_nm  (key)
                                    
                                    	Source VRF name
                                    	**type**\: str
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_>`
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator ID Separation Protocol (LISP)
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Process ID
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm, self).__init__()

                                        self.yang_name = "vrf-nm"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['vrf_nm']
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application)), ("bgp", ("bgp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp)), ("connected", ("connected", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected)), ("eigrp", ("eigrp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp)), ("isis", ("isis", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp)), ("lisp", ("lisp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp)), ("mobile", ("mobile", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile)), ("ospfv3", ("ospfv3", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3)), ("rip", ("rip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip)), ("static", ("static", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static))])
                                        self._leafs = OrderedDict([
                                            ('vrf_nm', (YLeaf(YType.str, 'vrf-nm'), ['str'])),
                                            ('ospf', (YLeaf(YType.uint16, 'ospf'), ['int'])),
                                        ])
                                        self.vrf_nm = None
                                        self.ospf = None

                                        self.application = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application()
                                        self.application.parent = self
                                        self._children_name_map["application"] = "application"

                                        self.bgp = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.eigrp = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp()
                                        self.eigrp.parent = self
                                        self._children_name_map["eigrp"] = "eigrp"

                                        self.isis = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_()
                                        self.isis.parent = self
                                        self._children_name_map["isis"] = "isis"

                                        self.iso_igrp = None
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.lisp = None
                                        self._children_name_map["lisp"] = "lisp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.ospfv3 = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3()
                                        self.ospfv3.parent = self
                                        self._children_name_map["ospfv3"] = "ospfv3"

                                        self.rip = None
                                        self._children_name_map["rip"] = "rip"

                                        self.static = None
                                        self._children_name_map["static"] = "static"
                                        self._segment_path = lambda: "vrf-nm" + "[vrf-nm='" + str(self.vrf_nm) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm, [u'vrf_nm', u'ospf'], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: appname
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Appname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "vrf-nm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("appname", ("appname", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname))])
                                            self._leafs = OrderedDict()

                                            self.appname = YList(self)
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application, [], name, value)


                                        class Appname(Entity):
                                            """
                                            
                                            
                                            .. attribute:: appname  (key)
                                            
                                            	Application name
                                            	**type**\: str
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname, self).__init__()

                                                self.yang_name = "appname"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['appname']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('appname', (YLeaf(YType.str, 'appname'), ['str'])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.appname = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "appname" + "[appname='" + str(self.appname) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname, [u'appname', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: bp_as_num
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BpAsNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum>`
                                        
                                        .. attribute:: a_lesser_1_period_0_xx_period_yy_greater_
                                        
                                        	Autonomous system number
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "vrf-nm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bp-as-num", ("bp_as_num", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum))])
                                            self._leafs = OrderedDict([
                                                ('a_lesser_1_period_0_xx_period_yy_greater_', (YLeaf(YType.empty, 'a_LESSER_1_PERIOD_0-XX_PERIOD_YY_GREATER_'), ['Empty'])),
                                            ])
                                            self.a_lesser_1_period_0_xx_period_yy_greater_ = None

                                            self.bp_as_num = YList(self)
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp, [u'a_lesser_1_period_0_xx_period_yy_greater_'], name, value)


                                        class BpAsNum(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bp_as_num  (key)
                                            
                                            	Autonomous system number
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of BGP NSAP routes
                                            	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of BGP IP routes
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum, self).__init__()

                                                self.yang_name = "bp-as-num"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bp_as_num']
                                                self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns)), ("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip))])
                                                self._leafs = OrderedDict([
                                                    ('bp_as_num', (YLeaf(YType.str, 'bp-as-num'), ['int','str'])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bp_as_num = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None

                                                self.clns = None
                                                self._children_name_map["clns"] = "clns"

                                                self.ip = None
                                                self._children_name_map["ip"] = "ip"
                                                self._segment_path = lambda: "bp-as-num" + "[bp-as-num='" + str(self.bp_as_num) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum, [u'bp_as_num', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                            class Clns(Entity):
                                                """
                                                Redistribution of BGP NSAP routes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns, self).__init__()

                                                    self.yang_name = "clns"
                                                    self.yang_parent_name = "bp-as-num"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "clns"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                            class Ip(Entity):
                                                """
                                                Redistribution of BGP IP routes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "bp-as-num"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "vrf-nm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: eigrp_as
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "vrf-nm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eigrp-as", ("eigrp_as", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs))])
                                            self._leafs = OrderedDict()

                                            self.eigrp_as = YList(self)
                                            self._segment_path = lambda: "eigrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp, [], name, value)


                                        class EigrpAs(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eigrp_as  (key)
                                            
                                            	AS number
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs, self).__init__()

                                                self.yang_name = "eigrp-as"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eigrp_as']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eigrp_as', (YLeaf(YType.uint16, 'eigrp-as'), ['int'])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.eigrp_as = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-as" + "[eigrp-as='" + str(self.eigrp_as) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs, [u'eigrp_as', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Isis_(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_atag
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag>`
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP routes between levels or processes
                                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "vrf-nm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-atag", ("isis_atag", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag)), ("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip))])
                                            self._leafs = OrderedDict()

                                            self.ip = None
                                            self._children_name_map["ip"] = "ip"

                                            self.isis_atag = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_, [], name, value)


                                        class IsisAtag(Entity):
                                            """
                                            
                                            
                                            .. attribute:: isis_atag  (key)
                                            
                                            	ISO routing area tag
                                            	**type**\: str
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP routes between levels or processes
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag, self).__init__()

                                                self.yang_name = "isis-atag"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['isis_atag']
                                                self._child_classes = OrderedDict([("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip))])
                                                self._leafs = OrderedDict([
                                                    ('isis_atag', (YLeaf(YType.str, 'isis-atag'), ['str'])),
                                                ])
                                                self.isis_atag = None

                                                self.ip = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip()
                                                self.ip.parent = self
                                                self._children_name_map["ip"] = "ip"
                                                self._segment_path = lambda: "isis-atag" + "[isis-atag='" + str(self.isis_atag) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag, [u'isis_atag'], name, value)


                                            class Ip(Entity):
                                                """
                                                Redistribution of IP routes between levels or processes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "isis-atag"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Ip(Entity):
                                            """
                                            Redistribution of IP routes between levels or processes
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip, self).__init__()

                                                self.yang_name = "ip"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: iso_atag
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsoAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "vrf-nm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("iso-atag", ("iso_atag", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag)), ("route-map", ("route_map", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.route_map = None
                                            self._children_name_map["route_map"] = "route-map"

                                            self.iso_atag = YList(self)
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp, [], name, value)


                                        class IsoAtag(Entity):
                                            """
                                            
                                            
                                            .. attribute:: iso_atag  (key)
                                            
                                            	ISO routing area tag
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag, self).__init__()

                                                self.yang_name = "iso-atag"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['iso_atag']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('iso_atag', (YLeaf(YType.str, 'iso-atag'), ['str'])),
                                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                                ])
                                                self.iso_atag = None
                                                self.route_map = None
                                                self._segment_path = lambda: "iso-atag" + "[iso-atag='" + str(self.iso_atag) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag, [u'iso_atag', u'route_map'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Route map reference
                                            
                                            .. attribute:: rm_point
                                            
                                            	Pointer to route\-map entries
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('rm_point', (YLeaf(YType.str, 'rm-point'), ['str'])),
                                                ])
                                                self.rm_point = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap, [u'rm_point'], name, value)


                                    class Lisp(Entity):
                                        """
                                        Locator ID Separation Protocol (LISP)
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "vrf-nm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "vrf-nm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: os3_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Os3Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "vrf-nm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("os3-id", ("os3_id", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id))])
                                            self._leafs = OrderedDict()

                                            self.os3_id = YList(self)
                                            self._segment_path = lambda: "ospfv3"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3, [], name, value)


                                        class Os3Id(Entity):
                                            """
                                            
                                            
                                            .. attribute:: os3_id  (key)
                                            
                                            	Process ID
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id, self).__init__()

                                                self.yang_name = "os3-id"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['os3_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('os3_id', (YLeaf(YType.uint16, 'os3-id'), ['int'])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.os3_id = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "os3-id" + "[os3-id='" + str(self.os3_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id, [u'os3_id', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "vrf-nm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of BGP NSAP routes
                                        	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of BGP IP routes
                                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "vrf-nm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns)), ("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None

                                            self.clns = None
                                            self._children_name_map["clns"] = "clns"

                                            self.ip = None
                                            self._children_name_map["ip"] = "ip"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Clns(Entity):
                                            """
                                            Redistribution of BGP NSAP routes
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns, self).__init__()

                                                self.yang_name = "clns"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "clns"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Ip(Entity):
                                            """
                                            Redistribution of BGP IP routes
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip, self).__init__()

                                                self.yang_name = "ip"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Global(Entity):
                                    """
                                    global VRF
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_>`
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator ID Separation Protocol (LISP)
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Process ID
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application)), ("bgp", ("bgp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp)), ("connected", ("connected", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected)), ("eigrp", ("eigrp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp)), ("isis", ("isis", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp)), ("lisp", ("lisp", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp)), ("mobile", ("mobile", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile)), ("ospfv3", ("ospfv3", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3)), ("rip", ("rip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip)), ("static", ("static", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static))])
                                        self._leafs = OrderedDict([
                                            ('ospf', (YLeaf(YType.uint16, 'ospf'), ['int'])),
                                        ])
                                        self.ospf = None

                                        self.application = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application()
                                        self.application.parent = self
                                        self._children_name_map["application"] = "application"

                                        self.bgp = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.eigrp = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp()
                                        self.eigrp.parent = self
                                        self._children_name_map["eigrp"] = "eigrp"

                                        self.isis = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_()
                                        self.isis.parent = self
                                        self._children_name_map["isis"] = "isis"

                                        self.iso_igrp = None
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.lisp = None
                                        self._children_name_map["lisp"] = "lisp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.ospfv3 = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3()
                                        self.ospfv3.parent = self
                                        self._children_name_map["ospfv3"] = "ospfv3"

                                        self.rip = None
                                        self._children_name_map["rip"] = "rip"

                                        self.static = None
                                        self._children_name_map["static"] = "static"
                                        self._segment_path = lambda: "global"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global, [u'ospf'], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: appname
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Appname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("appname", ("appname", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname))])
                                            self._leafs = OrderedDict()

                                            self.appname = YList(self)
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application, [], name, value)


                                        class Appname(Entity):
                                            """
                                            
                                            
                                            .. attribute:: appname  (key)
                                            
                                            	Application name
                                            	**type**\: str
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname, self).__init__()

                                                self.yang_name = "appname"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['appname']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('appname', (YLeaf(YType.str, 'appname'), ['str'])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.appname = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "appname" + "[appname='" + str(self.appname) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname, [u'appname', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: bp_as_num
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BpAsNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum>`
                                        
                                        .. attribute:: a_lesser_1_period_0_xx_period_yy_greater_
                                        
                                        	Autonomous system number
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bp-as-num", ("bp_as_num", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum))])
                                            self._leafs = OrderedDict([
                                                ('a_lesser_1_period_0_xx_period_yy_greater_', (YLeaf(YType.empty, 'a_LESSER_1_PERIOD_0-XX_PERIOD_YY_GREATER_'), ['Empty'])),
                                            ])
                                            self.a_lesser_1_period_0_xx_period_yy_greater_ = None

                                            self.bp_as_num = YList(self)
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp, [u'a_lesser_1_period_0_xx_period_yy_greater_'], name, value)


                                        class BpAsNum(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bp_as_num  (key)
                                            
                                            	Autonomous system number
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of BGP NSAP routes
                                            	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of BGP IP routes
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum, self).__init__()

                                                self.yang_name = "bp-as-num"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bp_as_num']
                                                self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns)), ("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip))])
                                                self._leafs = OrderedDict([
                                                    ('bp_as_num', (YLeaf(YType.str, 'bp-as-num'), ['int','str'])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bp_as_num = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None

                                                self.clns = None
                                                self._children_name_map["clns"] = "clns"

                                                self.ip = None
                                                self._children_name_map["ip"] = "ip"
                                                self._segment_path = lambda: "bp-as-num" + "[bp-as-num='" + str(self.bp_as_num) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum, [u'bp_as_num', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                            class Clns(Entity):
                                                """
                                                Redistribution of BGP NSAP routes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns, self).__init__()

                                                    self.yang_name = "clns"
                                                    self.yang_parent_name = "bp-as-num"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "clns"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                            class Ip(Entity):
                                                """
                                                Redistribution of BGP IP routes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "bp-as-num"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: eigrp_as
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eigrp-as", ("eigrp_as", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs))])
                                            self._leafs = OrderedDict()

                                            self.eigrp_as = YList(self)
                                            self._segment_path = lambda: "eigrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp, [], name, value)


                                        class EigrpAs(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eigrp_as  (key)
                                            
                                            	AS number
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs, self).__init__()

                                                self.yang_name = "eigrp-as"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eigrp_as']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eigrp_as', (YLeaf(YType.uint16, 'eigrp-as'), ['int'])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.eigrp_as = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-as" + "[eigrp-as='" + str(self.eigrp_as) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs, [u'eigrp_as', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Isis_(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_atag
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag>`
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP routes between levels or processes
                                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-atag", ("isis_atag", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag)), ("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip))])
                                            self._leafs = OrderedDict()

                                            self.ip = None
                                            self._children_name_map["ip"] = "ip"

                                            self.isis_atag = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_, [], name, value)


                                        class IsisAtag(Entity):
                                            """
                                            
                                            
                                            .. attribute:: isis_atag  (key)
                                            
                                            	ISO routing area tag
                                            	**type**\: str
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP routes between levels or processes
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag, self).__init__()

                                                self.yang_name = "isis-atag"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['isis_atag']
                                                self._child_classes = OrderedDict([("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip))])
                                                self._leafs = OrderedDict([
                                                    ('isis_atag', (YLeaf(YType.str, 'isis-atag'), ['str'])),
                                                ])
                                                self.isis_atag = None

                                                self.ip = Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip()
                                                self.ip.parent = self
                                                self._children_name_map["ip"] = "ip"
                                                self._segment_path = lambda: "isis-atag" + "[isis-atag='" + str(self.isis_atag) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag, [u'isis_atag'], name, value)


                                            class Ip(Entity):
                                                """
                                                Redistribution of IP routes between levels or processes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "isis-atag"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Ip(Entity):
                                            """
                                            Redistribution of IP routes between levels or processes
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip, self).__init__()

                                                self.yang_name = "ip"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: iso_atag
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsoAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.IsoAtag>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.RouteMap>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("iso-atag", ("iso_atag", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.IsoAtag)), ("route-map", ("route_map", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.RouteMap))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.route_map = None
                                            self._children_name_map["route_map"] = "route-map"

                                            self.iso_atag = YList(self)
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp, [], name, value)


                                        class IsoAtag(Entity):
                                            """
                                            
                                            
                                            .. attribute:: iso_atag  (key)
                                            
                                            	ISO routing area tag
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.IsoAtag, self).__init__()

                                                self.yang_name = "iso-atag"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['iso_atag']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('iso_atag', (YLeaf(YType.str, 'iso-atag'), ['str'])),
                                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                                ])
                                                self.iso_atag = None
                                                self.route_map = None
                                                self._segment_path = lambda: "iso-atag" + "[iso-atag='" + str(self.iso_atag) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.IsoAtag, [u'iso_atag', u'route_map'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Route map reference
                                            
                                            .. attribute:: rm_point
                                            
                                            	Pointer to route\-map entries
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('rm_point', (YLeaf(YType.str, 'rm-point'), ['str'])),
                                                ])
                                                self.rm_point = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.RouteMap, [u'rm_point'], name, value)


                                    class Lisp(Entity):
                                        """
                                        Locator ID Separation Protocol (LISP)
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: os3_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Os3Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("os3-id", ("os3_id", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id))])
                                            self._leafs = OrderedDict()

                                            self.os3_id = YList(self)
                                            self._segment_path = lambda: "ospfv3"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3, [], name, value)


                                        class Os3Id(Entity):
                                            """
                                            
                                            
                                            .. attribute:: os3_id  (key)
                                            
                                            	Process ID
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id, self).__init__()

                                                self.yang_name = "os3-id"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['os3_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('os3_id', (YLeaf(YType.uint16, 'os3-id'), ['int'])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.os3_id = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "os3-id" + "[os3-id='" + str(self.os3_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id, [u'os3_id', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of BGP NSAP routes
                                        	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of BGP IP routes
                                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns)), ("ip", ("ip", Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None

                                            self.clns = None
                                            self._children_name_map["clns"] = "clns"

                                            self.ip = None
                                            self._children_name_map["ip"] = "ip"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Clns(Entity):
                                            """
                                            Redistribution of BGP NSAP routes
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns, self).__init__()

                                                self.yang_name = "clns"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "clns"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Ip(Entity):
                                            """
                                            Redistribution of BGP IP routes
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip, self).__init__()

                                                self.yang_name = "ip"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class SetAttachedBit(Entity):
                            """
                            Conditionally advertise us as attached to L2
                            
                            .. attribute:: route_map
                            
                            	Route\-map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetAttachedBit, self).__init__()

                                self.yang_name = "set-attached-bit"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None
                                self._segment_path = lambda: "set-attached-bit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetAttachedBit, [u'route_map'], name, value)


                        class Snmp(Entity):
                            """
                            Modify snmp parameters
                            
                            .. attribute:: context
                            
                            	Configure a SNMP context
                            	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp, self).__init__()

                                self.yang_name = "snmp"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("context", ("context", Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context))])
                                self._leafs = OrderedDict()

                                self.context = YList(self)
                                self._segment_path = lambda: "snmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp, [], name, value)


                            class Context(Entity):
                                """
                                Configure a SNMP context
                                
                                .. attribute:: name  (key)
                                
                                	Context Name
                                	**type**\: str
                                
                                .. attribute:: community
                                
                                	Configure a SNMP v2c Community string and access privs
                                	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community>`
                                
                                .. attribute:: user
                                
                                	Configure a SNMP v3 user
                                	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context, self).__init__()

                                    self.yang_name = "context"
                                    self.yang_parent_name = "snmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("community", ("community", Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community)), ("user", ("user", Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.community = Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community()
                                    self.community.parent = self
                                    self._children_name_map["community"] = "community"

                                    self.user = Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User()
                                    self.user.parent = self
                                    self._children_name_map["user"] = "user"
                                    self._segment_path = lambda: "context" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context, [u'name'], name, value)


                                class Community(Entity):
                                    """
                                    Configure a SNMP v2c Community string and access privs
                                    
                                    .. attribute:: community_string
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: access
                                    
                                    	
                                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community.Access>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "context"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("access", ("access", Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community.Access))])
                                        self._leafs = OrderedDict([
                                            ('community_string', (YLeaf(YType.str, 'community-string'), ['str'])),
                                        ])
                                        self.community_string = None

                                        self.access = Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community.Access()
                                        self.access.parent = self
                                        self._children_name_map["access"] = "access"
                                        self._segment_path = lambda: "community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community, [u'community_string'], name, value)


                                    class Access(Entity):
                                        """
                                        
                                        
                                        .. attribute:: standard_acl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..99
                                        
                                        .. attribute:: expanded_acl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1300..1999
                                        
                                        .. attribute:: acl_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	Specify IPv6 Named Access\-List
                                        	**type**\: str
                                        
                                        .. attribute:: ro
                                        
                                        	Read\-only access with this community string
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rw
                                        
                                        	Read\-write access with this community string
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community.Access, self).__init__()

                                            self.yang_name = "access"
                                            self.yang_parent_name = "community"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                ('expanded_acl', (YLeaf(YType.uint32, 'expanded-acl'), ['int'])),
                                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ('ro', (YLeaf(YType.empty, 'ro'), ['Empty'])),
                                                ('rw', (YLeaf(YType.empty, 'rw'), ['Empty'])),
                                            ])
                                            self.standard_acl = None
                                            self.expanded_acl = None
                                            self.acl_name = None
                                            self.ipv6 = None
                                            self.ro = None
                                            self.rw = None
                                            self._segment_path = lambda: "access"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community.Access, [u'standard_acl', u'expanded_acl', u'acl_name', u'ipv6', u'ro', u'rw'], name, value)


                                class User(Entity):
                                    """
                                    Configure a SNMP v3 user
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: permisssion
                                    
                                    	
                                    	**type**\:  :py:class:`Permisssion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User, self).__init__()

                                        self.yang_name = "user"
                                        self.yang_parent_name = "context"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("permisssion", ("permisssion", Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.permisssion = Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion()
                                        self.permisssion.parent = self
                                        self._children_name_map["permisssion"] = "permisssion"
                                        self._segment_path = lambda: "user"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User, [u'name'], name, value)


                                    class Permisssion(Entity):
                                        """
                                        
                                        
                                        .. attribute:: access
                                        
                                        	specify an access\-list associated with this group
                                        	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Access>`
                                        
                                        .. attribute:: auth
                                        
                                        	authentication parameters for the user
                                        	**type**\:  :py:class:`Auth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Auth>`
                                        
                                        .. attribute:: credential
                                        
                                        	If the user password is already configured and saved
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: encrypted
                                        
                                        	specifying passwords as MD5 or SHA digests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion, self).__init__()

                                            self.yang_name = "permisssion"
                                            self.yang_parent_name = "user"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("access", ("access", Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Access)), ("auth", ("auth", Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Auth))])
                                            self._leafs = OrderedDict([
                                                ('credential', (YLeaf(YType.empty, 'credential'), ['Empty'])),
                                                ('encrypted', (YLeaf(YType.empty, 'encrypted'), ['Empty'])),
                                            ])
                                            self.credential = None
                                            self.encrypted = None

                                            self.access = Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Access()
                                            self.access.parent = self
                                            self._children_name_map["access"] = "access"

                                            self.auth = Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Auth()
                                            self.auth.parent = self
                                            self._children_name_map["auth"] = "auth"
                                            self._segment_path = lambda: "permisssion"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion, [u'credential', u'encrypted'], name, value)


                                        class Access(Entity):
                                            """
                                            specify an access\-list associated with this group
                                            
                                            .. attribute:: standard_acl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: acl_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Access, self).__init__()

                                                self.yang_name = "access"
                                                self.yang_parent_name = "permisssion"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.standard_acl = None
                                                self.acl_name = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "access"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Access, [u'standard_acl', u'acl_name', u'ipv6'], name, value)


                                        class Auth(Entity):
                                            """
                                            authentication parameters for the user
                                            
                                            .. attribute:: md5
                                            
                                            	Use HMAC MD5 algorithm for authentication
                                            	**type**\: str
                                            
                                            .. attribute:: sha
                                            
                                            	Use HMAC SHA algorithm for authentication
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Auth, self).__init__()

                                                self.yang_name = "auth"
                                                self.yang_parent_name = "permisssion"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('md5', (YLeaf(YType.str, 'md5'), ['str'])),
                                                    ('sha', (YLeaf(YType.str, 'sha'), ['str'])),
                                                ])
                                                self.md5 = None
                                                self.sha = None
                                                self._segment_path = lambda: "auth"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Auth, [u'md5', u'sha'], name, value)


                        class SummaryAddress(Entity):
                            """
                            Configure IP address summaries
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: level_1
                            
                            	Summarize into level\-1 area
                            	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level1>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: level_1_2
                            
                            	Summarize into both area and sub\-domain
                            	**type**\:  :py:class:`Level12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level12>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: level_2
                            
                            	Summarize into level\-2 sub\-domain
                            	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level2>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: metric_tag_container
                            
                            	
                            	**type**\:  :py:class:`MetricTagContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.MetricTagContainer>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress, self).__init__()

                                self.yang_name = "summary-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip','mask']
                                self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level1)), ("level-1-2", ("level_1_2", Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level12)), ("level-2", ("level_2", Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level2)), ("metric-tag-container", ("metric_tag_container", Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.MetricTagContainer))])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.ip = None
                                self.mask = None

                                self.level_1 = None
                                self._children_name_map["level_1"] = "level-1"

                                self.level_1_2 = None
                                self._children_name_map["level_1_2"] = "level-1-2"

                                self.level_2 = None
                                self._children_name_map["level_2"] = "level-2"

                                self.metric_tag_container = Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.MetricTagContainer()
                                self.metric_tag_container.parent = self
                                self._children_name_map["metric_tag_container"] = "metric-tag-container"
                                self._segment_path = lambda: "summary-address" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress, [u'ip', u'mask'], name, value)


                            class Level1(Entity):
                                """
                                Summarize into level\-1 area
                                
                                .. attribute:: metric
                                
                                	Set metric for summay route
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: tag
                                
                                	Set tag
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level1, self).__init__()

                                    self.yang_name = "level-1"
                                    self.yang_parent_name = "summary-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ])
                                    self.metric = None
                                    self.tag = None
                                    self._segment_path = lambda: "level-1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level1, [u'metric', u'tag'], name, value)


                            class Level12(Entity):
                                """
                                Summarize into both area and sub\-domain
                                
                                .. attribute:: metric
                                
                                	Set metric for summay route
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: tag
                                
                                	Set tag
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level12, self).__init__()

                                    self.yang_name = "level-1-2"
                                    self.yang_parent_name = "summary-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ])
                                    self.metric = None
                                    self.tag = None
                                    self._segment_path = lambda: "level-1-2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level12, [u'metric', u'tag'], name, value)


                            class Level2(Entity):
                                """
                                Summarize into level\-2 sub\-domain
                                
                                .. attribute:: metric
                                
                                	Set metric for summay route
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: tag
                                
                                	Set tag
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level2, self).__init__()

                                    self.yang_name = "level-2"
                                    self.yang_parent_name = "summary-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ])
                                    self.metric = None
                                    self.tag = None
                                    self._segment_path = lambda: "level-2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level2, [u'metric', u'tag'], name, value)


                            class MetricTagContainer(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Set metric for summay route
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: tag
                                
                                	Set tag
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.MetricTagContainer, self).__init__()

                                    self.yang_name = "metric-tag-container"
                                    self.yang_parent_name = "summary-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ])
                                    self.metric = None
                                    self.tag = None
                                    self._segment_path = lambda: "metric-tag-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.MetricTagContainer, [u'metric', u'tag'], name, value)


                        class TrafficShare(Entity):
                            """
                            How to compute traffic share over alternate paths
                            
                            .. attribute:: min
                            
                            	All traffic shared among min metric paths
                            	**type**\:  :py:class:`Min <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.TrafficShare.Min>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.TrafficShare, self).__init__()

                                self.yang_name = "traffic-share"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("min", ("min", Native.Router.Isis.AddressFamily.Ipv4.Topology.TrafficShare.Min))])
                                self._leafs = OrderedDict()

                                self.min = Native.Router.Isis.AddressFamily.Ipv4.Topology.TrafficShare.Min()
                                self.min.parent = self
                                self._children_name_map["min"] = "min"
                                self._segment_path = lambda: "traffic-share"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.TrafficShare, [], name, value)


                            class Min(Entity):
                                """
                                All traffic shared among min metric paths
                                
                                .. attribute:: across_interfaces
                                
                                	Use different interfaces for equal\-cost paths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.TrafficShare.Min, self).__init__()

                                    self.yang_name = "min"
                                    self.yang_parent_name = "traffic-share"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                                    ])
                                    self.across_interfaces = None
                                    self._segment_path = lambda: "min"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.TrafficShare.Min, [u'across_interfaces'], name, value)


                        class Advertise(Entity):
                            """
                            Control which IP routes flow in L1 and L2 LSPs
                            
                            .. attribute:: passive_only
                            
                            	only interface address of passive interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Advertise, self).__init__()

                                self.yang_name = "advertise"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('passive_only', (YLeaf(YType.empty, 'passive-only'), ['Empty'])),
                                ])
                                self.passive_only = None
                                self._segment_path = lambda: "advertise"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Advertise, [u'passive_only'], name, value)


                        class DefaultInformation(Entity):
                            """
                            Control distribution of default information
                            
                            .. attribute:: originate
                            
                            	Distribute a default route
                            	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.DefaultInformation.Originate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.DefaultInformation, self).__init__()

                                self.yang_name = "default-information"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("originate", ("originate", Native.Router.Isis.AddressFamily.Ipv4.Topology.DefaultInformation.Originate))])
                                self._leafs = OrderedDict()

                                self.originate = None
                                self._children_name_map["originate"] = "originate"
                                self._segment_path = lambda: "default-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.DefaultInformation, [], name, value)


                            class Originate(Entity):
                                """
                                Distribute a default route
                                
                                .. attribute:: route_map
                                
                                	Route\-map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.DefaultInformation.Originate, self).__init__()

                                    self.yang_name = "originate"
                                    self.yang_parent_name = "default-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "originate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.DefaultInformation.Originate, [u'route_map'], name, value)


                        class Metric(Entity):
                            """
                            Set ISIS metric for all interfaces
                            
                            .. attribute:: metrics
                            
                            	
                            	**type**\: list of  		 :py:class:`Metrics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics>`
                            
                            .. attribute:: metric
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metrics", ("metrics", Native.Router.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics))])
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ])
                                self.metric = None

                                self.metrics = YList(self)
                                self._segment_path = lambda: "metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Metric, [u'metric'], name, value)


                            class Metrics(Entity):
                                """
                                
                                
                                .. attribute:: level  (key)
                                
                                	
                                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics.Level>`
                                
                                .. attribute:: metric
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..16777214
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics, self).__init__()

                                    self.yang_name = "metrics"
                                    self.yang_parent_name = "metric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['level']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics.Level')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ])
                                    self.level = None
                                    self.metric = None
                                    self._segment_path = lambda: "metrics" + "[level='" + str(self.level) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics, [u'level', u'metric'], name, value)

                                class Level(Enum):
                                    """
                                    Level (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")



                        class PrcInterval(Entity):
                            """
                            Minimum interval between partial route calculations
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120
                            
                            .. attribute:: initial_wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            .. attribute:: minimum_wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.PrcInterval, self).__init__()

                                self.yang_name = "prc-interval"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                    ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                    ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                                ])
                                self.interval = None
                                self.initial_wait = None
                                self.minimum_wait = None
                                self._segment_path = lambda: "prc-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.PrcInterval, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


                        class SetOverloadBit(Entity):
                            """
                            Signal other routers not to use us in SPF
                            
                            .. attribute:: on_startup
                            
                            	Set overload\-bit only temporarily after reboot
                            	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup>`
                            
                            .. attribute:: suppress
                            
                            	If overload\-bit set, suppress the following types of IP prefixes
                            	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.Suppress>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit, self).__init__()

                                self.yang_name = "set-overload-bit"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("on-startup", ("on_startup", Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup)), ("suppress", ("suppress", Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.Suppress))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.on_startup = Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup()
                                self.on_startup.parent = self
                                self._children_name_map["on_startup"] = "on-startup"

                                self.suppress = Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.Suppress()
                                self.suppress.parent = self
                                self._children_name_map["suppress"] = "suppress"
                                self._segment_path = lambda: "set-overload-bit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit, [], name, value)


                            class OnStartup(Entity):
                                """
                                Set overload\-bit only temporarily after reboot
                                
                                .. attribute:: time
                                
                                	
                                	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.Time>`
                                
                                .. attribute:: wait_for_bgp
                                
                                	Let BGP decide when to unset the overload bit
                                	**type**\:  :py:class:`WaitForBgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup, self).__init__()

                                    self.yang_name = "on-startup"
                                    self.yang_parent_name = "set-overload-bit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("time", ("time", Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.Time)), ("wait-for-bgp", ("wait_for_bgp", Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp))])
                                    self._leafs = OrderedDict()

                                    self.time = Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.Time()
                                    self.time.parent = self
                                    self._children_name_map["time"] = "time"

                                    self.wait_for_bgp = None
                                    self._children_name_map["wait_for_bgp"] = "wait-for-bgp"
                                    self._segment_path = lambda: "on-startup"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup, [], name, value)


                                class Time(Entity):
                                    """
                                    
                                    
                                    .. attribute:: time
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 5..86400
                                    
                                    .. attribute:: suppress
                                    
                                    	If overload\-bit set, suppress the following types of IP prefixes
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: external
                                    
                                    	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: interlevel
                                    
                                    	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.Time, self).__init__()

                                        self.yang_name = "time"
                                        self.yang_parent_name = "on-startup"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                            ('suppress', (YLeaf(YType.empty, 'suppress'), ['Empty'])),
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                        ])
                                        self.time = None
                                        self.suppress = None
                                        self.external = None
                                        self.interlevel = None
                                        self._segment_path = lambda: "time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.Time, [u'time', u'suppress', u'external', u'interlevel'], name, value)


                                class WaitForBgp(Entity):
                                    """
                                    Let BGP decide when to unset the overload bit
                                    
                                    .. attribute:: suppress
                                    
                                    	If overload\-bit set, suppress the following types of IP prefixes
                                    	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp.Suppress>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp, self).__init__()

                                        self.yang_name = "wait-for-bgp"
                                        self.yang_parent_name = "on-startup"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("suppress", ("suppress", Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp.Suppress))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.suppress = Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp.Suppress()
                                        self.suppress.parent = self
                                        self._children_name_map["suppress"] = "suppress"
                                        self._segment_path = lambda: "wait-for-bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp, [], name, value)


                                    class Suppress(Entity):
                                        """
                                        If overload\-bit set, suppress the following types of IP prefixes
                                        
                                        .. attribute:: external
                                        
                                        	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: interlevel
                                        
                                        	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp.Suppress, self).__init__()

                                            self.yang_name = "suppress"
                                            self.yang_parent_name = "wait-for-bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                                ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                            ])
                                            self.external = None
                                            self.interlevel = None
                                            self._segment_path = lambda: "suppress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp.Suppress, [u'external', u'interlevel'], name, value)


                            class Suppress(Entity):
                                """
                                If overload\-bit set, suppress the following types of IP prefixes
                                
                                .. attribute:: external
                                
                                	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: interlevel
                                
                                	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.Suppress, self).__init__()

                                    self.yang_name = "suppress"
                                    self.yang_parent_name = "set-overload-bit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                        ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                    ])
                                    self.external = None
                                    self.interlevel = None
                                    self._segment_path = lambda: "suppress"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.Suppress, [u'external', u'interlevel'], name, value)


                        class SpfInterval(Entity):
                            """
                            Minimum interval between SPF calculations
                            
                            .. attribute:: level_1_2
                            
                            	
                            	**type**\: list of  		 :py:class:`Level12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12>`
                            
                            .. attribute:: intervals
                            
                            	
                            	**type**\:  :py:class:`Intervals <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Intervals>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval, self).__init__()

                                self.yang_name = "spf-interval"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("level-1-2", ("level_1_2", Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12)), ("intervals", ("intervals", Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Intervals))])
                                self._leafs = OrderedDict()

                                self.intervals = Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Intervals()
                                self.intervals.parent = self
                                self._children_name_map["intervals"] = "intervals"

                                self.level_1_2 = YList(self)
                                self._segment_path = lambda: "spf-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval, [], name, value)


                            class Level12(Entity):
                                """
                                
                                
                                .. attribute:: level  (key)
                                
                                	
                                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12.Level>`
                                
                                .. attribute:: interval
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120
                                
                                .. attribute:: initial_wait
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120000
                                
                                .. attribute:: minimum_wait
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120000
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12, self).__init__()

                                    self.yang_name = "level-1-2"
                                    self.yang_parent_name = "spf-interval"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['level']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12.Level')])),
                                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                        ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                        ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                                    ])
                                    self.level = None
                                    self.interval = None
                                    self.initial_wait = None
                                    self.minimum_wait = None
                                    self._segment_path = lambda: "level-1-2" + "[level='" + str(self.level) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12, [u'level', u'interval', u'initial_wait', u'minimum_wait'], name, value)

                                class Level(Enum):
                                    """
                                    Level (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")



                            class Intervals(Entity):
                                """
                                
                                
                                .. attribute:: interval
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120
                                
                                .. attribute:: initial_wait
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120000
                                
                                .. attribute:: minimum_wait
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120000
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Intervals, self).__init__()

                                    self.yang_name = "intervals"
                                    self.yang_parent_name = "spf-interval"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                        ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                        ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.initial_wait = None
                                    self.minimum_wait = None
                                    self._segment_path = lambda: "intervals"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Intervals, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


                class Ipv6(Entity):
                    """
                    Address family
                    
                    .. attribute:: unicast
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: advertise
                    
                    	Control which IP routes flow in L1 and L2 LSPs
                    	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Advertise>`
                    
                    .. attribute:: default_information
                    
                    	Control distribution of default information
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.DefaultInformation>`
                    
                    .. attribute:: help
                    
                    	Description of the interactive help system
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: maximum_paths
                    
                    	Forward packets over multiple paths
                    	**type**\: int
                    
                    	**range:** 1..32
                    
                    .. attribute:: metric
                    
                    	Set ISIS metric for all interfaces
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Metric>`
                    
                    .. attribute:: prc_interval
                    
                    	Minimum interval between partial route calculations
                    	**type**\:  :py:class:`PrcInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.PrcInterval>`
                    
                    .. attribute:: set_overload_bit
                    
                    	Signal other routers not to use us in SPF
                    	**type**\:  :py:class:`SetOverloadBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: spf_interval
                    
                    	Minimum interval between SPF calculations
                    	**type**\:  :py:class:`SpfInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SpfInterval>`
                    
                    .. attribute:: adjacency_check
                    
                    	Check ISIS neighbor protocol support
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bfd
                    
                    	BFD configuration commands
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Bfd>`
                    
                    .. attribute:: router_id
                    
                    	Interface of stable IP address for system
                    	**type**\: str
                    
                    .. attribute:: distance
                    
                    	Administrative distance
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    .. attribute:: distribute_list
                    
                    	Filter networks in routing updates
                    	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.DistributeList>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 specific commands
                    	**type**\:  :py:class:`Ipv6_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Ipv6_>`
                    
                    .. attribute:: multi_topology
                    
                    	Enable multi\-topology mode
                    	**type**\:  :py:class:`MultiTopology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.MultiTopology>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: redistribute
                    
                    	Redistribute IPv6 prefixes from another routing protocol
                    	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute>`
                    
                    .. attribute:: summary_prefix
                    
                    	Configure IPv6 summary prefix
                    	**type**\: list of  		 :py:class:`SummaryPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SummaryPrefix>`
                    
                    .. attribute:: table_map
                    
                    	Map external entry attributes into routing table
                    	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.TableMap>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.AddressFamily.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Isis.AddressFamily.Ipv6.Advertise)), ("default-information", ("default_information", Native.Router.Isis.AddressFamily.Ipv6.DefaultInformation)), ("metric", ("metric", Native.Router.Isis.AddressFamily.Ipv6.Metric)), ("prc-interval", ("prc_interval", Native.Router.Isis.AddressFamily.Ipv6.PrcInterval)), ("set-overload-bit", ("set_overload_bit", Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit)), ("spf-interval", ("spf_interval", Native.Router.Isis.AddressFamily.Ipv6.SpfInterval)), ("bfd", ("bfd", Native.Router.Isis.AddressFamily.Ipv6.Bfd)), ("distribute-list", ("distribute_list", Native.Router.Isis.AddressFamily.Ipv6.DistributeList)), ("ipv6", ("ipv6", Native.Router.Isis.AddressFamily.Ipv6.Ipv6_)), ("multi-topology", ("multi_topology", Native.Router.Isis.AddressFamily.Ipv6.MultiTopology)), ("redistribute", ("redistribute", Native.Router.Isis.AddressFamily.Ipv6.Redistribute)), ("summary-prefix", ("summary_prefix", Native.Router.Isis.AddressFamily.Ipv6.SummaryPrefix)), ("table-map", ("table_map", Native.Router.Isis.AddressFamily.Ipv6.TableMap))])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ('help', (YLeaf(YType.empty, 'help'), ['Empty'])),
                            ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                            ('adjacency_check', (YLeaf(YType.empty, 'adjacency-check'), ['Empty'])),
                            ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                            ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                        ])
                        self.unicast = None
                        self.help = None
                        self.maximum_paths = None
                        self.adjacency_check = None
                        self.router_id = None
                        self.distance = None

                        self.advertise = Native.Router.Isis.AddressFamily.Ipv6.Advertise()
                        self.advertise.parent = self
                        self._children_name_map["advertise"] = "advertise"

                        self.default_information = Native.Router.Isis.AddressFamily.Ipv6.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"

                        self.metric = Native.Router.Isis.AddressFamily.Ipv6.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.prc_interval = Native.Router.Isis.AddressFamily.Ipv6.PrcInterval()
                        self.prc_interval.parent = self
                        self._children_name_map["prc_interval"] = "prc-interval"

                        self.set_overload_bit = None
                        self._children_name_map["set_overload_bit"] = "set-overload-bit"

                        self.spf_interval = Native.Router.Isis.AddressFamily.Ipv6.SpfInterval()
                        self.spf_interval.parent = self
                        self._children_name_map["spf_interval"] = "spf-interval"

                        self.bfd = Native.Router.Isis.AddressFamily.Ipv6.Bfd()
                        self.bfd.parent = self
                        self._children_name_map["bfd"] = "bfd"

                        self.distribute_list = Native.Router.Isis.AddressFamily.Ipv6.DistributeList()
                        self.distribute_list.parent = self
                        self._children_name_map["distribute_list"] = "distribute-list"

                        self.ipv6 = Native.Router.Isis.AddressFamily.Ipv6.Ipv6_()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.multi_topology = None
                        self._children_name_map["multi_topology"] = "multi-topology"

                        self.redistribute = Native.Router.Isis.AddressFamily.Ipv6.Redistribute()
                        self.redistribute.parent = self
                        self._children_name_map["redistribute"] = "redistribute"

                        self.table_map = Native.Router.Isis.AddressFamily.Ipv6.TableMap()
                        self.table_map.parent = self
                        self._children_name_map["table_map"] = "table-map"

                        self.summary_prefix = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6, [u'unicast', u'help', u'maximum_paths', u'adjacency_check', u'router_id', u'distance'], name, value)


                    class Advertise(Entity):
                        """
                        Control which IP routes flow in L1 and L2 LSPs
                        
                        .. attribute:: passive_only
                        
                        	only interface address of passive interfaces
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.Advertise, self).__init__()

                            self.yang_name = "advertise"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('passive_only', (YLeaf(YType.empty, 'passive-only'), ['Empty'])),
                            ])
                            self.passive_only = None
                            self._segment_path = lambda: "advertise"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Advertise, [u'passive_only'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Control distribution of default information
                        
                        .. attribute:: originate
                        
                        	Distribute a default route
                        	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.DefaultInformation.Originate>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("originate", ("originate", Native.Router.Isis.AddressFamily.Ipv6.DefaultInformation.Originate))])
                            self._leafs = OrderedDict()

                            self.originate = None
                            self._children_name_map["originate"] = "originate"
                            self._segment_path = lambda: "default-information"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.DefaultInformation, [], name, value)


                        class Originate(Entity):
                            """
                            Distribute a default route
                            
                            .. attribute:: route_map
                            
                            	Route\-map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.DefaultInformation.Originate, self).__init__()

                                self.yang_name = "originate"
                                self.yang_parent_name = "default-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None
                                self._segment_path = lambda: "originate"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/default-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.DefaultInformation.Originate, [u'route_map'], name, value)


                    class Metric(Entity):
                        """
                        Set ISIS metric for all interfaces
                        
                        .. attribute:: metrics
                        
                        	
                        	**type**\: list of  		 :py:class:`Metrics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Metric.Metrics>`
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metrics", ("metrics", Native.Router.Isis.AddressFamily.Ipv6.Metric.Metrics))])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.metric = None

                            self.metrics = YList(self)
                            self._segment_path = lambda: "metric"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Metric, [u'metric'], name, value)


                        class Metrics(Entity):
                            """
                            
                            
                            .. attribute:: level  (key)
                            
                            	
                            	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Metric.Metrics.Level>`
                            
                            .. attribute:: metric
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Metric.Metrics, self).__init__()

                                self.yang_name = "metrics"
                                self.yang_parent_name = "metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['level']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Metric.Metrics.Level')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ])
                                self.level = None
                                self.metric = None
                                self._segment_path = lambda: "metrics" + "[level='" + str(self.level) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/metric/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Metric.Metrics, [u'level', u'metric'], name, value)

                            class Level(Enum):
                                """
                                Level (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")



                    class PrcInterval(Entity):
                        """
                        Minimum interval between partial route calculations
                        
                        .. attribute:: interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120
                        
                        .. attribute:: initial_wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        .. attribute:: minimum_wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.PrcInterval, self).__init__()

                            self.yang_name = "prc-interval"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                            ])
                            self.interval = None
                            self.initial_wait = None
                            self.minimum_wait = None
                            self._segment_path = lambda: "prc-interval"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.PrcInterval, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


                    class SetOverloadBit(Entity):
                        """
                        Signal other routers not to use us in SPF
                        
                        .. attribute:: on_startup
                        
                        	Set overload\-bit only temporarily after reboot
                        	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup>`
                        
                        .. attribute:: suppress
                        
                        	If overload\-bit set, suppress the following types of IP prefixes
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.Suppress>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit, self).__init__()

                            self.yang_name = "set-overload-bit"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("on-startup", ("on_startup", Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup)), ("suppress", ("suppress", Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.Suppress))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.on_startup = Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup()
                            self.on_startup.parent = self
                            self._children_name_map["on_startup"] = "on-startup"

                            self.suppress = Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.Suppress()
                            self.suppress.parent = self
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "set-overload-bit"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit, [], name, value)


                        class OnStartup(Entity):
                            """
                            Set overload\-bit only temporarily after reboot
                            
                            .. attribute:: time
                            
                            	
                            	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.Time>`
                            
                            .. attribute:: wait_for_bgp
                            
                            	Let BGP decide when to unset the overload bit
                            	**type**\:  :py:class:`WaitForBgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup, self).__init__()

                                self.yang_name = "on-startup"
                                self.yang_parent_name = "set-overload-bit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("time", ("time", Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.Time)), ("wait-for-bgp", ("wait_for_bgp", Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp))])
                                self._leafs = OrderedDict()

                                self.time = Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.Time()
                                self.time.parent = self
                                self._children_name_map["time"] = "time"

                                self.wait_for_bgp = None
                                self._children_name_map["wait_for_bgp"] = "wait-for-bgp"
                                self._segment_path = lambda: "on-startup"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/set-overload-bit/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup, [], name, value)


                            class Time(Entity):
                                """
                                
                                
                                .. attribute:: time
                                
                                	
                                	**type**\: int
                                
                                	**range:** 5..86400
                                
                                .. attribute:: suppress
                                
                                	If overload\-bit set, suppress the following types of IP prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: external
                                
                                	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: interlevel
                                
                                	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.Time, self).__init__()

                                    self.yang_name = "time"
                                    self.yang_parent_name = "on-startup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                        ('suppress', (YLeaf(YType.empty, 'suppress'), ['Empty'])),
                                        ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                        ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                    ])
                                    self.time = None
                                    self.suppress = None
                                    self.external = None
                                    self.interlevel = None
                                    self._segment_path = lambda: "time"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/set-overload-bit/on-startup/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.Time, [u'time', u'suppress', u'external', u'interlevel'], name, value)


                            class WaitForBgp(Entity):
                                """
                                Let BGP decide when to unset the overload bit
                                
                                .. attribute:: suppress
                                
                                	If overload\-bit set, suppress the following types of IP prefixes
                                	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp.Suppress>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp, self).__init__()

                                    self.yang_name = "wait-for-bgp"
                                    self.yang_parent_name = "on-startup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("suppress", ("suppress", Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp.Suppress))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.suppress = Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp.Suppress()
                                    self.suppress.parent = self
                                    self._children_name_map["suppress"] = "suppress"
                                    self._segment_path = lambda: "wait-for-bgp"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/set-overload-bit/on-startup/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp, [], name, value)


                                class Suppress(Entity):
                                    """
                                    If overload\-bit set, suppress the following types of IP prefixes
                                    
                                    .. attribute:: external
                                    
                                    	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: interlevel
                                    
                                    	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp.Suppress, self).__init__()

                                        self.yang_name = "suppress"
                                        self.yang_parent_name = "wait-for-bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.interlevel = None
                                        self._segment_path = lambda: "suppress"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/set-overload-bit/on-startup/wait-for-bgp/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp.Suppress, [u'external', u'interlevel'], name, value)


                        class Suppress(Entity):
                            """
                            If overload\-bit set, suppress the following types of IP prefixes
                            
                            .. attribute:: external
                            
                            	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: interlevel
                            
                            	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "set-overload-bit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                    ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                ])
                                self.external = None
                                self.interlevel = None
                                self._segment_path = lambda: "suppress"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/set-overload-bit/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.SetOverloadBit.Suppress, [u'external', u'interlevel'], name, value)


                    class SpfInterval(Entity):
                        """
                        Minimum interval between SPF calculations
                        
                        .. attribute:: level_1_2
                        
                        	
                        	**type**\: list of  		 :py:class:`Level12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SpfInterval.Level12>`
                        
                        .. attribute:: intervals
                        
                        	
                        	**type**\:  :py:class:`Intervals <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SpfInterval.Intervals>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.SpfInterval, self).__init__()

                            self.yang_name = "spf-interval"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level-1-2", ("level_1_2", Native.Router.Isis.AddressFamily.Ipv6.SpfInterval.Level12)), ("intervals", ("intervals", Native.Router.Isis.AddressFamily.Ipv6.SpfInterval.Intervals))])
                            self._leafs = OrderedDict()

                            self.intervals = Native.Router.Isis.AddressFamily.Ipv6.SpfInterval.Intervals()
                            self.intervals.parent = self
                            self._children_name_map["intervals"] = "intervals"

                            self.level_1_2 = YList(self)
                            self._segment_path = lambda: "spf-interval"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.SpfInterval, [], name, value)


                        class Level12(Entity):
                            """
                            
                            
                            .. attribute:: level  (key)
                            
                            	
                            	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SpfInterval.Level12.Level>`
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120
                            
                            .. attribute:: initial_wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            .. attribute:: minimum_wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.SpfInterval.Level12, self).__init__()

                                self.yang_name = "level-1-2"
                                self.yang_parent_name = "spf-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['level']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.SpfInterval.Level12.Level')])),
                                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                    ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                    ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                                ])
                                self.level = None
                                self.interval = None
                                self.initial_wait = None
                                self.minimum_wait = None
                                self._segment_path = lambda: "level-1-2" + "[level='" + str(self.level) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/spf-interval/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.SpfInterval.Level12, [u'level', u'interval', u'initial_wait', u'minimum_wait'], name, value)

                            class Level(Enum):
                                """
                                Level (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")



                        class Intervals(Entity):
                            """
                            
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120
                            
                            .. attribute:: initial_wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            .. attribute:: minimum_wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.SpfInterval.Intervals, self).__init__()

                                self.yang_name = "intervals"
                                self.yang_parent_name = "spf-interval"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                    ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                    ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                                ])
                                self.interval = None
                                self.initial_wait = None
                                self.minimum_wait = None
                                self._segment_path = lambda: "intervals"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/spf-interval/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.SpfInterval.Intervals, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


                    class Bfd(Entity):
                        """
                        BFD configuration commands
                        
                        .. attribute:: all_interfaces
                        
                        	Enable BFD on all interfaces
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: check_ctrl_plane_failure
                        
                        	BFD check control plane failure
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                                ('check_ctrl_plane_failure', (YLeaf(YType.empty, 'check-ctrl-plane-failure'), ['Empty'])),
                            ])
                            self.all_interfaces = None
                            self.check_ctrl_plane_failure = None
                            self._segment_path = lambda: "bfd"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Bfd, [u'all_interfaces', u'check_ctrl_plane_failure'], name, value)


                    class DistributeList(Entity):
                        """
                        Filter networks in routing updates
                        
                        .. attribute:: prefix_list
                        
                        	Filter connections based on an IPv6 prefix\-list
                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.DistributeList, self).__init__()

                            self.yang_name = "distribute-list"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix-list", ("prefix_list", Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList))])
                            self._leafs = OrderedDict()

                            self.prefix_list = YList(self)
                            self._segment_path = lambda: "distribute-list"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.DistributeList, [], name, value)


                        class PrefixList(Entity):
                            """
                            Filter connections based on an IPv6 prefix\-list
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Filter incoming routing updates
                            	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList, self).__init__()

                                self.yang_name = "prefix-list"
                                self.yang_parent_name = "distribute-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("in", ("in_", Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.in_ = None
                                self._children_name_map["in_"] = "in"
                                self._segment_path = lambda: "prefix-list" + "[name='" + str(self.name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/distribute-list/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList, [u'name'], name, value)


                            class In(Entity):
                                """
                                Filter incoming routing updates
                                
                                .. attribute:: interface
                                
                                	Specify interface
                                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In, self).__init__()

                                    self.yang_name = "in"
                                    self.yang_parent_name = "prefix-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("interface", ("interface", Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.interface = Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                    self._segment_path = lambda: "in"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In, [], name, value)


                                class Interface(Entity):
                                    """
                                    Specify interface
                                    
                                    .. attribute:: appnav_compress
                                    
                                    	Service\-Context Virtual Interface Compress
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: appnav_uncompress
                                    
                                    	Service\-Context Virtual Interface UnCompress
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm
                                    
                                    	ATM interface
                                    	**type**\: str
                                    
                                    .. attribute:: atm_subinterface
                                    
                                    	
                                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMSubinterface>`
                                    
                                    .. attribute:: atm_acr
                                    
                                    	ATM\-ACR interface
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]
                                    
                                    .. attribute:: atm_acrsubinterface
                                    
                                    	
                                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMACRsubinterface>`
                                    
                                    .. attribute:: bdi
                                    
                                    	Bridge\-Domain interface
                                    	**type**\: str
                                    
                                    .. attribute:: cem
                                    
                                    	CEM interface
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9]/){2}[0\-9]
                                    
                                    .. attribute:: cem_acr
                                    
                                    	CEM\-ACR interface
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: embedded_service_engine
                                    
                                    	cisco embedded service engine module
                                    	**type**\: str
                                    
                                    .. attribute:: ethernet
                                    
                                    	IEEE 802.3
                                    	**type**\: str
                                    
                                    .. attribute:: fastethernet
                                    
                                    	FastEthernet IEEE 802.3
                                    	**type**\: str
                                    
                                    .. attribute:: gigabitethernet
                                    
                                    	GigabitEthernet IEEE 802.3z
                                    	**type**\: str
                                    
                                    .. attribute:: fivegigabitethernet
                                    
                                    	Five GigabitEthernet 
                                    	**type**\: str
                                    
                                    .. attribute:: twentyfivegige
                                    
                                    	Twenty Five GigabitEthernet 
                                    	**type**\: str
                                    
                                    .. attribute:: twogigabitethernet
                                    
                                    	Two GigabitEthernet 
                                    	**type**\: str
                                    
                                    .. attribute:: fortygigabitethernet
                                    
                                    	Forty GigabitEthernet 
                                    	**type**\: str
                                    
                                    .. attribute:: hundredgige
                                    
                                    	Hundred GigabitEthernet
                                    	**type**\: str
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator/ID Separation Protocol Virtual Interface
                                    	**type**\: str
                                    
                                    .. attribute:: lisp_subinterface
                                    
                                    	Locator/ID Separation Protocol Virtual Interface
                                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.LISPSubinterface>`
                                    
                                    .. attribute:: loopback
                                    
                                    	Loopback interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multilink
                                    
                                    	Multilink\-group interface
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nve
                                    
                                    	Network virtualization endpoint interface
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: overlay
                                    
                                    	Overlay interface
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: port_channel
                                    
                                    	Ethernet Channel of interfaces
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: port_channel_subinterface
                                    
                                    	
                                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.PortChannelSubinterface>`
                                    
                                    .. attribute:: pseudowire
                                    
                                    	Pseudowire Interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sm
                                    
                                    	SM Interface
                                    	**type**\: str
                                    
                                    .. attribute:: cellular
                                    
                                    	Cellular Interface
                                    	**type**\: str
                                    
                                    .. attribute:: serial
                                    
                                    	Serial interface
                                    	**type**\: str
                                    
                                    .. attribute:: tengigabitethernet
                                    
                                    	Ten Gigabit Ethernet
                                    	**type**\: str
                                    
                                    .. attribute:: tunnel
                                    
                                    	Tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_template
                                    
                                    	Virtual Template interface
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vlan
                                    
                                    	Iosxr Vlans
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: virtualportgroup
                                    
                                    	Virtual Port Group
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vasileft
                                    
                                    	vasileft
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vasiright
                                    
                                    	vasiright
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "in"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.PortChannelSubinterface))])
                                        self._leafs = OrderedDict([
                                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                        ])
                                        self.appnav_compress = None
                                        self.appnav_uncompress = None
                                        self.atm = None
                                        self.atm_acr = None
                                        self.bdi = None
                                        self.cem = None
                                        self.cem_acr = None
                                        self.embedded_service_engine = None
                                        self.ethernet = None
                                        self.fastethernet = None
                                        self.gigabitethernet = None
                                        self.fivegigabitethernet = None
                                        self.twentyfivegige = None
                                        self.twogigabitethernet = None
                                        self.fortygigabitethernet = None
                                        self.hundredgige = None
                                        self.lisp = None
                                        self.loopback = None
                                        self.multilink = None
                                        self.nve = None
                                        self.overlay = None
                                        self.port_channel = None
                                        self.pseudowire = None
                                        self.sm = None
                                        self.cellular = None
                                        self.serial = None
                                        self.tengigabitethernet = None
                                        self.tunnel = None
                                        self.virtual_template = None
                                        self.vlan = None
                                        self.virtualportgroup = None
                                        self.vasileft = None
                                        self.vasiright = None

                                        self.atm_subinterface = Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMSubinterface()
                                        self.atm_subinterface.parent = self
                                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                        self.atm_acrsubinterface = Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMACRsubinterface()
                                        self.atm_acrsubinterface.parent = self
                                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                        self.lisp_subinterface = Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.LISPSubinterface()
                                        self.lisp_subinterface.parent = self
                                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                        self.port_channel_subinterface = Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.PortChannelSubinterface()
                                        self.port_channel_subinterface.parent = self
                                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                        self._segment_path = lambda: "interface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                    class ATMSubinterface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: atm
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMSubinterface, self).__init__()

                                            self.yang_name = "ATM-subinterface"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                            ])
                                            self.atm = None
                                            self._segment_path = lambda: "ATM-subinterface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMSubinterface, [u'atm'], name, value)


                                    class ATMACRsubinterface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: atm_acr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMACRsubinterface, self).__init__()

                                            self.yang_name = "ATM-ACRsubinterface"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                            ])
                                            self.atm_acr = None
                                            self._segment_path = lambda: "ATM-ACRsubinterface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                    class LISPSubinterface(Entity):
                                        """
                                        Locator/ID Separation Protocol Virtual Interface
                                        
                                        .. attribute:: lisp
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.LISPSubinterface, self).__init__()

                                            self.yang_name = "LISP-subinterface"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                            ])
                                            self.lisp = None
                                            self._segment_path = lambda: "LISP-subinterface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.LISPSubinterface, [u'lisp'], name, value)


                                    class PortChannelSubinterface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: port_channel
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.PortChannelSubinterface, self).__init__()

                                            self.yang_name = "Port-channel-subinterface"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                            ])
                                            self.port_channel = None
                                            self._segment_path = lambda: "Port-channel-subinterface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                    class Ipv6_(Entity):
                        """
                        IPv6 specific commands
                        
                        .. attribute:: route
                        
                        	ISIS IPV6 routes
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.Ipv6_, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("route", ("route", Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route))])
                            self._leafs = OrderedDict()

                            self.route = Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "ipv6"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Ipv6_, [], name, value)


                        class Route(Entity):
                            """
                            ISIS IPV6 routes
                            
                            .. attribute:: priority
                            
                            	Assign priority to IPV6 prefixes
                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority))])
                                self._leafs = OrderedDict()

                                self.priority = Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority()
                                self.priority.parent = self
                                self._children_name_map["priority"] = "priority"
                                self._segment_path = lambda: "route"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route, [], name, value)


                            class Priority(Entity):
                                """
                                Assign priority to IPV6 prefixes
                                
                                .. attribute:: high
                                
                                	Assign high priority to important IPV6 prefixes in ISIS IPV6 local RIB
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority.High>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority, self).__init__()

                                    self.yang_name = "priority"
                                    self.yang_parent_name = "route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority.High))])
                                    self._leafs = OrderedDict()

                                    self.high = Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "priority"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/ipv6/route/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority, [], name, value)


                                class High(Entity):
                                    """
                                    Assign high priority to important IPV6 prefixes in ISIS IPV6 local RIB
                                    
                                    .. attribute:: tag
                                    
                                    	Assign high priority to IPV6 prefixes with a specific route tag
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "priority"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.tag = None
                                        self._segment_path = lambda: "high"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/ipv6/route/priority/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority.High, [u'tag'], name, value)


                    class MultiTopology(Entity):
                        """
                        Enable multi\-topology mode
                        
                        .. attribute:: transition
                        
                        	Accept and generate both IS\-IS IPv6 and Multi\-topology IPv6 TLVs
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.MultiTopology, self).__init__()

                            self.yang_name = "multi-topology"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('transition', (YLeaf(YType.empty, 'transition'), ['Empty'])),
                            ])
                            self.transition = None
                            self._segment_path = lambda: "multi-topology"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.MultiTopology, [u'transition'], name, value)


                    class Redistribute(Entity):
                        """
                        Redistribute IPv6 prefixes from another routing protocol
                        
                        .. attribute:: application
                        
                        	Application Protocol
                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Application>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Connected>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: lisp
                        
                        	Locator ID Separation Protocol (LISP)
                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Lisp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: nd
                        
                        	Neighbor Discovery
                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Nd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: nemo
                        
                        	Network Mobility (NEMO)
                        	**type**\:  :py:class:`Nemo <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Nemo>`
                        
                        .. attribute:: ospf
                        
                        	Open Shortest Path First (OSPF)
                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf>`
                        
                        .. attribute:: rip
                        
                        	IPv6 Routing Information Protocol (RIPv6)
                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Rip>`
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Static>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute, self).__init__()

                            self.yang_name = "redistribute"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Bgp)), ("connected", ("connected", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Connected)), ("eigrp", ("eigrp", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_)), ("lisp", ("lisp", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Lisp)), ("nd", ("nd", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Nd)), ("nemo", ("nemo", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Nemo)), ("ospf", ("ospf", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf)), ("rip", ("rip", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Rip)), ("static", ("static", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Static))])
                            self._leafs = OrderedDict()

                            self.application = None
                            self._children_name_map["application"] = "application"

                            self.bgp = Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Bgp()
                            self.bgp.parent = self
                            self._children_name_map["bgp"] = "bgp"

                            self.connected = None
                            self._children_name_map["connected"] = "connected"

                            self.isis = None
                            self._children_name_map["isis"] = "isis"

                            self.lisp = None
                            self._children_name_map["lisp"] = "lisp"

                            self.nd = None
                            self._children_name_map["nd"] = "nd"

                            self.nemo = Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Nemo()
                            self.nemo.parent = self
                            self._children_name_map["nemo"] = "nemo"

                            self.static = None
                            self._children_name_map["static"] = "static"

                            self.eigrp = YList(self)
                            self.ospf = YList(self)
                            self.rip = YList(self)
                            self._segment_path = lambda: "redistribute"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute, [], name, value)


                        class Application(Entity):
                            """
                            Application Protocol
                            
                            .. attribute:: include_connected
                            
                            	Include connected
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Application.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Application, self).__init__()

                                self.yang_name = "application"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Application.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.include_connected = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "application"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Application, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: as_number
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: include_connected
                            
                            	Include connected
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Bgp.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Bgp.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.as_number = None
                                self.include_connected = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "bgp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Bgp, [u'as_number', u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Connected.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Connected.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "connected"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: as_number  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: include_connected
                            
                            	Include connected
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Eigrp.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['as_number']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('as_number', (YLeaf(YType.uint32, 'as-number'), ['int'])),
                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Eigrp.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.as_number = None
                                self.include_connected = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Eigrp, [u'as_number', u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Isis_(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: isis_redistribute
                            
                            	
                            	**type**\: list of  		 :py:class:`IsisRedistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute>`
                            
                            .. attribute:: isis_leak
                            
                            	
                            	**type**\: list of  		 :py:class:`IsisLeak <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("isis-redistribute", ("isis_redistribute", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute)), ("isis-leak", ("isis_leak", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.isis_redistribute = YList(self)
                                self.isis_leak = YList(self)
                                self._segment_path = lambda: "isis"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_, [], name, value)


                            class IsisRedistribute(Entity):
                                """
                                
                                
                                .. attribute:: area_tag  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: include_connected
                                
                                	Include connected
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute, self).__init__()

                                    self.yang_name = "isis-redistribute"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['area_tag']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                        ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.area_tag = None
                                    self.include_connected = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "isis-redistribute" + "[area-tag='" + str(self.area_tag) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/isis/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute, [u'area_tag', u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class IsisLeak(Entity):
                                """
                                
                                
                                .. attribute:: isis_redist_levels1  (key)
                                
                                	
                                	**type**\:  :py:class:`IsisRedistLevels1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak.IsisRedistLevels1>`
                                
                                .. attribute:: isis_redist_levels2  (key)
                                
                                	
                                	**type**\:  :py:class:`IsisRedistLevels2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak.IsisRedistLevels2>`
                                
                                .. attribute:: into
                                
                                	from level\-n into level\-m
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: distribute_list
                                
                                	select routes
                                	**type**\: str
                                
                                .. attribute:: route_map
                                
                                	Route map for route matching
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak, self).__init__()

                                    self.yang_name = "isis-leak"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['isis_redist_levels1','isis_redist_levels2']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('isis_redist_levels1', (YLeaf(YType.enumeration, 'isis-redist-levels1'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak.IsisRedistLevels1')])),
                                        ('isis_redist_levels2', (YLeaf(YType.enumeration, 'isis-redist-levels2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak.IsisRedistLevels2')])),
                                        ('into', (YLeaf(YType.empty, 'into'), ['Empty'])),
                                        ('distribute_list', (YLeaf(YType.str, 'distribute-list'), ['str'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.isis_redist_levels1 = None
                                    self.isis_redist_levels2 = None
                                    self.into = None
                                    self.distribute_list = None
                                    self.route_map = None
                                    self._segment_path = lambda: "isis-leak" + "[isis-redist-levels1='" + str(self.isis_redist_levels1) + "']" + "[isis-redist-levels2='" + str(self.isis_redist_levels2) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/isis/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak, [u'isis_redist_levels1', u'isis_redist_levels2', u'into', u'distribute_list', u'route_map'], name, value)

                                class IsisRedistLevels1(Enum):
                                    """
                                    IsisRedistLevels1 (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")


                                class IsisRedistLevels2(Enum):
                                    """
                                    IsisRedistLevels2 (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")



                        class Lisp(Entity):
                            """
                            Locator ID Separation Protocol (LISP)
                            
                            .. attribute:: include_connected
                            
                            	Include connected
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Lisp.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Lisp, self).__init__()

                                self.yang_name = "lisp"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Lisp.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.include_connected = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "lisp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Lisp, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Nd(Entity):
                            """
                            Neighbor Discovery
                            
                            .. attribute:: include_connected
                            
                            	Include connected
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Nd.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Nd, self).__init__()

                                self.yang_name = "nd"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Nd.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.include_connected = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "nd"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Nd, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Nemo(Entity):
                            """
                            Network Mobility (NEMO)
                            
                            .. attribute:: include_connected
                            
                            	Include connected
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Nemo.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Nemo, self).__init__()

                                self.yang_name = "nemo"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Nemo.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.include_connected = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "nemo"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Nemo, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Ospf(Entity):
                            """
                            Open Shortest Path First (OSPF)
                            
                            .. attribute:: process_id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: include_connected
                            
                            	Include connected
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: match
                            
                            	Redistribution of OSPF routes
                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf, self).__init__()

                                self.yang_name = "ospf"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['process_id']
                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match))])
                                self._leafs = OrderedDict([
                                    ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.process_id = None
                                self.include_connected = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None

                                self.match = Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match()
                                self.match.parent = self
                                self._children_name_map["match"] = "match"
                                self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf, [u'process_id', u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Match(Entity):
                                """
                                Redistribution of OSPF routes
                                
                                .. attribute:: internal
                                
                                	Redistribute OSPF internal routes
                                	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: external
                                
                                	Redistribute OSPF external routes
                                	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: nssa_external
                                
                                	Redistribute OSPF NSSA external routes
                                	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match, self).__init__()

                                    self.yang_name = "match"
                                    self.yang_parent_name = "ospf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal))])
                                    self._leafs = OrderedDict()

                                    self.internal = None
                                    self._children_name_map["internal"] = "internal"

                                    self.external = None
                                    self._children_name_map["external"] = "external"

                                    self.nssa_external = None
                                    self._children_name_map["nssa_external"] = "nssa-external"
                                    self._segment_path = lambda: "match"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match, [], name, value)


                                class Internal(Entity):
                                    """
                                    Redistribute OSPF internal routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal, self).__init__()

                                        self.yang_name = "internal"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "internal"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class External(Entity):
                                    """
                                    Redistribute OSPF external routes
                                    
                                    .. attribute:: external_routes
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External, self).__init__()

                                        self.yang_name = "external"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.external_routes = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "external"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External, [u'external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class NssaExternal(Entity):
                                    """
                                    Redistribute OSPF NSSA external routes
                                    
                                    .. attribute:: nssa_external_routes
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                        self.yang_name = "nssa-external"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.nssa_external_routes = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "nssa-external"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal, [u'nssa_external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Rip(Entity):
                            """
                            IPv6 Routing Information Protocol (RIPv6)
                            
                            .. attribute:: process  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: include_connected
                            
                            	Include connected
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Rip.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['process']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('process', (YLeaf(YType.str, 'process'), ['str'])),
                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Rip.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.process = None
                                self.include_connected = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "rip" + "[process='" + str(self.process) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Rip, [u'process', u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Static.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.Redistribute.Static.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "static"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/redistribute/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.Redistribute.Static, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class SummaryPrefix(Entity):
                        """
                        Configure IPv6 summary prefix
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AddressFamily.Ipv6.SummaryPrefix.Levels>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.SummaryPrefix, self).__init__()

                            self.yang_name = "summary-prefix"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AddressFamily.Ipv6.SummaryPrefix.Levels')])),
                            ])
                            self.prefix = None
                            self.levels = None
                            self._segment_path = lambda: "summary-prefix" + "[prefix='" + str(self.prefix) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.SummaryPrefix, [u'prefix', u'levels'], name, value)

                        class Levels(Enum):
                            """
                            Levels (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_1_2 = 1

                            .. data:: level_2 = 2

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_1_2 = Enum.YLeaf(1, "level-1-2")

                            level_2 = Enum.YLeaf(2, "level-2")



                    class TableMap(Entity):
                        """
                        Map external entry attributes into routing table
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: filter
                        
                        	Selective route download
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.AddressFamily.Ipv6.TableMap, self).__init__()

                            self.yang_name = "table-map"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                            ])
                            self.name = None
                            self.filter = None
                            self._segment_path = lambda: "table-map"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/address-family/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.AddressFamily.Ipv6.TableMap, [u'name', u'filter'], name, value)


            class Distance(Entity):
                """
                Define an administrative distance
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: ip_list
                
                	
                	**type**\: list of  		 :py:class:`IpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Distance.IpList>`
                
                .. attribute:: clns
                
                	Distance applied for CLNS derived routes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ip
                
                	Distance applied for IP derived routes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Distance, self).__init__()

                    self.yang_name = "distance"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("ip-list", ("ip_list", Native.Router.Isis.Distance.IpList))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                        ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                        ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                    ])
                    self.number = None
                    self.clns = None
                    self.ip = None

                    self.ip_list = YList(self)
                    self._segment_path = lambda: "distance" + "[number='" + str(self.number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Distance, [u'number', u'clns', u'ip'], name, value)


                class IpList(Entity):
                    """
                    
                    
                    .. attribute:: ip  (key)
                    
                    	IP Source address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: wildcard_bits
                    
                    	
                    	**type**\: list of  		 :py:class:`WildcardBits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Distance.IpList.WildcardBits>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Distance.IpList, self).__init__()

                        self.yang_name = "ip-list"
                        self.yang_parent_name = "distance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['ip']
                        self._child_classes = OrderedDict([("wildcard-bits", ("wildcard_bits", Native.Router.Isis.Distance.IpList.WildcardBits))])
                        self._leafs = OrderedDict([
                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                        ])
                        self.ip = None

                        self.wildcard_bits = YList(self)
                        self._segment_path = lambda: "ip-list" + "[ip='" + str(self.ip) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Distance.IpList, [u'ip'], name, value)


                    class WildcardBits(Entity):
                        """
                        
                        
                        .. attribute:: w_bits  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..99
                        
                        		**type**\: int
                        
                        			**range:** 1300..1999
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Distance.IpList.WildcardBits, self).__init__()

                            self.yang_name = "wildcard-bits"
                            self.yang_parent_name = "ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['w_bits']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('w_bits', (YLeaf(YType.str, 'w-bits'), ['str'])),
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                            ])
                            self.w_bits = None
                            self.access_list = None
                            self._segment_path = lambda: "wildcard-bits" + "[w-bits='" + str(self.w_bits) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Distance.IpList.WildcardBits, [u'w_bits', u'access_list'], name, value)


            class Ip(Entity):
                """
                IP specific commands
                
                .. attribute:: route
                
                	ISIS IP routes
                	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Ip.Route>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("route", ("route", Native.Router.Isis.Ip.Route))])
                    self._leafs = OrderedDict()

                    self.route = Native.Router.Isis.Ip.Route()
                    self.route.parent = self
                    self._children_name_map["route"] = "route"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Ip, [], name, value)


                class Route(Entity):
                    """
                    ISIS IP routes
                    
                    .. attribute:: priority
                    
                    	Assign priority to IP prefixes
                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Ip.Route.Priority>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Ip.Route, self).__init__()

                        self.yang_name = "route"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Isis.Ip.Route.Priority))])
                        self._leafs = OrderedDict()

                        self.priority = Native.Router.Isis.Ip.Route.Priority()
                        self.priority.parent = self
                        self._children_name_map["priority"] = "priority"
                        self._segment_path = lambda: "route"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Ip.Route, [], name, value)


                    class Priority(Entity):
                        """
                        Assign priority to IP prefixes
                        
                        .. attribute:: high
                        
                        	Assign high priority to important IP prefixes in ISIS IP local RIB
                        	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Ip.Route.Priority.High>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Ip.Route.Priority, self).__init__()

                            self.yang_name = "priority"
                            self.yang_parent_name = "route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("high", ("high", Native.Router.Isis.Ip.Route.Priority.High))])
                            self._leafs = OrderedDict()

                            self.high = Native.Router.Isis.Ip.Route.Priority.High()
                            self.high.parent = self
                            self._children_name_map["high"] = "high"
                            self._segment_path = lambda: "priority"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/ip/route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Ip.Route.Priority, [], name, value)


                        class High(Entity):
                            """
                            Assign high priority to important IP prefixes in ISIS IP local RIB
                            
                            .. attribute:: tag
                            
                            	Assign high priority to IP prefixes with a specific route tag
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Ip.Route.Priority.High, self).__init__()

                                self.yang_name = "high"
                                self.yang_parent_name = "priority"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ])
                                self.tag = None
                                self._segment_path = lambda: "high"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/ip/route/priority/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Ip.Route.Priority.High, [u'tag'], name, value)


            class Redistribute(Entity):
                """
                Redistribute information from another routing protocol
                
                .. attribute:: application
                
                	Application
                	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Application>`
                
                .. attribute:: bgp
                
                	Border Gateway Protocol (BGP)
                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Bgp>`
                
                .. attribute:: connected
                
                	Connected
                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Connected>`
                
                	**presence node**\: True
                
                .. attribute:: eigrp
                
                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Eigrp>`
                
                .. attribute:: isis
                
                	ISO IS\-IS
                	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Isis_>`
                
                .. attribute:: iso_igrp
                
                	IGRP for OSI networks
                	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.IsoIgrp>`
                
                	**presence node**\: True
                
                .. attribute:: lisp
                
                	Locator ID Separation Protocol (LISP)
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Lisp>`
                
                	**presence node**\: True
                
                .. attribute:: maximum_prefix
                
                	Maximum number of prefixes redistributed to protocol
                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.MaximumPrefix>`
                
                .. attribute:: mobile
                
                	Mobile routes
                	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Mobile>`
                
                	**presence node**\: True
                
                .. attribute:: odr
                
                	On Demand stub Routes
                	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Odr>`
                
                	**presence node**\: True
                
                .. attribute:: ospf
                
                	Open Shortest Path First (OSPF)
                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospf>`
                
                .. attribute:: ospfv3
                
                	Open Shortest Path First (OSPF)
                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospfv3>`
                
                .. attribute:: rip
                
                	Routing Information Protocol (RIP)
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Rip>`
                
                	**presence node**\: True
                
                .. attribute:: static
                
                	Static routes
                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Static>`
                
                	**presence node**\: True
                
                .. attribute:: vrf
                
                	Specify a source VRF
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Redistribute, self).__init__()

                    self.yang_name = "redistribute"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("application", ("application", Native.Router.Isis.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Isis.Redistribute.Bgp)), ("connected", ("connected", Native.Router.Isis.Redistribute.Connected)), ("eigrp", ("eigrp", Native.Router.Isis.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Isis.Redistribute.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.Isis.Redistribute.IsoIgrp)), ("lisp", ("lisp", Native.Router.Isis.Redistribute.Lisp)), ("maximum-prefix", ("maximum_prefix", Native.Router.Isis.Redistribute.MaximumPrefix)), ("mobile", ("mobile", Native.Router.Isis.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Isis.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Isis.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Isis.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Isis.Redistribute.Rip)), ("static", ("static", Native.Router.Isis.Redistribute.Static)), ("vrf", ("vrf", Native.Router.Isis.Redistribute.Vrf))])
                    self._leafs = OrderedDict()

                    self.bgp = Native.Router.Isis.Redistribute.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "bgp"

                    self.connected = None
                    self._children_name_map["connected"] = "connected"

                    self.isis = Native.Router.Isis.Redistribute.Isis_()
                    self.isis.parent = self
                    self._children_name_map["isis"] = "isis"

                    self.iso_igrp = None
                    self._children_name_map["iso_igrp"] = "iso-igrp"

                    self.lisp = None
                    self._children_name_map["lisp"] = "lisp"

                    self.maximum_prefix = Native.Router.Isis.Redistribute.MaximumPrefix()
                    self.maximum_prefix.parent = self
                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                    self.mobile = None
                    self._children_name_map["mobile"] = "mobile"

                    self.odr = None
                    self._children_name_map["odr"] = "odr"

                    self.rip = None
                    self._children_name_map["rip"] = "rip"

                    self.static = None
                    self._children_name_map["static"] = "static"

                    self.vrf = Native.Router.Isis.Redistribute.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.application = YList(self)
                    self.eigrp = YList(self)
                    self.ospf = YList(self)
                    self.ospfv3 = YList(self)
                    self._segment_path = lambda: "redistribute"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Redistribute, [], name, value)


                class Application(Entity):
                    """
                    Application
                    
                    .. attribute:: name  (key)
                    
                    	Application name
                    	**type**\: str
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                    
                    .. attribute:: metric
                    
                    	ISIS default metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Application.MetricType>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Application, self).__init__()

                        self.yang_name = "application"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Application.MetricType')])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.name = None
                        self.levels = None
                        self.metric = None
                        self.metric_type = None
                        self.route_map = None
                        self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Application, [u'name', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: external = 0

                        .. data:: internal = 1

                        .. data:: rib_metric_as_external = 2

                        .. data:: rib_metric_as_internal = 3

                        """

                        external = Enum.YLeaf(0, "external")

                        internal = Enum.YLeaf(1, "internal")

                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class Bgp(Entity):
                    """
                    Border Gateway Protocol (BGP)
                    
                    .. attribute:: as_number
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: str
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                    
                    .. attribute:: metric
                    
                    	ISIS default metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Bgp.MetricType>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    .. attribute:: clns
                    
                    	Redistribution of BGP NSAP routes
                    	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Bgp.Clns>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ip
                    
                    	Redistribution of BGP IP routes
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Bgp.Ip>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.Redistribute.Bgp.Clns)), ("ip", ("ip", Native.Router.Isis.Redistribute.Bgp.Ip))])
                        self._leafs = OrderedDict([
                            ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Bgp.MetricType')])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.as_number = None
                        self.levels = None
                        self.metric = None
                        self.metric_type = None
                        self.route_map = None

                        self.clns = None
                        self._children_name_map["clns"] = "clns"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "bgp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Bgp, [u'as_number', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: external = 0

                        .. data:: internal = 1

                        .. data:: rib_metric_as_external = 2

                        .. data:: rib_metric_as_internal = 3

                        """

                        external = Enum.YLeaf(0, "external")

                        internal = Enum.YLeaf(1, "internal")

                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Clns(Entity):
                        """
                        Redistribution of BGP NSAP routes
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Bgp.Clns.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Redistribute.Bgp.Clns, self).__init__()

                            self.yang_name = "clns"
                            self.yang_parent_name = "bgp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Bgp.Clns.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self._segment_path = lambda: "clns"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/bgp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Redistribute.Bgp.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Ip(Entity):
                        """
                        Redistribution of BGP IP routes
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Bgp.Ip.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Redistribute.Bgp.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "bgp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Bgp.Ip.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self._segment_path = lambda: "ip"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/bgp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Redistribute.Bgp.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class Connected(Entity):
                    """
                    Connected
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                    
                    .. attribute:: metric
                    
                    	ISIS default metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Connected.MetricType>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Connected, self).__init__()

                        self.yang_name = "connected"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Connected.MetricType')])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.levels = None
                        self.metric = None
                        self.metric_type = None
                        self.route_map = None
                        self._segment_path = lambda: "connected"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: external = 0

                        .. data:: internal = 1

                        .. data:: rib_metric_as_external = 2

                        .. data:: rib_metric_as_internal = 3

                        """

                        external = Enum.YLeaf(0, "external")

                        internal = Enum.YLeaf(1, "internal")

                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class Eigrp(Entity):
                    """
                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                    
                    .. attribute:: as_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                    
                    .. attribute:: metric
                    
                    	ISIS default metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Eigrp.MetricType>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Eigrp, self).__init__()

                        self.yang_name = "eigrp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['as_number']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('as_number', (YLeaf(YType.uint32, 'as-number'), ['int'])),
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Eigrp.MetricType')])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.as_number = None
                        self.levels = None
                        self.metric = None
                        self.metric_type = None
                        self.route_map = None
                        self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Eigrp, [u'as_number', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: external = 0

                        .. data:: internal = 1

                        .. data:: rib_metric_as_external = 2

                        .. data:: rib_metric_as_internal = 3

                        """

                        external = Enum.YLeaf(0, "external")

                        internal = Enum.YLeaf(1, "internal")

                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class Isis_(Entity):
                    """
                    ISO IS\-IS
                    
                    .. attribute:: isis_redistribute
                    
                    	
                    	**type**\: list of  		 :py:class:`IsisRedistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Isis_.IsisRedistribute>`
                    
                    .. attribute:: ip
                    
                    	Redistribution of IP routes between levels
                    	**type**\: list of  		 :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Isis_.Ip>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Isis_, self).__init__()

                        self.yang_name = "isis"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis-redistribute", ("isis_redistribute", Native.Router.Isis.Redistribute.Isis_.IsisRedistribute)), ("ip", ("ip", Native.Router.Isis.Redistribute.Isis_.Ip))])
                        self._leafs = OrderedDict()

                        self.isis_redistribute = YList(self)
                        self.ip = YList(self)
                        self._segment_path = lambda: "isis"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Isis_, [], name, value)


                    class IsisRedistribute(Entity):
                        """
                        
                        
                        .. attribute:: area_tag  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip
                        
                        	Redistribution of IP routes between levels or processes
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Isis_.IsisRedistribute.Ip>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Redistribute.Isis_.IsisRedistribute, self).__init__()

                            self.yang_name = "isis-redistribute"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['area_tag']
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Router.Isis.Redistribute.Isis_.IsisRedistribute.Ip))])
                            self._leafs = OrderedDict([
                                ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                            ])
                            self.area_tag = None

                            self.ip = None
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "isis-redistribute" + "[area-tag='" + str(self.area_tag) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/isis/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Redistribute.Isis_.IsisRedistribute, [u'area_tag'], name, value)


                        class Ip(Entity):
                            """
                            Redistribution of IP routes between levels or processes
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Isis_.IsisRedistribute.Ip.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Isis_.IsisRedistribute.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "isis-redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Isis_.IsisRedistribute.Ip.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Isis_.IsisRedistribute.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Ip(Entity):
                        """
                        Redistribution of IP routes between levels
                        
                        .. attribute:: isis_redist_levels1  (key)
                        
                        	
                        	**type**\:  :py:class:`IsisRedistLevels1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Isis_.Ip.IsisRedistLevels1>`
                        
                        .. attribute:: isis_redist_levels2  (key)
                        
                        	
                        	**type**\:  :py:class:`IsisRedistLevels2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Isis_.Ip.IsisRedistLevels2>`
                        
                        .. attribute:: into
                        
                        	from level\-n into level\-m
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: distribute_list
                        
                        	select routes
                        	**type**\: int
                        
                        	**range:** 100..199
                        
                        .. attribute:: route_map
                        
                        	Route map for route matching
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Redistribute.Isis_.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['isis_redist_levels1','isis_redist_levels2']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('isis_redist_levels1', (YLeaf(YType.enumeration, 'isis-redist-levels1'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Isis_.Ip.IsisRedistLevels1')])),
                                ('isis_redist_levels2', (YLeaf(YType.enumeration, 'isis-redist-levels2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Isis_.Ip.IsisRedistLevels2')])),
                                ('into', (YLeaf(YType.empty, 'into'), ['Empty'])),
                                ('distribute_list', (YLeaf(YType.uint32, 'distribute-list'), ['int'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.isis_redist_levels1 = None
                            self.isis_redist_levels2 = None
                            self.into = None
                            self.distribute_list = None
                            self.route_map = None
                            self._segment_path = lambda: "ip" + "[isis-redist-levels1='" + str(self.isis_redist_levels1) + "']" + "[isis-redist-levels2='" + str(self.isis_redist_levels2) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/isis/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Redistribute.Isis_.Ip, [u'isis_redist_levels1', u'isis_redist_levels2', u'into', u'distribute_list', u'route_map'], name, value)

                        class IsisRedistLevels1(Enum):
                            """
                            IsisRedistLevels1 (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")


                        class IsisRedistLevels2(Enum):
                            """
                            IsisRedistLevels2 (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class IsoIgrp(Entity):
                    """
                    IGRP for OSI networks
                    
                    .. attribute:: area_tag_route_map_container
                    
                    	
                    	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.IsoIgrp.AreaTagRouteMapContainer>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                    
                    .. attribute:: metric
                    
                    	ISIS default metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.IsoIgrp.MetricType>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.IsoIgrp, self).__init__()

                        self.yang_name = "iso-igrp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Isis.Redistribute.IsoIgrp.AreaTagRouteMapContainer))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.IsoIgrp.MetricType')])),
                        ])
                        self.route_map = None
                        self.levels = None
                        self.metric = None
                        self.metric_type = None

                        self.area_tag_route_map_container = Native.Router.Isis.Redistribute.IsoIgrp.AreaTagRouteMapContainer()
                        self.area_tag_route_map_container.parent = self
                        self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"
                        self._segment_path = lambda: "iso-igrp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.IsoIgrp, [u'route_map', u'levels', u'metric', u'metric_type'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: external = 0

                        .. data:: internal = 1

                        .. data:: rib_metric_as_external = 2

                        .. data:: rib_metric_as_internal = 3

                        """

                        external = Enum.YLeaf(0, "external")

                        internal = Enum.YLeaf(1, "internal")

                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class AreaTagRouteMapContainer(Entity):
                        """
                        
                        
                        .. attribute:: area_tag
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Redistribute.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                            self.yang_name = "area-tag-route-map-container"
                            self.yang_parent_name = "iso-igrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.area_tag = None
                            self.route_map = None
                            self._segment_path = lambda: "area-tag-route-map-container"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/iso-igrp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Redistribute.IsoIgrp.AreaTagRouteMapContainer, [u'area_tag', u'route_map'], name, value)


                class Lisp(Entity):
                    """
                    Locator ID Separation Protocol (LISP)
                    
                    .. attribute:: include_connected
                    
                    	Include connected
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                    
                    .. attribute:: metric
                    
                    	ISIS default metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Lisp.MetricType>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Lisp.MetricType')])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.include_connected = None
                        self.levels = None
                        self.metric = None
                        self.metric_type = None
                        self.route_map = None
                        self._segment_path = lambda: "lisp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Lisp, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: external = 0

                        .. data:: internal = 1

                        .. data:: rib_metric_as_external = 2

                        .. data:: rib_metric_as_internal = 3

                        """

                        external = Enum.YLeaf(0, "external")

                        internal = Enum.YLeaf(1, "internal")

                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class MaximumPrefix(Entity):
                    """
                    Maximum number of prefixes redistributed to protocol
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: threshold_value
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    .. attribute:: warning_only
                    
                    	Only give warning message when limit is exceeded
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: withdraw
                    
                    	Withdraw redistibuted prefixes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.MaximumPrefix, self).__init__()

                        self.yang_name = "maximum-prefix"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                            ('threshold_value', (YLeaf(YType.uint32, 'threshold-value'), ['int'])),
                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                            ('withdraw', (YLeaf(YType.empty, 'withdraw'), ['Empty'])),
                        ])
                        self.number = None
                        self.threshold_value = None
                        self.warning_only = None
                        self.withdraw = None
                        self._segment_path = lambda: "maximum-prefix"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.MaximumPrefix, [u'number', u'threshold_value', u'warning_only', u'withdraw'], name, value)


                class Mobile(Entity):
                    """
                    Mobile routes
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                    
                    .. attribute:: metric
                    
                    	ISIS default metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Mobile.MetricType>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Mobile, self).__init__()

                        self.yang_name = "mobile"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Mobile.MetricType')])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.levels = None
                        self.metric = None
                        self.metric_type = None
                        self.route_map = None
                        self._segment_path = lambda: "mobile"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: external = 0

                        .. data:: internal = 1

                        .. data:: rib_metric_as_external = 2

                        .. data:: rib_metric_as_internal = 3

                        """

                        external = Enum.YLeaf(0, "external")

                        internal = Enum.YLeaf(1, "internal")

                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class Odr(Entity):
                    """
                    On Demand stub Routes
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                    
                    .. attribute:: metric
                    
                    	ISIS default metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Odr.MetricType>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Odr, self).__init__()

                        self.yang_name = "odr"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Odr.MetricType')])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.levels = None
                        self.metric = None
                        self.metric_type = None
                        self.route_map = None
                        self._segment_path = lambda: "odr"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Odr, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: external = 0

                        .. data:: internal = 1

                        .. data:: rib_metric_as_external = 2

                        .. data:: rib_metric_as_internal = 3

                        """

                        external = Enum.YLeaf(0, "external")

                        internal = Enum.YLeaf(1, "internal")

                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class Ospf(Entity):
                    """
                    Open Shortest Path First (OSPF)
                    
                    .. attribute:: process_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                    
                    .. attribute:: metric
                    
                    	ISIS default metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospf.MetricType>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    .. attribute:: match
                    
                    	Redistribution of OSPF routes
                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospf.Match>`
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding Instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['process_id']
                        self._child_classes = OrderedDict([("match", ("match", Native.Router.Isis.Redistribute.Ospf.Match))])
                        self._leafs = OrderedDict([
                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Ospf.MetricType')])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.process_id = None
                        self.levels = None
                        self.metric = None
                        self.metric_type = None
                        self.route_map = None
                        self.vrf = None

                        self.match = Native.Router.Isis.Redistribute.Ospf.Match()
                        self.match.parent = self
                        self._children_name_map["match"] = "match"
                        self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Ospf, [u'process_id', u'levels', u'metric', u'metric_type', u'route_map', u'vrf'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: external = 0

                        .. data:: internal = 1

                        .. data:: rib_metric_as_external = 2

                        .. data:: rib_metric_as_internal = 3

                        """

                        external = Enum.YLeaf(0, "external")

                        internal = Enum.YLeaf(1, "internal")

                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Match(Entity):
                        """
                        Redistribution of OSPF routes
                        
                        .. attribute:: internal
                        
                        	Redistribute OSPF internal routes
                        	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospf.Match.Internal>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: external
                        
                        	Redistribute OSPF external routes
                        	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospf.Match.External>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: nssa_external
                        
                        	Redistribute OSPF NSSA external routes
                        	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospf.Match.NssaExternal>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Redistribute.Ospf.Match, self).__init__()

                            self.yang_name = "match"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Isis.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.Isis.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Isis.Redistribute.Ospf.Match.NssaExternal))])
                            self._leafs = OrderedDict()

                            self.internal = None
                            self._children_name_map["internal"] = "internal"

                            self.external = None
                            self._children_name_map["external"] = "external"

                            self.nssa_external = None
                            self._children_name_map["nssa_external"] = "nssa-external"
                            self._segment_path = lambda: "match"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Redistribute.Ospf.Match, [], name, value)


                        class Internal(Entity):
                            """
                            Redistribute OSPF internal routes
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospf.Match.Internal.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Ospf.Match.Internal, self).__init__()

                                self.yang_name = "internal"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Ospf.Match.Internal.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "internal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Ospf.Match.Internal, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class External(Entity):
                            """
                            Redistribute OSPF external routes
                            
                            .. attribute:: external_routes
                            
                            	
                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospf.Match.External.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Ospf.Match.External, self).__init__()

                                self.yang_name = "external"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Ospf.Match.External.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.external_routes = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "external"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Ospf.Match.External, [u'external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class NssaExternal(Entity):
                            """
                            Redistribute OSPF NSSA external routes
                            
                            .. attribute:: nssa_external_routes
                            
                            	
                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospf.Match.NssaExternal.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                self.yang_name = "nssa-external"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Ospf.Match.NssaExternal.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.nssa_external_routes = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "nssa-external"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Ospf.Match.NssaExternal, [u'nssa_external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class Ospfv3(Entity):
                    """
                    Open Shortest Path First (OSPF)
                    
                    .. attribute:: process_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                    
                    .. attribute:: metric
                    
                    	ISIS default metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospfv3.MetricType>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    .. attribute:: match
                    
                    	Redistribution of OSPF routes
                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospfv3.Match>`
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding Instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Ospfv3, self).__init__()

                        self.yang_name = "ospfv3"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['process_id']
                        self._child_classes = OrderedDict([("match", ("match", Native.Router.Isis.Redistribute.Ospfv3.Match))])
                        self._leafs = OrderedDict([
                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Ospfv3.MetricType')])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.process_id = None
                        self.levels = None
                        self.metric = None
                        self.metric_type = None
                        self.route_map = None
                        self.vrf = None

                        self.match = Native.Router.Isis.Redistribute.Ospfv3.Match()
                        self.match.parent = self
                        self._children_name_map["match"] = "match"
                        self._segment_path = lambda: "ospfv3" + "[process-id='" + str(self.process_id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Ospfv3, [u'process_id', u'levels', u'metric', u'metric_type', u'route_map', u'vrf'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: external = 0

                        .. data:: internal = 1

                        .. data:: rib_metric_as_external = 2

                        .. data:: rib_metric_as_internal = 3

                        """

                        external = Enum.YLeaf(0, "external")

                        internal = Enum.YLeaf(1, "internal")

                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Match(Entity):
                        """
                        Redistribution of OSPF routes
                        
                        .. attribute:: internal
                        
                        	Redistribute OSPF internal routes
                        	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospfv3.Match.Internal>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: external
                        
                        	Redistribute OSPF external routes
                        	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospfv3.Match.External>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: nssa_external
                        
                        	Redistribute OSPF NSSA external routes
                        	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospfv3.Match.NssaExternal>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Redistribute.Ospfv3.Match, self).__init__()

                            self.yang_name = "match"
                            self.yang_parent_name = "ospfv3"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Isis.Redistribute.Ospfv3.Match.Internal)), ("external", ("external", Native.Router.Isis.Redistribute.Ospfv3.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Isis.Redistribute.Ospfv3.Match.NssaExternal))])
                            self._leafs = OrderedDict()

                            self.internal = None
                            self._children_name_map["internal"] = "internal"

                            self.external = None
                            self._children_name_map["external"] = "external"

                            self.nssa_external = None
                            self._children_name_map["nssa_external"] = "nssa-external"
                            self._segment_path = lambda: "match"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Redistribute.Ospfv3.Match, [], name, value)


                        class Internal(Entity):
                            """
                            Redistribute OSPF internal routes
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospfv3.Match.Internal.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Ospfv3.Match.Internal, self).__init__()

                                self.yang_name = "internal"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Ospfv3.Match.Internal.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "internal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Ospfv3.Match.Internal, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class External(Entity):
                            """
                            Redistribute OSPF external routes
                            
                            .. attribute:: external_routes
                            
                            	
                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospfv3.Match.External.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Ospfv3.Match.External, self).__init__()

                                self.yang_name = "external"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Ospfv3.Match.External.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.external_routes = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "external"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Ospfv3.Match.External, [u'external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class NssaExternal(Entity):
                            """
                            Redistribute OSPF NSSA external routes
                            
                            .. attribute:: nssa_external_routes
                            
                            	
                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Ospfv3.Match.NssaExternal.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Ospfv3.Match.NssaExternal, self).__init__()

                                self.yang_name = "nssa-external"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Ospfv3.Match.NssaExternal.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.nssa_external_routes = None
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "nssa-external"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Ospfv3.Match.NssaExternal, [u'nssa_external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class Rip(Entity):
                    """
                    Routing Information Protocol (RIP)
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                    
                    .. attribute:: metric
                    
                    	ISIS default metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Rip.MetricType>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Rip.MetricType')])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.levels = None
                        self.metric = None
                        self.metric_type = None
                        self.route_map = None
                        self._segment_path = lambda: "rip"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: external = 0

                        .. data:: internal = 1

                        .. data:: rib_metric_as_external = 2

                        .. data:: rib_metric_as_internal = 3

                        """

                        external = Enum.YLeaf(0, "external")

                        internal = Enum.YLeaf(1, "internal")

                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class Static(Entity):
                    """
                    Static routes
                    
                    .. attribute:: clns
                    
                    	Redistribution of BGP NSAP routes
                    	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Static.Clns>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ip
                    
                    	Redistribution of BGP IP routes
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Static.Ip>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Static, self).__init__()

                        self.yang_name = "static"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Isis.Redistribute.Static.Ip))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.clns = None
                        self._children_name_map["clns"] = "clns"

                        self.ip = None
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "static"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Static, [], name, value)


                    class Clns(Entity):
                        """
                        Redistribution of BGP NSAP routes
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Static.Clns.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Redistribute.Static.Clns, self).__init__()

                            self.yang_name = "clns"
                            self.yang_parent_name = "static"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Static.Clns.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self._segment_path = lambda: "clns"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/static/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Redistribute.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Ip(Entity):
                        """
                        Redistribution of BGP IP routes
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Static.Ip.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Redistribute.Static.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "static"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Static.Ip.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self._segment_path = lambda: "ip"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/static/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Redistribute.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class Vrf(Entity):
                    """
                    Specify a source VRF
                    
                    .. attribute:: vrf_nm
                    
                    	
                    	**type**\: list of  		 :py:class:`VrfNm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm>`
                    
                    .. attribute:: global_
                    
                    	global VRF
                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Redistribute.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf-nm", ("vrf_nm", Native.Router.Isis.Redistribute.Vrf.VrfNm)), ("global", ("global_", Native.Router.Isis.Redistribute.Vrf.Global))])
                        self._leafs = OrderedDict()

                        self.global_ = Native.Router.Isis.Redistribute.Vrf.Global()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"

                        self.vrf_nm = YList(self)
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Redistribute.Vrf, [], name, value)


                    class VrfNm(Entity):
                        """
                        
                        
                        .. attribute:: vrf_nm  (key)
                        
                        	Source VRF name
                        	**type**\: str
                        
                        .. attribute:: application
                        
                        	Application
                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Application>`
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Connected>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_>`
                        
                        .. attribute:: iso_igrp
                        
                        	IGRP for OSI networks
                        	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: lisp
                        
                        	Locator ID Separation Protocol (LISP)
                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Lisp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: mobile
                        
                        	Mobile routes
                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Mobile>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ospf
                        
                        	Process ID
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Rip>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Static>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Redistribute.Vrf.VrfNm, self).__init__()

                            self.yang_name = "vrf-nm"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['vrf_nm']
                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Isis.Redistribute.Vrf.VrfNm.Application)), ("bgp", ("bgp", Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp)), ("connected", ("connected", Native.Router.Isis.Redistribute.Vrf.VrfNm.Connected)), ("eigrp", ("eigrp", Native.Router.Isis.Redistribute.Vrf.VrfNm.Eigrp)), ("isis", ("isis", Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp)), ("lisp", ("lisp", Native.Router.Isis.Redistribute.Vrf.VrfNm.Lisp)), ("mobile", ("mobile", Native.Router.Isis.Redistribute.Vrf.VrfNm.Mobile)), ("ospfv3", ("ospfv3", Native.Router.Isis.Redistribute.Vrf.VrfNm.Ospfv3)), ("rip", ("rip", Native.Router.Isis.Redistribute.Vrf.VrfNm.Rip)), ("static", ("static", Native.Router.Isis.Redistribute.Vrf.VrfNm.Static))])
                            self._leafs = OrderedDict([
                                ('vrf_nm', (YLeaf(YType.str, 'vrf-nm'), ['str'])),
                                ('ospf', (YLeaf(YType.uint16, 'ospf'), ['int'])),
                            ])
                            self.vrf_nm = None
                            self.ospf = None

                            self.application = Native.Router.Isis.Redistribute.Vrf.VrfNm.Application()
                            self.application.parent = self
                            self._children_name_map["application"] = "application"

                            self.bgp = Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp()
                            self.bgp.parent = self
                            self._children_name_map["bgp"] = "bgp"

                            self.connected = None
                            self._children_name_map["connected"] = "connected"

                            self.eigrp = Native.Router.Isis.Redistribute.Vrf.VrfNm.Eigrp()
                            self.eigrp.parent = self
                            self._children_name_map["eigrp"] = "eigrp"

                            self.isis = Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_()
                            self.isis.parent = self
                            self._children_name_map["isis"] = "isis"

                            self.iso_igrp = None
                            self._children_name_map["iso_igrp"] = "iso-igrp"

                            self.lisp = None
                            self._children_name_map["lisp"] = "lisp"

                            self.mobile = None
                            self._children_name_map["mobile"] = "mobile"

                            self.ospfv3 = Native.Router.Isis.Redistribute.Vrf.VrfNm.Ospfv3()
                            self.ospfv3.parent = self
                            self._children_name_map["ospfv3"] = "ospfv3"

                            self.rip = None
                            self._children_name_map["rip"] = "rip"

                            self.static = None
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "vrf-nm" + "[vrf-nm='" + str(self.vrf_nm) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm, [u'vrf_nm', u'ospf'], name, value)


                        class Application(Entity):
                            """
                            Application
                            
                            .. attribute:: appname
                            
                            	
                            	**type**\: list of  		 :py:class:`Appname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Application.Appname>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Application, self).__init__()

                                self.yang_name = "application"
                                self.yang_parent_name = "vrf-nm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("appname", ("appname", Native.Router.Isis.Redistribute.Vrf.VrfNm.Application.Appname))])
                                self._leafs = OrderedDict()

                                self.appname = YList(self)
                                self._segment_path = lambda: "application"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Application, [], name, value)


                            class Appname(Entity):
                                """
                                
                                
                                .. attribute:: appname  (key)
                                
                                	Application name
                                	**type**\: str
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Application.Appname.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Application.Appname, self).__init__()

                                    self.yang_name = "appname"
                                    self.yang_parent_name = "application"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['appname']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('appname', (YLeaf(YType.str, 'appname'), ['str'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Application.Appname.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.appname = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "appname" + "[appname='" + str(self.appname) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Application.Appname, [u'appname', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: bp_as_num
                            
                            	
                            	**type**\: list of  		 :py:class:`BpAsNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum>`
                            
                            .. attribute:: a_lesser_1_period_0_xx_period_yy_greater_
                            
                            	Autonomous system number
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "vrf-nm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bp-as-num", ("bp_as_num", Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum))])
                                self._leafs = OrderedDict([
                                    ('a_lesser_1_period_0_xx_period_yy_greater_', (YLeaf(YType.empty, 'a_LESSER_1_PERIOD_0-XX_PERIOD_YY_GREATER_'), ['Empty'])),
                                ])
                                self.a_lesser_1_period_0_xx_period_yy_greater_ = None

                                self.bp_as_num = YList(self)
                                self._segment_path = lambda: "bgp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp, [u'a_lesser_1_period_0_xx_period_yy_greater_'], name, value)


                            class BpAsNum(Entity):
                                """
                                
                                
                                .. attribute:: bp_as_num  (key)
                                
                                	Autonomous system number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: clns
                                
                                	Redistribution of BGP NSAP routes
                                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ip
                                
                                	Redistribution of BGP IP routes
                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum, self).__init__()

                                    self.yang_name = "bp-as-num"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['bp_as_num']
                                    self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns)), ("ip", ("ip", Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip))])
                                    self._leafs = OrderedDict([
                                        ('bp_as_num', (YLeaf(YType.str, 'bp-as-num'), ['int','str'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.bp_as_num = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None

                                    self.clns = None
                                    self._children_name_map["clns"] = "clns"

                                    self.ip = None
                                    self._children_name_map["ip"] = "ip"
                                    self._segment_path = lambda: "bp-as-num" + "[bp-as-num='" + str(self.bp_as_num) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum, [u'bp_as_num', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Clns(Entity):
                                    """
                                    Redistribution of BGP NSAP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns, self).__init__()

                                        self.yang_name = "clns"
                                        self.yang_parent_name = "bp-as-num"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "clns"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Ip(Entity):
                                    """
                                    Redistribution of BGP IP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip, self).__init__()

                                        self.yang_name = "ip"
                                        self.yang_parent_name = "bp-as-num"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "ip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Connected.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "vrf-nm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Connected.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "connected"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: eigrp_as
                            
                            	
                            	**type**\: list of  		 :py:class:`EigrpAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "vrf-nm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("eigrp-as", ("eigrp_as", Native.Router.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs))])
                                self._leafs = OrderedDict()

                                self.eigrp_as = YList(self)
                                self._segment_path = lambda: "eigrp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Eigrp, [], name, value)


                            class EigrpAs(Entity):
                                """
                                
                                
                                .. attribute:: eigrp_as  (key)
                                
                                	AS number
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs, self).__init__()

                                    self.yang_name = "eigrp-as"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['eigrp_as']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eigrp_as', (YLeaf(YType.uint16, 'eigrp-as'), ['int'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.eigrp_as = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "eigrp-as" + "[eigrp-as='" + str(self.eigrp_as) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs, [u'eigrp_as', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Isis_(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: isis_atag
                            
                            	
                            	**type**\: list of  		 :py:class:`IsisAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag>`
                            
                            .. attribute:: ip
                            
                            	Redistribution of IP routes between levels or processes
                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "vrf-nm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("isis-atag", ("isis_atag", Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag)), ("ip", ("ip", Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip))])
                                self._leafs = OrderedDict()

                                self.ip = None
                                self._children_name_map["ip"] = "ip"

                                self.isis_atag = YList(self)
                                self._segment_path = lambda: "isis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_, [], name, value)


                            class IsisAtag(Entity):
                                """
                                
                                
                                .. attribute:: isis_atag  (key)
                                
                                	ISO routing area tag
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Redistribution of IP routes between levels or processes
                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag, self).__init__()

                                    self.yang_name = "isis-atag"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['isis_atag']
                                    self._child_classes = OrderedDict([("ip", ("ip", Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip))])
                                    self._leafs = OrderedDict([
                                        ('isis_atag', (YLeaf(YType.str, 'isis-atag'), ['str'])),
                                    ])
                                    self.isis_atag = None

                                    self.ip = Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip()
                                    self.ip.parent = self
                                    self._children_name_map["ip"] = "ip"
                                    self._segment_path = lambda: "isis-atag" + "[isis-atag='" + str(self.isis_atag) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag, [u'isis_atag'], name, value)


                                class Ip(Entity):
                                    """
                                    Redistribution of IP routes between levels or processes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip, self).__init__()

                                        self.yang_name = "ip"
                                        self.yang_parent_name = "isis-atag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "ip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Ip(Entity):
                                """
                                Redistribution of IP routes between levels or processes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip, self).__init__()

                                    self.yang_name = "ip"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "ip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class IsoIgrp(Entity):
                            """
                            IGRP for OSI networks
                            
                            .. attribute:: iso_atag
                            
                            	
                            	**type**\: list of  		 :py:class:`IsoAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp, self).__init__()

                                self.yang_name = "iso-igrp"
                                self.yang_parent_name = "vrf-nm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("iso-atag", ("iso_atag", Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag)), ("route-map", ("route_map", Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.route_map = None
                                self._children_name_map["route_map"] = "route-map"

                                self.iso_atag = YList(self)
                                self._segment_path = lambda: "iso-igrp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp, [], name, value)


                            class IsoAtag(Entity):
                                """
                                
                                
                                .. attribute:: iso_atag  (key)
                                
                                	ISO routing area tag
                                	**type**\: str
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag, self).__init__()

                                    self.yang_name = "iso-atag"
                                    self.yang_parent_name = "iso-igrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['iso_atag']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('iso_atag', (YLeaf(YType.str, 'iso-atag'), ['str'])),
                                        ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                    ])
                                    self.iso_atag = None
                                    self.route_map = None
                                    self._segment_path = lambda: "iso-atag" + "[iso-atag='" + str(self.iso_atag) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag, [u'iso_atag', u'route_map'], name, value)


                            class RouteMap(Entity):
                                """
                                Route map reference
                                
                                .. attribute:: rm_point
                                
                                	Pointer to route\-map entries
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap, self).__init__()

                                    self.yang_name = "route-map"
                                    self.yang_parent_name = "iso-igrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('rm_point', (YLeaf(YType.str, 'rm-point'), ['str'])),
                                    ])
                                    self.rm_point = None
                                    self._segment_path = lambda: "route-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap, [u'rm_point'], name, value)


                        class Lisp(Entity):
                            """
                            Locator ID Separation Protocol (LISP)
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Lisp.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Lisp, self).__init__()

                                self.yang_name = "lisp"
                                self.yang_parent_name = "vrf-nm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Lisp.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "lisp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Lisp, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Mobile(Entity):
                            """
                            Mobile routes
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Mobile.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Mobile, self).__init__()

                                self.yang_name = "mobile"
                                self.yang_parent_name = "vrf-nm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Mobile.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "mobile"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: os3_id
                            
                            	
                            	**type**\: list of  		 :py:class:`Os3Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "vrf-nm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("os3-id", ("os3_id", Native.Router.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id))])
                                self._leafs = OrderedDict()

                                self.os3_id = YList(self)
                                self._segment_path = lambda: "ospfv3"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Ospfv3, [], name, value)


                            class Os3Id(Entity):
                                """
                                
                                
                                .. attribute:: os3_id  (key)
                                
                                	Process ID
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id, self).__init__()

                                    self.yang_name = "os3-id"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['os3_id']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('os3_id', (YLeaf(YType.uint16, 'os3-id'), ['int'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.os3_id = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "os3-id" + "[os3-id='" + str(self.os3_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id, [u'os3_id', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Rip.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "vrf-nm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Rip.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "rip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: clns
                            
                            	Redistribution of BGP NSAP routes
                            	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Static.Clns>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ip
                            
                            	Redistribution of BGP IP routes
                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Static.Ip>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Static.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "vrf-nm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.Redistribute.Vrf.VrfNm.Static.Clns)), ("ip", ("ip", Native.Router.Isis.Redistribute.Vrf.VrfNm.Static.Ip))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Static.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None

                                self.clns = None
                                self._children_name_map["clns"] = "clns"

                                self.ip = None
                                self._children_name_map["ip"] = "ip"
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Static, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Clns(Entity):
                                """
                                Redistribution of BGP NSAP routes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Static.Clns.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Static.Clns, self).__init__()

                                    self.yang_name = "clns"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Static.Clns.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "clns"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Ip(Entity):
                                """
                                Redistribution of BGP IP routes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.VrfNm.Static.Ip.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.VrfNm.Static.Ip, self).__init__()

                                    self.yang_name = "ip"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.VrfNm.Static.Ip.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "ip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.VrfNm.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Global(Entity):
                        """
                        global VRF
                        
                        .. attribute:: application
                        
                        	Application
                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Application>`
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Connected>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Isis_>`
                        
                        .. attribute:: iso_igrp
                        
                        	IGRP for OSI networks
                        	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: lisp
                        
                        	Locator ID Separation Protocol (LISP)
                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Lisp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: mobile
                        
                        	Mobile routes
                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Mobile>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ospf
                        
                        	Process ID
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Rip>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Static>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Redistribute.Vrf.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Isis.Redistribute.Vrf.Global.Application)), ("bgp", ("bgp", Native.Router.Isis.Redistribute.Vrf.Global.Bgp)), ("connected", ("connected", Native.Router.Isis.Redistribute.Vrf.Global.Connected)), ("eigrp", ("eigrp", Native.Router.Isis.Redistribute.Vrf.Global.Eigrp)), ("isis", ("isis", Native.Router.Isis.Redistribute.Vrf.Global.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp)), ("lisp", ("lisp", Native.Router.Isis.Redistribute.Vrf.Global.Lisp)), ("mobile", ("mobile", Native.Router.Isis.Redistribute.Vrf.Global.Mobile)), ("ospfv3", ("ospfv3", Native.Router.Isis.Redistribute.Vrf.Global.Ospfv3)), ("rip", ("rip", Native.Router.Isis.Redistribute.Vrf.Global.Rip)), ("static", ("static", Native.Router.Isis.Redistribute.Vrf.Global.Static))])
                            self._leafs = OrderedDict([
                                ('ospf', (YLeaf(YType.uint16, 'ospf'), ['int'])),
                            ])
                            self.ospf = None

                            self.application = Native.Router.Isis.Redistribute.Vrf.Global.Application()
                            self.application.parent = self
                            self._children_name_map["application"] = "application"

                            self.bgp = Native.Router.Isis.Redistribute.Vrf.Global.Bgp()
                            self.bgp.parent = self
                            self._children_name_map["bgp"] = "bgp"

                            self.connected = None
                            self._children_name_map["connected"] = "connected"

                            self.eigrp = Native.Router.Isis.Redistribute.Vrf.Global.Eigrp()
                            self.eigrp.parent = self
                            self._children_name_map["eigrp"] = "eigrp"

                            self.isis = Native.Router.Isis.Redistribute.Vrf.Global.Isis_()
                            self.isis.parent = self
                            self._children_name_map["isis"] = "isis"

                            self.iso_igrp = None
                            self._children_name_map["iso_igrp"] = "iso-igrp"

                            self.lisp = None
                            self._children_name_map["lisp"] = "lisp"

                            self.mobile = None
                            self._children_name_map["mobile"] = "mobile"

                            self.ospfv3 = Native.Router.Isis.Redistribute.Vrf.Global.Ospfv3()
                            self.ospfv3.parent = self
                            self._children_name_map["ospfv3"] = "ospfv3"

                            self.rip = None
                            self._children_name_map["rip"] = "rip"

                            self.static = None
                            self._children_name_map["static"] = "static"
                            self._segment_path = lambda: "global"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global, [u'ospf'], name, value)


                        class Application(Entity):
                            """
                            Application
                            
                            .. attribute:: appname
                            
                            	
                            	**type**\: list of  		 :py:class:`Appname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Application.Appname>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.Global.Application, self).__init__()

                                self.yang_name = "application"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("appname", ("appname", Native.Router.Isis.Redistribute.Vrf.Global.Application.Appname))])
                                self._leafs = OrderedDict()

                                self.appname = YList(self)
                                self._segment_path = lambda: "application"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Application, [], name, value)


                            class Appname(Entity):
                                """
                                
                                
                                .. attribute:: appname  (key)
                                
                                	Application name
                                	**type**\: str
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Application.Appname.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.Global.Application.Appname, self).__init__()

                                    self.yang_name = "appname"
                                    self.yang_parent_name = "application"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['appname']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('appname', (YLeaf(YType.str, 'appname'), ['str'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Application.Appname.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.appname = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "appname" + "[appname='" + str(self.appname) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/application/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Application.Appname, [u'appname', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: bp_as_num
                            
                            	
                            	**type**\: list of  		 :py:class:`BpAsNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum>`
                            
                            .. attribute:: a_lesser_1_period_0_xx_period_yy_greater_
                            
                            	Autonomous system number
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.Global.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bp-as-num", ("bp_as_num", Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum))])
                                self._leafs = OrderedDict([
                                    ('a_lesser_1_period_0_xx_period_yy_greater_', (YLeaf(YType.empty, 'a_LESSER_1_PERIOD_0-XX_PERIOD_YY_GREATER_'), ['Empty'])),
                                ])
                                self.a_lesser_1_period_0_xx_period_yy_greater_ = None

                                self.bp_as_num = YList(self)
                                self._segment_path = lambda: "bgp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Bgp, [u'a_lesser_1_period_0_xx_period_yy_greater_'], name, value)


                            class BpAsNum(Entity):
                                """
                                
                                
                                .. attribute:: bp_as_num  (key)
                                
                                	Autonomous system number
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: clns
                                
                                	Redistribution of BGP NSAP routes
                                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ip
                                
                                	Redistribution of BGP IP routes
                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum, self).__init__()

                                    self.yang_name = "bp-as-num"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['bp_as_num']
                                    self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns)), ("ip", ("ip", Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip))])
                                    self._leafs = OrderedDict([
                                        ('bp_as_num', (YLeaf(YType.str, 'bp-as-num'), ['int','str'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.bp_as_num = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None

                                    self.clns = None
                                    self._children_name_map["clns"] = "clns"

                                    self.ip = None
                                    self._children_name_map["ip"] = "ip"
                                    self._segment_path = lambda: "bp-as-num" + "[bp-as-num='" + str(self.bp_as_num) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/bgp/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum, [u'bp_as_num', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Clns(Entity):
                                    """
                                    Redistribution of BGP NSAP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns, self).__init__()

                                        self.yang_name = "clns"
                                        self.yang_parent_name = "bp-as-num"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "clns"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Ip(Entity):
                                    """
                                    Redistribution of BGP IP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip, self).__init__()

                                        self.yang_name = "ip"
                                        self.yang_parent_name = "bp-as-num"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "ip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Connected.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.Global.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Connected.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "connected"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: eigrp_as
                            
                            	
                            	**type**\: list of  		 :py:class:`EigrpAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.Global.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("eigrp-as", ("eigrp_as", Native.Router.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs))])
                                self._leafs = OrderedDict()

                                self.eigrp_as = YList(self)
                                self._segment_path = lambda: "eigrp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Eigrp, [], name, value)


                            class EigrpAs(Entity):
                                """
                                
                                
                                .. attribute:: eigrp_as  (key)
                                
                                	AS number
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs, self).__init__()

                                    self.yang_name = "eigrp-as"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['eigrp_as']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eigrp_as', (YLeaf(YType.uint16, 'eigrp-as'), ['int'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.eigrp_as = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "eigrp-as" + "[eigrp-as='" + str(self.eigrp_as) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/eigrp/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs, [u'eigrp_as', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Isis_(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: isis_atag
                            
                            	
                            	**type**\: list of  		 :py:class:`IsisAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag>`
                            
                            .. attribute:: ip
                            
                            	Redistribution of IP routes between levels or processes
                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Isis_.Ip>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.Global.Isis_, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("isis-atag", ("isis_atag", Native.Router.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag)), ("ip", ("ip", Native.Router.Isis.Redistribute.Vrf.Global.Isis_.Ip))])
                                self._leafs = OrderedDict()

                                self.ip = None
                                self._children_name_map["ip"] = "ip"

                                self.isis_atag = YList(self)
                                self._segment_path = lambda: "isis"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Isis_, [], name, value)


                            class IsisAtag(Entity):
                                """
                                
                                
                                .. attribute:: isis_atag  (key)
                                
                                	ISO routing area tag
                                	**type**\: str
                                
                                .. attribute:: ip
                                
                                	Redistribution of IP routes between levels or processes
                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag, self).__init__()

                                    self.yang_name = "isis-atag"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['isis_atag']
                                    self._child_classes = OrderedDict([("ip", ("ip", Native.Router.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip))])
                                    self._leafs = OrderedDict([
                                        ('isis_atag', (YLeaf(YType.str, 'isis-atag'), ['str'])),
                                    ])
                                    self.isis_atag = None

                                    self.ip = Native.Router.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip()
                                    self.ip.parent = self
                                    self._children_name_map["ip"] = "ip"
                                    self._segment_path = lambda: "isis-atag" + "[isis-atag='" + str(self.isis_atag) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/isis/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag, [u'isis_atag'], name, value)


                                class Ip(Entity):
                                    """
                                    Redistribution of IP routes between levels or processes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip, self).__init__()

                                        self.yang_name = "ip"
                                        self.yang_parent_name = "isis-atag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "ip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Ip(Entity):
                                """
                                Redistribution of IP routes between levels or processes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Isis_.Ip.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.Global.Isis_.Ip, self).__init__()

                                    self.yang_name = "ip"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Isis_.Ip.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "ip"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/isis/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Isis_.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class IsoIgrp(Entity):
                            """
                            IGRP for OSI networks
                            
                            .. attribute:: iso_atag
                            
                            	
                            	**type**\: list of  		 :py:class:`IsoAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp.IsoAtag>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp.RouteMap>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp, self).__init__()

                                self.yang_name = "iso-igrp"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("iso-atag", ("iso_atag", Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp.IsoAtag)), ("route-map", ("route_map", Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp.RouteMap))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.route_map = None
                                self._children_name_map["route_map"] = "route-map"

                                self.iso_atag = YList(self)
                                self._segment_path = lambda: "iso-igrp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp, [], name, value)


                            class IsoAtag(Entity):
                                """
                                
                                
                                .. attribute:: iso_atag  (key)
                                
                                	ISO routing area tag
                                	**type**\: str
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp.IsoAtag, self).__init__()

                                    self.yang_name = "iso-atag"
                                    self.yang_parent_name = "iso-igrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['iso_atag']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('iso_atag', (YLeaf(YType.str, 'iso-atag'), ['str'])),
                                        ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                    ])
                                    self.iso_atag = None
                                    self.route_map = None
                                    self._segment_path = lambda: "iso-atag" + "[iso-atag='" + str(self.iso_atag) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/iso-igrp/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp.IsoAtag, [u'iso_atag', u'route_map'], name, value)


                            class RouteMap(Entity):
                                """
                                Route map reference
                                
                                .. attribute:: rm_point
                                
                                	Pointer to route\-map entries
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp.RouteMap, self).__init__()

                                    self.yang_name = "route-map"
                                    self.yang_parent_name = "iso-igrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('rm_point', (YLeaf(YType.str, 'rm-point'), ['str'])),
                                    ])
                                    self.rm_point = None
                                    self._segment_path = lambda: "route-map"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/iso-igrp/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.IsoIgrp.RouteMap, [u'rm_point'], name, value)


                        class Lisp(Entity):
                            """
                            Locator ID Separation Protocol (LISP)
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Lisp.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.Global.Lisp, self).__init__()

                                self.yang_name = "lisp"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Lisp.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "lisp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Lisp, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Mobile(Entity):
                            """
                            Mobile routes
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Mobile.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.Global.Mobile, self).__init__()

                                self.yang_name = "mobile"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Mobile.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "mobile"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: os3_id
                            
                            	
                            	**type**\: list of  		 :py:class:`Os3Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.Global.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("os3-id", ("os3_id", Native.Router.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id))])
                                self._leafs = OrderedDict()

                                self.os3_id = YList(self)
                                self._segment_path = lambda: "ospfv3"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Ospfv3, [], name, value)


                            class Os3Id(Entity):
                                """
                                
                                
                                .. attribute:: os3_id  (key)
                                
                                	Process ID
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id, self).__init__()

                                    self.yang_name = "os3-id"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['os3_id']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('os3_id', (YLeaf(YType.uint16, 'os3-id'), ['int'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.os3_id = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "os3-id" + "[os3-id='" + str(self.os3_id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/ospfv3/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id, [u'os3_id', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Rip.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.Global.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Rip.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "rip"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: clns
                            
                            	Redistribution of BGP NSAP routes
                            	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Static.Clns>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ip
                            
                            	Redistribution of BGP IP routes
                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Static.Ip>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Static.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Redistribute.Vrf.Global.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Isis.Redistribute.Vrf.Global.Static.Clns)), ("ip", ("ip", Native.Router.Isis.Redistribute.Vrf.Global.Static.Ip))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Static.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None

                                self.clns = None
                                self._children_name_map["clns"] = "clns"

                                self.ip = None
                                self._children_name_map["ip"] = "ip"
                                self._segment_path = lambda: "static"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Static, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Clns(Entity):
                                """
                                Redistribution of BGP NSAP routes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Static.Clns.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.Global.Static.Clns, self).__init__()

                                    self.yang_name = "clns"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Static.Clns.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "clns"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/static/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Ip(Entity):
                                """
                                Redistribution of BGP IP routes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Redistribute.Vrf.Global.Static.Ip.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Redistribute.Vrf.Global.Static.Ip, self).__init__()

                                    self.yang_name = "ip"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Redistribute.Vrf.Global.Static.Ip.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "ip"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/redistribute/vrf/global/static/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Redistribute.Vrf.Global.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



            class SetAttachedBit(Entity):
                """
                Conditionally advertise us as attached to L2
                
                .. attribute:: route_map
                
                	Route\-map reference
                	**type**\: str
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.SetAttachedBit, self).__init__()

                    self.yang_name = "set-attached-bit"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                    ])
                    self.route_map = None
                    self._segment_path = lambda: "set-attached-bit"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.SetAttachedBit, [u'route_map'], name, value)


            class Snmp(Entity):
                """
                Modify snmp parameters
                
                .. attribute:: context
                
                	Configure a SNMP context
                	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Snmp.Context>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Isis.Snmp.Context))])
                    self._leafs = OrderedDict()

                    self.context = YList(self)
                    self._segment_path = lambda: "snmp"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Snmp, [], name, value)


                class Context(Entity):
                    """
                    Configure a SNMP context
                    
                    .. attribute:: name  (key)
                    
                    	Context Name
                    	**type**\: str
                    
                    .. attribute:: community
                    
                    	Configure a SNMP v2c Community string and access privs
                    	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Snmp.Context.Community>`
                    
                    .. attribute:: user
                    
                    	Configure a SNMP v3 user
                    	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Snmp.Context.User>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Snmp.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("community", ("community", Native.Router.Isis.Snmp.Context.Community)), ("user", ("user", Native.Router.Isis.Snmp.Context.User))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.community = Native.Router.Isis.Snmp.Context.Community()
                        self.community.parent = self
                        self._children_name_map["community"] = "community"

                        self.user = Native.Router.Isis.Snmp.Context.User()
                        self.user.parent = self
                        self._children_name_map["user"] = "user"
                        self._segment_path = lambda: "context" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/snmp/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Snmp.Context, [u'name'], name, value)


                    class Community(Entity):
                        """
                        Configure a SNMP v2c Community string and access privs
                        
                        .. attribute:: community_string
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: access
                        
                        	
                        	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Snmp.Context.Community.Access>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Snmp.Context.Community, self).__init__()

                            self.yang_name = "community"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("access", ("access", Native.Router.Isis.Snmp.Context.Community.Access))])
                            self._leafs = OrderedDict([
                                ('community_string', (YLeaf(YType.str, 'community-string'), ['str'])),
                            ])
                            self.community_string = None

                            self.access = Native.Router.Isis.Snmp.Context.Community.Access()
                            self.access.parent = self
                            self._children_name_map["access"] = "access"
                            self._segment_path = lambda: "community"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Snmp.Context.Community, [u'community_string'], name, value)


                        class Access(Entity):
                            """
                            
                            
                            .. attribute:: standard_acl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..99
                            
                            .. attribute:: expanded_acl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1300..1999
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ipv6
                            
                            	Specify IPv6 Named Access\-List
                            	**type**\: str
                            
                            .. attribute:: ro
                            
                            	Read\-only access with this community string
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rw
                            
                            	Read\-write access with this community string
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Snmp.Context.Community.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "community"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                    ('expanded_acl', (YLeaf(YType.uint32, 'expanded-acl'), ['int'])),
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ('ro', (YLeaf(YType.empty, 'ro'), ['Empty'])),
                                    ('rw', (YLeaf(YType.empty, 'rw'), ['Empty'])),
                                ])
                                self.standard_acl = None
                                self.expanded_acl = None
                                self.acl_name = None
                                self.ipv6 = None
                                self.ro = None
                                self.rw = None
                                self._segment_path = lambda: "access"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Snmp.Context.Community.Access, [u'standard_acl', u'expanded_acl', u'acl_name', u'ipv6', u'ro', u'rw'], name, value)


                    class User(Entity):
                        """
                        Configure a SNMP v3 user
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: permisssion
                        
                        	
                        	**type**\:  :py:class:`Permisssion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Snmp.Context.User.Permisssion>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Snmp.Context.User, self).__init__()

                            self.yang_name = "user"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("permisssion", ("permisssion", Native.Router.Isis.Snmp.Context.User.Permisssion))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.permisssion = Native.Router.Isis.Snmp.Context.User.Permisssion()
                            self.permisssion.parent = self
                            self._children_name_map["permisssion"] = "permisssion"
                            self._segment_path = lambda: "user"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Snmp.Context.User, [u'name'], name, value)


                        class Permisssion(Entity):
                            """
                            
                            
                            .. attribute:: access
                            
                            	specify an access\-list associated with this group
                            	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Snmp.Context.User.Permisssion.Access>`
                            
                            .. attribute:: auth
                            
                            	authentication parameters for the user
                            	**type**\:  :py:class:`Auth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Snmp.Context.User.Permisssion.Auth>`
                            
                            .. attribute:: credential
                            
                            	If the user password is already configured and saved
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: encrypted
                            
                            	specifying passwords as MD5 or SHA digests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Snmp.Context.User.Permisssion, self).__init__()

                                self.yang_name = "permisssion"
                                self.yang_parent_name = "user"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("access", ("access", Native.Router.Isis.Snmp.Context.User.Permisssion.Access)), ("auth", ("auth", Native.Router.Isis.Snmp.Context.User.Permisssion.Auth))])
                                self._leafs = OrderedDict([
                                    ('credential', (YLeaf(YType.empty, 'credential'), ['Empty'])),
                                    ('encrypted', (YLeaf(YType.empty, 'encrypted'), ['Empty'])),
                                ])
                                self.credential = None
                                self.encrypted = None

                                self.access = Native.Router.Isis.Snmp.Context.User.Permisssion.Access()
                                self.access.parent = self
                                self._children_name_map["access"] = "access"

                                self.auth = Native.Router.Isis.Snmp.Context.User.Permisssion.Auth()
                                self.auth.parent = self
                                self._children_name_map["auth"] = "auth"
                                self._segment_path = lambda: "permisssion"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Snmp.Context.User.Permisssion, [u'credential', u'encrypted'], name, value)


                            class Access(Entity):
                                """
                                specify an access\-list associated with this group
                                
                                .. attribute:: standard_acl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: ipv6
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Snmp.Context.User.Permisssion.Access, self).__init__()

                                    self.yang_name = "access"
                                    self.yang_parent_name = "permisssion"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.standard_acl = None
                                    self.acl_name = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "access"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Snmp.Context.User.Permisssion.Access, [u'standard_acl', u'acl_name', u'ipv6'], name, value)


                            class Auth(Entity):
                                """
                                authentication parameters for the user
                                
                                .. attribute:: md5
                                
                                	Use HMAC MD5 algorithm for authentication
                                	**type**\: str
                                
                                .. attribute:: sha
                                
                                	Use HMAC SHA algorithm for authentication
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.Snmp.Context.User.Permisssion.Auth, self).__init__()

                                    self.yang_name = "auth"
                                    self.yang_parent_name = "permisssion"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('md5', (YLeaf(YType.str, 'md5'), ['str'])),
                                        ('sha', (YLeaf(YType.str, 'sha'), ['str'])),
                                    ])
                                    self.md5 = None
                                    self.sha = None
                                    self._segment_path = lambda: "auth"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.Snmp.Context.User.Permisssion.Auth, [u'md5', u'sha'], name, value)


            class SummaryAddress(Entity):
                """
                Configure IP address summaries
                
                .. attribute:: ip  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mask  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: level_1
                
                	Summarize into level\-1 area
                	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SummaryAddress.Level1>`
                
                	**presence node**\: True
                
                .. attribute:: level_1_2
                
                	Summarize into both area and sub\-domain
                	**type**\:  :py:class:`Level12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SummaryAddress.Level12>`
                
                	**presence node**\: True
                
                .. attribute:: level_2
                
                	Summarize into level\-2 sub\-domain
                	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SummaryAddress.Level2>`
                
                	**presence node**\: True
                
                .. attribute:: metric_tag_container
                
                	
                	**type**\:  :py:class:`MetricTagContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SummaryAddress.MetricTagContainer>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.SummaryAddress, self).__init__()

                    self.yang_name = "summary-address"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['ip','mask']
                    self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.Isis.SummaryAddress.Level1)), ("level-1-2", ("level_1_2", Native.Router.Isis.SummaryAddress.Level12)), ("level-2", ("level_2", Native.Router.Isis.SummaryAddress.Level2)), ("metric-tag-container", ("metric_tag_container", Native.Router.Isis.SummaryAddress.MetricTagContainer))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                        ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                    ])
                    self.ip = None
                    self.mask = None

                    self.level_1 = None
                    self._children_name_map["level_1"] = "level-1"

                    self.level_1_2 = None
                    self._children_name_map["level_1_2"] = "level-1-2"

                    self.level_2 = None
                    self._children_name_map["level_2"] = "level-2"

                    self.metric_tag_container = Native.Router.Isis.SummaryAddress.MetricTagContainer()
                    self.metric_tag_container.parent = self
                    self._children_name_map["metric_tag_container"] = "metric-tag-container"
                    self._segment_path = lambda: "summary-address" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.SummaryAddress, [u'ip', u'mask'], name, value)


                class Level1(Entity):
                    """
                    Summarize into level\-1 area
                    
                    .. attribute:: metric
                    
                    	Set metric for summay route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: tag
                    
                    	Set tag
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.SummaryAddress.Level1, self).__init__()

                        self.yang_name = "level-1"
                        self.yang_parent_name = "summary-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.metric = None
                        self.tag = None
                        self._segment_path = lambda: "level-1"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.SummaryAddress.Level1, [u'metric', u'tag'], name, value)


                class Level12(Entity):
                    """
                    Summarize into both area and sub\-domain
                    
                    .. attribute:: metric
                    
                    	Set metric for summay route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: tag
                    
                    	Set tag
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.SummaryAddress.Level12, self).__init__()

                        self.yang_name = "level-1-2"
                        self.yang_parent_name = "summary-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.metric = None
                        self.tag = None
                        self._segment_path = lambda: "level-1-2"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.SummaryAddress.Level12, [u'metric', u'tag'], name, value)


                class Level2(Entity):
                    """
                    Summarize into level\-2 sub\-domain
                    
                    .. attribute:: metric
                    
                    	Set metric for summay route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: tag
                    
                    	Set tag
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.SummaryAddress.Level2, self).__init__()

                        self.yang_name = "level-2"
                        self.yang_parent_name = "summary-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.metric = None
                        self.tag = None
                        self._segment_path = lambda: "level-2"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.SummaryAddress.Level2, [u'metric', u'tag'], name, value)


                class MetricTagContainer(Entity):
                    """
                    
                    
                    .. attribute:: metric
                    
                    	Set metric for summay route
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: tag
                    
                    	Set tag
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.SummaryAddress.MetricTagContainer, self).__init__()

                        self.yang_name = "metric-tag-container"
                        self.yang_parent_name = "summary-address"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.metric = None
                        self.tag = None
                        self._segment_path = lambda: "metric-tag-container"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.SummaryAddress.MetricTagContainer, [u'metric', u'tag'], name, value)


            class TrafficShare(Entity):
                """
                How to compute traffic share over alternate paths
                
                .. attribute:: min
                
                	All traffic shared among min metric paths
                	**type**\:  :py:class:`Min <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.TrafficShare.Min>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.TrafficShare, self).__init__()

                    self.yang_name = "traffic-share"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("min", ("min", Native.Router.Isis.TrafficShare.Min))])
                    self._leafs = OrderedDict()

                    self.min = Native.Router.Isis.TrafficShare.Min()
                    self.min.parent = self
                    self._children_name_map["min"] = "min"
                    self._segment_path = lambda: "traffic-share"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.TrafficShare, [], name, value)


                class Min(Entity):
                    """
                    All traffic shared among min metric paths
                    
                    .. attribute:: across_interfaces
                    
                    	Use different interfaces for equal\-cost paths
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.TrafficShare.Min, self).__init__()

                        self.yang_name = "min"
                        self.yang_parent_name = "traffic-share"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                        ])
                        self.across_interfaces = None
                        self._segment_path = lambda: "min"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/traffic-share/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.TrafficShare.Min, [u'across_interfaces'], name, value)


            class Advertise(Entity):
                """
                Control which IP routes flow in L1 and L2 LSPs
                
                .. attribute:: passive_only
                
                	only interface address of passive interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Advertise, self).__init__()

                    self.yang_name = "advertise"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('passive_only', (YLeaf(YType.empty, 'passive-only'), ['Empty'])),
                    ])
                    self.passive_only = None
                    self._segment_path = lambda: "advertise"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Advertise, [u'passive_only'], name, value)


            class DefaultInformation(Entity):
                """
                Control distribution of default information
                
                .. attribute:: originate
                
                	Distribute a default route
                	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.DefaultInformation.Originate>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.DefaultInformation, self).__init__()

                    self.yang_name = "default-information"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("originate", ("originate", Native.Router.Isis.DefaultInformation.Originate))])
                    self._leafs = OrderedDict()

                    self.originate = None
                    self._children_name_map["originate"] = "originate"
                    self._segment_path = lambda: "default-information"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.DefaultInformation, [], name, value)


                class Originate(Entity):
                    """
                    Distribute a default route
                    
                    .. attribute:: route_map
                    
                    	Route\-map reference
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.DefaultInformation.Originate, self).__init__()

                        self.yang_name = "originate"
                        self.yang_parent_name = "default-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "originate"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/default-information/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.DefaultInformation.Originate, [u'route_map'], name, value)


            class Metric(Entity):
                """
                Set ISIS metric for all interfaces
                
                .. attribute:: metrics
                
                	
                	**type**\: list of  		 :py:class:`Metrics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Metric.Metrics>`
                
                .. attribute:: metric
                
                	
                	**type**\: int
                
                	**range:** 1..16777214
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Metric, self).__init__()

                    self.yang_name = "metric"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("metrics", ("metrics", Native.Router.Isis.Metric.Metrics))])
                    self._leafs = OrderedDict([
                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                    ])
                    self.metric = None

                    self.metrics = YList(self)
                    self._segment_path = lambda: "metric"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Metric, [u'metric'], name, value)


                class Metrics(Entity):
                    """
                    
                    
                    .. attribute:: level  (key)
                    
                    	
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Metric.Metrics.Level>`
                    
                    .. attribute:: metric
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..16777214
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Metric.Metrics, self).__init__()

                        self.yang_name = "metrics"
                        self.yang_parent_name = "metric"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['level']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Metric.Metrics.Level')])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                        ])
                        self.level = None
                        self.metric = None
                        self._segment_path = lambda: "metrics" + "[level='" + str(self.level) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/metric/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Metric.Metrics, [u'level', u'metric'], name, value)

                    class Level(Enum):
                        """
                        Level (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_2 = 1

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_2 = Enum.YLeaf(1, "level-2")



            class PrcInterval(Entity):
                """
                Minimum interval between partial route calculations
                
                .. attribute:: interval
                
                	
                	**type**\: int
                
                	**range:** 1..120
                
                .. attribute:: initial_wait
                
                	
                	**type**\: int
                
                	**range:** 1..120000
                
                .. attribute:: minimum_wait
                
                	
                	**type**\: int
                
                	**range:** 1..120000
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.PrcInterval, self).__init__()

                    self.yang_name = "prc-interval"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                        ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                        ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                    ])
                    self.interval = None
                    self.initial_wait = None
                    self.minimum_wait = None
                    self._segment_path = lambda: "prc-interval"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.PrcInterval, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


            class SetOverloadBit(Entity):
                """
                Signal other routers not to use us in SPF
                
                .. attribute:: on_startup
                
                	Set overload\-bit only temporarily after reboot
                	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SetOverloadBit.OnStartup>`
                
                .. attribute:: suppress
                
                	If overload\-bit set, suppress the following types of IP prefixes
                	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SetOverloadBit.Suppress>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.SetOverloadBit, self).__init__()

                    self.yang_name = "set-overload-bit"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("on-startup", ("on_startup", Native.Router.Isis.SetOverloadBit.OnStartup)), ("suppress", ("suppress", Native.Router.Isis.SetOverloadBit.Suppress))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.on_startup = Native.Router.Isis.SetOverloadBit.OnStartup()
                    self.on_startup.parent = self
                    self._children_name_map["on_startup"] = "on-startup"

                    self.suppress = Native.Router.Isis.SetOverloadBit.Suppress()
                    self.suppress.parent = self
                    self._children_name_map["suppress"] = "suppress"
                    self._segment_path = lambda: "set-overload-bit"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.SetOverloadBit, [], name, value)


                class OnStartup(Entity):
                    """
                    Set overload\-bit only temporarily after reboot
                    
                    .. attribute:: time
                    
                    	
                    	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SetOverloadBit.OnStartup.Time>`
                    
                    .. attribute:: wait_for_bgp
                    
                    	Let BGP decide when to unset the overload bit
                    	**type**\:  :py:class:`WaitForBgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SetOverloadBit.OnStartup.WaitForBgp>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.SetOverloadBit.OnStartup, self).__init__()

                        self.yang_name = "on-startup"
                        self.yang_parent_name = "set-overload-bit"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("time", ("time", Native.Router.Isis.SetOverloadBit.OnStartup.Time)), ("wait-for-bgp", ("wait_for_bgp", Native.Router.Isis.SetOverloadBit.OnStartup.WaitForBgp))])
                        self._leafs = OrderedDict()

                        self.time = Native.Router.Isis.SetOverloadBit.OnStartup.Time()
                        self.time.parent = self
                        self._children_name_map["time"] = "time"

                        self.wait_for_bgp = None
                        self._children_name_map["wait_for_bgp"] = "wait-for-bgp"
                        self._segment_path = lambda: "on-startup"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/set-overload-bit/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.SetOverloadBit.OnStartup, [], name, value)


                    class Time(Entity):
                        """
                        
                        
                        .. attribute:: time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 5..86400
                        
                        .. attribute:: suppress
                        
                        	If overload\-bit set, suppress the following types of IP prefixes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: external
                        
                        	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: interlevel
                        
                        	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.SetOverloadBit.OnStartup.Time, self).__init__()

                            self.yang_name = "time"
                            self.yang_parent_name = "on-startup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                ('suppress', (YLeaf(YType.empty, 'suppress'), ['Empty'])),
                                ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                            ])
                            self.time = None
                            self.suppress = None
                            self.external = None
                            self.interlevel = None
                            self._segment_path = lambda: "time"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/set-overload-bit/on-startup/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.SetOverloadBit.OnStartup.Time, [u'time', u'suppress', u'external', u'interlevel'], name, value)


                    class WaitForBgp(Entity):
                        """
                        Let BGP decide when to unset the overload bit
                        
                        .. attribute:: suppress
                        
                        	If overload\-bit set, suppress the following types of IP prefixes
                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SetOverloadBit.OnStartup.WaitForBgp.Suppress>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.SetOverloadBit.OnStartup.WaitForBgp, self).__init__()

                            self.yang_name = "wait-for-bgp"
                            self.yang_parent_name = "on-startup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Router.Isis.SetOverloadBit.OnStartup.WaitForBgp.Suppress))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.suppress = Native.Router.Isis.SetOverloadBit.OnStartup.WaitForBgp.Suppress()
                            self.suppress.parent = self
                            self._children_name_map["suppress"] = "suppress"
                            self._segment_path = lambda: "wait-for-bgp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/set-overload-bit/on-startup/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.SetOverloadBit.OnStartup.WaitForBgp, [], name, value)


                        class Suppress(Entity):
                            """
                            If overload\-bit set, suppress the following types of IP prefixes
                            
                            .. attribute:: external
                            
                            	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: interlevel
                            
                            	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.SetOverloadBit.OnStartup.WaitForBgp.Suppress, self).__init__()

                                self.yang_name = "suppress"
                                self.yang_parent_name = "wait-for-bgp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                    ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                ])
                                self.external = None
                                self.interlevel = None
                                self._segment_path = lambda: "suppress"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/set-overload-bit/on-startup/wait-for-bgp/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.SetOverloadBit.OnStartup.WaitForBgp.Suppress, [u'external', u'interlevel'], name, value)


                class Suppress(Entity):
                    """
                    If overload\-bit set, suppress the following types of IP prefixes
                    
                    .. attribute:: external
                    
                    	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: interlevel
                    
                    	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.SetOverloadBit.Suppress, self).__init__()

                        self.yang_name = "suppress"
                        self.yang_parent_name = "set-overload-bit"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                            ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                        ])
                        self.external = None
                        self.interlevel = None
                        self._segment_path = lambda: "suppress"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/set-overload-bit/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.SetOverloadBit.Suppress, [u'external', u'interlevel'], name, value)


            class SpfInterval(Entity):
                """
                Minimum interval between SPF calculations
                
                .. attribute:: level_1_2
                
                	
                	**type**\: list of  		 :py:class:`Level12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SpfInterval.Level12>`
                
                .. attribute:: intervals
                
                	
                	**type**\:  :py:class:`Intervals <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SpfInterval.Intervals>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.SpfInterval, self).__init__()

                    self.yang_name = "spf-interval"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level-1-2", ("level_1_2", Native.Router.Isis.SpfInterval.Level12)), ("intervals", ("intervals", Native.Router.Isis.SpfInterval.Intervals))])
                    self._leafs = OrderedDict()

                    self.intervals = Native.Router.Isis.SpfInterval.Intervals()
                    self.intervals.parent = self
                    self._children_name_map["intervals"] = "intervals"

                    self.level_1_2 = YList(self)
                    self._segment_path = lambda: "spf-interval"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.SpfInterval, [], name, value)


                class Level12(Entity):
                    """
                    
                    
                    .. attribute:: level  (key)
                    
                    	
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SpfInterval.Level12.Level>`
                    
                    .. attribute:: interval
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    .. attribute:: initial_wait
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    .. attribute:: minimum_wait
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.SpfInterval.Level12, self).__init__()

                        self.yang_name = "level-1-2"
                        self.yang_parent_name = "spf-interval"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['level']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.SpfInterval.Level12.Level')])),
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                            ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                            ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                        ])
                        self.level = None
                        self.interval = None
                        self.initial_wait = None
                        self.minimum_wait = None
                        self._segment_path = lambda: "level-1-2" + "[level='" + str(self.level) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/spf-interval/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.SpfInterval.Level12, [u'level', u'interval', u'initial_wait', u'minimum_wait'], name, value)

                    class Level(Enum):
                        """
                        Level (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_2 = 1

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_2 = Enum.YLeaf(1, "level-2")



                class Intervals(Entity):
                    """
                    
                    
                    .. attribute:: interval
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    .. attribute:: initial_wait
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    .. attribute:: minimum_wait
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.SpfInterval.Intervals, self).__init__()

                        self.yang_name = "intervals"
                        self.yang_parent_name = "spf-interval"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                            ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                            ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                        ])
                        self.interval = None
                        self.initial_wait = None
                        self.minimum_wait = None
                        self._segment_path = lambda: "intervals"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/spf-interval/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.SpfInterval.Intervals, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


            class AreaPassword(Entity):
                """
                Configure the authentication password for an area
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: authenticate
                
                	Authentication
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: snp
                
                	SNP PDUs
                	**type**\:  :py:class:`Snp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.AreaPassword.Snp>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.AreaPassword, self).__init__()

                    self.yang_name = "area-password"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('authenticate', (YLeaf(YType.empty, 'authenticate'), ['Empty'])),
                        ('snp', (YLeaf(YType.enumeration, 'snp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.AreaPassword.Snp')])),
                    ])
                    self.name = None
                    self.authenticate = None
                    self.snp = None
                    self._segment_path = lambda: "area-password"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.AreaPassword, [u'name', u'authenticate', u'snp'], name, value)

                class Snp(Enum):
                    """
                    Snp (Enum Class)

                    SNP PDUs

                    .. data:: send_only = 0

                    .. data:: validate = 1

                    """

                    send_only = Enum.YLeaf(0, "send-only")

                    validate = Enum.YLeaf(1, "validate")



            class Authentication(Entity):
                """
                ISIS authentication for LSPs
                
                .. attribute:: mode
                
                	Authentication mode
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Authentication.Mode>`
                
                .. attribute:: key_chain
                
                	Authentication key\-chain
                	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Authentication.KeyChain>`
                
                .. attribute:: send_only
                
                	Authentication send only, receive ignore
                	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Authentication.SendOnly>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Router.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Router.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Router.Isis.Authentication.SendOnly))])
                    self._leafs = OrderedDict()

                    self.mode = Native.Router.Isis.Authentication.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.key_chain = Native.Router.Isis.Authentication.KeyChain()
                    self.key_chain.parent = self
                    self._children_name_map["key_chain"] = "key-chain"

                    self.send_only = None
                    self._children_name_map["send_only"] = "send-only"
                    self._segment_path = lambda: "authentication"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Authentication, [], name, value)


                class Mode(Entity):
                    """
                    Authentication mode
                    
                    .. attribute:: md5
                    
                    	Keyed message digest
                    	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Authentication.Mode.Md5>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: text
                    
                    	Clear text password
                    	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Authentication.Mode.Text>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Authentication.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Router.Isis.Authentication.Mode.Text))])
                        self._leafs = OrderedDict()

                        self.md5 = None
                        self._children_name_map["md5"] = "md5"

                        self.text = None
                        self._children_name_map["text"] = "text"
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/authentication/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Authentication.Mode, [], name, value)


                    class Md5(Entity):
                        """
                        Keyed message digest
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Authentication.Mode.Md5, self).__init__()

                            self.yang_name = "md5"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "md5"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/authentication/mode/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                    class Text(Entity):
                        """
                        Clear text password
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Authentication.Mode.Text, self).__init__()

                            self.yang_name = "text"
                            self.yang_parent_name = "mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "text"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/authentication/mode/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                class KeyChain(Entity):
                    """
                    Authentication key\-chain
                    
                    .. attribute:: key_chain_list
                    
                    	
                    	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Authentication.KeyChain.KeyChainList>`
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Authentication.KeyChain, self).__init__()

                        self.yang_name = "key-chain"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Router.Isis.Authentication.KeyChain.KeyChainList))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.key_chain_list = YList(self)
                        self._segment_path = lambda: "key-chain"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/authentication/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Authentication.KeyChain, [u'name'], name, value)


                    class KeyChainList(Entity):
                        """
                        
                        
                        .. attribute:: levels  (key)
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                            self.yang_name = "key-chain-list"
                            self.yang_parent_name = "key-chain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['levels']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.levels = None
                            self.name = None
                            self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/authentication/key-chain/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                class SendOnly(Entity):
                    """
                    Authentication send only, receive ignore
                    
                    .. attribute:: levels
                    
                    	
                    	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Authentication.SendOnly, self).__init__()

                        self.yang_name = "send-only"
                        self.yang_parent_name = "authentication"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                        ])
                        self.levels = None
                        self._segment_path = lambda: "send-only"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/authentication/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Authentication.SendOnly, [u'levels'], name, value)


            class DistributeList(Entity):
                """
                Filter networks in routing updates
                
                .. attribute:: acl_name
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: int
                
                			**range:** 1300..1999
                
                		**type**\: str
                
                .. attribute:: in_
                
                	Filter incoming routing updates
                	**type**\: str
                
                .. attribute:: gateway
                
                	Filtering incoming updates based on gateway
                	**type**\: str
                
                .. attribute:: prefix
                
                	Filter prefixes in routing updates
                	**type**\: str
                
                .. attribute:: gateway_prefix_in
                
                	Filter incoming routing updates
                	**type**\: str
                
                .. attribute:: route_map
                
                	Filter prefixes based on the route\-map
                	**type**\: str
                
                .. attribute:: route_map_in
                
                	Filter incoming routing updates
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.DistributeList, self).__init__()

                    self.yang_name = "distribute-list"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','int','str'])),
                        ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                        ('gateway', (YLeaf(YType.str, 'gateway'), ['str'])),
                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                        ('gateway_prefix_in', (YLeaf(YType.str, 'gateway-prefix-in'), ['str'])),
                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ('route_map_in', (YLeaf(YType.empty, 'route-map-in'), ['Empty'])),
                    ])
                    self.acl_name = None
                    self.in_ = None
                    self.gateway = None
                    self.prefix = None
                    self.gateway_prefix_in = None
                    self.route_map = None
                    self.route_map_in = None
                    self._segment_path = lambda: "distribute-list"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.DistributeList, [u'acl_name', u'in_', u'gateway', u'prefix', u'gateway_prefix_in', u'route_map', u'route_map_in'], name, value)


            class DomainPassword(Entity):
                """
                Set the authentication password for a routing domain
                
                .. attribute:: name
                
                	
                	**type**\: str
                
                .. attribute:: authenticate
                
                	Authentication
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: snp
                
                	SNP PDUs
                	**type**\:  :py:class:`Snp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.DomainPassword.Snp>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.DomainPassword, self).__init__()

                    self.yang_name = "domain-password"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('authenticate', (YLeaf(YType.empty, 'authenticate'), ['Empty'])),
                        ('snp', (YLeaf(YType.enumeration, 'snp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.DomainPassword.Snp')])),
                    ])
                    self.name = None
                    self.authenticate = None
                    self.snp = None
                    self._segment_path = lambda: "domain-password"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.DomainPassword, [u'name', u'authenticate', u'snp'], name, value)

                class Snp(Enum):
                    """
                    Snp (Enum Class)

                    SNP PDUs

                    .. data:: send_only = 0

                    .. data:: validate = 1

                    """

                    send_only = Enum.YLeaf(0, "send-only")

                    validate = Enum.YLeaf(1, "validate")



            class FastFlood(Entity):
                """
                Flood LSPs (that triggered SPF) before running SPF
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..15
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.FastFlood, self).__init__()

                    self.yang_name = "fast-flood"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                    ])
                    self.number = None
                    self._segment_path = lambda: "fast-flood"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.FastFlood, [u'number'], name, value)


            class FastReroute(Entity):
                """
                Configure Fast\-Reroute
                
                .. attribute:: load_sharing
                
                	Distributes repair paths equally among links and prefixes
                	**type**\:  :py:class:`LoadSharing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.LoadSharing>`
                
                .. attribute:: per_prefix
                
                	Enable Fast\-Reroute Per\-Prefix
                	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.PerPrefix>`
                
                .. attribute:: remote_lfa
                
                	Configuring fast\-reroute remote\-lfa
                	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.RemoteLfa>`
                
                .. attribute:: tie_break
                
                	Set repair path preference
                	**type**\:  :py:class:`TieBreak <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.TieBreak>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.FastReroute, self).__init__()

                    self.yang_name = "fast-reroute"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("load-sharing", ("load_sharing", Native.Router.Isis.FastReroute.LoadSharing)), ("per-prefix", ("per_prefix", Native.Router.Isis.FastReroute.PerPrefix)), ("remote-lfa", ("remote_lfa", Native.Router.Isis.FastReroute.RemoteLfa)), ("tie-break", ("tie_break", Native.Router.Isis.FastReroute.TieBreak))])
                    self._leafs = OrderedDict()

                    self.load_sharing = Native.Router.Isis.FastReroute.LoadSharing()
                    self.load_sharing.parent = self
                    self._children_name_map["load_sharing"] = "load-sharing"

                    self.per_prefix = Native.Router.Isis.FastReroute.PerPrefix()
                    self.per_prefix.parent = self
                    self._children_name_map["per_prefix"] = "per-prefix"

                    self.remote_lfa = Native.Router.Isis.FastReroute.RemoteLfa()
                    self.remote_lfa.parent = self
                    self._children_name_map["remote_lfa"] = "remote-lfa"

                    self.tie_break = Native.Router.Isis.FastReroute.TieBreak()
                    self.tie_break.parent = self
                    self._children_name_map["tie_break"] = "tie-break"
                    self._segment_path = lambda: "fast-reroute"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.FastReroute, [], name, value)


                class LoadSharing(Entity):
                    """
                    Distributes repair paths equally among links and prefixes
                    
                    .. attribute:: level_1
                    
                    	Apply to level\-1
                    	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.LoadSharing.Level1>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: level_2
                    
                    	Apply to level\-2
                    	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.LoadSharing.Level2>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.FastReroute.LoadSharing, self).__init__()

                        self.yang_name = "load-sharing"
                        self.yang_parent_name = "fast-reroute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.Isis.FastReroute.LoadSharing.Level1)), ("level-2", ("level_2", Native.Router.Isis.FastReroute.LoadSharing.Level2))])
                        self._leafs = OrderedDict()

                        self.level_1 = None
                        self._children_name_map["level_1"] = "level-1"

                        self.level_2 = None
                        self._children_name_map["level_2"] = "level-2"
                        self._segment_path = lambda: "load-sharing"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.FastReroute.LoadSharing, [], name, value)


                    class Level1(Entity):
                        """
                        Apply to level\-1
                        
                        .. attribute:: disable
                        
                        	Disable load\-sharing
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.FastReroute.LoadSharing.Level1, self).__init__()

                            self.yang_name = "level-1"
                            self.yang_parent_name = "load-sharing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "level-1"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/load-sharing/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.FastReroute.LoadSharing.Level1, [u'disable'], name, value)


                    class Level2(Entity):
                        """
                        Apply to level\-2
                        
                        .. attribute:: disable
                        
                        	Disable load\-sharing
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.FastReroute.LoadSharing.Level2, self).__init__()

                            self.yang_name = "level-2"
                            self.yang_parent_name = "load-sharing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "level-2"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/load-sharing/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.FastReroute.LoadSharing.Level2, [u'disable'], name, value)


                class PerPrefix(Entity):
                    """
                    Enable Fast\-Reroute Per\-Prefix
                    
                    .. attribute:: level_1
                    
                    	Apply to level\-1
                    	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.PerPrefix.Level1>`
                    
                    .. attribute:: level_2
                    
                    	Apply to level\-2
                    	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.PerPrefix.Level2>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.FastReroute.PerPrefix, self).__init__()

                        self.yang_name = "per-prefix"
                        self.yang_parent_name = "fast-reroute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.Isis.FastReroute.PerPrefix.Level1)), ("level-2", ("level_2", Native.Router.Isis.FastReroute.PerPrefix.Level2))])
                        self._leafs = OrderedDict()

                        self.level_1 = Native.Router.Isis.FastReroute.PerPrefix.Level1()
                        self.level_1.parent = self
                        self._children_name_map["level_1"] = "level-1"

                        self.level_2 = Native.Router.Isis.FastReroute.PerPrefix.Level2()
                        self.level_2.parent = self
                        self._children_name_map["level_2"] = "level-2"
                        self._segment_path = lambda: "per-prefix"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.FastReroute.PerPrefix, [], name, value)


                    class Level1(Entity):
                        """
                        Apply to level\-1
                        
                        .. attribute:: all
                        
                        	Enable Fast\-Reroute for primary paths
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	route\-map name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.FastReroute.PerPrefix.Level1, self).__init__()

                            self.yang_name = "level-1"
                            self.yang_parent_name = "per-prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.all = None
                            self.route_map = None
                            self._segment_path = lambda: "level-1"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/per-prefix/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.FastReroute.PerPrefix.Level1, [u'all', u'route_map'], name, value)


                    class Level2(Entity):
                        """
                        Apply to level\-2
                        
                        .. attribute:: all
                        
                        	Enable Fast\-Reroute for primary paths
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	route\-map name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.FastReroute.PerPrefix.Level2, self).__init__()

                            self.yang_name = "level-2"
                            self.yang_parent_name = "per-prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.all = None
                            self.route_map = None
                            self._segment_path = lambda: "level-2"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/per-prefix/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.FastReroute.PerPrefix.Level2, [u'all', u'route_map'], name, value)


                class RemoteLfa(Entity):
                    """
                    Configuring fast\-reroute remote\-lfa
                    
                    .. attribute:: level_1
                    
                    	Apply to level\-1
                    	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.RemoteLfa.Level1>`
                    
                    .. attribute:: level_2
                    
                    	Apply to level\-2
                    	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.RemoteLfa.Level2>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.FastReroute.RemoteLfa, self).__init__()

                        self.yang_name = "remote-lfa"
                        self.yang_parent_name = "fast-reroute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.Isis.FastReroute.RemoteLfa.Level1)), ("level-2", ("level_2", Native.Router.Isis.FastReroute.RemoteLfa.Level2))])
                        self._leafs = OrderedDict()

                        self.level_1 = Native.Router.Isis.FastReroute.RemoteLfa.Level1()
                        self.level_1.parent = self
                        self._children_name_map["level_1"] = "level-1"

                        self.level_2 = Native.Router.Isis.FastReroute.RemoteLfa.Level2()
                        self.level_2.parent = self
                        self._children_name_map["level_2"] = "level-2"
                        self._segment_path = lambda: "remote-lfa"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.FastReroute.RemoteLfa, [], name, value)


                    class Level1(Entity):
                        """
                        Apply to level\-1
                        
                        .. attribute:: mpls_ldp
                        
                        	Use mpls\-ldp tunnel type
                        	**type**\:  :py:class:`MplsLdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.RemoteLfa.Level1.MplsLdp>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.FastReroute.RemoteLfa.Level1, self).__init__()

                            self.yang_name = "level-1"
                            self.yang_parent_name = "remote-lfa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mpls-ldp", ("mpls_ldp", Native.Router.Isis.FastReroute.RemoteLfa.Level1.MplsLdp))])
                            self._leafs = OrderedDict()

                            self.mpls_ldp = None
                            self._children_name_map["mpls_ldp"] = "mpls-ldp"
                            self._segment_path = lambda: "level-1"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/remote-lfa/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.FastReroute.RemoteLfa.Level1, [], name, value)


                        class MplsLdp(Entity):
                            """
                            Use mpls\-ldp tunnel type
                            
                            .. attribute:: maximum_metric
                            
                            	maximum metric to reach release node
                            	**type**\:  :py:class:`MaximumMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.RemoteLfa.Level1.MplsLdp.MaximumMetric>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.FastReroute.RemoteLfa.Level1.MplsLdp, self).__init__()

                                self.yang_name = "mpls-ldp"
                                self.yang_parent_name = "level-1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum-metric", ("maximum_metric", Native.Router.Isis.FastReroute.RemoteLfa.Level1.MplsLdp.MaximumMetric))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.maximum_metric = None
                                self._children_name_map["maximum_metric"] = "maximum-metric"
                                self._segment_path = lambda: "mpls-ldp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/remote-lfa/level-1/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.FastReroute.RemoteLfa.Level1.MplsLdp, [], name, value)


                            class MaximumMetric(Entity):
                                """
                                maximum metric to reach release node
                                
                                .. attribute:: max_met
                                
                                	metric value
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.FastReroute.RemoteLfa.Level1.MplsLdp.MaximumMetric, self).__init__()

                                    self.yang_name = "maximum-metric"
                                    self.yang_parent_name = "mpls-ldp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('max_met', (YLeaf(YType.uint32, 'max-met'), ['int'])),
                                    ])
                                    self.max_met = None
                                    self._segment_path = lambda: "maximum-metric"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/remote-lfa/level-1/mpls-ldp/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.FastReroute.RemoteLfa.Level1.MplsLdp.MaximumMetric, [u'max_met'], name, value)


                    class Level2(Entity):
                        """
                        Apply to level\-2
                        
                        .. attribute:: mpls_ldp
                        
                        	Use mpls\-ldp tunnel type
                        	**type**\:  :py:class:`MplsLdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.RemoteLfa.Level2.MplsLdp>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.FastReroute.RemoteLfa.Level2, self).__init__()

                            self.yang_name = "level-2"
                            self.yang_parent_name = "remote-lfa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mpls-ldp", ("mpls_ldp", Native.Router.Isis.FastReroute.RemoteLfa.Level2.MplsLdp))])
                            self._leafs = OrderedDict()

                            self.mpls_ldp = None
                            self._children_name_map["mpls_ldp"] = "mpls-ldp"
                            self._segment_path = lambda: "level-2"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/remote-lfa/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.FastReroute.RemoteLfa.Level2, [], name, value)


                        class MplsLdp(Entity):
                            """
                            Use mpls\-ldp tunnel type
                            
                            .. attribute:: maximum_metric
                            
                            	maximum metric to reach release node
                            	**type**\:  :py:class:`MaximumMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.RemoteLfa.Level2.MplsLdp.MaximumMetric>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.FastReroute.RemoteLfa.Level2.MplsLdp, self).__init__()

                                self.yang_name = "mpls-ldp"
                                self.yang_parent_name = "level-2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("maximum-metric", ("maximum_metric", Native.Router.Isis.FastReroute.RemoteLfa.Level2.MplsLdp.MaximumMetric))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.maximum_metric = None
                                self._children_name_map["maximum_metric"] = "maximum-metric"
                                self._segment_path = lambda: "mpls-ldp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/remote-lfa/level-2/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.FastReroute.RemoteLfa.Level2.MplsLdp, [], name, value)


                            class MaximumMetric(Entity):
                                """
                                maximum metric to reach release node
                                
                                .. attribute:: max_met
                                
                                	metric value
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Isis.FastReroute.RemoteLfa.Level2.MplsLdp.MaximumMetric, self).__init__()

                                    self.yang_name = "maximum-metric"
                                    self.yang_parent_name = "mpls-ldp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('max_met', (YLeaf(YType.uint32, 'max-met'), ['int'])),
                                    ])
                                    self.max_met = None
                                    self._segment_path = lambda: "maximum-metric"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/remote-lfa/level-2/mpls-ldp/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Isis.FastReroute.RemoteLfa.Level2.MplsLdp.MaximumMetric, [u'max_met'], name, value)


                class TieBreak(Entity):
                    """
                    Set repair path preference
                    
                    .. attribute:: level_1
                    
                    	Apply to level\-1
                    	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.TieBreak.Level1>`
                    
                    .. attribute:: level_2
                    
                    	Apply to level\-2
                    	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.FastReroute.TieBreak.Level2>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.FastReroute.TieBreak, self).__init__()

                        self.yang_name = "tie-break"
                        self.yang_parent_name = "fast-reroute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.Isis.FastReroute.TieBreak.Level1)), ("level-2", ("level_2", Native.Router.Isis.FastReroute.TieBreak.Level2))])
                        self._leafs = OrderedDict()

                        self.level_1 = Native.Router.Isis.FastReroute.TieBreak.Level1()
                        self.level_1.parent = self
                        self._children_name_map["level_1"] = "level-1"

                        self.level_2 = Native.Router.Isis.FastReroute.TieBreak.Level2()
                        self.level_2.parent = self
                        self._children_name_map["level_2"] = "level-2"
                        self._segment_path = lambda: "tie-break"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.FastReroute.TieBreak, [], name, value)


                    class Level1(Entity):
                        """
                        Apply to level\-1
                        
                        .. attribute:: downstream
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: linecard_disjoint
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: lowest_backup_path_metric
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: node_protecting
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: primary_path
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: secondary_path
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: srlg_disjoint
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.FastReroute.TieBreak.Level1, self).__init__()

                            self.yang_name = "level-1"
                            self.yang_parent_name = "tie-break"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('downstream', (YLeaf(YType.uint8, 'downstream'), ['int'])),
                                ('linecard_disjoint', (YLeaf(YType.uint8, 'linecard-disjoint'), ['int'])),
                                ('lowest_backup_path_metric', (YLeaf(YType.uint8, 'lowest-backup-path-metric'), ['int'])),
                                ('node_protecting', (YLeaf(YType.uint8, 'node-protecting'), ['int'])),
                                ('primary_path', (YLeaf(YType.uint8, 'primary-path'), ['int'])),
                                ('secondary_path', (YLeaf(YType.uint8, 'secondary-path'), ['int'])),
                                ('srlg_disjoint', (YLeaf(YType.uint8, 'srlg-disjoint'), ['int'])),
                            ])
                            self.downstream = None
                            self.linecard_disjoint = None
                            self.lowest_backup_path_metric = None
                            self.node_protecting = None
                            self.primary_path = None
                            self.secondary_path = None
                            self.srlg_disjoint = None
                            self._segment_path = lambda: "level-1"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/tie-break/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.FastReroute.TieBreak.Level1, [u'downstream', u'linecard_disjoint', u'lowest_backup_path_metric', u'node_protecting', u'primary_path', u'secondary_path', u'srlg_disjoint'], name, value)


                    class Level2(Entity):
                        """
                        Apply to level\-2
                        
                        .. attribute:: downstream
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: linecard_disjoint
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: lowest_backup_path_metric
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: node_protecting
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: primary_path
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: secondary_path
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: srlg_disjoint
                        
                        	priority number
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.FastReroute.TieBreak.Level2, self).__init__()

                            self.yang_name = "level-2"
                            self.yang_parent_name = "tie-break"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('downstream', (YLeaf(YType.uint8, 'downstream'), ['int'])),
                                ('linecard_disjoint', (YLeaf(YType.uint8, 'linecard-disjoint'), ['int'])),
                                ('lowest_backup_path_metric', (YLeaf(YType.uint8, 'lowest-backup-path-metric'), ['int'])),
                                ('node_protecting', (YLeaf(YType.uint8, 'node-protecting'), ['int'])),
                                ('primary_path', (YLeaf(YType.uint8, 'primary-path'), ['int'])),
                                ('secondary_path', (YLeaf(YType.uint8, 'secondary-path'), ['int'])),
                                ('srlg_disjoint', (YLeaf(YType.uint8, 'srlg-disjoint'), ['int'])),
                            ])
                            self.downstream = None
                            self.linecard_disjoint = None
                            self.lowest_backup_path_metric = None
                            self.node_protecting = None
                            self.primary_path = None
                            self.secondary_path = None
                            self.srlg_disjoint = None
                            self._segment_path = lambda: "level-2"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/fast-reroute/tie-break/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.FastReroute.TieBreak.Level2, [u'downstream', u'linecard_disjoint', u'lowest_backup_path_metric', u'node_protecting', u'primary_path', u'secondary_path', u'srlg_disjoint'], name, value)


            class TiLfa(Entity):
                """
                
                
                .. attribute:: level_1
                
                	Apply to level\-1
                	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.TiLfa.Level1>`
                
                .. attribute:: level_2
                
                	Apply to level\-2
                	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.TiLfa.Level2>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.TiLfa, self).__init__()

                    self.yang_name = "ti-lfa"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.Isis.TiLfa.Level1)), ("level-2", ("level_2", Native.Router.Isis.TiLfa.Level2))])
                    self._leafs = OrderedDict()

                    self.level_1 = Native.Router.Isis.TiLfa.Level1()
                    self.level_1.parent = self
                    self._children_name_map["level_1"] = "level-1"

                    self.level_2 = None
                    self._children_name_map["level_2"] = "level-2"
                    self._segment_path = lambda: "ti-lfa"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.TiLfa, [], name, value)


                class Level1(Entity):
                    """
                    Apply to level\-1
                    
                    .. attribute:: maximum_metric
                    
                    	maximum metric to reach release node
                    	**type**\:  :py:class:`MaximumMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.TiLfa.Level1.MaximumMetric>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.TiLfa.Level1, self).__init__()

                        self.yang_name = "level-1"
                        self.yang_parent_name = "ti-lfa"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("maximum-metric", ("maximum_metric", Native.Router.Isis.TiLfa.Level1.MaximumMetric))])
                        self._leafs = OrderedDict()

                        self.maximum_metric = Native.Router.Isis.TiLfa.Level1.MaximumMetric()
                        self.maximum_metric.parent = self
                        self._children_name_map["maximum_metric"] = "maximum-metric"
                        self._segment_path = lambda: "level-1"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/ti-lfa/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.TiLfa.Level1, [], name, value)


                    class MaximumMetric(Entity):
                        """
                        maximum metric to reach release node
                        
                        .. attribute:: max_met
                        
                        	metric value
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.TiLfa.Level1.MaximumMetric, self).__init__()

                            self.yang_name = "maximum-metric"
                            self.yang_parent_name = "level-1"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_met', (YLeaf(YType.uint32, 'max-met'), ['int'])),
                            ])
                            self.max_met = None
                            self._segment_path = lambda: "maximum-metric"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/ti-lfa/level-1/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.TiLfa.Level1.MaximumMetric, [u'max_met'], name, value)


                class Level2(Entity):
                    """
                    Apply to level\-2
                    
                    .. attribute:: maximum_metric
                    
                    	maximum metric to reach release node
                    	**type**\:  :py:class:`MaximumMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.TiLfa.Level2.MaximumMetric>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.TiLfa.Level2, self).__init__()

                        self.yang_name = "level-2"
                        self.yang_parent_name = "ti-lfa"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("maximum-metric", ("maximum_metric", Native.Router.Isis.TiLfa.Level2.MaximumMetric))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.maximum_metric = Native.Router.Isis.TiLfa.Level2.MaximumMetric()
                        self.maximum_metric.parent = self
                        self._children_name_map["maximum_metric"] = "maximum-metric"
                        self._segment_path = lambda: "level-2"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/ti-lfa/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.TiLfa.Level2, [], name, value)


                    class MaximumMetric(Entity):
                        """
                        maximum metric to reach release node
                        
                        .. attribute:: max_met
                        
                        	metric value
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.TiLfa.Level2.MaximumMetric, self).__init__()

                            self.yang_name = "maximum-metric"
                            self.yang_parent_name = "level-2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_met', (YLeaf(YType.uint32, 'max-met'), ['int'])),
                            ])
                            self.max_met = None
                            self._segment_path = lambda: "maximum-metric"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/ti-lfa/level-2/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.TiLfa.Level2.MaximumMetric, [u'max_met'], name, value)


            class Hello(Entity):
                """
                Pad ISIS hello PDUs to full MTU
                
                .. attribute:: padding
                
                	Pad hello PDU
                	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Hello.Padding>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Hello, self).__init__()

                    self.yang_name = "hello"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("padding", ("padding", Native.Router.Isis.Hello.Padding))])
                    self._leafs = OrderedDict()

                    self.padding = None
                    self._children_name_map["padding"] = "padding"
                    self._segment_path = lambda: "hello"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Hello, [], name, value)


                class Padding(Entity):
                    """
                    Pad hello PDU
                    
                    .. attribute:: pad_type
                    
                    	
                    	**type**\:  :py:class:`PadType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Hello.Padding.PadType>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Hello.Padding, self).__init__()

                        self.yang_name = "padding"
                        self.yang_parent_name = "hello"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('pad_type', (YLeaf(YType.enumeration, 'pad-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Hello.Padding.PadType')])),
                        ])
                        self.pad_type = None
                        self._segment_path = lambda: "padding"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/hello/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Hello.Padding, [u'pad_type'], name, value)

                    class PadType(Enum):
                        """
                        PadType (Enum Class)

                        .. data:: multi_point = 0

                        .. data:: point_to_point = 1

                        """

                        multi_point = Enum.YLeaf(0, "multi-point")

                        point_to_point = Enum.YLeaf(1, "point-to-point")



            class Hostname(Entity):
                """
                Dynamic hostname for IS\-IS
                
                .. attribute:: dynamic
                
                	Dynamic hostname
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Hostname, self).__init__()

                    self.yang_name = "hostname"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                    ])
                    self.dynamic = None
                    self._segment_path = lambda: "hostname"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Hostname, [u'dynamic'], name, value)


            class Ispf(Entity):
                """
                Configure execution of incremental SPF
                
                .. attribute:: level
                
                	
                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Ispf.Level>`
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..600
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Ispf, self).__init__()

                    self.yang_name = "ispf"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Isis.Ispf.Level')])),
                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                    ])
                    self.level = None
                    self.number = None
                    self._segment_path = lambda: "ispf"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Ispf, [u'level', u'number'], name, value)

                class Level(Enum):
                    """
                    Level (Enum Class)

                    .. data:: level_1 = 0

                    .. data:: level_1_2 = 1

                    .. data:: level_2 = 2

                    """

                    level_1 = Enum.YLeaf(0, "level-1")

                    level_1_2 = Enum.YLeaf(1, "level-1-2")

                    level_2 = Enum.YLeaf(2, "level-2")



            class LogAdjacencyChanges(Entity):
                """
                Log changes in adjacency state
                
                .. attribute:: all
                
                	Include changes generated by non\-IIH event
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.LogAdjacencyChanges, self).__init__()

                    self.yang_name = "log-adjacency-changes"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                    ])
                    self.all = None
                    self._segment_path = lambda: "log-adjacency-changes"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.LogAdjacencyChanges, [u'all'], name, value)


            class LspFull(Entity):
                """
                If we run out of LSP fragments
                
                .. attribute:: suppress
                
                	suppress the following types of IP prefixes
                	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.LspFull.Suppress>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.LspFull, self).__init__()

                    self.yang_name = "lsp-full"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("suppress", ("suppress", Native.Router.Isis.LspFull.Suppress))])
                    self._leafs = OrderedDict()

                    self.suppress = Native.Router.Isis.LspFull.Suppress()
                    self.suppress.parent = self
                    self._children_name_map["suppress"] = "suppress"
                    self._segment_path = lambda: "lsp-full"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.LspFull, [], name, value)


                class Suppress(Entity):
                    """
                    suppress the following types of IP prefixes
                    
                    .. attribute:: external_interlevel_container
                    
                    	
                    	**type**\:  :py:class:`ExternalInterlevelContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.LspFull.Suppress.ExternalInterlevelContainer>`
                    
                    .. attribute:: none
                    
                    	don't suppress any prefixes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.LspFull.Suppress, self).__init__()

                        self.yang_name = "suppress"
                        self.yang_parent_name = "lsp-full"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("external-interlevel-container", ("external_interlevel_container", Native.Router.Isis.LspFull.Suppress.ExternalInterlevelContainer))])
                        self._leafs = OrderedDict([
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ])
                        self.none = None

                        self.external_interlevel_container = Native.Router.Isis.LspFull.Suppress.ExternalInterlevelContainer()
                        self.external_interlevel_container.parent = self
                        self._children_name_map["external_interlevel_container"] = "external-interlevel-container"
                        self._segment_path = lambda: "suppress"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/lsp-full/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.LspFull.Suppress, [u'none'], name, value)


                    class ExternalInterlevelContainer(Entity):
                        """
                        
                        
                        .. attribute:: external
                        
                        	don't advertise IP prefixes learned from other protocols
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: interlevel
                        
                        	don't advertise IP prefixes learned from another ISIS level
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.LspFull.Suppress.ExternalInterlevelContainer, self).__init__()

                            self.yang_name = "external-interlevel-container"
                            self.yang_parent_name = "suppress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                            ])
                            self.external = None
                            self.interlevel = None
                            self._segment_path = lambda: "external-interlevel-container"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/lsp-full/suppress/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.LspFull.Suppress.ExternalInterlevelContainer, [u'external', u'interlevel'], name, value)


            class LspGenInterval(Entity):
                """
                Minimum interval between regenerating same LSP
                
                .. attribute:: intervals
                
                	
                	**type**\:  :py:class:`Intervals <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.LspGenInterval.Intervals>`
                
                .. attribute:: intervals_levels
                
                	
                	**type**\:  :py:class:`IntervalsLevels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.LspGenInterval.IntervalsLevels>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.LspGenInterval, self).__init__()

                    self.yang_name = "lsp-gen-interval"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("intervals", ("intervals", Native.Router.Isis.LspGenInterval.Intervals)), ("intervals-levels", ("intervals_levels", Native.Router.Isis.LspGenInterval.IntervalsLevels))])
                    self._leafs = OrderedDict()

                    self.intervals = Native.Router.Isis.LspGenInterval.Intervals()
                    self.intervals.parent = self
                    self._children_name_map["intervals"] = "intervals"

                    self.intervals_levels = Native.Router.Isis.LspGenInterval.IntervalsLevels()
                    self.intervals_levels.parent = self
                    self._children_name_map["intervals_levels"] = "intervals-levels"
                    self._segment_path = lambda: "lsp-gen-interval"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.LspGenInterval, [], name, value)


                class Intervals(Entity):
                    """
                    
                    
                    .. attribute:: interval
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    .. attribute:: initial_wait
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    .. attribute:: wait
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.LspGenInterval.Intervals, self).__init__()

                        self.yang_name = "intervals"
                        self.yang_parent_name = "lsp-gen-interval"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                            ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                            ('wait', (YLeaf(YType.uint32, 'wait'), ['int'])),
                        ])
                        self.interval = None
                        self.initial_wait = None
                        self.wait = None
                        self._segment_path = lambda: "intervals"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/lsp-gen-interval/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.LspGenInterval.Intervals, [u'interval', u'initial_wait', u'wait'], name, value)


                class IntervalsLevels(Entity):
                    """
                    
                    
                    .. attribute:: intervals_level_1
                    
                    	
                    	**type**\:  :py:class:`IntervalsLevel1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel1>`
                    
                    .. attribute:: intervals_level_2
                    
                    	
                    	**type**\:  :py:class:`IntervalsLevel2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel2>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.LspGenInterval.IntervalsLevels, self).__init__()

                        self.yang_name = "intervals-levels"
                        self.yang_parent_name = "lsp-gen-interval"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("intervals-level-1", ("intervals_level_1", Native.Router.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel1)), ("intervals-level-2", ("intervals_level_2", Native.Router.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel2))])
                        self._leafs = OrderedDict()

                        self.intervals_level_1 = Native.Router.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel1()
                        self.intervals_level_1.parent = self
                        self._children_name_map["intervals_level_1"] = "intervals-level-1"

                        self.intervals_level_2 = Native.Router.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel2()
                        self.intervals_level_2.parent = self
                        self._children_name_map["intervals_level_2"] = "intervals-level-2"
                        self._segment_path = lambda: "intervals-levels"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/lsp-gen-interval/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.LspGenInterval.IntervalsLevels, [], name, value)


                    class IntervalsLevel1(Entity):
                        """
                        
                        
                        .. attribute:: level_1
                        
                        	Set interval for level 1 only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120
                        
                        .. attribute:: initial_wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        .. attribute:: wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel1, self).__init__()

                            self.yang_name = "intervals-level-1"
                            self.yang_parent_name = "intervals-levels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                ('wait', (YLeaf(YType.uint32, 'wait'), ['int'])),
                            ])
                            self.level_1 = None
                            self.interval = None
                            self.initial_wait = None
                            self.wait = None
                            self._segment_path = lambda: "intervals-level-1"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/lsp-gen-interval/intervals-levels/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel1, [u'level_1', u'interval', u'initial_wait', u'wait'], name, value)


                    class IntervalsLevel2(Entity):
                        """
                        
                        
                        .. attribute:: level_2
                        
                        	Set interval for level 2 only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120
                        
                        .. attribute:: initial_wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        .. attribute:: wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel2, self).__init__()

                            self.yang_name = "intervals-level-2"
                            self.yang_parent_name = "intervals-levels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                ('wait', (YLeaf(YType.uint32, 'wait'), ['int'])),
                            ])
                            self.level_2 = None
                            self.interval = None
                            self.initial_wait = None
                            self.wait = None
                            self._segment_path = lambda: "intervals-level-2"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/lsp-gen-interval/intervals-levels/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel2, [u'level_2', u'interval', u'initial_wait', u'wait'], name, value)


            class Microloop(Entity):
                """
                Enable microloop protection configuration commands
                
                .. attribute:: avoidance
                
                	Enable local microloop avoidance
                	**type**\:  :py:class:`Avoidance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Microloop.Avoidance>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Microloop, self).__init__()

                    self.yang_name = "microloop"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("avoidance", ("avoidance", Native.Router.Isis.Microloop.Avoidance))])
                    self._leafs = OrderedDict()

                    self.avoidance = None
                    self._children_name_map["avoidance"] = "avoidance"
                    self._segment_path = lambda: "microloop"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Microloop, [], name, value)


                class Avoidance(Entity):
                    """
                    Enable local microloop avoidance
                    
                    .. attribute:: disable
                    
                    	Disable Microloop avoidance
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: protected
                    
                    	Microloop avoidance for protected link or prefix only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: rib_update_delay
                    
                    	Value of the delay in milliseconds
                    	**type**\: int
                    
                    	**range:** 1..600000
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Microloop.Avoidance, self).__init__()

                        self.yang_name = "avoidance"
                        self.yang_parent_name = "microloop"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('protected', (YLeaf(YType.empty, 'protected'), ['Empty'])),
                            ('rib_update_delay', (YLeaf(YType.uint32, 'rib-update-delay'), ['int'])),
                        ])
                        self.disable = None
                        self.protected = None
                        self.rib_update_delay = None
                        self._segment_path = lambda: "avoidance"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/microloop/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Microloop.Avoidance, [u'disable', u'protected', u'rib_update_delay'], name, value)


            class Mpls(Entity):
                """
                Configure MPLS routing protocol parameters
                
                .. attribute:: ldp
                
                	routing protocol commands for MPLS LDP
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Mpls.Ldp>`
                
                .. attribute:: traffic_eng
                
                	routing protocol commands for MPLS Traffic Engineering
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ldp", ("ldp", Native.Router.Isis.Mpls.Ldp)), ("traffic-eng", ("traffic_eng", Native.Router.Isis.Mpls.TrafficEng))])
                    self._leafs = OrderedDict()

                    self.ldp = Native.Router.Isis.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "ldp"

                    self.traffic_eng = Native.Router.Isis.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Mpls, [], name, value)


                class Ldp(Entity):
                    """
                    routing protocol commands for MPLS LDP
                    
                    .. attribute:: autoconfig
                    
                    	Configure LDP automatic configuration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Mpls.Ldp.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: sync
                    
                    	Configure LDP\-IGP Synchronization
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sync_igp_shortcuts
                    
                    	Configure LDP\-IGP Synchronization on MPLS shortcuts
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("autoconfig", ("autoconfig", Native.Router.Isis.Mpls.Ldp.Autoconfig))])
                        self._leafs = OrderedDict([
                            ('sync', (YLeaf(YType.empty, 'sync'), ['Empty'])),
                            ('sync_igp_shortcuts', (YLeaf(YType.empty, 'sync-igp-shortcuts'), ['Empty'])),
                        ])
                        self.sync = None
                        self.sync_igp_shortcuts = None

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"
                        self._segment_path = lambda: "ldp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/mpls/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Mpls.Ldp, [u'sync', u'sync_igp_shortcuts'], name, value)


                    class Autoconfig(Entity):
                        """
                        Configure LDP automatic configuration
                        
                        .. attribute:: level_1
                        
                        	Configure ISIS level\-1 to run MPLS LDP
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: level_2
                        
                        	Configure ISIS level\-2 to run MPLS LDP
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Mpls.Ldp.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                                ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                            ])
                            self.level_1 = None
                            self.level_2 = None
                            self._segment_path = lambda: "autoconfig"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/mpls/ldp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Mpls.Ldp.Autoconfig, [u'level_1', u'level_2'], name, value)


                class TrafficEng(Entity):
                    """
                    routing protocol commands for MPLS Traffic Engineering
                    
                    .. attribute:: level_1
                    
                    	Run MPLS TE on IS\-IS level 1 only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level_2
                    
                    	Run MPLS TE on IS\-IS level 2 only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: multicast_intact
                    
                    	MPLS TE and PIM interaction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: router_id
                    
                    	Traffic Engineering stable IP address for system
                    	**type**\:  :py:class:`RouterId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Mpls.TrafficEng.RouterId>`
                    
                    .. attribute:: scanner
                    
                    	Timer parameters for TE database
                    	**type**\:  :py:class:`Scanner <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Mpls.TrafficEng.Scanner>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("router-id", ("router_id", Native.Router.Isis.Mpls.TrafficEng.RouterId)), ("scanner", ("scanner", Native.Router.Isis.Mpls.TrafficEng.Scanner))])
                        self._leafs = OrderedDict([
                            ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                            ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                            ('multicast_intact', (YLeaf(YType.empty, 'multicast-intact'), ['Empty'])),
                        ])
                        self.level_1 = None
                        self.level_2 = None
                        self.multicast_intact = None

                        self.router_id = Native.Router.Isis.Mpls.TrafficEng.RouterId()
                        self.router_id.parent = self
                        self._children_name_map["router_id"] = "router-id"

                        self.scanner = Native.Router.Isis.Mpls.TrafficEng.Scanner()
                        self.scanner.parent = self
                        self._children_name_map["scanner"] = "scanner"
                        self._segment_path = lambda: "traffic-eng"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/mpls/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Mpls.TrafficEng, [u'level_1', u'level_2', u'multicast_intact'], name, value)


                    class RouterId(Entity):
                        """
                        Traffic Engineering stable IP address for system
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Mpls.TrafficEng.RouterId.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Mpls.TrafficEng.RouterId.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Mpls.TrafficEng.RouterId.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Mpls.TrafficEng.RouterId.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Mpls.TrafficEng.RouterId, self).__init__()

                            self.yang_name = "router-id"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Isis.Mpls.TrafficEng.RouterId.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Isis.Mpls.TrafficEng.RouterId.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Isis.Mpls.TrafficEng.RouterId.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Isis.Mpls.TrafficEng.RouterId.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Router.Isis.Mpls.TrafficEng.RouterId.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Router.Isis.Mpls.TrafficEng.RouterId.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Router.Isis.Mpls.TrafficEng.RouterId.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Router.Isis.Mpls.TrafficEng.RouterId.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "router-id"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/mpls/traffic-eng/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Mpls.TrafficEng.RouterId, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Mpls.TrafficEng.RouterId.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "router-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/mpls/traffic-eng/router-id/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Mpls.TrafficEng.RouterId.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Mpls.TrafficEng.RouterId.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "router-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/mpls/traffic-eng/router-id/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Mpls.TrafficEng.RouterId.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Mpls.TrafficEng.RouterId.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "router-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/mpls/traffic-eng/router-id/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Mpls.TrafficEng.RouterId.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Isis.Mpls.TrafficEng.RouterId.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "router-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/mpls/traffic-eng/router-id/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Isis.Mpls.TrafficEng.RouterId.PortChannelSubinterface, [u'port_channel'], name, value)


                    class Scanner(Entity):
                        """
                        Timer parameters for TE database
                        
                        .. attribute:: interval
                        
                        	Time (secs) between LSPDB walks for TE
                        	**type**\: int
                        
                        	**range:** 1..60
                        
                        .. attribute:: max_flash
                        
                        	Max. number of LSPs ISIS may send to TE db without delay\: <0..200>
                        	**type**\: int
                        
                        	**range:** 0..200
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.Mpls.TrafficEng.Scanner, self).__init__()

                            self.yang_name = "scanner"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                ('max_flash', (YLeaf(YType.uint32, 'max-flash'), ['int'])),
                            ])
                            self.interval = None
                            self.max_flash = None
                            self._segment_path = lambda: "scanner"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/mpls/traffic-eng/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.Mpls.TrafficEng.Scanner, [u'interval', u'max_flash'], name, value)


            class Net(Entity):
                """
                A Network Entity Title for this process (OSI only)
                
                .. attribute:: tag  (key)
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Net, self).__init__()

                    self.yang_name = "net"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['tag']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                    ])
                    self.tag = None
                    self._segment_path = lambda: "net" + "[tag='" + str(self.tag) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Net, [u'tag'], name, value)


            class Nsf(Entity):
                """
                Non\-stop forwarding
                
                .. attribute:: cisco
                
                	Checkpoint method
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ietf
                
                	IETF method
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface
                
                	Interface properties
                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Nsf.Interface>`
                
                .. attribute:: interval
                
                	Minutes
                	**type**\: int
                
                	**range:** 0..1440
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Native.Router.Isis.Nsf.Interface))])
                    self._leafs = OrderedDict([
                        ('cisco', (YLeaf(YType.empty, 'cisco'), ['Empty'])),
                        ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                    ])
                    self.cisco = None
                    self.ietf = None
                    self.interval = None

                    self.interface = Native.Router.Isis.Nsf.Interface()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Nsf, [u'cisco', u'ietf', u'interval'], name, value)


                class Interface(Entity):
                    """
                    Interface properties
                    
                    .. attribute:: wait
                    
                    	Seconds
                    	**type**\: int
                    
                    	**range:** 1..60
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Nsf.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "nsf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('wait', (YLeaf(YType.uint8, 'wait'), ['int'])),
                        ])
                        self.wait = None
                        self._segment_path = lambda: "interface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/nsf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Nsf.Interface, [u'wait'], name, value)


            class Partition(Entity):
                """
                CLNS area partition
                
                .. attribute:: avoidance
                
                	Withdraw area prefix if partition detected
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Partition, self).__init__()

                    self.yang_name = "partition"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('avoidance', (YLeaf(YType.empty, 'avoidance'), ['Empty'])),
                    ])
                    self.avoidance = None
                    self._segment_path = lambda: "partition"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Partition, [u'avoidance'], name, value)


            class PassiveInterface(Entity):
                """
                Suppress routing updates on an interface
                
                .. attribute:: default
                
                	Suppress routing updates on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.PassiveInterface, self).__init__()

                    self.yang_name = "passive-interface"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                    ])
                    self.default = None
                    self.interface = None
                    self._segment_path = lambda: "passive-interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.PassiveInterface, [u'default', u'interface'], name, value)


            class Disable(Entity):
                """
                
                
                .. attribute:: passive_interface
                
                	
                	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.Disable.PassiveInterface>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Disable, self).__init__()

                    self.yang_name = "disable"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.Isis.Disable.PassiveInterface))])
                    self._leafs = OrderedDict()

                    self.passive_interface = YList(self)
                    self._segment_path = lambda: "disable"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Disable, [], name, value)


                class PassiveInterface(Entity):
                    """
                    
                    
                    .. attribute:: interface  (key)
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.Disable.PassiveInterface, self).__init__()

                        self.yang_name = "passive-interface"
                        self.yang_parent_name = "disable"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ])
                        self.interface = None
                        self._segment_path = lambda: "passive-interface" + "[interface='" + str(self.interface) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/disable/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.Disable.PassiveInterface, [u'interface'], name, value)


            class Protocol(Entity):
                """
                Set protocol's administrative state
                
                .. attribute:: shutdown
                
                	Set protocol's administrative state to disable
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Protocol, self).__init__()

                    self.yang_name = "protocol"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ])
                    self.shutdown = None
                    self._segment_path = lambda: "protocol"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Protocol, [u'shutdown'], name, value)


            class SegmentRouting(Entity):
                """
                Enable Segment Routing Feature
                
                .. attribute:: mpls
                
                	Enable Segment Routing Feature using MPLS encapsulation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: prefix_sid_map
                
                	Enable prefix\-sid\-map
                	**type**\:  :py:class:`PrefixSidMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SegmentRouting.PrefixSidMap>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.SegmentRouting, self).__init__()

                    self.yang_name = "segment-routing"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("prefix-sid-map", ("prefix_sid_map", Native.Router.Isis.SegmentRouting.PrefixSidMap))])
                    self._leafs = OrderedDict([
                        ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                    ])
                    self.mpls = None

                    self.prefix_sid_map = Native.Router.Isis.SegmentRouting.PrefixSidMap()
                    self.prefix_sid_map.parent = self
                    self._children_name_map["prefix_sid_map"] = "prefix-sid-map"
                    self._segment_path = lambda: "segment-routing"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.SegmentRouting, [u'mpls'], name, value)


                class PrefixSidMap(Entity):
                    """
                    Enable prefix\-sid\-map
                    
                    .. attribute:: advertise_local
                    
                    	Advertise active local prefix\-SID mappings
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: receive
                    
                    	Enable prefix\-SID mapping client
                    	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Isis.SegmentRouting.PrefixSidMap.Receive>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Isis.SegmentRouting.PrefixSidMap, self).__init__()

                        self.yang_name = "prefix-sid-map"
                        self.yang_parent_name = "segment-routing"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("receive", ("receive", Native.Router.Isis.SegmentRouting.PrefixSidMap.Receive))])
                        self._leafs = OrderedDict([
                            ('advertise_local', (YLeaf(YType.empty, 'advertise-local'), ['Empty'])),
                        ])
                        self.advertise_local = None

                        self.receive = None
                        self._children_name_map["receive"] = "receive"
                        self._segment_path = lambda: "prefix-sid-map"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/segment-routing/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Isis.SegmentRouting.PrefixSidMap, [u'advertise_local'], name, value)


                    class Receive(Entity):
                        """
                        Enable prefix\-SID mapping client
                        
                        .. attribute:: disable
                        
                        	Disable prefix\-SID mapping
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Isis.SegmentRouting.PrefixSidMap.Receive, self).__init__()

                            self.yang_name = "receive"
                            self.yang_parent_name = "prefix-sid-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "receive"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/segment-routing/prefix-sid-map/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Isis.SegmentRouting.PrefixSidMap.Receive, [u'disable'], name, value)


            class Skeptical(Entity):
                """
                Be a cautious NSF helper when refresh adjacency
                
                .. attribute:: interval
                
                	Minutes
                	**type**\: int
                
                	**range:** 0..1440
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Skeptical, self).__init__()

                    self.yang_name = "skeptical"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                    ])
                    self.interval = None
                    self._segment_path = lambda: "skeptical"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Skeptical, [u'interval'], name, value)


            class Use(Entity):
                """
                Use different algorithms during SPF
                
                .. attribute:: external_metrics
                
                	Honour external metrics during SPF
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Use, self).__init__()

                    self.yang_name = "use"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('external_metrics', (YLeaf(YType.empty, 'external-metrics'), ['Empty'])),
                    ])
                    self.external_metrics = None
                    self._segment_path = lambda: "use"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Use, [u'external_metrics'], name, value)


            class Bfd(Entity):
                """
                BFD configuration commands
                
                .. attribute:: all_interfaces
                
                	Enable BFD on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: check_ctrl_plane_failure
                
                	BFD check control plane failure
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Isis.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                        ('check_ctrl_plane_failure', (YLeaf(YType.empty, 'check-ctrl-plane-failure'), ['Empty'])),
                    ])
                    self.all_interfaces = None
                    self.check_ctrl_plane_failure = None
                    self._segment_path = lambda: "bfd"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Isis.Bfd, [u'all_interfaces', u'check_ctrl_plane_failure'], name, value)


        class IsisContainer(Entity):
            """
            
            
            .. attribute:: isis
            
            	ISO IS\-IS
            	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis>`
            
            

            """

            _prefix = 'ios-isis'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Router.IsisContainer, self).__init__()

                self.yang_name = "isis-container"
                self.yang_parent_name = "router"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("isis", ("isis", Native.Router.IsisContainer.Isis))])
                self._leafs = OrderedDict()

                self.isis = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-isis:isis-container"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Router.IsisContainer, [], name, value)


            class Isis(Entity):
                """
                ISO IS\-IS
                
                .. attribute:: area_tag  (key)
                
                	
                	**type**\: str
                
                .. attribute:: metric_style
                
                	Use old\-style (ISO 10589) or new\-style packet formats
                	**type**\:  :py:class:`MetricStyle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.MetricStyle>`
                
                .. attribute:: address_family
                
                	Enter Address Family command mode
                	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily>`
                
                .. attribute:: distance
                
                	Define an administrative distance
                	**type**\: list of  		 :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Distance>`
                
                .. attribute:: ip
                
                	IP specific commands
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Ip>`
                
                .. attribute:: priority
                
                	priority value
                	**type**\: int
                
                	**range:** 0..127
                
                .. attribute:: redistribute
                
                	Redistribute information from another routing protocol
                	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute>`
                
                .. attribute:: set_attached_bit
                
                	Conditionally advertise us as attached to L2
                	**type**\:  :py:class:`SetAttachedBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SetAttachedBit>`
                
                .. attribute:: snmp
                
                	Modify snmp parameters
                	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Snmp>`
                
                .. attribute:: summary_address
                
                	Configure IP address summaries
                	**type**\: list of  		 :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SummaryAddress>`
                
                .. attribute:: traffic_share
                
                	How to compute traffic share over alternate paths
                	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.TrafficShare>`
                
                .. attribute:: advertise
                
                	Control which IP routes flow in L1 and L2 LSPs
                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Advertise>`
                
                .. attribute:: default_information
                
                	Control distribution of default information
                	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.DefaultInformation>`
                
                .. attribute:: help
                
                	Description of the interactive help system
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: maximum_paths
                
                	Forward packets over multiple paths
                	**type**\: int
                
                	**range:** 1..32
                
                .. attribute:: metric
                
                	Set ISIS metric for all interfaces
                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Metric>`
                
                .. attribute:: prc_interval
                
                	Minimum interval between partial route calculations
                	**type**\:  :py:class:`PrcInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.PrcInterval>`
                
                .. attribute:: set_overload_bit
                
                	Signal other routers not to use us in SPF
                	**type**\:  :py:class:`SetOverloadBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SetOverloadBit>`
                
                	**presence node**\: True
                
                .. attribute:: spf_interval
                
                	Minimum interval between SPF calculations
                	**type**\:  :py:class:`SpfInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SpfInterval>`
                
                .. attribute:: area_password
                
                	Configure the authentication password for an area
                	**type**\:  :py:class:`AreaPassword <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AreaPassword>`
                
                .. attribute:: authentication
                
                	ISIS authentication for LSPs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Authentication>`
                
                .. attribute:: distribute_list
                
                	Filter networks in routing updates
                	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.DistributeList>`
                
                .. attribute:: domain_password
                
                	Set the authentication password for a routing domain
                	**type**\:  :py:class:`DomainPassword <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.DomainPassword>`
                
                .. attribute:: fast_flood
                
                	Flood LSPs (that triggered SPF) before running SPF
                	**type**\:  :py:class:`FastFlood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastFlood>`
                
                	**presence node**\: True
                
                .. attribute:: fast_reroute
                
                	Configure Fast\-Reroute
                	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute>`
                
                .. attribute:: ti_lfa
                
                	
                	**type**\:  :py:class:`TiLfa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.TiLfa>`
                
                .. attribute:: hello
                
                	Pad ISIS hello PDUs to full MTU
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Hello>`
                
                .. attribute:: hostname
                
                	Dynamic hostname for IS\-IS
                	**type**\:  :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Hostname>`
                
                .. attribute:: ignore_lsp_errors
                
                	Ignore LSPs with bad checksums
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: is_type
                
                	IS Level for this routing process (OSI only)
                	**type**\:  :py:class:`IsType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.IsType>`
                
                .. attribute:: ispf
                
                	Configure execution of incremental SPF
                	**type**\:  :py:class:`Ispf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Ispf>`
                
                .. attribute:: log_adjacency_changes
                
                	Log changes in adjacency state
                	**type**\:  :py:class:`LogAdjacencyChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.LogAdjacencyChanges>`
                
                	**presence node**\: True
                
                .. attribute:: lsp_full
                
                	If we run out of LSP fragments
                	**type**\:  :py:class:`LspFull <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.LspFull>`
                
                .. attribute:: lsp_gen_interval
                
                	Minimum interval between regenerating same LSP
                	**type**\:  :py:class:`LspGenInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.LspGenInterval>`
                
                .. attribute:: lsp_mtu
                
                	Set maximum LSP size
                	**type**\: int
                
                	**range:** 128..4352
                
                .. attribute:: lsp_refresh_interval
                
                	Set LSP refresh interval
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: max_area_addresses
                
                	Allow configuration of more manual area addresses
                	**type**\: int
                
                	**range:** 3..254
                
                .. attribute:: max_lsp_lifetime
                
                	Set maximum LSP lifetime
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: microloop
                
                	Enable microloop protection configuration commands
                	**type**\:  :py:class:`Microloop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Microloop>`
                
                .. attribute:: mpls
                
                	Configure MPLS routing protocol parameters
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Mpls>`
                
                .. attribute:: net
                
                	A Network Entity Title for this process (OSI only)
                	**type**\: list of  		 :py:class:`Net <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Net>`
                
                .. attribute:: nsf
                
                	Non\-stop forwarding
                	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Nsf>`
                
                .. attribute:: partition
                
                	CLNS area partition
                	**type**\:  :py:class:`Partition <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Partition>`
                
                .. attribute:: passive_interface
                
                	Suppress routing updates on an interface
                	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.PassiveInterface>`
                
                .. attribute:: disable
                
                	
                	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Disable>`
                
                .. attribute:: protocol
                
                	Set protocol's administrative state
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Protocol>`
                
                .. attribute:: segment_routing
                
                	Enable Segment Routing Feature
                	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SegmentRouting>`
                
                .. attribute:: skeptical
                
                	Be a cautious NSF helper when refresh adjacency
                	**type**\:  :py:class:`Skeptical <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Skeptical>`
                
                .. attribute:: update_queue_depth
                
                	Set Update process queue depth
                	**type**\: int
                
                	**range:** 1..2147483647
                
                .. attribute:: use
                
                	Use different algorithms during SPF
                	**type**\:  :py:class:`Use <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Use>`
                
                .. attribute:: vrf
                
                	VRF name for this process
                	**type**\: str
                
                .. attribute:: adjacency_check
                
                	Check ISIS neighbor protocol support
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bfd
                
                	BFD configuration commands
                	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Bfd>`
                
                .. attribute:: router_id
                
                	Interface of stable IP address for system
                	**type**\: str
                
                

                """

                _prefix = 'ios-isis'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.IsisContainer.Isis, self).__init__()

                    self.yang_name = "isis"
                    self.yang_parent_name = "isis-container"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['area_tag']
                    self._child_classes = OrderedDict([("metric-style", ("metric_style", Native.Router.IsisContainer.Isis.MetricStyle)), ("address-family", ("address_family", Native.Router.IsisContainer.Isis.AddressFamily)), ("distance", ("distance", Native.Router.IsisContainer.Isis.Distance)), ("ip", ("ip", Native.Router.IsisContainer.Isis.Ip)), ("redistribute", ("redistribute", Native.Router.IsisContainer.Isis.Redistribute)), ("set-attached-bit", ("set_attached_bit", Native.Router.IsisContainer.Isis.SetAttachedBit)), ("snmp", ("snmp", Native.Router.IsisContainer.Isis.Snmp)), ("summary-address", ("summary_address", Native.Router.IsisContainer.Isis.SummaryAddress)), ("traffic-share", ("traffic_share", Native.Router.IsisContainer.Isis.TrafficShare)), ("advertise", ("advertise", Native.Router.IsisContainer.Isis.Advertise)), ("default-information", ("default_information", Native.Router.IsisContainer.Isis.DefaultInformation)), ("metric", ("metric", Native.Router.IsisContainer.Isis.Metric)), ("prc-interval", ("prc_interval", Native.Router.IsisContainer.Isis.PrcInterval)), ("set-overload-bit", ("set_overload_bit", Native.Router.IsisContainer.Isis.SetOverloadBit)), ("spf-interval", ("spf_interval", Native.Router.IsisContainer.Isis.SpfInterval)), ("area-password", ("area_password", Native.Router.IsisContainer.Isis.AreaPassword)), ("authentication", ("authentication", Native.Router.IsisContainer.Isis.Authentication)), ("distribute-list", ("distribute_list", Native.Router.IsisContainer.Isis.DistributeList)), ("domain-password", ("domain_password", Native.Router.IsisContainer.Isis.DomainPassword)), ("fast-flood", ("fast_flood", Native.Router.IsisContainer.Isis.FastFlood)), ("fast-reroute", ("fast_reroute", Native.Router.IsisContainer.Isis.FastReroute)), ("ti-lfa", ("ti_lfa", Native.Router.IsisContainer.Isis.TiLfa)), ("hello", ("hello", Native.Router.IsisContainer.Isis.Hello)), ("hostname", ("hostname", Native.Router.IsisContainer.Isis.Hostname)), ("ispf", ("ispf", Native.Router.IsisContainer.Isis.Ispf)), ("log-adjacency-changes", ("log_adjacency_changes", Native.Router.IsisContainer.Isis.LogAdjacencyChanges)), ("lsp-full", ("lsp_full", Native.Router.IsisContainer.Isis.LspFull)), ("lsp-gen-interval", ("lsp_gen_interval", Native.Router.IsisContainer.Isis.LspGenInterval)), ("microloop", ("microloop", Native.Router.IsisContainer.Isis.Microloop)), ("mpls", ("mpls", Native.Router.IsisContainer.Isis.Mpls)), ("net", ("net", Native.Router.IsisContainer.Isis.Net)), ("nsf", ("nsf", Native.Router.IsisContainer.Isis.Nsf)), ("partition", ("partition", Native.Router.IsisContainer.Isis.Partition)), ("passive-interface", ("passive_interface", Native.Router.IsisContainer.Isis.PassiveInterface)), ("disable", ("disable", Native.Router.IsisContainer.Isis.Disable)), ("protocol", ("protocol", Native.Router.IsisContainer.Isis.Protocol)), ("segment-routing", ("segment_routing", Native.Router.IsisContainer.Isis.SegmentRouting)), ("skeptical", ("skeptical", Native.Router.IsisContainer.Isis.Skeptical)), ("use", ("use", Native.Router.IsisContainer.Isis.Use)), ("bfd", ("bfd", Native.Router.IsisContainer.Isis.Bfd))])
                    self._leafs = OrderedDict([
                        ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ('help', (YLeaf(YType.empty, 'help'), ['Empty'])),
                        ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                        ('ignore_lsp_errors', (YLeaf(YType.empty, 'ignore-lsp-errors'), ['Empty'])),
                        ('is_type', (YLeaf(YType.enumeration, 'is-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.IsType')])),
                        ('lsp_mtu', (YLeaf(YType.uint32, 'lsp-mtu'), ['int'])),
                        ('lsp_refresh_interval', (YLeaf(YType.uint32, 'lsp-refresh-interval'), ['int'])),
                        ('max_area_addresses', (YLeaf(YType.uint32, 'max-area-addresses'), ['int'])),
                        ('max_lsp_lifetime', (YLeaf(YType.uint32, 'max-lsp-lifetime'), ['int'])),
                        ('update_queue_depth', (YLeaf(YType.uint32, 'update-queue-depth'), ['int'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ('adjacency_check', (YLeaf(YType.empty, 'adjacency-check'), ['Empty'])),
                        ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                    ])
                    self.area_tag = None
                    self.priority = None
                    self.help = None
                    self.maximum_paths = None
                    self.ignore_lsp_errors = None
                    self.is_type = None
                    self.lsp_mtu = None
                    self.lsp_refresh_interval = None
                    self.max_area_addresses = None
                    self.max_lsp_lifetime = None
                    self.update_queue_depth = None
                    self.vrf = None
                    self.adjacency_check = None
                    self.router_id = None

                    self.metric_style = Native.Router.IsisContainer.Isis.MetricStyle()
                    self.metric_style.parent = self
                    self._children_name_map["metric_style"] = "metric-style"

                    self.address_family = Native.Router.IsisContainer.Isis.AddressFamily()
                    self.address_family.parent = self
                    self._children_name_map["address_family"] = "address-family"

                    self.ip = Native.Router.IsisContainer.Isis.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.redistribute = Native.Router.IsisContainer.Isis.Redistribute()
                    self.redistribute.parent = self
                    self._children_name_map["redistribute"] = "redistribute"

                    self.set_attached_bit = Native.Router.IsisContainer.Isis.SetAttachedBit()
                    self.set_attached_bit.parent = self
                    self._children_name_map["set_attached_bit"] = "set-attached-bit"

                    self.snmp = Native.Router.IsisContainer.Isis.Snmp()
                    self.snmp.parent = self
                    self._children_name_map["snmp"] = "snmp"

                    self.traffic_share = Native.Router.IsisContainer.Isis.TrafficShare()
                    self.traffic_share.parent = self
                    self._children_name_map["traffic_share"] = "traffic-share"

                    self.advertise = Native.Router.IsisContainer.Isis.Advertise()
                    self.advertise.parent = self
                    self._children_name_map["advertise"] = "advertise"

                    self.default_information = Native.Router.IsisContainer.Isis.DefaultInformation()
                    self.default_information.parent = self
                    self._children_name_map["default_information"] = "default-information"

                    self.metric = Native.Router.IsisContainer.Isis.Metric()
                    self.metric.parent = self
                    self._children_name_map["metric"] = "metric"

                    self.prc_interval = Native.Router.IsisContainer.Isis.PrcInterval()
                    self.prc_interval.parent = self
                    self._children_name_map["prc_interval"] = "prc-interval"

                    self.set_overload_bit = None
                    self._children_name_map["set_overload_bit"] = "set-overload-bit"

                    self.spf_interval = Native.Router.IsisContainer.Isis.SpfInterval()
                    self.spf_interval.parent = self
                    self._children_name_map["spf_interval"] = "spf-interval"

                    self.area_password = Native.Router.IsisContainer.Isis.AreaPassword()
                    self.area_password.parent = self
                    self._children_name_map["area_password"] = "area-password"

                    self.authentication = Native.Router.IsisContainer.Isis.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.distribute_list = Native.Router.IsisContainer.Isis.DistributeList()
                    self.distribute_list.parent = self
                    self._children_name_map["distribute_list"] = "distribute-list"

                    self.domain_password = Native.Router.IsisContainer.Isis.DomainPassword()
                    self.domain_password.parent = self
                    self._children_name_map["domain_password"] = "domain-password"

                    self.fast_flood = None
                    self._children_name_map["fast_flood"] = "fast-flood"

                    self.fast_reroute = Native.Router.IsisContainer.Isis.FastReroute()
                    self.fast_reroute.parent = self
                    self._children_name_map["fast_reroute"] = "fast-reroute"

                    self.ti_lfa = Native.Router.IsisContainer.Isis.TiLfa()
                    self.ti_lfa.parent = self
                    self._children_name_map["ti_lfa"] = "ti-lfa"

                    self.hello = Native.Router.IsisContainer.Isis.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "hello"

                    self.hostname = Native.Router.IsisContainer.Isis.Hostname()
                    self.hostname.parent = self
                    self._children_name_map["hostname"] = "hostname"

                    self.ispf = Native.Router.IsisContainer.Isis.Ispf()
                    self.ispf.parent = self
                    self._children_name_map["ispf"] = "ispf"

                    self.log_adjacency_changes = None
                    self._children_name_map["log_adjacency_changes"] = "log-adjacency-changes"

                    self.lsp_full = Native.Router.IsisContainer.Isis.LspFull()
                    self.lsp_full.parent = self
                    self._children_name_map["lsp_full"] = "lsp-full"

                    self.lsp_gen_interval = Native.Router.IsisContainer.Isis.LspGenInterval()
                    self.lsp_gen_interval.parent = self
                    self._children_name_map["lsp_gen_interval"] = "lsp-gen-interval"

                    self.microloop = Native.Router.IsisContainer.Isis.Microloop()
                    self.microloop.parent = self
                    self._children_name_map["microloop"] = "microloop"

                    self.mpls = Native.Router.IsisContainer.Isis.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"

                    self.nsf = Native.Router.IsisContainer.Isis.Nsf()
                    self.nsf.parent = self
                    self._children_name_map["nsf"] = "nsf"

                    self.partition = Native.Router.IsisContainer.Isis.Partition()
                    self.partition.parent = self
                    self._children_name_map["partition"] = "partition"

                    self.passive_interface = Native.Router.IsisContainer.Isis.PassiveInterface()
                    self.passive_interface.parent = self
                    self._children_name_map["passive_interface"] = "passive-interface"

                    self.disable = Native.Router.IsisContainer.Isis.Disable()
                    self.disable.parent = self
                    self._children_name_map["disable"] = "disable"

                    self.protocol = Native.Router.IsisContainer.Isis.Protocol()
                    self.protocol.parent = self
                    self._children_name_map["protocol"] = "protocol"

                    self.segment_routing = Native.Router.IsisContainer.Isis.SegmentRouting()
                    self.segment_routing.parent = self
                    self._children_name_map["segment_routing"] = "segment-routing"

                    self.skeptical = Native.Router.IsisContainer.Isis.Skeptical()
                    self.skeptical.parent = self
                    self._children_name_map["skeptical"] = "skeptical"

                    self.use = Native.Router.IsisContainer.Isis.Use()
                    self.use.parent = self
                    self._children_name_map["use"] = "use"

                    self.bfd = Native.Router.IsisContainer.Isis.Bfd()
                    self.bfd.parent = self
                    self._children_name_map["bfd"] = "bfd"

                    self.distance = YList(self)
                    self.summary_address = YList(self)
                    self.net = YList(self)
                    self._segment_path = lambda: "isis" + "[area-tag='" + str(self.area_tag) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-isis:isis-container/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.IsisContainer.Isis, [u'area_tag', u'priority', u'help', u'maximum_paths', u'ignore_lsp_errors', u'is_type', u'lsp_mtu', u'lsp_refresh_interval', u'max_area_addresses', u'max_lsp_lifetime', u'update_queue_depth', u'vrf', u'adjacency_check', u'router_id'], name, value)

                class IsType(Enum):
                    """
                    IsType (Enum Class)

                    IS Level for this routing process (OSI only)

                    .. data:: level_1 = 0

                    .. data:: level_1_2 = 1

                    .. data:: level_2_only = 2

                    """

                    level_1 = Enum.YLeaf(0, "level-1")

                    level_1_2 = Enum.YLeaf(1, "level-1-2")

                    level_2_only = Enum.YLeaf(2, "level-2-only")



                class MetricStyle(Entity):
                    """
                    Use old\-style (ISO 10589) or new\-style packet formats
                    
                    .. attribute:: narrow
                    
                    	Use old style of TLVs with narrow metric
                    	**type**\:  :py:class:`Narrow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.MetricStyle.Narrow>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: transition
                    
                    	Send and accept both styles of TLVs during transition
                    	**type**\:  :py:class:`Transition <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.MetricStyle.Transition>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: wide
                    
                    	Use new style of TLVs to carry wider metric
                    	**type**\:  :py:class:`Wide <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.MetricStyle.Wide>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.MetricStyle, self).__init__()

                        self.yang_name = "metric-style"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("narrow", ("narrow", Native.Router.IsisContainer.Isis.MetricStyle.Narrow)), ("transition", ("transition", Native.Router.IsisContainer.Isis.MetricStyle.Transition)), ("wide", ("wide", Native.Router.IsisContainer.Isis.MetricStyle.Wide))])
                        self._leafs = OrderedDict()

                        self.narrow = None
                        self._children_name_map["narrow"] = "narrow"

                        self.transition = None
                        self._children_name_map["transition"] = "transition"

                        self.wide = None
                        self._children_name_map["wide"] = "wide"
                        self._segment_path = lambda: "metric-style"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.MetricStyle, [], name, value)


                    class Narrow(Entity):
                        """
                        Use old style of TLVs with narrow metric
                        
                        .. attribute:: narrow_wide
                        
                        	
                        	**type**\:  :py:class:`IsisLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisLevelType>`
                        
                        .. attribute:: transition
                        
                        	Accept both styles of TLVs during transition
                        	**type**\:  :py:class:`IsisLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.MetricStyle.Narrow, self).__init__()

                            self.yang_name = "narrow"
                            self.yang_parent_name = "metric-style"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('narrow_wide', (YLeaf(YType.enumeration, 'narrow-wide'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisLevelType', '')])),
                                ('transition', (YLeaf(YType.enumeration, 'transition'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisLevelType', '')])),
                            ])
                            self.narrow_wide = None
                            self.transition = None
                            self._segment_path = lambda: "narrow"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.MetricStyle.Narrow, [u'narrow_wide', u'transition'], name, value)


                    class Transition(Entity):
                        """
                        Send and accept both styles of TLVs during transition
                        
                        .. attribute:: transition
                        
                        	
                        	**type**\:  :py:class:`IsisLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.MetricStyle.Transition, self).__init__()

                            self.yang_name = "transition"
                            self.yang_parent_name = "metric-style"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('transition', (YLeaf(YType.enumeration, 'transition'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisLevelType', '')])),
                            ])
                            self.transition = None
                            self._segment_path = lambda: "transition"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.MetricStyle.Transition, [u'transition'], name, value)


                    class Wide(Entity):
                        """
                        Use new style of TLVs to carry wider metric
                        
                        .. attribute:: narrow_wide
                        
                        	
                        	**type**\:  :py:class:`IsisLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisLevelType>`
                        
                        .. attribute:: transition
                        
                        	Accept both styles of TLVs during transition
                        	**type**\:  :py:class:`IsisLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.MetricStyle.Wide, self).__init__()

                            self.yang_name = "wide"
                            self.yang_parent_name = "metric-style"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('narrow_wide', (YLeaf(YType.enumeration, 'narrow-wide'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisLevelType', '')])),
                                ('transition', (YLeaf(YType.enumeration, 'transition'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisLevelType', '')])),
                            ])
                            self.narrow_wide = None
                            self.transition = None
                            self._segment_path = lambda: "wide"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.MetricStyle.Wide, [u'narrow_wide', u'transition'], name, value)


                class AddressFamily(Entity):
                    """
                    Enter Address Family command mode
                    
                    .. attribute:: ipv4
                    
                    	Address family
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Address family
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.AddressFamily, self).__init__()

                        self.yang_name = "address-family"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4)), ("ipv6", ("ipv6", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6))])
                        self._leafs = OrderedDict()

                        self.ipv4 = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"
                        self._segment_path = lambda: "address-family"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily, [], name, value)


                    class Ipv4(Entity):
                        """
                        Address family
                        
                        .. attribute:: unicast_multicast
                        
                        	
                        	**type**\:  :py:class:`UnicastMulticast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.UnicastMulticast>`
                        
                        .. attribute:: help
                        
                        	Description of the interactive help system
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: snmp
                        
                        	Modify snmp parameters
                        	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp>`
                        
                        .. attribute:: topology
                        
                        	Associate the routing protocol to a topology instance
                        	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "address-family"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("snmp", ("snmp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp)), ("topology", ("topology", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology))])
                            self._leafs = OrderedDict([
                                ('unicast_multicast', (YLeaf(YType.enumeration, 'unicast-multicast'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.UnicastMulticast')])),
                                ('help', (YLeaf(YType.empty, 'help'), ['Empty'])),
                            ])
                            self.unicast_multicast = None
                            self.help = None

                            self.snmp = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp()
                            self.snmp.parent = self
                            self._children_name_map["snmp"] = "snmp"

                            self.topology = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4, [u'unicast_multicast', u'help'], name, value)

                        class UnicastMulticast(Enum):
                            """
                            UnicastMulticast (Enum Class)

                            .. data:: unicast = 0

                            .. data:: multicast = 1

                            """

                            unicast = Enum.YLeaf(0, "unicast")

                            multicast = Enum.YLeaf(1, "multicast")



                        class Snmp(Entity):
                            """
                            Modify snmp parameters
                            
                            .. attribute:: context
                            
                            	Configure a SNMP context
                            	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp, self).__init__()

                                self.yang_name = "snmp"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("context", ("context", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context))])
                                self._leafs = OrderedDict()

                                self.context = YList(self)
                                self._segment_path = lambda: "snmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp, [], name, value)


                            class Context(Entity):
                                """
                                Configure a SNMP context
                                
                                .. attribute:: name  (key)
                                
                                	Context Name
                                	**type**\: str
                                
                                .. attribute:: community
                                
                                	Configure a SNMP v2c Community string and access privs
                                	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.Community>`
                                
                                .. attribute:: user
                                
                                	Configure a SNMP v3 user
                                	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context, self).__init__()

                                    self.yang_name = "context"
                                    self.yang_parent_name = "snmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("community", ("community", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.Community)), ("user", ("user", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.community = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.Community()
                                    self.community.parent = self
                                    self._children_name_map["community"] = "community"

                                    self.user = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User()
                                    self.user.parent = self
                                    self._children_name_map["user"] = "user"
                                    self._segment_path = lambda: "context" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context, [u'name'], name, value)


                                class Community(Entity):
                                    """
                                    Configure a SNMP v2c Community string and access privs
                                    
                                    .. attribute:: community_string
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: access
                                    
                                    	
                                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.Community.Access>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "context"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("access", ("access", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.Community.Access))])
                                        self._leafs = OrderedDict([
                                            ('community_string', (YLeaf(YType.str, 'community-string'), ['str'])),
                                        ])
                                        self.community_string = None

                                        self.access = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.Community.Access()
                                        self.access.parent = self
                                        self._children_name_map["access"] = "access"
                                        self._segment_path = lambda: "community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.Community, [u'community_string'], name, value)


                                    class Access(Entity):
                                        """
                                        
                                        
                                        .. attribute:: standard_acl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..99
                                        
                                        .. attribute:: expanded_acl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1300..1999
                                        
                                        .. attribute:: acl_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	Specify IPv6 Named Access\-List
                                        	**type**\: str
                                        
                                        .. attribute:: ro
                                        
                                        	Read\-only access with this community string
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rw
                                        
                                        	Read\-write access with this community string
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.Community.Access, self).__init__()

                                            self.yang_name = "access"
                                            self.yang_parent_name = "community"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                ('expanded_acl', (YLeaf(YType.uint32, 'expanded-acl'), ['int'])),
                                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ('ro', (YLeaf(YType.empty, 'ro'), ['Empty'])),
                                                ('rw', (YLeaf(YType.empty, 'rw'), ['Empty'])),
                                            ])
                                            self.standard_acl = None
                                            self.expanded_acl = None
                                            self.acl_name = None
                                            self.ipv6 = None
                                            self.ro = None
                                            self.rw = None
                                            self._segment_path = lambda: "access"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.Community.Access, [u'standard_acl', u'expanded_acl', u'acl_name', u'ipv6', u'ro', u'rw'], name, value)


                                class User(Entity):
                                    """
                                    Configure a SNMP v3 user
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: permisssion
                                    
                                    	
                                    	**type**\:  :py:class:`Permisssion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User, self).__init__()

                                        self.yang_name = "user"
                                        self.yang_parent_name = "context"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("permisssion", ("permisssion", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.permisssion = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion()
                                        self.permisssion.parent = self
                                        self._children_name_map["permisssion"] = "permisssion"
                                        self._segment_path = lambda: "user"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User, [u'name'], name, value)


                                    class Permisssion(Entity):
                                        """
                                        
                                        
                                        .. attribute:: access
                                        
                                        	specify an access\-list associated with this group
                                        	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Access>`
                                        
                                        .. attribute:: auth
                                        
                                        	authentication parameters for the user
                                        	**type**\:  :py:class:`Auth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Auth>`
                                        
                                        .. attribute:: credential
                                        
                                        	If the user password is already configured and saved
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: encrypted
                                        
                                        	specifying passwords as MD5 or SHA digests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion, self).__init__()

                                            self.yang_name = "permisssion"
                                            self.yang_parent_name = "user"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("access", ("access", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Access)), ("auth", ("auth", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Auth))])
                                            self._leafs = OrderedDict([
                                                ('credential', (YLeaf(YType.empty, 'credential'), ['Empty'])),
                                                ('encrypted', (YLeaf(YType.empty, 'encrypted'), ['Empty'])),
                                            ])
                                            self.credential = None
                                            self.encrypted = None

                                            self.access = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Access()
                                            self.access.parent = self
                                            self._children_name_map["access"] = "access"

                                            self.auth = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Auth()
                                            self.auth.parent = self
                                            self._children_name_map["auth"] = "auth"
                                            self._segment_path = lambda: "permisssion"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion, [u'credential', u'encrypted'], name, value)


                                        class Access(Entity):
                                            """
                                            specify an access\-list associated with this group
                                            
                                            .. attribute:: standard_acl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: acl_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Access, self).__init__()

                                                self.yang_name = "access"
                                                self.yang_parent_name = "permisssion"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.standard_acl = None
                                                self.acl_name = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "access"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Access, [u'standard_acl', u'acl_name', u'ipv6'], name, value)


                                        class Auth(Entity):
                                            """
                                            authentication parameters for the user
                                            
                                            .. attribute:: md5
                                            
                                            	Use HMAC MD5 algorithm for authentication
                                            	**type**\: str
                                            
                                            .. attribute:: sha
                                            
                                            	Use HMAC SHA algorithm for authentication
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Auth, self).__init__()

                                                self.yang_name = "auth"
                                                self.yang_parent_name = "permisssion"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('md5', (YLeaf(YType.str, 'md5'), ['str'])),
                                                    ('sha', (YLeaf(YType.str, 'sha'), ['str'])),
                                                ])
                                                self.md5 = None
                                                self.sha = None
                                                self._segment_path = lambda: "auth"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Snmp.Context.User.Permisssion.Auth, [u'md5', u'sha'], name, value)


                        class Topology(Entity):
                            """
                            Associate the routing protocol to a topology instance
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: tid
                            
                            	Configuring the routing protocol topology tid
                            	**type**\: int
                            
                            	**range:** 5..4095
                            
                            .. attribute:: ignore_attached_bit
                            
                            	Never install default route to closest L2 router
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: distance
                            
                            	Define an administrative distance
                            	**type**\: list of  		 :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance>`
                            
                            .. attribute:: ip
                            
                            	IP specific commands
                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip>`
                            
                            .. attribute:: priority
                            
                            	priority value
                            	**type**\: int
                            
                            	**range:** 0..127
                            
                            .. attribute:: redistribute
                            
                            	Redistribute information from another routing protocol
                            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute>`
                            
                            .. attribute:: set_attached_bit
                            
                            	Conditionally advertise us as attached to L2
                            	**type**\:  :py:class:`SetAttachedBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetAttachedBit>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp>`
                            
                            .. attribute:: summary_address
                            
                            	Configure IP address summaries
                            	**type**\: list of  		 :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress>`
                            
                            .. attribute:: traffic_share
                            
                            	How to compute traffic share over alternate paths
                            	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.TrafficShare>`
                            
                            .. attribute:: advertise
                            
                            	Control which IP routes flow in L1 and L2 LSPs
                            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Advertise>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.DefaultInformation>`
                            
                            .. attribute:: help
                            
                            	Description of the interactive help system
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\: int
                            
                            	**range:** 1..32
                            
                            .. attribute:: metric
                            
                            	Set ISIS metric for all interfaces
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Metric>`
                            
                            .. attribute:: prc_interval
                            
                            	Minimum interval between partial route calculations
                            	**type**\:  :py:class:`PrcInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.PrcInterval>`
                            
                            .. attribute:: set_overload_bit
                            
                            	Signal other routers not to use us in SPF
                            	**type**\:  :py:class:`SetOverloadBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: spf_interval
                            
                            	Minimum interval between SPF calculations
                            	**type**\:  :py:class:`SpfInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("distance", ("distance", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance)), ("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip)), ("redistribute", ("redistribute", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute)), ("set-attached-bit", ("set_attached_bit", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetAttachedBit)), ("snmp", ("snmp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp)), ("summary-address", ("summary_address", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress)), ("traffic-share", ("traffic_share", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.TrafficShare)), ("advertise", ("advertise", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Advertise)), ("default-information", ("default_information", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.DefaultInformation)), ("metric", ("metric", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Metric)), ("prc-interval", ("prc_interval", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.PrcInterval)), ("set-overload-bit", ("set_overload_bit", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit)), ("spf-interval", ("spf_interval", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('tid', (YLeaf(YType.uint32, 'tid'), ['int'])),
                                    ('ignore_attached_bit', (YLeaf(YType.empty, 'ignore-attached-bit'), ['Empty'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('help', (YLeaf(YType.empty, 'help'), ['Empty'])),
                                    ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                ])
                                self.name = None
                                self.tid = None
                                self.ignore_attached_bit = None
                                self.priority = None
                                self.help = None
                                self.maximum_paths = None

                                self.ip = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip()
                                self.ip.parent = self
                                self._children_name_map["ip"] = "ip"

                                self.redistribute = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute()
                                self.redistribute.parent = self
                                self._children_name_map["redistribute"] = "redistribute"

                                self.set_attached_bit = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetAttachedBit()
                                self.set_attached_bit.parent = self
                                self._children_name_map["set_attached_bit"] = "set-attached-bit"

                                self.snmp = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp()
                                self.snmp.parent = self
                                self._children_name_map["snmp"] = "snmp"

                                self.traffic_share = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.TrafficShare()
                                self.traffic_share.parent = self
                                self._children_name_map["traffic_share"] = "traffic-share"

                                self.advertise = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Advertise()
                                self.advertise.parent = self
                                self._children_name_map["advertise"] = "advertise"

                                self.default_information = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.metric = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"

                                self.prc_interval = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.PrcInterval()
                                self.prc_interval.parent = self
                                self._children_name_map["prc_interval"] = "prc-interval"

                                self.set_overload_bit = None
                                self._children_name_map["set_overload_bit"] = "set-overload-bit"

                                self.spf_interval = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval()
                                self.spf_interval.parent = self
                                self._children_name_map["spf_interval"] = "spf-interval"

                                self.distance = YList(self)
                                self.summary_address = YList(self)
                                self._segment_path = lambda: "topology" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology, [u'name', u'tid', u'ignore_attached_bit', u'priority', u'help', u'maximum_paths'], name, value)


                            class Distance(Entity):
                                """
                                Define an administrative distance
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: ip_list
                                
                                	
                                	**type**\: list of  		 :py:class:`IpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance.IpList>`
                                
                                .. attribute:: clns
                                
                                	Distance applied for CLNS derived routes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ip
                                
                                	Distance applied for IP derived routes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("ip-list", ("ip_list", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance.IpList))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                        ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                        ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.clns = None
                                    self.ip = None

                                    self.ip_list = YList(self)
                                    self._segment_path = lambda: "distance" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance, [u'number', u'clns', u'ip'], name, value)


                                class IpList(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ip  (key)
                                    
                                    	IP Source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: wildcard_bits
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`WildcardBits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance.IpList.WildcardBits>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance.IpList, self).__init__()

                                        self.yang_name = "ip-list"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip']
                                        self._child_classes = OrderedDict([("wildcard-bits", ("wildcard_bits", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance.IpList.WildcardBits))])
                                        self._leafs = OrderedDict([
                                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                        ])
                                        self.ip = None

                                        self.wildcard_bits = YList(self)
                                        self._segment_path = lambda: "ip-list" + "[ip='" + str(self.ip) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance.IpList, [u'ip'], name, value)


                                    class WildcardBits(Entity):
                                        """
                                        
                                        
                                        .. attribute:: w_bits  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: access_list
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..99
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..1999
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance.IpList.WildcardBits, self).__init__()

                                            self.yang_name = "wildcard-bits"
                                            self.yang_parent_name = "ip-list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['w_bits']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('w_bits', (YLeaf(YType.str, 'w-bits'), ['str'])),
                                                ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                                            ])
                                            self.w_bits = None
                                            self.access_list = None
                                            self._segment_path = lambda: "wildcard-bits" + "[w-bits='" + str(self.w_bits) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Distance.IpList.WildcardBits, [u'w_bits', u'access_list'], name, value)


                            class Ip(Entity):
                                """
                                IP specific commands
                                
                                .. attribute:: route
                                
                                	ISIS IP routes
                                	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip, self).__init__()

                                    self.yang_name = "ip"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("route", ("route", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route))])
                                    self._leafs = OrderedDict()

                                    self.route = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route()
                                    self.route.parent = self
                                    self._children_name_map["route"] = "route"
                                    self._segment_path = lambda: "ip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip, [], name, value)


                                class Route(Entity):
                                    """
                                    ISIS IP routes
                                    
                                    .. attribute:: priority
                                    
                                    	Assign priority to IP prefixes
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route, self).__init__()

                                        self.yang_name = "route"
                                        self.yang_parent_name = "ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority))])
                                        self._leafs = OrderedDict()

                                        self.priority = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route, [], name, value)


                                    class Priority(Entity):
                                        """
                                        Assign priority to IP prefixes
                                        
                                        .. attribute:: high
                                        
                                        	Assign high priority to important IP prefixes in ISIS IP local RIB
                                        	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority.High>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("high", ("high", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority.High))])
                                            self._leafs = OrderedDict()

                                            self.high = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority.High()
                                            self.high.parent = self
                                            self._children_name_map["high"] = "high"
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority, [], name, value)


                                        class High(Entity):
                                            """
                                            Assign high priority to important IP prefixes in ISIS IP local RIB
                                            
                                            .. attribute:: tag
                                            
                                            	Assign high priority to IP prefixes with a specific route tag
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority.High, self).__init__()

                                                self.yang_name = "high"
                                                self.yang_parent_name = "priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ])
                                                self.tag = None
                                                self._segment_path = lambda: "high"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Ip.Route.Priority.High, [u'tag'], name, value)


                            class Redistribute(Entity):
                                """
                                Redistribute information from another routing protocol
                                
                                .. attribute:: application
                                
                                	Application
                                	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application>`
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_>`
                                
                                .. attribute:: iso_igrp
                                
                                	IGRP for OSI networks
                                	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: lisp
                                
                                	Locator ID Separation Protocol (LISP)
                                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes redistributed to protocol
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.MaximumPrefix>`
                                
                                .. attribute:: mobile
                                
                                	Mobile routes
                                	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: odr
                                
                                	On Demand stub Routes
                                	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: vrf
                                
                                	Specify a source VRF
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute, self).__init__()

                                    self.yang_name = "redistribute"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application)), ("bgp", ("bgp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp)), ("connected", ("connected", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected)), ("eigrp", ("eigrp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp)), ("lisp", ("lisp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp)), ("maximum-prefix", ("maximum_prefix", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.MaximumPrefix)), ("mobile", ("mobile", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile)), ("odr", ("odr", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip)), ("static", ("static", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static)), ("vrf", ("vrf", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf))])
                                    self._leafs = OrderedDict()

                                    self.bgp = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.connected = None
                                    self._children_name_map["connected"] = "connected"

                                    self.isis = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_()
                                    self.isis.parent = self
                                    self._children_name_map["isis"] = "isis"

                                    self.iso_igrp = None
                                    self._children_name_map["iso_igrp"] = "iso-igrp"

                                    self.lisp = None
                                    self._children_name_map["lisp"] = "lisp"

                                    self.maximum_prefix = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.mobile = None
                                    self._children_name_map["mobile"] = "mobile"

                                    self.odr = None
                                    self._children_name_map["odr"] = "odr"

                                    self.rip = None
                                    self._children_name_map["rip"] = "rip"

                                    self.static = None
                                    self._children_name_map["static"] = "static"

                                    self.vrf = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.application = YList(self)
                                    self.eigrp = YList(self)
                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "redistribute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute, [], name, value)


                                class Application(Entity):
                                    """
                                    Application
                                    
                                    .. attribute:: name  (key)
                                    
                                    	Application name
                                    	**type**\: str
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application, self).__init__()

                                        self.yang_name = "application"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.name = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Application, [u'name', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Bgp(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: clns
                                    
                                    	Redistribution of BGP NSAP routes
                                    	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ip
                                    
                                    	Redistribution of BGP IP routes
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip))])
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_number = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None

                                        self.clns = None
                                        self._children_name_map["clns"] = "clns"

                                        self.ip = None
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp, [u'as_number', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Clns(Entity):
                                        """
                                        Redistribution of BGP NSAP routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns, self).__init__()

                                            self.yang_name = "clns"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "clns"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Ip(Entity):
                                        """
                                        Redistribution of BGP IP routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Bgp.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: as_number  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['as_number']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint32, 'as-number'), ['int'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_number = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Eigrp, [u'as_number', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Isis_(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: isis_redistribute
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsisRedistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute>`
                                    
                                    .. attribute:: ip
                                    
                                    	Redistribution of IP routes between levels
                                    	**type**\: list of  		 :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isis-redistribute", ("isis_redistribute", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute)), ("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip))])
                                        self._leafs = OrderedDict()

                                        self.isis_redistribute = YList(self)
                                        self.ip = YList(self)
                                        self._segment_path = lambda: "isis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_, [], name, value)


                                    class IsisRedistribute(Entity):
                                        """
                                        
                                        
                                        .. attribute:: area_tag  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP routes between levels or processes
                                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute, self).__init__()

                                            self.yang_name = "isis-redistribute"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['area_tag']
                                            self._child_classes = OrderedDict([("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip))])
                                            self._leafs = OrderedDict([
                                                ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                            ])
                                            self.area_tag = None

                                            self.ip = None
                                            self._children_name_map["ip"] = "ip"
                                            self._segment_path = lambda: "isis-redistribute" + "[area-tag='" + str(self.area_tag) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute, [u'area_tag'], name, value)


                                        class Ip(Entity):
                                            """
                                            Redistribution of IP routes between levels or processes
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip, self).__init__()

                                                self.yang_name = "ip"
                                                self.yang_parent_name = "isis-redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.IsisRedistribute.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Ip(Entity):
                                        """
                                        Redistribution of IP routes between levels
                                        
                                        .. attribute:: isis_redist_levels1  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRedistLevels1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip.IsisRedistLevels1>`
                                        
                                        .. attribute:: isis_redist_levels2  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRedistLevels2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip.IsisRedistLevels2>`
                                        
                                        .. attribute:: into
                                        
                                        	from level\-n into level\-m
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: distribute_list
                                        
                                        	select routes
                                        	**type**\: int
                                        
                                        	**range:** 100..199
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route matching
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['isis_redist_levels1','isis_redist_levels2']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('isis_redist_levels1', (YLeaf(YType.enumeration, 'isis-redist-levels1'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip.IsisRedistLevels1')])),
                                                ('isis_redist_levels2', (YLeaf(YType.enumeration, 'isis-redist-levels2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip.IsisRedistLevels2')])),
                                                ('into', (YLeaf(YType.empty, 'into'), ['Empty'])),
                                                ('distribute_list', (YLeaf(YType.uint32, 'distribute-list'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.isis_redist_levels1 = None
                                            self.isis_redist_levels2 = None
                                            self.into = None
                                            self.distribute_list = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip" + "[isis-redist-levels1='" + str(self.isis_redist_levels1) + "']" + "[isis-redist-levels2='" + str(self.isis_redist_levels2) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Isis_.Ip, [u'isis_redist_levels1', u'isis_redist_levels2', u'into', u'distribute_list', u'route_map'], name, value)

                                        class IsisRedistLevels1(Enum):
                                            """
                                            IsisRedistLevels1 (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")


                                        class IsisRedistLevels2(Enum):
                                            """
                                            IsisRedistLevels2 (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")



                                class IsoIgrp(Entity):
                                    """
                                    IGRP for OSI networks
                                    
                                    .. attribute:: area_tag_route_map_container
                                    
                                    	
                                    	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.AreaTagRouteMapContainer>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.MetricType>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp, self).__init__()

                                        self.yang_name = "iso-igrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.AreaTagRouteMapContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.MetricType')])),
                                        ])
                                        self.route_map = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None

                                        self.area_tag_route_map_container = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.AreaTagRouteMapContainer()
                                        self.area_tag_route_map_container.parent = self
                                        self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"
                                        self._segment_path = lambda: "iso-igrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp, [u'route_map', u'levels', u'metric', u'metric_type'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class AreaTagRouteMapContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: area_tag
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                            self.yang_name = "area-tag-route-map-container"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.area_tag = None
                                            self.route_map = None
                                            self._segment_path = lambda: "area-tag-route-map-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.IsoIgrp.AreaTagRouteMapContainer, [u'area_tag', u'route_map'], name, value)


                                class Lisp(Entity):
                                    """
                                    Locator ID Separation Protocol (LISP)
                                    
                                    .. attribute:: include_connected
                                    
                                    	Include connected
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp, self).__init__()

                                        self.yang_name = "lisp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.include_connected = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "lisp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Lisp, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes redistributed to protocol
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: withdraw
                                    
                                    	Withdraw redistibuted prefixes
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                            ('threshold_value', (YLeaf(YType.uint32, 'threshold-value'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('withdraw', (YLeaf(YType.empty, 'withdraw'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.threshold_value = None
                                        self.warning_only = None
                                        self.withdraw = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.MaximumPrefix, [u'number', u'threshold_value', u'warning_only', u'withdraw'], name, value)


                                class Mobile(Entity):
                                    """
                                    Mobile routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile, self).__init__()

                                        self.yang_name = "mobile"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "mobile"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Odr(Entity):
                                    """
                                    On Demand stub Routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr, self).__init__()

                                        self.yang_name = "odr"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "odr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Odr, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: process_id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: match
                                    
                                    	Redistribution of OSPF routes
                                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VPN Routing/Forwarding Instance
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['process_id']
                                        self._child_classes = OrderedDict([("match", ("match", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match))])
                                        self._leafs = OrderedDict([
                                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.process_id = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self.vrf = None

                                        self.match = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match()
                                        self.match.parent = self
                                        self._children_name_map["match"] = "match"
                                        self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf, [u'process_id', u'levels', u'metric', u'metric_type', u'route_map', u'vrf'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Match(Entity):
                                        """
                                        Redistribution of OSPF routes
                                        
                                        .. attribute:: internal
                                        
                                        	Redistribute OSPF internal routes
                                        	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: external
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: nssa_external
                                        
                                        	Redistribute OSPF NSSA external routes
                                        	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match, self).__init__()

                                            self.yang_name = "match"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("internal", ("internal", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal))])
                                            self._leafs = OrderedDict()

                                            self.internal = None
                                            self._children_name_map["internal"] = "internal"

                                            self.external = None
                                            self._children_name_map["external"] = "external"

                                            self.nssa_external = None
                                            self._children_name_map["nssa_external"] = "nssa-external"
                                            self._segment_path = lambda: "match"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match, [], name, value)


                                        class Internal(Entity):
                                            """
                                            Redistribute OSPF internal routes
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal, self).__init__()

                                                self.yang_name = "internal"
                                                self.yang_parent_name = "match"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "internal"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.Internal, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class External(Entity):
                                            """
                                            Redistribute OSPF external routes
                                            
                                            .. attribute:: external_routes
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External, self).__init__()

                                                self.yang_name = "external"
                                                self.yang_parent_name = "match"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.external_routes = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.External, [u'external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class NssaExternal(Entity):
                                            """
                                            Redistribute OSPF NSSA external routes
                                            
                                            .. attribute:: nssa_external_routes
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                                self.yang_name = "nssa-external"
                                                self.yang_parent_name = "match"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.nssa_external_routes = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "nssa-external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospf.Match.NssaExternal, [u'nssa_external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Ospfv3(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: process_id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: match
                                    
                                    	Redistribution of OSPF routes
                                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VPN Routing/Forwarding Instance
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['process_id']
                                        self._child_classes = OrderedDict([("match", ("match", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match))])
                                        self._leafs = OrderedDict([
                                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.process_id = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self.vrf = None

                                        self.match = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match()
                                        self.match.parent = self
                                        self._children_name_map["match"] = "match"
                                        self._segment_path = lambda: "ospfv3" + "[process-id='" + str(self.process_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3, [u'process_id', u'levels', u'metric', u'metric_type', u'route_map', u'vrf'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Match(Entity):
                                        """
                                        Redistribution of OSPF routes
                                        
                                        .. attribute:: internal
                                        
                                        	Redistribute OSPF internal routes
                                        	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: external
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: nssa_external
                                        
                                        	Redistribute OSPF NSSA external routes
                                        	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match, self).__init__()

                                            self.yang_name = "match"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("internal", ("internal", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal)), ("external", ("external", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External)), ("nssa-external", ("nssa_external", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal))])
                                            self._leafs = OrderedDict()

                                            self.internal = None
                                            self._children_name_map["internal"] = "internal"

                                            self.external = None
                                            self._children_name_map["external"] = "external"

                                            self.nssa_external = None
                                            self._children_name_map["nssa_external"] = "nssa-external"
                                            self._segment_path = lambda: "match"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match, [], name, value)


                                        class Internal(Entity):
                                            """
                                            Redistribute OSPF internal routes
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal, self).__init__()

                                                self.yang_name = "internal"
                                                self.yang_parent_name = "match"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "internal"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.Internal, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class External(Entity):
                                            """
                                            Redistribute OSPF external routes
                                            
                                            .. attribute:: external_routes
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External, self).__init__()

                                                self.yang_name = "external"
                                                self.yang_parent_name = "match"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.external_routes = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.External, [u'external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class NssaExternal(Entity):
                                            """
                                            Redistribute OSPF NSSA external routes
                                            
                                            .. attribute:: nssa_external_routes
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal, self).__init__()

                                                self.yang_name = "nssa-external"
                                                self.yang_parent_name = "match"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.nssa_external_routes = None
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "nssa-external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Ospfv3.Match.NssaExternal, [u'nssa_external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: clns
                                    
                                    	Redistribution of BGP NSAP routes
                                    	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ip
                                    
                                    	Redistribution of BGP IP routes
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.clns = None
                                        self._children_name_map["clns"] = "clns"

                                        self.ip = None
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static, [], name, value)


                                    class Clns(Entity):
                                        """
                                        Redistribution of BGP NSAP routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns, self).__init__()

                                            self.yang_name = "clns"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "clns"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Ip(Entity):
                                        """
                                        Redistribution of BGP IP routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Vrf(Entity):
                                    """
                                    Specify a source VRF
                                    
                                    .. attribute:: vrf_nm
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`VrfNm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm>`
                                    
                                    .. attribute:: global_
                                    
                                    	global VRF
                                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf-nm", ("vrf_nm", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm)), ("global", ("global_", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global))])
                                        self._leafs = OrderedDict()

                                        self.global_ = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"

                                        self.vrf_nm = YList(self)
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf, [], name, value)


                                    class VrfNm(Entity):
                                        """
                                        
                                        
                                        .. attribute:: vrf_nm  (key)
                                        
                                        	Source VRF name
                                        	**type**\: str
                                        
                                        .. attribute:: application
                                        
                                        	Application
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_>`
                                        
                                        .. attribute:: iso_igrp
                                        
                                        	IGRP for OSI networks
                                        	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator ID Separation Protocol (LISP)
                                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile routes
                                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Process ID
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: ospfv3
                                        
                                        	OSPFv3
                                        	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm, self).__init__()

                                            self.yang_name = "vrf-nm"
                                            self.yang_parent_name = "vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['vrf_nm']
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application)), ("bgp", ("bgp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp)), ("connected", ("connected", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected)), ("eigrp", ("eigrp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp)), ("isis", ("isis", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp)), ("lisp", ("lisp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp)), ("mobile", ("mobile", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile)), ("ospfv3", ("ospfv3", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3)), ("rip", ("rip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip)), ("static", ("static", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static))])
                                            self._leafs = OrderedDict([
                                                ('vrf_nm', (YLeaf(YType.str, 'vrf-nm'), ['str'])),
                                                ('ospf', (YLeaf(YType.uint16, 'ospf'), ['int'])),
                                            ])
                                            self.vrf_nm = None
                                            self.ospf = None

                                            self.application = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.bgp = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.eigrp = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"

                                            self.isis = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.iso_igrp = None
                                            self._children_name_map["iso_igrp"] = "iso-igrp"

                                            self.lisp = None
                                            self._children_name_map["lisp"] = "lisp"

                                            self.mobile = None
                                            self._children_name_map["mobile"] = "mobile"

                                            self.ospfv3 = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3()
                                            self.ospfv3.parent = self
                                            self._children_name_map["ospfv3"] = "ospfv3"

                                            self.rip = None
                                            self._children_name_map["rip"] = "rip"

                                            self.static = None
                                            self._children_name_map["static"] = "static"
                                            self._segment_path = lambda: "vrf-nm" + "[vrf-nm='" + str(self.vrf_nm) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm, [u'vrf_nm', u'ospf'], name, value)


                                        class Application(Entity):
                                            """
                                            Application
                                            
                                            .. attribute:: appname
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Appname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "vrf-nm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("appname", ("appname", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname))])
                                                self._leafs = OrderedDict()

                                                self.appname = YList(self)
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application, [], name, value)


                                            class Appname(Entity):
                                                """
                                                
                                                
                                                .. attribute:: appname  (key)
                                                
                                                	Application name
                                                	**type**\: str
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname, self).__init__()

                                                    self.yang_name = "appname"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['appname']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('appname', (YLeaf(YType.str, 'appname'), ['str'])),
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.appname = None
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "appname" + "[appname='" + str(self.appname) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Application.Appname, [u'appname', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: bp_as_num
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BpAsNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum>`
                                            
                                            .. attribute:: a_lesser_1_period_0_xx_period_yy_greater_
                                            
                                            	Autonomous system number
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "vrf-nm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bp-as-num", ("bp_as_num", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum))])
                                                self._leafs = OrderedDict([
                                                    ('a_lesser_1_period_0_xx_period_yy_greater_', (YLeaf(YType.empty, 'a_LESSER_1_PERIOD_0-XX_PERIOD_YY_GREATER_'), ['Empty'])),
                                                ])
                                                self.a_lesser_1_period_0_xx_period_yy_greater_ = None

                                                self.bp_as_num = YList(self)
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp, [u'a_lesser_1_period_0_xx_period_yy_greater_'], name, value)


                                            class BpAsNum(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bp_as_num  (key)
                                                
                                                	Autonomous system number
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: clns
                                                
                                                	Redistribution of BGP NSAP routes
                                                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of BGP IP routes
                                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum, self).__init__()

                                                    self.yang_name = "bp-as-num"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bp_as_num']
                                                    self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip))])
                                                    self._leafs = OrderedDict([
                                                        ('bp_as_num', (YLeaf(YType.str, 'bp-as-num'), ['int','str'])),
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bp_as_num = None
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None

                                                    self.clns = None
                                                    self._children_name_map["clns"] = "clns"

                                                    self.ip = None
                                                    self._children_name_map["ip"] = "ip"
                                                    self._segment_path = lambda: "bp-as-num" + "[bp-as-num='" + str(self.bp_as_num) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum, [u'bp_as_num', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                                class Clns(Entity):
                                                    """
                                                    Redistribution of BGP NSAP routes
                                                    
                                                    .. attribute:: levels
                                                    
                                                    	
                                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	ISIS default metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: metric_type
                                                    
                                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns.MetricType>`
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map reference
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-isis'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns, self).__init__()

                                                        self.yang_name = "clns"
                                                        self.yang_parent_name = "bp-as-num"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns.MetricType')])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.levels = None
                                                        self.metric = None
                                                        self.metric_type = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "clns"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                    class MetricType(Enum):
                                                        """
                                                        MetricType (Enum Class)

                                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                                        .. data:: external = 0

                                                        .. data:: internal = 1

                                                        .. data:: rib_metric_as_external = 2

                                                        .. data:: rib_metric_as_internal = 3

                                                        """

                                                        external = Enum.YLeaf(0, "external")

                                                        internal = Enum.YLeaf(1, "internal")

                                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                                class Ip(Entity):
                                                    """
                                                    Redistribution of BGP IP routes
                                                    
                                                    .. attribute:: levels
                                                    
                                                    	
                                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	ISIS default metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: metric_type
                                                    
                                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip.MetricType>`
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map reference
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-isis'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip, self).__init__()

                                                        self.yang_name = "ip"
                                                        self.yang_parent_name = "bp-as-num"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip.MetricType')])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.levels = None
                                                        self.metric = None
                                                        self.metric_type = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                    class MetricType(Enum):
                                                        """
                                                        MetricType (Enum Class)

                                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                                        .. data:: external = 0

                                                        .. data:: internal = 1

                                                        .. data:: rib_metric_as_external = 2

                                                        .. data:: rib_metric_as_internal = 3

                                                        """

                                                        external = Enum.YLeaf(0, "external")

                                                        internal = Enum.YLeaf(1, "internal")

                                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "vrf-nm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: eigrp_as
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "vrf-nm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eigrp-as", ("eigrp_as", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs))])
                                                self._leafs = OrderedDict()

                                                self.eigrp_as = YList(self)
                                                self._segment_path = lambda: "eigrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp, [], name, value)


                                            class EigrpAs(Entity):
                                                """
                                                
                                                
                                                .. attribute:: eigrp_as  (key)
                                                
                                                	AS number
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs, self).__init__()

                                                    self.yang_name = "eigrp-as"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eigrp_as']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('eigrp_as', (YLeaf(YType.uint16, 'eigrp-as'), ['int'])),
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.eigrp_as = None
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-as" + "[eigrp-as='" + str(self.eigrp_as) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs, [u'eigrp_as', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Isis_(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: isis_atag
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsisAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag>`
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP routes between levels or processes
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "vrf-nm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("isis-atag", ("isis_atag", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag)), ("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip))])
                                                self._leafs = OrderedDict()

                                                self.ip = None
                                                self._children_name_map["ip"] = "ip"

                                                self.isis_atag = YList(self)
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_, [], name, value)


                                            class IsisAtag(Entity):
                                                """
                                                
                                                
                                                .. attribute:: isis_atag  (key)
                                                
                                                	ISO routing area tag
                                                	**type**\: str
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of IP routes between levels or processes
                                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip>`
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag, self).__init__()

                                                    self.yang_name = "isis-atag"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['isis_atag']
                                                    self._child_classes = OrderedDict([("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip))])
                                                    self._leafs = OrderedDict([
                                                        ('isis_atag', (YLeaf(YType.str, 'isis-atag'), ['str'])),
                                                    ])
                                                    self.isis_atag = None

                                                    self.ip = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip()
                                                    self.ip.parent = self
                                                    self._children_name_map["ip"] = "ip"
                                                    self._segment_path = lambda: "isis-atag" + "[isis-atag='" + str(self.isis_atag) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag, [u'isis_atag'], name, value)


                                                class Ip(Entity):
                                                    """
                                                    Redistribution of IP routes between levels or processes
                                                    
                                                    .. attribute:: levels
                                                    
                                                    	
                                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	ISIS default metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: metric_type
                                                    
                                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip.MetricType>`
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map reference
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-isis'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip, self).__init__()

                                                        self.yang_name = "ip"
                                                        self.yang_parent_name = "isis-atag"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip.MetricType')])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.levels = None
                                                        self.metric = None
                                                        self.metric_type = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                    class MetricType(Enum):
                                                        """
                                                        MetricType (Enum Class)

                                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                                        .. data:: external = 0

                                                        .. data:: internal = 1

                                                        .. data:: rib_metric_as_external = 2

                                                        .. data:: rib_metric_as_internal = 3

                                                        """

                                                        external = Enum.YLeaf(0, "external")

                                                        internal = Enum.YLeaf(1, "internal")

                                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                            class Ip(Entity):
                                                """
                                                Redistribution of IP routes between levels or processes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Isis_.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class IsoIgrp(Entity):
                                            """
                                            IGRP for OSI networks
                                            
                                            .. attribute:: iso_atag
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsoAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp, self).__init__()

                                                self.yang_name = "iso-igrp"
                                                self.yang_parent_name = "vrf-nm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("iso-atag", ("iso_atag", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag)), ("route-map", ("route_map", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.route_map = None
                                                self._children_name_map["route_map"] = "route-map"

                                                self.iso_atag = YList(self)
                                                self._segment_path = lambda: "iso-igrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp, [], name, value)


                                            class IsoAtag(Entity):
                                                """
                                                
                                                
                                                .. attribute:: iso_atag  (key)
                                                
                                                	ISO routing area tag
                                                	**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag, self).__init__()

                                                    self.yang_name = "iso-atag"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['iso_atag']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('iso_atag', (YLeaf(YType.str, 'iso-atag'), ['str'])),
                                                        ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                                    ])
                                                    self.iso_atag = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "iso-atag" + "[iso-atag='" + str(self.iso_atag) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag, [u'iso_atag', u'route_map'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Route map reference
                                                
                                                .. attribute:: rm_point
                                                
                                                	Pointer to route\-map entries
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('rm_point', (YLeaf(YType.str, 'rm-point'), ['str'])),
                                                    ])
                                                    self.rm_point = None
                                                    self._segment_path = lambda: "route-map"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap, [u'rm_point'], name, value)


                                        class Lisp(Entity):
                                            """
                                            Locator ID Separation Protocol (LISP)
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp, self).__init__()

                                                self.yang_name = "lisp"
                                                self.yang_parent_name = "vrf-nm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "lisp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Lisp, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Mobile(Entity):
                                            """
                                            Mobile routes
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "vrf-nm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "mobile"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Ospfv3(Entity):
                                            """
                                            OSPFv3
                                            
                                            .. attribute:: os3_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Os3Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3, self).__init__()

                                                self.yang_name = "ospfv3"
                                                self.yang_parent_name = "vrf-nm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("os3-id", ("os3_id", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id))])
                                                self._leafs = OrderedDict()

                                                self.os3_id = YList(self)
                                                self._segment_path = lambda: "ospfv3"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3, [], name, value)


                                            class Os3Id(Entity):
                                                """
                                                
                                                
                                                .. attribute:: os3_id  (key)
                                                
                                                	Process ID
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id, self).__init__()

                                                    self.yang_name = "os3-id"
                                                    self.yang_parent_name = "ospfv3"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['os3_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('os3_id', (YLeaf(YType.uint16, 'os3-id'), ['int'])),
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.os3_id = None
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "os3-id" + "[os3-id='" + str(self.os3_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id, [u'os3_id', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "vrf-nm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of BGP NSAP routes
                                            	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of BGP IP routes
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "vrf-nm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None

                                                self.clns = None
                                                self._children_name_map["clns"] = "clns"

                                                self.ip = None
                                                self._children_name_map["ip"] = "ip"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                            class Clns(Entity):
                                                """
                                                Redistribution of BGP NSAP routes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns, self).__init__()

                                                    self.yang_name = "clns"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "clns"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                            class Ip(Entity):
                                                """
                                                Redistribution of BGP IP routes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.VrfNm.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Global(Entity):
                                        """
                                        global VRF
                                        
                                        .. attribute:: application
                                        
                                        	Application
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_>`
                                        
                                        .. attribute:: iso_igrp
                                        
                                        	IGRP for OSI networks
                                        	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator ID Separation Protocol (LISP)
                                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile routes
                                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Process ID
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: ospfv3
                                        
                                        	OSPFv3
                                        	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application)), ("bgp", ("bgp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp)), ("connected", ("connected", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected)), ("eigrp", ("eigrp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp)), ("isis", ("isis", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp)), ("lisp", ("lisp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp)), ("mobile", ("mobile", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile)), ("ospfv3", ("ospfv3", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3)), ("rip", ("rip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip)), ("static", ("static", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static))])
                                            self._leafs = OrderedDict([
                                                ('ospf', (YLeaf(YType.uint16, 'ospf'), ['int'])),
                                            ])
                                            self.ospf = None

                                            self.application = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.bgp = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.eigrp = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"

                                            self.isis = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.iso_igrp = None
                                            self._children_name_map["iso_igrp"] = "iso-igrp"

                                            self.lisp = None
                                            self._children_name_map["lisp"] = "lisp"

                                            self.mobile = None
                                            self._children_name_map["mobile"] = "mobile"

                                            self.ospfv3 = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3()
                                            self.ospfv3.parent = self
                                            self._children_name_map["ospfv3"] = "ospfv3"

                                            self.rip = None
                                            self._children_name_map["rip"] = "rip"

                                            self.static = None
                                            self._children_name_map["static"] = "static"
                                            self._segment_path = lambda: "global"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global, [u'ospf'], name, value)


                                        class Application(Entity):
                                            """
                                            Application
                                            
                                            .. attribute:: appname
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Appname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("appname", ("appname", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname))])
                                                self._leafs = OrderedDict()

                                                self.appname = YList(self)
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application, [], name, value)


                                            class Appname(Entity):
                                                """
                                                
                                                
                                                .. attribute:: appname  (key)
                                                
                                                	Application name
                                                	**type**\: str
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname, self).__init__()

                                                    self.yang_name = "appname"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['appname']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('appname', (YLeaf(YType.str, 'appname'), ['str'])),
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.appname = None
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "appname" + "[appname='" + str(self.appname) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Application.Appname, [u'appname', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: bp_as_num
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BpAsNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum>`
                                            
                                            .. attribute:: a_lesser_1_period_0_xx_period_yy_greater_
                                            
                                            	Autonomous system number
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bp-as-num", ("bp_as_num", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum))])
                                                self._leafs = OrderedDict([
                                                    ('a_lesser_1_period_0_xx_period_yy_greater_', (YLeaf(YType.empty, 'a_LESSER_1_PERIOD_0-XX_PERIOD_YY_GREATER_'), ['Empty'])),
                                                ])
                                                self.a_lesser_1_period_0_xx_period_yy_greater_ = None

                                                self.bp_as_num = YList(self)
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp, [u'a_lesser_1_period_0_xx_period_yy_greater_'], name, value)


                                            class BpAsNum(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bp_as_num  (key)
                                                
                                                	Autonomous system number
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: clns
                                                
                                                	Redistribution of BGP NSAP routes
                                                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of BGP IP routes
                                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum, self).__init__()

                                                    self.yang_name = "bp-as-num"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bp_as_num']
                                                    self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip))])
                                                    self._leafs = OrderedDict([
                                                        ('bp_as_num', (YLeaf(YType.str, 'bp-as-num'), ['int','str'])),
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bp_as_num = None
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None

                                                    self.clns = None
                                                    self._children_name_map["clns"] = "clns"

                                                    self.ip = None
                                                    self._children_name_map["ip"] = "ip"
                                                    self._segment_path = lambda: "bp-as-num" + "[bp-as-num='" + str(self.bp_as_num) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum, [u'bp_as_num', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                                class Clns(Entity):
                                                    """
                                                    Redistribution of BGP NSAP routes
                                                    
                                                    .. attribute:: levels
                                                    
                                                    	
                                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	ISIS default metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: metric_type
                                                    
                                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns.MetricType>`
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map reference
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-isis'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns, self).__init__()

                                                        self.yang_name = "clns"
                                                        self.yang_parent_name = "bp-as-num"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns.MetricType')])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.levels = None
                                                        self.metric = None
                                                        self.metric_type = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "clns"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                    class MetricType(Enum):
                                                        """
                                                        MetricType (Enum Class)

                                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                                        .. data:: external = 0

                                                        .. data:: internal = 1

                                                        .. data:: rib_metric_as_external = 2

                                                        .. data:: rib_metric_as_internal = 3

                                                        """

                                                        external = Enum.YLeaf(0, "external")

                                                        internal = Enum.YLeaf(1, "internal")

                                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                                class Ip(Entity):
                                                    """
                                                    Redistribution of BGP IP routes
                                                    
                                                    .. attribute:: levels
                                                    
                                                    	
                                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	ISIS default metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: metric_type
                                                    
                                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip.MetricType>`
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map reference
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-isis'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip, self).__init__()

                                                        self.yang_name = "ip"
                                                        self.yang_parent_name = "bp-as-num"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip.MetricType')])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.levels = None
                                                        self.metric = None
                                                        self.metric_type = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                    class MetricType(Enum):
                                                        """
                                                        MetricType (Enum Class)

                                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                                        .. data:: external = 0

                                                        .. data:: internal = 1

                                                        .. data:: rib_metric_as_external = 2

                                                        .. data:: rib_metric_as_internal = 3

                                                        """

                                                        external = Enum.YLeaf(0, "external")

                                                        internal = Enum.YLeaf(1, "internal")

                                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: eigrp_as
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eigrp-as", ("eigrp_as", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs))])
                                                self._leafs = OrderedDict()

                                                self.eigrp_as = YList(self)
                                                self._segment_path = lambda: "eigrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp, [], name, value)


                                            class EigrpAs(Entity):
                                                """
                                                
                                                
                                                .. attribute:: eigrp_as  (key)
                                                
                                                	AS number
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs, self).__init__()

                                                    self.yang_name = "eigrp-as"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eigrp_as']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('eigrp_as', (YLeaf(YType.uint16, 'eigrp-as'), ['int'])),
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.eigrp_as = None
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-as" + "[eigrp-as='" + str(self.eigrp_as) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Eigrp.EigrpAs, [u'eigrp_as', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Isis_(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: isis_atag
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsisAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag>`
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP routes between levels or processes
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("isis-atag", ("isis_atag", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag)), ("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip))])
                                                self._leafs = OrderedDict()

                                                self.ip = None
                                                self._children_name_map["ip"] = "ip"

                                                self.isis_atag = YList(self)
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_, [], name, value)


                                            class IsisAtag(Entity):
                                                """
                                                
                                                
                                                .. attribute:: isis_atag  (key)
                                                
                                                	ISO routing area tag
                                                	**type**\: str
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of IP routes between levels or processes
                                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip>`
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag, self).__init__()

                                                    self.yang_name = "isis-atag"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['isis_atag']
                                                    self._child_classes = OrderedDict([("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip))])
                                                    self._leafs = OrderedDict([
                                                        ('isis_atag', (YLeaf(YType.str, 'isis-atag'), ['str'])),
                                                    ])
                                                    self.isis_atag = None

                                                    self.ip = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip()
                                                    self.ip.parent = self
                                                    self._children_name_map["ip"] = "ip"
                                                    self._segment_path = lambda: "isis-atag" + "[isis-atag='" + str(self.isis_atag) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag, [u'isis_atag'], name, value)


                                                class Ip(Entity):
                                                    """
                                                    Redistribution of IP routes between levels or processes
                                                    
                                                    .. attribute:: levels
                                                    
                                                    	
                                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	ISIS default metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: metric_type
                                                    
                                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip.MetricType>`
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map reference
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-isis'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip, self).__init__()

                                                        self.yang_name = "ip"
                                                        self.yang_parent_name = "isis-atag"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip.MetricType')])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.levels = None
                                                        self.metric = None
                                                        self.metric_type = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                    class MetricType(Enum):
                                                        """
                                                        MetricType (Enum Class)

                                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                                        .. data:: external = 0

                                                        .. data:: internal = 1

                                                        .. data:: rib_metric_as_external = 2

                                                        .. data:: rib_metric_as_internal = 3

                                                        """

                                                        external = Enum.YLeaf(0, "external")

                                                        internal = Enum.YLeaf(1, "internal")

                                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                            class Ip(Entity):
                                                """
                                                Redistribution of IP routes between levels or processes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Isis_.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class IsoIgrp(Entity):
                                            """
                                            IGRP for OSI networks
                                            
                                            .. attribute:: iso_atag
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsoAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.IsoAtag>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.RouteMap>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp, self).__init__()

                                                self.yang_name = "iso-igrp"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("iso-atag", ("iso_atag", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.IsoAtag)), ("route-map", ("route_map", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.RouteMap))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.route_map = None
                                                self._children_name_map["route_map"] = "route-map"

                                                self.iso_atag = YList(self)
                                                self._segment_path = lambda: "iso-igrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp, [], name, value)


                                            class IsoAtag(Entity):
                                                """
                                                
                                                
                                                .. attribute:: iso_atag  (key)
                                                
                                                	ISO routing area tag
                                                	**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.IsoAtag, self).__init__()

                                                    self.yang_name = "iso-atag"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['iso_atag']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('iso_atag', (YLeaf(YType.str, 'iso-atag'), ['str'])),
                                                        ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                                    ])
                                                    self.iso_atag = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "iso-atag" + "[iso-atag='" + str(self.iso_atag) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.IsoAtag, [u'iso_atag', u'route_map'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Route map reference
                                                
                                                .. attribute:: rm_point
                                                
                                                	Pointer to route\-map entries
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('rm_point', (YLeaf(YType.str, 'rm-point'), ['str'])),
                                                    ])
                                                    self.rm_point = None
                                                    self._segment_path = lambda: "route-map"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.IsoIgrp.RouteMap, [u'rm_point'], name, value)


                                        class Lisp(Entity):
                                            """
                                            Locator ID Separation Protocol (LISP)
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp, self).__init__()

                                                self.yang_name = "lisp"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "lisp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Lisp, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Mobile(Entity):
                                            """
                                            Mobile routes
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "mobile"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Ospfv3(Entity):
                                            """
                                            OSPFv3
                                            
                                            .. attribute:: os3_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Os3Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3, self).__init__()

                                                self.yang_name = "ospfv3"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("os3-id", ("os3_id", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id))])
                                                self._leafs = OrderedDict()

                                                self.os3_id = YList(self)
                                                self._segment_path = lambda: "ospfv3"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3, [], name, value)


                                            class Os3Id(Entity):
                                                """
                                                
                                                
                                                .. attribute:: os3_id  (key)
                                                
                                                	Process ID
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id, self).__init__()

                                                    self.yang_name = "os3-id"
                                                    self.yang_parent_name = "ospfv3"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['os3_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('os3_id', (YLeaf(YType.uint16, 'os3-id'), ['int'])),
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.os3_id = None
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "os3-id" + "[os3-id='" + str(self.os3_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Ospfv3.Os3Id, [u'os3_id', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of BGP NSAP routes
                                            	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of BGP IP routes
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: levels
                                            
                                            	
                                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                            
                                            .. attribute:: metric
                                            
                                            	ISIS default metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.MetricType>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.MetricType')])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.levels = None
                                                self.metric = None
                                                self.metric_type = None
                                                self.route_map = None

                                                self.clns = None
                                                self._children_name_map["clns"] = "clns"

                                                self.ip = None
                                                self._children_name_map["ip"] = "ip"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: external = 0

                                                .. data:: internal = 1

                                                .. data:: rib_metric_as_external = 2

                                                .. data:: rib_metric_as_internal = 3

                                                """

                                                external = Enum.YLeaf(0, "external")

                                                internal = Enum.YLeaf(1, "internal")

                                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                            class Clns(Entity):
                                                """
                                                Redistribution of BGP NSAP routes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns, self).__init__()

                                                    self.yang_name = "clns"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "clns"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                            class Ip(Entity):
                                                """
                                                Redistribution of BGP IP routes
                                                
                                                .. attribute:: levels
                                                
                                                	
                                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS default metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip.MetricType>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip.MetricType')])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.levels = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Redistribute.Vrf.Global.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: external = 0

                                                    .. data:: internal = 1

                                                    .. data:: rib_metric_as_external = 2

                                                    .. data:: rib_metric_as_internal = 3

                                                    """

                                                    external = Enum.YLeaf(0, "external")

                                                    internal = Enum.YLeaf(1, "internal")

                                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class SetAttachedBit(Entity):
                                """
                                Conditionally advertise us as attached to L2
                                
                                .. attribute:: route_map
                                
                                	Route\-map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetAttachedBit, self).__init__()

                                    self.yang_name = "set-attached-bit"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "set-attached-bit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetAttachedBit, [u'route_map'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context))])
                                    self._leafs = OrderedDict()

                                    self.context = YList(self)
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: name  (key)
                                    
                                    	Context Name
                                    	**type**\: str
                                    
                                    .. attribute:: community
                                    
                                    	Configure a SNMP v2c Community string and access privs
                                    	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community>`
                                    
                                    .. attribute:: user
                                    
                                    	Configure a SNMP v3 user
                                    	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("community", ("community", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community)), ("user", ("user", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.community = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community()
                                        self.community.parent = self
                                        self._children_name_map["community"] = "community"

                                        self.user = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User()
                                        self.user.parent = self
                                        self._children_name_map["user"] = "user"
                                        self._segment_path = lambda: "context" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context, [u'name'], name, value)


                                    class Community(Entity):
                                        """
                                        Configure a SNMP v2c Community string and access privs
                                        
                                        .. attribute:: community_string
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: access
                                        
                                        	
                                        	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community.Access>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community, self).__init__()

                                            self.yang_name = "community"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("access", ("access", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community.Access))])
                                            self._leafs = OrderedDict([
                                                ('community_string', (YLeaf(YType.str, 'community-string'), ['str'])),
                                            ])
                                            self.community_string = None

                                            self.access = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community.Access()
                                            self.access.parent = self
                                            self._children_name_map["access"] = "access"
                                            self._segment_path = lambda: "community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community, [u'community_string'], name, value)


                                        class Access(Entity):
                                            """
                                            
                                            
                                            .. attribute:: standard_acl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..99
                                            
                                            .. attribute:: expanded_acl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1300..1999
                                            
                                            .. attribute:: acl_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	Specify IPv6 Named Access\-List
                                            	**type**\: str
                                            
                                            .. attribute:: ro
                                            
                                            	Read\-only access with this community string
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: rw
                                            
                                            	Read\-write access with this community string
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community.Access, self).__init__()

                                                self.yang_name = "access"
                                                self.yang_parent_name = "community"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                    ('expanded_acl', (YLeaf(YType.uint32, 'expanded-acl'), ['int'])),
                                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ('ro', (YLeaf(YType.empty, 'ro'), ['Empty'])),
                                                    ('rw', (YLeaf(YType.empty, 'rw'), ['Empty'])),
                                                ])
                                                self.standard_acl = None
                                                self.expanded_acl = None
                                                self.acl_name = None
                                                self.ipv6 = None
                                                self.ro = None
                                                self.rw = None
                                                self._segment_path = lambda: "access"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.Community.Access, [u'standard_acl', u'expanded_acl', u'acl_name', u'ipv6', u'ro', u'rw'], name, value)


                                    class User(Entity):
                                        """
                                        Configure a SNMP v3 user
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: permisssion
                                        
                                        	
                                        	**type**\:  :py:class:`Permisssion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User, self).__init__()

                                            self.yang_name = "user"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("permisssion", ("permisssion", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.permisssion = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion()
                                            self.permisssion.parent = self
                                            self._children_name_map["permisssion"] = "permisssion"
                                            self._segment_path = lambda: "user"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User, [u'name'], name, value)


                                        class Permisssion(Entity):
                                            """
                                            
                                            
                                            .. attribute:: access
                                            
                                            	specify an access\-list associated with this group
                                            	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Access>`
                                            
                                            .. attribute:: auth
                                            
                                            	authentication parameters for the user
                                            	**type**\:  :py:class:`Auth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Auth>`
                                            
                                            .. attribute:: credential
                                            
                                            	If the user password is already configured and saved
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: encrypted
                                            
                                            	specifying passwords as MD5 or SHA digests
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion, self).__init__()

                                                self.yang_name = "permisssion"
                                                self.yang_parent_name = "user"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("access", ("access", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Access)), ("auth", ("auth", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Auth))])
                                                self._leafs = OrderedDict([
                                                    ('credential', (YLeaf(YType.empty, 'credential'), ['Empty'])),
                                                    ('encrypted', (YLeaf(YType.empty, 'encrypted'), ['Empty'])),
                                                ])
                                                self.credential = None
                                                self.encrypted = None

                                                self.access = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Access()
                                                self.access.parent = self
                                                self._children_name_map["access"] = "access"

                                                self.auth = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Auth()
                                                self.auth.parent = self
                                                self._children_name_map["auth"] = "auth"
                                                self._segment_path = lambda: "permisssion"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion, [u'credential', u'encrypted'], name, value)


                                            class Access(Entity):
                                                """
                                                specify an access\-list associated with this group
                                                
                                                .. attribute:: standard_acl
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: acl_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Access, self).__init__()

                                                    self.yang_name = "access"
                                                    self.yang_parent_name = "permisssion"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.standard_acl = None
                                                    self.acl_name = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "access"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Access, [u'standard_acl', u'acl_name', u'ipv6'], name, value)


                                            class Auth(Entity):
                                                """
                                                authentication parameters for the user
                                                
                                                .. attribute:: md5
                                                
                                                	Use HMAC MD5 algorithm for authentication
                                                	**type**\: str
                                                
                                                .. attribute:: sha
                                                
                                                	Use HMAC SHA algorithm for authentication
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-isis'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Auth, self).__init__()

                                                    self.yang_name = "auth"
                                                    self.yang_parent_name = "permisssion"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('md5', (YLeaf(YType.str, 'md5'), ['str'])),
                                                        ('sha', (YLeaf(YType.str, 'sha'), ['str'])),
                                                    ])
                                                    self.md5 = None
                                                    self.sha = None
                                                    self._segment_path = lambda: "auth"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Snmp.Context.User.Permisssion.Auth, [u'md5', u'sha'], name, value)


                            class SummaryAddress(Entity):
                                """
                                Configure IP address summaries
                                
                                .. attribute:: ip  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: level_1
                                
                                	Summarize into level\-1 area
                                	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level1>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: level_1_2
                                
                                	Summarize into both area and sub\-domain
                                	**type**\:  :py:class:`Level12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level12>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: level_2
                                
                                	Summarize into level\-2 sub\-domain
                                	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level2>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: metric_tag_container
                                
                                	
                                	**type**\:  :py:class:`MetricTagContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.MetricTagContainer>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress, self).__init__()

                                    self.yang_name = "summary-address"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip','mask']
                                    self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level1)), ("level-1-2", ("level_1_2", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level12)), ("level-2", ("level_2", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level2)), ("metric-tag-container", ("metric_tag_container", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.MetricTagContainer))])
                                    self._leafs = OrderedDict([
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                        ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ])
                                    self.ip = None
                                    self.mask = None

                                    self.level_1 = None
                                    self._children_name_map["level_1"] = "level-1"

                                    self.level_1_2 = None
                                    self._children_name_map["level_1_2"] = "level-1-2"

                                    self.level_2 = None
                                    self._children_name_map["level_2"] = "level-2"

                                    self.metric_tag_container = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.MetricTagContainer()
                                    self.metric_tag_container.parent = self
                                    self._children_name_map["metric_tag_container"] = "metric-tag-container"
                                    self._segment_path = lambda: "summary-address" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress, [u'ip', u'mask'], name, value)


                                class Level1(Entity):
                                    """
                                    Summarize into level\-1 area
                                    
                                    .. attribute:: metric
                                    
                                    	Set metric for summay route
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level1, self).__init__()

                                        self.yang_name = "level-1"
                                        self.yang_parent_name = "summary-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.metric = None
                                        self.tag = None
                                        self._segment_path = lambda: "level-1"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level1, [u'metric', u'tag'], name, value)


                                class Level12(Entity):
                                    """
                                    Summarize into both area and sub\-domain
                                    
                                    .. attribute:: metric
                                    
                                    	Set metric for summay route
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level12, self).__init__()

                                        self.yang_name = "level-1-2"
                                        self.yang_parent_name = "summary-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.metric = None
                                        self.tag = None
                                        self._segment_path = lambda: "level-1-2"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level12, [u'metric', u'tag'], name, value)


                                class Level2(Entity):
                                    """
                                    Summarize into level\-2 sub\-domain
                                    
                                    .. attribute:: metric
                                    
                                    	Set metric for summay route
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level2, self).__init__()

                                        self.yang_name = "level-2"
                                        self.yang_parent_name = "summary-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.metric = None
                                        self.tag = None
                                        self._segment_path = lambda: "level-2"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.Level2, [u'metric', u'tag'], name, value)


                                class MetricTagContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Set metric for summay route
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.MetricTagContainer, self).__init__()

                                        self.yang_name = "metric-tag-container"
                                        self.yang_parent_name = "summary-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.metric = None
                                        self.tag = None
                                        self._segment_path = lambda: "metric-tag-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SummaryAddress.MetricTagContainer, [u'metric', u'tag'], name, value)


                            class TrafficShare(Entity):
                                """
                                How to compute traffic share over alternate paths
                                
                                .. attribute:: min
                                
                                	All traffic shared among min metric paths
                                	**type**\:  :py:class:`Min <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.TrafficShare.Min>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.TrafficShare, self).__init__()

                                    self.yang_name = "traffic-share"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("min", ("min", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.TrafficShare.Min))])
                                    self._leafs = OrderedDict()

                                    self.min = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.TrafficShare.Min()
                                    self.min.parent = self
                                    self._children_name_map["min"] = "min"
                                    self._segment_path = lambda: "traffic-share"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.TrafficShare, [], name, value)


                                class Min(Entity):
                                    """
                                    All traffic shared among min metric paths
                                    
                                    .. attribute:: across_interfaces
                                    
                                    	Use different interfaces for equal\-cost paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.TrafficShare.Min, self).__init__()

                                        self.yang_name = "min"
                                        self.yang_parent_name = "traffic-share"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                                        ])
                                        self.across_interfaces = None
                                        self._segment_path = lambda: "min"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.TrafficShare.Min, [u'across_interfaces'], name, value)


                            class Advertise(Entity):
                                """
                                Control which IP routes flow in L1 and L2 LSPs
                                
                                .. attribute:: passive_only
                                
                                	only interface address of passive interfaces
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Advertise, self).__init__()

                                    self.yang_name = "advertise"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('passive_only', (YLeaf(YType.empty, 'passive-only'), ['Empty'])),
                                    ])
                                    self.passive_only = None
                                    self._segment_path = lambda: "advertise"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Advertise, [u'passive_only'], name, value)


                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.DefaultInformation.Originate>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("originate", ("originate", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.DefaultInformation.Originate))])
                                    self._leafs = OrderedDict()

                                    self.originate = None
                                    self._children_name_map["originate"] = "originate"
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.DefaultInformation, [], name, value)


                                class Originate(Entity):
                                    """
                                    Distribute a default route
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.DefaultInformation.Originate, self).__init__()

                                        self.yang_name = "originate"
                                        self.yang_parent_name = "default-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "originate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.DefaultInformation.Originate, [u'route_map'], name, value)


                            class Metric(Entity):
                                """
                                Set ISIS metric for all interfaces
                                
                                .. attribute:: metrics
                                
                                	
                                	**type**\: list of  		 :py:class:`Metrics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics>`
                                
                                .. attribute:: metric
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..16777214
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("metrics", ("metrics", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics))])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ])
                                    self.metric = None

                                    self.metrics = YList(self)
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Metric, [u'metric'], name, value)


                                class Metrics(Entity):
                                    """
                                    
                                    
                                    .. attribute:: level  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics.Level>`
                                    
                                    .. attribute:: metric
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..16777214
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics, self).__init__()

                                        self.yang_name = "metrics"
                                        self.yang_parent_name = "metric"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['level']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics.Level')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.level = None
                                        self.metric = None
                                        self._segment_path = lambda: "metrics" + "[level='" + str(self.level) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.Metric.Metrics, [u'level', u'metric'], name, value)

                                    class Level(Enum):
                                        """
                                        Level (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")



                            class PrcInterval(Entity):
                                """
                                Minimum interval between partial route calculations
                                
                                .. attribute:: interval
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120
                                
                                .. attribute:: initial_wait
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120000
                                
                                .. attribute:: minimum_wait
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120000
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.PrcInterval, self).__init__()

                                    self.yang_name = "prc-interval"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                        ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                        ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.initial_wait = None
                                    self.minimum_wait = None
                                    self._segment_path = lambda: "prc-interval"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.PrcInterval, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


                            class SetOverloadBit(Entity):
                                """
                                Signal other routers not to use us in SPF
                                
                                .. attribute:: on_startup
                                
                                	Set overload\-bit only temporarily after reboot
                                	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup>`
                                
                                .. attribute:: suppress
                                
                                	If overload\-bit set, suppress the following types of IP prefixes
                                	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.Suppress>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit, self).__init__()

                                    self.yang_name = "set-overload-bit"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("on-startup", ("on_startup", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup)), ("suppress", ("suppress", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.Suppress))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.on_startup = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup()
                                    self.on_startup.parent = self
                                    self._children_name_map["on_startup"] = "on-startup"

                                    self.suppress = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.Suppress()
                                    self.suppress.parent = self
                                    self._children_name_map["suppress"] = "suppress"
                                    self._segment_path = lambda: "set-overload-bit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit, [], name, value)


                                class OnStartup(Entity):
                                    """
                                    Set overload\-bit only temporarily after reboot
                                    
                                    .. attribute:: time
                                    
                                    	
                                    	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.Time>`
                                    
                                    .. attribute:: wait_for_bgp
                                    
                                    	Let BGP decide when to unset the overload bit
                                    	**type**\:  :py:class:`WaitForBgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup, self).__init__()

                                        self.yang_name = "on-startup"
                                        self.yang_parent_name = "set-overload-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("time", ("time", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.Time)), ("wait-for-bgp", ("wait_for_bgp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp))])
                                        self._leafs = OrderedDict()

                                        self.time = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.Time()
                                        self.time.parent = self
                                        self._children_name_map["time"] = "time"

                                        self.wait_for_bgp = None
                                        self._children_name_map["wait_for_bgp"] = "wait-for-bgp"
                                        self._segment_path = lambda: "on-startup"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup, [], name, value)


                                    class Time(Entity):
                                        """
                                        
                                        
                                        .. attribute:: time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 5..86400
                                        
                                        .. attribute:: suppress
                                        
                                        	If overload\-bit set, suppress the following types of IP prefixes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: external
                                        
                                        	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: interlevel
                                        
                                        	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.Time, self).__init__()

                                            self.yang_name = "time"
                                            self.yang_parent_name = "on-startup"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                                ('suppress', (YLeaf(YType.empty, 'suppress'), ['Empty'])),
                                                ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                                ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                            ])
                                            self.time = None
                                            self.suppress = None
                                            self.external = None
                                            self.interlevel = None
                                            self._segment_path = lambda: "time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.Time, [u'time', u'suppress', u'external', u'interlevel'], name, value)


                                    class WaitForBgp(Entity):
                                        """
                                        Let BGP decide when to unset the overload bit
                                        
                                        .. attribute:: suppress
                                        
                                        	If overload\-bit set, suppress the following types of IP prefixes
                                        	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp.Suppress>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp, self).__init__()

                                            self.yang_name = "wait-for-bgp"
                                            self.yang_parent_name = "on-startup"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("suppress", ("suppress", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp.Suppress))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.suppress = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp.Suppress()
                                            self.suppress.parent = self
                                            self._children_name_map["suppress"] = "suppress"
                                            self._segment_path = lambda: "wait-for-bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp, [], name, value)


                                        class Suppress(Entity):
                                            """
                                            If overload\-bit set, suppress the following types of IP prefixes
                                            
                                            .. attribute:: external
                                            
                                            	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: interlevel
                                            
                                            	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp.Suppress, self).__init__()

                                                self.yang_name = "suppress"
                                                self.yang_parent_name = "wait-for-bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                                    ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                                ])
                                                self.external = None
                                                self.interlevel = None
                                                self._segment_path = lambda: "suppress"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.OnStartup.WaitForBgp.Suppress, [u'external', u'interlevel'], name, value)


                                class Suppress(Entity):
                                    """
                                    If overload\-bit set, suppress the following types of IP prefixes
                                    
                                    .. attribute:: external
                                    
                                    	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: interlevel
                                    
                                    	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.Suppress, self).__init__()

                                        self.yang_name = "suppress"
                                        self.yang_parent_name = "set-overload-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                        ])
                                        self.external = None
                                        self.interlevel = None
                                        self._segment_path = lambda: "suppress"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SetOverloadBit.Suppress, [u'external', u'interlevel'], name, value)


                            class SpfInterval(Entity):
                                """
                                Minimum interval between SPF calculations
                                
                                .. attribute:: level_1_2
                                
                                	
                                	**type**\: list of  		 :py:class:`Level12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12>`
                                
                                .. attribute:: intervals
                                
                                	
                                	**type**\:  :py:class:`Intervals <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Intervals>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval, self).__init__()

                                    self.yang_name = "spf-interval"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("level-1-2", ("level_1_2", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12)), ("intervals", ("intervals", Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Intervals))])
                                    self._leafs = OrderedDict()

                                    self.intervals = Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Intervals()
                                    self.intervals.parent = self
                                    self._children_name_map["intervals"] = "intervals"

                                    self.level_1_2 = YList(self)
                                    self._segment_path = lambda: "spf-interval"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval, [], name, value)


                                class Level12(Entity):
                                    """
                                    
                                    
                                    .. attribute:: level  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12.Level>`
                                    
                                    .. attribute:: interval
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..120
                                    
                                    .. attribute:: initial_wait
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..120000
                                    
                                    .. attribute:: minimum_wait
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..120000
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12, self).__init__()

                                        self.yang_name = "level-1-2"
                                        self.yang_parent_name = "spf-interval"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['level']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12.Level')])),
                                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                            ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                            ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                                        ])
                                        self.level = None
                                        self.interval = None
                                        self.initial_wait = None
                                        self.minimum_wait = None
                                        self._segment_path = lambda: "level-1-2" + "[level='" + str(self.level) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Level12, [u'level', u'interval', u'initial_wait', u'minimum_wait'], name, value)

                                    class Level(Enum):
                                        """
                                        Level (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")



                                class Intervals(Entity):
                                    """
                                    
                                    
                                    .. attribute:: interval
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..120
                                    
                                    .. attribute:: initial_wait
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..120000
                                    
                                    .. attribute:: minimum_wait
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..120000
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Intervals, self).__init__()

                                        self.yang_name = "intervals"
                                        self.yang_parent_name = "spf-interval"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                            ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                            ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                                        ])
                                        self.interval = None
                                        self.initial_wait = None
                                        self.minimum_wait = None
                                        self._segment_path = lambda: "intervals"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv4.Topology.SpfInterval.Intervals, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


                    class Ipv6(Entity):
                        """
                        Address family
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: advertise
                        
                        	Control which IP routes flow in L1 and L2 LSPs
                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Advertise>`
                        
                        .. attribute:: default_information
                        
                        	Control distribution of default information
                        	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DefaultInformation>`
                        
                        .. attribute:: help
                        
                        	Description of the interactive help system
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: maximum_paths
                        
                        	Forward packets over multiple paths
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: metric
                        
                        	Set ISIS metric for all interfaces
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Metric>`
                        
                        .. attribute:: prc_interval
                        
                        	Minimum interval between partial route calculations
                        	**type**\:  :py:class:`PrcInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.PrcInterval>`
                        
                        .. attribute:: set_overload_bit
                        
                        	Signal other routers not to use us in SPF
                        	**type**\:  :py:class:`SetOverloadBit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: spf_interval
                        
                        	Minimum interval between SPF calculations
                        	**type**\:  :py:class:`SpfInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval>`
                        
                        .. attribute:: adjacency_check
                        
                        	Check ISIS neighbor protocol support
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: bfd
                        
                        	BFD configuration commands
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Bfd>`
                        
                        .. attribute:: router_id
                        
                        	Interface of stable IP address for system
                        	**type**\: str
                        
                        .. attribute:: distance
                        
                        	Administrative distance
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        .. attribute:: distribute_list
                        
                        	Filter networks in routing updates
                        	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList>`
                        
                        .. attribute:: ipv6
                        
                        	IPv6 specific commands
                        	**type**\:  :py:class:`Ipv6_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_>`
                        
                        .. attribute:: multi_topology
                        
                        	Enable multi\-topology mode
                        	**type**\:  :py:class:`MultiTopology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.MultiTopology>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: redistribute
                        
                        	Redistribute IPv6 prefixes from another routing protocol
                        	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute>`
                        
                        .. attribute:: summary_prefix
                        
                        	Configure IPv6 summary prefix
                        	**type**\: list of  		 :py:class:`SummaryPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SummaryPrefix>`
                        
                        .. attribute:: table_map
                        
                        	Map external entry attributes into routing table
                        	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.TableMap>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "address-family"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Advertise)), ("default-information", ("default_information", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DefaultInformation)), ("metric", ("metric", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Metric)), ("prc-interval", ("prc_interval", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.PrcInterval)), ("set-overload-bit", ("set_overload_bit", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit)), ("spf-interval", ("spf_interval", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval)), ("bfd", ("bfd", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Bfd)), ("distribute-list", ("distribute_list", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList)), ("ipv6", ("ipv6", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_)), ("multi-topology", ("multi_topology", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.MultiTopology)), ("redistribute", ("redistribute", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute)), ("summary-prefix", ("summary_prefix", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SummaryPrefix)), ("table-map", ("table_map", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.TableMap))])
                            self._leafs = OrderedDict([
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                ('help', (YLeaf(YType.empty, 'help'), ['Empty'])),
                                ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                ('adjacency_check', (YLeaf(YType.empty, 'adjacency-check'), ['Empty'])),
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                            ])
                            self.unicast = None
                            self.help = None
                            self.maximum_paths = None
                            self.adjacency_check = None
                            self.router_id = None
                            self.distance = None

                            self.advertise = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Advertise()
                            self.advertise.parent = self
                            self._children_name_map["advertise"] = "advertise"

                            self.default_information = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DefaultInformation()
                            self.default_information.parent = self
                            self._children_name_map["default_information"] = "default-information"

                            self.metric = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"

                            self.prc_interval = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.PrcInterval()
                            self.prc_interval.parent = self
                            self._children_name_map["prc_interval"] = "prc-interval"

                            self.set_overload_bit = None
                            self._children_name_map["set_overload_bit"] = "set-overload-bit"

                            self.spf_interval = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval()
                            self.spf_interval.parent = self
                            self._children_name_map["spf_interval"] = "spf-interval"

                            self.bfd = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Bfd()
                            self.bfd.parent = self
                            self._children_name_map["bfd"] = "bfd"

                            self.distribute_list = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList()
                            self.distribute_list.parent = self
                            self._children_name_map["distribute_list"] = "distribute-list"

                            self.ipv6 = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.multi_topology = None
                            self._children_name_map["multi_topology"] = "multi-topology"

                            self.redistribute = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute()
                            self.redistribute.parent = self
                            self._children_name_map["redistribute"] = "redistribute"

                            self.table_map = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.TableMap()
                            self.table_map.parent = self
                            self._children_name_map["table_map"] = "table-map"

                            self.summary_prefix = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6, [u'unicast', u'help', u'maximum_paths', u'adjacency_check', u'router_id', u'distance'], name, value)


                        class Advertise(Entity):
                            """
                            Control which IP routes flow in L1 and L2 LSPs
                            
                            .. attribute:: passive_only
                            
                            	only interface address of passive interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Advertise, self).__init__()

                                self.yang_name = "advertise"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('passive_only', (YLeaf(YType.empty, 'passive-only'), ['Empty'])),
                                ])
                                self.passive_only = None
                                self._segment_path = lambda: "advertise"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Advertise, [u'passive_only'], name, value)


                        class DefaultInformation(Entity):
                            """
                            Control distribution of default information
                            
                            .. attribute:: originate
                            
                            	Distribute a default route
                            	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DefaultInformation.Originate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DefaultInformation, self).__init__()

                                self.yang_name = "default-information"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("originate", ("originate", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DefaultInformation.Originate))])
                                self._leafs = OrderedDict()

                                self.originate = None
                                self._children_name_map["originate"] = "originate"
                                self._segment_path = lambda: "default-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DefaultInformation, [], name, value)


                            class Originate(Entity):
                                """
                                Distribute a default route
                                
                                .. attribute:: route_map
                                
                                	Route\-map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DefaultInformation.Originate, self).__init__()

                                    self.yang_name = "originate"
                                    self.yang_parent_name = "default-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "originate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DefaultInformation.Originate, [u'route_map'], name, value)


                        class Metric(Entity):
                            """
                            Set ISIS metric for all interfaces
                            
                            .. attribute:: metrics
                            
                            	
                            	**type**\: list of  		 :py:class:`Metrics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Metric.Metrics>`
                            
                            .. attribute:: metric
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metrics", ("metrics", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Metric.Metrics))])
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ])
                                self.metric = None

                                self.metrics = YList(self)
                                self._segment_path = lambda: "metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Metric, [u'metric'], name, value)


                            class Metrics(Entity):
                                """
                                
                                
                                .. attribute:: level  (key)
                                
                                	
                                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Metric.Metrics.Level>`
                                
                                .. attribute:: metric
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..16777214
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Metric.Metrics, self).__init__()

                                    self.yang_name = "metrics"
                                    self.yang_parent_name = "metric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['level']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Metric.Metrics.Level')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ])
                                    self.level = None
                                    self.metric = None
                                    self._segment_path = lambda: "metrics" + "[level='" + str(self.level) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Metric.Metrics, [u'level', u'metric'], name, value)

                                class Level(Enum):
                                    """
                                    Level (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")



                        class PrcInterval(Entity):
                            """
                            Minimum interval between partial route calculations
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120
                            
                            .. attribute:: initial_wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            .. attribute:: minimum_wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.PrcInterval, self).__init__()

                                self.yang_name = "prc-interval"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                    ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                    ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                                ])
                                self.interval = None
                                self.initial_wait = None
                                self.minimum_wait = None
                                self._segment_path = lambda: "prc-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.PrcInterval, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


                        class SetOverloadBit(Entity):
                            """
                            Signal other routers not to use us in SPF
                            
                            .. attribute:: on_startup
                            
                            	Set overload\-bit only temporarily after reboot
                            	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup>`
                            
                            .. attribute:: suppress
                            
                            	If overload\-bit set, suppress the following types of IP prefixes
                            	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.Suppress>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit, self).__init__()

                                self.yang_name = "set-overload-bit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("on-startup", ("on_startup", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup)), ("suppress", ("suppress", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.Suppress))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.on_startup = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup()
                                self.on_startup.parent = self
                                self._children_name_map["on_startup"] = "on-startup"

                                self.suppress = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.Suppress()
                                self.suppress.parent = self
                                self._children_name_map["suppress"] = "suppress"
                                self._segment_path = lambda: "set-overload-bit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit, [], name, value)


                            class OnStartup(Entity):
                                """
                                Set overload\-bit only temporarily after reboot
                                
                                .. attribute:: time
                                
                                	
                                	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.Time>`
                                
                                .. attribute:: wait_for_bgp
                                
                                	Let BGP decide when to unset the overload bit
                                	**type**\:  :py:class:`WaitForBgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup, self).__init__()

                                    self.yang_name = "on-startup"
                                    self.yang_parent_name = "set-overload-bit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("time", ("time", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.Time)), ("wait-for-bgp", ("wait_for_bgp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp))])
                                    self._leafs = OrderedDict()

                                    self.time = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.Time()
                                    self.time.parent = self
                                    self._children_name_map["time"] = "time"

                                    self.wait_for_bgp = None
                                    self._children_name_map["wait_for_bgp"] = "wait-for-bgp"
                                    self._segment_path = lambda: "on-startup"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup, [], name, value)


                                class Time(Entity):
                                    """
                                    
                                    
                                    .. attribute:: time
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 5..86400
                                    
                                    .. attribute:: suppress
                                    
                                    	If overload\-bit set, suppress the following types of IP prefixes
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: external
                                    
                                    	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: interlevel
                                    
                                    	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.Time, self).__init__()

                                        self.yang_name = "time"
                                        self.yang_parent_name = "on-startup"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                            ('suppress', (YLeaf(YType.empty, 'suppress'), ['Empty'])),
                                            ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                            ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                        ])
                                        self.time = None
                                        self.suppress = None
                                        self.external = None
                                        self.interlevel = None
                                        self._segment_path = lambda: "time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.Time, [u'time', u'suppress', u'external', u'interlevel'], name, value)


                                class WaitForBgp(Entity):
                                    """
                                    Let BGP decide when to unset the overload bit
                                    
                                    .. attribute:: suppress
                                    
                                    	If overload\-bit set, suppress the following types of IP prefixes
                                    	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp.Suppress>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp, self).__init__()

                                        self.yang_name = "wait-for-bgp"
                                        self.yang_parent_name = "on-startup"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("suppress", ("suppress", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp.Suppress))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.suppress = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp.Suppress()
                                        self.suppress.parent = self
                                        self._children_name_map["suppress"] = "suppress"
                                        self._segment_path = lambda: "wait-for-bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp, [], name, value)


                                    class Suppress(Entity):
                                        """
                                        If overload\-bit set, suppress the following types of IP prefixes
                                        
                                        .. attribute:: external
                                        
                                        	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: interlevel
                                        
                                        	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp.Suppress, self).__init__()

                                            self.yang_name = "suppress"
                                            self.yang_parent_name = "wait-for-bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                                ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                            ])
                                            self.external = None
                                            self.interlevel = None
                                            self._segment_path = lambda: "suppress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.OnStartup.WaitForBgp.Suppress, [u'external', u'interlevel'], name, value)


                            class Suppress(Entity):
                                """
                                If overload\-bit set, suppress the following types of IP prefixes
                                
                                .. attribute:: external
                                
                                	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: interlevel
                                
                                	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.Suppress, self).__init__()

                                    self.yang_name = "suppress"
                                    self.yang_parent_name = "set-overload-bit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                        ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                    ])
                                    self.external = None
                                    self.interlevel = None
                                    self._segment_path = lambda: "suppress"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SetOverloadBit.Suppress, [u'external', u'interlevel'], name, value)


                        class SpfInterval(Entity):
                            """
                            Minimum interval between SPF calculations
                            
                            .. attribute:: level_1_2
                            
                            	
                            	**type**\: list of  		 :py:class:`Level12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval.Level12>`
                            
                            .. attribute:: intervals
                            
                            	
                            	**type**\:  :py:class:`Intervals <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval.Intervals>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval, self).__init__()

                                self.yang_name = "spf-interval"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("level-1-2", ("level_1_2", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval.Level12)), ("intervals", ("intervals", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval.Intervals))])
                                self._leafs = OrderedDict()

                                self.intervals = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval.Intervals()
                                self.intervals.parent = self
                                self._children_name_map["intervals"] = "intervals"

                                self.level_1_2 = YList(self)
                                self._segment_path = lambda: "spf-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval, [], name, value)


                            class Level12(Entity):
                                """
                                
                                
                                .. attribute:: level  (key)
                                
                                	
                                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval.Level12.Level>`
                                
                                .. attribute:: interval
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120
                                
                                .. attribute:: initial_wait
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120000
                                
                                .. attribute:: minimum_wait
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120000
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval.Level12, self).__init__()

                                    self.yang_name = "level-1-2"
                                    self.yang_parent_name = "spf-interval"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['level']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval.Level12.Level')])),
                                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                        ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                        ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                                    ])
                                    self.level = None
                                    self.interval = None
                                    self.initial_wait = None
                                    self.minimum_wait = None
                                    self._segment_path = lambda: "level-1-2" + "[level='" + str(self.level) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval.Level12, [u'level', u'interval', u'initial_wait', u'minimum_wait'], name, value)

                                class Level(Enum):
                                    """
                                    Level (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")



                            class Intervals(Entity):
                                """
                                
                                
                                .. attribute:: interval
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120
                                
                                .. attribute:: initial_wait
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120000
                                
                                .. attribute:: minimum_wait
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..120000
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval.Intervals, self).__init__()

                                    self.yang_name = "intervals"
                                    self.yang_parent_name = "spf-interval"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                        ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                        ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                                    ])
                                    self.interval = None
                                    self.initial_wait = None
                                    self.minimum_wait = None
                                    self._segment_path = lambda: "intervals"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SpfInterval.Intervals, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


                        class Bfd(Entity):
                            """
                            BFD configuration commands
                            
                            .. attribute:: all_interfaces
                            
                            	Enable BFD on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: check_ctrl_plane_failure
                            
                            	BFD check control plane failure
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                                    ('check_ctrl_plane_failure', (YLeaf(YType.empty, 'check-ctrl-plane-failure'), ['Empty'])),
                                ])
                                self.all_interfaces = None
                                self.check_ctrl_plane_failure = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Bfd, [u'all_interfaces', u'check_ctrl_plane_failure'], name, value)


                        class DistributeList(Entity):
                            """
                            Filter networks in routing updates
                            
                            .. attribute:: prefix_list
                            
                            	Filter connections based on an IPv6 prefix\-list
                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList, self).__init__()

                                self.yang_name = "distribute-list"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix-list", ("prefix_list", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList))])
                                self._leafs = OrderedDict()

                                self.prefix_list = YList(self)
                                self._segment_path = lambda: "distribute-list"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList, [], name, value)


                            class PrefixList(Entity):
                                """
                                Filter connections based on an IPv6 prefix\-list
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: in_
                                
                                	Filter incoming routing updates
                                	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList, self).__init__()

                                    self.yang_name = "prefix-list"
                                    self.yang_parent_name = "distribute-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("in", ("in_", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.in_ = None
                                    self._children_name_map["in_"] = "in"
                                    self._segment_path = lambda: "prefix-list" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList, [u'name'], name, value)


                                class In(Entity):
                                    """
                                    Filter incoming routing updates
                                    
                                    .. attribute:: interface
                                    
                                    	Specify interface
                                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In, self).__init__()

                                        self.yang_name = "in"
                                        self.yang_parent_name = "prefix-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface", ("interface", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.interface = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface()
                                        self.interface.parent = self
                                        self._children_name_map["interface"] = "interface"
                                        self._segment_path = lambda: "in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In, [], name, value)


                                    class Interface(Entity):
                                        """
                                        Specify interface
                                        
                                        .. attribute:: appnav_compress
                                        
                                        	Service\-Context Virtual Interface Compress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: appnav_uncompress
                                        
                                        	Service\-Context Virtual Interface UnCompress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm
                                        
                                        	ATM interface
                                        	**type**\: str
                                        
                                        .. attribute:: atm_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMSubinterface>`
                                        
                                        .. attribute:: atm_acr
                                        
                                        	ATM\-ACR interface
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9]
                                        
                                        .. attribute:: atm_acrsubinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMACRsubinterface>`
                                        
                                        .. attribute:: bdi
                                        
                                        	Bridge\-Domain interface
                                        	**type**\: str
                                        
                                        .. attribute:: cem
                                        
                                        	CEM interface
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9]/){2}[0\-9]
                                        
                                        .. attribute:: cem_acr
                                        
                                        	CEM\-ACR interface
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: embedded_service_engine
                                        
                                        	cisco embedded service engine module
                                        	**type**\: str
                                        
                                        .. attribute:: ethernet
                                        
                                        	IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: fastethernet
                                        
                                        	FastEthernet IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: gigabitethernet
                                        
                                        	GigabitEthernet IEEE 802.3z
                                        	**type**\: str
                                        
                                        .. attribute:: fivegigabitethernet
                                        
                                        	Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twentyfivegige
                                        
                                        	Twenty Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twogigabitethernet
                                        
                                        	Two GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: fortygigabitethernet
                                        
                                        	Forty GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: hundredgige
                                        
                                        	Hundred GigabitEthernet
                                        	**type**\: str
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_subinterface
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.LISPSubinterface>`
                                        
                                        .. attribute:: loopback
                                        
                                        	Loopback interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multilink
                                        
                                        	Multilink\-group interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: nve
                                        
                                        	Network virtualization endpoint interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: overlay
                                        
                                        	Overlay interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: port_channel
                                        
                                        	Ethernet Channel of interfaces
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: port_channel_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.PortChannelSubinterface>`
                                        
                                        .. attribute:: pseudowire
                                        
                                        	Pseudowire Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sm
                                        
                                        	SM Interface
                                        	**type**\: str
                                        
                                        .. attribute:: cellular
                                        
                                        	Cellular Interface
                                        	**type**\: str
                                        
                                        .. attribute:: serial
                                        
                                        	Serial interface
                                        	**type**\: str
                                        
                                        .. attribute:: tengigabitethernet
                                        
                                        	Ten Gigabit Ethernet
                                        	**type**\: str
                                        
                                        .. attribute:: tunnel
                                        
                                        	Tunnel interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_template
                                        
                                        	Virtual Template interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vlan
                                        
                                        	Iosxr Vlans
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: virtualportgroup
                                        
                                        	Virtual Port Group
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasileft
                                        
                                        	vasileft
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasiright
                                        
                                        	vasiright
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "in"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.PortChannelSubinterface))])
                                            self._leafs = OrderedDict([
                                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                            ])
                                            self.appnav_compress = None
                                            self.appnav_uncompress = None
                                            self.atm = None
                                            self.atm_acr = None
                                            self.bdi = None
                                            self.cem = None
                                            self.cem_acr = None
                                            self.embedded_service_engine = None
                                            self.ethernet = None
                                            self.fastethernet = None
                                            self.gigabitethernet = None
                                            self.fivegigabitethernet = None
                                            self.twentyfivegige = None
                                            self.twogigabitethernet = None
                                            self.fortygigabitethernet = None
                                            self.hundredgige = None
                                            self.lisp = None
                                            self.loopback = None
                                            self.multilink = None
                                            self.nve = None
                                            self.overlay = None
                                            self.port_channel = None
                                            self.pseudowire = None
                                            self.sm = None
                                            self.cellular = None
                                            self.serial = None
                                            self.tengigabitethernet = None
                                            self.tunnel = None
                                            self.virtual_template = None
                                            self.vlan = None
                                            self.virtualportgroup = None
                                            self.vasileft = None
                                            self.vasiright = None

                                            self.atm_subinterface = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMSubinterface()
                                            self.atm_subinterface.parent = self
                                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                            self.atm_acrsubinterface = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMACRsubinterface()
                                            self.atm_acrsubinterface.parent = self
                                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                            self.lisp_subinterface = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.LISPSubinterface()
                                            self.lisp_subinterface.parent = self
                                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                            self.port_channel_subinterface = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.PortChannelSubinterface()
                                            self.port_channel_subinterface.parent = self
                                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                            self._segment_path = lambda: "interface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                        class ATMSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMSubinterface, self).__init__()

                                                self.yang_name = "ATM-subinterface"
                                                self.yang_parent_name = "interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ])
                                                self.atm = None
                                                self._segment_path = lambda: "ATM-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMSubinterface, [u'atm'], name, value)


                                        class ATMACRsubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm_acr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMACRsubinterface, self).__init__()

                                                self.yang_name = "ATM-ACRsubinterface"
                                                self.yang_parent_name = "interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ])
                                                self.atm_acr = None
                                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                        class LISPSubinterface(Entity):
                                            """
                                            Locator/ID Separation Protocol Virtual Interface
                                            
                                            .. attribute:: lisp
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.LISPSubinterface, self).__init__()

                                                self.yang_name = "LISP-subinterface"
                                                self.yang_parent_name = "interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ])
                                                self.lisp = None
                                                self._segment_path = lambda: "LISP-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.LISPSubinterface, [u'lisp'], name, value)


                                        class PortChannelSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: port_channel
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-isis'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.PortChannelSubinterface, self).__init__()

                                                self.yang_name = "Port-channel-subinterface"
                                                self.yang_parent_name = "interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                ])
                                                self.port_channel = None
                                                self._segment_path = lambda: "Port-channel-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.DistributeList.PrefixList.In.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                        class Ipv6_(Entity):
                            """
                            IPv6 specific commands
                            
                            .. attribute:: route
                            
                            	ISIS IPV6 routes
                            	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("route", ("route", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route))])
                                self._leafs = OrderedDict()

                                self.route = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route()
                                self.route.parent = self
                                self._children_name_map["route"] = "route"
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_, [], name, value)


                            class Route(Entity):
                                """
                                ISIS IPV6 routes
                                
                                .. attribute:: priority
                                
                                	Assign priority to IPV6 prefixes
                                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route, self).__init__()

                                    self.yang_name = "route"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("priority", ("priority", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority))])
                                    self._leafs = OrderedDict()

                                    self.priority = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority()
                                    self.priority.parent = self
                                    self._children_name_map["priority"] = "priority"
                                    self._segment_path = lambda: "route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route, [], name, value)


                                class Priority(Entity):
                                    """
                                    Assign priority to IPV6 prefixes
                                    
                                    .. attribute:: high
                                    
                                    	Assign high priority to important IPV6 prefixes in ISIS IPV6 local RIB
                                    	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority.High>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority, self).__init__()

                                        self.yang_name = "priority"
                                        self.yang_parent_name = "route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("high", ("high", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority.High))])
                                        self._leafs = OrderedDict()

                                        self.high = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority.High()
                                        self.high.parent = self
                                        self._children_name_map["high"] = "high"
                                        self._segment_path = lambda: "priority"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority, [], name, value)


                                    class High(Entity):
                                        """
                                        Assign high priority to important IPV6 prefixes in ISIS IPV6 local RIB
                                        
                                        .. attribute:: tag
                                        
                                        	Assign high priority to IPV6 prefixes with a specific route tag
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority.High, self).__init__()

                                            self.yang_name = "high"
                                            self.yang_parent_name = "priority"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.tag = None
                                            self._segment_path = lambda: "high"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Ipv6_.Route.Priority.High, [u'tag'], name, value)


                        class MultiTopology(Entity):
                            """
                            Enable multi\-topology mode
                            
                            .. attribute:: transition
                            
                            	Accept and generate both IS\-IS IPv6 and Multi\-topology IPv6 TLVs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.MultiTopology, self).__init__()

                                self.yang_name = "multi-topology"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('transition', (YLeaf(YType.empty, 'transition'), ['Empty'])),
                                ])
                                self.transition = None
                                self._segment_path = lambda: "multi-topology"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.MultiTopology, [u'transition'], name, value)


                        class Redistribute(Entity):
                            """
                            Redistribute IPv6 prefixes from another routing protocol
                            
                            .. attribute:: application
                            
                            	Application Protocol
                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Application>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: lisp
                            
                            	Locator ID Separation Protocol (LISP)
                            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Lisp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: nd
                            
                            	Neighbor Discovery
                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nd>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: nemo
                            
                            	Network Mobility (NEMO)
                            	**type**\:  :py:class:`Nemo <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nemo>`
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf>`
                            
                            .. attribute:: rip
                            
                            	IPv6 Routing Information Protocol (RIPv6)
                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Rip>`
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Static>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute, self).__init__()

                                self.yang_name = "redistribute"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("application", ("application", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Application)), ("bgp", ("bgp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Bgp)), ("connected", ("connected", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Connected)), ("eigrp", ("eigrp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_)), ("lisp", ("lisp", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Lisp)), ("nd", ("nd", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nd)), ("nemo", ("nemo", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nemo)), ("ospf", ("ospf", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf)), ("rip", ("rip", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Rip)), ("static", ("static", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Static))])
                                self._leafs = OrderedDict()

                                self.application = None
                                self._children_name_map["application"] = "application"

                                self.bgp = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Bgp()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.isis = None
                                self._children_name_map["isis"] = "isis"

                                self.lisp = None
                                self._children_name_map["lisp"] = "lisp"

                                self.nd = None
                                self._children_name_map["nd"] = "nd"

                                self.nemo = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nemo()
                                self.nemo.parent = self
                                self._children_name_map["nemo"] = "nemo"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.eigrp = YList(self)
                                self.ospf = YList(self)
                                self.rip = YList(self)
                                self._segment_path = lambda: "redistribute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute, [], name, value)


                            class Application(Entity):
                                """
                                Application Protocol
                                
                                .. attribute:: include_connected
                                
                                	Include connected
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Application.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Application, self).__init__()

                                    self.yang_name = "application"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Application.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.include_connected = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "application"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Application, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: as_number
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: include_connected
                                
                                	Include connected
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Bgp.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                        ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Bgp.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.as_number = None
                                    self.include_connected = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Bgp, [u'as_number', u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Connected.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Connected.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: include_connected
                                
                                	Include connected
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Eigrp.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.uint32, 'as-number'), ['int'])),
                                        ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Eigrp.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.as_number = None
                                    self.include_connected = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Eigrp, [u'as_number', u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Isis_(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: isis_redistribute
                                
                                	
                                	**type**\: list of  		 :py:class:`IsisRedistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute>`
                                
                                .. attribute:: isis_leak
                                
                                	
                                	**type**\: list of  		 :py:class:`IsisLeak <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isis-redistribute", ("isis_redistribute", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute)), ("isis-leak", ("isis_leak", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.isis_redistribute = YList(self)
                                    self.isis_leak = YList(self)
                                    self._segment_path = lambda: "isis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_, [], name, value)


                                class IsisRedistribute(Entity):
                                    """
                                    
                                    
                                    .. attribute:: area_tag  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: include_connected
                                    
                                    	Include connected
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute, self).__init__()

                                        self.yang_name = "isis-redistribute"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['area_tag']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                            ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.area_tag = None
                                        self.include_connected = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "isis-redistribute" + "[area-tag='" + str(self.area_tag) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisRedistribute, [u'area_tag', u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class IsisLeak(Entity):
                                    """
                                    
                                    
                                    .. attribute:: isis_redist_levels1  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRedistLevels1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak.IsisRedistLevels1>`
                                    
                                    .. attribute:: isis_redist_levels2  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRedistLevels2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak.IsisRedistLevels2>`
                                    
                                    .. attribute:: into
                                    
                                    	from level\-n into level\-m
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	select routes
                                    	**type**\: str
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route matching
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak, self).__init__()

                                        self.yang_name = "isis-leak"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['isis_redist_levels1','isis_redist_levels2']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('isis_redist_levels1', (YLeaf(YType.enumeration, 'isis-redist-levels1'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak.IsisRedistLevels1')])),
                                            ('isis_redist_levels2', (YLeaf(YType.enumeration, 'isis-redist-levels2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak.IsisRedistLevels2')])),
                                            ('into', (YLeaf(YType.empty, 'into'), ['Empty'])),
                                            ('distribute_list', (YLeaf(YType.str, 'distribute-list'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.isis_redist_levels1 = None
                                        self.isis_redist_levels2 = None
                                        self.into = None
                                        self.distribute_list = None
                                        self.route_map = None
                                        self._segment_path = lambda: "isis-leak" + "[isis-redist-levels1='" + str(self.isis_redist_levels1) + "']" + "[isis-redist-levels2='" + str(self.isis_redist_levels2) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Isis_.IsisLeak, [u'isis_redist_levels1', u'isis_redist_levels2', u'into', u'distribute_list', u'route_map'], name, value)

                                    class IsisRedistLevels1(Enum):
                                        """
                                        IsisRedistLevels1 (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")


                                    class IsisRedistLevels2(Enum):
                                        """
                                        IsisRedistLevels2 (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")



                            class Lisp(Entity):
                                """
                                Locator ID Separation Protocol (LISP)
                                
                                .. attribute:: include_connected
                                
                                	Include connected
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Lisp.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Lisp, self).__init__()

                                    self.yang_name = "lisp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Lisp.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.include_connected = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "lisp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Lisp, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Nd(Entity):
                                """
                                Neighbor Discovery
                                
                                .. attribute:: include_connected
                                
                                	Include connected
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nd.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nd, self).__init__()

                                    self.yang_name = "nd"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nd.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.include_connected = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "nd"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nd, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Nemo(Entity):
                                """
                                Network Mobility (NEMO)
                                
                                .. attribute:: include_connected
                                
                                	Include connected
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nemo.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nemo, self).__init__()

                                    self.yang_name = "nemo"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nemo.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.include_connected = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "nemo"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Nemo, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: process_id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: include_connected
                                
                                	Include connected
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['process_id']
                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match))])
                                    self._leafs = OrderedDict([
                                        ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                        ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.process_id = None
                                    self.include_connected = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None

                                    self.match = Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"
                                    self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf, [u'process_id', u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.Internal, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.external_routes = None
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.External, [u'external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.nssa_external_routes = None
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Ospf.Match.NssaExternal, [u'nssa_external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Rip(Entity):
                                """
                                IPv6 Routing Information Protocol (RIPv6)
                                
                                .. attribute:: process  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: include_connected
                                
                                	Include connected
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Rip.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['process']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('process', (YLeaf(YType.str, 'process'), ['str'])),
                                        ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Rip.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.process = None
                                    self.include_connected = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "rip" + "[process='" + str(self.process) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Rip, [u'process', u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Static.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Static.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.Redistribute.Static, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class SummaryPrefix(Entity):
                            """
                            Configure IPv6 summary prefix
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SummaryPrefix.Levels>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SummaryPrefix, self).__init__()

                                self.yang_name = "summary-prefix"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AddressFamily.Ipv6.SummaryPrefix.Levels')])),
                                ])
                                self.prefix = None
                                self.levels = None
                                self._segment_path = lambda: "summary-prefix" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.SummaryPrefix, [u'prefix', u'levels'], name, value)

                            class Levels(Enum):
                                """
                                Levels (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_1_2 = 1

                                .. data:: level_2 = 2

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_1_2 = Enum.YLeaf(1, "level-1-2")

                                level_2 = Enum.YLeaf(2, "level-2")



                        class TableMap(Entity):
                            """
                            Map external entry attributes into routing table
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: filter
                            
                            	Selective route download
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.TableMap, self).__init__()

                                self.yang_name = "table-map"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                                ])
                                self.name = None
                                self.filter = None
                                self._segment_path = lambda: "table-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.AddressFamily.Ipv6.TableMap, [u'name', u'filter'], name, value)


                class Distance(Entity):
                    """
                    Define an administrative distance
                    
                    .. attribute:: number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: ip_list
                    
                    	
                    	**type**\: list of  		 :py:class:`IpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Distance.IpList>`
                    
                    .. attribute:: clns
                    
                    	Distance applied for CLNS derived routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ip
                    
                    	Distance applied for IP derived routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Distance, self).__init__()

                        self.yang_name = "distance"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['number']
                        self._child_classes = OrderedDict([("ip-list", ("ip_list", Native.Router.IsisContainer.Isis.Distance.IpList))])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                            ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                            ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                        ])
                        self.number = None
                        self.clns = None
                        self.ip = None

                        self.ip_list = YList(self)
                        self._segment_path = lambda: "distance" + "[number='" + str(self.number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Distance, [u'number', u'clns', u'ip'], name, value)


                    class IpList(Entity):
                        """
                        
                        
                        .. attribute:: ip  (key)
                        
                        	IP Source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: wildcard_bits
                        
                        	
                        	**type**\: list of  		 :py:class:`WildcardBits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Distance.IpList.WildcardBits>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Distance.IpList, self).__init__()

                            self.yang_name = "ip-list"
                            self.yang_parent_name = "distance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip']
                            self._child_classes = OrderedDict([("wildcard-bits", ("wildcard_bits", Native.Router.IsisContainer.Isis.Distance.IpList.WildcardBits))])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                            ])
                            self.ip = None

                            self.wildcard_bits = YList(self)
                            self._segment_path = lambda: "ip-list" + "[ip='" + str(self.ip) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Distance.IpList, [u'ip'], name, value)


                        class WildcardBits(Entity):
                            """
                            
                            
                            .. attribute:: w_bits  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: access_list
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..99
                            
                            		**type**\: int
                            
                            			**range:** 1300..1999
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Distance.IpList.WildcardBits, self).__init__()

                                self.yang_name = "wildcard-bits"
                                self.yang_parent_name = "ip-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['w_bits']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('w_bits', (YLeaf(YType.str, 'w-bits'), ['str'])),
                                    ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                                ])
                                self.w_bits = None
                                self.access_list = None
                                self._segment_path = lambda: "wildcard-bits" + "[w-bits='" + str(self.w_bits) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Distance.IpList.WildcardBits, [u'w_bits', u'access_list'], name, value)


                class Ip(Entity):
                    """
                    IP specific commands
                    
                    .. attribute:: route
                    
                    	ISIS IP routes
                    	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Ip.Route>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("route", ("route", Native.Router.IsisContainer.Isis.Ip.Route))])
                        self._leafs = OrderedDict()

                        self.route = Native.Router.IsisContainer.Isis.Ip.Route()
                        self.route.parent = self
                        self._children_name_map["route"] = "route"
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Ip, [], name, value)


                    class Route(Entity):
                        """
                        ISIS IP routes
                        
                        .. attribute:: priority
                        
                        	Assign priority to IP prefixes
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Ip.Route.Priority>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Ip.Route, self).__init__()

                            self.yang_name = "route"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.IsisContainer.Isis.Ip.Route.Priority))])
                            self._leafs = OrderedDict()

                            self.priority = Native.Router.IsisContainer.Isis.Ip.Route.Priority()
                            self.priority.parent = self
                            self._children_name_map["priority"] = "priority"
                            self._segment_path = lambda: "route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Ip.Route, [], name, value)


                        class Priority(Entity):
                            """
                            Assign priority to IP prefixes
                            
                            .. attribute:: high
                            
                            	Assign high priority to important IP prefixes in ISIS IP local RIB
                            	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Ip.Route.Priority.High>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Ip.Route.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("high", ("high", Native.Router.IsisContainer.Isis.Ip.Route.Priority.High))])
                                self._leafs = OrderedDict()

                                self.high = Native.Router.IsisContainer.Isis.Ip.Route.Priority.High()
                                self.high.parent = self
                                self._children_name_map["high"] = "high"
                                self._segment_path = lambda: "priority"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Ip.Route.Priority, [], name, value)


                            class High(Entity):
                                """
                                Assign high priority to important IP prefixes in ISIS IP local RIB
                                
                                .. attribute:: tag
                                
                                	Assign high priority to IP prefixes with a specific route tag
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Ip.Route.Priority.High, self).__init__()

                                    self.yang_name = "high"
                                    self.yang_parent_name = "priority"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ])
                                    self.tag = None
                                    self._segment_path = lambda: "high"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Ip.Route.Priority.High, [u'tag'], name, value)


                class Redistribute(Entity):
                    """
                    Redistribute information from another routing protocol
                    
                    .. attribute:: application
                    
                    	Application
                    	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Application>`
                    
                    .. attribute:: bgp
                    
                    	Border Gateway Protocol (BGP)
                    	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Bgp>`
                    
                    .. attribute:: connected
                    
                    	Connected
                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Connected>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Eigrp>`
                    
                    .. attribute:: isis
                    
                    	ISO IS\-IS
                    	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Isis_>`
                    
                    .. attribute:: iso_igrp
                    
                    	IGRP for OSI networks
                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.IsoIgrp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: lisp
                    
                    	Locator ID Separation Protocol (LISP)
                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Lisp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: maximum_prefix
                    
                    	Maximum number of prefixes redistributed to protocol
                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.MaximumPrefix>`
                    
                    .. attribute:: mobile
                    
                    	Mobile routes
                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Mobile>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: odr
                    
                    	On Demand stub Routes
                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Odr>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ospf
                    
                    	Open Shortest Path First (OSPF)
                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospf>`
                    
                    .. attribute:: ospfv3
                    
                    	Open Shortest Path First (OSPF)
                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospfv3>`
                    
                    .. attribute:: rip
                    
                    	Routing Information Protocol (RIP)
                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Rip>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: static
                    
                    	Static routes
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Static>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: vrf
                    
                    	Specify a source VRF
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Redistribute, self).__init__()

                        self.yang_name = "redistribute"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("application", ("application", Native.Router.IsisContainer.Isis.Redistribute.Application)), ("bgp", ("bgp", Native.Router.IsisContainer.Isis.Redistribute.Bgp)), ("connected", ("connected", Native.Router.IsisContainer.Isis.Redistribute.Connected)), ("eigrp", ("eigrp", Native.Router.IsisContainer.Isis.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.IsisContainer.Isis.Redistribute.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.IsisContainer.Isis.Redistribute.IsoIgrp)), ("lisp", ("lisp", Native.Router.IsisContainer.Isis.Redistribute.Lisp)), ("maximum-prefix", ("maximum_prefix", Native.Router.IsisContainer.Isis.Redistribute.MaximumPrefix)), ("mobile", ("mobile", Native.Router.IsisContainer.Isis.Redistribute.Mobile)), ("odr", ("odr", Native.Router.IsisContainer.Isis.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.IsisContainer.Isis.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.IsisContainer.Isis.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.IsisContainer.Isis.Redistribute.Rip)), ("static", ("static", Native.Router.IsisContainer.Isis.Redistribute.Static)), ("vrf", ("vrf", Native.Router.IsisContainer.Isis.Redistribute.Vrf))])
                        self._leafs = OrderedDict()

                        self.bgp = Native.Router.IsisContainer.Isis.Redistribute.Bgp()
                        self.bgp.parent = self
                        self._children_name_map["bgp"] = "bgp"

                        self.connected = None
                        self._children_name_map["connected"] = "connected"

                        self.isis = Native.Router.IsisContainer.Isis.Redistribute.Isis_()
                        self.isis.parent = self
                        self._children_name_map["isis"] = "isis"

                        self.iso_igrp = None
                        self._children_name_map["iso_igrp"] = "iso-igrp"

                        self.lisp = None
                        self._children_name_map["lisp"] = "lisp"

                        self.maximum_prefix = Native.Router.IsisContainer.Isis.Redistribute.MaximumPrefix()
                        self.maximum_prefix.parent = self
                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                        self.mobile = None
                        self._children_name_map["mobile"] = "mobile"

                        self.odr = None
                        self._children_name_map["odr"] = "odr"

                        self.rip = None
                        self._children_name_map["rip"] = "rip"

                        self.static = None
                        self._children_name_map["static"] = "static"

                        self.vrf = Native.Router.IsisContainer.Isis.Redistribute.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.application = YList(self)
                        self.eigrp = YList(self)
                        self.ospf = YList(self)
                        self.ospfv3 = YList(self)
                        self._segment_path = lambda: "redistribute"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute, [], name, value)


                    class Application(Entity):
                        """
                        Application
                        
                        .. attribute:: name  (key)
                        
                        	Application name
                        	**type**\: str
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Application.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Application, self).__init__()

                            self.yang_name = "application"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Application.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.name = None
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Application, [u'name', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Bgp(Entity):
                        """
                        Border Gateway Protocol (BGP)
                        
                        .. attribute:: as_number
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4294967295
                        
                        		**type**\: str
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Bgp.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: clns
                        
                        	Redistribution of BGP NSAP routes
                        	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Bgp.Clns>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ip
                        
                        	Redistribution of BGP IP routes
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Bgp.Ip>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Bgp, self).__init__()

                            self.yang_name = "bgp"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.Redistribute.Bgp.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Bgp.Ip))])
                            self._leafs = OrderedDict([
                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Bgp.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.as_number = None
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None

                            self.clns = None
                            self._children_name_map["clns"] = "clns"

                            self.ip = None
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "bgp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Bgp, [u'as_number', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Clns(Entity):
                            """
                            Redistribution of BGP NSAP routes
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Bgp.Clns.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Redistribute.Bgp.Clns, self).__init__()

                                self.yang_name = "clns"
                                self.yang_parent_name = "bgp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Bgp.Clns.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "clns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Bgp.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Ip(Entity):
                            """
                            Redistribution of BGP IP routes
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Bgp.Ip.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Redistribute.Bgp.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "bgp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Bgp.Ip.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Bgp.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Connected(Entity):
                        """
                        Connected
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Connected.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Connected, self).__init__()

                            self.yang_name = "connected"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Connected.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self._segment_path = lambda: "connected"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Eigrp(Entity):
                        """
                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                        
                        .. attribute:: as_number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Eigrp.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['as_number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('as_number', (YLeaf(YType.uint32, 'as-number'), ['int'])),
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Eigrp.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.as_number = None
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Eigrp, [u'as_number', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Isis_(Entity):
                        """
                        ISO IS\-IS
                        
                        .. attribute:: isis_redistribute
                        
                        	
                        	**type**\: list of  		 :py:class:`IsisRedistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Isis_.IsisRedistribute>`
                        
                        .. attribute:: ip
                        
                        	Redistribution of IP routes between levels
                        	**type**\: list of  		 :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Isis_.Ip>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Isis_, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("isis-redistribute", ("isis_redistribute", Native.Router.IsisContainer.Isis.Redistribute.Isis_.IsisRedistribute)), ("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Isis_.Ip))])
                            self._leafs = OrderedDict()

                            self.isis_redistribute = YList(self)
                            self.ip = YList(self)
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Isis_, [], name, value)


                        class IsisRedistribute(Entity):
                            """
                            
                            
                            .. attribute:: area_tag  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip
                            
                            	Redistribution of IP routes between levels or processes
                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Isis_.IsisRedistribute.Ip>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Redistribute.Isis_.IsisRedistribute, self).__init__()

                                self.yang_name = "isis-redistribute"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['area_tag']
                                self._child_classes = OrderedDict([("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Isis_.IsisRedistribute.Ip))])
                                self._leafs = OrderedDict([
                                    ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                ])
                                self.area_tag = None

                                self.ip = None
                                self._children_name_map["ip"] = "ip"
                                self._segment_path = lambda: "isis-redistribute" + "[area-tag='" + str(self.area_tag) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Isis_.IsisRedistribute, [u'area_tag'], name, value)


                            class Ip(Entity):
                                """
                                Redistribution of IP routes between levels or processes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Isis_.IsisRedistribute.Ip.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Isis_.IsisRedistribute.Ip, self).__init__()

                                    self.yang_name = "ip"
                                    self.yang_parent_name = "isis-redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Isis_.IsisRedistribute.Ip.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "ip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Isis_.IsisRedistribute.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Ip(Entity):
                            """
                            Redistribution of IP routes between levels
                            
                            .. attribute:: isis_redist_levels1  (key)
                            
                            	
                            	**type**\:  :py:class:`IsisRedistLevels1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Isis_.Ip.IsisRedistLevels1>`
                            
                            .. attribute:: isis_redist_levels2  (key)
                            
                            	
                            	**type**\:  :py:class:`IsisRedistLevels2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Isis_.Ip.IsisRedistLevels2>`
                            
                            .. attribute:: into
                            
                            	from level\-n into level\-m
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: distribute_list
                            
                            	select routes
                            	**type**\: int
                            
                            	**range:** 100..199
                            
                            .. attribute:: route_map
                            
                            	Route map for route matching
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Redistribute.Isis_.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['isis_redist_levels1','isis_redist_levels2']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('isis_redist_levels1', (YLeaf(YType.enumeration, 'isis-redist-levels1'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Isis_.Ip.IsisRedistLevels1')])),
                                    ('isis_redist_levels2', (YLeaf(YType.enumeration, 'isis-redist-levels2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Isis_.Ip.IsisRedistLevels2')])),
                                    ('into', (YLeaf(YType.empty, 'into'), ['Empty'])),
                                    ('distribute_list', (YLeaf(YType.uint32, 'distribute-list'), ['int'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.isis_redist_levels1 = None
                                self.isis_redist_levels2 = None
                                self.into = None
                                self.distribute_list = None
                                self.route_map = None
                                self._segment_path = lambda: "ip" + "[isis-redist-levels1='" + str(self.isis_redist_levels1) + "']" + "[isis-redist-levels2='" + str(self.isis_redist_levels2) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Isis_.Ip, [u'isis_redist_levels1', u'isis_redist_levels2', u'into', u'distribute_list', u'route_map'], name, value)

                            class IsisRedistLevels1(Enum):
                                """
                                IsisRedistLevels1 (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")


                            class IsisRedistLevels2(Enum):
                                """
                                IsisRedistLevels2 (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")



                    class IsoIgrp(Entity):
                        """
                        IGRP for OSI networks
                        
                        .. attribute:: area_tag_route_map_container
                        
                        	
                        	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.IsoIgrp.AreaTagRouteMapContainer>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.IsoIgrp.MetricType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.IsoIgrp, self).__init__()

                            self.yang_name = "iso-igrp"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.IsisContainer.Isis.Redistribute.IsoIgrp.AreaTagRouteMapContainer))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.IsoIgrp.MetricType')])),
                            ])
                            self.route_map = None
                            self.levels = None
                            self.metric = None
                            self.metric_type = None

                            self.area_tag_route_map_container = Native.Router.IsisContainer.Isis.Redistribute.IsoIgrp.AreaTagRouteMapContainer()
                            self.area_tag_route_map_container.parent = self
                            self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"
                            self._segment_path = lambda: "iso-igrp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.IsoIgrp, [u'route_map', u'levels', u'metric', u'metric_type'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class AreaTagRouteMapContainer(Entity):
                            """
                            
                            
                            .. attribute:: area_tag
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Redistribute.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                self.yang_name = "area-tag-route-map-container"
                                self.yang_parent_name = "iso-igrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.area_tag = None
                                self.route_map = None
                                self._segment_path = lambda: "area-tag-route-map-container"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.IsoIgrp.AreaTagRouteMapContainer, [u'area_tag', u'route_map'], name, value)


                    class Lisp(Entity):
                        """
                        Locator ID Separation Protocol (LISP)
                        
                        .. attribute:: include_connected
                        
                        	Include connected
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Lisp.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Lisp, self).__init__()

                            self.yang_name = "lisp"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Lisp.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.include_connected = None
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self._segment_path = lambda: "lisp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Lisp, [u'include_connected', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class MaximumPrefix(Entity):
                        """
                        Maximum number of prefixes redistributed to protocol
                        
                        .. attribute:: number
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: threshold_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: warning_only
                        
                        	Only give warning message when limit is exceeded
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: withdraw
                        
                        	Withdraw redistibuted prefixes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.MaximumPrefix, self).__init__()

                            self.yang_name = "maximum-prefix"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                ('threshold_value', (YLeaf(YType.uint32, 'threshold-value'), ['int'])),
                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                ('withdraw', (YLeaf(YType.empty, 'withdraw'), ['Empty'])),
                            ])
                            self.number = None
                            self.threshold_value = None
                            self.warning_only = None
                            self.withdraw = None
                            self._segment_path = lambda: "maximum-prefix"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.MaximumPrefix, [u'number', u'threshold_value', u'warning_only', u'withdraw'], name, value)


                    class Mobile(Entity):
                        """
                        Mobile routes
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Mobile.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Mobile, self).__init__()

                            self.yang_name = "mobile"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Mobile.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self._segment_path = lambda: "mobile"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Odr(Entity):
                        """
                        On Demand stub Routes
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Odr.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Odr, self).__init__()

                            self.yang_name = "odr"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Odr.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self._segment_path = lambda: "odr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Odr, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Ospf(Entity):
                        """
                        Open Shortest Path First (OSPF)
                        
                        .. attribute:: process_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospf.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: match
                        
                        	Redistribution of OSPF routes
                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match>`
                        
                        .. attribute:: vrf
                        
                        	VPN Routing/Forwarding Instance
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Ospf, self).__init__()

                            self.yang_name = "ospf"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['process_id']
                            self._child_classes = OrderedDict([("match", ("match", Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match))])
                            self._leafs = OrderedDict([
                                ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Ospf.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.process_id = None
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self.vrf = None

                            self.match = Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match()
                            self.match.parent = self
                            self._children_name_map["match"] = "match"
                            self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Ospf, [u'process_id', u'levels', u'metric', u'metric_type', u'route_map', u'vrf'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Match(Entity):
                            """
                            Redistribution of OSPF routes
                            
                            .. attribute:: internal
                            
                            	Redistribute OSPF internal routes
                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.Internal>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: external
                            
                            	Redistribute OSPF external routes
                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.External>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: nssa_external
                            
                            	Redistribute OSPF NSSA external routes
                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.NssaExternal>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match, self).__init__()

                                self.yang_name = "match"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.NssaExternal))])
                                self._leafs = OrderedDict()

                                self.internal = None
                                self._children_name_map["internal"] = "internal"

                                self.external = None
                                self._children_name_map["external"] = "external"

                                self.nssa_external = None
                                self._children_name_map["nssa_external"] = "nssa-external"
                                self._segment_path = lambda: "match"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match, [], name, value)


                            class Internal(Entity):
                                """
                                Redistribute OSPF internal routes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.Internal.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.Internal, self).__init__()

                                    self.yang_name = "internal"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Ospf.Match.Internal.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "internal"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.Internal, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class External(Entity):
                                """
                                Redistribute OSPF external routes
                                
                                .. attribute:: external_routes
                                
                                	
                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.External.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.External, self).__init__()

                                    self.yang_name = "external"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Ospf.Match.External.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.external_routes = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "external"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.External, [u'external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class NssaExternal(Entity):
                                """
                                Redistribute OSPF NSSA external routes
                                
                                .. attribute:: nssa_external_routes
                                
                                	
                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.NssaExternal.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                    self.yang_name = "nssa-external"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Ospf.Match.NssaExternal.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.nssa_external_routes = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "nssa-external"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Ospf.Match.NssaExternal, [u'nssa_external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Ospfv3(Entity):
                        """
                        Open Shortest Path First (OSPF)
                        
                        .. attribute:: process_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: match
                        
                        	Redistribution of OSPF routes
                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match>`
                        
                        .. attribute:: vrf
                        
                        	VPN Routing/Forwarding Instance
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Ospfv3, self).__init__()

                            self.yang_name = "ospfv3"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['process_id']
                            self._child_classes = OrderedDict([("match", ("match", Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match))])
                            self._leafs = OrderedDict([
                                ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Ospfv3.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.process_id = None
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self.vrf = None

                            self.match = Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match()
                            self.match.parent = self
                            self._children_name_map["match"] = "match"
                            self._segment_path = lambda: "ospfv3" + "[process-id='" + str(self.process_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Ospfv3, [u'process_id', u'levels', u'metric', u'metric_type', u'route_map', u'vrf'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Match(Entity):
                            """
                            Redistribution of OSPF routes
                            
                            .. attribute:: internal
                            
                            	Redistribute OSPF internal routes
                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.Internal>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: external
                            
                            	Redistribute OSPF external routes
                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.External>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: nssa_external
                            
                            	Redistribute OSPF NSSA external routes
                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.NssaExternal>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match, self).__init__()

                                self.yang_name = "match"
                                self.yang_parent_name = "ospfv3"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.Internal)), ("external", ("external", Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.External)), ("nssa-external", ("nssa_external", Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.NssaExternal))])
                                self._leafs = OrderedDict()

                                self.internal = None
                                self._children_name_map["internal"] = "internal"

                                self.external = None
                                self._children_name_map["external"] = "external"

                                self.nssa_external = None
                                self._children_name_map["nssa_external"] = "nssa-external"
                                self._segment_path = lambda: "match"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match, [], name, value)


                            class Internal(Entity):
                                """
                                Redistribute OSPF internal routes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.Internal.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.Internal, self).__init__()

                                    self.yang_name = "internal"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.Internal.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "internal"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.Internal, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class External(Entity):
                                """
                                Redistribute OSPF external routes
                                
                                .. attribute:: external_routes
                                
                                	
                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.External.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.External, self).__init__()

                                    self.yang_name = "external"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.External.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.external_routes = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "external"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.External, [u'external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class NssaExternal(Entity):
                                """
                                Redistribute OSPF NSSA external routes
                                
                                .. attribute:: nssa_external_routes
                                
                                	
                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.NssaExternal.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.NssaExternal, self).__init__()

                                    self.yang_name = "nssa-external"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.NssaExternal.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.nssa_external_routes = None
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "nssa-external"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Ospfv3.Match.NssaExternal, [u'nssa_external_routes', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Rip(Entity):
                        """
                        Routing Information Protocol (RIP)
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                        
                        .. attribute:: metric
                        
                        	ISIS default metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Rip.MetricType>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Rip, self).__init__()

                            self.yang_name = "rip"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Rip.MetricType')])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.levels = None
                            self.metric = None
                            self.metric_type = None
                            self.route_map = None
                            self._segment_path = lambda: "rip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: external = 0

                            .. data:: internal = 1

                            .. data:: rib_metric_as_external = 2

                            .. data:: rib_metric_as_internal = 3

                            """

                            external = Enum.YLeaf(0, "external")

                            internal = Enum.YLeaf(1, "internal")

                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Static(Entity):
                        """
                        Static routes
                        
                        .. attribute:: clns
                        
                        	Redistribution of BGP NSAP routes
                        	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Static.Clns>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ip
                        
                        	Redistribution of BGP IP routes
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Static.Ip>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Static.Ip))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.clns = None
                            self._children_name_map["clns"] = "clns"

                            self.ip = None
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "static"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Static, [], name, value)


                        class Clns(Entity):
                            """
                            Redistribution of BGP NSAP routes
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Static.Clns.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Redistribute.Static.Clns, self).__init__()

                                self.yang_name = "clns"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Static.Clns.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "clns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Ip(Entity):
                            """
                            Redistribution of BGP IP routes
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                            
                            .. attribute:: metric
                            
                            	ISIS default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Static.Ip.MetricType>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Redistribute.Static.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Static.Ip.MetricType')])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.levels = None
                                self.metric = None
                                self.metric_type = None
                                self.route_map = None
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: external = 0

                                .. data:: internal = 1

                                .. data:: rib_metric_as_external = 2

                                .. data:: rib_metric_as_internal = 3

                                """

                                external = Enum.YLeaf(0, "external")

                                internal = Enum.YLeaf(1, "internal")

                                rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                    class Vrf(Entity):
                        """
                        Specify a source VRF
                        
                        .. attribute:: vrf_nm
                        
                        	
                        	**type**\: list of  		 :py:class:`VrfNm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm>`
                        
                        .. attribute:: global_
                        
                        	global VRF
                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Redistribute.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf-nm", ("vrf_nm", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm)), ("global", ("global_", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global))])
                            self._leafs = OrderedDict()

                            self.global_ = Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"

                            self.vrf_nm = YList(self)
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf, [], name, value)


                        class VrfNm(Entity):
                            """
                            
                            
                            .. attribute:: vrf_nm  (key)
                            
                            	Source VRF name
                            	**type**\: str
                            
                            .. attribute:: application
                            
                            	Application
                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Application>`
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_>`
                            
                            .. attribute:: iso_igrp
                            
                            	IGRP for OSI networks
                            	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: lisp
                            
                            	Locator ID Separation Protocol (LISP)
                            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Lisp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: mobile
                            
                            	Mobile routes
                            	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Mobile>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ospf
                            
                            	Process ID
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Ospfv3>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Rip>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm, self).__init__()

                                self.yang_name = "vrf-nm"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['vrf_nm']
                                self._child_classes = OrderedDict([("application", ("application", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Application)), ("bgp", ("bgp", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp)), ("connected", ("connected", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Connected)), ("eigrp", ("eigrp", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Eigrp)), ("isis", ("isis", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp)), ("lisp", ("lisp", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Lisp)), ("mobile", ("mobile", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Mobile)), ("ospfv3", ("ospfv3", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Ospfv3)), ("rip", ("rip", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Rip)), ("static", ("static", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static))])
                                self._leafs = OrderedDict([
                                    ('vrf_nm', (YLeaf(YType.str, 'vrf-nm'), ['str'])),
                                    ('ospf', (YLeaf(YType.uint16, 'ospf'), ['int'])),
                                ])
                                self.vrf_nm = None
                                self.ospf = None

                                self.application = Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Application()
                                self.application.parent = self
                                self._children_name_map["application"] = "application"

                                self.bgp = Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.eigrp = Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Eigrp()
                                self.eigrp.parent = self
                                self._children_name_map["eigrp"] = "eigrp"

                                self.isis = Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_()
                                self.isis.parent = self
                                self._children_name_map["isis"] = "isis"

                                self.iso_igrp = None
                                self._children_name_map["iso_igrp"] = "iso-igrp"

                                self.lisp = None
                                self._children_name_map["lisp"] = "lisp"

                                self.mobile = None
                                self._children_name_map["mobile"] = "mobile"

                                self.ospfv3 = Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Ospfv3()
                                self.ospfv3.parent = self
                                self._children_name_map["ospfv3"] = "ospfv3"

                                self.rip = None
                                self._children_name_map["rip"] = "rip"

                                self.static = None
                                self._children_name_map["static"] = "static"
                                self._segment_path = lambda: "vrf-nm" + "[vrf-nm='" + str(self.vrf_nm) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm, [u'vrf_nm', u'ospf'], name, value)


                            class Application(Entity):
                                """
                                Application
                                
                                .. attribute:: appname
                                
                                	
                                	**type**\: list of  		 :py:class:`Appname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Application.Appname>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Application, self).__init__()

                                    self.yang_name = "application"
                                    self.yang_parent_name = "vrf-nm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("appname", ("appname", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Application.Appname))])
                                    self._leafs = OrderedDict()

                                    self.appname = YList(self)
                                    self._segment_path = lambda: "application"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Application, [], name, value)


                                class Appname(Entity):
                                    """
                                    
                                    
                                    .. attribute:: appname  (key)
                                    
                                    	Application name
                                    	**type**\: str
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Application.Appname.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Application.Appname, self).__init__()

                                        self.yang_name = "appname"
                                        self.yang_parent_name = "application"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['appname']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('appname', (YLeaf(YType.str, 'appname'), ['str'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Application.Appname.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.appname = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "appname" + "[appname='" + str(self.appname) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Application.Appname, [u'appname', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: bp_as_num
                                
                                	
                                	**type**\: list of  		 :py:class:`BpAsNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum>`
                                
                                .. attribute:: a_lesser_1_period_0_xx_period_yy_greater_
                                
                                	Autonomous system number
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "vrf-nm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bp-as-num", ("bp_as_num", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum))])
                                    self._leafs = OrderedDict([
                                        ('a_lesser_1_period_0_xx_period_yy_greater_', (YLeaf(YType.empty, 'a_LESSER_1_PERIOD_0-XX_PERIOD_YY_GREATER_'), ['Empty'])),
                                    ])
                                    self.a_lesser_1_period_0_xx_period_yy_greater_ = None

                                    self.bp_as_num = YList(self)
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp, [u'a_lesser_1_period_0_xx_period_yy_greater_'], name, value)


                                class BpAsNum(Entity):
                                    """
                                    
                                    
                                    .. attribute:: bp_as_num  (key)
                                    
                                    	Autonomous system number
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: clns
                                    
                                    	Redistribution of BGP NSAP routes
                                    	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ip
                                    
                                    	Redistribution of BGP IP routes
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum, self).__init__()

                                        self.yang_name = "bp-as-num"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['bp_as_num']
                                        self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip))])
                                        self._leafs = OrderedDict([
                                            ('bp_as_num', (YLeaf(YType.str, 'bp-as-num'), ['int','str'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.bp_as_num = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None

                                        self.clns = None
                                        self._children_name_map["clns"] = "clns"

                                        self.ip = None
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "bp-as-num" + "[bp-as-num='" + str(self.bp_as_num) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum, [u'bp_as_num', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Clns(Entity):
                                        """
                                        Redistribution of BGP NSAP routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns, self).__init__()

                                            self.yang_name = "clns"
                                            self.yang_parent_name = "bp-as-num"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "clns"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Ip(Entity):
                                        """
                                        Redistribution of BGP IP routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "bp-as-num"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Bgp.BpAsNum.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Connected.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "vrf-nm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Connected.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: eigrp_as
                                
                                	
                                	**type**\: list of  		 :py:class:`EigrpAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "vrf-nm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eigrp-as", ("eigrp_as", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs))])
                                    self._leafs = OrderedDict()

                                    self.eigrp_as = YList(self)
                                    self._segment_path = lambda: "eigrp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Eigrp, [], name, value)


                                class EigrpAs(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eigrp_as  (key)
                                    
                                    	AS number
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs, self).__init__()

                                        self.yang_name = "eigrp-as"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eigrp_as']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eigrp_as', (YLeaf(YType.uint16, 'eigrp-as'), ['int'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.eigrp_as = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "eigrp-as" + "[eigrp-as='" + str(self.eigrp_as) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Eigrp.EigrpAs, [u'eigrp_as', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Isis_(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: isis_atag
                                
                                	
                                	**type**\: list of  		 :py:class:`IsisAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag>`
                                
                                .. attribute:: ip
                                
                                	Redistribution of IP routes between levels or processes
                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "vrf-nm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isis-atag", ("isis_atag", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag)), ("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip))])
                                    self._leafs = OrderedDict()

                                    self.ip = None
                                    self._children_name_map["ip"] = "ip"

                                    self.isis_atag = YList(self)
                                    self._segment_path = lambda: "isis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_, [], name, value)


                                class IsisAtag(Entity):
                                    """
                                    
                                    
                                    .. attribute:: isis_atag  (key)
                                    
                                    	ISO routing area tag
                                    	**type**\: str
                                    
                                    .. attribute:: ip
                                    
                                    	Redistribution of IP routes between levels or processes
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag, self).__init__()

                                        self.yang_name = "isis-atag"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['isis_atag']
                                        self._child_classes = OrderedDict([("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip))])
                                        self._leafs = OrderedDict([
                                            ('isis_atag', (YLeaf(YType.str, 'isis-atag'), ['str'])),
                                        ])
                                        self.isis_atag = None

                                        self.ip = Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip()
                                        self.ip.parent = self
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "isis-atag" + "[isis-atag='" + str(self.isis_atag) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag, [u'isis_atag'], name, value)


                                    class Ip(Entity):
                                        """
                                        Redistribution of IP routes between levels or processes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "isis-atag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.IsisAtag.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Ip(Entity):
                                    """
                                    Redistribution of IP routes between levels or processes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip, self).__init__()

                                        self.yang_name = "ip"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "ip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Isis_.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class IsoIgrp(Entity):
                                """
                                IGRP for OSI networks
                                
                                .. attribute:: iso_atag
                                
                                	
                                	**type**\: list of  		 :py:class:`IsoAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp, self).__init__()

                                    self.yang_name = "iso-igrp"
                                    self.yang_parent_name = "vrf-nm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("iso-atag", ("iso_atag", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag)), ("route-map", ("route_map", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.route_map = None
                                    self._children_name_map["route_map"] = "route-map"

                                    self.iso_atag = YList(self)
                                    self._segment_path = lambda: "iso-igrp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp, [], name, value)


                                class IsoAtag(Entity):
                                    """
                                    
                                    
                                    .. attribute:: iso_atag  (key)
                                    
                                    	ISO routing area tag
                                    	**type**\: str
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag, self).__init__()

                                        self.yang_name = "iso-atag"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['iso_atag']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('iso_atag', (YLeaf(YType.str, 'iso-atag'), ['str'])),
                                            ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                        ])
                                        self.iso_atag = None
                                        self.route_map = None
                                        self._segment_path = lambda: "iso-atag" + "[iso-atag='" + str(self.iso_atag) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.IsoAtag, [u'iso_atag', u'route_map'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Route map reference
                                    
                                    .. attribute:: rm_point
                                    
                                    	Pointer to route\-map entries
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('rm_point', (YLeaf(YType.str, 'rm-point'), ['str'])),
                                        ])
                                        self.rm_point = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.IsoIgrp.RouteMap, [u'rm_point'], name, value)


                            class Lisp(Entity):
                                """
                                Locator ID Separation Protocol (LISP)
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Lisp.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Lisp, self).__init__()

                                    self.yang_name = "lisp"
                                    self.yang_parent_name = "vrf-nm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Lisp.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "lisp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Lisp, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Mobile(Entity):
                                """
                                Mobile routes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Mobile.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Mobile, self).__init__()

                                    self.yang_name = "mobile"
                                    self.yang_parent_name = "vrf-nm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Mobile.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "mobile"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Ospfv3(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: os3_id
                                
                                	
                                	**type**\: list of  		 :py:class:`Os3Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Ospfv3, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "vrf-nm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("os3-id", ("os3_id", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id))])
                                    self._leafs = OrderedDict()

                                    self.os3_id = YList(self)
                                    self._segment_path = lambda: "ospfv3"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Ospfv3, [], name, value)


                                class Os3Id(Entity):
                                    """
                                    
                                    
                                    .. attribute:: os3_id  (key)
                                    
                                    	Process ID
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id, self).__init__()

                                        self.yang_name = "os3-id"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['os3_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('os3_id', (YLeaf(YType.uint16, 'os3-id'), ['int'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.os3_id = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "os3-id" + "[os3-id='" + str(self.os3_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Ospfv3.Os3Id, [u'os3_id', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Rip.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "vrf-nm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Rip.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "rip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: clns
                                
                                	Redistribution of BGP NSAP routes
                                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Clns>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ip
                                
                                	Redistribution of BGP IP routes
                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Ip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "vrf-nm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Ip))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None

                                    self.clns = None
                                    self._children_name_map["clns"] = "clns"

                                    self.ip = None
                                    self._children_name_map["ip"] = "ip"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Clns(Entity):
                                    """
                                    Redistribution of BGP NSAP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Clns.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Clns, self).__init__()

                                        self.yang_name = "clns"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Clns.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "clns"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Ip(Entity):
                                    """
                                    Redistribution of BGP IP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Ip.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Ip, self).__init__()

                                        self.yang_name = "ip"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Ip.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "ip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.VrfNm.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                        class Global(Entity):
                            """
                            global VRF
                            
                            .. attribute:: application
                            
                            	Application
                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Application>`
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\:  :py:class:`Isis_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_>`
                            
                            .. attribute:: iso_igrp
                            
                            	IGRP for OSI networks
                            	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: lisp
                            
                            	Locator ID Separation Protocol (LISP)
                            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Lisp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: mobile
                            
                            	Mobile routes
                            	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Mobile>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ospf
                            
                            	Process ID
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Ospfv3>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Rip>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("application", ("application", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Application)), ("bgp", ("bgp", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp)), ("connected", ("connected", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Connected)), ("eigrp", ("eigrp", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Eigrp)), ("isis", ("isis", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_)), ("iso-igrp", ("iso_igrp", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp)), ("lisp", ("lisp", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Lisp)), ("mobile", ("mobile", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Mobile)), ("ospfv3", ("ospfv3", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Ospfv3)), ("rip", ("rip", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Rip)), ("static", ("static", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static))])
                                self._leafs = OrderedDict([
                                    ('ospf', (YLeaf(YType.uint16, 'ospf'), ['int'])),
                                ])
                                self.ospf = None

                                self.application = Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Application()
                                self.application.parent = self
                                self._children_name_map["application"] = "application"

                                self.bgp = Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.eigrp = Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Eigrp()
                                self.eigrp.parent = self
                                self._children_name_map["eigrp"] = "eigrp"

                                self.isis = Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_()
                                self.isis.parent = self
                                self._children_name_map["isis"] = "isis"

                                self.iso_igrp = None
                                self._children_name_map["iso_igrp"] = "iso-igrp"

                                self.lisp = None
                                self._children_name_map["lisp"] = "lisp"

                                self.mobile = None
                                self._children_name_map["mobile"] = "mobile"

                                self.ospfv3 = Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Ospfv3()
                                self.ospfv3.parent = self
                                self._children_name_map["ospfv3"] = "ospfv3"

                                self.rip = None
                                self._children_name_map["rip"] = "rip"

                                self.static = None
                                self._children_name_map["static"] = "static"
                                self._segment_path = lambda: "global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global, [u'ospf'], name, value)


                            class Application(Entity):
                                """
                                Application
                                
                                .. attribute:: appname
                                
                                	
                                	**type**\: list of  		 :py:class:`Appname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Application.Appname>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Application, self).__init__()

                                    self.yang_name = "application"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("appname", ("appname", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Application.Appname))])
                                    self._leafs = OrderedDict()

                                    self.appname = YList(self)
                                    self._segment_path = lambda: "application"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Application, [], name, value)


                                class Appname(Entity):
                                    """
                                    
                                    
                                    .. attribute:: appname  (key)
                                    
                                    	Application name
                                    	**type**\: str
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Application.Appname.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Application.Appname, self).__init__()

                                        self.yang_name = "appname"
                                        self.yang_parent_name = "application"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['appname']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('appname', (YLeaf(YType.str, 'appname'), ['str'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Application.Appname.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.appname = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "appname" + "[appname='" + str(self.appname) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Application.Appname, [u'appname', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: bp_as_num
                                
                                	
                                	**type**\: list of  		 :py:class:`BpAsNum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum>`
                                
                                .. attribute:: a_lesser_1_period_0_xx_period_yy_greater_
                                
                                	Autonomous system number
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bp-as-num", ("bp_as_num", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum))])
                                    self._leafs = OrderedDict([
                                        ('a_lesser_1_period_0_xx_period_yy_greater_', (YLeaf(YType.empty, 'a_LESSER_1_PERIOD_0-XX_PERIOD_YY_GREATER_'), ['Empty'])),
                                    ])
                                    self.a_lesser_1_period_0_xx_period_yy_greater_ = None

                                    self.bp_as_num = YList(self)
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp, [u'a_lesser_1_period_0_xx_period_yy_greater_'], name, value)


                                class BpAsNum(Entity):
                                    """
                                    
                                    
                                    .. attribute:: bp_as_num  (key)
                                    
                                    	Autonomous system number
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: clns
                                    
                                    	Redistribution of BGP NSAP routes
                                    	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ip
                                    
                                    	Redistribution of BGP IP routes
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum, self).__init__()

                                        self.yang_name = "bp-as-num"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['bp_as_num']
                                        self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip))])
                                        self._leafs = OrderedDict([
                                            ('bp_as_num', (YLeaf(YType.str, 'bp-as-num'), ['int','str'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.bp_as_num = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None

                                        self.clns = None
                                        self._children_name_map["clns"] = "clns"

                                        self.ip = None
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "bp-as-num" + "[bp-as-num='" + str(self.bp_as_num) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum, [u'bp_as_num', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Clns(Entity):
                                        """
                                        Redistribution of BGP NSAP routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns, self).__init__()

                                            self.yang_name = "clns"
                                            self.yang_parent_name = "bp-as-num"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "clns"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                    class Ip(Entity):
                                        """
                                        Redistribution of BGP IP routes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "bp-as-num"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Bgp.BpAsNum.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Connected.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Connected.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Connected, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: eigrp_as
                                
                                	
                                	**type**\: list of  		 :py:class:`EigrpAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eigrp-as", ("eigrp_as", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs))])
                                    self._leafs = OrderedDict()

                                    self.eigrp_as = YList(self)
                                    self._segment_path = lambda: "eigrp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Eigrp, [], name, value)


                                class EigrpAs(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eigrp_as  (key)
                                    
                                    	AS number
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs, self).__init__()

                                        self.yang_name = "eigrp-as"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eigrp_as']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eigrp_as', (YLeaf(YType.uint16, 'eigrp-as'), ['int'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.eigrp_as = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "eigrp-as" + "[eigrp-as='" + str(self.eigrp_as) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Eigrp.EigrpAs, [u'eigrp_as', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Isis_(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: isis_atag
                                
                                	
                                	**type**\: list of  		 :py:class:`IsisAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag>`
                                
                                .. attribute:: ip
                                
                                	Redistribution of IP routes between levels or processes
                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.Ip>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isis-atag", ("isis_atag", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag)), ("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.Ip))])
                                    self._leafs = OrderedDict()

                                    self.ip = None
                                    self._children_name_map["ip"] = "ip"

                                    self.isis_atag = YList(self)
                                    self._segment_path = lambda: "isis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_, [], name, value)


                                class IsisAtag(Entity):
                                    """
                                    
                                    
                                    .. attribute:: isis_atag  (key)
                                    
                                    	ISO routing area tag
                                    	**type**\: str
                                    
                                    .. attribute:: ip
                                    
                                    	Redistribution of IP routes between levels or processes
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag, self).__init__()

                                        self.yang_name = "isis-atag"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['isis_atag']
                                        self._child_classes = OrderedDict([("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip))])
                                        self._leafs = OrderedDict([
                                            ('isis_atag', (YLeaf(YType.str, 'isis-atag'), ['str'])),
                                        ])
                                        self.isis_atag = None

                                        self.ip = Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip()
                                        self.ip.parent = self
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "isis-atag" + "[isis-atag='" + str(self.isis_atag) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag, [u'isis_atag'], name, value)


                                    class Ip(Entity):
                                        """
                                        Redistribution of IP routes between levels or processes
                                        
                                        .. attribute:: levels
                                        
                                        	
                                        	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS default metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip.MetricType>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-isis'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "isis-atag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip.MetricType')])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.levels = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.IsisAtag.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: external = 0

                                            .. data:: internal = 1

                                            .. data:: rib_metric_as_external = 2

                                            .. data:: rib_metric_as_internal = 3

                                            """

                                            external = Enum.YLeaf(0, "external")

                                            internal = Enum.YLeaf(1, "internal")

                                            rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                            rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Ip(Entity):
                                    """
                                    Redistribution of IP routes between levels or processes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.Ip.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.Ip, self).__init__()

                                        self.yang_name = "ip"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.Ip.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "ip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Isis_.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class IsoIgrp(Entity):
                                """
                                IGRP for OSI networks
                                
                                .. attribute:: iso_atag
                                
                                	
                                	**type**\: list of  		 :py:class:`IsoAtag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp.IsoAtag>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp.RouteMap>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp, self).__init__()

                                    self.yang_name = "iso-igrp"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("iso-atag", ("iso_atag", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp.IsoAtag)), ("route-map", ("route_map", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp.RouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.route_map = None
                                    self._children_name_map["route_map"] = "route-map"

                                    self.iso_atag = YList(self)
                                    self._segment_path = lambda: "iso-igrp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp, [], name, value)


                                class IsoAtag(Entity):
                                    """
                                    
                                    
                                    .. attribute:: iso_atag  (key)
                                    
                                    	ISO routing area tag
                                    	**type**\: str
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp.IsoAtag, self).__init__()

                                        self.yang_name = "iso-atag"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['iso_atag']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('iso_atag', (YLeaf(YType.str, 'iso-atag'), ['str'])),
                                            ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                        ])
                                        self.iso_atag = None
                                        self.route_map = None
                                        self._segment_path = lambda: "iso-atag" + "[iso-atag='" + str(self.iso_atag) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp.IsoAtag, [u'iso_atag', u'route_map'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Route map reference
                                    
                                    .. attribute:: rm_point
                                    
                                    	Pointer to route\-map entries
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('rm_point', (YLeaf(YType.str, 'rm-point'), ['str'])),
                                        ])
                                        self.rm_point = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.IsoIgrp.RouteMap, [u'rm_point'], name, value)


                            class Lisp(Entity):
                                """
                                Locator ID Separation Protocol (LISP)
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Lisp.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Lisp, self).__init__()

                                    self.yang_name = "lisp"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Lisp.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "lisp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Lisp, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Mobile(Entity):
                                """
                                Mobile routes
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Mobile.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Mobile, self).__init__()

                                    self.yang_name = "mobile"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Mobile.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "mobile"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Mobile, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Ospfv3(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: os3_id
                                
                                	
                                	**type**\: list of  		 :py:class:`Os3Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Ospfv3, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("os3-id", ("os3_id", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id))])
                                    self._leafs = OrderedDict()

                                    self.os3_id = YList(self)
                                    self._segment_path = lambda: "ospfv3"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Ospfv3, [], name, value)


                                class Os3Id(Entity):
                                    """
                                    
                                    
                                    .. attribute:: os3_id  (key)
                                    
                                    	Process ID
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id, self).__init__()

                                        self.yang_name = "os3-id"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['os3_id']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('os3_id', (YLeaf(YType.uint16, 'os3-id'), ['int'])),
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.os3_id = None
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "os3-id" + "[os3-id='" + str(self.os3_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Ospfv3.Os3Id, [u'os3_id', u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Rip.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Rip.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "rip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Rip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: clns
                                
                                	Redistribution of BGP NSAP routes
                                	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Clns>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ip
                                
                                	Redistribution of BGP IP routes
                                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Ip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: levels
                                
                                	
                                	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                
                                .. attribute:: metric
                                
                                	ISIS default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.MetricType>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("clns", ("clns", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Clns)), ("ip", ("ip", Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Ip))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.MetricType')])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.levels = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None

                                    self.clns = None
                                    self._children_name_map["clns"] = "clns"

                                    self.ip = None
                                    self._children_name_map["ip"] = "ip"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: external = 0

                                    .. data:: internal = 1

                                    .. data:: rib_metric_as_external = 2

                                    .. data:: rib_metric_as_internal = 3

                                    """

                                    external = Enum.YLeaf(0, "external")

                                    internal = Enum.YLeaf(1, "internal")

                                    rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                    rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Clns(Entity):
                                    """
                                    Redistribution of BGP NSAP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Clns.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Clns, self).__init__()

                                        self.yang_name = "clns"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Clns.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "clns"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Clns, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                                class Ip(Entity):
                                    """
                                    Redistribution of BGP IP routes
                                    
                                    .. attribute:: levels
                                    
                                    	
                                    	**type**\:  :py:class:`IsisRoutesLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.IsisRoutesLevelType>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Ip.MetricType>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Ip, self).__init__()

                                        self.yang_name = "ip"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'IsisRoutesLevelType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Ip.MetricType')])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.levels = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.route_map = None
                                        self._segment_path = lambda: "ip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Redistribute.Vrf.Global.Static.Ip, [u'levels', u'metric', u'metric_type', u'route_map'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: external = 0

                                        .. data:: internal = 1

                                        .. data:: rib_metric_as_external = 2

                                        .. data:: rib_metric_as_internal = 3

                                        """

                                        external = Enum.YLeaf(0, "external")

                                        internal = Enum.YLeaf(1, "internal")

                                        rib_metric_as_external = Enum.YLeaf(2, "rib-metric-as-external")

                                        rib_metric_as_internal = Enum.YLeaf(3, "rib-metric-as-internal")



                class SetAttachedBit(Entity):
                    """
                    Conditionally advertise us as attached to L2
                    
                    .. attribute:: route_map
                    
                    	Route\-map reference
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.SetAttachedBit, self).__init__()

                        self.yang_name = "set-attached-bit"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "set-attached-bit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.SetAttachedBit, [u'route_map'], name, value)


                class Snmp(Entity):
                    """
                    Modify snmp parameters
                    
                    .. attribute:: context
                    
                    	Configure a SNMP context
                    	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Snmp.Context>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Snmp, self).__init__()

                        self.yang_name = "snmp"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("context", ("context", Native.Router.IsisContainer.Isis.Snmp.Context))])
                        self._leafs = OrderedDict()

                        self.context = YList(self)
                        self._segment_path = lambda: "snmp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Snmp, [], name, value)


                    class Context(Entity):
                        """
                        Configure a SNMP context
                        
                        .. attribute:: name  (key)
                        
                        	Context Name
                        	**type**\: str
                        
                        .. attribute:: community
                        
                        	Configure a SNMP v2c Community string and access privs
                        	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Snmp.Context.Community>`
                        
                        .. attribute:: user
                        
                        	Configure a SNMP v3 user
                        	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Snmp.Context.User>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Snmp.Context, self).__init__()

                            self.yang_name = "context"
                            self.yang_parent_name = "snmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("community", ("community", Native.Router.IsisContainer.Isis.Snmp.Context.Community)), ("user", ("user", Native.Router.IsisContainer.Isis.Snmp.Context.User))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.community = Native.Router.IsisContainer.Isis.Snmp.Context.Community()
                            self.community.parent = self
                            self._children_name_map["community"] = "community"

                            self.user = Native.Router.IsisContainer.Isis.Snmp.Context.User()
                            self.user.parent = self
                            self._children_name_map["user"] = "user"
                            self._segment_path = lambda: "context" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Snmp.Context, [u'name'], name, value)


                        class Community(Entity):
                            """
                            Configure a SNMP v2c Community string and access privs
                            
                            .. attribute:: community_string
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: access
                            
                            	
                            	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Snmp.Context.Community.Access>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Snmp.Context.Community, self).__init__()

                                self.yang_name = "community"
                                self.yang_parent_name = "context"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("access", ("access", Native.Router.IsisContainer.Isis.Snmp.Context.Community.Access))])
                                self._leafs = OrderedDict([
                                    ('community_string', (YLeaf(YType.str, 'community-string'), ['str'])),
                                ])
                                self.community_string = None

                                self.access = Native.Router.IsisContainer.Isis.Snmp.Context.Community.Access()
                                self.access.parent = self
                                self._children_name_map["access"] = "access"
                                self._segment_path = lambda: "community"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Snmp.Context.Community, [u'community_string'], name, value)


                            class Access(Entity):
                                """
                                
                                
                                .. attribute:: standard_acl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..99
                                
                                .. attribute:: expanded_acl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1300..1999
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: ipv6
                                
                                	Specify IPv6 Named Access\-List
                                	**type**\: str
                                
                                .. attribute:: ro
                                
                                	Read\-only access with this community string
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rw
                                
                                	Read\-write access with this community string
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Snmp.Context.Community.Access, self).__init__()

                                    self.yang_name = "access"
                                    self.yang_parent_name = "community"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                        ('expanded_acl', (YLeaf(YType.uint32, 'expanded-acl'), ['int'])),
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ('ro', (YLeaf(YType.empty, 'ro'), ['Empty'])),
                                        ('rw', (YLeaf(YType.empty, 'rw'), ['Empty'])),
                                    ])
                                    self.standard_acl = None
                                    self.expanded_acl = None
                                    self.acl_name = None
                                    self.ipv6 = None
                                    self.ro = None
                                    self.rw = None
                                    self._segment_path = lambda: "access"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Snmp.Context.Community.Access, [u'standard_acl', u'expanded_acl', u'acl_name', u'ipv6', u'ro', u'rw'], name, value)


                        class User(Entity):
                            """
                            Configure a SNMP v3 user
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: permisssion
                            
                            	
                            	**type**\:  :py:class:`Permisssion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Snmp.Context.User, self).__init__()

                                self.yang_name = "user"
                                self.yang_parent_name = "context"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("permisssion", ("permisssion", Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.permisssion = Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion()
                                self.permisssion.parent = self
                                self._children_name_map["permisssion"] = "permisssion"
                                self._segment_path = lambda: "user"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Snmp.Context.User, [u'name'], name, value)


                            class Permisssion(Entity):
                                """
                                
                                
                                .. attribute:: access
                                
                                	specify an access\-list associated with this group
                                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion.Access>`
                                
                                .. attribute:: auth
                                
                                	authentication parameters for the user
                                	**type**\:  :py:class:`Auth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion.Auth>`
                                
                                .. attribute:: credential
                                
                                	If the user password is already configured and saved
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: encrypted
                                
                                	specifying passwords as MD5 or SHA digests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion, self).__init__()

                                    self.yang_name = "permisssion"
                                    self.yang_parent_name = "user"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("access", ("access", Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion.Access)), ("auth", ("auth", Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion.Auth))])
                                    self._leafs = OrderedDict([
                                        ('credential', (YLeaf(YType.empty, 'credential'), ['Empty'])),
                                        ('encrypted', (YLeaf(YType.empty, 'encrypted'), ['Empty'])),
                                    ])
                                    self.credential = None
                                    self.encrypted = None

                                    self.access = Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion.Access()
                                    self.access.parent = self
                                    self._children_name_map["access"] = "access"

                                    self.auth = Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion.Auth()
                                    self.auth.parent = self
                                    self._children_name_map["auth"] = "auth"
                                    self._segment_path = lambda: "permisssion"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion, [u'credential', u'encrypted'], name, value)


                                class Access(Entity):
                                    """
                                    specify an access\-list associated with this group
                                    
                                    .. attribute:: standard_acl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: acl_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: ipv6
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion.Access, self).__init__()

                                        self.yang_name = "access"
                                        self.yang_parent_name = "permisssion"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.standard_acl = None
                                        self.acl_name = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "access"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion.Access, [u'standard_acl', u'acl_name', u'ipv6'], name, value)


                                class Auth(Entity):
                                    """
                                    authentication parameters for the user
                                    
                                    .. attribute:: md5
                                    
                                    	Use HMAC MD5 algorithm for authentication
                                    	**type**\: str
                                    
                                    .. attribute:: sha
                                    
                                    	Use HMAC SHA algorithm for authentication
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion.Auth, self).__init__()

                                        self.yang_name = "auth"
                                        self.yang_parent_name = "permisssion"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('md5', (YLeaf(YType.str, 'md5'), ['str'])),
                                            ('sha', (YLeaf(YType.str, 'sha'), ['str'])),
                                        ])
                                        self.md5 = None
                                        self.sha = None
                                        self._segment_path = lambda: "auth"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.Snmp.Context.User.Permisssion.Auth, [u'md5', u'sha'], name, value)


                class SummaryAddress(Entity):
                    """
                    Configure IP address summaries
                    
                    .. attribute:: ip  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mask  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: level_1
                    
                    	Summarize into level\-1 area
                    	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SummaryAddress.Level1>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: level_1_2
                    
                    	Summarize into both area and sub\-domain
                    	**type**\:  :py:class:`Level12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SummaryAddress.Level12>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: level_2
                    
                    	Summarize into level\-2 sub\-domain
                    	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SummaryAddress.Level2>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: metric_tag_container
                    
                    	
                    	**type**\:  :py:class:`MetricTagContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SummaryAddress.MetricTagContainer>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['ip','mask']
                        self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.IsisContainer.Isis.SummaryAddress.Level1)), ("level-1-2", ("level_1_2", Native.Router.IsisContainer.Isis.SummaryAddress.Level12)), ("level-2", ("level_2", Native.Router.IsisContainer.Isis.SummaryAddress.Level2)), ("metric-tag-container", ("metric_tag_container", Native.Router.IsisContainer.Isis.SummaryAddress.MetricTagContainer))])
                        self._leafs = OrderedDict([
                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                        ])
                        self.ip = None
                        self.mask = None

                        self.level_1 = None
                        self._children_name_map["level_1"] = "level-1"

                        self.level_1_2 = None
                        self._children_name_map["level_1_2"] = "level-1-2"

                        self.level_2 = None
                        self._children_name_map["level_2"] = "level-2"

                        self.metric_tag_container = Native.Router.IsisContainer.Isis.SummaryAddress.MetricTagContainer()
                        self.metric_tag_container.parent = self
                        self._children_name_map["metric_tag_container"] = "metric-tag-container"
                        self._segment_path = lambda: "summary-address" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.SummaryAddress, [u'ip', u'mask'], name, value)


                    class Level1(Entity):
                        """
                        Summarize into level\-1 area
                        
                        .. attribute:: metric
                        
                        	Set metric for summay route
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: tag
                        
                        	Set tag
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.SummaryAddress.Level1, self).__init__()

                            self.yang_name = "level-1"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                            ])
                            self.metric = None
                            self.tag = None
                            self._segment_path = lambda: "level-1"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.SummaryAddress.Level1, [u'metric', u'tag'], name, value)


                    class Level12(Entity):
                        """
                        Summarize into both area and sub\-domain
                        
                        .. attribute:: metric
                        
                        	Set metric for summay route
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: tag
                        
                        	Set tag
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.SummaryAddress.Level12, self).__init__()

                            self.yang_name = "level-1-2"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                            ])
                            self.metric = None
                            self.tag = None
                            self._segment_path = lambda: "level-1-2"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.SummaryAddress.Level12, [u'metric', u'tag'], name, value)


                    class Level2(Entity):
                        """
                        Summarize into level\-2 sub\-domain
                        
                        .. attribute:: metric
                        
                        	Set metric for summay route
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: tag
                        
                        	Set tag
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.SummaryAddress.Level2, self).__init__()

                            self.yang_name = "level-2"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                            ])
                            self.metric = None
                            self.tag = None
                            self._segment_path = lambda: "level-2"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.SummaryAddress.Level2, [u'metric', u'tag'], name, value)


                    class MetricTagContainer(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Set metric for summay route
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: tag
                        
                        	Set tag
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.SummaryAddress.MetricTagContainer, self).__init__()

                            self.yang_name = "metric-tag-container"
                            self.yang_parent_name = "summary-address"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                            ])
                            self.metric = None
                            self.tag = None
                            self._segment_path = lambda: "metric-tag-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.SummaryAddress.MetricTagContainer, [u'metric', u'tag'], name, value)


                class TrafficShare(Entity):
                    """
                    How to compute traffic share over alternate paths
                    
                    .. attribute:: min
                    
                    	All traffic shared among min metric paths
                    	**type**\:  :py:class:`Min <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.TrafficShare.Min>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.TrafficShare, self).__init__()

                        self.yang_name = "traffic-share"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("min", ("min", Native.Router.IsisContainer.Isis.TrafficShare.Min))])
                        self._leafs = OrderedDict()

                        self.min = Native.Router.IsisContainer.Isis.TrafficShare.Min()
                        self.min.parent = self
                        self._children_name_map["min"] = "min"
                        self._segment_path = lambda: "traffic-share"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.TrafficShare, [], name, value)


                    class Min(Entity):
                        """
                        All traffic shared among min metric paths
                        
                        .. attribute:: across_interfaces
                        
                        	Use different interfaces for equal\-cost paths
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.TrafficShare.Min, self).__init__()

                            self.yang_name = "min"
                            self.yang_parent_name = "traffic-share"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                            ])
                            self.across_interfaces = None
                            self._segment_path = lambda: "min"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.TrafficShare.Min, [u'across_interfaces'], name, value)


                class Advertise(Entity):
                    """
                    Control which IP routes flow in L1 and L2 LSPs
                    
                    .. attribute:: passive_only
                    
                    	only interface address of passive interfaces
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Advertise, self).__init__()

                        self.yang_name = "advertise"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('passive_only', (YLeaf(YType.empty, 'passive-only'), ['Empty'])),
                        ])
                        self.passive_only = None
                        self._segment_path = lambda: "advertise"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Advertise, [u'passive_only'], name, value)


                class DefaultInformation(Entity):
                    """
                    Control distribution of default information
                    
                    .. attribute:: originate
                    
                    	Distribute a default route
                    	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.DefaultInformation.Originate>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.DefaultInformation, self).__init__()

                        self.yang_name = "default-information"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("originate", ("originate", Native.Router.IsisContainer.Isis.DefaultInformation.Originate))])
                        self._leafs = OrderedDict()

                        self.originate = None
                        self._children_name_map["originate"] = "originate"
                        self._segment_path = lambda: "default-information"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.DefaultInformation, [], name, value)


                    class Originate(Entity):
                        """
                        Distribute a default route
                        
                        .. attribute:: route_map
                        
                        	Route\-map reference
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.DefaultInformation.Originate, self).__init__()

                            self.yang_name = "originate"
                            self.yang_parent_name = "default-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None
                            self._segment_path = lambda: "originate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.DefaultInformation.Originate, [u'route_map'], name, value)


                class Metric(Entity):
                    """
                    Set ISIS metric for all interfaces
                    
                    .. attribute:: metrics
                    
                    	
                    	**type**\: list of  		 :py:class:`Metrics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Metric.Metrics>`
                    
                    .. attribute:: metric
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..16777214
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Metric, self).__init__()

                        self.yang_name = "metric"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metrics", ("metrics", Native.Router.IsisContainer.Isis.Metric.Metrics))])
                        self._leafs = OrderedDict([
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                        ])
                        self.metric = None

                        self.metrics = YList(self)
                        self._segment_path = lambda: "metric"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Metric, [u'metric'], name, value)


                    class Metrics(Entity):
                        """
                        
                        
                        .. attribute:: level  (key)
                        
                        	
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Metric.Metrics.Level>`
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Metric.Metrics, self).__init__()

                            self.yang_name = "metrics"
                            self.yang_parent_name = "metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['level']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Metric.Metrics.Level')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.level = None
                            self.metric = None
                            self._segment_path = lambda: "metrics" + "[level='" + str(self.level) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Metric.Metrics, [u'level', u'metric'], name, value)

                        class Level(Enum):
                            """
                            Level (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                class PrcInterval(Entity):
                    """
                    Minimum interval between partial route calculations
                    
                    .. attribute:: interval
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    .. attribute:: initial_wait
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    .. attribute:: minimum_wait
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.PrcInterval, self).__init__()

                        self.yang_name = "prc-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                            ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                            ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                        ])
                        self.interval = None
                        self.initial_wait = None
                        self.minimum_wait = None
                        self._segment_path = lambda: "prc-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.PrcInterval, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


                class SetOverloadBit(Entity):
                    """
                    Signal other routers not to use us in SPF
                    
                    .. attribute:: on_startup
                    
                    	Set overload\-bit only temporarily after reboot
                    	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup>`
                    
                    .. attribute:: suppress
                    
                    	If overload\-bit set, suppress the following types of IP prefixes
                    	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SetOverloadBit.Suppress>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.SetOverloadBit, self).__init__()

                        self.yang_name = "set-overload-bit"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("on-startup", ("on_startup", Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup)), ("suppress", ("suppress", Native.Router.IsisContainer.Isis.SetOverloadBit.Suppress))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.on_startup = Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup()
                        self.on_startup.parent = self
                        self._children_name_map["on_startup"] = "on-startup"

                        self.suppress = Native.Router.IsisContainer.Isis.SetOverloadBit.Suppress()
                        self.suppress.parent = self
                        self._children_name_map["suppress"] = "suppress"
                        self._segment_path = lambda: "set-overload-bit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.SetOverloadBit, [], name, value)


                    class OnStartup(Entity):
                        """
                        Set overload\-bit only temporarily after reboot
                        
                        .. attribute:: time
                        
                        	
                        	**type**\:  :py:class:`Time <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.Time>`
                        
                        .. attribute:: wait_for_bgp
                        
                        	Let BGP decide when to unset the overload bit
                        	**type**\:  :py:class:`WaitForBgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.WaitForBgp>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup, self).__init__()

                            self.yang_name = "on-startup"
                            self.yang_parent_name = "set-overload-bit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("time", ("time", Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.Time)), ("wait-for-bgp", ("wait_for_bgp", Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.WaitForBgp))])
                            self._leafs = OrderedDict()

                            self.time = Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.Time()
                            self.time.parent = self
                            self._children_name_map["time"] = "time"

                            self.wait_for_bgp = None
                            self._children_name_map["wait_for_bgp"] = "wait-for-bgp"
                            self._segment_path = lambda: "on-startup"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup, [], name, value)


                        class Time(Entity):
                            """
                            
                            
                            .. attribute:: time
                            
                            	
                            	**type**\: int
                            
                            	**range:** 5..86400
                            
                            .. attribute:: suppress
                            
                            	If overload\-bit set, suppress the following types of IP prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: external
                            
                            	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: interlevel
                            
                            	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.Time, self).__init__()

                                self.yang_name = "time"
                                self.yang_parent_name = "on-startup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                    ('suppress', (YLeaf(YType.empty, 'suppress'), ['Empty'])),
                                    ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                    ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                ])
                                self.time = None
                                self.suppress = None
                                self.external = None
                                self.interlevel = None
                                self._segment_path = lambda: "time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.Time, [u'time', u'suppress', u'external', u'interlevel'], name, value)


                        class WaitForBgp(Entity):
                            """
                            Let BGP decide when to unset the overload bit
                            
                            .. attribute:: suppress
                            
                            	If overload\-bit set, suppress the following types of IP prefixes
                            	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.WaitForBgp.Suppress>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.WaitForBgp, self).__init__()

                                self.yang_name = "wait-for-bgp"
                                self.yang_parent_name = "on-startup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("suppress", ("suppress", Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.WaitForBgp.Suppress))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.suppress = Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.WaitForBgp.Suppress()
                                self.suppress.parent = self
                                self._children_name_map["suppress"] = "suppress"
                                self._segment_path = lambda: "wait-for-bgp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.WaitForBgp, [], name, value)


                            class Suppress(Entity):
                                """
                                If overload\-bit set, suppress the following types of IP prefixes
                                
                                .. attribute:: external
                                
                                	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: interlevel
                                
                                	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.WaitForBgp.Suppress, self).__init__()

                                    self.yang_name = "suppress"
                                    self.yang_parent_name = "wait-for-bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                        ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                    ])
                                    self.external = None
                                    self.interlevel = None
                                    self._segment_path = lambda: "suppress"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.SetOverloadBit.OnStartup.WaitForBgp.Suppress, [u'external', u'interlevel'], name, value)


                    class Suppress(Entity):
                        """
                        If overload\-bit set, suppress the following types of IP prefixes
                        
                        .. attribute:: external
                        
                        	If overload\-bit set, don't advertise IP prefixes learned from other protocols
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: interlevel
                        
                        	If overload\-bit set, don't advertise IP prefixes learned from another ISIS level
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.SetOverloadBit.Suppress, self).__init__()

                            self.yang_name = "suppress"
                            self.yang_parent_name = "set-overload-bit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                            ])
                            self.external = None
                            self.interlevel = None
                            self._segment_path = lambda: "suppress"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.SetOverloadBit.Suppress, [u'external', u'interlevel'], name, value)


                class SpfInterval(Entity):
                    """
                    Minimum interval between SPF calculations
                    
                    .. attribute:: level_1_2
                    
                    	
                    	**type**\: list of  		 :py:class:`Level12 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SpfInterval.Level12>`
                    
                    .. attribute:: intervals
                    
                    	
                    	**type**\:  :py:class:`Intervals <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SpfInterval.Intervals>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.SpfInterval, self).__init__()

                        self.yang_name = "spf-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level-1-2", ("level_1_2", Native.Router.IsisContainer.Isis.SpfInterval.Level12)), ("intervals", ("intervals", Native.Router.IsisContainer.Isis.SpfInterval.Intervals))])
                        self._leafs = OrderedDict()

                        self.intervals = Native.Router.IsisContainer.Isis.SpfInterval.Intervals()
                        self.intervals.parent = self
                        self._children_name_map["intervals"] = "intervals"

                        self.level_1_2 = YList(self)
                        self._segment_path = lambda: "spf-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.SpfInterval, [], name, value)


                    class Level12(Entity):
                        """
                        
                        
                        .. attribute:: level  (key)
                        
                        	
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SpfInterval.Level12.Level>`
                        
                        .. attribute:: interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120
                        
                        .. attribute:: initial_wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        .. attribute:: minimum_wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.SpfInterval.Level12, self).__init__()

                            self.yang_name = "level-1-2"
                            self.yang_parent_name = "spf-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['level']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.SpfInterval.Level12.Level')])),
                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                            ])
                            self.level = None
                            self.interval = None
                            self.initial_wait = None
                            self.minimum_wait = None
                            self._segment_path = lambda: "level-1-2" + "[level='" + str(self.level) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.SpfInterval.Level12, [u'level', u'interval', u'initial_wait', u'minimum_wait'], name, value)

                        class Level(Enum):
                            """
                            Level (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")



                    class Intervals(Entity):
                        """
                        
                        
                        .. attribute:: interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120
                        
                        .. attribute:: initial_wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        .. attribute:: minimum_wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.SpfInterval.Intervals, self).__init__()

                            self.yang_name = "intervals"
                            self.yang_parent_name = "spf-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                ('minimum_wait', (YLeaf(YType.uint32, 'minimum-wait'), ['int'])),
                            ])
                            self.interval = None
                            self.initial_wait = None
                            self.minimum_wait = None
                            self._segment_path = lambda: "intervals"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.SpfInterval.Intervals, [u'interval', u'initial_wait', u'minimum_wait'], name, value)


                class AreaPassword(Entity):
                    """
                    Configure the authentication password for an area
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: authenticate
                    
                    	Authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: snp
                    
                    	SNP PDUs
                    	**type**\:  :py:class:`Snp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.AreaPassword.Snp>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.AreaPassword, self).__init__()

                        self.yang_name = "area-password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('authenticate', (YLeaf(YType.empty, 'authenticate'), ['Empty'])),
                            ('snp', (YLeaf(YType.enumeration, 'snp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.AreaPassword.Snp')])),
                        ])
                        self.name = None
                        self.authenticate = None
                        self.snp = None
                        self._segment_path = lambda: "area-password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.AreaPassword, [u'name', u'authenticate', u'snp'], name, value)

                    class Snp(Enum):
                        """
                        Snp (Enum Class)

                        SNP PDUs

                        .. data:: send_only = 0

                        .. data:: validate = 1

                        """

                        send_only = Enum.YLeaf(0, "send-only")

                        validate = Enum.YLeaf(1, "validate")



                class Authentication(Entity):
                    """
                    ISIS authentication for LSPs
                    
                    .. attribute:: mode
                    
                    	Authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Authentication.KeyChain>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\:  :py:class:`SendOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Authentication.SendOnly>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Router.IsisContainer.Isis.Authentication.Mode)), ("key-chain", ("key_chain", Native.Router.IsisContainer.Isis.Authentication.KeyChain)), ("send-only", ("send_only", Native.Router.IsisContainer.Isis.Authentication.SendOnly))])
                        self._leafs = OrderedDict()

                        self.mode = Native.Router.IsisContainer.Isis.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"

                        self.key_chain = Native.Router.IsisContainer.Isis.Authentication.KeyChain()
                        self.key_chain.parent = self
                        self._children_name_map["key_chain"] = "key-chain"

                        self.send_only = None
                        self._children_name_map["send_only"] = "send-only"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Authentication, [], name, value)


                    class Mode(Entity):
                        """
                        Authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Authentication.Mode.Md5>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: text
                        
                        	Clear text password
                        	**type**\:  :py:class:`Text <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Authentication.Mode.Text>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Router.IsisContainer.Isis.Authentication.Mode.Md5)), ("text", ("text", Native.Router.IsisContainer.Isis.Authentication.Mode.Text))])
                            self._leafs = OrderedDict()

                            self.md5 = None
                            self._children_name_map["md5"] = "md5"

                            self.text = None
                            self._children_name_map["text"] = "text"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Authentication.Mode, [], name, value)


                        class Md5(Entity):
                            """
                            Keyed message digest
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Authentication.Mode.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Authentication.Mode.Md5, [u'levels'], name, value)


                        class Text(Entity):
                            """
                            Clear text password
                            
                            .. attribute:: levels
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Authentication.Mode.Text, self).__init__()

                                self.yang_name = "text"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                ])
                                self.levels = None
                                self._segment_path = lambda: "text"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Authentication.Mode.Text, [u'levels'], name, value)


                    class KeyChain(Entity):
                        """
                        Authentication key\-chain
                        
                        .. attribute:: key_chain_list
                        
                        	
                        	**type**\: list of  		 :py:class:`KeyChainList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Authentication.KeyChain.KeyChainList>`
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Authentication.KeyChain, self).__init__()

                            self.yang_name = "key-chain"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("key-chain-list", ("key_chain_list", Native.Router.IsisContainer.Isis.Authentication.KeyChain.KeyChainList))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.key_chain_list = YList(self)
                            self._segment_path = lambda: "key-chain"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Authentication.KeyChain, [u'name'], name, value)


                        class KeyChainList(Entity):
                            """
                            
                            
                            .. attribute:: levels  (key)
                            
                            	
                            	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Authentication.KeyChain.KeyChainList, self).__init__()

                                self.yang_name = "key-chain-list"
                                self.yang_parent_name = "key-chain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['levels']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.levels = None
                                self.name = None
                                self._segment_path = lambda: "key-chain-list" + "[levels='" + str(self.levels) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Authentication.KeyChain.KeyChainList, [u'levels', u'name'], name, value)


                    class SendOnly(Entity):
                        """
                        Authentication send only, receive ignore
                        
                        .. attribute:: levels
                        
                        	
                        	**type**\:  :py:class:`AuthenticationLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis.AuthenticationLevelType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Authentication.SendOnly, self).__init__()

                            self.yang_name = "send-only"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('levels', (YLeaf(YType.enumeration, 'levels'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_isis', 'AuthenticationLevelType', '')])),
                            ])
                            self.levels = None
                            self._segment_path = lambda: "send-only"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Authentication.SendOnly, [u'levels'], name, value)


                class DistributeList(Entity):
                    """
                    Filter networks in routing updates
                    
                    .. attribute:: acl_name
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    .. attribute:: in_
                    
                    	Filter incoming routing updates
                    	**type**\: str
                    
                    .. attribute:: gateway
                    
                    	Filtering incoming updates based on gateway
                    	**type**\: str
                    
                    .. attribute:: prefix
                    
                    	Filter prefixes in routing updates
                    	**type**\: str
                    
                    .. attribute:: gateway_prefix_in
                    
                    	Filter incoming routing updates
                    	**type**\: str
                    
                    .. attribute:: route_map
                    
                    	Filter prefixes based on the route\-map
                    	**type**\: str
                    
                    .. attribute:: route_map_in
                    
                    	Filter incoming routing updates
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.DistributeList, self).__init__()

                        self.yang_name = "distribute-list"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','int','str'])),
                            ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                            ('gateway', (YLeaf(YType.str, 'gateway'), ['str'])),
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ('gateway_prefix_in', (YLeaf(YType.str, 'gateway-prefix-in'), ['str'])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ('route_map_in', (YLeaf(YType.empty, 'route-map-in'), ['Empty'])),
                        ])
                        self.acl_name = None
                        self.in_ = None
                        self.gateway = None
                        self.prefix = None
                        self.gateway_prefix_in = None
                        self.route_map = None
                        self.route_map_in = None
                        self._segment_path = lambda: "distribute-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.DistributeList, [u'acl_name', u'in_', u'gateway', u'prefix', u'gateway_prefix_in', u'route_map', u'route_map_in'], name, value)


                class DomainPassword(Entity):
                    """
                    Set the authentication password for a routing domain
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: authenticate
                    
                    	Authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: snp
                    
                    	SNP PDUs
                    	**type**\:  :py:class:`Snp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.DomainPassword.Snp>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.DomainPassword, self).__init__()

                        self.yang_name = "domain-password"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('authenticate', (YLeaf(YType.empty, 'authenticate'), ['Empty'])),
                            ('snp', (YLeaf(YType.enumeration, 'snp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.DomainPassword.Snp')])),
                        ])
                        self.name = None
                        self.authenticate = None
                        self.snp = None
                        self._segment_path = lambda: "domain-password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.DomainPassword, [u'name', u'authenticate', u'snp'], name, value)

                    class Snp(Enum):
                        """
                        Snp (Enum Class)

                        SNP PDUs

                        .. data:: send_only = 0

                        .. data:: validate = 1

                        """

                        send_only = Enum.YLeaf(0, "send-only")

                        validate = Enum.YLeaf(1, "validate")



                class FastFlood(Entity):
                    """
                    Flood LSPs (that triggered SPF) before running SPF
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..15
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.FastFlood, self).__init__()

                        self.yang_name = "fast-flood"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                        ])
                        self.number = None
                        self._segment_path = lambda: "fast-flood"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.FastFlood, [u'number'], name, value)


                class FastReroute(Entity):
                    """
                    Configure Fast\-Reroute
                    
                    .. attribute:: load_sharing
                    
                    	Distributes repair paths equally among links and prefixes
                    	**type**\:  :py:class:`LoadSharing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.LoadSharing>`
                    
                    .. attribute:: per_prefix
                    
                    	Enable Fast\-Reroute Per\-Prefix
                    	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.PerPrefix>`
                    
                    .. attribute:: remote_lfa
                    
                    	Configuring fast\-reroute remote\-lfa
                    	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa>`
                    
                    .. attribute:: tie_break
                    
                    	Set repair path preference
                    	**type**\:  :py:class:`TieBreak <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.TieBreak>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.FastReroute, self).__init__()

                        self.yang_name = "fast-reroute"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("load-sharing", ("load_sharing", Native.Router.IsisContainer.Isis.FastReroute.LoadSharing)), ("per-prefix", ("per_prefix", Native.Router.IsisContainer.Isis.FastReroute.PerPrefix)), ("remote-lfa", ("remote_lfa", Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa)), ("tie-break", ("tie_break", Native.Router.IsisContainer.Isis.FastReroute.TieBreak))])
                        self._leafs = OrderedDict()

                        self.load_sharing = Native.Router.IsisContainer.Isis.FastReroute.LoadSharing()
                        self.load_sharing.parent = self
                        self._children_name_map["load_sharing"] = "load-sharing"

                        self.per_prefix = Native.Router.IsisContainer.Isis.FastReroute.PerPrefix()
                        self.per_prefix.parent = self
                        self._children_name_map["per_prefix"] = "per-prefix"

                        self.remote_lfa = Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa()
                        self.remote_lfa.parent = self
                        self._children_name_map["remote_lfa"] = "remote-lfa"

                        self.tie_break = Native.Router.IsisContainer.Isis.FastReroute.TieBreak()
                        self.tie_break.parent = self
                        self._children_name_map["tie_break"] = "tie-break"
                        self._segment_path = lambda: "fast-reroute"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute, [], name, value)


                    class LoadSharing(Entity):
                        """
                        Distributes repair paths equally among links and prefixes
                        
                        .. attribute:: level_1
                        
                        	Apply to level\-1
                        	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.LoadSharing.Level1>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: level_2
                        
                        	Apply to level\-2
                        	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.LoadSharing.Level2>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.FastReroute.LoadSharing, self).__init__()

                            self.yang_name = "load-sharing"
                            self.yang_parent_name = "fast-reroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.IsisContainer.Isis.FastReroute.LoadSharing.Level1)), ("level-2", ("level_2", Native.Router.IsisContainer.Isis.FastReroute.LoadSharing.Level2))])
                            self._leafs = OrderedDict()

                            self.level_1 = None
                            self._children_name_map["level_1"] = "level-1"

                            self.level_2 = None
                            self._children_name_map["level_2"] = "level-2"
                            self._segment_path = lambda: "load-sharing"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.LoadSharing, [], name, value)


                        class Level1(Entity):
                            """
                            Apply to level\-1
                            
                            .. attribute:: disable
                            
                            	Disable load\-sharing
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.FastReroute.LoadSharing.Level1, self).__init__()

                                self.yang_name = "level-1"
                                self.yang_parent_name = "load-sharing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "level-1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.LoadSharing.Level1, [u'disable'], name, value)


                        class Level2(Entity):
                            """
                            Apply to level\-2
                            
                            .. attribute:: disable
                            
                            	Disable load\-sharing
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.FastReroute.LoadSharing.Level2, self).__init__()

                                self.yang_name = "level-2"
                                self.yang_parent_name = "load-sharing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "level-2"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.LoadSharing.Level2, [u'disable'], name, value)


                    class PerPrefix(Entity):
                        """
                        Enable Fast\-Reroute Per\-Prefix
                        
                        .. attribute:: level_1
                        
                        	Apply to level\-1
                        	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.PerPrefix.Level1>`
                        
                        .. attribute:: level_2
                        
                        	Apply to level\-2
                        	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.PerPrefix.Level2>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.FastReroute.PerPrefix, self).__init__()

                            self.yang_name = "per-prefix"
                            self.yang_parent_name = "fast-reroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.IsisContainer.Isis.FastReroute.PerPrefix.Level1)), ("level-2", ("level_2", Native.Router.IsisContainer.Isis.FastReroute.PerPrefix.Level2))])
                            self._leafs = OrderedDict()

                            self.level_1 = Native.Router.IsisContainer.Isis.FastReroute.PerPrefix.Level1()
                            self.level_1.parent = self
                            self._children_name_map["level_1"] = "level-1"

                            self.level_2 = Native.Router.IsisContainer.Isis.FastReroute.PerPrefix.Level2()
                            self.level_2.parent = self
                            self._children_name_map["level_2"] = "level-2"
                            self._segment_path = lambda: "per-prefix"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.PerPrefix, [], name, value)


                        class Level1(Entity):
                            """
                            Apply to level\-1
                            
                            .. attribute:: all
                            
                            	Enable Fast\-Reroute for primary paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	route\-map name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.FastReroute.PerPrefix.Level1, self).__init__()

                                self.yang_name = "level-1"
                                self.yang_parent_name = "per-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.all = None
                                self.route_map = None
                                self._segment_path = lambda: "level-1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.PerPrefix.Level1, [u'all', u'route_map'], name, value)


                        class Level2(Entity):
                            """
                            Apply to level\-2
                            
                            .. attribute:: all
                            
                            	Enable Fast\-Reroute for primary paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	route\-map name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.FastReroute.PerPrefix.Level2, self).__init__()

                                self.yang_name = "level-2"
                                self.yang_parent_name = "per-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.all = None
                                self.route_map = None
                                self._segment_path = lambda: "level-2"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.PerPrefix.Level2, [u'all', u'route_map'], name, value)


                    class RemoteLfa(Entity):
                        """
                        Configuring fast\-reroute remote\-lfa
                        
                        .. attribute:: level_1
                        
                        	Apply to level\-1
                        	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1>`
                        
                        .. attribute:: level_2
                        
                        	Apply to level\-2
                        	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa, self).__init__()

                            self.yang_name = "remote-lfa"
                            self.yang_parent_name = "fast-reroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1)), ("level-2", ("level_2", Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2))])
                            self._leafs = OrderedDict()

                            self.level_1 = Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1()
                            self.level_1.parent = self
                            self._children_name_map["level_1"] = "level-1"

                            self.level_2 = Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2()
                            self.level_2.parent = self
                            self._children_name_map["level_2"] = "level-2"
                            self._segment_path = lambda: "remote-lfa"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa, [], name, value)


                        class Level1(Entity):
                            """
                            Apply to level\-1
                            
                            .. attribute:: mpls_ldp
                            
                            	Use mpls\-ldp tunnel type
                            	**type**\:  :py:class:`MplsLdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1.MplsLdp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1, self).__init__()

                                self.yang_name = "level-1"
                                self.yang_parent_name = "remote-lfa"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mpls-ldp", ("mpls_ldp", Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1.MplsLdp))])
                                self._leafs = OrderedDict()

                                self.mpls_ldp = None
                                self._children_name_map["mpls_ldp"] = "mpls-ldp"
                                self._segment_path = lambda: "level-1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1, [], name, value)


                            class MplsLdp(Entity):
                                """
                                Use mpls\-ldp tunnel type
                                
                                .. attribute:: maximum_metric
                                
                                	maximum metric to reach release node
                                	**type**\:  :py:class:`MaximumMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1.MplsLdp.MaximumMetric>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1.MplsLdp, self).__init__()

                                    self.yang_name = "mpls-ldp"
                                    self.yang_parent_name = "level-1"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("maximum-metric", ("maximum_metric", Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1.MplsLdp.MaximumMetric))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.maximum_metric = None
                                    self._children_name_map["maximum_metric"] = "maximum-metric"
                                    self._segment_path = lambda: "mpls-ldp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1.MplsLdp, [], name, value)


                                class MaximumMetric(Entity):
                                    """
                                    maximum metric to reach release node
                                    
                                    .. attribute:: max_met
                                    
                                    	metric value
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1.MplsLdp.MaximumMetric, self).__init__()

                                        self.yang_name = "maximum-metric"
                                        self.yang_parent_name = "mpls-ldp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('max_met', (YLeaf(YType.uint32, 'max-met'), ['int'])),
                                        ])
                                        self.max_met = None
                                        self._segment_path = lambda: "maximum-metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level1.MplsLdp.MaximumMetric, [u'max_met'], name, value)


                        class Level2(Entity):
                            """
                            Apply to level\-2
                            
                            .. attribute:: mpls_ldp
                            
                            	Use mpls\-ldp tunnel type
                            	**type**\:  :py:class:`MplsLdp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2.MplsLdp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2, self).__init__()

                                self.yang_name = "level-2"
                                self.yang_parent_name = "remote-lfa"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mpls-ldp", ("mpls_ldp", Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2.MplsLdp))])
                                self._leafs = OrderedDict()

                                self.mpls_ldp = None
                                self._children_name_map["mpls_ldp"] = "mpls-ldp"
                                self._segment_path = lambda: "level-2"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2, [], name, value)


                            class MplsLdp(Entity):
                                """
                                Use mpls\-ldp tunnel type
                                
                                .. attribute:: maximum_metric
                                
                                	maximum metric to reach release node
                                	**type**\:  :py:class:`MaximumMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2.MplsLdp.MaximumMetric>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2.MplsLdp, self).__init__()

                                    self.yang_name = "mpls-ldp"
                                    self.yang_parent_name = "level-2"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("maximum-metric", ("maximum_metric", Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2.MplsLdp.MaximumMetric))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.maximum_metric = None
                                    self._children_name_map["maximum_metric"] = "maximum-metric"
                                    self._segment_path = lambda: "mpls-ldp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2.MplsLdp, [], name, value)


                                class MaximumMetric(Entity):
                                    """
                                    maximum metric to reach release node
                                    
                                    .. attribute:: max_met
                                    
                                    	metric value
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-isis'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2.MplsLdp.MaximumMetric, self).__init__()

                                        self.yang_name = "maximum-metric"
                                        self.yang_parent_name = "mpls-ldp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('max_met', (YLeaf(YType.uint32, 'max-met'), ['int'])),
                                        ])
                                        self.max_met = None
                                        self._segment_path = lambda: "maximum-metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.RemoteLfa.Level2.MplsLdp.MaximumMetric, [u'max_met'], name, value)


                    class TieBreak(Entity):
                        """
                        Set repair path preference
                        
                        .. attribute:: level_1
                        
                        	Apply to level\-1
                        	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.TieBreak.Level1>`
                        
                        .. attribute:: level_2
                        
                        	Apply to level\-2
                        	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.FastReroute.TieBreak.Level2>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.FastReroute.TieBreak, self).__init__()

                            self.yang_name = "tie-break"
                            self.yang_parent_name = "fast-reroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.IsisContainer.Isis.FastReroute.TieBreak.Level1)), ("level-2", ("level_2", Native.Router.IsisContainer.Isis.FastReroute.TieBreak.Level2))])
                            self._leafs = OrderedDict()

                            self.level_1 = Native.Router.IsisContainer.Isis.FastReroute.TieBreak.Level1()
                            self.level_1.parent = self
                            self._children_name_map["level_1"] = "level-1"

                            self.level_2 = Native.Router.IsisContainer.Isis.FastReroute.TieBreak.Level2()
                            self.level_2.parent = self
                            self._children_name_map["level_2"] = "level-2"
                            self._segment_path = lambda: "tie-break"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.TieBreak, [], name, value)


                        class Level1(Entity):
                            """
                            Apply to level\-1
                            
                            .. attribute:: downstream
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: linecard_disjoint
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: lowest_backup_path_metric
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: node_protecting
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: primary_path
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: secondary_path
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: srlg_disjoint
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.FastReroute.TieBreak.Level1, self).__init__()

                                self.yang_name = "level-1"
                                self.yang_parent_name = "tie-break"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('downstream', (YLeaf(YType.uint8, 'downstream'), ['int'])),
                                    ('linecard_disjoint', (YLeaf(YType.uint8, 'linecard-disjoint'), ['int'])),
                                    ('lowest_backup_path_metric', (YLeaf(YType.uint8, 'lowest-backup-path-metric'), ['int'])),
                                    ('node_protecting', (YLeaf(YType.uint8, 'node-protecting'), ['int'])),
                                    ('primary_path', (YLeaf(YType.uint8, 'primary-path'), ['int'])),
                                    ('secondary_path', (YLeaf(YType.uint8, 'secondary-path'), ['int'])),
                                    ('srlg_disjoint', (YLeaf(YType.uint8, 'srlg-disjoint'), ['int'])),
                                ])
                                self.downstream = None
                                self.linecard_disjoint = None
                                self.lowest_backup_path_metric = None
                                self.node_protecting = None
                                self.primary_path = None
                                self.secondary_path = None
                                self.srlg_disjoint = None
                                self._segment_path = lambda: "level-1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.TieBreak.Level1, [u'downstream', u'linecard_disjoint', u'lowest_backup_path_metric', u'node_protecting', u'primary_path', u'secondary_path', u'srlg_disjoint'], name, value)


                        class Level2(Entity):
                            """
                            Apply to level\-2
                            
                            .. attribute:: downstream
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: linecard_disjoint
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: lowest_backup_path_metric
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: node_protecting
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: primary_path
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: secondary_path
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: srlg_disjoint
                            
                            	priority number
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.FastReroute.TieBreak.Level2, self).__init__()

                                self.yang_name = "level-2"
                                self.yang_parent_name = "tie-break"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('downstream', (YLeaf(YType.uint8, 'downstream'), ['int'])),
                                    ('linecard_disjoint', (YLeaf(YType.uint8, 'linecard-disjoint'), ['int'])),
                                    ('lowest_backup_path_metric', (YLeaf(YType.uint8, 'lowest-backup-path-metric'), ['int'])),
                                    ('node_protecting', (YLeaf(YType.uint8, 'node-protecting'), ['int'])),
                                    ('primary_path', (YLeaf(YType.uint8, 'primary-path'), ['int'])),
                                    ('secondary_path', (YLeaf(YType.uint8, 'secondary-path'), ['int'])),
                                    ('srlg_disjoint', (YLeaf(YType.uint8, 'srlg-disjoint'), ['int'])),
                                ])
                                self.downstream = None
                                self.linecard_disjoint = None
                                self.lowest_backup_path_metric = None
                                self.node_protecting = None
                                self.primary_path = None
                                self.secondary_path = None
                                self.srlg_disjoint = None
                                self._segment_path = lambda: "level-2"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.FastReroute.TieBreak.Level2, [u'downstream', u'linecard_disjoint', u'lowest_backup_path_metric', u'node_protecting', u'primary_path', u'secondary_path', u'srlg_disjoint'], name, value)


                class TiLfa(Entity):
                    """
                    
                    
                    .. attribute:: level_1
                    
                    	Apply to level\-1
                    	**type**\:  :py:class:`Level1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.TiLfa.Level1>`
                    
                    .. attribute:: level_2
                    
                    	Apply to level\-2
                    	**type**\:  :py:class:`Level2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.TiLfa.Level2>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.TiLfa, self).__init__()

                        self.yang_name = "ti-lfa"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level-1", ("level_1", Native.Router.IsisContainer.Isis.TiLfa.Level1)), ("level-2", ("level_2", Native.Router.IsisContainer.Isis.TiLfa.Level2))])
                        self._leafs = OrderedDict()

                        self.level_1 = Native.Router.IsisContainer.Isis.TiLfa.Level1()
                        self.level_1.parent = self
                        self._children_name_map["level_1"] = "level-1"

                        self.level_2 = None
                        self._children_name_map["level_2"] = "level-2"
                        self._segment_path = lambda: "ti-lfa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.TiLfa, [], name, value)


                    class Level1(Entity):
                        """
                        Apply to level\-1
                        
                        .. attribute:: maximum_metric
                        
                        	maximum metric to reach release node
                        	**type**\:  :py:class:`MaximumMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.TiLfa.Level1.MaximumMetric>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.TiLfa.Level1, self).__init__()

                            self.yang_name = "level-1"
                            self.yang_parent_name = "ti-lfa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("maximum-metric", ("maximum_metric", Native.Router.IsisContainer.Isis.TiLfa.Level1.MaximumMetric))])
                            self._leafs = OrderedDict()

                            self.maximum_metric = Native.Router.IsisContainer.Isis.TiLfa.Level1.MaximumMetric()
                            self.maximum_metric.parent = self
                            self._children_name_map["maximum_metric"] = "maximum-metric"
                            self._segment_path = lambda: "level-1"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.TiLfa.Level1, [], name, value)


                        class MaximumMetric(Entity):
                            """
                            maximum metric to reach release node
                            
                            .. attribute:: max_met
                            
                            	metric value
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.TiLfa.Level1.MaximumMetric, self).__init__()

                                self.yang_name = "maximum-metric"
                                self.yang_parent_name = "level-1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_met', (YLeaf(YType.uint32, 'max-met'), ['int'])),
                                ])
                                self.max_met = None
                                self._segment_path = lambda: "maximum-metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.TiLfa.Level1.MaximumMetric, [u'max_met'], name, value)


                    class Level2(Entity):
                        """
                        Apply to level\-2
                        
                        .. attribute:: maximum_metric
                        
                        	maximum metric to reach release node
                        	**type**\:  :py:class:`MaximumMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.TiLfa.Level2.MaximumMetric>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.TiLfa.Level2, self).__init__()

                            self.yang_name = "level-2"
                            self.yang_parent_name = "ti-lfa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("maximum-metric", ("maximum_metric", Native.Router.IsisContainer.Isis.TiLfa.Level2.MaximumMetric))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.maximum_metric = Native.Router.IsisContainer.Isis.TiLfa.Level2.MaximumMetric()
                            self.maximum_metric.parent = self
                            self._children_name_map["maximum_metric"] = "maximum-metric"
                            self._segment_path = lambda: "level-2"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.TiLfa.Level2, [], name, value)


                        class MaximumMetric(Entity):
                            """
                            maximum metric to reach release node
                            
                            .. attribute:: max_met
                            
                            	metric value
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.TiLfa.Level2.MaximumMetric, self).__init__()

                                self.yang_name = "maximum-metric"
                                self.yang_parent_name = "level-2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_met', (YLeaf(YType.uint32, 'max-met'), ['int'])),
                                ])
                                self.max_met = None
                                self._segment_path = lambda: "maximum-metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.TiLfa.Level2.MaximumMetric, [u'max_met'], name, value)


                class Hello(Entity):
                    """
                    Pad ISIS hello PDUs to full MTU
                    
                    .. attribute:: padding
                    
                    	Pad hello PDU
                    	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Hello.Padding>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("padding", ("padding", Native.Router.IsisContainer.Isis.Hello.Padding))])
                        self._leafs = OrderedDict()

                        self.padding = None
                        self._children_name_map["padding"] = "padding"
                        self._segment_path = lambda: "hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Hello, [], name, value)


                    class Padding(Entity):
                        """
                        Pad hello PDU
                        
                        .. attribute:: pad_type
                        
                        	
                        	**type**\:  :py:class:`PadType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Hello.Padding.PadType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Hello.Padding, self).__init__()

                            self.yang_name = "padding"
                            self.yang_parent_name = "hello"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('pad_type', (YLeaf(YType.enumeration, 'pad-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Hello.Padding.PadType')])),
                            ])
                            self.pad_type = None
                            self._segment_path = lambda: "padding"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Hello.Padding, [u'pad_type'], name, value)

                        class PadType(Enum):
                            """
                            PadType (Enum Class)

                            .. data:: multi_point = 0

                            .. data:: point_to_point = 1

                            """

                            multi_point = Enum.YLeaf(0, "multi-point")

                            point_to_point = Enum.YLeaf(1, "point-to-point")



                class Hostname(Entity):
                    """
                    Dynamic hostname for IS\-IS
                    
                    .. attribute:: dynamic
                    
                    	Dynamic hostname
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Hostname, self).__init__()

                        self.yang_name = "hostname"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                        ])
                        self.dynamic = None
                        self._segment_path = lambda: "hostname"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Hostname, [u'dynamic'], name, value)


                class Ispf(Entity):
                    """
                    Configure execution of incremental SPF
                    
                    .. attribute:: level
                    
                    	
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Ispf.Level>`
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..600
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Ispf, self).__init__()

                        self.yang_name = "ispf"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.IsisContainer.Isis.Ispf.Level')])),
                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                        ])
                        self.level = None
                        self.number = None
                        self._segment_path = lambda: "ispf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Ispf, [u'level', u'number'], name, value)

                    class Level(Enum):
                        """
                        Level (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_1_2 = 1

                        .. data:: level_2 = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_1_2 = Enum.YLeaf(1, "level-1-2")

                        level_2 = Enum.YLeaf(2, "level-2")



                class LogAdjacencyChanges(Entity):
                    """
                    Log changes in adjacency state
                    
                    .. attribute:: all
                    
                    	Include changes generated by non\-IIH event
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.LogAdjacencyChanges, self).__init__()

                        self.yang_name = "log-adjacency-changes"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "log-adjacency-changes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.LogAdjacencyChanges, [u'all'], name, value)


                class LspFull(Entity):
                    """
                    If we run out of LSP fragments
                    
                    .. attribute:: suppress
                    
                    	suppress the following types of IP prefixes
                    	**type**\:  :py:class:`Suppress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.LspFull.Suppress>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.LspFull, self).__init__()

                        self.yang_name = "lsp-full"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("suppress", ("suppress", Native.Router.IsisContainer.Isis.LspFull.Suppress))])
                        self._leafs = OrderedDict()

                        self.suppress = Native.Router.IsisContainer.Isis.LspFull.Suppress()
                        self.suppress.parent = self
                        self._children_name_map["suppress"] = "suppress"
                        self._segment_path = lambda: "lsp-full"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.LspFull, [], name, value)


                    class Suppress(Entity):
                        """
                        suppress the following types of IP prefixes
                        
                        .. attribute:: external_interlevel_container
                        
                        	
                        	**type**\:  :py:class:`ExternalInterlevelContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.LspFull.Suppress.ExternalInterlevelContainer>`
                        
                        .. attribute:: none
                        
                        	don't suppress any prefixes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.LspFull.Suppress, self).__init__()

                            self.yang_name = "suppress"
                            self.yang_parent_name = "lsp-full"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("external-interlevel-container", ("external_interlevel_container", Native.Router.IsisContainer.Isis.LspFull.Suppress.ExternalInterlevelContainer))])
                            self._leafs = OrderedDict([
                                ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                            ])
                            self.none = None

                            self.external_interlevel_container = Native.Router.IsisContainer.Isis.LspFull.Suppress.ExternalInterlevelContainer()
                            self.external_interlevel_container.parent = self
                            self._children_name_map["external_interlevel_container"] = "external-interlevel-container"
                            self._segment_path = lambda: "suppress"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.LspFull.Suppress, [u'none'], name, value)


                        class ExternalInterlevelContainer(Entity):
                            """
                            
                            
                            .. attribute:: external
                            
                            	don't advertise IP prefixes learned from other protocols
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: interlevel
                            
                            	don't advertise IP prefixes learned from another ISIS level
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.LspFull.Suppress.ExternalInterlevelContainer, self).__init__()

                                self.yang_name = "external-interlevel-container"
                                self.yang_parent_name = "suppress"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                    ('interlevel', (YLeaf(YType.empty, 'interlevel'), ['Empty'])),
                                ])
                                self.external = None
                                self.interlevel = None
                                self._segment_path = lambda: "external-interlevel-container"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.LspFull.Suppress.ExternalInterlevelContainer, [u'external', u'interlevel'], name, value)


                class LspGenInterval(Entity):
                    """
                    Minimum interval between regenerating same LSP
                    
                    .. attribute:: intervals
                    
                    	
                    	**type**\:  :py:class:`Intervals <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.LspGenInterval.Intervals>`
                    
                    .. attribute:: intervals_levels
                    
                    	
                    	**type**\:  :py:class:`IntervalsLevels <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.LspGenInterval, self).__init__()

                        self.yang_name = "lsp-gen-interval"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("intervals", ("intervals", Native.Router.IsisContainer.Isis.LspGenInterval.Intervals)), ("intervals-levels", ("intervals_levels", Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels))])
                        self._leafs = OrderedDict()

                        self.intervals = Native.Router.IsisContainer.Isis.LspGenInterval.Intervals()
                        self.intervals.parent = self
                        self._children_name_map["intervals"] = "intervals"

                        self.intervals_levels = Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels()
                        self.intervals_levels.parent = self
                        self._children_name_map["intervals_levels"] = "intervals-levels"
                        self._segment_path = lambda: "lsp-gen-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.LspGenInterval, [], name, value)


                    class Intervals(Entity):
                        """
                        
                        
                        .. attribute:: interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120
                        
                        .. attribute:: initial_wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        .. attribute:: wait
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..120000
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.LspGenInterval.Intervals, self).__init__()

                            self.yang_name = "intervals"
                            self.yang_parent_name = "lsp-gen-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                ('wait', (YLeaf(YType.uint32, 'wait'), ['int'])),
                            ])
                            self.interval = None
                            self.initial_wait = None
                            self.wait = None
                            self._segment_path = lambda: "intervals"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.LspGenInterval.Intervals, [u'interval', u'initial_wait', u'wait'], name, value)


                    class IntervalsLevels(Entity):
                        """
                        
                        
                        .. attribute:: intervals_level_1
                        
                        	
                        	**type**\:  :py:class:`IntervalsLevel1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel1>`
                        
                        .. attribute:: intervals_level_2
                        
                        	
                        	**type**\:  :py:class:`IntervalsLevel2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel2>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels, self).__init__()

                            self.yang_name = "intervals-levels"
                            self.yang_parent_name = "lsp-gen-interval"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("intervals-level-1", ("intervals_level_1", Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel1)), ("intervals-level-2", ("intervals_level_2", Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel2))])
                            self._leafs = OrderedDict()

                            self.intervals_level_1 = Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel1()
                            self.intervals_level_1.parent = self
                            self._children_name_map["intervals_level_1"] = "intervals-level-1"

                            self.intervals_level_2 = Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel2()
                            self.intervals_level_2.parent = self
                            self._children_name_map["intervals_level_2"] = "intervals-level-2"
                            self._segment_path = lambda: "intervals-levels"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels, [], name, value)


                        class IntervalsLevel1(Entity):
                            """
                            
                            
                            .. attribute:: level_1
                            
                            	Set interval for level 1 only
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120
                            
                            .. attribute:: initial_wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            .. attribute:: wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel1, self).__init__()

                                self.yang_name = "intervals-level-1"
                                self.yang_parent_name = "intervals-levels"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                    ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                    ('wait', (YLeaf(YType.uint32, 'wait'), ['int'])),
                                ])
                                self.level_1 = None
                                self.interval = None
                                self.initial_wait = None
                                self.wait = None
                                self._segment_path = lambda: "intervals-level-1"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel1, [u'level_1', u'interval', u'initial_wait', u'wait'], name, value)


                        class IntervalsLevel2(Entity):
                            """
                            
                            
                            .. attribute:: level_2
                            
                            	Set interval for level 2 only
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: interval
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120
                            
                            .. attribute:: initial_wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            .. attribute:: wait
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..120000
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel2, self).__init__()

                                self.yang_name = "intervals-level-2"
                                self.yang_parent_name = "intervals-levels"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                    ('initial_wait', (YLeaf(YType.uint32, 'initial-wait'), ['int'])),
                                    ('wait', (YLeaf(YType.uint32, 'wait'), ['int'])),
                                ])
                                self.level_2 = None
                                self.interval = None
                                self.initial_wait = None
                                self.wait = None
                                self._segment_path = lambda: "intervals-level-2"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.LspGenInterval.IntervalsLevels.IntervalsLevel2, [u'level_2', u'interval', u'initial_wait', u'wait'], name, value)


                class Microloop(Entity):
                    """
                    Enable microloop protection configuration commands
                    
                    .. attribute:: avoidance
                    
                    	Enable local microloop avoidance
                    	**type**\:  :py:class:`Avoidance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Microloop.Avoidance>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Microloop, self).__init__()

                        self.yang_name = "microloop"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("avoidance", ("avoidance", Native.Router.IsisContainer.Isis.Microloop.Avoidance))])
                        self._leafs = OrderedDict()

                        self.avoidance = None
                        self._children_name_map["avoidance"] = "avoidance"
                        self._segment_path = lambda: "microloop"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Microloop, [], name, value)


                    class Avoidance(Entity):
                        """
                        Enable local microloop avoidance
                        
                        .. attribute:: disable
                        
                        	Disable Microloop avoidance
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: protected
                        
                        	Microloop avoidance for protected link or prefix only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rib_update_delay
                        
                        	Value of the delay in milliseconds
                        	**type**\: int
                        
                        	**range:** 1..600000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Microloop.Avoidance, self).__init__()

                            self.yang_name = "avoidance"
                            self.yang_parent_name = "microloop"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('protected', (YLeaf(YType.empty, 'protected'), ['Empty'])),
                                ('rib_update_delay', (YLeaf(YType.uint32, 'rib-update-delay'), ['int'])),
                            ])
                            self.disable = None
                            self.protected = None
                            self.rib_update_delay = None
                            self._segment_path = lambda: "avoidance"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Microloop.Avoidance, [u'disable', u'protected', u'rib_update_delay'], name, value)


                class Mpls(Entity):
                    """
                    Configure MPLS routing protocol parameters
                    
                    .. attribute:: ldp
                    
                    	routing protocol commands for MPLS LDP
                    	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Mpls.Ldp>`
                    
                    .. attribute:: traffic_eng
                    
                    	routing protocol commands for MPLS Traffic Engineering
                    	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Mpls.TrafficEng>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ldp", ("ldp", Native.Router.IsisContainer.Isis.Mpls.Ldp)), ("traffic-eng", ("traffic_eng", Native.Router.IsisContainer.Isis.Mpls.TrafficEng))])
                        self._leafs = OrderedDict()

                        self.ldp = Native.Router.IsisContainer.Isis.Mpls.Ldp()
                        self.ldp.parent = self
                        self._children_name_map["ldp"] = "ldp"

                        self.traffic_eng = Native.Router.IsisContainer.Isis.Mpls.TrafficEng()
                        self.traffic_eng.parent = self
                        self._children_name_map["traffic_eng"] = "traffic-eng"
                        self._segment_path = lambda: "mpls"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Mpls, [], name, value)


                    class Ldp(Entity):
                        """
                        routing protocol commands for MPLS LDP
                        
                        .. attribute:: autoconfig
                        
                        	Configure LDP automatic configuration
                        	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Mpls.Ldp.Autoconfig>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: sync
                        
                        	Configure LDP\-IGP Synchronization
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: sync_igp_shortcuts
                        
                        	Configure LDP\-IGP Synchronization on MPLS shortcuts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Mpls.Ldp, self).__init__()

                            self.yang_name = "ldp"
                            self.yang_parent_name = "mpls"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("autoconfig", ("autoconfig", Native.Router.IsisContainer.Isis.Mpls.Ldp.Autoconfig))])
                            self._leafs = OrderedDict([
                                ('sync', (YLeaf(YType.empty, 'sync'), ['Empty'])),
                                ('sync_igp_shortcuts', (YLeaf(YType.empty, 'sync-igp-shortcuts'), ['Empty'])),
                            ])
                            self.sync = None
                            self.sync_igp_shortcuts = None

                            self.autoconfig = None
                            self._children_name_map["autoconfig"] = "autoconfig"
                            self._segment_path = lambda: "ldp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Mpls.Ldp, [u'sync', u'sync_igp_shortcuts'], name, value)


                        class Autoconfig(Entity):
                            """
                            Configure LDP automatic configuration
                            
                            .. attribute:: level_1
                            
                            	Configure ISIS level\-1 to run MPLS LDP
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: level_2
                            
                            	Configure ISIS level\-2 to run MPLS LDP
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Mpls.Ldp.Autoconfig, self).__init__()

                                self.yang_name = "autoconfig"
                                self.yang_parent_name = "ldp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                                    ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                                ])
                                self.level_1 = None
                                self.level_2 = None
                                self._segment_path = lambda: "autoconfig"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Mpls.Ldp.Autoconfig, [u'level_1', u'level_2'], name, value)


                    class TrafficEng(Entity):
                        """
                        routing protocol commands for MPLS Traffic Engineering
                        
                        .. attribute:: level_1
                        
                        	Run MPLS TE on IS\-IS level 1 only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: level_2
                        
                        	Run MPLS TE on IS\-IS level 2 only
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multicast_intact
                        
                        	MPLS TE and PIM interaction
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: router_id
                        
                        	Traffic Engineering stable IP address for system
                        	**type**\:  :py:class:`RouterId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId>`
                        
                        .. attribute:: scanner
                        
                        	Timer parameters for TE database
                        	**type**\:  :py:class:`Scanner <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Mpls.TrafficEng.Scanner>`
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Mpls.TrafficEng, self).__init__()

                            self.yang_name = "traffic-eng"
                            self.yang_parent_name = "mpls"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("router-id", ("router_id", Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId)), ("scanner", ("scanner", Native.Router.IsisContainer.Isis.Mpls.TrafficEng.Scanner))])
                            self._leafs = OrderedDict([
                                ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                                ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                                ('multicast_intact', (YLeaf(YType.empty, 'multicast-intact'), ['Empty'])),
                            ])
                            self.level_1 = None
                            self.level_2 = None
                            self.multicast_intact = None

                            self.router_id = Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId()
                            self.router_id.parent = self
                            self._children_name_map["router_id"] = "router-id"

                            self.scanner = Native.Router.IsisContainer.Isis.Mpls.TrafficEng.Scanner()
                            self.scanner.parent = self
                            self._children_name_map["scanner"] = "scanner"
                            self._segment_path = lambda: "traffic-eng"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Mpls.TrafficEng, [u'level_1', u'level_2', u'multicast_intact'], name, value)


                        class RouterId(Entity):
                            """
                            Traffic Engineering stable IP address for system
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId, self).__init__()

                                self.yang_name = "router-id"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "router-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "router-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "router-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "router-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-isis'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "router-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.RouterId.PortChannelSubinterface, [u'port_channel'], name, value)


                        class Scanner(Entity):
                            """
                            Timer parameters for TE database
                            
                            .. attribute:: interval
                            
                            	Time (secs) between LSPDB walks for TE
                            	**type**\: int
                            
                            	**range:** 1..60
                            
                            .. attribute:: max_flash
                            
                            	Max. number of LSPs ISIS may send to TE db without delay\: <0..200>
                            	**type**\: int
                            
                            	**range:** 0..200
                            
                            

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.Scanner, self).__init__()

                                self.yang_name = "scanner"
                                self.yang_parent_name = "traffic-eng"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                    ('max_flash', (YLeaf(YType.uint32, 'max-flash'), ['int'])),
                                ])
                                self.interval = None
                                self.max_flash = None
                                self._segment_path = lambda: "scanner"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.Mpls.TrafficEng.Scanner, [u'interval', u'max_flash'], name, value)


                class Net(Entity):
                    """
                    A Network Entity Title for this process (OSI only)
                    
                    .. attribute:: tag  (key)
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Net, self).__init__()

                        self.yang_name = "net"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['tag']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('tag', (YLeaf(YType.str, 'tag'), ['str'])),
                        ])
                        self.tag = None
                        self._segment_path = lambda: "net" + "[tag='" + str(self.tag) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Net, [u'tag'], name, value)


                class Nsf(Entity):
                    """
                    Non\-stop forwarding
                    
                    .. attribute:: cisco
                    
                    	Checkpoint method
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ietf
                    
                    	IETF method
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: interface
                    
                    	Interface properties
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Nsf.Interface>`
                    
                    .. attribute:: interval
                    
                    	Minutes
                    	**type**\: int
                    
                    	**range:** 0..1440
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Nsf, self).__init__()

                        self.yang_name = "nsf"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Native.Router.IsisContainer.Isis.Nsf.Interface))])
                        self._leafs = OrderedDict([
                            ('cisco', (YLeaf(YType.empty, 'cisco'), ['Empty'])),
                            ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                        ])
                        self.cisco = None
                        self.ietf = None
                        self.interval = None

                        self.interface = Native.Router.IsisContainer.Isis.Nsf.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._segment_path = lambda: "nsf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Nsf, [u'cisco', u'ietf', u'interval'], name, value)


                    class Interface(Entity):
                        """
                        Interface properties
                        
                        .. attribute:: wait
                        
                        	Seconds
                        	**type**\: int
                        
                        	**range:** 1..60
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Nsf.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "nsf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wait', (YLeaf(YType.uint8, 'wait'), ['int'])),
                            ])
                            self.wait = None
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Nsf.Interface, [u'wait'], name, value)


                class Partition(Entity):
                    """
                    CLNS area partition
                    
                    .. attribute:: avoidance
                    
                    	Withdraw area prefix if partition detected
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Partition, self).__init__()

                        self.yang_name = "partition"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('avoidance', (YLeaf(YType.empty, 'avoidance'), ['Empty'])),
                        ])
                        self.avoidance = None
                        self._segment_path = lambda: "partition"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Partition, [u'avoidance'], name, value)


                class PassiveInterface(Entity):
                    """
                    Suppress routing updates on an interface
                    
                    .. attribute:: default
                    
                    	Suppress routing updates on all interfaces
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: interface
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.PassiveInterface, self).__init__()

                        self.yang_name = "passive-interface"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ])
                        self.default = None
                        self.interface = None
                        self._segment_path = lambda: "passive-interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.PassiveInterface, [u'default', u'interface'], name, value)


                class Disable(Entity):
                    """
                    
                    
                    .. attribute:: passive_interface
                    
                    	
                    	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.Disable.PassiveInterface>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Disable, self).__init__()

                        self.yang_name = "disable"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.IsisContainer.Isis.Disable.PassiveInterface))])
                        self._leafs = OrderedDict()

                        self.passive_interface = YList(self)
                        self._segment_path = lambda: "disable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Disable, [], name, value)


                    class PassiveInterface(Entity):
                        """
                        
                        
                        .. attribute:: interface  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.Disable.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "disable"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "passive-interface" + "[interface='" + str(self.interface) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.Disable.PassiveInterface, [u'interface'], name, value)


                class Protocol(Entity):
                    """
                    Set protocol's administrative state
                    
                    .. attribute:: shutdown
                    
                    	Set protocol's administrative state to disable
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Protocol, self).__init__()

                        self.yang_name = "protocol"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self._segment_path = lambda: "protocol"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Protocol, [u'shutdown'], name, value)


                class SegmentRouting(Entity):
                    """
                    Enable Segment Routing Feature
                    
                    .. attribute:: mpls
                    
                    	Enable Segment Routing Feature using MPLS encapsulation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: prefix_sid_map
                    
                    	Enable prefix\-sid\-map
                    	**type**\:  :py:class:`PrefixSidMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SegmentRouting.PrefixSidMap>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.SegmentRouting, self).__init__()

                        self.yang_name = "segment-routing"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix-sid-map", ("prefix_sid_map", Native.Router.IsisContainer.Isis.SegmentRouting.PrefixSidMap))])
                        self._leafs = OrderedDict([
                            ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                        ])
                        self.mpls = None

                        self.prefix_sid_map = Native.Router.IsisContainer.Isis.SegmentRouting.PrefixSidMap()
                        self.prefix_sid_map.parent = self
                        self._children_name_map["prefix_sid_map"] = "prefix-sid-map"
                        self._segment_path = lambda: "segment-routing"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.SegmentRouting, [u'mpls'], name, value)


                    class PrefixSidMap(Entity):
                        """
                        Enable prefix\-sid\-map
                        
                        .. attribute:: advertise_local
                        
                        	Advertise active local prefix\-SID mappings
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive
                        
                        	Enable prefix\-SID mapping client
                        	**type**\:  :py:class:`Receive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.IsisContainer.Isis.SegmentRouting.PrefixSidMap.Receive>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-isis'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.IsisContainer.Isis.SegmentRouting.PrefixSidMap, self).__init__()

                            self.yang_name = "prefix-sid-map"
                            self.yang_parent_name = "segment-routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("receive", ("receive", Native.Router.IsisContainer.Isis.SegmentRouting.PrefixSidMap.Receive))])
                            self._leafs = OrderedDict([
                                ('advertise_local', (YLeaf(YType.empty, 'advertise-local'), ['Empty'])),
                            ])
                            self.advertise_local = None

                            self.receive = None
                            self._children_name_map["receive"] = "receive"
                            self._segment_path = lambda: "prefix-sid-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.IsisContainer.Isis.SegmentRouting.PrefixSidMap, [u'advertise_local'], name, value)


                        class Receive(Entity):
                            """
                            Enable prefix\-SID mapping client
                            
                            .. attribute:: disable
                            
                            	Disable prefix\-SID mapping
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-isis'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.IsisContainer.Isis.SegmentRouting.PrefixSidMap.Receive, self).__init__()

                                self.yang_name = "receive"
                                self.yang_parent_name = "prefix-sid-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "receive"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.IsisContainer.Isis.SegmentRouting.PrefixSidMap.Receive, [u'disable'], name, value)


                class Skeptical(Entity):
                    """
                    Be a cautious NSF helper when refresh adjacency
                    
                    .. attribute:: interval
                    
                    	Minutes
                    	**type**\: int
                    
                    	**range:** 0..1440
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Skeptical, self).__init__()

                        self.yang_name = "skeptical"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                        ])
                        self.interval = None
                        self._segment_path = lambda: "skeptical"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Skeptical, [u'interval'], name, value)


                class Use(Entity):
                    """
                    Use different algorithms during SPF
                    
                    .. attribute:: external_metrics
                    
                    	Honour external metrics during SPF
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Use, self).__init__()

                        self.yang_name = "use"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('external_metrics', (YLeaf(YType.empty, 'external-metrics'), ['Empty'])),
                        ])
                        self.external_metrics = None
                        self._segment_path = lambda: "use"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Use, [u'external_metrics'], name, value)


                class Bfd(Entity):
                    """
                    BFD configuration commands
                    
                    .. attribute:: all_interfaces
                    
                    	Enable BFD on all interfaces
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: check_ctrl_plane_failure
                    
                    	BFD check control plane failure
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-isis'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.IsisContainer.Isis.Bfd, self).__init__()

                        self.yang_name = "bfd"
                        self.yang_parent_name = "isis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                            ('check_ctrl_plane_failure', (YLeaf(YType.empty, 'check-ctrl-plane-failure'), ['Empty'])),
                        ])
                        self.all_interfaces = None
                        self.check_ctrl_plane_failure = None
                        self._segment_path = lambda: "bfd"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.IsisContainer.Isis.Bfd, [u'all_interfaces', u'check_ctrl_plane_failure'], name, value)


        class Ospf(Entity):
            """
            Open Shortest Path First (OSPF)
            
            .. attribute:: id  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding Instance
            	**type**\: str
            
            .. attribute:: address_family
            
            	Enter Address Family command mode
            	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily>`
            
            .. attribute:: area
            
            	OSPF area parameters
            	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area>`
            
            .. attribute:: auto_cost
            
            	Calculate OSPF interface cost according to bandwidth
            	**type**\:  :py:class:`AutoCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AutoCost>`
            
            	**presence node**\: True
            
            .. attribute:: event_log
            
            	OSPF Event Logging
            	**type**\:  :py:class:`EventLog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.EventLog>`
            
            	**presence node**\: True
            
            .. attribute:: bfd
            
            	BFD configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Bfd>`
            
            .. attribute:: interface_id
            
            	Source of the interface ID
            	**type**\:  :py:class:`InterfaceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.InterfaceId>`
            
            .. attribute:: log_adjacency_changes
            
            	Log changes in adjacency state
            	**type**\:  :py:class:`LogAdjacencyChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.LogAdjacencyChanges>`
            
            	**presence node**\: True
            
            .. attribute:: max_lsa
            
            	maximum number of LSAs OSPF process will receive
            	**type**\:  :py:class:`MaxLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.MaxLsa>`
            
            .. attribute:: max_metric
            
            	Set maximum metric
            	**type**\:  :py:class:`MaxMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.MaxMetric>`
            
            .. attribute:: passive_interface
            
            	Suppress routing updates on an interface
            	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.PassiveInterface>`
            
            .. attribute:: disable
            
            	
            	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Disable>`
            
            .. attribute:: queue_depth
            
            	OSPF Hello/Router process queue depth
            	**type**\:  :py:class:`QueueDepth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.QueueDepth>`
            
            .. attribute:: timers
            
            	Adjust routing timers
            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Timers>`
            
            .. attribute:: router_id
            
            	Override configured router identifier (peers will reset)
            	**type**\: str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: nsr
            
            	Enable non\-stop routing
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: traffic_share
            
            	How to compute traffic share over alternate paths
            	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.TrafficShare>`
            
            .. attribute:: ttl_security
            
            	TTL security check
            	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.TtlSecurity>`
            
            .. attribute:: capability
            
            	Enable specific OSPF feature
            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Capability>`
            
            .. attribute:: compatible
            
            	OSPF compatibility list
            	**type**\:  :py:class:`Compatible <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Compatible>`
            
            .. attribute:: default_information
            
            	Control distribution of default information
            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DefaultInformation>`
            
            .. attribute:: default_metric
            
            	Set metric of redistributed routes
            	**type**\: int
            
            	**range:** 1..16777214
            
            .. attribute:: discard_route
            
            	Enable or disable discard\-route installation
            	**type**\:  :py:class:`DiscardRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DiscardRoute>`
            
            	**presence node**\: True
            
            .. attribute:: distance
            
            	Define an administrative distance
            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Distance>`
            
            .. attribute:: maximum_paths
            
            	Forward packets over multiple paths
            	**type**\: int
            
            	**range:** 1..32
            
            .. attribute:: redistribute
            
            	Redistribute information from another routing protocol
            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute>`
            
            .. attribute:: distribute_list
            
            	Filter networks in routing updates
            	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DistributeList>`
            
            .. attribute:: domain_id
            
            	OSPF domain\-id
            	**type**\:  :py:class:`DomainId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DomainId>`
            
            .. attribute:: domain_tag
            
            	OSPF domain\-tag
            	**type**\: int
            
            	**range:** 1..4294967295
            
            .. attribute:: fast_reroute
            
            	LFA FastReroute parameters
            	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute>`
            
            .. attribute:: graceful_restart
            
            	Graceful\-restart options
            	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.GracefulRestart>`
            
            	**presence node**\: True
            
            .. attribute:: ignore
            
            	Do not complain about specific event
            	**type**\:  :py:class:`Ignore <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Ignore>`
            
            .. attribute:: ispf
            
            	Enable incremental SPF computation
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: limit
            
            	Limit a specific OSPF feature
            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Limit>`
            
            .. attribute:: local_rib_criteria
            
            	Enable or disable usage of local RIB as route criteria
            	**type**\:  :py:class:`LocalRibCriteria <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.LocalRibCriteria>`
            
            .. attribute:: microloop
            
            	Traffic microloop control parameters
            	**type**\:  :py:class:`Microloop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Microloop>`
            
            .. attribute:: mpls
            
            	Configure MPLS routing protocol parameters
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls>`
            
            .. attribute:: neighbor
            
            	Specify a neighbor router
            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Neighbor>`
            
            .. attribute:: network
            
            	Enable routing on an IP network
            	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Network>`
            
            .. attribute:: nsf
            
            	Non\-stop forwarding
            	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Nsf>`
            
            	**presence node**\: True
            
            .. attribute:: prefix_priority
            
            	OSPF prefix priority
            	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.PrefixPriority>`
            
            .. attribute:: prefix_suppression
            
            	OSPF prefix suppression
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: priority
            
            	OSPF topology priority
            	**type**\: int
            
            	**range:** 0..127
            
            .. attribute:: process_min_time
            
            	Percentage of quantum to be used before releasing CPU
            	**type**\:  :py:class:`ProcessMinTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.ProcessMinTime>`
            
            .. attribute:: shutdown
            
            	Shutdown the OSPF protocol under the current instance
            	**type**\: bool
            
            .. attribute:: snmp
            
            	Modify snmp parameters
            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Snmp>`
            
            .. attribute:: summary_address
            
            	Configure IP address summaries
            	**type**\: list of  		 :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.SummaryAddress>`
            
            

            """

            _prefix = 'ios-ospf'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Router.Ospf, self).__init__()

                self.yang_name = "ospf"
                self.yang_parent_name = "router"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("address-family", ("address_family", Native.Router.Ospf.AddressFamily)), ("area", ("area", Native.Router.Ospf.Area)), ("auto-cost", ("auto_cost", Native.Router.Ospf.AutoCost)), ("event-log", ("event_log", Native.Router.Ospf.EventLog)), ("bfd", ("bfd", Native.Router.Ospf.Bfd)), ("interface-id", ("interface_id", Native.Router.Ospf.InterfaceId)), ("log-adjacency-changes", ("log_adjacency_changes", Native.Router.Ospf.LogAdjacencyChanges)), ("max-lsa", ("max_lsa", Native.Router.Ospf.MaxLsa)), ("max-metric", ("max_metric", Native.Router.Ospf.MaxMetric)), ("passive-interface", ("passive_interface", Native.Router.Ospf.PassiveInterface)), ("disable", ("disable", Native.Router.Ospf.Disable)), ("queue-depth", ("queue_depth", Native.Router.Ospf.QueueDepth)), ("timers", ("timers", Native.Router.Ospf.Timers)), ("traffic-share", ("traffic_share", Native.Router.Ospf.TrafficShare)), ("ttl-security", ("ttl_security", Native.Router.Ospf.TtlSecurity)), ("capability", ("capability", Native.Router.Ospf.Capability)), ("compatible", ("compatible", Native.Router.Ospf.Compatible)), ("default-information", ("default_information", Native.Router.Ospf.DefaultInformation)), ("discard-route", ("discard_route", Native.Router.Ospf.DiscardRoute)), ("distance", ("distance", Native.Router.Ospf.Distance)), ("redistribute", ("redistribute", Native.Router.Ospf.Redistribute)), ("distribute-list", ("distribute_list", Native.Router.Ospf.DistributeList)), ("domain-id", ("domain_id", Native.Router.Ospf.DomainId)), ("fast-reroute", ("fast_reroute", Native.Router.Ospf.FastReroute)), ("graceful-restart", ("graceful_restart", Native.Router.Ospf.GracefulRestart)), ("ignore", ("ignore", Native.Router.Ospf.Ignore)), ("limit", ("limit", Native.Router.Ospf.Limit)), ("local-rib-criteria", ("local_rib_criteria", Native.Router.Ospf.LocalRibCriteria)), ("microloop", ("microloop", Native.Router.Ospf.Microloop)), ("mpls", ("mpls", Native.Router.Ospf.Mpls)), ("neighbor", ("neighbor", Native.Router.Ospf.Neighbor)), ("network", ("network", Native.Router.Ospf.Network)), ("nsf", ("nsf", Native.Router.Ospf.Nsf)), ("prefix-priority", ("prefix_priority", Native.Router.Ospf.PrefixPriority)), ("process-min-time", ("process_min_time", Native.Router.Ospf.ProcessMinTime)), ("snmp", ("snmp", Native.Router.Ospf.Snmp)), ("summary-address", ("summary_address", Native.Router.Ospf.SummaryAddress))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                    ('nsr', (YLeaf(YType.empty, 'nsr'), ['Empty'])),
                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                    ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                    ('domain_tag', (YLeaf(YType.uint32, 'domain-tag'), ['int'])),
                    ('ispf', (YLeaf(YType.empty, 'ispf'), ['Empty'])),
                    ('prefix_suppression', (YLeaf(YType.empty, 'prefix-suppression'), ['Empty'])),
                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                    ('shutdown', (YLeaf(YType.boolean, 'shutdown'), ['bool'])),
                ])
                self.id = None
                self.vrf = None
                self.router_id = None
                self.nsr = None
                self.default_metric = None
                self.maximum_paths = None
                self.domain_tag = None
                self.ispf = None
                self.prefix_suppression = None
                self.priority = None
                self.shutdown = None

                self.address_family = Native.Router.Ospf.AddressFamily()
                self.address_family.parent = self
                self._children_name_map["address_family"] = "address-family"

                self.auto_cost = None
                self._children_name_map["auto_cost"] = "auto-cost"

                self.event_log = None
                self._children_name_map["event_log"] = "event-log"

                self.bfd = Native.Router.Ospf.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.interface_id = Native.Router.Ospf.InterfaceId()
                self.interface_id.parent = self
                self._children_name_map["interface_id"] = "interface-id"

                self.log_adjacency_changes = None
                self._children_name_map["log_adjacency_changes"] = "log-adjacency-changes"

                self.max_lsa = Native.Router.Ospf.MaxLsa()
                self.max_lsa.parent = self
                self._children_name_map["max_lsa"] = "max-lsa"

                self.max_metric = Native.Router.Ospf.MaxMetric()
                self.max_metric.parent = self
                self._children_name_map["max_metric"] = "max-metric"

                self.passive_interface = Native.Router.Ospf.PassiveInterface()
                self.passive_interface.parent = self
                self._children_name_map["passive_interface"] = "passive-interface"

                self.disable = Native.Router.Ospf.Disable()
                self.disable.parent = self
                self._children_name_map["disable"] = "disable"

                self.queue_depth = Native.Router.Ospf.QueueDepth()
                self.queue_depth.parent = self
                self._children_name_map["queue_depth"] = "queue-depth"

                self.timers = Native.Router.Ospf.Timers()
                self.timers.parent = self
                self._children_name_map["timers"] = "timers"

                self.traffic_share = Native.Router.Ospf.TrafficShare()
                self.traffic_share.parent = self
                self._children_name_map["traffic_share"] = "traffic-share"

                self.ttl_security = Native.Router.Ospf.TtlSecurity()
                self.ttl_security.parent = self
                self._children_name_map["ttl_security"] = "ttl-security"

                self.capability = Native.Router.Ospf.Capability()
                self.capability.parent = self
                self._children_name_map["capability"] = "capability"

                self.compatible = Native.Router.Ospf.Compatible()
                self.compatible.parent = self
                self._children_name_map["compatible"] = "compatible"

                self.default_information = Native.Router.Ospf.DefaultInformation()
                self.default_information.parent = self
                self._children_name_map["default_information"] = "default-information"

                self.discard_route = None
                self._children_name_map["discard_route"] = "discard-route"

                self.distance = Native.Router.Ospf.Distance()
                self.distance.parent = self
                self._children_name_map["distance"] = "distance"

                self.redistribute = Native.Router.Ospf.Redistribute()
                self.redistribute.parent = self
                self._children_name_map["redistribute"] = "redistribute"

                self.distribute_list = Native.Router.Ospf.DistributeList()
                self.distribute_list.parent = self
                self._children_name_map["distribute_list"] = "distribute-list"

                self.domain_id = Native.Router.Ospf.DomainId()
                self.domain_id.parent = self
                self._children_name_map["domain_id"] = "domain-id"

                self.fast_reroute = Native.Router.Ospf.FastReroute()
                self.fast_reroute.parent = self
                self._children_name_map["fast_reroute"] = "fast-reroute"

                self.graceful_restart = None
                self._children_name_map["graceful_restart"] = "graceful-restart"

                self.ignore = Native.Router.Ospf.Ignore()
                self.ignore.parent = self
                self._children_name_map["ignore"] = "ignore"

                self.limit = Native.Router.Ospf.Limit()
                self.limit.parent = self
                self._children_name_map["limit"] = "limit"

                self.local_rib_criteria = Native.Router.Ospf.LocalRibCriteria()
                self.local_rib_criteria.parent = self
                self._children_name_map["local_rib_criteria"] = "local-rib-criteria"

                self.microloop = Native.Router.Ospf.Microloop()
                self.microloop.parent = self
                self._children_name_map["microloop"] = "microloop"

                self.mpls = Native.Router.Ospf.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.nsf = None
                self._children_name_map["nsf"] = "nsf"

                self.prefix_priority = Native.Router.Ospf.PrefixPriority()
                self.prefix_priority.parent = self
                self._children_name_map["prefix_priority"] = "prefix-priority"

                self.process_min_time = Native.Router.Ospf.ProcessMinTime()
                self.process_min_time.parent = self
                self._children_name_map["process_min_time"] = "process-min-time"

                self.snmp = Native.Router.Ospf.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "snmp"

                self.area = YList(self)
                self.neighbor = YList(self)
                self.network = YList(self)
                self.summary_address = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-ospf:ospf" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Router.Ospf, ['id', 'vrf', 'router_id', 'nsr', 'default_metric', 'maximum_paths', 'domain_tag', 'ispf', 'prefix_suppression', 'priority', 'shutdown'], name, value)


            class AddressFamily(Entity):
                """
                Enter Address Family command mode
                
                .. attribute:: ipv4_1
                
                	
                	**type**\:  :py:class:`Ipv41 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv41>`
                
                .. attribute:: ipv4
                
                	Address family
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4_1", ("ipv4_1", Native.Router.Ospf.AddressFamily.Ipv41)), ("ipv4", ("ipv4", Native.Router.Ospf.AddressFamily.Ipv4))])
                    self._leafs = OrderedDict()

                    self.ipv4_1 = Native.Router.Ospf.AddressFamily.Ipv41()
                    self.ipv4_1.parent = self
                    self._children_name_map["ipv4_1"] = "ipv4_1"

                    self.ipv4 = Native.Router.Ospf.AddressFamily.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._segment_path = lambda: "address-family"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.AddressFamily, [], name, value)


                class Ipv41(Entity):
                    """
                    
                    
                    .. attribute:: ipv4
                    
                    	Address family
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv41.Ipv4>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.AddressFamily.Ipv41, self).__init__()

                        self.yang_name = "ipv4_1"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Ospf.AddressFamily.Ipv41.Ipv4))])
                        self._leafs = OrderedDict()

                        self.ipv4 = Native.Router.Ospf.AddressFamily.Ipv41.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._segment_path = lambda: "ipv4_1"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv41, [], name, value)


                    class Ipv4(Entity):
                        """
                        Address family
                        
                        .. attribute:: snmp
                        
                        	Modify snmp parameters
                        	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp>`
                        
                        .. attribute:: topology
                        
                        	Associate the routing protocol to a topology instance
                        	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Topology>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "ipv4_1"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("snmp", ("snmp", Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp)), ("topology", ("topology", Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Topology))])
                            self._leafs = OrderedDict()

                            self.snmp = Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp()
                            self.snmp.parent = self
                            self._children_name_map["snmp"] = "snmp"

                            self.topology = Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Topology()
                            self.topology.parent = self
                            self._children_name_map["topology"] = "topology"
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4, [], name, value)


                        class Snmp(Entity):
                            """
                            Modify snmp parameters
                            
                            .. attribute:: context
                            
                            	Configure a SNMP context
                            	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp, self).__init__()

                                self.yang_name = "snmp"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("context", ("context", Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context))])
                                self._leafs = OrderedDict()

                                self.context = YList(self)
                                self._segment_path = lambda: "snmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp, [], name, value)


                            class Context(Entity):
                                """
                                Configure a SNMP context
                                
                                .. attribute:: name  (key)
                                
                                	Context Name
                                	**type**\: str
                                
                                .. attribute:: community
                                
                                	Configure a SNMP v2c Community string and access privs
                                	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.Community>`
                                
                                .. attribute:: user
                                
                                	Configure a SNMP v3 user
                                	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context, self).__init__()

                                    self.yang_name = "context"
                                    self.yang_parent_name = "snmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("community", ("community", Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.Community)), ("user", ("user", Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.community = Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.Community()
                                    self.community.parent = self
                                    self._children_name_map["community"] = "community"

                                    self.user = Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User()
                                    self.user.parent = self
                                    self._children_name_map["user"] = "user"
                                    self._segment_path = lambda: "context" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context, ['name'], name, value)


                                class Community(Entity):
                                    """
                                    Configure a SNMP v2c Community string and access privs
                                    
                                    .. attribute:: community_string
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: access
                                    
                                    	
                                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.Community.Access>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "context"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("access", ("access", Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.Community.Access))])
                                        self._leafs = OrderedDict([
                                            ('community_string', (YLeaf(YType.str, 'community-string'), ['str'])),
                                        ])
                                        self.community_string = None

                                        self.access = Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.Community.Access()
                                        self.access.parent = self
                                        self._children_name_map["access"] = "access"
                                        self._segment_path = lambda: "community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.Community, ['community_string'], name, value)


                                    class Access(Entity):
                                        """
                                        
                                        
                                        .. attribute:: standard_acl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..99
                                        
                                        .. attribute:: expanded_acl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1300..1999
                                        
                                        .. attribute:: acl_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	Specify IPv6 Named Access\-List
                                        	**type**\: str
                                        
                                        .. attribute:: ro
                                        
                                        	Read\-only access with this community string
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rw
                                        
                                        	Read\-write access with this community string
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.Community.Access, self).__init__()

                                            self.yang_name = "access"
                                            self.yang_parent_name = "community"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                ('expanded_acl', (YLeaf(YType.uint32, 'expanded-acl'), ['int'])),
                                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ('ro', (YLeaf(YType.empty, 'ro'), ['Empty'])),
                                                ('rw', (YLeaf(YType.empty, 'rw'), ['Empty'])),
                                            ])
                                            self.standard_acl = None
                                            self.expanded_acl = None
                                            self.acl_name = None
                                            self.ipv6 = None
                                            self.ro = None
                                            self.rw = None
                                            self._segment_path = lambda: "access"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.Community.Access, ['standard_acl', 'expanded_acl', 'acl_name', 'ipv6', 'ro', 'rw'], name, value)


                                class User(Entity):
                                    """
                                    Configure a SNMP v3 user
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: permisssion
                                    
                                    	
                                    	**type**\:  :py:class:`Permisssion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User, self).__init__()

                                        self.yang_name = "user"
                                        self.yang_parent_name = "context"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("permisssion", ("permisssion", Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.permisssion = Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion()
                                        self.permisssion.parent = self
                                        self._children_name_map["permisssion"] = "permisssion"
                                        self._segment_path = lambda: "user"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User, ['name'], name, value)


                                    class Permisssion(Entity):
                                        """
                                        
                                        
                                        .. attribute:: access
                                        
                                        	specify an access\-list associated with this group
                                        	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion.Access>`
                                        
                                        .. attribute:: auth
                                        
                                        	authentication parameters for the user
                                        	**type**\:  :py:class:`Auth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion.Auth>`
                                        
                                        .. attribute:: credential
                                        
                                        	If the user password is already configured and saved
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: encrypted
                                        
                                        	specifying passwords as MD5 or SHA digests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion, self).__init__()

                                            self.yang_name = "permisssion"
                                            self.yang_parent_name = "user"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("access", ("access", Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion.Access)), ("auth", ("auth", Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion.Auth))])
                                            self._leafs = OrderedDict([
                                                ('credential', (YLeaf(YType.empty, 'credential'), ['Empty'])),
                                                ('encrypted', (YLeaf(YType.empty, 'encrypted'), ['Empty'])),
                                            ])
                                            self.credential = None
                                            self.encrypted = None

                                            self.access = Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion.Access()
                                            self.access.parent = self
                                            self._children_name_map["access"] = "access"

                                            self.auth = Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion.Auth()
                                            self.auth.parent = self
                                            self._children_name_map["auth"] = "auth"
                                            self._segment_path = lambda: "permisssion"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion, ['credential', 'encrypted'], name, value)


                                        class Access(Entity):
                                            """
                                            specify an access\-list associated with this group
                                            
                                            .. attribute:: standard_acl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: acl_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospf'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion.Access, self).__init__()

                                                self.yang_name = "access"
                                                self.yang_parent_name = "permisssion"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.standard_acl = None
                                                self.acl_name = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "access"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion.Access, ['standard_acl', 'acl_name', 'ipv6'], name, value)


                                        class Auth(Entity):
                                            """
                                            authentication parameters for the user
                                            
                                            .. attribute:: md5
                                            
                                            	Use HMAC MD5 algorithm for authentication
                                            	**type**\: str
                                            
                                            .. attribute:: sha
                                            
                                            	Use HMAC SHA algorithm for authentication
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospf'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion.Auth, self).__init__()

                                                self.yang_name = "auth"
                                                self.yang_parent_name = "permisssion"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('md5', (YLeaf(YType.str, 'md5'), ['str'])),
                                                    ('sha', (YLeaf(YType.str, 'sha'), ['str'])),
                                                ])
                                                self.md5 = None
                                                self.sha = None
                                                self._segment_path = lambda: "auth"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Snmp.Context.User.Permisssion.Auth, ['md5', 'sha'], name, value)


                        class Topology(Entity):
                            """
                            Associate the routing protocol to a topology instance
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: tid
                            
                            	Configuring the routing protocol topology tid
                            	**type**\: int
                            
                            	**range:** 32..127
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('tid', (YLeaf(YType.uint32, 'tid'), ['int'])),
                                ])
                                self.name = None
                                self.tid = None
                                self._segment_path = lambda: "topology"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv41.Ipv4.Topology, ['name', 'tid'], name, value)


                class Ipv4(Entity):
                    """
                    Address family
                    
                    .. attribute:: unicast
                    
                    	Address Family Modifier
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Unicast>`
                    
                    .. attribute:: multicast
                    
                    	Address Family Modifier
                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Multicast>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.AddressFamily.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("unicast", ("unicast", Native.Router.Ospf.AddressFamily.Ipv4.Unicast)), ("multicast", ("multicast", Native.Router.Ospf.AddressFamily.Ipv4.Multicast))])
                        self._leafs = OrderedDict()

                        self.unicast = Native.Router.Ospf.AddressFamily.Ipv4.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"

                        self.multicast = Native.Router.Ospf.AddressFamily.Ipv4.Multicast()
                        self.multicast.parent = self
                        self._children_name_map["multicast"] = "multicast"
                        self._segment_path = lambda: "ipv4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4, [], name, value)


                    class Unicast(Entity):
                        """
                        Address Family Modifier
                        
                        .. attribute:: snmp
                        
                        	Modify snmp parameters
                        	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp>`
                        
                        .. attribute:: topology
                        
                        	Associate the routing protocol to a topology instance
                        	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Topology>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.AddressFamily.Ipv4.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("snmp", ("snmp", Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp)), ("topology", ("topology", Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Topology))])
                            self._leafs = OrderedDict()

                            self.snmp = Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp()
                            self.snmp.parent = self
                            self._children_name_map["snmp"] = "snmp"

                            self.topology = Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Topology()
                            self.topology.parent = self
                            self._children_name_map["topology"] = "topology"
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Unicast, [], name, value)


                        class Snmp(Entity):
                            """
                            Modify snmp parameters
                            
                            .. attribute:: context
                            
                            	Configure a SNMP context
                            	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp, self).__init__()

                                self.yang_name = "snmp"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("context", ("context", Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context))])
                                self._leafs = OrderedDict()

                                self.context = YList(self)
                                self._segment_path = lambda: "snmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp, [], name, value)


                            class Context(Entity):
                                """
                                Configure a SNMP context
                                
                                .. attribute:: name  (key)
                                
                                	Context Name
                                	**type**\: str
                                
                                .. attribute:: community
                                
                                	Configure a SNMP v2c Community string and access privs
                                	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.Community>`
                                
                                .. attribute:: user
                                
                                	Configure a SNMP v3 user
                                	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context, self).__init__()

                                    self.yang_name = "context"
                                    self.yang_parent_name = "snmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("community", ("community", Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.Community)), ("user", ("user", Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.community = Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.Community()
                                    self.community.parent = self
                                    self._children_name_map["community"] = "community"

                                    self.user = Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User()
                                    self.user.parent = self
                                    self._children_name_map["user"] = "user"
                                    self._segment_path = lambda: "context" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context, ['name'], name, value)


                                class Community(Entity):
                                    """
                                    Configure a SNMP v2c Community string and access privs
                                    
                                    .. attribute:: community_string
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: access
                                    
                                    	
                                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.Community.Access>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "context"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("access", ("access", Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.Community.Access))])
                                        self._leafs = OrderedDict([
                                            ('community_string', (YLeaf(YType.str, 'community-string'), ['str'])),
                                        ])
                                        self.community_string = None

                                        self.access = Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.Community.Access()
                                        self.access.parent = self
                                        self._children_name_map["access"] = "access"
                                        self._segment_path = lambda: "community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.Community, ['community_string'], name, value)


                                    class Access(Entity):
                                        """
                                        
                                        
                                        .. attribute:: standard_acl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..99
                                        
                                        .. attribute:: expanded_acl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1300..1999
                                        
                                        .. attribute:: acl_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	Specify IPv6 Named Access\-List
                                        	**type**\: str
                                        
                                        .. attribute:: ro
                                        
                                        	Read\-only access with this community string
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rw
                                        
                                        	Read\-write access with this community string
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.Community.Access, self).__init__()

                                            self.yang_name = "access"
                                            self.yang_parent_name = "community"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                ('expanded_acl', (YLeaf(YType.uint32, 'expanded-acl'), ['int'])),
                                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ('ro', (YLeaf(YType.empty, 'ro'), ['Empty'])),
                                                ('rw', (YLeaf(YType.empty, 'rw'), ['Empty'])),
                                            ])
                                            self.standard_acl = None
                                            self.expanded_acl = None
                                            self.acl_name = None
                                            self.ipv6 = None
                                            self.ro = None
                                            self.rw = None
                                            self._segment_path = lambda: "access"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.Community.Access, ['standard_acl', 'expanded_acl', 'acl_name', 'ipv6', 'ro', 'rw'], name, value)


                                class User(Entity):
                                    """
                                    Configure a SNMP v3 user
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: permisssion
                                    
                                    	
                                    	**type**\:  :py:class:`Permisssion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User, self).__init__()

                                        self.yang_name = "user"
                                        self.yang_parent_name = "context"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("permisssion", ("permisssion", Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.permisssion = Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion()
                                        self.permisssion.parent = self
                                        self._children_name_map["permisssion"] = "permisssion"
                                        self._segment_path = lambda: "user"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User, ['name'], name, value)


                                    class Permisssion(Entity):
                                        """
                                        
                                        
                                        .. attribute:: access
                                        
                                        	specify an access\-list associated with this group
                                        	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion.Access>`
                                        
                                        .. attribute:: auth
                                        
                                        	authentication parameters for the user
                                        	**type**\:  :py:class:`Auth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion.Auth>`
                                        
                                        .. attribute:: credential
                                        
                                        	If the user password is already configured and saved
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: encrypted
                                        
                                        	specifying passwords as MD5 or SHA digests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion, self).__init__()

                                            self.yang_name = "permisssion"
                                            self.yang_parent_name = "user"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("access", ("access", Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion.Access)), ("auth", ("auth", Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion.Auth))])
                                            self._leafs = OrderedDict([
                                                ('credential', (YLeaf(YType.empty, 'credential'), ['Empty'])),
                                                ('encrypted', (YLeaf(YType.empty, 'encrypted'), ['Empty'])),
                                            ])
                                            self.credential = None
                                            self.encrypted = None

                                            self.access = Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion.Access()
                                            self.access.parent = self
                                            self._children_name_map["access"] = "access"

                                            self.auth = Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion.Auth()
                                            self.auth.parent = self
                                            self._children_name_map["auth"] = "auth"
                                            self._segment_path = lambda: "permisssion"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion, ['credential', 'encrypted'], name, value)


                                        class Access(Entity):
                                            """
                                            specify an access\-list associated with this group
                                            
                                            .. attribute:: standard_acl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: acl_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospf'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion.Access, self).__init__()

                                                self.yang_name = "access"
                                                self.yang_parent_name = "permisssion"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.standard_acl = None
                                                self.acl_name = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "access"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion.Access, ['standard_acl', 'acl_name', 'ipv6'], name, value)


                                        class Auth(Entity):
                                            """
                                            authentication parameters for the user
                                            
                                            .. attribute:: md5
                                            
                                            	Use HMAC MD5 algorithm for authentication
                                            	**type**\: str
                                            
                                            .. attribute:: sha
                                            
                                            	Use HMAC SHA algorithm for authentication
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospf'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion.Auth, self).__init__()

                                                self.yang_name = "auth"
                                                self.yang_parent_name = "permisssion"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('md5', (YLeaf(YType.str, 'md5'), ['str'])),
                                                    ('sha', (YLeaf(YType.str, 'sha'), ['str'])),
                                                ])
                                                self.md5 = None
                                                self.sha = None
                                                self._segment_path = lambda: "auth"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Snmp.Context.User.Permisssion.Auth, ['md5', 'sha'], name, value)


                        class Topology(Entity):
                            """
                            Associate the routing protocol to a topology instance
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: tid
                            
                            	Configuring the routing protocol topology tid
                            	**type**\: int
                            
                            	**range:** 32..127
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('tid', (YLeaf(YType.uint32, 'tid'), ['int'])),
                                ])
                                self.name = None
                                self.tid = None
                                self._segment_path = lambda: "topology"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Unicast.Topology, ['name', 'tid'], name, value)


                    class Multicast(Entity):
                        """
                        Address Family Modifier
                        
                        .. attribute:: snmp
                        
                        	Modify snmp parameters
                        	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp>`
                        
                        .. attribute:: topology
                        
                        	Associate the routing protocol to a topology instance
                        	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Topology>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.AddressFamily.Ipv4.Multicast, self).__init__()

                            self.yang_name = "multicast"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("snmp", ("snmp", Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp)), ("topology", ("topology", Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Topology))])
                            self._leafs = OrderedDict()

                            self.snmp = Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp()
                            self.snmp.parent = self
                            self._children_name_map["snmp"] = "snmp"

                            self.topology = Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Topology()
                            self.topology.parent = self
                            self._children_name_map["topology"] = "topology"
                            self._segment_path = lambda: "multicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Multicast, [], name, value)


                        class Snmp(Entity):
                            """
                            Modify snmp parameters
                            
                            .. attribute:: context
                            
                            	Configure a SNMP context
                            	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp, self).__init__()

                                self.yang_name = "snmp"
                                self.yang_parent_name = "multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("context", ("context", Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context))])
                                self._leafs = OrderedDict()

                                self.context = YList(self)
                                self._segment_path = lambda: "snmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp, [], name, value)


                            class Context(Entity):
                                """
                                Configure a SNMP context
                                
                                .. attribute:: name  (key)
                                
                                	Context Name
                                	**type**\: str
                                
                                .. attribute:: community
                                
                                	Configure a SNMP v2c Community string and access privs
                                	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.Community>`
                                
                                .. attribute:: user
                                
                                	Configure a SNMP v3 user
                                	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context, self).__init__()

                                    self.yang_name = "context"
                                    self.yang_parent_name = "snmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("community", ("community", Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.Community)), ("user", ("user", Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.community = Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.Community()
                                    self.community.parent = self
                                    self._children_name_map["community"] = "community"

                                    self.user = Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User()
                                    self.user.parent = self
                                    self._children_name_map["user"] = "user"
                                    self._segment_path = lambda: "context" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context, ['name'], name, value)


                                class Community(Entity):
                                    """
                                    Configure a SNMP v2c Community string and access privs
                                    
                                    .. attribute:: community_string
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: access
                                    
                                    	
                                    	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.Community.Access>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "context"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("access", ("access", Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.Community.Access))])
                                        self._leafs = OrderedDict([
                                            ('community_string', (YLeaf(YType.str, 'community-string'), ['str'])),
                                        ])
                                        self.community_string = None

                                        self.access = Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.Community.Access()
                                        self.access.parent = self
                                        self._children_name_map["access"] = "access"
                                        self._segment_path = lambda: "community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.Community, ['community_string'], name, value)


                                    class Access(Entity):
                                        """
                                        
                                        
                                        .. attribute:: standard_acl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..99
                                        
                                        .. attribute:: expanded_acl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1300..1999
                                        
                                        .. attribute:: acl_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	Specify IPv6 Named Access\-List
                                        	**type**\: str
                                        
                                        .. attribute:: ro
                                        
                                        	Read\-only access with this community string
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rw
                                        
                                        	Read\-write access with this community string
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.Community.Access, self).__init__()

                                            self.yang_name = "access"
                                            self.yang_parent_name = "community"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                ('expanded_acl', (YLeaf(YType.uint32, 'expanded-acl'), ['int'])),
                                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ('ro', (YLeaf(YType.empty, 'ro'), ['Empty'])),
                                                ('rw', (YLeaf(YType.empty, 'rw'), ['Empty'])),
                                            ])
                                            self.standard_acl = None
                                            self.expanded_acl = None
                                            self.acl_name = None
                                            self.ipv6 = None
                                            self.ro = None
                                            self.rw = None
                                            self._segment_path = lambda: "access"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.Community.Access, ['standard_acl', 'expanded_acl', 'acl_name', 'ipv6', 'ro', 'rw'], name, value)


                                class User(Entity):
                                    """
                                    Configure a SNMP v3 user
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: permisssion
                                    
                                    	
                                    	**type**\:  :py:class:`Permisssion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User, self).__init__()

                                        self.yang_name = "user"
                                        self.yang_parent_name = "context"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("permisssion", ("permisssion", Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.permisssion = Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion()
                                        self.permisssion.parent = self
                                        self._children_name_map["permisssion"] = "permisssion"
                                        self._segment_path = lambda: "user"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User, ['name'], name, value)


                                    class Permisssion(Entity):
                                        """
                                        
                                        
                                        .. attribute:: access
                                        
                                        	specify an access\-list associated with this group
                                        	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion.Access>`
                                        
                                        .. attribute:: auth
                                        
                                        	authentication parameters for the user
                                        	**type**\:  :py:class:`Auth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion.Auth>`
                                        
                                        .. attribute:: credential
                                        
                                        	If the user password is already configured and saved
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: encrypted
                                        
                                        	specifying passwords as MD5 or SHA digests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospf'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion, self).__init__()

                                            self.yang_name = "permisssion"
                                            self.yang_parent_name = "user"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("access", ("access", Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion.Access)), ("auth", ("auth", Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion.Auth))])
                                            self._leafs = OrderedDict([
                                                ('credential', (YLeaf(YType.empty, 'credential'), ['Empty'])),
                                                ('encrypted', (YLeaf(YType.empty, 'encrypted'), ['Empty'])),
                                            ])
                                            self.credential = None
                                            self.encrypted = None

                                            self.access = Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion.Access()
                                            self.access.parent = self
                                            self._children_name_map["access"] = "access"

                                            self.auth = Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion.Auth()
                                            self.auth.parent = self
                                            self._children_name_map["auth"] = "auth"
                                            self._segment_path = lambda: "permisssion"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion, ['credential', 'encrypted'], name, value)


                                        class Access(Entity):
                                            """
                                            specify an access\-list associated with this group
                                            
                                            .. attribute:: standard_acl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: acl_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospf'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion.Access, self).__init__()

                                                self.yang_name = "access"
                                                self.yang_parent_name = "permisssion"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.standard_acl = None
                                                self.acl_name = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "access"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion.Access, ['standard_acl', 'acl_name', 'ipv6'], name, value)


                                        class Auth(Entity):
                                            """
                                            authentication parameters for the user
                                            
                                            .. attribute:: md5
                                            
                                            	Use HMAC MD5 algorithm for authentication
                                            	**type**\: str
                                            
                                            .. attribute:: sha
                                            
                                            	Use HMAC SHA algorithm for authentication
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospf'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion.Auth, self).__init__()

                                                self.yang_name = "auth"
                                                self.yang_parent_name = "permisssion"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('md5', (YLeaf(YType.str, 'md5'), ['str'])),
                                                    ('sha', (YLeaf(YType.str, 'sha'), ['str'])),
                                                ])
                                                self.md5 = None
                                                self.sha = None
                                                self._segment_path = lambda: "auth"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Snmp.Context.User.Permisssion.Auth, ['md5', 'sha'], name, value)


                        class Topology(Entity):
                            """
                            Associate the routing protocol to a topology instance
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: tid
                            
                            	Configuring the routing protocol topology tid
                            	**type**\: int
                            
                            	**range:** 32..127
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('tid', (YLeaf(YType.uint32, 'tid'), ['int'])),
                                ])
                                self.name = None
                                self.tid = None
                                self._segment_path = lambda: "topology"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.AddressFamily.Ipv4.Multicast.Topology, ['name', 'tid'], name, value)


            class Area(Entity):
                """
                OSPF area parameters
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..4294967295
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Authentication>`
                
                	**presence node**\: True
                
                .. attribute:: capability
                
                	Enable area specific capability
                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Capability>`
                
                .. attribute:: default_cost
                
                	Set the summary default\-cost of a NSSA/stub area
                	**type**\: int
                
                	**range:** 0..16777215
                
                .. attribute:: filter_list
                
                	Filter networks between OSPF areas
                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.FilterList>`
                
                .. attribute:: nssa
                
                	Specify a NSSA area
                	**type**\:  :py:class:`Nssa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Nssa>`
                
                	**presence node**\: True
                
                .. attribute:: ipv4_range
                
                	
                	**type**\:  :py:class:`Ipv4Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Ipv4Range>`
                
                .. attribute:: ipv6_range
                
                	
                	**type**\:  :py:class:`Ipv6Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Ipv6Range>`
                
                .. attribute:: sham_link
                
                	Define a sham link and its parameters
                	**type**\: list of  		 :py:class:`ShamLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.ShamLink>`
                
                .. attribute:: stub
                
                	Specify a stub area
                	**type**\:  :py:class:`Stub <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Stub>`
                
                	**presence node**\: True
                
                .. attribute:: virtual_link
                
                	Define a virtual link and its parameters
                	**type**\: list of  		 :py:class:`VirtualLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Area, self).__init__()

                    self.yang_name = "area"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospf.Area.Authentication)), ("capability", ("capability", Native.Router.Ospf.Area.Capability)), ("filter-list", ("filter_list", Native.Router.Ospf.Area.FilterList)), ("nssa", ("nssa", Native.Router.Ospf.Area.Nssa)), ("ipv4-range", ("ipv4_range", Native.Router.Ospf.Area.Ipv4Range)), ("ipv6-range", ("ipv6_range", Native.Router.Ospf.Area.Ipv6Range)), ("sham-link", ("sham_link", Native.Router.Ospf.Area.ShamLink)), ("stub", ("stub", Native.Router.Ospf.Area.Stub)), ("virtual-link", ("virtual_link", Native.Router.Ospf.Area.VirtualLink))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                        ('default_cost', (YLeaf(YType.uint32, 'default-cost'), ['int'])),
                    ])
                    self.id = None
                    self.default_cost = None

                    self.authentication = None
                    self._children_name_map["authentication"] = "authentication"

                    self.capability = Native.Router.Ospf.Area.Capability()
                    self.capability.parent = self
                    self._children_name_map["capability"] = "capability"

                    self.nssa = None
                    self._children_name_map["nssa"] = "nssa"

                    self.ipv4_range = Native.Router.Ospf.Area.Ipv4Range()
                    self.ipv4_range.parent = self
                    self._children_name_map["ipv4_range"] = "ipv4-range"

                    self.ipv6_range = Native.Router.Ospf.Area.Ipv6Range()
                    self.ipv6_range.parent = self
                    self._children_name_map["ipv6_range"] = "ipv6-range"

                    self.stub = None
                    self._children_name_map["stub"] = "stub"

                    self.filter_list = YList(self)
                    self.sham_link = YList(self)
                    self.virtual_link = YList(self)
                    self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Area, ['id', 'default_cost'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: message_digest
                    
                    	Use message\-digest authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Area.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                        ])
                        self.message_digest = None
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Area.Authentication, ['message_digest'], name, value)


                class Capability(Entity):
                    """
                    Enable area specific capability
                    
                    .. attribute:: default_exclusion
                    
                    	Enable exclusion of links from base topology
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Area.Capability, self).__init__()

                        self.yang_name = "capability"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default_exclusion', (YLeaf(YType.empty, 'default-exclusion'), ['Empty'])),
                        ])
                        self.default_exclusion = None
                        self._segment_path = lambda: "capability"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Area.Capability, ['default_exclusion'], name, value)


                class FilterList(Entity):
                    """
                    Filter networks between OSPF areas
                    
                    .. attribute:: in_out  (key)
                    
                    	
                    	**type**\:  :py:class:`InOut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.FilterList.InOut>`
                    
                    .. attribute:: prefix
                    
                    	Filter prefixes between OSPF areas
                    	**type**\: str
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Area.FilterList, self).__init__()

                        self.yang_name = "filter-list"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['in_out']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Area.FilterList.InOut')])),
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                        ])
                        self.in_out = None
                        self.prefix = None
                        self._segment_path = lambda: "filter-list" + "[in-out='" + str(self.in_out) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Area.FilterList, ['in_out', 'prefix'], name, value)

                    class InOut(Enum):
                        """
                        InOut (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Nssa(Entity):
                    """
                    Specify a NSSA area
                    
                    .. attribute:: default_information_originate
                    
                    	Originate Type 7 default into NSSA area
                    	**type**\:  :py:class:`DefaultInformationOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: no_ext_capability
                    
                    	Do not send domain specific capabilities into NSSA
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: no_redistribution
                    
                    	No redistribution into this NSSA area
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: no_summary
                    
                    	Do not send summary LSA into NSSA
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nssa_only
                    
                    	Limit default advertisement to this NSSA area
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: translate
                    
                    	Translate LSA
                    	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Nssa.Translate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Area.Nssa, self).__init__()

                        self.yang_name = "nssa"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default-information-originate", ("default_information_originate", Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate)), ("translate", ("translate", Native.Router.Ospf.Area.Nssa.Translate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                            ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                            ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                        ])
                        self.no_ext_capability = None
                        self.no_redistribution = None
                        self.no_summary = None
                        self.nssa_only = None

                        self.default_information_originate = None
                        self._children_name_map["default_information_originate"] = "default-information-originate"

                        self.translate = Native.Router.Ospf.Area.Nssa.Translate()
                        self.translate.parent = self
                        self._children_name_map["translate"] = "translate"
                        self._segment_path = lambda: "nssa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Area.Nssa, ['no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                    class DefaultInformationOriginate(Entity):
                        """
                        Originate Type 7 default into NSSA area
                        
                        .. attribute:: metric
                        
                        	OSPF default metric
                        	**type**\: int
                        
                        	**range:** 0..16777214
                        
                        .. attribute:: metric_type
                        
                        	OSPF metric type for default routes
                        	**type**\: int
                        
                        	**range:** 1..2
                        
                        .. attribute:: no_ext_capability
                        
                        	Do not send domain specific capabilities into NSSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: no_redistribution
                        
                        	No redistribution into this NSSA area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: no_summary
                        
                        	Do not send summary LSA into NSSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: nssa_only
                        
                        	Limit default advertisement to this NSSA area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: translate
                        
                        	Translate LSA
                        	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate.Translate>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate, self).__init__()

                            self.yang_name = "default-information-originate"
                            self.yang_parent_name = "nssa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("translate", ("translate", Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate.Translate))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.int32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.uint32, 'metric-type'), ['int'])),
                                ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                                ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.no_ext_capability = None
                            self.no_redistribution = None
                            self.no_summary = None
                            self.nssa_only = None

                            self.translate = Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate.Translate()
                            self.translate.parent = self
                            self._children_name_map["translate"] = "translate"
                            self._segment_path = lambda: "default-information-originate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate, ['metric', 'metric_type', 'no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                        class Translate(Entity):
                            """
                            Translate LSA
                            
                            .. attribute:: type7
                            
                            	From Type 7 to Type 5
                            	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate.Translate.Type7>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate.Translate, self).__init__()

                                self.yang_name = "translate"
                                self.yang_parent_name = "default-information-originate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate.Translate.Type7))])
                                self._leafs = OrderedDict()

                                self.type7 = Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate.Translate.Type7()
                                self.type7.parent = self
                                self._children_name_map["type7"] = "type7"
                                self._segment_path = lambda: "translate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate.Translate, [], name, value)


                            class Type7(Entity):
                                """
                                From Type 7 to Type 5
                                
                                .. attribute:: always
                                
                                	Always translate LSAs on this ABR
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: suppress_fa
                                
                                	Suppress forwarding address in translated LSAs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate.Translate.Type7, self).__init__()

                                    self.yang_name = "type7"
                                    self.yang_parent_name = "translate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                        ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                    ])
                                    self.always = None
                                    self.suppress_fa = None
                                    self._segment_path = lambda: "type7"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Area.Nssa.DefaultInformationOriginate.Translate.Type7, ['always', 'suppress_fa'], name, value)


                    class Translate(Entity):
                        """
                        Translate LSA
                        
                        .. attribute:: type7
                        
                        	From Type 7 to Type 5
                        	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Nssa.Translate.Type7>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.Nssa.Translate, self).__init__()

                            self.yang_name = "translate"
                            self.yang_parent_name = "nssa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospf.Area.Nssa.Translate.Type7))])
                            self._leafs = OrderedDict()

                            self.type7 = Native.Router.Ospf.Area.Nssa.Translate.Type7()
                            self.type7.parent = self
                            self._children_name_map["type7"] = "type7"
                            self._segment_path = lambda: "translate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.Nssa.Translate, [], name, value)


                        class Type7(Entity):
                            """
                            From Type 7 to Type 5
                            
                            .. attribute:: always
                            
                            	Always translate LSAs on this ABR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: suppress_fa
                            
                            	Suppress forwarding address in translated LSAs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Area.Nssa.Translate.Type7, self).__init__()

                                self.yang_name = "type7"
                                self.yang_parent_name = "translate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                    ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                ])
                                self.always = None
                                self.suppress_fa = None
                                self._segment_path = lambda: "type7"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Area.Nssa.Translate.Type7, ['always', 'suppress_fa'], name, value)


                class Ipv4Range(Entity):
                    """
                    
                    
                    .. attribute:: range
                    
                    	Summarize routes matching address/mask (border routers only)
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Ipv4Range.Range>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Area.Ipv4Range, self).__init__()

                        self.yang_name = "ipv4-range"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospf.Area.Ipv4Range.Range))])
                        self._leafs = OrderedDict()

                        self.range = YList(self)
                        self._segment_path = lambda: "ipv4-range"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Area.Ipv4Range, [], name, value)


                    class Range(Entity):
                        """
                        Summarize routes matching address/mask (border routers only)
                        
                        .. attribute:: ip  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: advertise
                        
                        	Advertise this range (default)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: not_advertise
                        
                        	DoNotAdvertise this range
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cost
                        
                        	User specified metric for this range
                        	**type**\: int
                        
                        	**range:** 0..16777215
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.Ipv4Range.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ipv4-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip','mask']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.ip = None
                            self.mask = None
                            self.advertise = None
                            self.not_advertise = None
                            self.cost = None
                            self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.Ipv4Range.Range, ['ip', 'mask', 'advertise', 'not_advertise', 'cost'], name, value)


                class Ipv6Range(Entity):
                    """
                    
                    
                    .. attribute:: range
                    
                    	Summarize routes matching address/mask (border routers only)
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.Ipv6Range.Range>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Area.Ipv6Range, self).__init__()

                        self.yang_name = "ipv6-range"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospf.Area.Ipv6Range.Range))])
                        self._leafs = OrderedDict()

                        self.range = YList(self)
                        self._segment_path = lambda: "ipv6-range"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Area.Ipv6Range, [], name, value)


                    class Range(Entity):
                        """
                        Summarize routes matching address/mask (border routers only)
                        
                        .. attribute:: ip  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: advertise
                        
                        	Advertise this range (default)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: not_advertise
                        
                        	DoNotAdvertise this range
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cost
                        
                        	User specified metric for this range
                        	**type**\: int
                        
                        	**range:** 0..16777215
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.Ipv6Range.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ipv6-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.ip = None
                            self.advertise = None
                            self.not_advertise = None
                            self.cost = None
                            self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.Ipv6Range.Range, ['ip', 'advertise', 'not_advertise', 'cost'], name, value)


                class ShamLink(Entity):
                    """
                    Define a sham link and its parameters
                    
                    .. attribute:: source  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: dest  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Associate a cost with the sham\-link
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.ShamLink.TtlSecurity>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Area.ShamLink, self).__init__()

                        self.yang_name = "sham-link"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['source','dest']
                        self._child_classes = OrderedDict([("ttl-security", ("ttl_security", Native.Router.Ospf.Area.ShamLink.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('source', (YLeaf(YType.str, 'source'), ['str','str'])),
                            ('dest', (YLeaf(YType.str, 'dest'), ['str','str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                        ])
                        self.source = None
                        self.dest = None
                        self.cost = None

                        self.ttl_security = Native.Router.Ospf.Area.ShamLink.TtlSecurity()
                        self.ttl_security.parent = self
                        self._children_name_map["ttl_security"] = "ttl-security"
                        self._segment_path = lambda: "sham-link" + "[source='" + str(self.source) + "']" + "[dest='" + str(self.dest) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Area.ShamLink, ['source', 'dest', 'cost'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.ShamLink.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "sham-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.ShamLink.TtlSecurity, ['hops'], name, value)


                class Stub(Entity):
                    """
                    Specify a stub area
                    
                    .. attribute:: no_ext_capability
                    
                    	Do not send domain specific capabilities into stub area
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: no_summary
                    
                    	Do not send summary LSA into stub area
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Area.Stub, self).__init__()

                        self.yang_name = "stub"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                            ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                        ])
                        self.no_ext_capability = None
                        self.no_summary = None
                        self._segment_path = lambda: "stub"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Area.Stub, ['no_ext_capability', 'no_summary'], name, value)


                class VirtualLink(Entity):
                    """
                    Define a virtual link and its parameters
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: authentication
                    
                    	Set authentication type
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication>`
                    
                    .. attribute:: hello_interval
                    
                    	Hello packet interval
                    	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.HelloInterval>`
                    
                    .. attribute:: dead_interval
                    
                    	Dead router detection time
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.DeadInterval>`
                    
                    .. attribute:: retransmit_interval
                    
                    	LSA retransmit interval
                    	**type**\:  :py:class:`RetransmitInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.RetransmitInterval>`
                    
                    .. attribute:: transmit_delay
                    
                    	LSA transmission delay
                    	**type**\:  :py:class:`TransmitDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.TransmitDelay>`
                    
                    .. attribute:: topology
                    
                    	Disable virtual link on topology
                    	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Topology>`
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.TtlSecurity>`
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.AuthenticationKey>`
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.MessageDigestKey>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Area.VirtualLink, self).__init__()

                        self.yang_name = "virtual-link"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospf.Area.VirtualLink.Authentication)), ("hello-interval", ("hello_interval", Native.Router.Ospf.Area.VirtualLink.HelloInterval)), ("dead-interval", ("dead_interval", Native.Router.Ospf.Area.VirtualLink.DeadInterval)), ("retransmit-interval", ("retransmit_interval", Native.Router.Ospf.Area.VirtualLink.RetransmitInterval)), ("transmit-delay", ("transmit_delay", Native.Router.Ospf.Area.VirtualLink.TransmitDelay)), ("topology", ("topology", Native.Router.Ospf.Area.VirtualLink.Topology)), ("ttl-security", ("ttl_security", Native.Router.Ospf.Area.VirtualLink.TtlSecurity)), ("authentication-key", ("authentication_key", Native.Router.Ospf.Area.VirtualLink.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospf.Area.VirtualLink.MessageDigestKey))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                        ])
                        self.id = None

                        self.authentication = Native.Router.Ospf.Area.VirtualLink.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.hello_interval = Native.Router.Ospf.Area.VirtualLink.HelloInterval()
                        self.hello_interval.parent = self
                        self._children_name_map["hello_interval"] = "hello-interval"

                        self.dead_interval = Native.Router.Ospf.Area.VirtualLink.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.retransmit_interval = Native.Router.Ospf.Area.VirtualLink.RetransmitInterval()
                        self.retransmit_interval.parent = self
                        self._children_name_map["retransmit_interval"] = "retransmit-interval"

                        self.transmit_delay = Native.Router.Ospf.Area.VirtualLink.TransmitDelay()
                        self.transmit_delay.parent = self
                        self._children_name_map["transmit_delay"] = "transmit-delay"

                        self.topology = Native.Router.Ospf.Area.VirtualLink.Topology()
                        self.topology.parent = self
                        self._children_name_map["topology"] = "topology"

                        self.ttl_security = Native.Router.Ospf.Area.VirtualLink.TtlSecurity()
                        self.ttl_security.parent = self
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.authentication_key = Native.Router.Ospf.Area.VirtualLink.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "virtual-link" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Area.VirtualLink, ['id'], name, value)


                    class Authentication(Entity):
                        """
                        Set authentication type
                        
                        .. attribute:: authentication_key
                        
                        	Set authentication key
                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication.AuthenticationKey>`
                        
                        .. attribute:: message_digest_key
                        
                        	Set message digest key
                        	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigestKey>`
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Message\-digest authentication
                        	**type**\:  :py:class:`MessageDigest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest>`
                        
                        .. attribute:: null
                        
                        	No authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.VirtualLink.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospf.Area.VirtualLink.Authentication.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigestKey)), ("key-chain", ("key_chain", Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain)), ("message-digest", ("message_digest", Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.authentication_key = Native.Router.Ospf.Area.VirtualLink.Authentication.AuthenticationKey()
                            self.authentication_key.parent = self
                            self._children_name_map["authentication_key"] = "authentication-key"

                            self.key_chain = Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"

                            self.message_digest = Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest()
                            self.message_digest.parent = self
                            self._children_name_map["message_digest"] = "message-digest"

                            self.message_digest_key = YList(self)
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication, ['null'], name, value)


                        class AuthenticationKey(Entity):
                            """
                            Set authentication key
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Area.VirtualLink.Authentication.AuthenticationKey, self).__init__()

                                self.yang_name = "authentication-key"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "authentication-key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                        class MessageDigestKey(Entity):
                            """
                            Set message digest key
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: md5
                            
                            	Use MD5 algorithm
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigestKey.Md5>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigestKey, self).__init__()

                                self.yang_name = "message-digest-key"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigestKey.Md5))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.md5 = Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigestKey.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"
                                self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigestKey, ['id'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 algorithm
                                
                                .. attribute:: auth_type
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: auth_key
                                
                                	
                                	**type**\: str
                                
                                	**length:** 1..16
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigestKey.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "message-digest-key"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                    ])
                                    self.auth_type = None
                                    self.auth_key = None
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: authentication_key
                            
                            	Set authentication key
                            	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey>`
                            
                            .. attribute:: message_digest_key
                            
                            	Set message digest key
                            	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.authentication_key = Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey()
                                self.authentication_key.parent = self
                                self._children_name_map["authentication_key"] = "authentication-key"

                                self.message_digest_key = YList(self)
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain, ['name'], name, value)


                            class AuthenticationKey(Entity):
                                """
                                Set authentication key
                                
                                .. attribute:: auth_type
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: auth_key
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, self).__init__()

                                    self.yang_name = "authentication-key"
                                    self.yang_parent_name = "key-chain"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                    ])
                                    self.auth_type = None
                                    self.auth_key = None
                                    self._segment_path = lambda: "authentication-key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                            class MessageDigestKey(Entity):
                                """
                                Set message digest key
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: md5
                                
                                	Use MD5 algorithm
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, self).__init__()

                                    self.yang_name = "message-digest-key"
                                    self.yang_parent_name = "key-chain"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.md5 = Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, ['id'], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 algorithm
                                    
                                    .. attribute:: auth_type
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: auth_key
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**length:** 1..16
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "message-digest-key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                            ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                        ])
                                        self.auth_type = None
                                        self.auth_key = None
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                        class MessageDigest(Entity):
                            """
                            Message\-digest authentication
                            
                            .. attribute:: authentication_key
                            
                            	Set authentication key
                            	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey>`
                            
                            .. attribute:: message_digest_key
                            
                            	Set message digest key
                            	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest, self).__init__()

                                self.yang_name = "message-digest"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey))])
                                self._leafs = OrderedDict()

                                self.authentication_key = Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey()
                                self.authentication_key.parent = self
                                self._children_name_map["authentication_key"] = "authentication-key"

                                self.message_digest_key = YList(self)
                                self._segment_path = lambda: "message-digest"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest, [], name, value)


                            class AuthenticationKey(Entity):
                                """
                                Set authentication key
                                
                                .. attribute:: auth_type
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: auth_key
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, self).__init__()

                                    self.yang_name = "authentication-key"
                                    self.yang_parent_name = "message-digest"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                    ])
                                    self.auth_type = None
                                    self.auth_key = None
                                    self._segment_path = lambda: "authentication-key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                            class MessageDigestKey(Entity):
                                """
                                Set message digest key
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: md5
                                
                                	Use MD5 algorithm
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, self).__init__()

                                    self.yang_name = "message-digest-key"
                                    self.yang_parent_name = "message-digest"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.md5 = Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, ['id'], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 algorithm
                                    
                                    .. attribute:: auth_type
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: auth_key
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**length:** 1..16
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "message-digest-key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                            ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                        ])
                                        self.auth_type = None
                                        self.auth_key = None
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class HelloInterval(Entity):
                        """
                        Hello packet interval
                        
                        .. attribute:: hello_interval_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8192
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.VirtualLink.HelloInterval, self).__init__()

                            self.yang_name = "hello-interval"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('hello_interval_value', (YLeaf(YType.int32, 'hello-interval-value'), ['int'])),
                            ])
                            self.hello_interval_value = None
                            self._segment_path = lambda: "hello-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.HelloInterval, ['hello_interval_value'], name, value)


                    class DeadInterval(Entity):
                        """
                        Dead router detection time
                        
                        .. attribute:: dead_interval_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8192
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.VirtualLink.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dead_interval_value', (YLeaf(YType.uint16, 'dead-interval-value'), ['int'])),
                            ])
                            self.dead_interval_value = None
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.DeadInterval, ['dead_interval_value'], name, value)


                    class RetransmitInterval(Entity):
                        """
                        LSA retransmit interval
                        
                        .. attribute:: retransmit_interval_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8192
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.VirtualLink.RetransmitInterval, self).__init__()

                            self.yang_name = "retransmit-interval"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('retransmit_interval_value', (YLeaf(YType.uint16, 'retransmit-interval-value'), ['int'])),
                            ])
                            self.retransmit_interval_value = None
                            self._segment_path = lambda: "retransmit-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.RetransmitInterval, ['retransmit_interval_value'], name, value)


                    class TransmitDelay(Entity):
                        """
                        LSA transmission delay
                        
                        .. attribute:: transmit_delay_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8192
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.VirtualLink.TransmitDelay, self).__init__()

                            self.yang_name = "transmit-delay"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transmit_delay_value', (YLeaf(YType.uint16, 'transmit-delay-value'), ['int'])),
                            ])
                            self.transmit_delay_value = None
                            self._segment_path = lambda: "transmit-delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.TransmitDelay, ['transmit_delay_value'], name, value)


                    class Topology(Entity):
                        """
                        Disable virtual link on topology
                        
                        .. attribute:: disable
                        
                        	Disable virtual link
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.VirtualLink.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "topology"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.Topology, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.VirtualLink.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.TtlSecurity, ['hops'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.VirtualLink.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Area.VirtualLink.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Area.VirtualLink.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospf.Area.VirtualLink.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Router.Ospf.Area.VirtualLink.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..16
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Area.VirtualLink.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Area.VirtualLink.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


            class AutoCost(Entity):
                """
                Calculate OSPF interface cost according to bandwidth
                
                .. attribute:: reference_bandwidth
                
                	Use reference bandwidth method to assign OSPF cost
                	**type**\: int
                
                	**range:** 1..4294967
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.AutoCost, self).__init__()

                    self.yang_name = "auto-cost"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('reference_bandwidth', (YLeaf(YType.uint32, 'reference-bandwidth'), ['int'])),
                    ])
                    self.reference_bandwidth = None
                    self._segment_path = lambda: "auto-cost"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.AutoCost, ['reference_bandwidth'], name, value)


            class EventLog(Entity):
                """
                OSPF Event Logging
                
                .. attribute:: one_shot
                
                	Disable Logging When Log Buffer Becomes Full
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pause
                
                	Pause Event Logging
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: size
                
                	Maximum Number of Events Stored in the Event Log
                	**type**\: int
                
                	**range:** 1..65534
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.EventLog, self).__init__()

                    self.yang_name = "event-log"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('one_shot', (YLeaf(YType.empty, 'one-shot'), ['Empty'])),
                        ('pause', (YLeaf(YType.empty, 'pause'), ['Empty'])),
                        ('size', (YLeaf(YType.uint32, 'size'), ['int'])),
                    ])
                    self.one_shot = None
                    self.pause = None
                    self.size = None
                    self._segment_path = lambda: "event-log"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.EventLog, ['one_shot', 'pause', 'size'], name, value)


            class Bfd(Entity):
                """
                BFD configuration commands
                
                .. attribute:: all_interfaces
                
                	Enable BFD on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                    ])
                    self.all_interfaces = None
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Bfd, ['all_interfaces'], name, value)


            class InterfaceId(Entity):
                """
                Source of the interface ID
                
                .. attribute:: snmp_if_index
                
                	SNMP MIB ifIndex
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.InterfaceId, self).__init__()

                    self.yang_name = "interface-id"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('snmp_if_index', (YLeaf(YType.empty, 'snmp-if-index'), ['Empty'])),
                    ])
                    self.snmp_if_index = None
                    self._segment_path = lambda: "interface-id"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.InterfaceId, ['snmp_if_index'], name, value)


            class LogAdjacencyChanges(Entity):
                """
                Log changes in adjacency state
                
                .. attribute:: detail
                
                	Log all state changes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.LogAdjacencyChanges, self).__init__()

                    self.yang_name = "log-adjacency-changes"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('detail', (YLeaf(YType.empty, 'detail'), ['Empty'])),
                    ])
                    self.detail = None
                    self._segment_path = lambda: "log-adjacency-changes"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.LogAdjacencyChanges, ['detail'], name, value)


            class MaxLsa(Entity):
                """
                maximum number of LSAs OSPF process will receive
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..4294967294
                
                .. attribute:: threshold_value
                
                	
                	**type**\: int
                
                	**range:** 1..100
                
                .. attribute:: ignore_count
                
                	maximum number of times adjacencies can be suppressed
                	**type**\: int
                
                	**range:** 1..65534
                
                .. attribute:: ignore_time
                
                	time during which all adjacencies are suppressed
                	**type**\: int
                
                	**range:** 1..17895
                
                .. attribute:: reset_time
                
                	time after which ignore\-count is reset to zero
                	**type**\: int
                
                	**range:** 2..35791
                
                .. attribute:: warning_only
                
                	Only give warning message when limit is exceeded
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.MaxLsa, self).__init__()

                    self.yang_name = "max-lsa"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                        ('threshold_value', (YLeaf(YType.uint32, 'threshold-value'), ['int'])),
                        ('ignore_count', (YLeaf(YType.uint32, 'ignore-count'), ['int'])),
                        ('ignore_time', (YLeaf(YType.uint32, 'ignore-time'), ['int'])),
                        ('reset_time', (YLeaf(YType.uint32, 'reset-time'), ['int'])),
                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                    ])
                    self.number = None
                    self.threshold_value = None
                    self.ignore_count = None
                    self.ignore_time = None
                    self.reset_time = None
                    self.warning_only = None
                    self._segment_path = lambda: "max-lsa"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.MaxLsa, ['number', 'threshold_value', 'ignore_count', 'ignore_time', 'reset_time', 'warning_only'], name, value)


            class MaxMetric(Entity):
                """
                Set maximum metric
                
                .. attribute:: router_lsa
                
                	Maximum metric in self\-originated router\-LSAs
                	**type**\:  :py:class:`RouterLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.MaxMetric.RouterLsa>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.MaxMetric, self).__init__()

                    self.yang_name = "max-metric"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("router-lsa", ("router_lsa", Native.Router.Ospf.MaxMetric.RouterLsa))])
                    self._leafs = OrderedDict()

                    self.router_lsa = None
                    self._children_name_map["router_lsa"] = "router-lsa"
                    self._segment_path = lambda: "max-metric"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.MaxMetric, [], name, value)


                class RouterLsa(Entity):
                    """
                    Maximum metric in self\-originated router\-LSAs
                    
                    .. attribute:: external_lsa
                    
                    	Override external\-lsa metric with max\-metric value
                    	**type**\:  :py:class:`ExternalLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.MaxMetric.RouterLsa.ExternalLsa>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: include_stub
                    
                    	Set maximum metric for stub links in router\-LSAs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: on_startup
                    
                    	Set maximum metric temporarily after reboot
                    	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.MaxMetric.RouterLsa.OnStartup>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: summary_lsa
                    
                    	Override summary\-lsa metric with max\-metric value
                    	**type**\:  :py:class:`SummaryLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.MaxMetric.RouterLsa.SummaryLsa>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.MaxMetric.RouterLsa, self).__init__()

                        self.yang_name = "router-lsa"
                        self.yang_parent_name = "max-metric"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("external-lsa", ("external_lsa", Native.Router.Ospf.MaxMetric.RouterLsa.ExternalLsa)), ("on-startup", ("on_startup", Native.Router.Ospf.MaxMetric.RouterLsa.OnStartup)), ("summary-lsa", ("summary_lsa", Native.Router.Ospf.MaxMetric.RouterLsa.SummaryLsa))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('include_stub', (YLeaf(YType.empty, 'include-stub'), ['Empty'])),
                        ])
                        self.include_stub = None

                        self.external_lsa = None
                        self._children_name_map["external_lsa"] = "external-lsa"

                        self.on_startup = None
                        self._children_name_map["on_startup"] = "on-startup"

                        self.summary_lsa = None
                        self._children_name_map["summary_lsa"] = "summary-lsa"
                        self._segment_path = lambda: "router-lsa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.MaxMetric.RouterLsa, ['include_stub'], name, value)


                    class ExternalLsa(Entity):
                        """
                        Override external\-lsa metric with max\-metric value
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777215
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.MaxMetric.RouterLsa.ExternalLsa, self).__init__()

                            self.yang_name = "external-lsa"
                            self.yang_parent_name = "router-lsa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.metric = None
                            self._segment_path = lambda: "external-lsa"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.MaxMetric.RouterLsa.ExternalLsa, ['metric'], name, value)


                    class OnStartup(Entity):
                        """
                        Set maximum metric temporarily after reboot
                        
                        .. attribute:: time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 5..86400
                        
                        .. attribute:: wait_for_bgp
                        
                        	Let BGP decide when to originate router\-LSA with normal metric
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.MaxMetric.RouterLsa.OnStartup, self).__init__()

                            self.yang_name = "on-startup"
                            self.yang_parent_name = "router-lsa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                ('wait_for_bgp', (YLeaf(YType.empty, 'wait-for-bgp'), ['Empty'])),
                            ])
                            self.time = None
                            self.wait_for_bgp = None
                            self._segment_path = lambda: "on-startup"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.MaxMetric.RouterLsa.OnStartup, ['time', 'wait_for_bgp'], name, value)


                    class SummaryLsa(Entity):
                        """
                        Override summary\-lsa metric with max\-metric value
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777215
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.MaxMetric.RouterLsa.SummaryLsa, self).__init__()

                            self.yang_name = "summary-lsa"
                            self.yang_parent_name = "router-lsa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.metric = None
                            self._segment_path = lambda: "summary-lsa"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.MaxMetric.RouterLsa.SummaryLsa, ['metric'], name, value)


            class PassiveInterface(Entity):
                """
                Suppress routing updates on an interface
                
                .. attribute:: default
                
                	Suppress routing updates on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.PassiveInterface, self).__init__()

                    self.yang_name = "passive-interface"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                    ])
                    self.default = None
                    self.interface = None
                    self._segment_path = lambda: "passive-interface"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.PassiveInterface, [u'default', u'interface'], name, value)


            class Disable(Entity):
                """
                
                
                .. attribute:: passive_interface
                
                	
                	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Disable.PassiveInterface>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Disable, self).__init__()

                    self.yang_name = "disable"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.Ospf.Disable.PassiveInterface))])
                    self._leafs = OrderedDict()

                    self.passive_interface = YList(self)
                    self._segment_path = lambda: "disable"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Disable, [], name, value)


                class PassiveInterface(Entity):
                    """
                    
                    
                    .. attribute:: interface  (key)
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Disable.PassiveInterface, self).__init__()

                        self.yang_name = "passive-interface"
                        self.yang_parent_name = "disable"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ])
                        self.interface = None
                        self._segment_path = lambda: "passive-interface" + "[interface='" + str(self.interface) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Disable.PassiveInterface, [u'interface'], name, value)


            class QueueDepth(Entity):
                """
                OSPF Hello/Router process queue depth
                
                .. attribute:: hello
                
                	OSPF Hello process queue depth
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.QueueDepth.Hello>`
                
                .. attribute:: update
                
                	OSPF Router process queue depth
                	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.QueueDepth.Update>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.QueueDepth, self).__init__()

                    self.yang_name = "queue-depth"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("hello", ("hello", Native.Router.Ospf.QueueDepth.Hello)), ("update", ("update", Native.Router.Ospf.QueueDepth.Update))])
                    self._leafs = OrderedDict()

                    self.hello = Native.Router.Ospf.QueueDepth.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "hello"

                    self.update = Native.Router.Ospf.QueueDepth.Update()
                    self.update.parent = self
                    self._children_name_map["update"] = "update"
                    self._segment_path = lambda: "queue-depth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.QueueDepth, [], name, value)


                class Hello(Entity):
                    """
                    OSPF Hello process queue depth
                    
                    .. attribute:: options
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..2147483647
                    
                    		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.QueueDepth.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "queue-depth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                        ])
                        self.options = None
                        self._segment_path = lambda: "hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.QueueDepth.Hello, ['options'], name, value)

                    class Options(Enum):
                        """
                        Options (Enum Class)

                        .. data:: unlimited = 0

                        """

                        unlimited = Enum.YLeaf(0, "unlimited")



                class Update(Entity):
                    """
                    OSPF Router process queue depth
                    
                    .. attribute:: options
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..2147483647
                    
                    		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.QueueDepth.Update, self).__init__()

                        self.yang_name = "update"
                        self.yang_parent_name = "queue-depth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                        ])
                        self.options = None
                        self._segment_path = lambda: "update"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.QueueDepth.Update, ['options'], name, value)

                    class Options(Enum):
                        """
                        Options (Enum Class)

                        .. data:: unlimited = 0

                        """

                        unlimited = Enum.YLeaf(0, "unlimited")



            class Timers(Entity):
                """
                Adjust routing timers
                
                .. attribute:: lsa
                
                	OSPF LSA timers
                	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Timers.Lsa>`
                
                .. attribute:: pacing
                
                	OSPF pacing timers
                	**type**\:  :py:class:`Pacing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Timers.Pacing>`
                
                .. attribute:: throttle
                
                	OSPF throttle timers
                	**type**\:  :py:class:`Throttle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Timers.Throttle>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Timers, self).__init__()

                    self.yang_name = "timers"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospf.Timers.Lsa)), ("pacing", ("pacing", Native.Router.Ospf.Timers.Pacing)), ("throttle", ("throttle", Native.Router.Ospf.Timers.Throttle))])
                    self._leafs = OrderedDict()

                    self.lsa = Native.Router.Ospf.Timers.Lsa()
                    self.lsa.parent = self
                    self._children_name_map["lsa"] = "lsa"

                    self.pacing = Native.Router.Ospf.Timers.Pacing()
                    self.pacing.parent = self
                    self._children_name_map["pacing"] = "pacing"

                    self.throttle = Native.Router.Ospf.Timers.Throttle()
                    self.throttle.parent = self
                    self._children_name_map["throttle"] = "throttle"
                    self._segment_path = lambda: "timers"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Timers, [], name, value)


                class Lsa(Entity):
                    """
                    OSPF LSA timers
                    
                    .. attribute:: arrival
                    
                    	OSPF LSA arrival timer
                    	**type**\: int
                    
                    	**range:** 0..600000
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Timers.Lsa, self).__init__()

                        self.yang_name = "lsa"
                        self.yang_parent_name = "timers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('arrival', (YLeaf(YType.uint32, 'arrival'), ['int'])),
                        ])
                        self.arrival = None
                        self._segment_path = lambda: "lsa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Timers.Lsa, ['arrival'], name, value)


                class Pacing(Entity):
                    """
                    OSPF pacing timers
                    
                    .. attribute:: flood
                    
                    	OSPF flood pacing timer
                    	**type**\: int
                    
                    	**range:** 5..100
                    
                    .. attribute:: lsa_group
                    
                    	OSPF LSA group pacing timer
                    	**type**\: int
                    
                    	**range:** 10..1800
                    
                    .. attribute:: retransmission
                    
                    	OSPF retransmission pacing timer
                    	**type**\: int
                    
                    	**range:** 5..200
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Timers.Pacing, self).__init__()

                        self.yang_name = "pacing"
                        self.yang_parent_name = "timers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('flood', (YLeaf(YType.uint32, 'flood'), ['int'])),
                            ('lsa_group', (YLeaf(YType.uint32, 'lsa-group'), ['int'])),
                            ('retransmission', (YLeaf(YType.uint32, 'retransmission'), ['int'])),
                        ])
                        self.flood = None
                        self.lsa_group = None
                        self.retransmission = None
                        self._segment_path = lambda: "pacing"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Timers.Pacing, ['flood', 'lsa_group', 'retransmission'], name, value)


                class Throttle(Entity):
                    """
                    OSPF throttle timers
                    
                    .. attribute:: lsa
                    
                    	OSPF LSA throttle timers
                    	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Timers.Throttle.Lsa>`
                    
                    .. attribute:: spf
                    
                    	OSPF SPF throttle timers
                    	**type**\:  :py:class:`Spf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Timers.Throttle.Spf>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Timers.Throttle, self).__init__()

                        self.yang_name = "throttle"
                        self.yang_parent_name = "timers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospf.Timers.Throttle.Lsa)), ("spf", ("spf", Native.Router.Ospf.Timers.Throttle.Spf))])
                        self._leafs = OrderedDict()

                        self.lsa = Native.Router.Ospf.Timers.Throttle.Lsa()
                        self.lsa.parent = self
                        self._children_name_map["lsa"] = "lsa"

                        self.spf = Native.Router.Ospf.Timers.Throttle.Spf()
                        self.spf.parent = self
                        self._children_name_map["spf"] = "spf"
                        self._segment_path = lambda: "throttle"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Timers.Throttle, [], name, value)


                    class Lsa(Entity):
                        """
                        OSPF LSA throttle timers
                        
                        .. attribute:: all
                        
                        	For all type of OSPF LSAs
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Timers.Throttle.Lsa.All>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Timers.Throttle.Lsa, self).__init__()

                            self.yang_name = "lsa"
                            self.yang_parent_name = "throttle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Ospf.Timers.Throttle.Lsa.All))])
                            self._leafs = OrderedDict()

                            self.all = Native.Router.Ospf.Timers.Throttle.Lsa.All()
                            self.all.parent = self
                            self._children_name_map["all"] = "all"
                            self._segment_path = lambda: "lsa"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Timers.Throttle.Lsa, [], name, value)


                        class All(Entity):
                            """
                            For all type of OSPF LSAs
                            
                            .. attribute:: delay
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..600000
                            
                            .. attribute:: min_delay
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..600000
                            
                            .. attribute:: max_delay
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..600000
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Timers.Throttle.Lsa.All, self).__init__()

                                self.yang_name = "all"
                                self.yang_parent_name = "lsa"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                    ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                    ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                ])
                                self.delay = None
                                self.min_delay = None
                                self.max_delay = None
                                self._segment_path = lambda: "all"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Timers.Throttle.Lsa.All, ['delay', 'min_delay', 'max_delay'], name, value)


                    class Spf(Entity):
                        """
                        OSPF SPF throttle timers
                        
                        .. attribute:: delay
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..600000
                        
                        .. attribute:: min_delay
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..600000
                        
                        .. attribute:: max_delay
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..600000
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Timers.Throttle.Spf, self).__init__()

                            self.yang_name = "spf"
                            self.yang_parent_name = "throttle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                            ])
                            self.delay = None
                            self.min_delay = None
                            self.max_delay = None
                            self._segment_path = lambda: "spf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Timers.Throttle.Spf, ['delay', 'min_delay', 'max_delay'], name, value)


            class TrafficShare(Entity):
                """
                How to compute traffic share over alternate paths
                
                .. attribute:: min
                
                	All traffic shared among min metric paths
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: across_interfaces
                
                	Use different interfaces for equal\-cost paths
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.TrafficShare, self).__init__()

                    self.yang_name = "traffic-share"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                        ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                    ])
                    self.min = None
                    self.across_interfaces = None
                    self._segment_path = lambda: "traffic-share"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.TrafficShare, ['min', 'across_interfaces'], name, value)


            class TtlSecurity(Entity):
                """
                TTL security check
                
                .. attribute:: all_interfaces
                
                	Enable TTL Security on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hops
                
                	IP hops
                	**type**\: int
                
                	**range:** 1..254
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.TtlSecurity, self).__init__()

                    self.yang_name = "ttl-security"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                        ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                    ])
                    self.all_interfaces = None
                    self.hops = None
                    self._segment_path = lambda: "ttl-security"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.TtlSecurity, ['all_interfaces', 'hops'], name, value)


            class Capability(Entity):
                """
                Enable specific OSPF feature
                
                .. attribute:: capability_type
                
                	
                	**type**\:  :py:class:`CapabilityType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Capability.CapabilityType>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Capability, self).__init__()

                    self.yang_name = "capability"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('capability_type', (YLeaf(YType.enumeration, 'capability-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Capability.CapabilityType')])),
                    ])
                    self.capability_type = None
                    self._segment_path = lambda: "capability"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Capability, ['capability_type'], name, value)

                class CapabilityType(Enum):
                    """
                    CapabilityType (Enum Class)

                    .. data:: lls = 0

                    .. data:: opaque = 1

                    .. data:: transit = 2

                    .. data:: vrf_lite = 3

                    """

                    lls = Enum.YLeaf(0, "lls")

                    opaque = Enum.YLeaf(1, "opaque")

                    transit = Enum.YLeaf(2, "transit")

                    vrf_lite = Enum.YLeaf(3, "vrf-lite")



            class Compatible(Entity):
                """
                OSPF compatibility list
                
                .. attribute:: rfc1583
                
                	Compatible with RFC 1583
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: rfc1587
                
                	Compatible with RFC 1587
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: rfc5243
                
                	Compatible with RFC 5243
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Compatible, self).__init__()

                    self.yang_name = "compatible"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('rfc1583', (YLeaf(YType.empty, 'rfc1583'), ['Empty'])),
                        ('rfc1587', (YLeaf(YType.empty, 'rfc1587'), ['Empty'])),
                        ('rfc5243', (YLeaf(YType.empty, 'rfc5243'), ['Empty'])),
                    ])
                    self.rfc1583 = None
                    self.rfc1587 = None
                    self.rfc5243 = None
                    self._segment_path = lambda: "compatible"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Compatible, ['rfc1583', 'rfc1587', 'rfc5243'], name, value)


            class DefaultInformation(Entity):
                """
                Control distribution of default information
                
                .. attribute:: originate
                
                	Distribute a default route
                	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DefaultInformation.Originate>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.DefaultInformation, self).__init__()

                    self.yang_name = "default-information"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("originate", ("originate", Native.Router.Ospf.DefaultInformation.Originate))])
                    self._leafs = OrderedDict()

                    self.originate = None
                    self._children_name_map["originate"] = "originate"
                    self._segment_path = lambda: "default-information"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.DefaultInformation, [], name, value)


                class Originate(Entity):
                    """
                    Distribute a default route
                    
                    .. attribute:: always
                    
                    	Always advertise default route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: metric
                    
                    	OSPF default metric
                    	**type**\: int
                    
                    	**range:** 0..16777214
                    
                    .. attribute:: metric_type
                    
                    	OSPF metric type for default routes
                    	**type**\: int
                    
                    	**range:** 1..2
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.DefaultInformation.Originate, self).__init__()

                        self.yang_name = "originate"
                        self.yang_parent_name = "default-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.uint32, 'metric-type'), ['int'])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.always = None
                        self.metric = None
                        self.metric_type = None
                        self.route_map = None
                        self._segment_path = lambda: "originate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.DefaultInformation.Originate, ['always', 'metric', 'metric_type', 'route_map'], name, value)


            class DiscardRoute(Entity):
                """
                Enable or disable discard\-route installation
                
                .. attribute:: external
                
                	Discard route for redistributed summarised routes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: internal
                
                	Discard route for summarised internal routes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: metric
                
                	
                	**type**\: int
                
                	**range:** 1..255
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.DiscardRoute, self).__init__()

                    self.yang_name = "discard-route"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                        ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                    ])
                    self.external = None
                    self.internal = None
                    self.metric = None
                    self._segment_path = lambda: "discard-route"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.DiscardRoute, ['external', 'internal', 'metric'], name, value)


            class Distance(Entity):
                """
                Define an administrative distance
                
                .. attribute:: ospf_distance
                
                	
                	**type**\:  :py:class:`OspfDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Distance.OspfDistance>`
                
                .. attribute:: ospf
                
                	OSPF routes Administrative distance
                	**type**\:  :py:class:`Ospf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Distance.Ospf_>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Distance, self).__init__()

                    self.yang_name = "distance"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ospf-distance", ("ospf_distance", Native.Router.Ospf.Distance.OspfDistance)), ("ospf", ("ospf", Native.Router.Ospf.Distance.Ospf_))])
                    self._leafs = OrderedDict()

                    self.ospf_distance = Native.Router.Ospf.Distance.OspfDistance()
                    self.ospf_distance.parent = self
                    self._children_name_map["ospf_distance"] = "ospf-distance"

                    self.ospf = Native.Router.Ospf.Distance.Ospf_()
                    self.ospf.parent = self
                    self._children_name_map["ospf"] = "ospf"
                    self._segment_path = lambda: "distance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Distance, [], name, value)


                class OspfDistance(Entity):
                    """
                    
                    
                    .. attribute:: distance
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: wildcard
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: acl_name
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Distance.OspfDistance, self).__init__()

                        self.yang_name = "ospf-distance"
                        self.yang_parent_name = "distance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                            ('wildcard', (YLeaf(YType.str, 'wildcard'), ['str'])),
                            ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','int','str'])),
                        ])
                        self.distance = None
                        self.ip = None
                        self.wildcard = None
                        self.acl_name = None
                        self._segment_path = lambda: "ospf-distance"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Distance.OspfDistance, ['distance', 'ip', 'wildcard', 'acl_name'], name, value)


                class Ospf_(Entity):
                    """
                    OSPF routes Administrative distance
                    
                    .. attribute:: external
                    
                    	External routes
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: inter_area
                    
                    	Inter\-area routes
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: intra_area
                    
                    	Intra\-area routes
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Distance.Ospf_, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "distance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('external', (YLeaf(YType.uint32, 'external'), ['int'])),
                            ('inter_area', (YLeaf(YType.uint32, 'inter-area'), ['int'])),
                            ('intra_area', (YLeaf(YType.uint32, 'intra-area'), ['int'])),
                        ])
                        self.external = None
                        self.inter_area = None
                        self.intra_area = None
                        self._segment_path = lambda: "ospf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Distance.Ospf_, ['external', 'inter_area', 'intra_area'], name, value)


            class Redistribute(Entity):
                """
                Redistribute information from another routing protocol
                
                .. attribute:: application
                
                	Application
                	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Application>`
                
                .. attribute:: bgp
                
                	Border Gateway Protocol (BGP)
                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Bgp>`
                
                .. attribute:: connected
                
                	Connected
                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Connected>`
                
                	**presence node**\: True
                
                .. attribute:: eigrp
                
                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Eigrp>`
                
                .. attribute:: isis
                
                	ISO IS\-IS
                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Isis>`
                
                	**presence node**\: True
                
                .. attribute:: iso_igrp
                
                	IGRP for OSI networks
                	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.IsoIgrp>`
                
                	**presence node**\: True
                
                .. attribute:: lisp
                
                	Locator ID Separation Protocol (LISP)
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Lisp>`
                
                .. attribute:: mobile
                
                	Mobile routes
                	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Mobile>`
                
                	**presence node**\: True
                
                .. attribute:: odr
                
                	On Demand stub Routes
                	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Odr>`
                
                	**presence node**\: True
                
                .. attribute:: ospf
                
                	Open Shortest Path First (OSPF)
                	**type**\: list of  		 :py:class:`Ospf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospf_>`
                
                .. attribute:: ospfv3
                
                	OSPFv3
                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospfv3>`
                
                .. attribute:: rip
                
                	Routing Information Protocol (RIP)
                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Rip>`
                
                .. attribute:: static
                
                	Static routes
                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Static>`
                
                	**presence node**\: True
                
                .. attribute:: maximum_prefix
                
                	Maximum number of prefixes redistributed to protocol
                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.MaximumPrefix>`
                
                .. attribute:: vrf
                
                	Specify a source VRF
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Redistribute, self).__init__()

                    self.yang_name = "redistribute"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospf.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Ospf.Redistribute.Bgp)), ("connected", ("connected", Native.Router.Ospf.Redistribute.Connected)), ("eigrp", ("eigrp", Native.Router.Ospf.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Ospf.Redistribute.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospf.Redistribute.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospf.Redistribute.Lisp)), ("mobile", ("mobile", Native.Router.Ospf.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Ospf.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Ospf.Redistribute.Ospf_)), ("ospfv3", ("ospfv3", Native.Router.Ospf.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Ospf.Redistribute.Rip)), ("static", ("static", Native.Router.Ospf.Redistribute.Static)), ("maximum-prefix", ("maximum_prefix", Native.Router.Ospf.Redistribute.MaximumPrefix)), ("vrf", ("vrf", Native.Router.Ospf.Redistribute.Vrf))])
                    self._leafs = OrderedDict()

                    self.connected = None
                    self._children_name_map["connected"] = "connected"

                    self.isis = None
                    self._children_name_map["isis"] = "isis"

                    self.iso_igrp = None
                    self._children_name_map["iso_igrp"] = "iso-igrp"

                    self.lisp = Native.Router.Ospf.Redistribute.Lisp()
                    self.lisp.parent = self
                    self._children_name_map["lisp"] = "lisp"

                    self.mobile = None
                    self._children_name_map["mobile"] = "mobile"

                    self.odr = None
                    self._children_name_map["odr"] = "odr"

                    self.static = None
                    self._children_name_map["static"] = "static"

                    self.maximum_prefix = Native.Router.Ospf.Redistribute.MaximumPrefix()
                    self.maximum_prefix.parent = self
                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                    self.vrf = Native.Router.Ospf.Redistribute.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.application = YList(self)
                    self.bgp = YList(self)
                    self.eigrp = YList(self)
                    self.ospf = YList(self)
                    self.ospfv3 = YList(self)
                    self.rip = YList(self)
                    self._segment_path = lambda: "redistribute"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Redistribute, [], name, value)


                class Application(Entity):
                    """
                    Application
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: redist_options
                    
                    	
                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Application.RedistOptions>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Application, self).__init__()

                        self.yang_name = "application"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Application.RedistOptions))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.redist_options = Native.Router.Ospf.Redistribute.Application.RedistOptions()
                        self.redist_options.parent = self
                        self._children_name_map["redist_options"] = "redist-options"
                        self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Application, ['name'], name, value)


                    class RedistOptions(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Application.RedistOptions.MetricType>`
                        
                        .. attribute:: tag
                        
                        	Set tag for routes redistributed into OSPF
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subnets
                        
                        	Consider subnets for redistribution into OSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: nssa_only
                        
                        	Limit redistributed routes to NSSA areas
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Application.RedistOptions, self).__init__()

                            self.yang_name = "redist-options"
                            self.yang_parent_name = "application"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Application.RedistOptions.MetricType')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.tag = None
                            self.subnets = None
                            self.route_map = None
                            self.nssa_only = None
                            self._segment_path = lambda: "redist-options"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: Y_1 = 0

                            .. data:: Y_2 = 1

                            """

                            Y_1 = Enum.YLeaf(0, "1")

                            Y_2 = Enum.YLeaf(1, "2")



                class Bgp(Entity):
                    """
                    Border Gateway Protocol (BGP)
                    
                    .. attribute:: as_number  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: str
                    
                    .. attribute:: redist_options
                    
                    	
                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Bgp.RedistOptions>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['as_number']
                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Bgp.RedistOptions))])
                        self._leafs = OrderedDict([
                            ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                        ])
                        self.as_number = None

                        self.redist_options = Native.Router.Ospf.Redistribute.Bgp.RedistOptions()
                        self.redist_options.parent = self
                        self._children_name_map["redist_options"] = "redist-options"
                        self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Bgp, ['as_number'], name, value)


                    class RedistOptions(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Bgp.RedistOptions.MetricType>`
                        
                        .. attribute:: tag
                        
                        	Set tag for routes redistributed into OSPF
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subnets
                        
                        	Consider subnets for redistribution into OSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: nssa_only
                        
                        	Limit redistributed routes to NSSA areas
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Bgp.RedistOptions, self).__init__()

                            self.yang_name = "redist-options"
                            self.yang_parent_name = "bgp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Bgp.RedistOptions.MetricType')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.tag = None
                            self.subnets = None
                            self.route_map = None
                            self.nssa_only = None
                            self._segment_path = lambda: "redist-options"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: Y_1 = 0

                            .. data:: Y_2 = 1

                            """

                            Y_1 = Enum.YLeaf(0, "1")

                            Y_2 = Enum.YLeaf(1, "2")



                class Connected(Entity):
                    """
                    Connected
                    
                    .. attribute:: redist_options
                    
                    	
                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Connected.RedistOptions>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Connected, self).__init__()

                        self.yang_name = "connected"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Connected.RedistOptions))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.redist_options = Native.Router.Ospf.Redistribute.Connected.RedistOptions()
                        self.redist_options.parent = self
                        self._children_name_map["redist_options"] = "redist-options"
                        self._segment_path = lambda: "connected"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Connected, [], name, value)


                    class RedistOptions(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Connected.RedistOptions.MetricType>`
                        
                        .. attribute:: tag
                        
                        	Set tag for routes redistributed into OSPF
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subnets
                        
                        	Consider subnets for redistribution into OSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: nssa_only
                        
                        	Limit redistributed routes to NSSA areas
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Connected.RedistOptions, self).__init__()

                            self.yang_name = "redist-options"
                            self.yang_parent_name = "connected"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Connected.RedistOptions.MetricType')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.tag = None
                            self.subnets = None
                            self.route_map = None
                            self.nssa_only = None
                            self._segment_path = lambda: "redist-options"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: Y_1 = 0

                            .. data:: Y_2 = 1

                            """

                            Y_1 = Enum.YLeaf(0, "1")

                            Y_2 = Enum.YLeaf(1, "2")



                class Eigrp(Entity):
                    """
                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                    
                    .. attribute:: as_number  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: str
                    
                    .. attribute:: redist_options
                    
                    	
                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Eigrp.RedistOptions>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Eigrp, self).__init__()

                        self.yang_name = "eigrp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['as_number']
                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Eigrp.RedistOptions))])
                        self._leafs = OrderedDict([
                            ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                        ])
                        self.as_number = None

                        self.redist_options = Native.Router.Ospf.Redistribute.Eigrp.RedistOptions()
                        self.redist_options.parent = self
                        self._children_name_map["redist_options"] = "redist-options"
                        self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Eigrp, ['as_number'], name, value)


                    class RedistOptions(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Eigrp.RedistOptions.MetricType>`
                        
                        .. attribute:: tag
                        
                        	Set tag for routes redistributed into OSPF
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subnets
                        
                        	Consider subnets for redistribution into OSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: nssa_only
                        
                        	Limit redistributed routes to NSSA areas
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Eigrp.RedistOptions, self).__init__()

                            self.yang_name = "redist-options"
                            self.yang_parent_name = "eigrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Eigrp.RedistOptions.MetricType')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.tag = None
                            self.subnets = None
                            self.route_map = None
                            self.nssa_only = None
                            self._segment_path = lambda: "redist-options"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: Y_1 = 0

                            .. data:: Y_2 = 1

                            """

                            Y_1 = Enum.YLeaf(0, "1")

                            Y_2 = Enum.YLeaf(1, "2")



                class Isis(Entity):
                    """
                    ISO IS\-IS
                    
                    .. attribute:: isis_level_routes
                    
                    	
                    	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Isis.IsisLevelRoutes>`
                    
                    .. attribute:: isis_area
                    
                    	
                    	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Isis.IsisArea>`
                    
                    .. attribute:: redist_options
                    
                    	
                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Isis.RedistOptions>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Isis, self).__init__()

                        self.yang_name = "isis"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospf.Redistribute.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Isis.RedistOptions))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Isis.IsisLevelRoutes')])),
                        ])
                        self.isis_level_routes = None

                        self.redist_options = Native.Router.Ospf.Redistribute.Isis.RedistOptions()
                        self.redist_options.parent = self
                        self._children_name_map["redist_options"] = "redist-options"

                        self.isis_area = YList(self)
                        self._segment_path = lambda: "isis"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Isis, ['isis_level_routes'], name, value)

                    class IsisLevelRoutes(Enum):
                        """
                        IsisLevelRoutes (Enum Class)

                        .. data:: level_1 = 0

                        .. data:: level_2 = 1

                        .. data:: level_1_2 = 2

                        """

                        level_1 = Enum.YLeaf(0, "level-1")

                        level_2 = Enum.YLeaf(1, "level-2")

                        level_1_2 = Enum.YLeaf(2, "level-1-2")



                    class IsisArea(Entity):
                        """
                        
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: isis_level_routes
                        
                        	
                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Isis.IsisArea.IsisLevelRoutes>`
                        
                        .. attribute:: redist_options
                        
                        	
                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Isis.IsisArea.RedistOptions>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Isis.IsisArea, self).__init__()

                            self.yang_name = "isis-area"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Isis.IsisArea.RedistOptions))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Isis.IsisArea.IsisLevelRoutes')])),
                            ])
                            self.name = None
                            self.isis_level_routes = None

                            self.redist_options = Native.Router.Ospf.Redistribute.Isis.IsisArea.RedistOptions()
                            self.redist_options.parent = self
                            self._children_name_map["redist_options"] = "redist-options"
                            self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                        class IsisLevelRoutes(Enum):
                            """
                            IsisLevelRoutes (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            .. data:: level_1_2 = 2

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")

                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                        class RedistOptions(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Isis.IsisArea.RedistOptions.MetricType>`
                            
                            .. attribute:: tag
                            
                            	Set tag for routes redistributed into OSPF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: subnets
                            
                            	Consider subnets for redistribution into OSPF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: nssa_only
                            
                            	Limit redistributed routes to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Isis.IsisArea.RedistOptions, self).__init__()

                                self.yang_name = "redist-options"
                                self.yang_parent_name = "isis-area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Isis.IsisArea.RedistOptions.MetricType')])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                ])
                                self.metric = None
                                self.metric_type = None
                                self.tag = None
                                self.subnets = None
                                self.route_map = None
                                self.nssa_only = None
                                self._segment_path = lambda: "redist-options"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: Y_1 = 0

                                .. data:: Y_2 = 1

                                """

                                Y_1 = Enum.YLeaf(0, "1")

                                Y_2 = Enum.YLeaf(1, "2")



                    class RedistOptions(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Isis.RedistOptions.MetricType>`
                        
                        .. attribute:: tag
                        
                        	Set tag for routes redistributed into OSPF
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subnets
                        
                        	Consider subnets for redistribution into OSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: nssa_only
                        
                        	Limit redistributed routes to NSSA areas
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Isis.RedistOptions, self).__init__()

                            self.yang_name = "redist-options"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Isis.RedistOptions.MetricType')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.tag = None
                            self.subnets = None
                            self.route_map = None
                            self.nssa_only = None
                            self._segment_path = lambda: "redist-options"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: Y_1 = 0

                            .. data:: Y_2 = 1

                            """

                            Y_1 = Enum.YLeaf(0, "1")

                            Y_2 = Enum.YLeaf(1, "2")



                class IsoIgrp(Entity):
                    """
                    IGRP for OSI networks
                    
                    .. attribute:: area_tag_route_map_container
                    
                    	
                    	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.IsoIgrp.AreaTagRouteMapContainer>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    .. attribute:: iso_igrp_container
                    
                    	
                    	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.IsoIgrp.IsoIgrpContainer>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.IsoIgrp, self).__init__()

                        self.yang_name = "iso-igrp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospf.Redistribute.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospf.Redistribute.IsoIgrp.IsoIgrpContainer))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None

                        self.area_tag_route_map_container = Native.Router.Ospf.Redistribute.IsoIgrp.AreaTagRouteMapContainer()
                        self.area_tag_route_map_container.parent = self
                        self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                        self.iso_igrp_container = Native.Router.Ospf.Redistribute.IsoIgrp.IsoIgrpContainer()
                        self.iso_igrp_container.parent = self
                        self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                        self._segment_path = lambda: "iso-igrp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.IsoIgrp, ['route_map'], name, value)


                    class AreaTagRouteMapContainer(Entity):
                        """
                        
                        
                        .. attribute:: area_tag
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                            self.yang_name = "area-tag-route-map-container"
                            self.yang_parent_name = "iso-igrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.area_tag = None
                            self.route_map = None
                            self._segment_path = lambda: "area-tag-route-map-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                    class IsoIgrpContainer(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.IsoIgrp.IsoIgrpContainer.MetricType>`
                        
                        .. attribute:: tag
                        
                        	Set tag for routes redistributed into OSPF
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subnets
                        
                        	Consider subnets for redistribution into OSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.IsoIgrp.IsoIgrpContainer, self).__init__()

                            self.yang_name = "iso-igrp-container"
                            self.yang_parent_name = "iso-igrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.tag = None
                            self.subnets = None
                            self._segment_path = lambda: "iso-igrp-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: Y_1 = 0

                            .. data:: Y_2 = 1

                            """

                            Y_1 = Enum.YLeaf(0, "1")

                            Y_2 = Enum.YLeaf(1, "2")



                class Lisp(Entity):
                    """
                    Locator ID Separation Protocol (LISP)
                    
                    .. attribute:: redist_options
                    
                    	
                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Lisp.RedistOptions>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Lisp.RedistOptions))])
                        self._leafs = OrderedDict()

                        self.redist_options = Native.Router.Ospf.Redistribute.Lisp.RedistOptions()
                        self.redist_options.parent = self
                        self._children_name_map["redist_options"] = "redist-options"
                        self._segment_path = lambda: "lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Lisp, [], name, value)


                    class RedistOptions(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Lisp.RedistOptions.MetricType>`
                        
                        .. attribute:: tag
                        
                        	Set tag for routes redistributed into OSPF
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subnets
                        
                        	Consider subnets for redistribution into OSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: nssa_only
                        
                        	Limit redistributed routes to NSSA areas
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Lisp.RedistOptions, self).__init__()

                            self.yang_name = "redist-options"
                            self.yang_parent_name = "lisp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Lisp.RedistOptions.MetricType')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.tag = None
                            self.subnets = None
                            self.route_map = None
                            self.nssa_only = None
                            self._segment_path = lambda: "redist-options"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: Y_1 = 0

                            .. data:: Y_2 = 1

                            """

                            Y_1 = Enum.YLeaf(0, "1")

                            Y_2 = Enum.YLeaf(1, "2")



                class Mobile(Entity):
                    """
                    Mobile routes
                    
                    .. attribute:: redist_options
                    
                    	
                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Mobile.RedistOptions>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Mobile, self).__init__()

                        self.yang_name = "mobile"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Mobile.RedistOptions))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.redist_options = Native.Router.Ospf.Redistribute.Mobile.RedistOptions()
                        self.redist_options.parent = self
                        self._children_name_map["redist_options"] = "redist-options"
                        self._segment_path = lambda: "mobile"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Mobile, [], name, value)


                    class RedistOptions(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Mobile.RedistOptions.MetricType>`
                        
                        .. attribute:: tag
                        
                        	Set tag for routes redistributed into OSPF
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subnets
                        
                        	Consider subnets for redistribution into OSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: nssa_only
                        
                        	Limit redistributed routes to NSSA areas
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Mobile.RedistOptions, self).__init__()

                            self.yang_name = "redist-options"
                            self.yang_parent_name = "mobile"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Mobile.RedistOptions.MetricType')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.tag = None
                            self.subnets = None
                            self.route_map = None
                            self.nssa_only = None
                            self._segment_path = lambda: "redist-options"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: Y_1 = 0

                            .. data:: Y_2 = 1

                            """

                            Y_1 = Enum.YLeaf(0, "1")

                            Y_2 = Enum.YLeaf(1, "2")



                class Odr(Entity):
                    """
                    On Demand stub Routes
                    
                    .. attribute:: redist_options
                    
                    	
                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Odr.RedistOptions>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Odr, self).__init__()

                        self.yang_name = "odr"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Odr.RedistOptions))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.redist_options = Native.Router.Ospf.Redistribute.Odr.RedistOptions()
                        self.redist_options.parent = self
                        self._children_name_map["redist_options"] = "redist-options"
                        self._segment_path = lambda: "odr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Odr, [], name, value)


                    class RedistOptions(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Odr.RedistOptions.MetricType>`
                        
                        .. attribute:: tag
                        
                        	Set tag for routes redistributed into OSPF
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subnets
                        
                        	Consider subnets for redistribution into OSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: nssa_only
                        
                        	Limit redistributed routes to NSSA areas
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Odr.RedistOptions, self).__init__()

                            self.yang_name = "redist-options"
                            self.yang_parent_name = "odr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Odr.RedistOptions.MetricType')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.tag = None
                            self.subnets = None
                            self.route_map = None
                            self.nssa_only = None
                            self._segment_path = lambda: "redist-options"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: Y_1 = 0

                            .. data:: Y_2 = 1

                            """

                            Y_1 = Enum.YLeaf(0, "1")

                            Y_2 = Enum.YLeaf(1, "2")



                class Ospf_(Entity):
                    """
                    Open Shortest Path First (OSPF)
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: match
                    
                    	Redistribution of OSPF routes
                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospf_.Match>`
                    
                    .. attribute:: metric
                    
                    	Metric for redistributed routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospf_.MetricType>`
                    
                    .. attribute:: nssa_only
                    
                    	Limit redistributed routes to NSSA areas
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: subnets
                    
                    	Consider subnets for redistribution into OSPF
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    .. attribute:: tag
                    
                    	Set tag for routes redistributed into OSPF
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding Instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Ospf_, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospf.Redistribute.Ospf_.Match))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Ospf_.MetricType')])),
                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.id = None
                        self.metric = None
                        self.metric_type = None
                        self.nssa_only = None
                        self.subnets = None
                        self.route_map = None
                        self.tag = None
                        self.vrf = None

                        self.match = Native.Router.Ospf.Redistribute.Ospf_.Match()
                        self.match.parent = self
                        self._children_name_map["match"] = "match"
                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Ospf_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: Y_1 = 0

                        .. data:: Y_2 = 1

                        """

                        Y_1 = Enum.YLeaf(0, "1")

                        Y_2 = Enum.YLeaf(1, "2")



                    class Match(Entity):
                        """
                        Redistribution of OSPF routes
                        
                        .. attribute:: internal
                        
                        	Redistribute OSPF internal routes
                        	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospf_.Match.Internal>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: external
                        
                        	Redistribute OSPF external routes
                        	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospf_.Match.External>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: nssa_external
                        
                        	Redistribute OSPF NSSA external routes
                        	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospf_.Match.NssaExternal>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Ospf_.Match, self).__init__()

                            self.yang_name = "match"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospf.Redistribute.Ospf_.Match.Internal)), ("external", ("external", Native.Router.Ospf.Redistribute.Ospf_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospf.Redistribute.Ospf_.Match.NssaExternal))])
                            self._leafs = OrderedDict()

                            self.internal = None
                            self._children_name_map["internal"] = "internal"

                            self.external = None
                            self._children_name_map["external"] = "external"

                            self.nssa_external = None
                            self._children_name_map["nssa_external"] = "nssa-external"
                            self._segment_path = lambda: "match"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Ospf_.Match, [], name, value)


                        class Internal(Entity):
                            """
                            Redistribute OSPF internal routes
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospf_.Match.Internal.MetricType>`
                            
                            .. attribute:: nssa_only
                            
                            	Limit redistributed routes to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: subnets
                            
                            	Consider subnets for redistribution into OSPF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: tag
                            
                            	Set tag for routes redistributed into OSPF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Ospf_.Match.Internal, self).__init__()

                                self.yang_name = "internal"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Ospf_.Match.Internal.MetricType')])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ])
                                self.metric = None
                                self.metric_type = None
                                self.nssa_only = None
                                self.subnets = None
                                self.route_map = None
                                self.tag = None
                                self._segment_path = lambda: "internal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Ospf_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: Y_1 = 0

                                .. data:: Y_2 = 1

                                """

                                Y_1 = Enum.YLeaf(0, "1")

                                Y_2 = Enum.YLeaf(1, "2")



                        class External(Entity):
                            """
                            Redistribute OSPF external routes
                            
                            .. attribute:: external_routes
                            
                            	
                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospf_.Match.External.MetricType>`
                            
                            .. attribute:: nssa_only
                            
                            	Limit redistributed routes to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: subnets
                            
                            	Consider subnets for redistribution into OSPF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: tag
                            
                            	Set tag for routes redistributed into OSPF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Ospf_.Match.External, self).__init__()

                                self.yang_name = "external"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Ospf_.Match.External.MetricType')])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ])
                                self.external_routes = None
                                self.metric = None
                                self.metric_type = None
                                self.nssa_only = None
                                self.subnets = None
                                self.route_map = None
                                self.tag = None
                                self._segment_path = lambda: "external"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Ospf_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: Y_1 = 0

                                .. data:: Y_2 = 1

                                """

                                Y_1 = Enum.YLeaf(0, "1")

                                Y_2 = Enum.YLeaf(1, "2")



                        class NssaExternal(Entity):
                            """
                            Redistribute OSPF NSSA external routes
                            
                            .. attribute:: nssa_external_routes
                            
                            	
                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospf_.Match.NssaExternal.MetricType>`
                            
                            .. attribute:: nssa_only
                            
                            	Limit redistributed routes to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: subnets
                            
                            	Consider subnets for redistribution into OSPF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: tag
                            
                            	Set tag for routes redistributed into OSPF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Ospf_.Match.NssaExternal, self).__init__()

                                self.yang_name = "nssa-external"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Ospf_.Match.NssaExternal.MetricType')])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ])
                                self.nssa_external_routes = None
                                self.metric = None
                                self.metric_type = None
                                self.nssa_only = None
                                self.subnets = None
                                self.route_map = None
                                self.tag = None
                                self._segment_path = lambda: "nssa-external"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Ospf_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: Y_1 = 0

                                .. data:: Y_2 = 1

                                """

                                Y_1 = Enum.YLeaf(0, "1")

                                Y_2 = Enum.YLeaf(1, "2")



                class Ospfv3(Entity):
                    """
                    OSPFv3
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: match
                    
                    	Redistribution of OSPF routes
                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospfv3.Match>`
                    
                    .. attribute:: metric
                    
                    	Metric for redistributed routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_type
                    
                    	OSPF/IS\-IS exterior metric type for redistributed routes
                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospfv3.MetricType>`
                    
                    .. attribute:: nssa_only
                    
                    	Limit redistributed routes to NSSA areas
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: subnets
                    
                    	Consider subnets for redistribution into OSPF
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    .. attribute:: tag
                    
                    	Set tag for routes redistributed into OSPF
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Ospfv3, self).__init__()

                        self.yang_name = "ospfv3"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospf.Redistribute.Ospfv3.Match))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Ospfv3.MetricType')])),
                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ])
                        self.id = None
                        self.metric = None
                        self.metric_type = None
                        self.nssa_only = None
                        self.subnets = None
                        self.route_map = None
                        self.tag = None

                        self.match = Native.Router.Ospf.Redistribute.Ospfv3.Match()
                        self.match.parent = self
                        self._children_name_map["match"] = "match"
                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Ospfv3, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                    class MetricType(Enum):
                        """
                        MetricType (Enum Class)

                        OSPF/IS\-IS exterior metric type for redistributed routes

                        .. data:: Y_1 = 0

                        .. data:: Y_2 = 1

                        """

                        Y_1 = Enum.YLeaf(0, "1")

                        Y_2 = Enum.YLeaf(1, "2")



                    class Match(Entity):
                        """
                        Redistribution of OSPF routes
                        
                        .. attribute:: internal
                        
                        	Redistribute OSPF internal routes
                        	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospfv3.Match.Internal>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: external
                        
                        	Redistribute OSPF external routes
                        	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospfv3.Match.External>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: nssa_external
                        
                        	Redistribute OSPF NSSA external routes
                        	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospfv3.Match.NssaExternal>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Ospfv3.Match, self).__init__()

                            self.yang_name = "match"
                            self.yang_parent_name = "ospfv3"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospf.Redistribute.Ospfv3.Match.Internal)), ("external", ("external", Native.Router.Ospf.Redistribute.Ospfv3.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospf.Redistribute.Ospfv3.Match.NssaExternal))])
                            self._leafs = OrderedDict()

                            self.internal = None
                            self._children_name_map["internal"] = "internal"

                            self.external = None
                            self._children_name_map["external"] = "external"

                            self.nssa_external = None
                            self._children_name_map["nssa_external"] = "nssa-external"
                            self._segment_path = lambda: "match"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Ospfv3.Match, [], name, value)


                        class Internal(Entity):
                            """
                            Redistribute OSPF internal routes
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospfv3.Match.Internal.MetricType>`
                            
                            .. attribute:: nssa_only
                            
                            	Limit redistributed routes to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: subnets
                            
                            	Consider subnets for redistribution into OSPF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: tag
                            
                            	Set tag for routes redistributed into OSPF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Ospfv3.Match.Internal, self).__init__()

                                self.yang_name = "internal"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Ospfv3.Match.Internal.MetricType')])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ])
                                self.metric = None
                                self.metric_type = None
                                self.nssa_only = None
                                self.subnets = None
                                self.route_map = None
                                self.tag = None
                                self._segment_path = lambda: "internal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Ospfv3.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: Y_1 = 0

                                .. data:: Y_2 = 1

                                """

                                Y_1 = Enum.YLeaf(0, "1")

                                Y_2 = Enum.YLeaf(1, "2")



                        class External(Entity):
                            """
                            Redistribute OSPF external routes
                            
                            .. attribute:: external_routes
                            
                            	
                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospfv3.Match.External.MetricType>`
                            
                            .. attribute:: nssa_only
                            
                            	Limit redistributed routes to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: subnets
                            
                            	Consider subnets for redistribution into OSPF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: tag
                            
                            	Set tag for routes redistributed into OSPF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Ospfv3.Match.External, self).__init__()

                                self.yang_name = "external"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Ospfv3.Match.External.MetricType')])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ])
                                self.external_routes = None
                                self.metric = None
                                self.metric_type = None
                                self.nssa_only = None
                                self.subnets = None
                                self.route_map = None
                                self.tag = None
                                self._segment_path = lambda: "external"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Ospfv3.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: Y_1 = 0

                                .. data:: Y_2 = 1

                                """

                                Y_1 = Enum.YLeaf(0, "1")

                                Y_2 = Enum.YLeaf(1, "2")



                        class NssaExternal(Entity):
                            """
                            Redistribute OSPF NSSA external routes
                            
                            .. attribute:: nssa_external_routes
                            
                            	
                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Ospfv3.Match.NssaExternal.MetricType>`
                            
                            .. attribute:: nssa_only
                            
                            	Limit redistributed routes to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: subnets
                            
                            	Consider subnets for redistribution into OSPF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: tag
                            
                            	Set tag for routes redistributed into OSPF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Ospfv3.Match.NssaExternal, self).__init__()

                                self.yang_name = "nssa-external"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Ospfv3.Match.NssaExternal.MetricType')])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ])
                                self.nssa_external_routes = None
                                self.metric = None
                                self.metric_type = None
                                self.nssa_only = None
                                self.subnets = None
                                self.route_map = None
                                self.tag = None
                                self._segment_path = lambda: "nssa-external"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Ospfv3.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: Y_1 = 0

                                .. data:: Y_2 = 1

                                """

                                Y_1 = Enum.YLeaf(0, "1")

                                Y_2 = Enum.YLeaf(1, "2")



                class Rip(Entity):
                    """
                    Routing Information Protocol (RIP)
                    
                    .. attribute:: id  (key)
                    
                    	User selected string identifying this rip process
                    	**type**\: str
                    
                    .. attribute:: redist_options
                    
                    	
                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Rip.RedistOptions>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Rip.RedistOptions))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                        ])
                        self.id = None

                        self.redist_options = Native.Router.Ospf.Redistribute.Rip.RedistOptions()
                        self.redist_options.parent = self
                        self._children_name_map["redist_options"] = "redist-options"
                        self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Rip, ['id'], name, value)


                    class RedistOptions(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Rip.RedistOptions.MetricType>`
                        
                        .. attribute:: tag
                        
                        	Set tag for routes redistributed into OSPF
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subnets
                        
                        	Consider subnets for redistribution into OSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: nssa_only
                        
                        	Limit redistributed routes to NSSA areas
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Rip.RedistOptions, self).__init__()

                            self.yang_name = "redist-options"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Rip.RedistOptions.MetricType')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.tag = None
                            self.subnets = None
                            self.route_map = None
                            self.nssa_only = None
                            self._segment_path = lambda: "redist-options"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: Y_1 = 0

                            .. data:: Y_2 = 1

                            """

                            Y_1 = Enum.YLeaf(0, "1")

                            Y_2 = Enum.YLeaf(1, "2")



                class Static(Entity):
                    """
                    Static routes
                    
                    .. attribute:: redist_options
                    
                    	
                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Static.RedistOptions>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Static, self).__init__()

                        self.yang_name = "static"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Static.RedistOptions))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.redist_options = Native.Router.Ospf.Redistribute.Static.RedistOptions()
                        self.redist_options.parent = self
                        self._children_name_map["redist_options"] = "redist-options"
                        self._segment_path = lambda: "static"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Static, [], name, value)


                    class RedistOptions(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_type
                        
                        	OSPF/IS\-IS exterior metric type for redistributed routes
                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Static.RedistOptions.MetricType>`
                        
                        .. attribute:: tag
                        
                        	Set tag for routes redistributed into OSPF
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subnets
                        
                        	Consider subnets for redistribution into OSPF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: nssa_only
                        
                        	Limit redistributed routes to NSSA areas
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Static.RedistOptions, self).__init__()

                            self.yang_name = "redist-options"
                            self.yang_parent_name = "static"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Static.RedistOptions.MetricType')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.tag = None
                            self.subnets = None
                            self.route_map = None
                            self.nssa_only = None
                            self._segment_path = lambda: "redist-options"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                        class MetricType(Enum):
                            """
                            MetricType (Enum Class)

                            OSPF/IS\-IS exterior metric type for redistributed routes

                            .. data:: Y_1 = 0

                            .. data:: Y_2 = 1

                            """

                            Y_1 = Enum.YLeaf(0, "1")

                            Y_2 = Enum.YLeaf(1, "2")



                class MaximumPrefix(Entity):
                    """
                    Maximum number of prefixes redistributed to protocol
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: threshold_warning_only_container
                    
                    	
                    	**type**\:  :py:class:`ThresholdWarningOnlyContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.MaximumPrefix, self).__init__()

                        self.yang_name = "maximum-prefix"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("threshold-warning-only-container", ("threshold_warning_only_container", Native.Router.Ospf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer))])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                        ])
                        self.number = None

                        self.threshold_warning_only_container = Native.Router.Ospf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer()
                        self.threshold_warning_only_container.parent = self
                        self._children_name_map["threshold_warning_only_container"] = "threshold-warning-only-container"
                        self._segment_path = lambda: "maximum-prefix"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.MaximumPrefix, ['number'], name, value)


                    class ThresholdWarningOnlyContainer(Entity):
                        """
                        
                        
                        .. attribute:: threshold
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: warning_only
                        
                        	Only give warning message when limit is exceeded
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer, self).__init__()

                            self.yang_name = "threshold-warning-only-container"
                            self.yang_parent_name = "maximum-prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                            ])
                            self.threshold = None
                            self.warning_only = None
                            self._segment_path = lambda: "threshold-warning-only-container"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer, ['threshold', 'warning_only'], name, value)


                class Vrf(Entity):
                    """
                    Specify a source VRF
                    
                    .. attribute:: non_global_vrf
                    
                    	
                    	**type**\: list of  		 :py:class:`NonGlobalVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf>`
                    
                    .. attribute:: global_
                    
                    	global VRF
                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Redistribute.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("non-global-vrf", ("non_global_vrf", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf)), ("global", ("global_", Native.Router.Ospf.Redistribute.Vrf.Global))])
                        self._leafs = OrderedDict()

                        self.global_ = Native.Router.Ospf.Redistribute.Vrf.Global()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"

                        self.non_global_vrf = YList(self)
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf, [], name, value)


                    class NonGlobalVrf(Entity):
                        """
                        
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: application
                        
                        	Application
                        	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Application>`
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Connected>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: iso_igrp
                        
                        	IGRP for OSI networks
                        	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: lisp
                        
                        	Locator ID Separation Protocol (LISP)
                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp>`
                        
                        .. attribute:: mobile
                        
                        	Mobile routes
                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Mobile>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: odr
                        
                        	On Demand stub Routes
                        	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Odr>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ospf
                        
                        	Open Shortest Path First (OSPF)
                        	**type**\: list of  		 :py:class:`Ospf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_>`
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Rip>`
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Static>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf, self).__init__()

                            self.yang_name = "non-global-vrf"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Application)), ("bgp", ("bgp", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Bgp)), ("connected", ("connected", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Connected)), ("eigrp", ("eigrp", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Eigrp)), ("isis", ("isis", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp)), ("mobile", ("mobile", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Mobile)), ("odr", ("odr", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Odr)), ("ospf", ("ospf", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_)), ("ospfv3", ("ospfv3", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3)), ("rip", ("rip", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Rip)), ("static", ("static", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Static))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.connected = None
                            self._children_name_map["connected"] = "connected"

                            self.isis = None
                            self._children_name_map["isis"] = "isis"

                            self.iso_igrp = None
                            self._children_name_map["iso_igrp"] = "iso-igrp"

                            self.lisp = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp()
                            self.lisp.parent = self
                            self._children_name_map["lisp"] = "lisp"

                            self.mobile = None
                            self._children_name_map["mobile"] = "mobile"

                            self.odr = None
                            self._children_name_map["odr"] = "odr"

                            self.static = None
                            self._children_name_map["static"] = "static"

                            self.application = YList(self)
                            self.bgp = YList(self)
                            self.eigrp = YList(self)
                            self.ospf = YList(self)
                            self.ospfv3 = YList(self)
                            self.rip = YList(self)
                            self._segment_path = lambda: "non-global-vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf, ['name'], name, value)


                        class Application(Entity):
                            """
                            Application
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Application, self).__init__()

                                self.yang_name = "application"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Application, ['name'], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "application"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: as_number  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['as_number']
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions))])
                                self._leafs = OrderedDict([
                                    ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                ])
                                self.as_number = None

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Bgp, ['as_number'], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "connected"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Connected, [], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "connected"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: as_number  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['as_number']
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions))])
                                self._leafs = OrderedDict([
                                    ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                ])
                                self.as_number = None

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Eigrp, ['as_number'], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: isis_level_routes
                            
                            	
                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisLevelRoutes>`
                            
                            .. attribute:: isis_area
                            
                            	
                            	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea>`
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisLevelRoutes')])),
                                ])
                                self.isis_level_routes = None

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"

                                self.isis_area = YList(self)
                                self._segment_path = lambda: "isis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis, ['isis_level_routes'], name, value)

                            class IsisLevelRoutes(Enum):
                                """
                                IsisLevelRoutes (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                .. data:: level_1_2 = 2

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")

                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                            class IsisArea(Entity):
                                """
                                
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: isis_level_routes
                                
                                	
                                	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.IsisLevelRoutes>`
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea, self).__init__()

                                    self.yang_name = "isis-area"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.IsisLevelRoutes')])),
                                    ])
                                    self.name = None
                                    self.isis_level_routes = None

                                    self.redist_options = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                class IsisLevelRoutes(Enum):
                                    """
                                    IsisLevelRoutes (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    .. data:: level_1_2 = 2

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")

                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "isis-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class IsoIgrp(Entity):
                            """
                            IGRP for OSI networks
                            
                            .. attribute:: area_tag_route_map_container
                            
                            	
                            	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: iso_igrp_container
                            
                            	
                            	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp, self).__init__()

                                self.yang_name = "iso-igrp"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.area_tag_route_map_container = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer()
                                self.area_tag_route_map_container.parent = self
                                self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                self.iso_igrp_container = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer()
                                self.iso_igrp_container.parent = self
                                self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                self._segment_path = lambda: "iso-igrp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp, ['route_map'], name, value)


                            class AreaTagRouteMapContainer(Entity):
                                """
                                
                                
                                .. attribute:: area_tag
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                    self.yang_name = "area-tag-route-map-container"
                                    self.yang_parent_name = "iso-igrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.area_tag = None
                                    self.route_map = None
                                    self._segment_path = lambda: "area-tag-route-map-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                            class IsoIgrpContainer(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer, self).__init__()

                                    self.yang_name = "iso-igrp-container"
                                    self.yang_parent_name = "iso-igrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self._segment_path = lambda: "iso-igrp-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Lisp(Entity):
                            """
                            Locator ID Separation Protocol (LISP)
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp, self).__init__()

                                self.yang_name = "lisp"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions))])
                                self._leafs = OrderedDict()

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "lisp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp, [], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "lisp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Mobile(Entity):
                            """
                            Mobile routes
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Mobile, self).__init__()

                                self.yang_name = "mobile"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "mobile"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Mobile, [], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "mobile"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Odr(Entity):
                            """
                            On Demand stub Routes
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Odr, self).__init__()

                                self.yang_name = "odr"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "odr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Odr, [], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "odr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Ospf_(Entity):
                            """
                            Open Shortest Path First (OSPF)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: match
                            
                            	Redistribution of OSPF routes
                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match>`
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.MetricType>`
                            
                            .. attribute:: nssa_only
                            
                            	Limit redistributed routes to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: subnets
                            
                            	Consider subnets for redistribution into OSPF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: tag
                            
                            	Set tag for routes redistributed into OSPF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf
                            
                            	VPN Routing/Forwarding Instance
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_, self).__init__()

                                self.yang_name = "ospf"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.MetricType')])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.id = None
                                self.metric = None
                                self.metric_type = None
                                self.nssa_only = None
                                self.subnets = None
                                self.route_map = None
                                self.tag = None
                                self.vrf = None

                                self.match = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match()
                                self.match.parent = self
                                self._children_name_map["match"] = "match"
                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: Y_1 = 0

                                .. data:: Y_2 = 1

                                """

                                Y_1 = Enum.YLeaf(0, "1")

                                Y_2 = Enum.YLeaf(1, "2")



                            class Match(Entity):
                                """
                                Redistribution of OSPF routes
                                
                                .. attribute:: internal
                                
                                	Redistribute OSPF internal routes
                                	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.Internal>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: external
                                
                                	Redistribute OSPF external routes
                                	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.External>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: nssa_external
                                
                                	Redistribute OSPF NSSA external routes
                                	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.NssaExternal>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match, self).__init__()

                                    self.yang_name = "match"
                                    self.yang_parent_name = "ospf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.Internal)), ("external", ("external", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.NssaExternal))])
                                    self._leafs = OrderedDict()

                                    self.internal = None
                                    self._children_name_map["internal"] = "internal"

                                    self.external = None
                                    self._children_name_map["external"] = "external"

                                    self.nssa_external = None
                                    self._children_name_map["nssa_external"] = "nssa-external"
                                    self._segment_path = lambda: "match"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match, [], name, value)


                                class Internal(Entity):
                                    """
                                    Redistribute OSPF internal routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.Internal.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.Internal, self).__init__()

                                        self.yang_name = "internal"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.Internal.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "internal"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class External(Entity):
                                    """
                                    Redistribute OSPF external routes
                                    
                                    .. attribute:: external_routes
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.External.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.External, self).__init__()

                                        self.yang_name = "external"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.External.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.external_routes = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "external"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class NssaExternal(Entity):
                                    """
                                    Redistribute OSPF NSSA external routes
                                    
                                    .. attribute:: nssa_external_routes
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.NssaExternal.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.NssaExternal, self).__init__()

                                        self.yang_name = "nssa-external"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.NssaExternal.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.nssa_external_routes = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "nssa-external"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospf_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: match
                            
                            	Redistribution of OSPF routes
                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match>`
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.MetricType>`
                            
                            .. attribute:: nssa_only
                            
                            	Limit redistributed routes to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: subnets
                            
                            	Consider subnets for redistribution into OSPF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: tag
                            
                            	Set tag for routes redistributed into OSPF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.MetricType')])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ])
                                self.id = None
                                self.metric = None
                                self.metric_type = None
                                self.nssa_only = None
                                self.subnets = None
                                self.route_map = None
                                self.tag = None

                                self.match = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match()
                                self.match.parent = self
                                self._children_name_map["match"] = "match"
                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: Y_1 = 0

                                .. data:: Y_2 = 1

                                """

                                Y_1 = Enum.YLeaf(0, "1")

                                Y_2 = Enum.YLeaf(1, "2")



                            class Match(Entity):
                                """
                                Redistribution of OSPF routes
                                
                                .. attribute:: internal
                                
                                	Redistribute OSPF internal routes
                                	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.Internal>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: external
                                
                                	Redistribute OSPF external routes
                                	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.External>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: nssa_external
                                
                                	Redistribute OSPF NSSA external routes
                                	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.NssaExternal>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match, self).__init__()

                                    self.yang_name = "match"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.Internal)), ("external", ("external", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.NssaExternal))])
                                    self._leafs = OrderedDict()

                                    self.internal = None
                                    self._children_name_map["internal"] = "internal"

                                    self.external = None
                                    self._children_name_map["external"] = "external"

                                    self.nssa_external = None
                                    self._children_name_map["nssa_external"] = "nssa-external"
                                    self._segment_path = lambda: "match"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match, [], name, value)


                                class Internal(Entity):
                                    """
                                    Redistribute OSPF internal routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.Internal.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.Internal, self).__init__()

                                        self.yang_name = "internal"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.Internal.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "internal"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class External(Entity):
                                    """
                                    Redistribute OSPF external routes
                                    
                                    .. attribute:: external_routes
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.External.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.External, self).__init__()

                                        self.yang_name = "external"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.External.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.external_routes = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "external"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class NssaExternal(Entity):
                                    """
                                    Redistribute OSPF NSSA external routes
                                    
                                    .. attribute:: nssa_external_routes
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.NssaExternal.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.NssaExternal, self).__init__()

                                        self.yang_name = "nssa-external"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.NssaExternal.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.nssa_external_routes = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "nssa-external"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Ospfv3.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: id  (key)
                            
                            	User selected string identifying this rip process
                            	**type**\: str
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Rip, ['id'], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "rip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "non-global-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Static, [], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                    class Global(Entity):
                        """
                        global VRF
                        
                        .. attribute:: application
                        
                        	Application
                        	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Application>`
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Connected>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Isis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: iso_igrp
                        
                        	IGRP for OSI networks
                        	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: lisp
                        
                        	Locator ID Separation Protocol (LISP)
                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Lisp>`
                        
                        .. attribute:: mobile
                        
                        	Mobile routes
                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Mobile>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: odr
                        
                        	On Demand stub Routes
                        	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Odr>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ospf
                        
                        	Open Shortest Path First (OSPF)
                        	**type**\: list of  		 :py:class:`Ospf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_>`
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Rip>`
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Static>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Redistribute.Vrf.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospf.Redistribute.Vrf.Global.Application)), ("bgp", ("bgp", Native.Router.Ospf.Redistribute.Vrf.Global.Bgp)), ("connected", ("connected", Native.Router.Ospf.Redistribute.Vrf.Global.Connected)), ("eigrp", ("eigrp", Native.Router.Ospf.Redistribute.Vrf.Global.Eigrp)), ("isis", ("isis", Native.Router.Ospf.Redistribute.Vrf.Global.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospf.Redistribute.Vrf.Global.Lisp)), ("mobile", ("mobile", Native.Router.Ospf.Redistribute.Vrf.Global.Mobile)), ("odr", ("odr", Native.Router.Ospf.Redistribute.Vrf.Global.Odr)), ("ospf", ("ospf", Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_)), ("ospfv3", ("ospfv3", Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3)), ("rip", ("rip", Native.Router.Ospf.Redistribute.Vrf.Global.Rip)), ("static", ("static", Native.Router.Ospf.Redistribute.Vrf.Global.Static))])
                            self._leafs = OrderedDict()

                            self.connected = None
                            self._children_name_map["connected"] = "connected"

                            self.isis = None
                            self._children_name_map["isis"] = "isis"

                            self.iso_igrp = None
                            self._children_name_map["iso_igrp"] = "iso-igrp"

                            self.lisp = Native.Router.Ospf.Redistribute.Vrf.Global.Lisp()
                            self.lisp.parent = self
                            self._children_name_map["lisp"] = "lisp"

                            self.mobile = None
                            self._children_name_map["mobile"] = "mobile"

                            self.odr = None
                            self._children_name_map["odr"] = "odr"

                            self.static = None
                            self._children_name_map["static"] = "static"

                            self.application = YList(self)
                            self.bgp = YList(self)
                            self.eigrp = YList(self)
                            self.ospf = YList(self)
                            self.ospfv3 = YList(self)
                            self.rip = YList(self)
                            self._segment_path = lambda: "global"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global, [], name, value)


                        class Application(Entity):
                            """
                            Application
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Application.RedistOptions>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Application, self).__init__()

                                self.yang_name = "application"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.Global.Application.RedistOptions))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.Global.Application.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Application, ['name'], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Application.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Application.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "application"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Application.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: as_number  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Bgp.RedistOptions>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['as_number']
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.Global.Bgp.RedistOptions))])
                                self._leafs = OrderedDict([
                                    ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                ])
                                self.as_number = None

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.Global.Bgp.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Bgp, ['as_number'], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Bgp.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Bgp.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Bgp.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Connected.RedistOptions>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.Global.Connected.RedistOptions))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.Global.Connected.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "connected"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Connected, [], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Connected.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Connected.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "connected"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Connected.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: as_number  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Eigrp.RedistOptions>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['as_number']
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.Global.Eigrp.RedistOptions))])
                                self._leafs = OrderedDict([
                                    ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                ])
                                self.as_number = None

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.Global.Eigrp.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Eigrp, ['as_number'], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Eigrp.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Eigrp.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Eigrp.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: isis_level_routes
                            
                            	
                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisLevelRoutes>`
                            
                            .. attribute:: isis_area
                            
                            	
                            	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea>`
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Isis.RedistOptions>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.Global.Isis.RedistOptions))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Isis.IsisLevelRoutes')])),
                                ])
                                self.isis_level_routes = None

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.Global.Isis.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"

                                self.isis_area = YList(self)
                                self._segment_path = lambda: "isis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Isis, ['isis_level_routes'], name, value)

                            class IsisLevelRoutes(Enum):
                                """
                                IsisLevelRoutes (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                .. data:: level_1_2 = 2

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")

                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                            class IsisArea(Entity):
                                """
                                
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: isis_level_routes
                                
                                	
                                	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea.IsisLevelRoutes>`
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea, self).__init__()

                                    self.yang_name = "isis-area"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea.IsisLevelRoutes')])),
                                    ])
                                    self.name = None
                                    self.isis_level_routes = None

                                    self.redist_options = Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                class IsisLevelRoutes(Enum):
                                    """
                                    IsisLevelRoutes (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    .. data:: level_1_2 = 2

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")

                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "isis-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Isis.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Isis.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Isis.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class IsoIgrp(Entity):
                            """
                            IGRP for OSI networks
                            
                            .. attribute:: area_tag_route_map_container
                            
                            	
                            	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: iso_igrp_container
                            
                            	
                            	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp, self).__init__()

                                self.yang_name = "iso-igrp"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.area_tag_route_map_container = Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer()
                                self.area_tag_route_map_container.parent = self
                                self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                self.iso_igrp_container = Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer()
                                self.iso_igrp_container.parent = self
                                self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                self._segment_path = lambda: "iso-igrp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp, ['route_map'], name, value)


                            class AreaTagRouteMapContainer(Entity):
                                """
                                
                                
                                .. attribute:: area_tag
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                    self.yang_name = "area-tag-route-map-container"
                                    self.yang_parent_name = "iso-igrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.area_tag = None
                                    self.route_map = None
                                    self._segment_path = lambda: "area-tag-route-map-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                            class IsoIgrpContainer(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer, self).__init__()

                                    self.yang_name = "iso-igrp-container"
                                    self.yang_parent_name = "iso-igrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self._segment_path = lambda: "iso-igrp-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Lisp(Entity):
                            """
                            Locator ID Separation Protocol (LISP)
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Lisp.RedistOptions>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Lisp, self).__init__()

                                self.yang_name = "lisp"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.Global.Lisp.RedistOptions))])
                                self._leafs = OrderedDict()

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.Global.Lisp.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "lisp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Lisp, [], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Lisp.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Lisp.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "lisp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Lisp.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Mobile(Entity):
                            """
                            Mobile routes
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Mobile.RedistOptions>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Mobile, self).__init__()

                                self.yang_name = "mobile"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.Global.Mobile.RedistOptions))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.Global.Mobile.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "mobile"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Mobile, [], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Mobile.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Mobile.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "mobile"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Mobile.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Odr(Entity):
                            """
                            On Demand stub Routes
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Odr.RedistOptions>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Odr, self).__init__()

                                self.yang_name = "odr"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.Global.Odr.RedistOptions))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.Global.Odr.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "odr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Odr, [], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Odr.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Odr.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "odr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Odr.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Ospf_(Entity):
                            """
                            Open Shortest Path First (OSPF)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: match
                            
                            	Redistribution of OSPF routes
                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match>`
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.MetricType>`
                            
                            .. attribute:: nssa_only
                            
                            	Limit redistributed routes to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: subnets
                            
                            	Consider subnets for redistribution into OSPF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: tag
                            
                            	Set tag for routes redistributed into OSPF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf
                            
                            	VPN Routing/Forwarding Instance
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_, self).__init__()

                                self.yang_name = "ospf"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Ospf_.MetricType')])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.id = None
                                self.metric = None
                                self.metric_type = None
                                self.nssa_only = None
                                self.subnets = None
                                self.route_map = None
                                self.tag = None
                                self.vrf = None

                                self.match = Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match()
                                self.match.parent = self
                                self._children_name_map["match"] = "match"
                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: Y_1 = 0

                                .. data:: Y_2 = 1

                                """

                                Y_1 = Enum.YLeaf(0, "1")

                                Y_2 = Enum.YLeaf(1, "2")



                            class Match(Entity):
                                """
                                Redistribution of OSPF routes
                                
                                .. attribute:: internal
                                
                                	Redistribute OSPF internal routes
                                	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.Internal>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: external
                                
                                	Redistribute OSPF external routes
                                	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.External>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: nssa_external
                                
                                	Redistribute OSPF NSSA external routes
                                	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.NssaExternal>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match, self).__init__()

                                    self.yang_name = "match"
                                    self.yang_parent_name = "ospf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.Internal)), ("external", ("external", Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.NssaExternal))])
                                    self._leafs = OrderedDict()

                                    self.internal = None
                                    self._children_name_map["internal"] = "internal"

                                    self.external = None
                                    self._children_name_map["external"] = "external"

                                    self.nssa_external = None
                                    self._children_name_map["nssa_external"] = "nssa-external"
                                    self._segment_path = lambda: "match"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match, [], name, value)


                                class Internal(Entity):
                                    """
                                    Redistribute OSPF internal routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.Internal.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.Internal, self).__init__()

                                        self.yang_name = "internal"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.Internal.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "internal"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class External(Entity):
                                    """
                                    Redistribute OSPF external routes
                                    
                                    .. attribute:: external_routes
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.External.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.External, self).__init__()

                                        self.yang_name = "external"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.External.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.external_routes = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "external"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class NssaExternal(Entity):
                                    """
                                    Redistribute OSPF NSSA external routes
                                    
                                    .. attribute:: nssa_external_routes
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.NssaExternal.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.NssaExternal, self).__init__()

                                        self.yang_name = "nssa-external"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.NssaExternal.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.nssa_external_routes = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "nssa-external"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Ospf_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: match
                            
                            	Redistribution of OSPF routes
                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match>`
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_type
                            
                            	OSPF/IS\-IS exterior metric type for redistributed routes
                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.MetricType>`
                            
                            .. attribute:: nssa_only
                            
                            	Limit redistributed routes to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: subnets
                            
                            	Consider subnets for redistribution into OSPF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: tag
                            
                            	Set tag for routes redistributed into OSPF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Ospfv3.MetricType')])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ])
                                self.id = None
                                self.metric = None
                                self.metric_type = None
                                self.nssa_only = None
                                self.subnets = None
                                self.route_map = None
                                self.tag = None

                                self.match = Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match()
                                self.match.parent = self
                                self._children_name_map["match"] = "match"
                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                            class MetricType(Enum):
                                """
                                MetricType (Enum Class)

                                OSPF/IS\-IS exterior metric type for redistributed routes

                                .. data:: Y_1 = 0

                                .. data:: Y_2 = 1

                                """

                                Y_1 = Enum.YLeaf(0, "1")

                                Y_2 = Enum.YLeaf(1, "2")



                            class Match(Entity):
                                """
                                Redistribution of OSPF routes
                                
                                .. attribute:: internal
                                
                                	Redistribute OSPF internal routes
                                	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.Internal>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: external
                                
                                	Redistribute OSPF external routes
                                	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.External>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: nssa_external
                                
                                	Redistribute OSPF NSSA external routes
                                	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.NssaExternal>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match, self).__init__()

                                    self.yang_name = "match"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.Internal)), ("external", ("external", Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.NssaExternal))])
                                    self._leafs = OrderedDict()

                                    self.internal = None
                                    self._children_name_map["internal"] = "internal"

                                    self.external = None
                                    self._children_name_map["external"] = "external"

                                    self.nssa_external = None
                                    self._children_name_map["nssa_external"] = "nssa-external"
                                    self._segment_path = lambda: "match"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match, [], name, value)


                                class Internal(Entity):
                                    """
                                    Redistribute OSPF internal routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.Internal.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.Internal, self).__init__()

                                        self.yang_name = "internal"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.Internal.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "internal"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class External(Entity):
                                    """
                                    Redistribute OSPF external routes
                                    
                                    .. attribute:: external_routes
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.External.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.External, self).__init__()

                                        self.yang_name = "external"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.External.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.external_routes = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "external"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                                class NssaExternal(Entity):
                                    """
                                    Redistribute OSPF NSSA external routes
                                    
                                    .. attribute:: nssa_external_routes
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.NssaExternal.MetricType>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospf'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.NssaExternal, self).__init__()

                                        self.yang_name = "nssa-external"
                                        self.yang_parent_name = "match"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.NssaExternal.MetricType')])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ])
                                        self.nssa_external_routes = None
                                        self.metric = None
                                        self.metric_type = None
                                        self.nssa_only = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.tag = None
                                        self._segment_path = lambda: "nssa-external"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Ospfv3.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: id  (key)
                            
                            	User selected string identifying this rip process
                            	**type**\: str
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Rip.RedistOptions>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.Global.Rip.RedistOptions))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.Global.Rip.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Rip, ['id'], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Rip.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Rip.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "rip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Rip.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: redist_options
                            
                            	
                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Static.RedistOptions>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Redistribute.Vrf.Global.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospf.Redistribute.Vrf.Global.Static.RedistOptions))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.redist_options = Native.Router.Ospf.Redistribute.Vrf.Global.Static.RedistOptions()
                                self.redist_options.parent = self
                                self._children_name_map["redist_options"] = "redist-options"
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Static, [], name, value)


                            class RedistOptions(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Redistribute.Vrf.Global.Static.RedistOptions.MetricType>`
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Redistribute.Vrf.Global.Static.RedistOptions, self).__init__()

                                    self.yang_name = "redist-options"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.Redistribute.Vrf.Global.Static.RedistOptions.MetricType')])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.metric = None
                                    self.metric_type = None
                                    self.tag = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.nssa_only = None
                                    self._segment_path = lambda: "redist-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Redistribute.Vrf.Global.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



            class DistributeList(Entity):
                """
                Filter networks in routing updates
                
                .. attribute:: accesslist
                
                	
                	**type**\: list of  		 :py:class:`Accesslist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DistributeList.Accesslist>`
                
                .. attribute:: accesslist_ifname
                
                	
                	**type**\: list of  		 :py:class:`AccesslistIfname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DistributeList.AccesslistIfname>`
                
                .. attribute:: accesslist_prefix_gateway
                
                	
                	**type**\: list of  		 :py:class:`AccesslistPrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DistributeList.AccesslistPrefixGateway>`
                
                .. attribute:: accesslist_prefix_gateway_ifname
                
                	
                	**type**\: list of  		 :py:class:`AccesslistPrefixGatewayIfname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DistributeList.AccesslistPrefixGatewayIfname>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.DistributeList, self).__init__()

                    self.yang_name = "distribute-list"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("accesslist", ("accesslist", Native.Router.Ospf.DistributeList.Accesslist)), ("accesslist-ifname", ("accesslist_ifname", Native.Router.Ospf.DistributeList.AccesslistIfname)), ("accesslist-prefix-gateway", ("accesslist_prefix_gateway", Native.Router.Ospf.DistributeList.AccesslistPrefixGateway)), ("accesslist-prefix-gateway-ifname", ("accesslist_prefix_gateway_ifname", Native.Router.Ospf.DistributeList.AccesslistPrefixGatewayIfname))])
                    self._leafs = OrderedDict()

                    self.accesslist = YList(self)
                    self.accesslist_ifname = YList(self)
                    self.accesslist_prefix_gateway = YList(self)
                    self.accesslist_prefix_gateway_ifname = YList(self)
                    self._segment_path = lambda: "distribute-list"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.DistributeList, [], name, value)


                class Accesslist(Entity):
                    """
                    
                    
                    .. attribute:: in_out  (key)
                    
                    	
                    	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.DistributeList.Accesslist, self).__init__()

                        self.yang_name = "accesslist"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['in_out']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                        ])
                        self.in_out = None
                        self._segment_path = lambda: "accesslist" + "[in-out='" + str(self.in_out) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.DistributeList.Accesslist, ['in_out'], name, value)


                class AccesslistIfname(Entity):
                    """
                    
                    
                    .. attribute:: in_out  (key)
                    
                    	
                    	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                    
                    .. attribute:: interface  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: interface_routing_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: isis_tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding Instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.DistributeList.AccesslistIfname, self).__init__()

                        self.yang_name = "accesslist-ifname"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['in_out','interface']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ('interface_routing_id', (YLeaf(YType.uint8, 'interface-routing-id'), ['int'])),
                            ('isis_tag', (YLeaf(YType.str, 'isis-tag'), ['str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.in_out = None
                        self.interface = None
                        self.interface_routing_id = None
                        self.isis_tag = None
                        self.vrf = None
                        self._segment_path = lambda: "accesslist-ifname" + "[in-out='" + str(self.in_out) + "']" + "[interface='" + str(self.interface) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.DistributeList.AccesslistIfname, ['in_out', 'interface', 'interface_routing_id', 'isis_tag', 'vrf'], name, value)


                class AccesslistPrefixGateway(Entity):
                    """
                    
                    
                    .. attribute:: in_out  (key)
                    
                    	
                    	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                    
                    .. attribute:: prefix_gateway
                    
                    	
                    	**type**\:  :py:class:`PrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DistributeList.AccesslistPrefixGateway.PrefixGateway>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.DistributeList.AccesslistPrefixGateway, self).__init__()

                        self.yang_name = "accesslist-prefix-gateway"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['in_out']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                            ('prefix_gateway', (YLeaf(YType.enumeration, 'prefix-gateway'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.DistributeList.AccesslistPrefixGateway.PrefixGateway')])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.in_out = None
                        self.prefix_gateway = None
                        self.name = None
                        self._segment_path = lambda: "accesslist-prefix-gateway" + "[in-out='" + str(self.in_out) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.DistributeList.AccesslistPrefixGateway, ['in_out', 'prefix_gateway', 'name'], name, value)

                    class PrefixGateway(Enum):
                        """
                        PrefixGateway (Enum Class)

                        .. data:: prefix = 0

                        .. data:: gateway = 1

                        .. data:: route_map = 2

                        """

                        prefix = Enum.YLeaf(0, "prefix")

                        gateway = Enum.YLeaf(1, "gateway")

                        route_map = Enum.YLeaf(2, "route-map")



                class AccesslistPrefixGatewayIfname(Entity):
                    """
                    
                    
                    .. attribute:: in_out  (key)
                    
                    	
                    	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                    
                    .. attribute:: interface  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: prefix_gateway
                    
                    	
                    	**type**\:  :py:class:`PrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DistributeList.AccesslistPrefixGatewayIfname.PrefixGateway>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    	**mandatory**\: True
                    
                    .. attribute:: interface_routing_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: isis_tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding Instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.DistributeList.AccesslistPrefixGatewayIfname, self).__init__()

                        self.yang_name = "accesslist-prefix-gateway-ifname"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['in_out','interface']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ('prefix_gateway', (YLeaf(YType.enumeration, 'prefix-gateway'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.DistributeList.AccesslistPrefixGatewayIfname.PrefixGateway')])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('interface_routing_id', (YLeaf(YType.uint8, 'interface-routing-id'), ['int'])),
                            ('isis_tag', (YLeaf(YType.str, 'isis-tag'), ['str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.in_out = None
                        self.interface = None
                        self.prefix_gateway = None
                        self.name = None
                        self.interface_routing_id = None
                        self.isis_tag = None
                        self.vrf = None
                        self._segment_path = lambda: "accesslist-prefix-gateway-ifname" + "[in-out='" + str(self.in_out) + "']" + "[interface='" + str(self.interface) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.DistributeList.AccesslistPrefixGatewayIfname, ['in_out', 'interface', 'prefix_gateway', 'name', 'interface_routing_id', 'isis_tag', 'vrf'], name, value)

                    class PrefixGateway(Enum):
                        """
                        PrefixGateway (Enum Class)

                        .. data:: prefix = 0

                        .. data:: gateway = 1

                        .. data:: route_map = 2

                        """

                        prefix = Enum.YLeaf(0, "prefix")

                        gateway = Enum.YLeaf(1, "gateway")

                        route_map = Enum.YLeaf(2, "route-map")



            class DomainId(Entity):
                """
                OSPF domain\-id
                
                .. attribute:: ip_format
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ip_format_secondary
                
                	
                	**type**\:  :py:class:`IpFormatSecondary <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DomainId.IpFormatSecondary>`
                
                .. attribute:: null
                
                	Null Domain\-ID
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: type
                
                	OSPF domain ID type in Hex format
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DomainId.Type>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.DomainId, self).__init__()

                    self.yang_name = "domain-id"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip-format-secondary", ("ip_format_secondary", Native.Router.Ospf.DomainId.IpFormatSecondary)), ("type", ("type", Native.Router.Ospf.DomainId.Type))])
                    self._leafs = OrderedDict([
                        ('ip_format', (YLeaf(YType.str, 'ip-format'), ['str'])),
                        ('null', (YLeaf(YType.empty, 'Null'), ['Empty'])),
                    ])
                    self.ip_format = None
                    self.null = None

                    self.ip_format_secondary = Native.Router.Ospf.DomainId.IpFormatSecondary()
                    self.ip_format_secondary.parent = self
                    self._children_name_map["ip_format_secondary"] = "ip-format-secondary"

                    self.type = Native.Router.Ospf.DomainId.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "domain-id"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.DomainId, ['ip_format', 'null'], name, value)


                class IpFormatSecondary(Entity):
                    """
                    
                    
                    .. attribute:: ip
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: secondary
                    
                    	Secondary Domain\-ID
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.DomainId.IpFormatSecondary, self).__init__()

                        self.yang_name = "ip-format-secondary"
                        self.yang_parent_name = "domain-id"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                            ('secondary', (YLeaf(YType.empty, 'secondary'), ['Empty'])),
                        ])
                        self.ip = None
                        self.secondary = None
                        self._segment_path = lambda: "ip-format-secondary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.DomainId.IpFormatSecondary, ['ip', 'secondary'], name, value)


                class Type(Entity):
                    """
                    OSPF domain ID type in Hex format
                    
                    .. attribute:: type_leaf
                    
                    	
                    	**type**\:  :py:class:`TypeLeaf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.DomainId.Type.TypeLeaf>`
                    
                    .. attribute:: value
                    
                    	OSPF domain ID value in Hex format
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{12}
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.DomainId.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "domain-id"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('type_leaf', (YLeaf(YType.enumeration, 'type-leaf'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.DomainId.Type.TypeLeaf')])),
                            ('value', (YLeaf(YType.str, 'value'), ['str'])),
                        ])
                        self.type_leaf = None
                        self.value = None
                        self._segment_path = lambda: "type"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.DomainId.Type, ['type_leaf', 'value'], name, value)

                    class TypeLeaf(Enum):
                        """
                        TypeLeaf (Enum Class)

                        .. data:: Y_0005 = 0

                        .. data:: Y_0105 = 1

                        .. data:: Y_0205 = 2

                        .. data:: Y_8005 = 3

                        """

                        Y_0005 = Enum.YLeaf(0, "0005")

                        Y_0105 = Enum.YLeaf(1, "0105")

                        Y_0205 = Enum.YLeaf(2, "0205")

                        Y_8005 = Enum.YLeaf(3, "8005")



            class FastReroute(Entity):
                """
                LFA FastReroute parameters
                
                .. attribute:: keep_all_paths
                
                	Keep LFA FRR audit trail
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: per_prefix
                
                	Per\-prefix LFA FRR parameters
                	**type**\:  :py:class:`PerPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.FastReroute, self).__init__()

                    self.yang_name = "fast-reroute"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("per-prefix", ("per_prefix", Native.Router.Ospf.FastReroute.PerPrefix))])
                    self._leafs = OrderedDict([
                        ('keep_all_paths', (YLeaf(YType.empty, 'keep-all-paths'), ['Empty'])),
                    ])
                    self.keep_all_paths = None

                    self.per_prefix = Native.Router.Ospf.FastReroute.PerPrefix()
                    self.per_prefix.parent = self
                    self._children_name_map["per_prefix"] = "per-prefix"
                    self._segment_path = lambda: "fast-reroute"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.FastReroute, ['keep_all_paths'], name, value)


                class PerPrefix(Entity):
                    """
                    Per\-prefix LFA FRR parameters
                    
                    .. attribute:: enable
                    
                    	Enable LFA Fast Reroute
                    	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.Enable>`
                    
                    .. attribute:: remote_lfa
                    
                    	Remote LFA FastReroute parameters
                    	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa>`
                    
                    .. attribute:: tie_break
                    
                    	LFA FRR repair path selection policy tiebreaks
                    	**type**\:  :py:class:`TieBreak <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.TieBreak>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.FastReroute.PerPrefix, self).__init__()

                        self.yang_name = "per-prefix"
                        self.yang_parent_name = "fast-reroute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("enable", ("enable", Native.Router.Ospf.FastReroute.PerPrefix.Enable)), ("remote-lfa", ("remote_lfa", Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa)), ("tie-break", ("tie_break", Native.Router.Ospf.FastReroute.PerPrefix.TieBreak))])
                        self._leafs = OrderedDict()

                        self.enable = Native.Router.Ospf.FastReroute.PerPrefix.Enable()
                        self.enable.parent = self
                        self._children_name_map["enable"] = "enable"

                        self.remote_lfa = Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa()
                        self.remote_lfa.parent = self
                        self._children_name_map["remote_lfa"] = "remote-lfa"

                        self.tie_break = Native.Router.Ospf.FastReroute.PerPrefix.TieBreak()
                        self.tie_break.parent = self
                        self._children_name_map["tie_break"] = "tie-break"
                        self._segment_path = lambda: "per-prefix"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix, [], name, value)


                    class Enable(Entity):
                        """
                        Enable LFA Fast Reroute
                        
                        .. attribute:: area
                        
                        	Area to enable LFA FRR in
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_priority
                        
                        	Priority of prefixes to be protected
                        	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.Enable.PrefixPriority>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.FastReroute.PerPrefix.Enable, self).__init__()

                            self.yang_name = "enable"
                            self.yang_parent_name = "per-prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('prefix_priority', (YLeaf(YType.enumeration, 'prefix-priority'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.FastReroute.PerPrefix.Enable.PrefixPriority')])),
                            ])
                            self.area = None
                            self.prefix_priority = None
                            self._segment_path = lambda: "enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.Enable, ['area', 'prefix_priority'], name, value)

                        class PrefixPriority(Enum):
                            """
                            PrefixPriority (Enum Class)

                            Priority of prefixes to be protected

                            .. data:: high = 0

                            .. data:: low = 1

                            """

                            high = Enum.YLeaf(0, "high")

                            low = Enum.YLeaf(1, "low")



                    class RemoteLfa(Entity):
                        """
                        Remote LFA FastReroute parameters
                        
                        .. attribute:: area_cost
                        
                        	
                        	**type**\:  :py:class:`AreaCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaCost>`
                        
                        .. attribute:: area_tunnel
                        
                        	
                        	**type**\:  :py:class:`AreaTunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaTunnel>`
                        
                        .. attribute:: maximum_cost
                        
                        	Maximum distance to tunnel endpoint
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: tunnel
                        
                        	Remote LFA tunnel type
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.Tunnel>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                            self.yang_name = "remote-lfa"
                            self.yang_parent_name = "per-prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area-cost", ("area_cost", Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaCost)), ("area-tunnel", ("area_tunnel", Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaTunnel))])
                            self._leafs = OrderedDict([
                                ('maximum_cost', (YLeaf(YType.uint32, 'maximum-cost'), ['int'])),
                                ('tunnel', (YLeaf(YType.enumeration, 'tunnel'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.FastReroute.PerPrefix.RemoteLfa.Tunnel')])),
                            ])
                            self.maximum_cost = None
                            self.tunnel = None

                            self.area_cost = Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaCost()
                            self.area_cost.parent = self
                            self._children_name_map["area_cost"] = "area-cost"

                            self.area_tunnel = Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaTunnel()
                            self.area_tunnel.parent = self
                            self._children_name_map["area_tunnel"] = "area-tunnel"
                            self._segment_path = lambda: "remote-lfa"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)

                        class Tunnel(Enum):
                            """
                            Tunnel (Enum Class)

                            Remote LFA tunnel type

                            .. data:: mpls_ldp = 0

                            """

                            mpls_ldp = Enum.YLeaf(0, "mpls-ldp")



                        class AreaCost(Entity):
                            """
                            
                            
                            .. attribute:: area
                            
                            	Area for remote LFA command
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: maximum_cost
                            
                            	Maximum distance to tunnel endpoint
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaCost, self).__init__()

                                self.yang_name = "area-cost"
                                self.yang_parent_name = "remote-lfa"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                    ('maximum_cost', (YLeaf(YType.uint32, 'maximum-cost'), ['int'])),
                                ])
                                self.area = None
                                self.maximum_cost = None
                                self._segment_path = lambda: "area-cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaCost, ['area', 'maximum_cost'], name, value)


                        class AreaTunnel(Entity):
                            """
                            
                            
                            .. attribute:: area
                            
                            	Area for remote LFA command
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: tunnel
                            
                            	Remote LFA tunnel type
                            	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaTunnel.Tunnel>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaTunnel, self).__init__()

                                self.yang_name = "area-tunnel"
                                self.yang_parent_name = "remote-lfa"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                    ('tunnel', (YLeaf(YType.enumeration, 'tunnel'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaTunnel.Tunnel')])),
                                ])
                                self.area = None
                                self.tunnel = None
                                self._segment_path = lambda: "area-tunnel"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.RemoteLfa.AreaTunnel, ['area', 'tunnel'], name, value)

                            class Tunnel(Enum):
                                """
                                Tunnel (Enum Class)

                                Remote LFA tunnel type

                                .. data:: mpls_ldp = 0

                                """

                                mpls_ldp = Enum.YLeaf(0, "mpls-ldp")



                    class TieBreak(Entity):
                        """
                        LFA FRR repair path selection policy tiebreaks
                        
                        .. attribute:: broadcast_interface_disjoint
                        
                        	Interface protection attribute
                        	**type**\:  :py:class:`BroadcastInterfaceDisjoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.BroadcastInterfaceDisjoint>`
                        
                        .. attribute:: downstream
                        
                        	Downstream repair path attribute
                        	**type**\:  :py:class:`Downstream <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.Downstream>`
                        
                        .. attribute:: linecard_disjoint
                        
                        	Line card protection attribute
                        	**type**\:  :py:class:`LinecardDisjoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.LinecardDisjoint>`
                        
                        .. attribute:: lowest_metric
                        
                        	Lowest metric repair path attribute
                        	**type**\:  :py:class:`LowestMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.LowestMetric>`
                        
                        .. attribute:: node_protecting
                        
                        	Node protecting repair path attribute
                        	**type**\:  :py:class:`NodeProtecting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.NodeProtecting>`
                        
                        .. attribute:: primary_path
                        
                        	Equal cost multipath attribute
                        	**type**\:  :py:class:`PrimaryPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.PrimaryPath>`
                        
                        .. attribute:: secondary_path
                        
                        	Not\-equal cost multipath attribute
                        	**type**\:  :py:class:`SecondaryPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.SecondaryPath>`
                        
                        .. attribute:: srlg
                        
                        	Shared risk link group attribute
                        	**type**\:  :py:class:`Srlg <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.Srlg>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak, self).__init__()

                            self.yang_name = "tie-break"
                            self.yang_parent_name = "per-prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("broadcast-interface-disjoint", ("broadcast_interface_disjoint", Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.BroadcastInterfaceDisjoint)), ("downstream", ("downstream", Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.Downstream)), ("linecard-disjoint", ("linecard_disjoint", Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.LinecardDisjoint)), ("lowest-metric", ("lowest_metric", Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.LowestMetric)), ("node-protecting", ("node_protecting", Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.NodeProtecting)), ("primary-path", ("primary_path", Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.PrimaryPath)), ("secondary-path", ("secondary_path", Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.SecondaryPath)), ("srlg", ("srlg", Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.Srlg))])
                            self._leafs = OrderedDict()

                            self.broadcast_interface_disjoint = Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.BroadcastInterfaceDisjoint()
                            self.broadcast_interface_disjoint.parent = self
                            self._children_name_map["broadcast_interface_disjoint"] = "broadcast-interface-disjoint"

                            self.downstream = Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.Downstream()
                            self.downstream.parent = self
                            self._children_name_map["downstream"] = "downstream"

                            self.linecard_disjoint = Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.LinecardDisjoint()
                            self.linecard_disjoint.parent = self
                            self._children_name_map["linecard_disjoint"] = "linecard-disjoint"

                            self.lowest_metric = Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.LowestMetric()
                            self.lowest_metric.parent = self
                            self._children_name_map["lowest_metric"] = "lowest-metric"

                            self.node_protecting = Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.NodeProtecting()
                            self.node_protecting.parent = self
                            self._children_name_map["node_protecting"] = "node-protecting"

                            self.primary_path = Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.PrimaryPath()
                            self.primary_path.parent = self
                            self._children_name_map["primary_path"] = "primary-path"

                            self.secondary_path = Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.SecondaryPath()
                            self.secondary_path.parent = self
                            self._children_name_map["secondary_path"] = "secondary-path"

                            self.srlg = Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.Srlg()
                            self.srlg.parent = self
                            self._children_name_map["srlg"] = "srlg"
                            self._segment_path = lambda: "tie-break"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak, [], name, value)


                        class BroadcastInterfaceDisjoint(Entity):
                            """
                            Interface protection attribute
                            
                            .. attribute:: required
                            
                            	Mandatory repair path attribute
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: index
                            
                            	Tiebreak attribute priority
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.BroadcastInterfaceDisjoint, self).__init__()

                                self.yang_name = "broadcast-interface-disjoint"
                                self.yang_parent_name = "tie-break"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('required', (YLeaf(YType.empty, 'required'), ['Empty'])),
                                    ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                ])
                                self.required = None
                                self.index = None
                                self._segment_path = lambda: "broadcast-interface-disjoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.BroadcastInterfaceDisjoint, ['required', 'index'], name, value)


                        class Downstream(Entity):
                            """
                            Downstream repair path attribute
                            
                            .. attribute:: required
                            
                            	Mandatory repair path attribute
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: index
                            
                            	Tiebreak attribute priority
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.Downstream, self).__init__()

                                self.yang_name = "downstream"
                                self.yang_parent_name = "tie-break"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('required', (YLeaf(YType.empty, 'required'), ['Empty'])),
                                    ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                ])
                                self.required = None
                                self.index = None
                                self._segment_path = lambda: "downstream"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.Downstream, ['required', 'index'], name, value)


                        class LinecardDisjoint(Entity):
                            """
                            Line card protection attribute
                            
                            .. attribute:: required
                            
                            	Mandatory repair path attribute
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: index
                            
                            	Tiebreak attribute priority
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.LinecardDisjoint, self).__init__()

                                self.yang_name = "linecard-disjoint"
                                self.yang_parent_name = "tie-break"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('required', (YLeaf(YType.empty, 'required'), ['Empty'])),
                                    ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                ])
                                self.required = None
                                self.index = None
                                self._segment_path = lambda: "linecard-disjoint"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.LinecardDisjoint, ['required', 'index'], name, value)


                        class LowestMetric(Entity):
                            """
                            Lowest metric repair path attribute
                            
                            .. attribute:: required
                            
                            	Mandatory repair path attribute
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: index
                            
                            	Tiebreak attribute priority
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.LowestMetric, self).__init__()

                                self.yang_name = "lowest-metric"
                                self.yang_parent_name = "tie-break"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('required', (YLeaf(YType.empty, 'required'), ['Empty'])),
                                    ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                ])
                                self.required = None
                                self.index = None
                                self._segment_path = lambda: "lowest-metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.LowestMetric, ['required', 'index'], name, value)


                        class NodeProtecting(Entity):
                            """
                            Node protecting repair path attribute
                            
                            .. attribute:: required
                            
                            	Mandatory repair path attribute
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: index
                            
                            	Tiebreak attribute priority
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.NodeProtecting, self).__init__()

                                self.yang_name = "node-protecting"
                                self.yang_parent_name = "tie-break"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('required', (YLeaf(YType.empty, 'required'), ['Empty'])),
                                    ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                ])
                                self.required = None
                                self.index = None
                                self._segment_path = lambda: "node-protecting"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.NodeProtecting, ['required', 'index'], name, value)


                        class PrimaryPath(Entity):
                            """
                            Equal cost multipath attribute
                            
                            .. attribute:: required
                            
                            	Mandatory repair path attribute
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: index
                            
                            	Tiebreak attribute priority
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.PrimaryPath, self).__init__()

                                self.yang_name = "primary-path"
                                self.yang_parent_name = "tie-break"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('required', (YLeaf(YType.empty, 'required'), ['Empty'])),
                                    ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                ])
                                self.required = None
                                self.index = None
                                self._segment_path = lambda: "primary-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.PrimaryPath, ['required', 'index'], name, value)


                        class SecondaryPath(Entity):
                            """
                            Not\-equal cost multipath attribute
                            
                            .. attribute:: required
                            
                            	Mandatory repair path attribute
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: index
                            
                            	Tiebreak attribute priority
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.SecondaryPath, self).__init__()

                                self.yang_name = "secondary-path"
                                self.yang_parent_name = "tie-break"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('required', (YLeaf(YType.empty, 'required'), ['Empty'])),
                                    ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                ])
                                self.required = None
                                self.index = None
                                self._segment_path = lambda: "secondary-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.SecondaryPath, ['required', 'index'], name, value)


                        class Srlg(Entity):
                            """
                            Shared risk link group attribute
                            
                            .. attribute:: required
                            
                            	Mandatory repair path attribute
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: index
                            
                            	Tiebreak attribute priority
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.Srlg, self).__init__()

                                self.yang_name = "srlg"
                                self.yang_parent_name = "tie-break"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('required', (YLeaf(YType.empty, 'required'), ['Empty'])),
                                    ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                ])
                                self.required = None
                                self.index = None
                                self._segment_path = lambda: "srlg"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.FastReroute.PerPrefix.TieBreak.Srlg, ['required', 'index'], name, value)


            class GracefulRestart(Entity):
                """
                Graceful\-restart options
                
                .. attribute:: disable
                
                	Graceful restart disable
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: helper
                
                	helper support
                	**type**\:  :py:class:`Helper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.GracefulRestart.Helper>`
                
                	**presence node**\: True
                
                .. attribute:: restart_interval
                
                	Graceful restart interval
                	**type**\: int
                
                	**range:** 0..65535
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.GracefulRestart, self).__init__()

                    self.yang_name = "graceful-restart"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("helper", ("helper", Native.Router.Ospf.GracefulRestart.Helper))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ('restart_interval', (YLeaf(YType.uint16, 'restart-interval'), ['int'])),
                    ])
                    self.disable = None
                    self.restart_interval = None

                    self.helper = None
                    self._children_name_map["helper"] = "helper"
                    self._segment_path = lambda: "graceful-restart"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.GracefulRestart, ['disable', 'restart_interval'], name, value)


                class Helper(Entity):
                    """
                    helper support
                    
                    .. attribute:: disable
                    
                    	disable helper support
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: strict_lsa_checking
                    
                    	enable helper strict LSA checking
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.GracefulRestart.Helper, self).__init__()

                        self.yang_name = "helper"
                        self.yang_parent_name = "graceful-restart"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('strict_lsa_checking', (YLeaf(YType.empty, 'strict-lsa-checking'), ['Empty'])),
                        ])
                        self.disable = None
                        self.strict_lsa_checking = None
                        self._segment_path = lambda: "helper"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.GracefulRestart.Helper, ['disable', 'strict_lsa_checking'], name, value)


            class Ignore(Entity):
                """
                Do not complain about specific event
                
                .. attribute:: lsa
                
                	Do not complain upon receiving LSA of the specified type
                	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Ignore.Lsa>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Ignore, self).__init__()

                    self.yang_name = "ignore"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospf.Ignore.Lsa))])
                    self._leafs = OrderedDict()

                    self.lsa = Native.Router.Ospf.Ignore.Lsa()
                    self.lsa.parent = self
                    self._children_name_map["lsa"] = "lsa"
                    self._segment_path = lambda: "ignore"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Ignore, [], name, value)


                class Lsa(Entity):
                    """
                    Do not complain upon receiving LSA of the specified type
                    
                    .. attribute:: mospf
                    
                    	MOSPF Type 6 LSA
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Ignore.Lsa, self).__init__()

                        self.yang_name = "lsa"
                        self.yang_parent_name = "ignore"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mospf', (YLeaf(YType.empty, 'mospf'), ['Empty'])),
                        ])
                        self.mospf = None
                        self._segment_path = lambda: "lsa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Ignore.Lsa, ['mospf'], name, value)


            class Limit(Entity):
                """
                Limit a specific OSPF feature
                
                .. attribute:: retransmissions
                
                	LS update, DBD, and LS request retransmissions
                	**type**\:  :py:class:`Retransmissions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Limit.Retransmissions>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Limit, self).__init__()

                    self.yang_name = "limit"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("retransmissions", ("retransmissions", Native.Router.Ospf.Limit.Retransmissions))])
                    self._leafs = OrderedDict()

                    self.retransmissions = Native.Router.Ospf.Limit.Retransmissions()
                    self.retransmissions.parent = self
                    self._children_name_map["retransmissions"] = "retransmissions"
                    self._segment_path = lambda: "limit"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Limit, [], name, value)


                class Retransmissions(Entity):
                    """
                    LS update, DBD, and LS request retransmissions
                    
                    .. attribute:: non_dc
                    
                    	Non\-demand\-circuit retransmissions
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..255
                    
                    		**type**\:  :py:class:`LimitDcNonDcType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.LimitDcNonDcType>`
                    
                    .. attribute:: dc
                    
                    	Demand circuit retransmissions
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..255
                    
                    		**type**\:  :py:class:`LimitDcNonDcType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.LimitDcNonDcType>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Limit.Retransmissions, self).__init__()

                        self.yang_name = "retransmissions"
                        self.yang_parent_name = "limit"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('non_dc', (YLeaf(YType.str, 'non-dc'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'LimitDcNonDcType', '')])),
                            ('dc', (YLeaf(YType.str, 'dc'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'LimitDcNonDcType', '')])),
                        ])
                        self.non_dc = None
                        self.dc = None
                        self._segment_path = lambda: "retransmissions"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Limit.Retransmissions, ['non_dc', 'dc'], name, value)


            class LocalRibCriteria(Entity):
                """
                Enable or disable usage of local RIB as route criteria
                
                .. attribute:: forwarding_address
                
                	Local RIB used to validate external/NSSA forwarding addresses
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: inter_area_summary
                
                	Local RIB used as criteria for inter\-area summaries
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nssa_translation
                
                	Local RIB used as criteria for NSSA translation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.LocalRibCriteria, self).__init__()

                    self.yang_name = "local-rib-criteria"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('forwarding_address', (YLeaf(YType.empty, 'forwarding-address'), ['Empty'])),
                        ('inter_area_summary', (YLeaf(YType.empty, 'inter-area-summary'), ['Empty'])),
                        ('nssa_translation', (YLeaf(YType.empty, 'nssa-translation'), ['Empty'])),
                    ])
                    self.forwarding_address = None
                    self.inter_area_summary = None
                    self.nssa_translation = None
                    self._segment_path = lambda: "local-rib-criteria"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.LocalRibCriteria, ['forwarding_address', 'inter_area_summary', 'nssa_translation'], name, value)


            class Microloop(Entity):
                """
                Traffic microloop control parameters
                
                .. attribute:: avoidance
                
                	Traffic microloop avoidance parameters
                	**type**\:  :py:class:`Avoidance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Microloop.Avoidance>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Microloop, self).__init__()

                    self.yang_name = "microloop"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("avoidance", ("avoidance", Native.Router.Ospf.Microloop.Avoidance))])
                    self._leafs = OrderedDict()

                    self.avoidance = None
                    self._children_name_map["avoidance"] = "avoidance"
                    self._segment_path = lambda: "microloop"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Microloop, [], name, value)


                class Avoidance(Entity):
                    """
                    Traffic microloop avoidance parameters
                    
                    .. attribute:: disable
                    
                    	Microloop avoidance auto\-enable prohibited
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: protected
                    
                    	Microloop avoidance for protected prefixes only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: rib_update_delay
                    
                    	Delay before updating the RIB
                    	**type**\: int
                    
                    	**range:** 1..600000
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Microloop.Avoidance, self).__init__()

                        self.yang_name = "avoidance"
                        self.yang_parent_name = "microloop"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('protected', (YLeaf(YType.empty, 'protected'), ['Empty'])),
                            ('rib_update_delay', (YLeaf(YType.uint32, 'rib-update-delay'), ['int'])),
                        ])
                        self.disable = None
                        self.protected = None
                        self.rib_update_delay = None
                        self._segment_path = lambda: "avoidance"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Microloop.Avoidance, ['disable', 'protected', 'rib_update_delay'], name, value)


            class Mpls(Entity):
                """
                Configure MPLS routing protocol parameters
                
                .. attribute:: ldp
                
                	routing protocol commands for MPLS LDP
                	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.Ldp>`
                
                .. attribute:: traffic_eng
                
                	routing protocol commands for MPLS Traffic Engineering
                	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.TrafficEng>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ldp", ("ldp", Native.Router.Ospf.Mpls.Ldp)), ("traffic-eng", ("traffic_eng", Native.Router.Ospf.Mpls.TrafficEng))])
                    self._leafs = OrderedDict()

                    self.ldp = Native.Router.Ospf.Mpls.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "ldp"

                    self.traffic_eng = Native.Router.Ospf.Mpls.TrafficEng()
                    self.traffic_eng.parent = self
                    self._children_name_map["traffic_eng"] = "traffic-eng"
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Mpls, [], name, value)


                class Ldp(Entity):
                    """
                    routing protocol commands for MPLS LDP
                    
                    .. attribute:: autoconfig
                    
                    	Configure LDP automatic configuration
                    	**type**\:  :py:class:`Autoconfig <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.Ldp.Autoconfig>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: sync
                    
                    	Configure LDP\-IGP Synchronization
                    	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.Ldp.Sync>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Mpls.Ldp, self).__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("autoconfig", ("autoconfig", Native.Router.Ospf.Mpls.Ldp.Autoconfig)), ("sync", ("sync", Native.Router.Ospf.Mpls.Ldp.Sync))])
                        self._leafs = OrderedDict()

                        self.autoconfig = None
                        self._children_name_map["autoconfig"] = "autoconfig"

                        self.sync = None
                        self._children_name_map["sync"] = "sync"
                        self._segment_path = lambda: "ldp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Mpls.Ldp, [], name, value)


                    class Autoconfig(Entity):
                        """
                        Configure LDP automatic configuration
                        
                        .. attribute:: area
                        
                        	Configure an OSPF area to run MPLS LDP
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Mpls.Ldp.Autoconfig, self).__init__()

                            self.yang_name = "autoconfig"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                            ])
                            self.area = None
                            self._segment_path = lambda: "autoconfig"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Mpls.Ldp.Autoconfig, ['area'], name, value)


                    class Sync(Entity):
                        """
                        Configure LDP\-IGP Synchronization
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Mpls.Ldp.Sync, self).__init__()

                            self.yang_name = "sync"
                            self.yang_parent_name = "ldp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "sync"
                            self._is_frozen = True


                class TrafficEng(Entity):
                    """
                    routing protocol commands for MPLS Traffic Engineering
                    
                    .. attribute:: multicast_intact
                    
                    	MPLS TE and PIM interaction
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: area
                    
                    	configure an ospf area to run MPLS Traffic Engineering
                    	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.TrafficEng.Area>`
                    
                    .. attribute:: autoroute_exclude
                    
                    	MPLS TE autoroute exclude
                    	**type**\:  :py:class:`AutorouteExclude <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.TrafficEng.AutorouteExclude>`
                    
                    .. attribute:: interface
                    
                    	MPLS TE interface configuration for this OSPF process
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.TrafficEng.Interface>`
                    
                    .. attribute:: mesh_group
                    
                    	Traffic Engineering Mesh\-Group advertisement
                    	**type**\: list of  		 :py:class:`MeshGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.TrafficEng.MeshGroup>`
                    
                    .. attribute:: router_id
                    
                    	Traffic Engineering stable IP address for system
                    	**type**\:  :py:class:`RouterId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.TrafficEng.RouterId>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Mpls.TrafficEng, self).__init__()

                        self.yang_name = "traffic-eng"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("area", ("area", Native.Router.Ospf.Mpls.TrafficEng.Area)), ("autoroute-exclude", ("autoroute_exclude", Native.Router.Ospf.Mpls.TrafficEng.AutorouteExclude)), ("interface", ("interface", Native.Router.Ospf.Mpls.TrafficEng.Interface)), ("mesh-group", ("mesh_group", Native.Router.Ospf.Mpls.TrafficEng.MeshGroup)), ("router-id", ("router_id", Native.Router.Ospf.Mpls.TrafficEng.RouterId))])
                        self._leafs = OrderedDict([
                            ('multicast_intact', (YLeaf(YType.empty, 'multicast-intact'), ['Empty'])),
                        ])
                        self.multicast_intact = None

                        self.autoroute_exclude = Native.Router.Ospf.Mpls.TrafficEng.AutorouteExclude()
                        self.autoroute_exclude.parent = self
                        self._children_name_map["autoroute_exclude"] = "autoroute-exclude"

                        self.router_id = Native.Router.Ospf.Mpls.TrafficEng.RouterId()
                        self.router_id.parent = self
                        self._children_name_map["router_id"] = "router-id"

                        self.area = YList(self)
                        self.interface = YList(self)
                        self.mesh_group = YList(self)
                        self._segment_path = lambda: "traffic-eng"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Mpls.TrafficEng, ['multicast_intact'], name, value)


                    class Area(Entity):
                        """
                        configure an ospf area to run MPLS Traffic Engineering
                        
                        .. attribute:: id  (key)
                        
                        	OSPF area ID
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Mpls.TrafficEng.Area, self).__init__()

                            self.yang_name = "area"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                            ])
                            self.id = None
                            self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Mpls.TrafficEng.Area, ['id'], name, value)


                    class AutorouteExclude(Entity):
                        """
                        MPLS TE autoroute exclude
                        
                        .. attribute:: prefix_list
                        
                        	Filter prefixes
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Mpls.TrafficEng.AutorouteExclude, self).__init__()

                            self.yang_name = "autoroute-exclude"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                            ])
                            self.prefix_list = None
                            self._segment_path = lambda: "autoroute-exclude"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Mpls.TrafficEng.AutorouteExclude, ['prefix_list'], name, value)


                    class Interface(Entity):
                        """
                        MPLS TE interface configuration for this OSPF process
                        
                        .. attribute:: name_id  (key)
                        
                        	Interface name and ID
                        	**type**\: str
                        
                        .. attribute:: area
                        
                        	Advertise MPLS TE information for this interface into area
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Mpls.TrafficEng.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name_id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name_id', (YLeaf(YType.str, 'name-id'), ['str'])),
                                ('area', (YLeaf(YType.uint32, 'area'), ['int'])),
                            ])
                            self.name_id = None
                            self.area = None
                            self._segment_path = lambda: "interface" + "[name-id='" + str(self.name_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Mpls.TrafficEng.Interface, ['name_id', 'area'], name, value)


                    class MeshGroup(Entity):
                        """
                        Traffic Engineering Mesh\-Group advertisement
                        
                        .. attribute:: id  (key)
                        
                        	Mesh Group ID\: <0..4294967295>
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area  (key)
                        
                        	configure flooding scope as area
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..4294967295
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface
                        
                        	Interface name and ID
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Mpls.TrafficEng.MeshGroup, self).__init__()

                            self.yang_name = "mesh-group"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id','area']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ])
                            self.id = None
                            self.area = None
                            self.interface = None
                            self._segment_path = lambda: "mesh-group" + "[id='" + str(self.id) + "']" + "[area='" + str(self.area) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Mpls.TrafficEng.MeshGroup, ['id', 'area', 'interface'], name, value)


                    class RouterId(Entity):
                        """
                        Traffic Engineering stable IP address for system
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.TrafficEng.RouterId.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.TrafficEng.RouterId.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.TrafficEng.RouterId.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Mpls.TrafficEng.RouterId.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Mpls.TrafficEng.RouterId, self).__init__()

                            self.yang_name = "router-id"
                            self.yang_parent_name = "traffic-eng"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Ospf.Mpls.TrafficEng.RouterId.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Ospf.Mpls.TrafficEng.RouterId.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Ospf.Mpls.TrafficEng.RouterId.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Ospf.Mpls.TrafficEng.RouterId.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Router.Ospf.Mpls.TrafficEng.RouterId.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Router.Ospf.Mpls.TrafficEng.RouterId.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Router.Ospf.Mpls.TrafficEng.RouterId.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Router.Ospf.Mpls.TrafficEng.RouterId.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "router-id"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Mpls.TrafficEng.RouterId, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Mpls.TrafficEng.RouterId.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "router-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Mpls.TrafficEng.RouterId.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Mpls.TrafficEng.RouterId.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "router-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Mpls.TrafficEng.RouterId.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Mpls.TrafficEng.RouterId.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "router-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Mpls.TrafficEng.RouterId.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Mpls.TrafficEng.RouterId.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "router-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Mpls.TrafficEng.RouterId.PortChannelSubinterface, [u'port_channel'], name, value)


            class Neighbor(Entity):
                """
                Specify a neighbor router
                
                .. attribute:: ip  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: cost
                
                	OSPF cost for point\-to\-multipoint neighbor
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: database_filter
                
                	Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                	**type**\:  :py:class:`DatabaseFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Neighbor.DatabaseFilter>`
                
                .. attribute:: poll_interval
                
                	OSPF dead\-router polling interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: priority
                
                	OSPF priority of non\-broadcast neighbor
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Neighbor, self).__init__()

                    self.yang_name = "neighbor"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['ip']
                    self._child_classes = OrderedDict([("database-filter", ("database_filter", Native.Router.Ospf.Neighbor.DatabaseFilter))])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                        ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                        ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                        ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                    ])
                    self.ip = None
                    self.cost = None
                    self.poll_interval = None
                    self.priority = None

                    self.database_filter = Native.Router.Ospf.Neighbor.DatabaseFilter()
                    self.database_filter.parent = self
                    self._children_name_map["database_filter"] = "database-filter"
                    self._segment_path = lambda: "neighbor" + "[ip='" + str(self.ip) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Neighbor, ['ip', 'cost', 'poll_interval', 'priority'], name, value)


                class DatabaseFilter(Entity):
                    """
                    Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint neighbor
                    
                    .. attribute:: all
                    
                    	Filter all LSA
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Neighbor.DatabaseFilter.All>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Neighbor.DatabaseFilter, self).__init__()

                        self.yang_name = "database-filter"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Ospf.Neighbor.DatabaseFilter.All))])
                        self._leafs = OrderedDict()

                        self.all = Native.Router.Ospf.Neighbor.DatabaseFilter.All()
                        self.all.parent = self
                        self._children_name_map["all"] = "all"
                        self._segment_path = lambda: "database-filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Neighbor.DatabaseFilter, [], name, value)


                    class All(Entity):
                        """
                        Filter all LSA
                        
                        .. attribute:: out
                        
                        	Outgoing LSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Neighbor.DatabaseFilter.All, self).__init__()

                            self.yang_name = "all"
                            self.yang_parent_name = "database-filter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.out = None
                            self._segment_path = lambda: "all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Neighbor.DatabaseFilter.All, ['out'], name, value)


            class Network(Entity):
                """
                Enable routing on an IP network
                
                .. attribute:: ip  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mask  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: area
                
                	Set the OSPF area ID
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..4294967295
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Network, self).__init__()

                    self.yang_name = "network"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['ip','mask']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                        ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                        ('area', (YLeaf(YType.str, 'area'), ['int','str'])),
                    ])
                    self.ip = None
                    self.mask = None
                    self.area = None
                    self._segment_path = lambda: "network" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Network, ['ip', 'mask', 'area'], name, value)


            class Nsf(Entity):
                """
                Non\-stop forwarding
                
                .. attribute:: cisco
                
                	Cisco Non\-stop forwarding
                	**type**\:  :py:class:`Cisco <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Nsf.Cisco>`
                
                	**presence node**\: True
                
                .. attribute:: ietf
                
                	IETF graceful restart
                	**type**\:  :py:class:`Ietf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Nsf.Ietf>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cisco", ("cisco", Native.Router.Ospf.Nsf.Cisco)), ("ietf", ("ietf", Native.Router.Ospf.Nsf.Ietf))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.cisco = None
                    self._children_name_map["cisco"] = "cisco"

                    self.ietf = None
                    self._children_name_map["ietf"] = "ietf"
                    self._segment_path = lambda: "nsf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Nsf, [], name, value)


                class Cisco(Entity):
                    """
                    Cisco Non\-stop forwarding
                    
                    .. attribute:: enforce
                    
                    	Cancel NSF restart when non\-NSF\-aware neighbors detected
                    	**type**\:  :py:class:`Enforce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Nsf.Cisco.Enforce>`
                    
                    .. attribute:: helper
                    
                    	helper support
                    	**type**\:  :py:class:`Helper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Nsf.Cisco.Helper>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Nsf.Cisco, self).__init__()

                        self.yang_name = "cisco"
                        self.yang_parent_name = "nsf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("enforce", ("enforce", Native.Router.Ospf.Nsf.Cisco.Enforce)), ("helper", ("helper", Native.Router.Ospf.Nsf.Cisco.Helper))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.enforce = Native.Router.Ospf.Nsf.Cisco.Enforce()
                        self.enforce.parent = self
                        self._children_name_map["enforce"] = "enforce"

                        self.helper = None
                        self._children_name_map["helper"] = "helper"
                        self._segment_path = lambda: "cisco"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Nsf.Cisco, [], name, value)


                    class Enforce(Entity):
                        """
                        Cancel NSF restart when non\-NSF\-aware neighbors detected
                        
                        .. attribute:: global_
                        
                        	For the whole OSPF process
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Nsf.Cisco.Enforce, self).__init__()

                            self.yang_name = "enforce"
                            self.yang_parent_name = "cisco"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ])
                            self.global_ = None
                            self._segment_path = lambda: "enforce"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Nsf.Cisco.Enforce, ['global_'], name, value)


                    class Helper(Entity):
                        """
                        helper support
                        
                        .. attribute:: disable
                        
                        	disable helper support
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Nsf.Cisco.Helper, self).__init__()

                            self.yang_name = "helper"
                            self.yang_parent_name = "cisco"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "helper"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Nsf.Cisco.Helper, ['disable'], name, value)


                class Ietf(Entity):
                    """
                    IETF graceful restart
                    
                    .. attribute:: helper
                    
                    	helper support
                    	**type**\:  :py:class:`Helper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Nsf.Ietf.Helper>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: restart_interval
                    
                    	Graceful restart interval
                    	**type**\: int
                    
                    	**range:** 1..1800
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Nsf.Ietf, self).__init__()

                        self.yang_name = "ietf"
                        self.yang_parent_name = "nsf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("helper", ("helper", Native.Router.Ospf.Nsf.Ietf.Helper))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('restart_interval', (YLeaf(YType.uint16, 'restart-interval'), ['int'])),
                        ])
                        self.restart_interval = None

                        self.helper = None
                        self._children_name_map["helper"] = "helper"
                        self._segment_path = lambda: "ietf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Nsf.Ietf, ['restart_interval'], name, value)


                    class Helper(Entity):
                        """
                        helper support
                        
                        .. attribute:: disable
                        
                        	disable helper support
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: strict_lsa_checking
                        
                        	enable helper strict LSA checking
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Nsf.Ietf.Helper, self).__init__()

                            self.yang_name = "helper"
                            self.yang_parent_name = "ietf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('strict_lsa_checking', (YLeaf(YType.empty, 'strict-lsa-checking'), ['Empty'])),
                            ])
                            self.disable = None
                            self.strict_lsa_checking = None
                            self._segment_path = lambda: "helper"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Nsf.Ietf.Helper, ['disable', 'strict_lsa_checking'], name, value)


            class PrefixPriority(Entity):
                """
                OSPF prefix priority
                
                .. attribute:: high
                
                	High prefix priority
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: route_map
                
                	Prefix priority selection by route\-map
                	**type**\: str
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.PrefixPriority, self).__init__()

                    self.yang_name = "prefix-priority"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('high', (YLeaf(YType.empty, 'high'), ['Empty'])),
                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                    ])
                    self.high = None
                    self.route_map = None
                    self._segment_path = lambda: "prefix-priority"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.PrefixPriority, ['high', 'route_map'], name, value)


            class ProcessMinTime(Entity):
                """
                Percentage of quantum to be used before releasing CPU
                
                .. attribute:: percent
                
                	percent
                	**type**\: int
                
                	**range:** 1..100
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.ProcessMinTime, self).__init__()

                    self.yang_name = "process-min-time"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('percent', (YLeaf(YType.uint32, 'percent'), ['int'])),
                    ])
                    self.percent = None
                    self._segment_path = lambda: "process-min-time"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.ProcessMinTime, ['percent'], name, value)


            class Snmp(Entity):
                """
                Modify snmp parameters
                
                .. attribute:: context
                
                	Configure a SNMP context
                	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Snmp.Context>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Ospf.Snmp.Context))])
                    self._leafs = OrderedDict()

                    self.context = YList(self)
                    self._segment_path = lambda: "snmp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.Snmp, [], name, value)


                class Context(Entity):
                    """
                    Configure a SNMP context
                    
                    .. attribute:: name  (key)
                    
                    	Context Name
                    	**type**\: str
                    
                    .. attribute:: community
                    
                    	Configure a SNMP v2c Community string and access privs
                    	**type**\:  :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Snmp.Context.Community>`
                    
                    .. attribute:: user
                    
                    	Configure a SNMP v3 user
                    	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Snmp.Context.User>`
                    
                    

                    """

                    _prefix = 'ios-ospf'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospf.Snmp.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("community", ("community", Native.Router.Ospf.Snmp.Context.Community)), ("user", ("user", Native.Router.Ospf.Snmp.Context.User))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.community = Native.Router.Ospf.Snmp.Context.Community()
                        self.community.parent = self
                        self._children_name_map["community"] = "community"

                        self.user = Native.Router.Ospf.Snmp.Context.User()
                        self.user.parent = self
                        self._children_name_map["user"] = "user"
                        self._segment_path = lambda: "context" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospf.Snmp.Context, ['name'], name, value)


                    class Community(Entity):
                        """
                        Configure a SNMP v2c Community string and access privs
                        
                        .. attribute:: community_string
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: access
                        
                        	
                        	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Snmp.Context.Community.Access>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Snmp.Context.Community, self).__init__()

                            self.yang_name = "community"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("access", ("access", Native.Router.Ospf.Snmp.Context.Community.Access))])
                            self._leafs = OrderedDict([
                                ('community_string', (YLeaf(YType.str, 'community-string'), ['str'])),
                            ])
                            self.community_string = None

                            self.access = Native.Router.Ospf.Snmp.Context.Community.Access()
                            self.access.parent = self
                            self._children_name_map["access"] = "access"
                            self._segment_path = lambda: "community"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Snmp.Context.Community, ['community_string'], name, value)


                        class Access(Entity):
                            """
                            
                            
                            .. attribute:: standard_acl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..99
                            
                            .. attribute:: expanded_acl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1300..1999
                            
                            .. attribute:: acl_name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ipv6
                            
                            	Specify IPv6 Named Access\-List
                            	**type**\: str
                            
                            .. attribute:: ro
                            
                            	Read\-only access with this community string
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rw
                            
                            	Read\-write access with this community string
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Snmp.Context.Community.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "community"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                    ('expanded_acl', (YLeaf(YType.uint32, 'expanded-acl'), ['int'])),
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ('ro', (YLeaf(YType.empty, 'ro'), ['Empty'])),
                                    ('rw', (YLeaf(YType.empty, 'rw'), ['Empty'])),
                                ])
                                self.standard_acl = None
                                self.expanded_acl = None
                                self.acl_name = None
                                self.ipv6 = None
                                self.ro = None
                                self.rw = None
                                self._segment_path = lambda: "access"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Snmp.Context.Community.Access, ['standard_acl', 'expanded_acl', 'acl_name', 'ipv6', 'ro', 'rw'], name, value)


                    class User(Entity):
                        """
                        Configure a SNMP v3 user
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: permisssion
                        
                        	
                        	**type**\:  :py:class:`Permisssion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Snmp.Context.User.Permisssion>`
                        
                        

                        """

                        _prefix = 'ios-ospf'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospf.Snmp.Context.User, self).__init__()

                            self.yang_name = "user"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("permisssion", ("permisssion", Native.Router.Ospf.Snmp.Context.User.Permisssion))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.permisssion = Native.Router.Ospf.Snmp.Context.User.Permisssion()
                            self.permisssion.parent = self
                            self._children_name_map["permisssion"] = "permisssion"
                            self._segment_path = lambda: "user"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospf.Snmp.Context.User, ['name'], name, value)


                        class Permisssion(Entity):
                            """
                            
                            
                            .. attribute:: access
                            
                            	specify an access\-list associated with this group
                            	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Snmp.Context.User.Permisssion.Access>`
                            
                            .. attribute:: auth
                            
                            	authentication parameters for the user
                            	**type**\:  :py:class:`Auth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospf.Snmp.Context.User.Permisssion.Auth>`
                            
                            .. attribute:: credential
                            
                            	If the user password is already configured and saved
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: encrypted
                            
                            	specifying passwords as MD5 or SHA digests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospf'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospf.Snmp.Context.User.Permisssion, self).__init__()

                                self.yang_name = "permisssion"
                                self.yang_parent_name = "user"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("access", ("access", Native.Router.Ospf.Snmp.Context.User.Permisssion.Access)), ("auth", ("auth", Native.Router.Ospf.Snmp.Context.User.Permisssion.Auth))])
                                self._leafs = OrderedDict([
                                    ('credential', (YLeaf(YType.empty, 'credential'), ['Empty'])),
                                    ('encrypted', (YLeaf(YType.empty, 'encrypted'), ['Empty'])),
                                ])
                                self.credential = None
                                self.encrypted = None

                                self.access = Native.Router.Ospf.Snmp.Context.User.Permisssion.Access()
                                self.access.parent = self
                                self._children_name_map["access"] = "access"

                                self.auth = Native.Router.Ospf.Snmp.Context.User.Permisssion.Auth()
                                self.auth.parent = self
                                self._children_name_map["auth"] = "auth"
                                self._segment_path = lambda: "permisssion"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospf.Snmp.Context.User.Permisssion, ['credential', 'encrypted'], name, value)


                            class Access(Entity):
                                """
                                specify an access\-list associated with this group
                                
                                .. attribute:: standard_acl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: ipv6
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Snmp.Context.User.Permisssion.Access, self).__init__()

                                    self.yang_name = "access"
                                    self.yang_parent_name = "permisssion"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('standard_acl', (YLeaf(YType.uint32, 'standard-acl'), ['int'])),
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.standard_acl = None
                                    self.acl_name = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "access"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Snmp.Context.User.Permisssion.Access, ['standard_acl', 'acl_name', 'ipv6'], name, value)


                            class Auth(Entity):
                                """
                                authentication parameters for the user
                                
                                .. attribute:: md5
                                
                                	Use HMAC MD5 algorithm for authentication
                                	**type**\: str
                                
                                .. attribute:: sha
                                
                                	Use HMAC SHA algorithm for authentication
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospf'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospf.Snmp.Context.User.Permisssion.Auth, self).__init__()

                                    self.yang_name = "auth"
                                    self.yang_parent_name = "permisssion"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('md5', (YLeaf(YType.str, 'md5'), ['str'])),
                                        ('sha', (YLeaf(YType.str, 'sha'), ['str'])),
                                    ])
                                    self.md5 = None
                                    self.sha = None
                                    self._segment_path = lambda: "auth"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospf.Snmp.Context.User.Permisssion.Auth, ['md5', 'sha'], name, value)


            class SummaryAddress(Entity):
                """
                Configure IP address summaries
                
                .. attribute:: ip  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: wildcard  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: nssa_only
                
                	Limit summary to NSSA areas
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: tag
                
                	Set tag
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: not_advertise
                
                	Do not advertise when translating OSPF type\-7 LSA
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ospf'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospf.SummaryAddress, self).__init__()

                    self.yang_name = "summary-address"
                    self.yang_parent_name = "ospf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['ip','wildcard']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                        ('wildcard', (YLeaf(YType.str, 'wildcard'), ['str'])),
                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                        ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                    ])
                    self.ip = None
                    self.wildcard = None
                    self.nssa_only = None
                    self.tag = None
                    self.not_advertise = None
                    self._segment_path = lambda: "summary-address" + "[ip='" + str(self.ip) + "']" + "[wildcard='" + str(self.wildcard) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospf.SummaryAddress, ['ip', 'wildcard', 'nssa_only', 'tag', 'not_advertise'], name, value)


        class Lisp(Entity):
            """
            Locator/ID Separation Protocol
            
            .. attribute:: default
            
            	
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default>`
            
            .. attribute:: service
            
            	Configure lisp service type
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Select encapsulation type for data packets
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Encapsulation>`
            
            .. attribute:: locator_set
            
            	Configure a named locator set
            	**type**\: list of  		 :py:class:`LocatorSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.LocatorSet>`
            
            .. attribute:: locator
            
            	Locator configuration
            	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Locator>`
            
            .. attribute:: locator_scope
            
            	Configure a locator scope
            	**type**\: list of  		 :py:class:`LocatorScope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.LocatorScope>`
            
            .. attribute:: prefix_list
            
            	Configure a named prefix list
            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.PrefixList>`
            
            .. attribute:: instance_container
            
            	EID instance\-ID
            	**type**\:  :py:class:`InstanceContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer>`
            
            .. attribute:: alt
            
            	LISP Alternative Topology, LISP\-ALT
            	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Alt>`
            
            .. attribute:: control_packet
            
            	Configure control packet tx option
            	**type**\:  :py:class:`ControlPacket <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.ControlPacket>`
            
            .. attribute:: ddt
            
            	Delegated Database Tree (DDT) mapping system
            	**type**\:  :py:class:`Ddt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ddt>`
            
            	**presence node**\: True
            
            .. attribute:: decapsulation
            
            	Decapsulation behavior (e.g. filters)
            	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Decapsulation>`
            
            .. attribute:: disable_ttl_propagate
            
            	Disable ttl propagation
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: etr
            
            	Configures a LISP Egress Tunnel Router (ETR)
            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Etr>`
            
            .. attribute:: ipv4
            
            	IPv4 address family
            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4>`
            
            .. attribute:: ipv6
            
            	IPv6 address family
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6>`
            
            .. attribute:: loc_reach_algorithm
            
            	Configure locator reachability algorithm
            	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.LocReachAlgorithm>`
            
            .. attribute:: locator_down
            
            	Manually set locator status to down
            	**type**\:  :py:class:`LocatorDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.LocatorDown>`
            
            .. attribute:: locator_table
            
            	Specify the RLOC table
            	**type**\:  :py:class:`LocatorTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.LocatorTable>`
            
            .. attribute:: map_request
            
            	Configure map\-request handling
            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.MapRequest>`
            
            .. attribute:: map_server
            
            	Map\-Server commands
            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.MapServer>`
            
            .. attribute:: other_xtr_probe
            
            	Configure parameters for probing of other xTRs in our site
            	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.OtherXtrProbe>`
            
            .. attribute:: remote_rloc_probe
            
            	Configure parameters for probing of remote RLOCs
            	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.RemoteRlocProbe>`
            
            .. attribute:: eid_table
            
            	Configure an EID instance for a VRF
            	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable>`
            
            .. attribute:: security
            
            	Enable default LISP security and authentication in reply is optional
            	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Security>`
            
            	**presence node**\: True
            
            .. attribute:: site
            
            	Configure a LISP site on a map server (MS)
            	**type**\: list of  		 :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site>`
            
            .. attribute:: site_id
            
            	Configure a site\-id for this site
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: syslog
            
            	Configure syslog option
            	**type**\:  :py:class:`Syslog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Syslog>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-lisp'
            _revision = '2018-04-17'

            def __init__(self):
                super(Native.Router.Lisp, self).__init__()

                self.yang_name = "lisp"
                self.yang_parent_name = "router"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default)), ("service", ("service", Native.Router.Lisp.Service)), ("encapsulation", ("encapsulation", Native.Router.Lisp.Encapsulation)), ("locator-set", ("locator_set", Native.Router.Lisp.LocatorSet)), ("locator", ("locator", Native.Router.Lisp.Locator)), ("locator-scope", ("locator_scope", Native.Router.Lisp.LocatorScope)), ("prefix-list", ("prefix_list", Native.Router.Lisp.PrefixList)), ("instance-container", ("instance_container", Native.Router.Lisp.InstanceContainer)), ("alt", ("alt", Native.Router.Lisp.Alt)), ("control-packet", ("control_packet", Native.Router.Lisp.ControlPacket)), ("ddt", ("ddt", Native.Router.Lisp.Ddt)), ("decapsulation", ("decapsulation", Native.Router.Lisp.Decapsulation)), ("etr", ("etr", Native.Router.Lisp.Etr)), ("ipv4", ("ipv4", Native.Router.Lisp.Ipv4)), ("ipv6", ("ipv6", Native.Router.Lisp.Ipv6)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.Lisp.LocReachAlgorithm)), ("locator-down", ("locator_down", Native.Router.Lisp.LocatorDown)), ("locator-table", ("locator_table", Native.Router.Lisp.LocatorTable)), ("map-request", ("map_request", Native.Router.Lisp.MapRequest)), ("map-server", ("map_server", Native.Router.Lisp.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.Lisp.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.Lisp.RemoteRlocProbe)), ("eid-table", ("eid_table", Native.Router.Lisp.EidTable)), ("security", ("security", Native.Router.Lisp.Security)), ("site", ("site", Native.Router.Lisp.Site)), ("syslog", ("syslog", Native.Router.Lisp.Syslog))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                    ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                ])
                self.disable_ttl_propagate = None
                self.site_id = None

                self.default = Native.Router.Lisp.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.service = None
                self._children_name_map["service"] = "service"

                self.encapsulation = Native.Router.Lisp.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.locator = Native.Router.Lisp.Locator()
                self.locator.parent = self
                self._children_name_map["locator"] = "locator"

                self.instance_container = Native.Router.Lisp.InstanceContainer()
                self.instance_container.parent = self
                self._children_name_map["instance_container"] = "instance-container"

                self.alt = Native.Router.Lisp.Alt()
                self.alt.parent = self
                self._children_name_map["alt"] = "alt"

                self.control_packet = Native.Router.Lisp.ControlPacket()
                self.control_packet.parent = self
                self._children_name_map["control_packet"] = "control-packet"

                self.ddt = None
                self._children_name_map["ddt"] = "ddt"

                self.decapsulation = Native.Router.Lisp.Decapsulation()
                self.decapsulation.parent = self
                self._children_name_map["decapsulation"] = "decapsulation"

                self.etr = Native.Router.Lisp.Etr()
                self.etr.parent = self
                self._children_name_map["etr"] = "etr"

                self.ipv4 = Native.Router.Lisp.Ipv4()
                self.ipv4.parent = self
                self._children_name_map["ipv4"] = "ipv4"

                self.ipv6 = Native.Router.Lisp.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.loc_reach_algorithm = Native.Router.Lisp.LocReachAlgorithm()
                self.loc_reach_algorithm.parent = self
                self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                self.locator_down = Native.Router.Lisp.LocatorDown()
                self.locator_down.parent = self
                self._children_name_map["locator_down"] = "locator-down"

                self.locator_table = Native.Router.Lisp.LocatorTable()
                self.locator_table.parent = self
                self._children_name_map["locator_table"] = "locator-table"

                self.map_request = Native.Router.Lisp.MapRequest()
                self.map_request.parent = self
                self._children_name_map["map_request"] = "map-request"

                self.map_server = Native.Router.Lisp.MapServer()
                self.map_server.parent = self
                self._children_name_map["map_server"] = "map-server"

                self.other_xtr_probe = Native.Router.Lisp.OtherXtrProbe()
                self.other_xtr_probe.parent = self
                self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                self.remote_rloc_probe = Native.Router.Lisp.RemoteRlocProbe()
                self.remote_rloc_probe.parent = self
                self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                self.eid_table = Native.Router.Lisp.EidTable()
                self.eid_table.parent = self
                self._children_name_map["eid_table"] = "eid-table"

                self.security = None
                self._children_name_map["security"] = "security"

                self.syslog = Native.Router.Lisp.Syslog()
                self.syslog.parent = self
                self._children_name_map["syslog"] = "syslog"

                self.locator_set = YList(self)
                self.locator_scope = YList(self)
                self.prefix_list = YList(self)
                self.site = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Router.Lisp, ['disable_ttl_propagate', 'site_id'], name, value)


            class Default(Entity):
                """
                
                
                .. attribute:: service
                
                	Configure lisp service type
                	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service>`
                
                	**presence node**\: True
                
                .. attribute:: encapsulation
                
                	Select encapsulation type for data packets
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Encapsulation>`
                
                .. attribute:: locator_set
                
                	Configure a named locator set
                	**type**\: list of  		 :py:class:`LocatorSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.LocatorSet>`
                
                .. attribute:: locator
                
                	Locator configuration
                	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Locator>`
                
                .. attribute:: locator_scope
                
                	Configure a locator scope
                	**type**\: list of  		 :py:class:`LocatorScope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.LocatorScope>`
                
                .. attribute:: prefix_list
                
                	Configure a named prefix list
                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.PrefixList>`
                
                .. attribute:: instance_container
                
                	EID instance\-ID
                	**type**\:  :py:class:`InstanceContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer>`
                
                .. attribute:: alt
                
                	LISP Alternative Topology, LISP\-ALT
                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Alt>`
                
                .. attribute:: control_packet
                
                	Configure control packet tx option
                	**type**\:  :py:class:`ControlPacket <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.ControlPacket>`
                
                .. attribute:: ddt
                
                	Delegated Database Tree (DDT) mapping system
                	**type**\:  :py:class:`Ddt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ddt>`
                
                	**presence node**\: True
                
                .. attribute:: decapsulation
                
                	Decapsulation behavior (e.g. filters)
                	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Decapsulation>`
                
                .. attribute:: disable_ttl_propagate
                
                	Disable ttl propagation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: etr
                
                	Configures a LISP Egress Tunnel Router (ETR)
                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Etr>`
                
                .. attribute:: ipv4
                
                	IPv4 address family
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4>`
                
                .. attribute:: ipv6
                
                	IPv6 address family
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6>`
                
                .. attribute:: loc_reach_algorithm
                
                	Configure locator reachability algorithm
                	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.LocReachAlgorithm>`
                
                .. attribute:: locator_down
                
                	Manually set locator status to down
                	**type**\:  :py:class:`LocatorDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.LocatorDown>`
                
                .. attribute:: locator_table
                
                	Specify the RLOC table
                	**type**\:  :py:class:`LocatorTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.LocatorTable>`
                
                .. attribute:: map_request
                
                	Configure map\-request handling
                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.MapRequest>`
                
                .. attribute:: map_server
                
                	Map\-Server commands
                	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.MapServer>`
                
                .. attribute:: other_xtr_probe
                
                	Configure parameters for probing of other xTRs in our site
                	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.OtherXtrProbe>`
                
                .. attribute:: remote_rloc_probe
                
                	Configure parameters for probing of remote RLOCs
                	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.RemoteRlocProbe>`
                
                .. attribute:: eid_table
                
                	Configure an EID instance for a VRF
                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable>`
                
                .. attribute:: security
                
                	Enable default LISP security and authentication in reply is optional
                	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Security>`
                
                	**presence node**\: True
                
                .. attribute:: site
                
                	Configure a LISP site on a map server (MS)
                	**type**\: list of  		 :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site>`
                
                .. attribute:: site_id
                
                	Configure a site\-id for this site
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: syslog
                
                	Configure syslog option
                	**type**\:  :py:class:`Syslog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Syslog>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("service", ("service", Native.Router.Lisp.Default.Service)), ("encapsulation", ("encapsulation", Native.Router.Lisp.Default.Encapsulation)), ("locator-set", ("locator_set", Native.Router.Lisp.Default.LocatorSet)), ("locator", ("locator", Native.Router.Lisp.Default.Locator)), ("locator-scope", ("locator_scope", Native.Router.Lisp.Default.LocatorScope)), ("prefix-list", ("prefix_list", Native.Router.Lisp.Default.PrefixList)), ("instance-container", ("instance_container", Native.Router.Lisp.Default.InstanceContainer)), ("alt", ("alt", Native.Router.Lisp.Default.Alt)), ("control-packet", ("control_packet", Native.Router.Lisp.Default.ControlPacket)), ("ddt", ("ddt", Native.Router.Lisp.Default.Ddt)), ("decapsulation", ("decapsulation", Native.Router.Lisp.Default.Decapsulation)), ("etr", ("etr", Native.Router.Lisp.Default.Etr)), ("ipv4", ("ipv4", Native.Router.Lisp.Default.Ipv4)), ("ipv6", ("ipv6", Native.Router.Lisp.Default.Ipv6)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.Lisp.Default.LocReachAlgorithm)), ("locator-down", ("locator_down", Native.Router.Lisp.Default.LocatorDown)), ("locator-table", ("locator_table", Native.Router.Lisp.Default.LocatorTable)), ("map-request", ("map_request", Native.Router.Lisp.Default.MapRequest)), ("map-server", ("map_server", Native.Router.Lisp.Default.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.Lisp.Default.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.Lisp.Default.RemoteRlocProbe)), ("eid-table", ("eid_table", Native.Router.Lisp.Default.EidTable)), ("security", ("security", Native.Router.Lisp.Default.Security)), ("site", ("site", Native.Router.Lisp.Default.Site)), ("syslog", ("syslog", Native.Router.Lisp.Default.Syslog))])
                    self._leafs = OrderedDict([
                        ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                        ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                    ])
                    self.disable_ttl_propagate = None
                    self.site_id = None

                    self.service = None
                    self._children_name_map["service"] = "service"

                    self.encapsulation = Native.Router.Lisp.Default.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"

                    self.locator = Native.Router.Lisp.Default.Locator()
                    self.locator.parent = self
                    self._children_name_map["locator"] = "locator"

                    self.instance_container = Native.Router.Lisp.Default.InstanceContainer()
                    self.instance_container.parent = self
                    self._children_name_map["instance_container"] = "instance-container"

                    self.alt = Native.Router.Lisp.Default.Alt()
                    self.alt.parent = self
                    self._children_name_map["alt"] = "alt"

                    self.control_packet = Native.Router.Lisp.Default.ControlPacket()
                    self.control_packet.parent = self
                    self._children_name_map["control_packet"] = "control-packet"

                    self.ddt = None
                    self._children_name_map["ddt"] = "ddt"

                    self.decapsulation = Native.Router.Lisp.Default.Decapsulation()
                    self.decapsulation.parent = self
                    self._children_name_map["decapsulation"] = "decapsulation"

                    self.etr = Native.Router.Lisp.Default.Etr()
                    self.etr.parent = self
                    self._children_name_map["etr"] = "etr"

                    self.ipv4 = Native.Router.Lisp.Default.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = Native.Router.Lisp.Default.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.loc_reach_algorithm = Native.Router.Lisp.Default.LocReachAlgorithm()
                    self.loc_reach_algorithm.parent = self
                    self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                    self.locator_down = Native.Router.Lisp.Default.LocatorDown()
                    self.locator_down.parent = self
                    self._children_name_map["locator_down"] = "locator-down"

                    self.locator_table = Native.Router.Lisp.Default.LocatorTable()
                    self.locator_table.parent = self
                    self._children_name_map["locator_table"] = "locator-table"

                    self.map_request = Native.Router.Lisp.Default.MapRequest()
                    self.map_request.parent = self
                    self._children_name_map["map_request"] = "map-request"

                    self.map_server = Native.Router.Lisp.Default.MapServer()
                    self.map_server.parent = self
                    self._children_name_map["map_server"] = "map-server"

                    self.other_xtr_probe = Native.Router.Lisp.Default.OtherXtrProbe()
                    self.other_xtr_probe.parent = self
                    self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                    self.remote_rloc_probe = Native.Router.Lisp.Default.RemoteRlocProbe()
                    self.remote_rloc_probe.parent = self
                    self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                    self.eid_table = Native.Router.Lisp.Default.EidTable()
                    self.eid_table.parent = self
                    self._children_name_map["eid_table"] = "eid-table"

                    self.security = None
                    self._children_name_map["security"] = "security"

                    self.syslog = Native.Router.Lisp.Default.Syslog()
                    self.syslog.parent = self
                    self._children_name_map["syslog"] = "syslog"

                    self.locator_set = YList(self)
                    self.locator_scope = YList(self)
                    self.prefix_list = YList(self)
                    self.site = YList(self)
                    self._segment_path = lambda: "default"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Default, ['disable_ttl_propagate', 'site_id'], name, value)


                class Service(Entity):
                    """
                    Configure lisp service type
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ethernet
                    
                    	
                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Service, self).__init__()

                        self.yang_name = "service"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Lisp.Default.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.Lisp.Default.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.Lisp.Default.Service.Ethernet))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.ipv4 = None
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = None
                        self._children_name_map["ipv6"] = "ipv6"

                        self.ethernet = None
                        self._children_name_map["ethernet"] = "ethernet"
                        self._segment_path = lambda: "service"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Service, [], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: default
                        
                        	
                        	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_>`
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.SolicitMapRequest>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Distance>`
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Encapsulation>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapCache>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapCachePersistent>`
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.ProxyItr>`
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.RouteExport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.UsePetr>`
                        
                        .. attribute:: import_
                        
                        	Redistribute LISP states internally
                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Import>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Service.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "service"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default.Service.Ipv4.Default_)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.Service.Ipv4.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Default.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.Service.Ipv4.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ipv4.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.Service.Ipv4.SolicitMapRequest)), ("distance", ("distance", Native.Router.Lisp.Default.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.Service.Ipv4.Import))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv4.Encapsulation')])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ])
                            self.encapsulation = None
                            self.proxy_etr = None
                            self.sgt = None
                            self.map_request_source = None

                            self.default = Native.Router.Lisp.Default.Service.Ipv4.Default_()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"

                            self.database_mapping = Native.Router.Lisp.Default.Service.Ipv4.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.Lisp.Default.Service.Ipv4.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.Lisp.Default.Service.Ipv4.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.Lisp.Default.Service.Ipv4.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.Lisp.Default.Service.Ipv4.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.Lisp.Default.Service.Ipv4.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.Lisp.Default.Service.Ipv4.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.Lisp.Default.Service.Ipv4.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.distance = Native.Router.Lisp.Default.Service.Ipv4.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.map_cache = Native.Router.Lisp.Default.Service.Ipv4.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_persistent = Native.Router.Lisp.Default.Service.Ipv4.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.proxy_itr = Native.Router.Lisp.Default.Service.Ipv4.ProxyItr()
                            self.proxy_itr.parent = self
                            self._children_name_map["proxy_itr"] = "proxy-itr"

                            self.route_export = Native.Router.Lisp.Default.Service.Ipv4.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.import_ = Native.Router.Lisp.Default.Service.Ipv4.Import()
                            self.import_.parent = self
                            self._children_name_map["import_"] = "import"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Select encapsulation type for data packets

                            .. data:: lisp = 0

                            .. data:: vxlan = 1

                            """

                            lisp = Enum.YLeaf(0, "lisp")

                            vxlan = Enum.YLeaf(1, "vxlan")



                        class Default_(Entity):
                            """
                            
                            
                            .. attribute:: database_mapping
                            
                            	Address family specific local EID prefixes database configuration
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.DatabaseMapping>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCacheLimit>`
                            
                            .. attribute:: map_resolver
                            
                            	Configures a LISP Map Resolver (MR)
                            	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: map_server
                            
                            	Configures a LISP Map Server (MS)
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.SolicitMapRequest>`
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Distance>`
                            
                            .. attribute:: encapsulation
                            
                            	Select encapsulation type for data packets
                            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Encapsulation>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCache>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCachePersistent>`
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.ProxyItr>`
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.RouteExport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.UsePetr>`
                            
                            .. attribute:: import_
                            
                            	Redistribute LISP states internally
                            	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Import>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.Default_, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Default.Service.Ipv4.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Default.Service.Ipv4.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.Service.Ipv4.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.Service.Ipv4.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.Service.Ipv4.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.Service.Ipv4.Default_.SolicitMapRequest)), ("distance", ("distance", Native.Router.Lisp.Default.Service.Ipv4.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.Service.Ipv4.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.Service.Ipv4.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.Service.Ipv4.Default_.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.Service.Ipv4.Default_.Import))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv4.Default_.Encapsulation')])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ])
                                self.encapsulation = None
                                self.proxy_etr = None
                                self.sgt = None
                                self.map_request_source = None

                                self.database_mapping = Native.Router.Lisp.Default.Service.Ipv4.Default_.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.itr = Native.Router.Lisp.Default.Service.Ipv4.Default_.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.Lisp.Default.Service.Ipv4.Default_.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.Lisp.Default.Service.Ipv4.Default_.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.map_resolver = None
                                self._children_name_map["map_resolver"] = "map-resolver"

                                self.map_server = None
                                self._children_name_map["map_server"] = "map-server"

                                self.site_registration = Native.Router.Lisp.Default.Service.Ipv4.Default_.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.Lisp.Default.Service.Ipv4.Default_.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.distance = Native.Router.Lisp.Default.Service.Ipv4.Default_.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.map_cache = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_persistent = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.proxy_itr = Native.Router.Lisp.Default.Service.Ipv4.Default_.ProxyItr()
                                self.proxy_itr.parent = self
                                self._children_name_map["proxy_itr"] = "proxy-itr"

                                self.route_export = Native.Router.Lisp.Default.Service.Ipv4.Default_.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.import_ = Native.Router.Lisp.Default.Service.Ipv4.Default_.Import()
                                self.import_.parent = self
                                self._children_name_map["import_"] = "import"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "default"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                            class Encapsulation(Enum):
                                """
                                Encapsulation (Enum Class)

                                Select encapsulation type for data packets

                                .. data:: lisp = 0

                                .. data:: vxlan = 1

                                """

                                lisp = Enum.YLeaf(0, "lisp")

                                vxlan = Enum.YLeaf(1, "vxlan")



                            class DatabaseMapping(Entity):
                                """
                                Address family specific local EID prefixes database configuration
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Default.Service.Ipv4.Default_.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.Lisp.Default.Service.Ipv4.Default_.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"
                                    self._segment_path = lambda: "database-mapping"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.DatabaseMapping, [], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.Default_.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/database-mapping/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ipv4.Default_.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/itr/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/etr/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/etr/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures a LISP Map Resolver (MR)
                                
                                .. attribute:: map_request
                                
                                	Map\-Request processing options
                                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_request = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest()
                                    self.map_request.parent = self
                                    self._children_name_map["map_request"] = "map-request"
                                    self._segment_path = lambda: "map-resolver"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver, [], name, value)


                                class MapRequest(Entity):
                                    """
                                    Map\-Request processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest, self).__init__()

                                        self.yang_name = "map-request"
                                        self.yang_parent_name = "map-resolver"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-request"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/map-resolver/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	Influence which source RLOCs map requests are accepted from
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/map-resolver/map-request/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            Influence which source RLOCs map requests are accepted from
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.List>`
                                            
                                            .. attribute:: registered
                                            
                                            	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"

                                                self.registered = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered()
                                                self.registered.parent = self
                                                self._children_name_map["registered"] = "registered"
                                                self._segment_path = lambda: "source"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/map-resolver/map-request/validate/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                            class Registered(Entity):
                                                """
                                                ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                                
                                                .. attribute:: list
                                                
                                                	Define allowed prefixes using an ip[v6] prefix list
                                                	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                    self.yang_name = "registered"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                    self._leafs = OrderedDict()

                                                    self.list = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                    self.list.parent = self
                                                    self._children_name_map["list"] = "list"
                                                    self._segment_path = lambda: "registered"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                                class List(Entity):
                                                    """
                                                    Define allowed prefixes using an ip[v6] prefix list
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 prefixes
                                                    	**type**\: str
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 prefixes
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                        self.yang_name = "list"
                                                        self.yang_parent_name = "registered"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "list"
                                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                            class MapServer(Entity):
                                """
                                Configures a LISP Map Server (MS)
                                
                                .. attribute:: map_register
                                
                                	Map\-Register processing options
                                	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_register = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister()
                                    self.map_register.parent = self
                                    self._children_name_map["map_register"] = "map-register"
                                    self._segment_path = lambda: "map-server"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer, [], name, value)


                                class MapRegister(Entity):
                                    """
                                    Map\-Register processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister, self).__init__()

                                        self.yang_name = "map-register"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-register"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/map-server/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	RLOC Source IP address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-register"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/map-server/map-register/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            RLOC Source IP address
                                            
                                            .. attribute:: allowed_locator
                                            
                                            	Against sites' allowed\-locators policy
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                                ])
                                                self.allowed_locator = None
                                                self._segment_path = lambda: "source"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/map-server/map-register/validate/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: away
                                
                                	Administrative distance for RIB route installation
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.away = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: away_eids
                                
                                	Map cache configuration for the away table
                                	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCache.AwayEids>`
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCache.AwayEids))])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None

                                    self.away_eids = Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCache.AwayEids()
                                    self.away_eids.parent = self
                                    self._children_name_map["away_eids"] = "away-eids"
                                    self._segment_path = lambda: "map-cache"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCache, ['site_registration'], name, value)


                                class AwayEids(Entity):
                                    """
                                    Map cache configuration for the away table
                                    
                                    .. attribute:: send_map_request
                                    
                                    	Export away table entries into the map cache with action set to send\-map\-request
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCache.AwayEids, self).__init__()

                                        self.yang_name = "away-eids"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                        ])
                                        self.send_map_request = None
                                        self._segment_path = lambda: "away-eids"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/map-cache/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.MapCachePersistent, ['interval'], name, value)


                            class ProxyItr(Entity):
                                """
                                Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                
                                .. attribute:: ipv4_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.ProxyItr, self).__init__()

                                    self.yang_name = "proxy-itr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                        ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                    ])
                                    self.ipv4_addr = None
                                    self.ipv6_addr = None
                                    self._segment_path = lambda: "proxy-itr"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	
                                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.UsePetr.Priority>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.Service.Ipv4.Default_.UsePetr.Priority))])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ])
                                    self.locator_address = None

                                    self.priority = Native.Router.Lisp.Default.Service.Ipv4.Default_.UsePetr.Priority()
                                    self.priority.parent = self
                                    self._children_name_map["priority"] = "priority"
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.UsePetr, ['locator_address'], name, value)


                                class Priority(Entity):
                                    """
                                    
                                    
                                    .. attribute:: priority_value
                                    
                                    	Configures which Locators from a set are preferred
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: weight
                                    
                                    	Traffic load\-spreading among Locators
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.Default_.UsePetr.Priority, self).__init__()

                                        self.yang_name = "priority"
                                        self.yang_parent_name = "use-petr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                        ])
                                        self.priority_value = None
                                        self.weight = None
                                        self._segment_path = lambda: "priority"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                            class Import(Entity):
                                """
                                Redistribute LISP states internally
                                
                                .. attribute:: database
                                
                                	Redistribute LISP internal states as database mapping
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Default_.Import.Database>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Import, self).__init__()

                                    self.yang_name = "import"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.Service.Ipv4.Default_.Import.Database))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.Lisp.Default.Service.Ipv4.Default_.Import.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"
                                    self._segment_path = lambda: "import"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Import, [], name, value)


                                class Database(Entity):
                                    """
                                    Redistribute LISP internal states as database mapping
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.Default_.Import.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.site_registration = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "database"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/default/import/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Default.Service.Ipv4.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.Lisp.Default.Service.Ipv4.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/database-mapping/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ipv4.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/itr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.Lisp.Default.Service.Ipv4.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/map-resolver/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/map-resolver/map-request/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/map-resolver/map-request/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/map-server/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/map-server/map-register/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/map-server/map-register/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: away
                            
                            	Administrative distance for RIB route installation
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.away = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: away_eids
                            
                            	Map cache configuration for the away table
                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.MapCache.AwayEids>`
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.Lisp.Default.Service.Ipv4.MapCache.AwayEids))])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None

                                self.away_eids = Native.Router.Lisp.Default.Service.Ipv4.MapCache.AwayEids()
                                self.away_eids.parent = self
                                self._children_name_map["away_eids"] = "away-eids"
                                self._segment_path = lambda: "map-cache"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapCache, ['site_registration'], name, value)


                            class AwayEids(Entity):
                                """
                                Map cache configuration for the away table
                                
                                .. attribute:: send_map_request
                                
                                	Export away table entries into the map cache with action set to send\-map\-request
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                    self.yang_name = "away-eids"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                    ])
                                    self.send_map_request = None
                                    self._segment_path = lambda: "away-eids"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                        class ProxyItr(Entity):
                            """
                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            
                            .. attribute:: ipv4_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.ProxyItr, self).__init__()

                                self.yang_name = "proxy-itr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                ])
                                self.ipv4_addr = None
                                self.ipv6_addr = None
                                self._segment_path = lambda: "proxy-itr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	
                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.UsePetr.Priority>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.Service.Ipv4.UsePetr.Priority))])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ])
                                self.locator_address = None

                                self.priority = Native.Router.Lisp.Default.Service.Ipv4.UsePetr.Priority()
                                self.priority.parent = self
                                self._children_name_map["priority"] = "priority"
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                            class Priority(Entity):
                                """
                                
                                
                                .. attribute:: priority_value
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.UsePetr.Priority, self).__init__()

                                    self.yang_name = "priority"
                                    self.yang_parent_name = "use-petr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.priority_value = None
                                    self.weight = None
                                    self._segment_path = lambda: "priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                        class Import(Entity):
                            """
                            Redistribute LISP states internally
                            
                            .. attribute:: database
                            
                            	Redistribute LISP internal states as database mapping
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv4.Import.Database>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv4.Import, self).__init__()

                                self.yang_name = "import"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.Service.Ipv4.Import.Database))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.Lisp.Default.Service.Ipv4.Import.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"
                                self._segment_path = lambda: "import"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Import, [], name, value)


                            class Database(Entity):
                                """
                                Redistribute LISP internal states as database mapping
                                
                                .. attribute:: site_registration
                                
                                	Import states from site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv4.Import.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.site_registration = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "database"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv4/import/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                    class Ipv6(Entity):
                        """
                        
                        
                        .. attribute:: default
                        
                        	
                        	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_>`
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.SolicitMapRequest>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Distance>`
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Encapsulation>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapCache>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapCachePersistent>`
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.ProxyItr>`
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.RouteExport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.UsePetr>`
                        
                        .. attribute:: import_
                        
                        	Redistribute LISP states internally
                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Import>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Service.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "service"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default.Service.Ipv6.Default_)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.Service.Ipv6.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Default.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.Service.Ipv6.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ipv6.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.Service.Ipv6.SolicitMapRequest)), ("distance", ("distance", Native.Router.Lisp.Default.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.Service.Ipv6.Import))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv6.Encapsulation')])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ])
                            self.encapsulation = None
                            self.proxy_etr = None
                            self.sgt = None
                            self.map_request_source = None

                            self.default = Native.Router.Lisp.Default.Service.Ipv6.Default_()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"

                            self.database_mapping = Native.Router.Lisp.Default.Service.Ipv6.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.Lisp.Default.Service.Ipv6.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.Lisp.Default.Service.Ipv6.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.Lisp.Default.Service.Ipv6.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.Lisp.Default.Service.Ipv6.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.Lisp.Default.Service.Ipv6.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.Lisp.Default.Service.Ipv6.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.Lisp.Default.Service.Ipv6.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.distance = Native.Router.Lisp.Default.Service.Ipv6.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.map_cache = Native.Router.Lisp.Default.Service.Ipv6.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_persistent = Native.Router.Lisp.Default.Service.Ipv6.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.proxy_itr = Native.Router.Lisp.Default.Service.Ipv6.ProxyItr()
                            self.proxy_itr.parent = self
                            self._children_name_map["proxy_itr"] = "proxy-itr"

                            self.route_export = Native.Router.Lisp.Default.Service.Ipv6.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.import_ = Native.Router.Lisp.Default.Service.Ipv6.Import()
                            self.import_.parent = self
                            self._children_name_map["import_"] = "import"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Select encapsulation type for data packets

                            .. data:: lisp = 0

                            .. data:: vxlan = 1

                            """

                            lisp = Enum.YLeaf(0, "lisp")

                            vxlan = Enum.YLeaf(1, "vxlan")



                        class Default_(Entity):
                            """
                            
                            
                            .. attribute:: database_mapping
                            
                            	Address family specific local EID prefixes database configuration
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.DatabaseMapping>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCacheLimit>`
                            
                            .. attribute:: map_resolver
                            
                            	Configures a LISP Map Resolver (MR)
                            	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: map_server
                            
                            	Configures a LISP Map Server (MS)
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.SolicitMapRequest>`
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Distance>`
                            
                            .. attribute:: encapsulation
                            
                            	Select encapsulation type for data packets
                            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Encapsulation>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCache>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCachePersistent>`
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.ProxyItr>`
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.RouteExport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.UsePetr>`
                            
                            .. attribute:: import_
                            
                            	Redistribute LISP states internally
                            	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Import>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.Default_, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Default.Service.Ipv6.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Default.Service.Ipv6.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.Service.Ipv6.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.Service.Ipv6.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.Service.Ipv6.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.Service.Ipv6.Default_.SolicitMapRequest)), ("distance", ("distance", Native.Router.Lisp.Default.Service.Ipv6.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.Service.Ipv6.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.Service.Ipv6.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.Service.Ipv6.Default_.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.Service.Ipv6.Default_.Import))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv6.Default_.Encapsulation')])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ])
                                self.encapsulation = None
                                self.proxy_etr = None
                                self.sgt = None
                                self.map_request_source = None

                                self.database_mapping = Native.Router.Lisp.Default.Service.Ipv6.Default_.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.itr = Native.Router.Lisp.Default.Service.Ipv6.Default_.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.Lisp.Default.Service.Ipv6.Default_.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.Lisp.Default.Service.Ipv6.Default_.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.map_resolver = None
                                self._children_name_map["map_resolver"] = "map-resolver"

                                self.map_server = None
                                self._children_name_map["map_server"] = "map-server"

                                self.site_registration = Native.Router.Lisp.Default.Service.Ipv6.Default_.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.Lisp.Default.Service.Ipv6.Default_.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.distance = Native.Router.Lisp.Default.Service.Ipv6.Default_.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.map_cache = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_persistent = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.proxy_itr = Native.Router.Lisp.Default.Service.Ipv6.Default_.ProxyItr()
                                self.proxy_itr.parent = self
                                self._children_name_map["proxy_itr"] = "proxy-itr"

                                self.route_export = Native.Router.Lisp.Default.Service.Ipv6.Default_.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.import_ = Native.Router.Lisp.Default.Service.Ipv6.Default_.Import()
                                self.import_.parent = self
                                self._children_name_map["import_"] = "import"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "default"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                            class Encapsulation(Enum):
                                """
                                Encapsulation (Enum Class)

                                Select encapsulation type for data packets

                                .. data:: lisp = 0

                                .. data:: vxlan = 1

                                """

                                lisp = Enum.YLeaf(0, "lisp")

                                vxlan = Enum.YLeaf(1, "vxlan")



                            class DatabaseMapping(Entity):
                                """
                                Address family specific local EID prefixes database configuration
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Default.Service.Ipv6.Default_.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.Lisp.Default.Service.Ipv6.Default_.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"
                                    self._segment_path = lambda: "database-mapping"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.DatabaseMapping, [], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.Default_.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/database-mapping/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ipv6.Default_.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/itr/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/etr/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/etr/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures a LISP Map Resolver (MR)
                                
                                .. attribute:: map_request
                                
                                	Map\-Request processing options
                                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_request = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest()
                                    self.map_request.parent = self
                                    self._children_name_map["map_request"] = "map-request"
                                    self._segment_path = lambda: "map-resolver"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver, [], name, value)


                                class MapRequest(Entity):
                                    """
                                    Map\-Request processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest, self).__init__()

                                        self.yang_name = "map-request"
                                        self.yang_parent_name = "map-resolver"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-request"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/map-resolver/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	Influence which source RLOCs map requests are accepted from
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/map-resolver/map-request/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            Influence which source RLOCs map requests are accepted from
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.List>`
                                            
                                            .. attribute:: registered
                                            
                                            	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"

                                                self.registered = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered()
                                                self.registered.parent = self
                                                self._children_name_map["registered"] = "registered"
                                                self._segment_path = lambda: "source"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/map-resolver/map-request/validate/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                            class Registered(Entity):
                                                """
                                                ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                                
                                                .. attribute:: list
                                                
                                                	Define allowed prefixes using an ip[v6] prefix list
                                                	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                    self.yang_name = "registered"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                    self._leafs = OrderedDict()

                                                    self.list = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                    self.list.parent = self
                                                    self._children_name_map["list"] = "list"
                                                    self._segment_path = lambda: "registered"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                                class List(Entity):
                                                    """
                                                    Define allowed prefixes using an ip[v6] prefix list
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 prefixes
                                                    	**type**\: str
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 prefixes
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                        self.yang_name = "list"
                                                        self.yang_parent_name = "registered"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "list"
                                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                            class MapServer(Entity):
                                """
                                Configures a LISP Map Server (MS)
                                
                                .. attribute:: map_register
                                
                                	Map\-Register processing options
                                	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_register = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister()
                                    self.map_register.parent = self
                                    self._children_name_map["map_register"] = "map-register"
                                    self._segment_path = lambda: "map-server"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer, [], name, value)


                                class MapRegister(Entity):
                                    """
                                    Map\-Register processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister, self).__init__()

                                        self.yang_name = "map-register"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-register"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/map-server/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	RLOC Source IP address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-register"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/map-server/map-register/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            RLOC Source IP address
                                            
                                            .. attribute:: allowed_locator
                                            
                                            	Against sites' allowed\-locators policy
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                                ])
                                                self.allowed_locator = None
                                                self._segment_path = lambda: "source"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/map-server/map-register/validate/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: away
                                
                                	Administrative distance for RIB route installation
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.away = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: away_eids
                                
                                	Map cache configuration for the away table
                                	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCache.AwayEids>`
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCache.AwayEids))])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None

                                    self.away_eids = Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCache.AwayEids()
                                    self.away_eids.parent = self
                                    self._children_name_map["away_eids"] = "away-eids"
                                    self._segment_path = lambda: "map-cache"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCache, ['site_registration'], name, value)


                                class AwayEids(Entity):
                                    """
                                    Map cache configuration for the away table
                                    
                                    .. attribute:: send_map_request
                                    
                                    	Export away table entries into the map cache with action set to send\-map\-request
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCache.AwayEids, self).__init__()

                                        self.yang_name = "away-eids"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                        ])
                                        self.send_map_request = None
                                        self._segment_path = lambda: "away-eids"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/map-cache/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.MapCachePersistent, ['interval'], name, value)


                            class ProxyItr(Entity):
                                """
                                Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                
                                .. attribute:: ipv4_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.ProxyItr, self).__init__()

                                    self.yang_name = "proxy-itr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                        ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                    ])
                                    self.ipv4_addr = None
                                    self.ipv6_addr = None
                                    self._segment_path = lambda: "proxy-itr"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	
                                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.UsePetr.Priority>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.Service.Ipv6.Default_.UsePetr.Priority))])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ])
                                    self.locator_address = None

                                    self.priority = Native.Router.Lisp.Default.Service.Ipv6.Default_.UsePetr.Priority()
                                    self.priority.parent = self
                                    self._children_name_map["priority"] = "priority"
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.UsePetr, ['locator_address'], name, value)


                                class Priority(Entity):
                                    """
                                    
                                    
                                    .. attribute:: priority_value
                                    
                                    	Configures which Locators from a set are preferred
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: weight
                                    
                                    	Traffic load\-spreading among Locators
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.Default_.UsePetr.Priority, self).__init__()

                                        self.yang_name = "priority"
                                        self.yang_parent_name = "use-petr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                        ])
                                        self.priority_value = None
                                        self.weight = None
                                        self._segment_path = lambda: "priority"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                            class Import(Entity):
                                """
                                Redistribute LISP states internally
                                
                                .. attribute:: database
                                
                                	Redistribute LISP internal states as database mapping
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Default_.Import.Database>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Import, self).__init__()

                                    self.yang_name = "import"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.Service.Ipv6.Default_.Import.Database))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.Lisp.Default.Service.Ipv6.Default_.Import.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"
                                    self._segment_path = lambda: "import"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Import, [], name, value)


                                class Database(Entity):
                                    """
                                    Redistribute LISP internal states as database mapping
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.Default_.Import.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.site_registration = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "database"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/default/import/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Default.Service.Ipv6.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.Lisp.Default.Service.Ipv6.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/database-mapping/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ipv6.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/itr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.Lisp.Default.Service.Ipv6.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/map-resolver/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/map-resolver/map-request/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/map-resolver/map-request/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/map-server/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/map-server/map-register/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/map-server/map-register/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: away
                            
                            	Administrative distance for RIB route installation
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.away = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: away_eids
                            
                            	Map cache configuration for the away table
                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.MapCache.AwayEids>`
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.Lisp.Default.Service.Ipv6.MapCache.AwayEids))])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None

                                self.away_eids = Native.Router.Lisp.Default.Service.Ipv6.MapCache.AwayEids()
                                self.away_eids.parent = self
                                self._children_name_map["away_eids"] = "away-eids"
                                self._segment_path = lambda: "map-cache"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapCache, ['site_registration'], name, value)


                            class AwayEids(Entity):
                                """
                                Map cache configuration for the away table
                                
                                .. attribute:: send_map_request
                                
                                	Export away table entries into the map cache with action set to send\-map\-request
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                    self.yang_name = "away-eids"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                    ])
                                    self.send_map_request = None
                                    self._segment_path = lambda: "away-eids"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                        class ProxyItr(Entity):
                            """
                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            
                            .. attribute:: ipv4_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.ProxyItr, self).__init__()

                                self.yang_name = "proxy-itr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                ])
                                self.ipv4_addr = None
                                self.ipv6_addr = None
                                self._segment_path = lambda: "proxy-itr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	
                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.UsePetr.Priority>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.Service.Ipv6.UsePetr.Priority))])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ])
                                self.locator_address = None

                                self.priority = Native.Router.Lisp.Default.Service.Ipv6.UsePetr.Priority()
                                self.priority.parent = self
                                self._children_name_map["priority"] = "priority"
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                            class Priority(Entity):
                                """
                                
                                
                                .. attribute:: priority_value
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.UsePetr.Priority, self).__init__()

                                    self.yang_name = "priority"
                                    self.yang_parent_name = "use-petr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.priority_value = None
                                    self.weight = None
                                    self._segment_path = lambda: "priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                        class Import(Entity):
                            """
                            Redistribute LISP states internally
                            
                            .. attribute:: database
                            
                            	Redistribute LISP internal states as database mapping
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ipv6.Import.Database>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ipv6.Import, self).__init__()

                                self.yang_name = "import"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.Service.Ipv6.Import.Database))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.Lisp.Default.Service.Ipv6.Import.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"
                                self._segment_path = lambda: "import"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Import, [], name, value)


                            class Database(Entity):
                                """
                                Redistribute LISP internal states as database mapping
                                
                                .. attribute:: site_registration
                                
                                	Import states from site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ipv6.Import.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.site_registration = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "database"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ipv6/import/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                    class Ethernet(Entity):
                        """
                        
                        
                        .. attribute:: default
                        
                        	
                        	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_>`
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Encapsulation>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.SolicitMapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Service.Ethernet, self).__init__()

                            self.yang_name = "ethernet"
                            self.yang_parent_name = "service"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default.Service.Ethernet.Default_)), ("encapsulation", ("encapsulation", Native.Router.Lisp.Default.Service.Ethernet.Encapsulation)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Default.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.Service.Ethernet.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ethernet.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ethernet.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.Service.Ethernet.SolicitMapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                            ])
                            self.map_request_source = None

                            self.default = Native.Router.Lisp.Default.Service.Ethernet.Default_()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"

                            self.encapsulation = Native.Router.Lisp.Default.Service.Ethernet.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.database_mapping = Native.Router.Lisp.Default.Service.Ethernet.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.Lisp.Default.Service.Ethernet.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.Lisp.Default.Service.Ethernet.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.Lisp.Default.Service.Ethernet.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.Lisp.Default.Service.Ethernet.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.Lisp.Default.Service.Ethernet.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.Lisp.Default.Service.Ethernet.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.Lisp.Default.Service.Ethernet.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"
                            self._segment_path = lambda: "ethernet"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet, ['map_request_source'], name, value)


                        class Default_(Entity):
                            """
                            
                            
                            .. attribute:: encapsulation
                            
                            	Select encapsulation type for data packets
                            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Encapsulation>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: database_mapping
                            
                            	Address family specific local EID prefixes database configuration
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.DatabaseMapping>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapCacheLimit>`
                            
                            .. attribute:: map_resolver
                            
                            	Configures a LISP Map Resolver (MR)
                            	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: map_server
                            
                            	Configures a LISP Map Server (MS)
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.SolicitMapRequest>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.Default_, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Router.Lisp.Default.Service.Ethernet.Default_.Encapsulation)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.Service.Ethernet.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Default.Service.Ethernet.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.Service.Ethernet.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.Service.Ethernet.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.Service.Ethernet.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.Service.Ethernet.Default_.SolicitMapRequest))])
                                self._leafs = OrderedDict([
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                ])
                                self.map_request_source = None

                                self.encapsulation = Native.Router.Lisp.Default.Service.Ethernet.Default_.Encapsulation()
                                self.encapsulation.parent = self
                                self._children_name_map["encapsulation"] = "encapsulation"

                                self.database_mapping = Native.Router.Lisp.Default.Service.Ethernet.Default_.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.itr = Native.Router.Lisp.Default.Service.Ethernet.Default_.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.Lisp.Default.Service.Ethernet.Default_.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.Lisp.Default.Service.Ethernet.Default_.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.Lisp.Default.Service.Ethernet.Default_.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.map_resolver = None
                                self._children_name_map["map_resolver"] = "map-resolver"

                                self.map_server = None
                                self._children_name_map["map_server"] = "map-server"

                                self.site_registration = Native.Router.Lisp.Default.Service.Ethernet.Default_.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.Lisp.Default.Service.Ethernet.Default_.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"
                                self._segment_path = lambda: "default"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_, ['map_request_source'], name, value)


                            class Encapsulation(Entity):
                                """
                                Select encapsulation type for data packets
                                
                                .. attribute:: vxlan
                                
                                	Use VXLAN encapsulation for data packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.Encapsulation, self).__init__()

                                    self.yang_name = "encapsulation"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                    ])
                                    self.vxlan = None
                                    self._segment_path = lambda: "encapsulation"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.Encapsulation, ['vxlan'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Address family specific local EID prefixes database configuration
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Default.Service.Ethernet.Default_.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.Lisp.Default.Service.Ethernet.Default_.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"
                                    self._segment_path = lambda: "database-mapping"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.DatabaseMapping, [], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ethernet.Default_.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/database-mapping/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ethernet.Default_.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ethernet.Default_.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/itr/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/etr/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/etr/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures a LISP Map Resolver (MR)
                                
                                .. attribute:: map_request
                                
                                	Map\-Request processing options
                                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_request = Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest()
                                    self.map_request.parent = self
                                    self._children_name_map["map_request"] = "map-request"
                                    self._segment_path = lambda: "map-resolver"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver, [], name, value)


                                class MapRequest(Entity):
                                    """
                                    Map\-Request processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest, self).__init__()

                                        self.yang_name = "map-request"
                                        self.yang_parent_name = "map-resolver"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-request"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/map-resolver/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	Influence which source RLOCs map requests are accepted from
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/map-resolver/map-request/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            Influence which source RLOCs map requests are accepted from
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.List>`
                                            
                                            .. attribute:: registered
                                            
                                            	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"

                                                self.registered = Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered()
                                                self.registered.parent = self
                                                self._children_name_map["registered"] = "registered"
                                                self._segment_path = lambda: "source"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/map-resolver/map-request/validate/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                            class Registered(Entity):
                                                """
                                                ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                                
                                                .. attribute:: list
                                                
                                                	Define allowed prefixes using an ip[v6] prefix list
                                                	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                    self.yang_name = "registered"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                    self._leafs = OrderedDict()

                                                    self.list = Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                    self.list.parent = self
                                                    self._children_name_map["list"] = "list"
                                                    self._segment_path = lambda: "registered"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                                class List(Entity):
                                                    """
                                                    Define allowed prefixes using an ip[v6] prefix list
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 prefixes
                                                    	**type**\: str
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 prefixes
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                        self.yang_name = "list"
                                                        self.yang_parent_name = "registered"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "list"
                                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                            class MapServer(Entity):
                                """
                                Configures a LISP Map Server (MS)
                                
                                .. attribute:: map_register
                                
                                	Map\-Register processing options
                                	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_register = Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister()
                                    self.map_register.parent = self
                                    self._children_name_map["map_register"] = "map-register"
                                    self._segment_path = lambda: "map-server"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer, [], name, value)


                                class MapRegister(Entity):
                                    """
                                    Map\-Register processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister, self).__init__()

                                        self.yang_name = "map-register"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-register"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/map-server/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	RLOC Source IP address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-register"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/map-server/map-register/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            RLOC Source IP address
                                            
                                            .. attribute:: allowed_locator
                                            
                                            	Against sites' allowed\-locators policy
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                                ])
                                                self.allowed_locator = None
                                                self._segment_path = lambda: "source"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/map-server/map-register/validate/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Default_.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/default/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class Encapsulation(Entity):
                            """
                            Select encapsulation type for data packets
                            
                            .. attribute:: vxlan
                            
                            	Use VXLAN encapsulation for data packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                ])
                                self.vxlan = None
                                self._segment_path = lambda: "encapsulation"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Encapsulation, ['vxlan'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Default.Service.Ethernet.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.Lisp.Default.Service.Ethernet.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/database-mapping/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Service.Ethernet.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/itr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.Lisp.Default.Service.Ethernet.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/map-resolver/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/map-resolver/map-request/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/map-resolver/map-request/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/map-server/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/map-server/map-register/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/map-server/map-register/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Service.Ethernet.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/service/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                class Encapsulation(Entity):
                    """
                    Select encapsulation type for data packets
                    
                    .. attribute:: vxlan
                    
                    	Use VXLAN encapsulation for data packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Encapsulation, self).__init__()

                        self.yang_name = "encapsulation"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                        ])
                        self.vxlan = None
                        self._segment_path = lambda: "encapsulation"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Encapsulation, ['vxlan'], name, value)


                class LocatorSet(Entity):
                    """
                    Configure a named locator set
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: auto_discover_rlocs
                    
                    	Auto discover locators registered by other xTRs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipv4_interface
                    
                    	Use IPv4 address of interface as locator
                    	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.LocatorSet.IPv4Interface>`
                    
                    .. attribute:: ipv6_interface
                    
                    	Use IPv6 address of interface as locator
                    	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.LocatorSet.IPv6Interface>`
                    
                    .. attribute:: ip_address
                    
                    	Use IPv6 address of interface as locator
                    	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.LocatorSet.IpAddress>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.LocatorSet, self).__init__()

                        self.yang_name = "locator-set"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.LocatorSet.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.LocatorSet.IPv6Interface)), ("ip-address", ("ip_address", Native.Router.Lisp.Default.LocatorSet.IpAddress))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                        ])
                        self.name = None
                        self.auto_discover_rlocs = None

                        self.ipv4_interface = YList(self)
                        self.ipv6_interface = YList(self)
                        self.ip_address = YList(self)
                        self._segment_path = lambda: "locator-set" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.LocatorSet, ['name', 'auto_discover_rlocs'], name, value)


                    class IPv4Interface(Entity):
                        """
                        Use IPv4 address of interface as locator
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: priority
                        
                        	Configures which Locators from a set are preferred
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: weight
                        
                        	Traffic load\-spreading among Locators
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.LocatorSet.IPv4Interface, self).__init__()

                            self.yang_name = "IPv4-interface"
                            self.yang_parent_name = "locator-set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                            ])
                            self.name = None
                            self.priority = None
                            self.weight = None
                            self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.LocatorSet.IPv4Interface, ['name', 'priority', 'weight'], name, value)


                    class IPv6Interface(Entity):
                        """
                        Use IPv6 address of interface as locator
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: priority
                        
                        	Configures which Locators from a set are preferred
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: weight
                        
                        	Traffic load\-spreading among Locators
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.LocatorSet.IPv6Interface, self).__init__()

                            self.yang_name = "IPv6-interface"
                            self.yang_parent_name = "locator-set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                            ])
                            self.name = None
                            self.priority = None
                            self.weight = None
                            self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.LocatorSet.IPv6Interface, ['name', 'priority', 'weight'], name, value)


                    class IpAddress(Entity):
                        """
                        Use IPv6 address of interface as locator
                        
                        .. attribute:: ip  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	Configures which Locators from a set are preferred
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: weight
                        
                        	Traffic load\-spreading among Locators
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.LocatorSet.IpAddress, self).__init__()

                            self.yang_name = "ip-address"
                            self.yang_parent_name = "locator-set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                            ])
                            self.ip = None
                            self.priority = None
                            self.weight = None
                            self._segment_path = lambda: "ip-address" + "[ip='" + str(self.ip) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.LocatorSet.IpAddress, ['ip', 'priority', 'weight'], name, value)


                class Locator(Entity):
                    """
                    Locator configuration
                    
                    .. attribute:: default_set
                    
                    	Specify a default locator\-set
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Locator, self).__init__()

                        self.yang_name = "locator"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default_set', (YLeaf(YType.str, 'default-set'), ['str'])),
                        ])
                        self.default_set = None
                        self._segment_path = lambda: "locator"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Locator, ['default_set'], name, value)


                class LocatorScope(Entity):
                    """
                    Configure a locator scope
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: rloc_prefix
                    
                    	RLOC prefix to check against ITR RLOC and ETR RLOC
                    	**type**\: union of the below types:
                    
                    		**type**\: list of str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                    
                    		**type**\: list of str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    .. attribute:: rtr_locator_set
                    
                    	Locator\-set of RTR to use in proxy reply for disjoint/cross AF RLOC
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.LocatorScope, self).__init__()

                        self.yang_name = "locator-scope"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('rloc_prefix', (YLeafList(YType.str, 'rloc-prefix'), ['str','str'])),
                            ('rtr_locator_set', (YLeafList(YType.str, 'rtr-locator-set'), ['str'])),
                        ])
                        self.name = None
                        self.rloc_prefix = []
                        self.rtr_locator_set = []
                        self._segment_path = lambda: "locator-scope" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.LocatorScope, ['name', 'rloc_prefix', 'rtr_locator_set'], name, value)


                class PrefixList(Entity):
                    """
                    Configure a named prefix list
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: ipv4_prefix
                    
                    	IPv4 EID\-prefix
                    	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.PrefixList.Ipv4Prefix>`
                    
                    .. attribute:: ipv6_prefix
                    
                    	IPv6 EID\-prefix
                    	**type**\: list of  		 :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.PrefixList.Ipv6Prefix>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.PrefixList, self).__init__()

                        self.yang_name = "prefix-list"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.Lisp.Default.PrefixList.Ipv4Prefix)), ("ipv6-prefix", ("ipv6_prefix", Native.Router.Lisp.Default.PrefixList.Ipv6Prefix))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.ipv4_prefix = YList(self)
                        self.ipv6_prefix = YList(self)
                        self._segment_path = lambda: "prefix-list" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.PrefixList, ['name'], name, value)


                    class Ipv4Prefix(Entity):
                        """
                        IPv4 EID\-prefix
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.PrefixList.Ipv4Prefix, self).__init__()

                            self.yang_name = "ipv4-prefix"
                            self.yang_parent_name = "prefix-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ])
                            self.prefix = None
                            self._segment_path = lambda: "ipv4-prefix" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.PrefixList.Ipv4Prefix, ['prefix'], name, value)


                    class Ipv6Prefix(Entity):
                        """
                        IPv6 EID\-prefix
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.PrefixList.Ipv6Prefix, self).__init__()

                            self.yang_name = "ipv6-prefix"
                            self.yang_parent_name = "prefix-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ])
                            self.prefix = None
                            self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.PrefixList.Ipv6Prefix, ['prefix'], name, value)


                class InstanceContainer(Entity):
                    """
                    EID instance\-ID
                    
                    .. attribute:: instance_list
                    
                    	
                    	**type**\: list of  		 :py:class:`InstanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.InstanceContainer, self).__init__()

                        self.yang_name = "instance-container"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("instance-list", ("instance_list", Native.Router.Lisp.Default.InstanceContainer.InstanceList))])
                        self._leafs = OrderedDict()

                        self.instance_list = YList(self)
                        self._segment_path = lambda: "instance-container"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer, [], name, value)


                    class InstanceList(Entity):
                        """
                        
                        
                        .. attribute:: instance_id  (key)
                        
                        	EID instance\-ID
                        	**type**\: int
                        
                        	**range:** 0..16777214
                        
                        .. attribute:: default
                        
                        	
                        	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_>`
                        
                        .. attribute:: decapsulation
                        
                        	Decapsulation behavior (e.g. filters)
                        	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation>`
                        
                        .. attribute:: disable_ttl_propagate
                        
                        	Disable ttl propagation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dynamic_eid
                        
                        	Configure a dynamic EID
                        	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid>`
                        
                        .. attribute:: loc_reach_algorithm
                        
                        	Configure locator reachability algorithm
                        	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.LocReachAlgorithm>`
                        
                        .. attribute:: map_server
                        
                        	Map\-Server commands
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer>`
                        
                        .. attribute:: other_xtr_probe
                        
                        	Configure parameters for probing of other xTRs in our site
                        	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.OtherXtrProbe>`
                        
                        .. attribute:: remote_rloc_probe
                        
                        	Configure parameters for probing of remote RLOCs
                        	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.RemoteRlocProbe>`
                        
                        .. attribute:: service
                        
                        	Configure lisp service type
                        	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList, self).__init__()

                            self.yang_name = "instance-list"
                            self.yang_parent_name = "instance-container"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['instance_id']
                            self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_)), ("decapsulation", ("decapsulation", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation)), ("dynamic-eid", ("dynamic_eid", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.Lisp.Default.InstanceContainer.InstanceList.LocReachAlgorithm)), ("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.Lisp.Default.InstanceContainer.InstanceList.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.Lisp.Default.InstanceContainer.InstanceList.RemoteRlocProbe)), ("service", ("service", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service))])
                            self._leafs = OrderedDict([
                                ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                            ])
                            self.instance_id = None
                            self.disable_ttl_propagate = None

                            self.default = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"

                            self.decapsulation = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation()
                            self.decapsulation.parent = self
                            self._children_name_map["decapsulation"] = "decapsulation"

                            self.loc_reach_algorithm = Native.Router.Lisp.Default.InstanceContainer.InstanceList.LocReachAlgorithm()
                            self.loc_reach_algorithm.parent = self
                            self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                            self.map_server = Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer()
                            self.map_server.parent = self
                            self._children_name_map["map_server"] = "map-server"

                            self.other_xtr_probe = Native.Router.Lisp.Default.InstanceContainer.InstanceList.OtherXtrProbe()
                            self.other_xtr_probe.parent = self
                            self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                            self.remote_rloc_probe = Native.Router.Lisp.Default.InstanceContainer.InstanceList.RemoteRlocProbe()
                            self.remote_rloc_probe.parent = self
                            self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                            self.service = None
                            self._children_name_map["service"] = "service"

                            self.dynamic_eid = YList(self)
                            self._segment_path = lambda: "instance-list" + "[instance-id='" + str(self.instance_id) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/instance-container/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList, ['instance_id', 'disable_ttl_propagate'], name, value)


                        class Default_(Entity):
                            """
                            
                            
                            .. attribute:: decapsulation
                            
                            	Decapsulation behavior (e.g. filters)
                            	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation>`
                            
                            .. attribute:: disable_ttl_propagate
                            
                            	Disable ttl propagation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dynamic_eid
                            
                            	Configure a dynamic EID
                            	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid>`
                            
                            .. attribute:: loc_reach_algorithm
                            
                            	Configure locator reachability algorithm
                            	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm>`
                            
                            .. attribute:: map_server
                            
                            	Map\-Server commands
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer>`
                            
                            .. attribute:: other_xtr_probe
                            
                            	Configure parameters for probing of other xTRs in our site
                            	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.OtherXtrProbe>`
                            
                            .. attribute:: remote_rloc_probe
                            
                            	Configure parameters for probing of remote RLOCs
                            	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.RemoteRlocProbe>`
                            
                            .. attribute:: service
                            
                            	Configure lisp service type
                            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("decapsulation", ("decapsulation", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation)), ("dynamic-eid", ("dynamic_eid", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm)), ("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.RemoteRlocProbe)), ("service", ("service", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service))])
                                self._leafs = OrderedDict([
                                    ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                                ])
                                self.disable_ttl_propagate = None

                                self.decapsulation = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation()
                                self.decapsulation.parent = self
                                self._children_name_map["decapsulation"] = "decapsulation"

                                self.loc_reach_algorithm = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm()
                                self.loc_reach_algorithm.parent = self
                                self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                                self.map_server = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer()
                                self.map_server.parent = self
                                self._children_name_map["map_server"] = "map-server"

                                self.other_xtr_probe = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.OtherXtrProbe()
                                self.other_xtr_probe.parent = self
                                self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                                self.remote_rloc_probe = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.RemoteRlocProbe()
                                self.remote_rloc_probe.parent = self
                                self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                                self.service = None
                                self._children_name_map["service"] = "service"

                                self.dynamic_eid = YList(self)
                                self._segment_path = lambda: "default"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_, ['disable_ttl_propagate'], name, value)


                            class Decapsulation(Entity):
                                """
                                Decapsulation behavior (e.g. filters)
                                
                                .. attribute:: filter
                                
                                	Filters traffic
                                	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation, self).__init__()

                                    self.yang_name = "decapsulation"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("filter", ("filter", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter))])
                                    self._leafs = OrderedDict()

                                    self.filter = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter()
                                    self.filter.parent = self
                                    self._children_name_map["filter"] = "filter"
                                    self._segment_path = lambda: "decapsulation"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation, [], name, value)


                                class Filter(Entity):
                                    """
                                    Filters traffic
                                    
                                    .. attribute:: rloc
                                    
                                    	Filter based on Routing Locator (RLOC) in packet header
                                    	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter, self).__init__()

                                        self.yang_name = "filter"
                                        self.yang_parent_name = "decapsulation"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc))])
                                        self._leafs = OrderedDict()

                                        self.rloc = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc()
                                        self.rloc.parent = self
                                        self._children_name_map["rloc"] = "rloc"
                                        self._segment_path = lambda: "filter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter, [], name, value)


                                    class Rloc(Entity):
                                        """
                                        Filter based on Routing Locator (RLOC) in packet header
                                        
                                        .. attribute:: source
                                        
                                        	Filters traffic based on RLOC source address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc, self).__init__()

                                            self.yang_name = "rloc"
                                            self.yang_parent_name = "filter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "rloc"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc, [], name, value)


                                        class Source(Entity):
                                            """
                                            Filters traffic based on RLOC source address
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator\-set Name
                                            	**type**\: str
                                            
                                            .. attribute:: member
                                            
                                            	Members learned from map\-server
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "rloc"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.member = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                            class DynamicEid(Entity):
                                """
                                Configure a dynamic EID
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: database_mapping
                                
                                	Configures EID\-prefix and locator\-set for dynamic\-EID
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping>`
                                
                                .. attribute:: eid_notify
                                
                                	Configure options for sending/receiving EID\-notify
                                	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify>`
                                
                                .. attribute:: map_notify_group
                                
                                	Multicast group which to send map\-notifies to
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid, self).__init__()

                                    self.yang_name = "dynamic-eid"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                                    ])
                                    self.name = None
                                    self.map_notify_group = None

                                    self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.eid_notify = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify()
                                    self.eid_notify.parent = self
                                    self._children_name_map["eid_notify"] = "eid-notify"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid, ['name', 'map_notify_group'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures EID\-prefix and locator\-set for dynamic\-EID
                                    
                                    .. attribute:: ipv4_prefix
                                    
                                    	IPv4 EID\-prefix for dynamic\-EID
                                    	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping.Ipv4Prefix>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "dynamic-eid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping.Ipv4Prefix))])
                                        self._leafs = OrderedDict()

                                        self.ipv4_prefix = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping, [], name, value)


                                    class Ipv4Prefix(Entity):
                                        """
                                        IPv4 EID\-prefix for dynamic\-EID
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping.Ipv4Prefix, self).__init__()

                                            self.yang_name = "ipv4-prefix"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.eid_prefix = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "ipv4-prefix" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping.Ipv4Prefix, ['eid_prefix', 'locator_set'], name, value)


                                class EidNotify(Entity):
                                    """
                                    Configure options for sending/receiving EID\-notify
                                    
                                    .. attribute:: authentication_key
                                    
                                    	Authentication key used for validating received EID\-notify
                                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.AuthenticationKey>`
                                    
                                    .. attribute:: gateway_key
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify, self).__init__()

                                        self.yang_name = "eid-notify"
                                        self.yang_parent_name = "dynamic-eid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey))])
                                        self._leafs = OrderedDict()

                                        self.authentication_key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.AuthenticationKey()
                                        self.authentication_key.parent = self
                                        self._children_name_map["authentication_key"] = "authentication-key"

                                        self.gateway_key = YList(self)
                                        self._segment_path = lambda: "eid-notify"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify, [], name, value)


                                    class AuthenticationKey(Entity):
                                        """
                                        Authentication key used for validating received EID\-notify
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: key_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: key_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: key_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                            self.yang_name = "authentication-key"
                                            self.yang_parent_name = "eid-notify"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                                ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                                ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.key_0 = None
                                            self.key_6 = None
                                            self.key_7 = None
                                            self._segment_path = lambda: "authentication-key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                                    class GatewayKey(Entity):
                                        """
                                        
                                        
                                        .. attribute:: gateway_ip  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                            self.yang_name = "gateway-key"
                                            self.yang_parent_name = "eid-notify"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['gateway_ip']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key))])
                                            self._leafs = OrderedDict([
                                                ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                            ])
                                            self.gateway_ip = None

                                            self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey, ['gateway_ip'], name, value)


                                        class Key(Entity):
                                            """
                                            
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "gateway-key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction')])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, ['unc_pwd', 'hash_function'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction')])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0, ['ak_0', 'hash_function'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction')])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6, ['ak_6', 'hash_function'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "dynamic-eid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                            class LocReachAlgorithm(Entity):
                                """
                                Configure locator reachability algorithm
                                
                                .. attribute:: lsb_reports
                                
                                	Configure data packet LSB report handling
                                	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm.LsbReports>`
                                
                                .. attribute:: rloc_probing
                                
                                	Probe high priority RLOCs with Map\-Requests as last resort
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm, self).__init__()

                                    self.yang_name = "loc-reach-algorithm"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm.LsbReports))])
                                    self._leafs = OrderedDict([
                                        ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                                    ])
                                    self.rloc_probing = None

                                    self.lsb_reports = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm.LsbReports()
                                    self.lsb_reports.parent = self
                                    self._children_name_map["lsb_reports"] = "lsb-reports"
                                    self._segment_path = lambda: "loc-reach-algorithm"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm, ['rloc_probing'], name, value)


                                class LsbReports(Entity):
                                    """
                                    Configure data packet LSB report handling
                                    
                                    .. attribute:: do_not_transmit
                                    
                                    	Force the setting of the encapsulation header L bit to zero
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore data packet LSB reports
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm.LsbReports, self).__init__()

                                        self.yang_name = "lsb-reports"
                                        self.yang_parent_name = "loc-reach-algorithm"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ])
                                        self.do_not_transmit = None
                                        self.ignore = None
                                        self._segment_path = lambda: "lsb-reports"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                            class MapServer(Entity):
                                """
                                Map\-Server commands
                                
                                .. attribute:: rloc
                                
                                	EID instance RLOC membership
                                	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc>`
                                
                                .. attribute:: site_registration
                                
                                	Map\-server site registration options
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.SiteRegistration>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.SiteRegistration))])
                                    self._leafs = OrderedDict()

                                    self.rloc = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc()
                                    self.rloc.parent = self
                                    self._children_name_map["rloc"] = "rloc"

                                    self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"
                                    self._segment_path = lambda: "map-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer, [], name, value)


                                class Rloc(Entity):
                                    """
                                    EID instance RLOC membership
                                    
                                    .. attribute:: members
                                    
                                    	EID instance RLOC membership
                                    	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc, self).__init__()

                                        self.yang_name = "rloc"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("members", ("members", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members))])
                                        self._leafs = OrderedDict()

                                        self.members = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members()
                                        self.members.parent = self
                                        self._children_name_map["members"] = "members"
                                        self._segment_path = lambda: "rloc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc, [], name, value)


                                    class Members(Entity):
                                        """
                                        EID instance RLOC membership
                                        
                                        .. attribute:: distribute
                                        
                                        	EID instance RLOC membership distribution
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: modify_discovered
                                        
                                        	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                        	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members, self).__init__()

                                            self.yang_name = "members"
                                            self.yang_parent_name = "rloc"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered))])
                                            self._leafs = OrderedDict([
                                                ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                            ])
                                            self.distribute = None

                                            self.modify_discovered = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered()
                                            self.modify_discovered.parent = self
                                            self._children_name_map["modify_discovered"] = "modify-discovered"
                                            self._segment_path = lambda: "members"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members, ['distribute'], name, value)


                                        class ModifyDiscovered(Entity):
                                            """
                                            Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                            
                                            .. attribute:: operator
                                            
                                            	
                                            	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set from which to get member RLOC addresses
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                                self.yang_name = "modify-discovered"
                                                self.yang_parent_name = "members"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.operator = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "modify-discovered"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                            class Operator(Enum):
                                                """
                                                Operator (Enum Class)

                                                .. data:: add = 0

                                                .. data:: override = 1

                                                """

                                                add = Enum.YLeaf(0, "add")

                                                override = Enum.YLeaf(1, "override")



                                class SiteRegistration(Entity):
                                    """
                                    Map\-server site registration options
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations as a result of accept\-more\-specifics
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class OtherXtrProbe(Entity):
                                """
                                Configure parameters for probing of other xTRs in our site
                                
                                .. attribute:: period
                                
                                	Period between probes in seconds
                                	**type**\: int
                                
                                	**range:** 5..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.OtherXtrProbe, self).__init__()

                                    self.yang_name = "other-xtr-probe"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                    ])
                                    self.period = None
                                    self._segment_path = lambda: "other-xtr-probe"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.OtherXtrProbe, ['period'], name, value)


                            class RemoteRlocProbe(Entity):
                                """
                                Configure parameters for probing of remote RLOCs
                                
                                .. attribute:: on_membership_change
                                
                                	Trigger probing upon membership changes for remote RLOC
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: on_route_change
                                
                                	Trigger probing upon routing changes for remote RLOC
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.RemoteRlocProbe, self).__init__()

                                    self.yang_name = "remote-rloc-probe"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                        ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                                    ])
                                    self.on_membership_change = None
                                    self.on_route_change = None
                                    self._segment_path = lambda: "remote-rloc-probe"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                            class Service(Entity):
                                """
                                Configure lisp service type
                                
                                .. attribute:: ipv4
                                
                                	
                                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ipv6
                                
                                	
                                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ethernet
                                
                                	
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service, self).__init__()

                                    self.yang_name = "service"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.ipv4 = None
                                    self._children_name_map["ipv4"] = "ipv4"

                                    self.ipv6 = None
                                    self._children_name_map["ipv6"] = "ipv6"

                                    self.ethernet = None
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._segment_path = lambda: "service"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service, [], name, value)


                                class Ipv4(Entity):
                                    """
                                    
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_>`
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4, self).__init__()

                                        self.yang_name = "ipv4"
                                        self.yang_parent_name = "service"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_)), ("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EidTable)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt)), ("distance", ("distance", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import)), ("route-import", ("route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.default = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "ipv4"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class Default_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_table
                                        
                                        	Bind an eid\-table
                                        	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EidTable>`
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr>`
                                        
                                        .. attribute:: itr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ItrEnable>`
                                        
                                        .. attribute:: etr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EtrEnable>`
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr>`
                                        
                                        .. attribute:: map_cache_limit
                                        
                                        	Configures maximum size of map\-cache
                                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCacheLimit>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Site registrations configuration for a given instance\-id
                                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SiteRegistration>`
                                        
                                        .. attribute:: solicit_map_request
                                        
                                        	Configure Solicit\-Map\-Request handling
                                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SolicitMapRequest>`
                                        
                                        .. attribute:: alt
                                        
                                        	LISP Alternative Topology, LISP\-ALT
                                        	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt>`
                                        
                                        .. attribute:: alt_vrf
                                        
                                        	Activate LISP\-ALT functionality in VRF
                                        	**type**\: str
                                        
                                        	**status**\: deprecated
                                        
                                        .. attribute:: distance
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Distance>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Address family specific map cache configuration
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache>`
                                        
                                        .. attribute:: map_cache_persistent
                                        
                                        	Dump map\-cache onto flash, making it persistent across reboots
                                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCachePersistent>`
                                        
                                        .. attribute:: proxy_etr
                                        
                                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: proxy_itr
                                        
                                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ProxyItr>`
                                        
                                        .. attribute:: route_export
                                        
                                        	Export routes into RIB from LISP
                                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteExport>`
                                        
                                        .. attribute:: sgt
                                        
                                        	Enable security group tag propagation in LISP encapsulated traffic
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: use_petr
                                        
                                        	Encapsulate to Proxy ETR when matching forward\-native entry
                                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr>`
                                        
                                        .. attribute:: import_
                                        
                                        	Redistribute LISP states internally
                                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import>`
                                        
                                        .. attribute:: route_import
                                        
                                        	Import RIB routes by a routing protocol into LISP
                                        	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport>`
                                        
                                        .. attribute:: map_request_source
                                        
                                        	Configures inner header source address in Map\-Request message
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping
                                        
                                        	Configures Locator addresses for an ETR
                                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EidTable)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt)), ("distance", ("distance", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import)), ("route-import", ("route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping))])
                                            self._leafs = OrderedDict([
                                                ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                            ])
                                            self.alt_vrf = None
                                            self.proxy_etr = None
                                            self.sgt = None
                                            self.map_request_source = None

                                            self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EidTable()
                                            self.eid_table.parent = self
                                            self._children_name_map["eid_table"] = "eid-table"

                                            self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr()
                                            self.itr.parent = self
                                            self._children_name_map["itr"] = "itr"

                                            self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ItrEnable()
                                            self.itr_enable.parent = self
                                            self._children_name_map["itr_enable"] = "itr-enable"

                                            self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EtrEnable()
                                            self.etr_enable.parent = self
                                            self._children_name_map["etr_enable"] = "etr-enable"

                                            self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr()
                                            self.etr.parent = self
                                            self._children_name_map["etr"] = "etr"

                                            self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCacheLimit()
                                            self.map_cache_limit.parent = self
                                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                            self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SiteRegistration()
                                            self.site_registration.parent = self
                                            self._children_name_map["site_registration"] = "site-registration"

                                            self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SolicitMapRequest()
                                            self.solicit_map_request.parent = self
                                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                            self.alt = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt()
                                            self.alt.parent = self
                                            self._children_name_map["alt"] = "alt"

                                            self.distance = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Distance()
                                            self.distance.parent = self
                                            self._children_name_map["distance"] = "distance"

                                            self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.map_cache_persistent = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCachePersistent()
                                            self.map_cache_persistent.parent = self
                                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                            self.proxy_itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ProxyItr()
                                            self.proxy_itr.parent = self
                                            self._children_name_map["proxy_itr"] = "proxy-itr"

                                            self.route_export = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteExport()
                                            self.route_export.parent = self
                                            self._children_name_map["route_export"] = "route-export"

                                            self.import_ = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"

                                            self.route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport()
                                            self.route_import.parent = self
                                            self._children_name_map["route_import"] = "route-import"

                                            self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping()
                                            self.database_mapping.parent = self
                                            self._children_name_map["database_mapping"] = "database-mapping"

                                            self.use_petr = YList(self)
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                        class EidTable(Entity):
                                            """
                                            Bind an eid\-table
                                            
                                            .. attribute:: vrf_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: vrf
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EidTable, self).__init__()

                                                self.yang_name = "eid-table"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                ])
                                                self.vrf_name = None
                                                self.default = None
                                                self.vrf = None
                                                self._segment_path = lambda: "eid-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                        class Itr(Entity):
                                            """
                                            Configures a LISP Ingress Tunnel Router (ITR)
                                            
                                            .. attribute:: map_resolver
                                            
                                            	Configures map\-resolver address for sending Map\-Requests
                                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr.MapResolver>`
                                            
                                            .. attribute:: nmr_ttl
                                            
                                            	verride negative map\-reply TTL for site EID
                                            	**type**\: int
                                            
                                            	**range:** 1..900
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr, self).__init__()

                                                self.yang_name = "itr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr.MapResolver))])
                                                self._leafs = OrderedDict([
                                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                                ])
                                                self.nmr_ttl = None

                                                self.map_resolver = YList(self)
                                                self._segment_path = lambda: "itr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr, ['nmr_ttl'], name, value)


                                            class MapResolver(Entity):
                                                """
                                                Configures map\-resolver address for sending Map\-Requests
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr.MapResolver, self).__init__()

                                                    self.yang_name = "map-resolver"
                                                    self.yang_parent_name = "itr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                        class ItrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: itr
                                            
                                            	Configures a LISP Ingress Tunnel Router (ITR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ItrEnable, self).__init__()

                                                self.yang_name = "itr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                                ])
                                                self.itr = None
                                                self._segment_path = lambda: "itr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ItrEnable, ['itr'], name, value)


                                        class EtrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr
                                            
                                            	Configures a LISP Egress Tunnel Router (ETR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EtrEnable, self).__init__()

                                                self.yang_name = "etr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                                ])
                                                self.etr = None
                                                self._segment_path = lambda: "etr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EtrEnable, ['etr'], name, value)


                                        class Etr(Entity):
                                            """
                                            Configures a LISP Egress Tunnel Router (ETR)
                                            
                                            .. attribute:: map_server
                                            
                                            	Configures map server for ETR registration
                                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer>`
                                            
                                            .. attribute:: map_cache_ttl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 60..10080
                                            
                                            .. attribute:: accept_map_request_mapping
                                            
                                            	
                                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr, self).__init__()

                                                self.yang_name = "etr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping))])
                                                self._leafs = OrderedDict([
                                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                                ])
                                                self.map_cache_ttl = None

                                                self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping()
                                                self.accept_map_request_mapping.parent = self
                                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                                self.map_server = YList(self)
                                                self._segment_path = lambda: "etr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr, ['map_cache_ttl'], name, value)


                                            class MapServer(Entity):
                                                """
                                                Configures map server for ETR registration
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: key
                                                
                                                	Authentication key used with map server
                                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key>`
                                                
                                                .. attribute:: proxy_reply
                                                
                                                	Request Map\-Server to send Map\-Replies on behalf of site
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer, self).__init__()

                                                    self.yang_name = "map-server"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key))])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.proxy_reply = None

                                                    self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key()
                                                    self.key.parent = self
                                                    self._children_name_map["key"] = "key"
                                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                                class Key(Entity):
                                                    """
                                                    Authentication key used with map server
                                                    
                                                    .. attribute:: key_pwd
                                                    
                                                    	
                                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd>`
                                                    
                                                    .. attribute:: key_0
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0>`
                                                    
                                                    .. attribute:: key_6
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6>`
                                                    
                                                    .. attribute:: key_7
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key, self).__init__()

                                                        self.yang_name = "key"
                                                        self.yang_parent_name = "map-server"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7))])
                                                        self._leafs = OrderedDict()

                                                        self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd()
                                                        self.key_pwd.parent = self
                                                        self._children_name_map["key_pwd"] = "key-pwd"

                                                        self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0()
                                                        self.key_0.parent = self
                                                        self._children_name_map["key_0"] = "key-0"

                                                        self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6()
                                                        self.key_6.parent = self
                                                        self._children_name_map["key_6"] = "key-6"

                                                        self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7()
                                                        self.key_7.parent = self
                                                        self._children_name_map["key_7"] = "key-7"
                                                        self._segment_path = lambda: "key"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key, [], name, value)


                                                    class KeyPwd(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: unc_pwd
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                            self.yang_name = "key-pwd"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.unc_pwd = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-pwd"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key0(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_0
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                            self.yang_name = "key-0"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_0 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-0"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key6(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_6
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                            self.yang_name = "key-6"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_6 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-6"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key7(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_7
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                            self.yang_name = "key-7"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_7 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-7"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                            class AcceptMapRequestMapping(Entity):
                                                """
                                                
                                                
                                                .. attribute:: accept_mappping
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: verify
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                    self.yang_name = "accept-map-request-mapping"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                    ])
                                                    self.accept_mappping = None
                                                    self.verify = None
                                                    self._segment_path = lambda: "accept-map-request-mapping"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                        class MapCacheLimit(Entity):
                                            """
                                            Configures maximum size of map\-cache
                                            
                                            .. attribute:: max_map_cache_entries
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..100000
                                            
                                            .. attribute:: reserve_list
                                            
                                            	EID\-prefixes guaranteed to be stored in map\-cache
                                            	**type**\: str
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCacheLimit, self).__init__()

                                                self.yang_name = "map-cache-limit"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.max_map_cache_entries = None
                                                self.reserve_list = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "map-cache-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                        class SiteRegistration(Entity):
                                            """
                                            Site registrations configuration for a given instance\-id
                                            
                                            .. attribute:: limit
                                            
                                            	Maximum number of site registrations
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Warning threshold to issue system logging
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SiteRegistration, self).__init__()

                                                self.yang_name = "site-registration"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.limit = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "site-registration"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                        class SolicitMapRequest(Entity):
                                            """
                                            Configure Solicit\-Map\-Request handling
                                            
                                            .. attribute:: ignore
                                            
                                            	Ignore SMR bit in incoming Map\-Requests
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: max_per_entry
                                            
                                            	Maximum number of SMRs for addresses under a map\-cache entry
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: suppression_time
                                            
                                            	How long to suppress repeated SMRs for the same address
                                            	**type**\: int
                                            
                                            	**range:** 1..600
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SolicitMapRequest, self).__init__()

                                                self.yang_name = "solicit-map-request"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                                ])
                                                self.ignore = None
                                                self.max_per_entry = None
                                                self.suppression_time = None
                                                self._segment_path = lambda: "solicit-map-request"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                        class Alt(Entity):
                                            """
                                            LISP Alternative Topology, LISP\-ALT
                                            
                                            .. attribute:: summary_route
                                            
                                            	Summary route to install into the ALT table
                                            	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt.SummaryRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt, self).__init__()

                                                self.yang_name = "alt"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt.SummaryRoute))])
                                                self._leafs = OrderedDict()

                                                self.summary_route = YList(self)
                                                self._segment_path = lambda: "alt"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt, [], name, value)


                                            class SummaryRoute(Entity):
                                                """
                                                Summary route to install into the ALT table
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                
                                                .. attribute:: route_tag
                                                
                                                	ALT RIB route tag for EID prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt.SummaryRoute, self).__init__()

                                                    self.yang_name = "summary-route"
                                                    self.yang_parent_name = "alt"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.route_tag = None
                                                    self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                        class Distance(Entity):
                                            """
                                            Administrative distance for RIB route installation
                                            
                                            .. attribute:: alt
                                            
                                            	LISP routes installed in the ALT table
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: away
                                            
                                            	Administrative distance for RIB route installation
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: dyn_eid
                                            
                                            	LISP installed routes of type dynamic\-EID
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: site_registrations
                                            
                                            	LISP installed routes of type site\-registrations
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Distance, self).__init__()

                                                self.yang_name = "distance"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                                ])
                                                self.alt = None
                                                self.away = None
                                                self.dyn_eid = None
                                                self.site_registrations = None
                                                self._segment_path = lambda: "distance"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Address family specific map cache configuration
                                            
                                            .. attribute:: eid_interface
                                            
                                            	Configures static EID\-to\-RLOC mappings for an ITR
                                            	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface>`
                                            
                                            .. attribute:: away_eids
                                            
                                            	Map cache configuration for the away table
                                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.AwayEids>`
                                            
                                            .. attribute:: site_registration
                                            
                                            	Install map cache to map request for site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.AwayEids))])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.site_registration = None

                                                self.away_eids = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.AwayEids()
                                                self.away_eids.parent = self
                                                self._children_name_map["away_eids"] = "away-eids"

                                                self.eid_interface = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache, ['site_registration'], name, value)


                                            class EidInterface(Entity):
                                                """
                                                Configures static EID\-to\-RLOC mappings for an ITR
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                
                                                .. attribute:: etr_interface_ip
                                                
                                                	
                                                	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                                
                                                .. attribute:: drop
                                                
                                                	Drop packets that match this map\-cache entry
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: map_request
                                                
                                                	Send Map\-Request for LISP destination EID
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: native_forward
                                                
                                                	Natively forward packets that match this map\-cache entry
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface, self).__init__()

                                                    self.yang_name = "eid-interface"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                        ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                        ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.drop = None
                                                    self.map_request = None
                                                    self.native_forward = None

                                                    self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                    self.etr_interface_ip.parent = self
                                                    self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                    self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                                class EtrInterfaceIp(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: etr_interface_ip_address
                                                    
                                                    	IP address of loopback or other ETR interface
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                        self.yang_name = "etr-interface-ip"
                                                        self.yang_parent_name = "eid-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ])
                                                        self.etr_interface_ip_address = None
                                                        self.priority = None
                                                        self.weight = None
                                                        self._segment_path = lambda: "etr-interface-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                            class AwayEids(Entity):
                                                """
                                                Map cache configuration for the away table
                                                
                                                .. attribute:: send_map_request
                                                
                                                	Export away table entries into the map cache with action set to send\-map\-request
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.AwayEids, self).__init__()

                                                    self.yang_name = "away-eids"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                    ])
                                                    self.send_map_request = None
                                                    self._segment_path = lambda: "away-eids"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                        class MapCachePersistent(Entity):
                                            """
                                            Dump map\-cache onto flash, making it persistent across reboots
                                            
                                            .. attribute:: interval
                                            
                                            	Interval in minutes of how often the map\-cache is saved
                                            	**type**\: int
                                            
                                            	**range:** 1..1440
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCachePersistent, self).__init__()

                                                self.yang_name = "map-cache-persistent"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                                ])
                                                self.interval = None
                                                self._segment_path = lambda: "map-cache-persistent"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCachePersistent, ['interval'], name, value)


                                        class ProxyItr(Entity):
                                            """
                                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                            
                                            .. attribute:: ipv4_addr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_addr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ProxyItr, self).__init__()

                                                self.yang_name = "proxy-itr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                                ])
                                                self.ipv4_addr = None
                                                self.ipv6_addr = None
                                                self._segment_path = lambda: "proxy-itr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                        class RouteExport(Entity):
                                            """
                                            Export routes into RIB from LISP
                                            
                                            .. attribute:: site_registrations
                                            
                                            	Export LISP site registrations to RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: away_eids
                                            
                                            	Export LISP away EIDs to RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteExport, self).__init__()

                                                self.yang_name = "route-export"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                                ])
                                                self.site_registrations = None
                                                self.away_eids = None
                                                self._segment_path = lambda: "route-export"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                        class UsePetr(Entity):
                                            """
                                            Encapsulate to Proxy ETR when matching forward\-native entry
                                            
                                            .. attribute:: locator_address  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	
                                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr.Priority>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr, self).__init__()

                                                self.yang_name = "use-petr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['locator_address']
                                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr.Priority))])
                                                self._leafs = OrderedDict([
                                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                                ])
                                                self.locator_address = None

                                                self.priority = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr.Priority()
                                                self.priority.parent = self
                                                self._children_name_map["priority"] = "priority"
                                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr, ['locator_address'], name, value)


                                            class Priority(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority_value
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr.Priority, self).__init__()

                                                    self.yang_name = "priority"
                                                    self.yang_parent_name = "use-petr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.priority_value = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "priority"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                        class Import(Entity):
                                            """
                                            Redistribute LISP states internally
                                            
                                            .. attribute:: database
                                            
                                            	Redistribute LISP internal states as database mapping
                                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.Database>`
                                            
                                            .. attribute:: prefix_list_container
                                            
                                            	Redistribute LISP internal states into LISP prefix\-list entries
                                            	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.PrefixListContainer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.PrefixListContainer))])
                                                self._leafs = OrderedDict()

                                                self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.Database()
                                                self.database.parent = self
                                                self._children_name_map["database"] = "database"

                                                self.prefix_list_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.PrefixListContainer()
                                                self.prefix_list_container.parent = self
                                                self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                                self._segment_path = lambda: "import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import, [], name, value)


                                            class Database(Entity):
                                                """
                                                Redistribute LISP internal states as database mapping
                                                
                                                .. attribute:: site_registration
                                                
                                                	Import states from site registrations
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.Database, self).__init__()

                                                    self.yang_name = "database"
                                                    self.yang_parent_name = "import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.site_registration = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "database"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                            class PrefixListContainer(Entity):
                                                """
                                                Redistribute LISP internal states into LISP prefix\-list entries
                                                
                                                .. attribute:: prefix_list
                                                
                                                	The name of the lisp prefix list
                                                	**type**\: str
                                                
                                                .. attribute:: site_registration
                                                
                                                	Import states from site registrations
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.PrefixListContainer, self).__init__()

                                                    self.yang_name = "prefix-list-container"
                                                    self.yang_parent_name = "import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ])
                                                    self.prefix_list = None
                                                    self.site_registration = None
                                                    self._segment_path = lambda: "prefix-list-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                        class RouteImport(Entity):
                                            """
                                            Import RIB routes by a routing protocol into LISP
                                            
                                            .. attribute:: database
                                            
                                            	Use RIB routes to define local EID database entries
                                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database>`
                                            
                                            .. attribute:: map_cache
                                            
                                            	Use RIB routes to define EID address space in map\-cache
                                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache>`
                                            
                                            .. attribute:: prefix_list_proto
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport, self).__init__()

                                                self.yang_name = "route-import"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto))])
                                                self._leafs = OrderedDict()

                                                self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database()
                                                self.database.parent = self
                                                self._children_name_map["database"] = "database"

                                                self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache()
                                                self.map_cache.parent = self
                                                self._children_name_map["map_cache"] = "map-cache"

                                                self.prefix_list_proto = YList(self)
                                                self._segment_path = lambda: "route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport, [], name, value)


                                            class Database(Entity):
                                                """
                                                Use RIB routes to define local EID database entries
                                                
                                                .. attribute:: application
                                                
                                                	Application Protocol
                                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application>`
                                                
                                                .. attribute:: bgp
                                                
                                                	Border Gateway Protocol (BGP)
                                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp>`
                                                
                                                .. attribute:: connected
                                                
                                                	Connected
                                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected>`
                                                
                                                .. attribute:: eigrp
                                                
                                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp>`
                                                
                                                .. attribute:: isis
                                                
                                                	ISO IS\-IS
                                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis>`
                                                
                                                .. attribute:: maximum_prefix
                                                
                                                	Maximum number of prefixes to pick up from the RIB
                                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix>`
                                                
                                                .. attribute:: nd
                                                
                                                	Neighbor Discovery
                                                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd>`
                                                
                                                .. attribute:: ospf
                                                
                                                	Open Shortest Path First (OSPF)
                                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf>`
                                                
                                                .. attribute:: static
                                                
                                                	Static routes
                                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static>`
                                                
                                                .. attribute:: rip
                                                
                                                	Routing Information Protocol (RIP)
                                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database, self).__init__()

                                                    self.yang_name = "database"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip))])
                                                    self._leafs = OrderedDict()

                                                    self.application = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application()
                                                    self.application.parent = self
                                                    self._children_name_map["application"] = "application"

                                                    self.connected = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected()
                                                    self.connected.parent = self
                                                    self._children_name_map["connected"] = "connected"

                                                    self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis()
                                                    self.isis.parent = self
                                                    self._children_name_map["isis"] = "isis"

                                                    self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix()
                                                    self.maximum_prefix.parent = self
                                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                    self.nd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd()
                                                    self.nd.parent = self
                                                    self._children_name_map["nd"] = "nd"

                                                    self.static = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static()
                                                    self.static.parent = self
                                                    self._children_name_map["static"] = "static"

                                                    self.rip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip()
                                                    self.rip.parent = self
                                                    self._children_name_map["rip"] = "rip"

                                                    self.bgp = YList(self)
                                                    self.eigrp = YList(self)
                                                    self.ospf = YList(self)
                                                    self._segment_path = lambda: "database"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database, [], name, value)


                                                class Application(Entity):
                                                    """
                                                    Application Protocol
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application, self).__init__()

                                                        self.yang_name = "application"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "application"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "application"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Bgp(Entity):
                                                    """
                                                    Border Gateway Protocol (BGP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp, self).__init__()

                                                        self.yang_name = "bgp"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "bgp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Connected(Entity):
                                                    """
                                                    Connected
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected, self).__init__()

                                                        self.yang_name = "connected"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "connected"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "connected"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Eigrp(Entity):
                                                    """
                                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                        self.yang_name = "eigrp"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "eigrp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Isis(Entity):
                                                    """
                                                    ISO IS\-IS
                                                    
                                                    .. attribute:: process_id
                                                    
                                                    	Process name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis, self).__init__()

                                                        self.yang_name = "isis"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                        ])
                                                        self.process_id = None

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "isis"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "isis"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class MaximumPrefix(Entity):
                                                    """
                                                    Maximum number of prefixes to pick up from the RIB
                                                    
                                                    .. attribute:: number
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: warning_only
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: threshold1
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: warning_only1
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                        self.yang_name = "maximum-prefix"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                        ])
                                                        self.number = None
                                                        self.warning_only = None
                                                        self.threshold = None
                                                        self.threshold1 = None
                                                        self.warning_only1 = None
                                                        self._segment_path = lambda: "maximum-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                                class Nd(Entity):
                                                    """
                                                    Neighbor Discovery
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd, self).__init__()

                                                        self.yang_name = "nd"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "nd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "nd"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Ospf(Entity):
                                                    """
                                                    Open Shortest Path First (OSPF)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf, self).__init__()

                                                        self.yang_name = "ospf"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "ospf"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Static(Entity):
                                                    """
                                                    Static routes
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static, self).__init__()

                                                        self.yang_name = "static"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "static"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "static"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Rip(Entity):
                                                    """
                                                    Routing Information Protocol (RIP)
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip, self).__init__()

                                                        self.yang_name = "rip"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "rip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "rip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MapCache(Entity):
                                                """
                                                Use RIB routes to define EID address space in map\-cache
                                                
                                                .. attribute:: application
                                                
                                                	Application Protocol
                                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: bgp
                                                
                                                	Border Gateway Protocol (BGP)
                                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp>`
                                                
                                                .. attribute:: connected
                                                
                                                	Connected
                                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: eigrp
                                                
                                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp>`
                                                
                                                .. attribute:: isis
                                                
                                                	ISO IS\-IS
                                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis>`
                                                
                                                .. attribute:: maximum_prefix
                                                
                                                	Maximum number of prefixes to pick up from the RIB
                                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix>`
                                                
                                                .. attribute:: nd
                                                
                                                	Neighbour Discovery
                                                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: ospf
                                                
                                                	Open Shortest Path First (OSPF)
                                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf>`
                                                
                                                .. attribute:: static
                                                
                                                	Static routes
                                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: rip
                                                
                                                	Routing Information Protocol (RIP)
                                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache, self).__init__()

                                                    self.yang_name = "map-cache"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip))])
                                                    self._leafs = OrderedDict()

                                                    self.application = None
                                                    self._children_name_map["application"] = "application"

                                                    self.connected = None
                                                    self._children_name_map["connected"] = "connected"

                                                    self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis()
                                                    self.isis.parent = self
                                                    self._children_name_map["isis"] = "isis"

                                                    self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix()
                                                    self.maximum_prefix.parent = self
                                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                    self.nd = None
                                                    self._children_name_map["nd"] = "nd"

                                                    self.static = None
                                                    self._children_name_map["static"] = "static"

                                                    self.rip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip()
                                                    self.rip.parent = self
                                                    self._children_name_map["rip"] = "rip"

                                                    self.bgp = YList(self)
                                                    self.eigrp = YList(self)
                                                    self.ospf = YList(self)
                                                    self._segment_path = lambda: "map-cache"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache, [], name, value)


                                                class Application(Entity):
                                                    """
                                                    Application Protocol
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application, self).__init__()

                                                        self.yang_name = "application"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "application"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "application"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                                class Bgp(Entity):
                                                    """
                                                    Border Gateway Protocol (BGP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                        self.yang_name = "bgp"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "bgp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                                class Connected(Entity):
                                                    """
                                                    Connected
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                        self.yang_name = "connected"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "connected"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "connected"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                                class Eigrp(Entity):
                                                    """
                                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                        self.yang_name = "eigrp"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "eigrp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                                class Isis(Entity):
                                                    """
                                                    ISO IS\-IS
                                                    
                                                    .. attribute:: id
                                                    
                                                    	Process name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                        self.yang_name = "isis"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "isis"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "isis"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                                class MaximumPrefix(Entity):
                                                    """
                                                    Maximum number of prefixes to pick up from the RIB
                                                    
                                                    .. attribute:: number
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: warning_only
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: threshold1
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: warning_only1
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                        self.yang_name = "maximum-prefix"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                        ])
                                                        self.number = None
                                                        self.warning_only = None
                                                        self.threshold = None
                                                        self.threshold1 = None
                                                        self.warning_only1 = None
                                                        self._segment_path = lambda: "maximum-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                                class Nd(Entity):
                                                    """
                                                    Neighbour Discovery
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                        self.yang_name = "nd"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "nd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "nd"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                                class Ospf(Entity):
                                                    """
                                                    Open Shortest Path First (OSPF)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                        self.yang_name = "ospf"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "ospf"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                                class Static(Entity):
                                                    """
                                                    Static routes
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static, self).__init__()

                                                        self.yang_name = "static"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "static"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "static"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                                class Rip(Entity):
                                                    """
                                                    Routing Information Protocol (RIP)
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                        self.yang_name = "rip"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "rip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "rip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                            class PrefixListProto(Entity):
                                                """
                                                
                                                
                                                .. attribute:: prefix_list  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: protocol  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol>`
                                                
                                                .. attribute:: bgp_id
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId>`
                                                
                                                .. attribute:: eigrp_or_ospf_id
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                                
                                                .. attribute:: isis_id
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto, self).__init__()

                                                    self.yang_name = "prefix-list-proto"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['prefix_list','protocol']
                                                    self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                        ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.prefix_list = None
                                                    self.protocol = None
                                                    self.isis_id = None
                                                    self.number = None
                                                    self.threshold = None
                                                    self.warning_only = None
                                                    self.route_map = None

                                                    self.bgp_id = YList(self)
                                                    self.eigrp_or_ospf_id = YList(self)
                                                    self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                                class Protocol(Enum):
                                                    """
                                                    Protocol (Enum Class)

                                                    .. data:: application = 0

                                                    .. data:: bgp = 1

                                                    .. data:: connected = 2

                                                    .. data:: eigrp = 3

                                                    .. data:: isis = 4

                                                    .. data:: maximum_prefix = 5

                                                    .. data:: nd = 6

                                                    .. data:: ospf = 7

                                                    .. data:: static = 8

                                                    .. data:: rip = 9

                                                    """

                                                    application = Enum.YLeaf(0, "application")

                                                    bgp = Enum.YLeaf(1, "bgp")

                                                    connected = Enum.YLeaf(2, "connected")

                                                    eigrp = Enum.YLeaf(3, "eigrp")

                                                    isis = Enum.YLeaf(4, "isis")

                                                    maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                    nd = Enum.YLeaf(6, "nd")

                                                    ospf = Enum.YLeaf(7, "ospf")

                                                    static = Enum.YLeaf(8, "static")

                                                    rip = Enum.YLeaf(9, "rip")



                                                class BgpId(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: bgp_id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                        self.yang_name = "bgp-id"
                                                        self.yang_parent_name = "prefix-list-proto"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['bgp_id']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.bgp_id = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                                class EigrpOrOspfId(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: int16_id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                        self.yang_name = "eigrp-or-ospf-id"
                                                        self.yang_parent_name = "prefix-list-proto"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['int16_id']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.int16_id = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                        class DatabaseMapping(Entity):
                                            """
                                            Configures Locator addresses for an ETR
                                            
                                            .. attribute:: eid_cont
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont>`
                                            
                                            .. attribute:: limit
                                            
                                            	Configures the maximum size of local EID prefixes database
                                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.Limit>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping, self).__init__()

                                                self.yang_name = "database-mapping"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.Limit))])
                                                self._leafs = OrderedDict()

                                                self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.Limit()
                                                self.limit.parent = self
                                                self._children_name_map["limit"] = "limit"

                                                self.eid_cont = YList(self)
                                                self._segment_path = lambda: "database-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping, [], name, value)


                                            class EidCont(Entity):
                                                """
                                                
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                
                                                .. attribute:: locator_set_container
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                                
                                                .. attribute:: ipv4_addrees
                                                
                                                	IPv4 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                                
                                                .. attribute:: ipv6_addrees
                                                
                                                	IPv6 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                                
                                                .. attribute:: ipv4_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                                
                                                .. attribute:: ipv6_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                                
                                                .. attribute:: auto_discover_rlocs
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont, self).__init__()

                                                    self.yang_name = "eid-cont"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                        ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.auto_discover_rlocs = None

                                                    self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                    self.locator_set_container.parent = self
                                                    self._children_name_map["locator_set_container"] = "locator-set-container"

                                                    self.ipv4_addrees = YList(self)
                                                    self.ipv6_addrees = YList(self)
                                                    self.ipv4_interface = YList(self)
                                                    self.ipv6_interface = YList(self)
                                                    self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                                class LocatorSetContainer(Entity):
                                                    """
                                                    Use locators defined by locator\-set
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Use locators defined by locator\-set
                                                    	**type**\: str
                                                    
                                                    .. attribute:: proxy
                                                    
                                                    	Enable configuration of static proxy database mapping
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                        self.yang_name = "locator-set-container"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                        ])
                                                        self.locator_set = None
                                                        self.proxy = None
                                                        self._segment_path = lambda: "locator-set-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                                class Ipv4Addrees(Entity):
                                                    """
                                                    IPv4 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                        self.yang_name = "ipv4-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv4-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class Ipv6Addrees(Entity):
                                                    """
                                                    IPv6 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                        self.yang_name = "ipv6-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv6-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv4Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                        self.yang_name = "IPv4-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv4-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv6Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                        self.yang_name = "IPv6-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv6-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Limit(Entity):
                                                """
                                                Configures the maximum size of local EID prefixes database
                                                
                                                .. attribute:: dynamic
                                                
                                                	Configures the maximum size of dynamic local EID prefixes database
                                                	**type**\: int
                                                
                                                	**range:** 1..5000
                                                
                                                .. attribute:: warning_threshold
                                                
                                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.Limit, self).__init__()

                                                    self.yang_name = "limit"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                    ])
                                                    self.dynamic = None
                                                    self.warning_threshold = None
                                                    self._segment_path = lambda: "limit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class Ipv6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_>`
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6, self).__init__()

                                        self.yang_name = "ipv6"
                                        self.yang_parent_name = "service"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_)), ("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EidTable)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt)), ("distance", ("distance", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import)), ("route-import", ("route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.default = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "ipv6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class Default_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_table
                                        
                                        	Bind an eid\-table
                                        	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EidTable>`
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr>`
                                        
                                        .. attribute:: itr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ItrEnable>`
                                        
                                        .. attribute:: etr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EtrEnable>`
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr>`
                                        
                                        .. attribute:: map_cache_limit
                                        
                                        	Configures maximum size of map\-cache
                                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCacheLimit>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Site registrations configuration for a given instance\-id
                                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SiteRegistration>`
                                        
                                        .. attribute:: solicit_map_request
                                        
                                        	Configure Solicit\-Map\-Request handling
                                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SolicitMapRequest>`
                                        
                                        .. attribute:: alt
                                        
                                        	LISP Alternative Topology, LISP\-ALT
                                        	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt>`
                                        
                                        .. attribute:: alt_vrf
                                        
                                        	Activate LISP\-ALT functionality in VRF
                                        	**type**\: str
                                        
                                        	**status**\: deprecated
                                        
                                        .. attribute:: distance
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Distance>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Address family specific map cache configuration
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache>`
                                        
                                        .. attribute:: map_cache_persistent
                                        
                                        	Dump map\-cache onto flash, making it persistent across reboots
                                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCachePersistent>`
                                        
                                        .. attribute:: proxy_etr
                                        
                                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: proxy_itr
                                        
                                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ProxyItr>`
                                        
                                        .. attribute:: route_export
                                        
                                        	Export routes into RIB from LISP
                                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteExport>`
                                        
                                        .. attribute:: sgt
                                        
                                        	Enable security group tag propagation in LISP encapsulated traffic
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: use_petr
                                        
                                        	Encapsulate to Proxy ETR when matching forward\-native entry
                                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr>`
                                        
                                        .. attribute:: import_
                                        
                                        	Redistribute LISP states internally
                                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import>`
                                        
                                        .. attribute:: route_import
                                        
                                        	Import RIB routes by a routing protocol into LISP
                                        	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport>`
                                        
                                        .. attribute:: map_request_source
                                        
                                        	Configures inner header source address in Map\-Request message
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping
                                        
                                        	Configures Locator addresses for an ETR
                                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EidTable)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt)), ("distance", ("distance", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import)), ("route-import", ("route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping))])
                                            self._leafs = OrderedDict([
                                                ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                            ])
                                            self.alt_vrf = None
                                            self.proxy_etr = None
                                            self.sgt = None
                                            self.map_request_source = None

                                            self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EidTable()
                                            self.eid_table.parent = self
                                            self._children_name_map["eid_table"] = "eid-table"

                                            self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr()
                                            self.itr.parent = self
                                            self._children_name_map["itr"] = "itr"

                                            self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ItrEnable()
                                            self.itr_enable.parent = self
                                            self._children_name_map["itr_enable"] = "itr-enable"

                                            self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EtrEnable()
                                            self.etr_enable.parent = self
                                            self._children_name_map["etr_enable"] = "etr-enable"

                                            self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr()
                                            self.etr.parent = self
                                            self._children_name_map["etr"] = "etr"

                                            self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCacheLimit()
                                            self.map_cache_limit.parent = self
                                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                            self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SiteRegistration()
                                            self.site_registration.parent = self
                                            self._children_name_map["site_registration"] = "site-registration"

                                            self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SolicitMapRequest()
                                            self.solicit_map_request.parent = self
                                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                            self.alt = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt()
                                            self.alt.parent = self
                                            self._children_name_map["alt"] = "alt"

                                            self.distance = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Distance()
                                            self.distance.parent = self
                                            self._children_name_map["distance"] = "distance"

                                            self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.map_cache_persistent = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCachePersistent()
                                            self.map_cache_persistent.parent = self
                                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                            self.proxy_itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ProxyItr()
                                            self.proxy_itr.parent = self
                                            self._children_name_map["proxy_itr"] = "proxy-itr"

                                            self.route_export = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteExport()
                                            self.route_export.parent = self
                                            self._children_name_map["route_export"] = "route-export"

                                            self.import_ = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"

                                            self.route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport()
                                            self.route_import.parent = self
                                            self._children_name_map["route_import"] = "route-import"

                                            self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping()
                                            self.database_mapping.parent = self
                                            self._children_name_map["database_mapping"] = "database-mapping"

                                            self.use_petr = YList(self)
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                        class EidTable(Entity):
                                            """
                                            Bind an eid\-table
                                            
                                            .. attribute:: vrf_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: vrf
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EidTable, self).__init__()

                                                self.yang_name = "eid-table"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                ])
                                                self.vrf_name = None
                                                self.default = None
                                                self.vrf = None
                                                self._segment_path = lambda: "eid-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                        class Itr(Entity):
                                            """
                                            Configures a LISP Ingress Tunnel Router (ITR)
                                            
                                            .. attribute:: map_resolver
                                            
                                            	Configures map\-resolver address for sending Map\-Requests
                                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr.MapResolver>`
                                            
                                            .. attribute:: nmr_ttl
                                            
                                            	verride negative map\-reply TTL for site EID
                                            	**type**\: int
                                            
                                            	**range:** 1..900
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr, self).__init__()

                                                self.yang_name = "itr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr.MapResolver))])
                                                self._leafs = OrderedDict([
                                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                                ])
                                                self.nmr_ttl = None

                                                self.map_resolver = YList(self)
                                                self._segment_path = lambda: "itr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr, ['nmr_ttl'], name, value)


                                            class MapResolver(Entity):
                                                """
                                                Configures map\-resolver address for sending Map\-Requests
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr.MapResolver, self).__init__()

                                                    self.yang_name = "map-resolver"
                                                    self.yang_parent_name = "itr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                        class ItrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: itr
                                            
                                            	Configures a LISP Ingress Tunnel Router (ITR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ItrEnable, self).__init__()

                                                self.yang_name = "itr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                                ])
                                                self.itr = None
                                                self._segment_path = lambda: "itr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ItrEnable, ['itr'], name, value)


                                        class EtrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr
                                            
                                            	Configures a LISP Egress Tunnel Router (ETR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EtrEnable, self).__init__()

                                                self.yang_name = "etr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                                ])
                                                self.etr = None
                                                self._segment_path = lambda: "etr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EtrEnable, ['etr'], name, value)


                                        class Etr(Entity):
                                            """
                                            Configures a LISP Egress Tunnel Router (ETR)
                                            
                                            .. attribute:: map_server
                                            
                                            	Configures map server for ETR registration
                                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer>`
                                            
                                            .. attribute:: map_cache_ttl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 60..10080
                                            
                                            .. attribute:: accept_map_request_mapping
                                            
                                            	
                                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr, self).__init__()

                                                self.yang_name = "etr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping))])
                                                self._leafs = OrderedDict([
                                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                                ])
                                                self.map_cache_ttl = None

                                                self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping()
                                                self.accept_map_request_mapping.parent = self
                                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                                self.map_server = YList(self)
                                                self._segment_path = lambda: "etr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr, ['map_cache_ttl'], name, value)


                                            class MapServer(Entity):
                                                """
                                                Configures map server for ETR registration
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: key
                                                
                                                	Authentication key used with map server
                                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key>`
                                                
                                                .. attribute:: proxy_reply
                                                
                                                	Request Map\-Server to send Map\-Replies on behalf of site
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer, self).__init__()

                                                    self.yang_name = "map-server"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key))])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.proxy_reply = None

                                                    self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key()
                                                    self.key.parent = self
                                                    self._children_name_map["key"] = "key"
                                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                                class Key(Entity):
                                                    """
                                                    Authentication key used with map server
                                                    
                                                    .. attribute:: key_pwd
                                                    
                                                    	
                                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd>`
                                                    
                                                    .. attribute:: key_0
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0>`
                                                    
                                                    .. attribute:: key_6
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6>`
                                                    
                                                    .. attribute:: key_7
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key, self).__init__()

                                                        self.yang_name = "key"
                                                        self.yang_parent_name = "map-server"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7))])
                                                        self._leafs = OrderedDict()

                                                        self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd()
                                                        self.key_pwd.parent = self
                                                        self._children_name_map["key_pwd"] = "key-pwd"

                                                        self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0()
                                                        self.key_0.parent = self
                                                        self._children_name_map["key_0"] = "key-0"

                                                        self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6()
                                                        self.key_6.parent = self
                                                        self._children_name_map["key_6"] = "key-6"

                                                        self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7()
                                                        self.key_7.parent = self
                                                        self._children_name_map["key_7"] = "key-7"
                                                        self._segment_path = lambda: "key"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key, [], name, value)


                                                    class KeyPwd(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: unc_pwd
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                            self.yang_name = "key-pwd"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.unc_pwd = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-pwd"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key0(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_0
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                            self.yang_name = "key-0"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_0 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-0"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key6(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_6
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                            self.yang_name = "key-6"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_6 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-6"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key7(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_7
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                            self.yang_name = "key-7"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_7 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-7"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                            class AcceptMapRequestMapping(Entity):
                                                """
                                                
                                                
                                                .. attribute:: accept_mappping
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: verify
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                    self.yang_name = "accept-map-request-mapping"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                    ])
                                                    self.accept_mappping = None
                                                    self.verify = None
                                                    self._segment_path = lambda: "accept-map-request-mapping"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                        class MapCacheLimit(Entity):
                                            """
                                            Configures maximum size of map\-cache
                                            
                                            .. attribute:: max_map_cache_entries
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..100000
                                            
                                            .. attribute:: reserve_list
                                            
                                            	EID\-prefixes guaranteed to be stored in map\-cache
                                            	**type**\: str
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCacheLimit, self).__init__()

                                                self.yang_name = "map-cache-limit"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.max_map_cache_entries = None
                                                self.reserve_list = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "map-cache-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                        class SiteRegistration(Entity):
                                            """
                                            Site registrations configuration for a given instance\-id
                                            
                                            .. attribute:: limit
                                            
                                            	Maximum number of site registrations
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Warning threshold to issue system logging
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SiteRegistration, self).__init__()

                                                self.yang_name = "site-registration"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.limit = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "site-registration"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                        class SolicitMapRequest(Entity):
                                            """
                                            Configure Solicit\-Map\-Request handling
                                            
                                            .. attribute:: ignore
                                            
                                            	Ignore SMR bit in incoming Map\-Requests
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: max_per_entry
                                            
                                            	Maximum number of SMRs for addresses under a map\-cache entry
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: suppression_time
                                            
                                            	How long to suppress repeated SMRs for the same address
                                            	**type**\: int
                                            
                                            	**range:** 1..600
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SolicitMapRequest, self).__init__()

                                                self.yang_name = "solicit-map-request"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                                ])
                                                self.ignore = None
                                                self.max_per_entry = None
                                                self.suppression_time = None
                                                self._segment_path = lambda: "solicit-map-request"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                        class Alt(Entity):
                                            """
                                            LISP Alternative Topology, LISP\-ALT
                                            
                                            .. attribute:: summary_route
                                            
                                            	Summary route to install into the ALT table
                                            	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt.SummaryRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt, self).__init__()

                                                self.yang_name = "alt"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt.SummaryRoute))])
                                                self._leafs = OrderedDict()

                                                self.summary_route = YList(self)
                                                self._segment_path = lambda: "alt"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt, [], name, value)


                                            class SummaryRoute(Entity):
                                                """
                                                Summary route to install into the ALT table
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                
                                                .. attribute:: route_tag
                                                
                                                	ALT RIB route tag for EID prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt.SummaryRoute, self).__init__()

                                                    self.yang_name = "summary-route"
                                                    self.yang_parent_name = "alt"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.route_tag = None
                                                    self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                        class Distance(Entity):
                                            """
                                            Administrative distance for RIB route installation
                                            
                                            .. attribute:: alt
                                            
                                            	LISP routes installed in the ALT table
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: away
                                            
                                            	Administrative distance for RIB route installation
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: dyn_eid
                                            
                                            	LISP installed routes of type dynamic\-EID
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: site_registrations
                                            
                                            	LISP installed routes of type site\-registrations
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Distance, self).__init__()

                                                self.yang_name = "distance"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                                ])
                                                self.alt = None
                                                self.away = None
                                                self.dyn_eid = None
                                                self.site_registrations = None
                                                self._segment_path = lambda: "distance"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Address family specific map cache configuration
                                            
                                            .. attribute:: eid_interface
                                            
                                            	Configures static EID\-to\-RLOC mappings for an ITR
                                            	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface>`
                                            
                                            .. attribute:: away_eids
                                            
                                            	Map cache configuration for the away table
                                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.AwayEids>`
                                            
                                            .. attribute:: site_registration
                                            
                                            	Install map cache to map request for site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.AwayEids))])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.site_registration = None

                                                self.away_eids = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.AwayEids()
                                                self.away_eids.parent = self
                                                self._children_name_map["away_eids"] = "away-eids"

                                                self.eid_interface = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache, ['site_registration'], name, value)


                                            class EidInterface(Entity):
                                                """
                                                Configures static EID\-to\-RLOC mappings for an ITR
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                
                                                .. attribute:: etr_interface_ip
                                                
                                                	
                                                	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                                
                                                .. attribute:: drop
                                                
                                                	Drop packets that match this map\-cache entry
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: map_request
                                                
                                                	Send Map\-Request for LISP destination EID
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: native_forward
                                                
                                                	Natively forward packets that match this map\-cache entry
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface, self).__init__()

                                                    self.yang_name = "eid-interface"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                        ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                        ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.drop = None
                                                    self.map_request = None
                                                    self.native_forward = None

                                                    self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                    self.etr_interface_ip.parent = self
                                                    self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                    self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                                class EtrInterfaceIp(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: etr_interface_ip_address
                                                    
                                                    	IP address of loopback or other ETR interface
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                        self.yang_name = "etr-interface-ip"
                                                        self.yang_parent_name = "eid-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ])
                                                        self.etr_interface_ip_address = None
                                                        self.priority = None
                                                        self.weight = None
                                                        self._segment_path = lambda: "etr-interface-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                            class AwayEids(Entity):
                                                """
                                                Map cache configuration for the away table
                                                
                                                .. attribute:: send_map_request
                                                
                                                	Export away table entries into the map cache with action set to send\-map\-request
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.AwayEids, self).__init__()

                                                    self.yang_name = "away-eids"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                    ])
                                                    self.send_map_request = None
                                                    self._segment_path = lambda: "away-eids"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                        class MapCachePersistent(Entity):
                                            """
                                            Dump map\-cache onto flash, making it persistent across reboots
                                            
                                            .. attribute:: interval
                                            
                                            	Interval in minutes of how often the map\-cache is saved
                                            	**type**\: int
                                            
                                            	**range:** 1..1440
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCachePersistent, self).__init__()

                                                self.yang_name = "map-cache-persistent"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                                ])
                                                self.interval = None
                                                self._segment_path = lambda: "map-cache-persistent"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCachePersistent, ['interval'], name, value)


                                        class ProxyItr(Entity):
                                            """
                                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                            
                                            .. attribute:: ipv4_addr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_addr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ProxyItr, self).__init__()

                                                self.yang_name = "proxy-itr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                                ])
                                                self.ipv4_addr = None
                                                self.ipv6_addr = None
                                                self._segment_path = lambda: "proxy-itr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                        class RouteExport(Entity):
                                            """
                                            Export routes into RIB from LISP
                                            
                                            .. attribute:: site_registrations
                                            
                                            	Export LISP site registrations to RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: away_eids
                                            
                                            	Export LISP away EIDs to RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteExport, self).__init__()

                                                self.yang_name = "route-export"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                                ])
                                                self.site_registrations = None
                                                self.away_eids = None
                                                self._segment_path = lambda: "route-export"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                        class UsePetr(Entity):
                                            """
                                            Encapsulate to Proxy ETR when matching forward\-native entry
                                            
                                            .. attribute:: locator_address  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	
                                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr.Priority>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr, self).__init__()

                                                self.yang_name = "use-petr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['locator_address']
                                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr.Priority))])
                                                self._leafs = OrderedDict([
                                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                                ])
                                                self.locator_address = None

                                                self.priority = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr.Priority()
                                                self.priority.parent = self
                                                self._children_name_map["priority"] = "priority"
                                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr, ['locator_address'], name, value)


                                            class Priority(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority_value
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr.Priority, self).__init__()

                                                    self.yang_name = "priority"
                                                    self.yang_parent_name = "use-petr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.priority_value = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "priority"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                        class Import(Entity):
                                            """
                                            Redistribute LISP states internally
                                            
                                            .. attribute:: database
                                            
                                            	Redistribute LISP internal states as database mapping
                                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.Database>`
                                            
                                            .. attribute:: prefix_list_container
                                            
                                            	Redistribute LISP internal states into LISP prefix\-list entries
                                            	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.PrefixListContainer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.PrefixListContainer))])
                                                self._leafs = OrderedDict()

                                                self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.Database()
                                                self.database.parent = self
                                                self._children_name_map["database"] = "database"

                                                self.prefix_list_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.PrefixListContainer()
                                                self.prefix_list_container.parent = self
                                                self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                                self._segment_path = lambda: "import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import, [], name, value)


                                            class Database(Entity):
                                                """
                                                Redistribute LISP internal states as database mapping
                                                
                                                .. attribute:: site_registration
                                                
                                                	Import states from site registrations
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.Database, self).__init__()

                                                    self.yang_name = "database"
                                                    self.yang_parent_name = "import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.site_registration = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "database"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                            class PrefixListContainer(Entity):
                                                """
                                                Redistribute LISP internal states into LISP prefix\-list entries
                                                
                                                .. attribute:: prefix_list
                                                
                                                	The name of the lisp prefix list
                                                	**type**\: str
                                                
                                                .. attribute:: site_registration
                                                
                                                	Import states from site registrations
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.PrefixListContainer, self).__init__()

                                                    self.yang_name = "prefix-list-container"
                                                    self.yang_parent_name = "import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ])
                                                    self.prefix_list = None
                                                    self.site_registration = None
                                                    self._segment_path = lambda: "prefix-list-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                        class RouteImport(Entity):
                                            """
                                            Import RIB routes by a routing protocol into LISP
                                            
                                            .. attribute:: database
                                            
                                            	Use RIB routes to define local EID database entries
                                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database>`
                                            
                                            .. attribute:: map_cache
                                            
                                            	Use RIB routes to define EID address space in map\-cache
                                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache>`
                                            
                                            .. attribute:: prefix_list_proto
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport, self).__init__()

                                                self.yang_name = "route-import"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto))])
                                                self._leafs = OrderedDict()

                                                self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database()
                                                self.database.parent = self
                                                self._children_name_map["database"] = "database"

                                                self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache()
                                                self.map_cache.parent = self
                                                self._children_name_map["map_cache"] = "map-cache"

                                                self.prefix_list_proto = YList(self)
                                                self._segment_path = lambda: "route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport, [], name, value)


                                            class Database(Entity):
                                                """
                                                Use RIB routes to define local EID database entries
                                                
                                                .. attribute:: application
                                                
                                                	Application Protocol
                                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application>`
                                                
                                                .. attribute:: bgp
                                                
                                                	Border Gateway Protocol (BGP)
                                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp>`
                                                
                                                .. attribute:: connected
                                                
                                                	Connected
                                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected>`
                                                
                                                .. attribute:: eigrp
                                                
                                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp>`
                                                
                                                .. attribute:: isis
                                                
                                                	ISO IS\-IS
                                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis>`
                                                
                                                .. attribute:: maximum_prefix
                                                
                                                	Maximum number of prefixes to pick up from the RIB
                                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix>`
                                                
                                                .. attribute:: nd
                                                
                                                	Neighbor Discovery
                                                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd>`
                                                
                                                .. attribute:: ospf
                                                
                                                	Open Shortest Path First (OSPF)
                                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf>`
                                                
                                                .. attribute:: static
                                                
                                                	Static routes
                                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static>`
                                                
                                                .. attribute:: rip
                                                
                                                	Routing Information Protocol (RIP)
                                                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database, self).__init__()

                                                    self.yang_name = "database"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip))])
                                                    self._leafs = OrderedDict()

                                                    self.application = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application()
                                                    self.application.parent = self
                                                    self._children_name_map["application"] = "application"

                                                    self.connected = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected()
                                                    self.connected.parent = self
                                                    self._children_name_map["connected"] = "connected"

                                                    self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis()
                                                    self.isis.parent = self
                                                    self._children_name_map["isis"] = "isis"

                                                    self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix()
                                                    self.maximum_prefix.parent = self
                                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                    self.nd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd()
                                                    self.nd.parent = self
                                                    self._children_name_map["nd"] = "nd"

                                                    self.static = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static()
                                                    self.static.parent = self
                                                    self._children_name_map["static"] = "static"

                                                    self.bgp = YList(self)
                                                    self.eigrp = YList(self)
                                                    self.ospf = YList(self)
                                                    self.rip = YList(self)
                                                    self._segment_path = lambda: "database"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database, [], name, value)


                                                class Application(Entity):
                                                    """
                                                    Application Protocol
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application, self).__init__()

                                                        self.yang_name = "application"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "application"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "application"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Bgp(Entity):
                                                    """
                                                    Border Gateway Protocol (BGP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp, self).__init__()

                                                        self.yang_name = "bgp"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "bgp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Connected(Entity):
                                                    """
                                                    Connected
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected, self).__init__()

                                                        self.yang_name = "connected"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "connected"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "connected"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Eigrp(Entity):
                                                    """
                                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                        self.yang_name = "eigrp"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "eigrp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Isis(Entity):
                                                    """
                                                    ISO IS\-IS
                                                    
                                                    .. attribute:: process_id
                                                    
                                                    	Process name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis, self).__init__()

                                                        self.yang_name = "isis"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                        ])
                                                        self.process_id = None

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "isis"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "isis"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class MaximumPrefix(Entity):
                                                    """
                                                    Maximum number of prefixes to pick up from the RIB
                                                    
                                                    .. attribute:: number
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: warning_only
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: threshold1
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: warning_only1
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                        self.yang_name = "maximum-prefix"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                        ])
                                                        self.number = None
                                                        self.warning_only = None
                                                        self.threshold = None
                                                        self.threshold1 = None
                                                        self.warning_only1 = None
                                                        self._segment_path = lambda: "maximum-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                                class Nd(Entity):
                                                    """
                                                    Neighbor Discovery
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd, self).__init__()

                                                        self.yang_name = "nd"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "nd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "nd"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Ospf(Entity):
                                                    """
                                                    Open Shortest Path First (OSPF)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf, self).__init__()

                                                        self.yang_name = "ospf"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "ospf"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Static(Entity):
                                                    """
                                                    Static routes
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static, self).__init__()

                                                        self.yang_name = "static"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "static"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "static"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Rip(Entity):
                                                    """
                                                    Routing Information Protocol (RIP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	User selected string identifying this process
                                                    	**type**\: str
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip, self).__init__()

                                                        self.yang_name = "rip"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "rip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MapCache(Entity):
                                                """
                                                Use RIB routes to define EID address space in map\-cache
                                                
                                                .. attribute:: application
                                                
                                                	Application Protocol
                                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: bgp
                                                
                                                	Border Gateway Protocol (BGP)
                                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp>`
                                                
                                                .. attribute:: connected
                                                
                                                	Connected
                                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: eigrp
                                                
                                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp>`
                                                
                                                .. attribute:: isis
                                                
                                                	ISO IS\-IS
                                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis>`
                                                
                                                .. attribute:: maximum_prefix
                                                
                                                	Maximum number of prefixes to pick up from the RIB
                                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix>`
                                                
                                                .. attribute:: nd
                                                
                                                	Neighbour Discovery
                                                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: ospf
                                                
                                                	Open Shortest Path First (OSPF)
                                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf>`
                                                
                                                .. attribute:: static
                                                
                                                	Static routes
                                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: rip
                                                
                                                	Routing Information Protocol (RIP)
                                                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache, self).__init__()

                                                    self.yang_name = "map-cache"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip))])
                                                    self._leafs = OrderedDict()

                                                    self.application = None
                                                    self._children_name_map["application"] = "application"

                                                    self.connected = None
                                                    self._children_name_map["connected"] = "connected"

                                                    self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis()
                                                    self.isis.parent = self
                                                    self._children_name_map["isis"] = "isis"

                                                    self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix()
                                                    self.maximum_prefix.parent = self
                                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                    self.nd = None
                                                    self._children_name_map["nd"] = "nd"

                                                    self.static = None
                                                    self._children_name_map["static"] = "static"

                                                    self.bgp = YList(self)
                                                    self.eigrp = YList(self)
                                                    self.ospf = YList(self)
                                                    self.rip = YList(self)
                                                    self._segment_path = lambda: "map-cache"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache, [], name, value)


                                                class Application(Entity):
                                                    """
                                                    Application Protocol
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application, self).__init__()

                                                        self.yang_name = "application"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "application"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "application"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                                class Bgp(Entity):
                                                    """
                                                    Border Gateway Protocol (BGP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                        self.yang_name = "bgp"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "bgp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                                class Connected(Entity):
                                                    """
                                                    Connected
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                        self.yang_name = "connected"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "connected"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "connected"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                                class Eigrp(Entity):
                                                    """
                                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                        self.yang_name = "eigrp"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "eigrp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                                class Isis(Entity):
                                                    """
                                                    ISO IS\-IS
                                                    
                                                    .. attribute:: id
                                                    
                                                    	Process name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                        self.yang_name = "isis"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "isis"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "isis"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                                class MaximumPrefix(Entity):
                                                    """
                                                    Maximum number of prefixes to pick up from the RIB
                                                    
                                                    .. attribute:: number
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: warning_only
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: threshold1
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: warning_only1
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                        self.yang_name = "maximum-prefix"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                        ])
                                                        self.number = None
                                                        self.warning_only = None
                                                        self.threshold = None
                                                        self.threshold1 = None
                                                        self.warning_only1 = None
                                                        self._segment_path = lambda: "maximum-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                                class Nd(Entity):
                                                    """
                                                    Neighbour Discovery
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                        self.yang_name = "nd"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "nd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "nd"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                                class Ospf(Entity):
                                                    """
                                                    Open Shortest Path First (OSPF)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                        self.yang_name = "ospf"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "ospf"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                                class Static(Entity):
                                                    """
                                                    Static routes
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static, self).__init__()

                                                        self.yang_name = "static"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "static"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "static"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                                class Rip(Entity):
                                                    """
                                                    Routing Information Protocol (RIP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	User selected string identifying this process
                                                    	**type**\: str
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                        self.yang_name = "rip"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "rip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                            class PrefixListProto(Entity):
                                                """
                                                
                                                
                                                .. attribute:: prefix_list  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: protocol  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol>`
                                                
                                                .. attribute:: bgp_id
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId>`
                                                
                                                .. attribute:: eigrp_or_ospf_id
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                                
                                                .. attribute:: isis_id
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto, self).__init__()

                                                    self.yang_name = "prefix-list-proto"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['prefix_list','protocol']
                                                    self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                        ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.prefix_list = None
                                                    self.protocol = None
                                                    self.isis_id = None
                                                    self.number = None
                                                    self.threshold = None
                                                    self.warning_only = None
                                                    self.route_map = None

                                                    self.bgp_id = YList(self)
                                                    self.eigrp_or_ospf_id = YList(self)
                                                    self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                                class Protocol(Enum):
                                                    """
                                                    Protocol (Enum Class)

                                                    .. data:: application = 0

                                                    .. data:: bgp = 1

                                                    .. data:: connected = 2

                                                    .. data:: eigrp = 3

                                                    .. data:: isis = 4

                                                    .. data:: maximum_prefix = 5

                                                    .. data:: nd = 6

                                                    .. data:: ospf = 7

                                                    .. data:: static = 8

                                                    .. data:: rip = 9

                                                    """

                                                    application = Enum.YLeaf(0, "application")

                                                    bgp = Enum.YLeaf(1, "bgp")

                                                    connected = Enum.YLeaf(2, "connected")

                                                    eigrp = Enum.YLeaf(3, "eigrp")

                                                    isis = Enum.YLeaf(4, "isis")

                                                    maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                    nd = Enum.YLeaf(6, "nd")

                                                    ospf = Enum.YLeaf(7, "ospf")

                                                    static = Enum.YLeaf(8, "static")

                                                    rip = Enum.YLeaf(9, "rip")



                                                class BgpId(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: bgp_id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                        self.yang_name = "bgp-id"
                                                        self.yang_parent_name = "prefix-list-proto"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['bgp_id']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.bgp_id = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                                class EigrpOrOspfId(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: int16_id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                        self.yang_name = "eigrp-or-ospf-id"
                                                        self.yang_parent_name = "prefix-list-proto"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['int16_id']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.int16_id = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                        class DatabaseMapping(Entity):
                                            """
                                            Configures Locator addresses for an ETR
                                            
                                            .. attribute:: eid_cont
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont>`
                                            
                                            .. attribute:: limit
                                            
                                            	Configures the maximum size of local EID prefixes database
                                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.Limit>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping, self).__init__()

                                                self.yang_name = "database-mapping"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.Limit))])
                                                self._leafs = OrderedDict()

                                                self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.Limit()
                                                self.limit.parent = self
                                                self._children_name_map["limit"] = "limit"

                                                self.eid_cont = YList(self)
                                                self._segment_path = lambda: "database-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping, [], name, value)


                                            class EidCont(Entity):
                                                """
                                                
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                
                                                .. attribute:: locator_set_container
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                                
                                                .. attribute:: ipv4_addrees
                                                
                                                	IPv4 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                                
                                                .. attribute:: ipv6_addrees
                                                
                                                	IPv6 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                                
                                                .. attribute:: ipv4_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                                
                                                .. attribute:: ipv6_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                                
                                                .. attribute:: auto_discover_rlocs
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont, self).__init__()

                                                    self.yang_name = "eid-cont"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                        ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.auto_discover_rlocs = None

                                                    self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                    self.locator_set_container.parent = self
                                                    self._children_name_map["locator_set_container"] = "locator-set-container"

                                                    self.ipv4_addrees = YList(self)
                                                    self.ipv6_addrees = YList(self)
                                                    self.ipv4_interface = YList(self)
                                                    self.ipv6_interface = YList(self)
                                                    self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                                class LocatorSetContainer(Entity):
                                                    """
                                                    Use locators defined by locator\-set
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Use locators defined by locator\-set
                                                    	**type**\: str
                                                    
                                                    .. attribute:: proxy
                                                    
                                                    	Enable configuration of static proxy database mapping
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                        self.yang_name = "locator-set-container"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                        ])
                                                        self.locator_set = None
                                                        self.proxy = None
                                                        self._segment_path = lambda: "locator-set-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                                class Ipv4Addrees(Entity):
                                                    """
                                                    IPv4 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                        self.yang_name = "ipv4-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv4-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class Ipv6Addrees(Entity):
                                                    """
                                                    IPv6 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                        self.yang_name = "ipv6-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv6-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv4Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                        self.yang_name = "IPv4-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv4-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv6Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                        self.yang_name = "IPv6-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv6-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Limit(Entity):
                                                """
                                                Configures the maximum size of local EID prefixes database
                                                
                                                .. attribute:: dynamic
                                                
                                                	Configures the maximum size of dynamic local EID prefixes database
                                                	**type**\: int
                                                
                                                	**range:** 1..5000
                                                
                                                .. attribute:: warning_threshold
                                                
                                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.Limit, self).__init__()

                                                    self.yang_name = "limit"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                    ])
                                                    self.dynamic = None
                                                    self.warning_threshold = None
                                                    self._segment_path = lambda: "limit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class Ethernet(Entity):
                                    """
                                    
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_>`
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EidTable>`
                                    
                                    .. attribute:: broadcast_underlay
                                    
                                    	Multicast group to use for underlay
                                    	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.BroadcastUnderlay>`
                                    
                                    .. attribute:: flood
                                    
                                    	Control flooding or local intercept of broadcast frames
                                    	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Flood>`
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SolicitMapRequest>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "service"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_)), ("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.BroadcastUnderlay)), ("flood", ("flood", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Flood)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                        ])
                                        self.map_request_source = None

                                        self.default = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.broadcast_underlay = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.BroadcastUnderlay()
                                        self.broadcast_underlay.parent = self
                                        self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                        self.flood = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Flood()
                                        self.flood.parent = self
                                        self._children_name_map["flood"] = "flood"

                                        self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"
                                        self._segment_path = lambda: "ethernet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet, ['map_request_source'], name, value)


                                    class Default_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_table
                                        
                                        	Bind an eid\-table
                                        	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EidTable>`
                                        
                                        .. attribute:: broadcast_underlay
                                        
                                        	Multicast group to use for underlay
                                        	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.BroadcastUnderlay>`
                                        
                                        .. attribute:: flood
                                        
                                        	Control flooding or local intercept of broadcast frames
                                        	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Flood>`
                                        
                                        .. attribute:: database_mapping
                                        
                                        	Configures Locator addresses for an ETR
                                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping>`
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr>`
                                        
                                        .. attribute:: itr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.ItrEnable>`
                                        
                                        .. attribute:: etr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EtrEnable>`
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr>`
                                        
                                        .. attribute:: map_cache_limit
                                        
                                        	Configures maximum size of map\-cache
                                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCacheLimit>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Site registrations configuration for a given instance\-id
                                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SiteRegistration>`
                                        
                                        .. attribute:: solicit_map_request
                                        
                                        	Configure Solicit\-Map\-Request handling
                                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SolicitMapRequest>`
                                        
                                        .. attribute:: map_request_source
                                        
                                        	Configures inner header source address in Map\-Request message
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.BroadcastUnderlay)), ("flood", ("flood", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Flood)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache))])
                                            self._leafs = OrderedDict([
                                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                            ])
                                            self.map_request_source = None

                                            self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EidTable()
                                            self.eid_table.parent = self
                                            self._children_name_map["eid_table"] = "eid-table"

                                            self.broadcast_underlay = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.BroadcastUnderlay()
                                            self.broadcast_underlay.parent = self
                                            self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                            self.flood = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Flood()
                                            self.flood.parent = self
                                            self._children_name_map["flood"] = "flood"

                                            self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping()
                                            self.database_mapping.parent = self
                                            self._children_name_map["database_mapping"] = "database-mapping"

                                            self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr()
                                            self.itr.parent = self
                                            self._children_name_map["itr"] = "itr"

                                            self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.ItrEnable()
                                            self.itr_enable.parent = self
                                            self._children_name_map["itr_enable"] = "itr-enable"

                                            self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EtrEnable()
                                            self.etr_enable.parent = self
                                            self._children_name_map["etr_enable"] = "etr-enable"

                                            self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr()
                                            self.etr.parent = self
                                            self._children_name_map["etr"] = "etr"

                                            self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCacheLimit()
                                            self.map_cache_limit.parent = self
                                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                            self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SiteRegistration()
                                            self.site_registration.parent = self
                                            self._children_name_map["site_registration"] = "site-registration"

                                            self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SolicitMapRequest()
                                            self.solicit_map_request.parent = self
                                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                            self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_, ['map_request_source'], name, value)


                                        class EidTable(Entity):
                                            """
                                            Bind an eid\-table
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN configuration
                                            	**type**\: int
                                            
                                            	**range:** 1..4094
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EidTable, self).__init__()

                                                self.yang_name = "eid-table"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                                ])
                                                self.vlan = None
                                                self._segment_path = lambda: "eid-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EidTable, ['vlan'], name, value)


                                        class BroadcastUnderlay(Entity):
                                            """
                                            Multicast group to use for underlay
                                            
                                            .. attribute:: ipv4_multicast
                                            
                                            	IPv4 multicast group address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_multicast
                                            
                                            	IPv6 multicast group address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.BroadcastUnderlay, self).__init__()

                                                self.yang_name = "broadcast-underlay"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                                    ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                                ])
                                                self.ipv4_multicast = None
                                                self.ipv6_multicast = None
                                                self._segment_path = lambda: "broadcast-underlay"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                        class Flood(Entity):
                                            """
                                            Control flooding or local intercept of broadcast frames
                                            
                                            .. attribute:: arp_nd
                                            
                                            	IPv4 ARP / IPv6 ND
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: unknown_unicast
                                            
                                            	Frames with unknown destination MAC
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Flood, self).__init__()

                                                self.yang_name = "flood"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                                    ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                                ])
                                                self.arp_nd = None
                                                self.unknown_unicast = None
                                                self._segment_path = lambda: "flood"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                        class DatabaseMapping(Entity):
                                            """
                                            Configures Locator addresses for an ETR
                                            
                                            .. attribute:: eid_cont
                                            
                                            	EID\-record for RLOC static mapping
                                            	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont>`
                                            
                                            .. attribute:: mac
                                            
                                            	L2 EID records
                                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Mac>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: limit
                                            
                                            	Configures the maximum size of local EID prefixes database
                                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Limit>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping, self).__init__()

                                                self.yang_name = "database-mapping"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Limit))])
                                                self._leafs = OrderedDict()

                                                self.mac = None
                                                self._children_name_map["mac"] = "mac"

                                                self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Limit()
                                                self.limit.parent = self
                                                self._children_name_map["limit"] = "limit"

                                                self.eid_cont = YList(self)
                                                self._segment_path = lambda: "database-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping, [], name, value)


                                            class EidCont(Entity):
                                                """
                                                EID\-record for RLOC static mapping
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	xxxx.xxxx.xxxx 48 bit mac address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                                
                                                .. attribute:: locator_set_container
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                                
                                                .. attribute:: ipv4_addrees
                                                
                                                	IPv4 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                                
                                                .. attribute:: ipv6_addrees
                                                
                                                	IPv6 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                                
                                                .. attribute:: ipv4_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                                
                                                .. attribute:: ipv6_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont, self).__init__()

                                                    self.yang_name = "eid-cont"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ])
                                                    self.eid_prefix = None

                                                    self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                    self.locator_set_container.parent = self
                                                    self._children_name_map["locator_set_container"] = "locator-set-container"

                                                    self.ipv4_addrees = YList(self)
                                                    self.ipv6_addrees = YList(self)
                                                    self.ipv4_interface = YList(self)
                                                    self.ipv6_interface = YList(self)
                                                    self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                                class LocatorSetContainer(Entity):
                                                    """
                                                    Use locators defined by locator\-set
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Use locators defined by locator\-set
                                                    	**type**\: str
                                                    
                                                    .. attribute:: proxy
                                                    
                                                    	Enable configuration of static proxy database mapping
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                        self.yang_name = "locator-set-container"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                        ])
                                                        self.locator_set = None
                                                        self.proxy = None
                                                        self._segment_path = lambda: "locator-set-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                                class Ipv4Addrees(Entity):
                                                    """
                                                    IPv4 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                        self.yang_name = "ipv4-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv4-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class Ipv6Addrees(Entity):
                                                    """
                                                    IPv6 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                        self.yang_name = "ipv6-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv6-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv4Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                        self.yang_name = "IPv4-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv4-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv6Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                        self.yang_name = "IPv6-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv6-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Mac(Entity):
                                                """
                                                L2 EID records
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Mac, self).__init__()

                                                    self.yang_name = "mac"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "mac"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Mac, ['locator_set'], name, value)


                                            class Limit(Entity):
                                                """
                                                Configures the maximum size of local EID prefixes database
                                                
                                                .. attribute:: dynamic
                                                
                                                	Configures the maximum size of dynamic local EID prefixes database
                                                	**type**\: int
                                                
                                                	**range:** 1..5000
                                                
                                                .. attribute:: warning_threshold
                                                
                                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Limit, self).__init__()

                                                    self.yang_name = "limit"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                    ])
                                                    self.dynamic = None
                                                    self.warning_threshold = None
                                                    self._segment_path = lambda: "limit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                        class Itr(Entity):
                                            """
                                            Configures a LISP Ingress Tunnel Router (ITR)
                                            
                                            .. attribute:: map_resolver
                                            
                                            	Configures map\-resolver address for sending Map\-Requests
                                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr.MapResolver>`
                                            
                                            .. attribute:: nmr_ttl
                                            
                                            	verride negative map\-reply TTL for site EID
                                            	**type**\: int
                                            
                                            	**range:** 1..900
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr, self).__init__()

                                                self.yang_name = "itr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr.MapResolver))])
                                                self._leafs = OrderedDict([
                                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                                ])
                                                self.nmr_ttl = None

                                                self.map_resolver = YList(self)
                                                self._segment_path = lambda: "itr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr, ['nmr_ttl'], name, value)


                                            class MapResolver(Entity):
                                                """
                                                Configures map\-resolver address for sending Map\-Requests
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr.MapResolver, self).__init__()

                                                    self.yang_name = "map-resolver"
                                                    self.yang_parent_name = "itr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                        class ItrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: itr
                                            
                                            	Configures a LISP Ingress Tunnel Router (ITR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.ItrEnable, self).__init__()

                                                self.yang_name = "itr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                                ])
                                                self.itr = None
                                                self._segment_path = lambda: "itr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.ItrEnable, ['itr'], name, value)


                                        class EtrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr
                                            
                                            	Configures a LISP Egress Tunnel Router (ETR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EtrEnable, self).__init__()

                                                self.yang_name = "etr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                                ])
                                                self.etr = None
                                                self._segment_path = lambda: "etr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EtrEnable, ['etr'], name, value)


                                        class Etr(Entity):
                                            """
                                            Configures a LISP Egress Tunnel Router (ETR)
                                            
                                            .. attribute:: map_server
                                            
                                            	Configures map server for ETR registration
                                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer>`
                                            
                                            .. attribute:: map_cache_ttl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 60..10080
                                            
                                            .. attribute:: accept_map_request_mapping
                                            
                                            	
                                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr, self).__init__()

                                                self.yang_name = "etr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping))])
                                                self._leafs = OrderedDict([
                                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                                ])
                                                self.map_cache_ttl = None

                                                self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping()
                                                self.accept_map_request_mapping.parent = self
                                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                                self.map_server = YList(self)
                                                self._segment_path = lambda: "etr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr, ['map_cache_ttl'], name, value)


                                            class MapServer(Entity):
                                                """
                                                Configures map server for ETR registration
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: key
                                                
                                                	Authentication key used with map server
                                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key>`
                                                
                                                .. attribute:: proxy_reply
                                                
                                                	Request Map\-Server to send Map\-Replies on behalf of site
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer, self).__init__()

                                                    self.yang_name = "map-server"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key))])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.proxy_reply = None

                                                    self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key()
                                                    self.key.parent = self
                                                    self._children_name_map["key"] = "key"
                                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                                class Key(Entity):
                                                    """
                                                    Authentication key used with map server
                                                    
                                                    .. attribute:: key_pwd
                                                    
                                                    	
                                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd>`
                                                    
                                                    .. attribute:: key_0
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0>`
                                                    
                                                    .. attribute:: key_6
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6>`
                                                    
                                                    .. attribute:: key_7
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key, self).__init__()

                                                        self.yang_name = "key"
                                                        self.yang_parent_name = "map-server"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7))])
                                                        self._leafs = OrderedDict()

                                                        self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd()
                                                        self.key_pwd.parent = self
                                                        self._children_name_map["key_pwd"] = "key-pwd"

                                                        self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0()
                                                        self.key_0.parent = self
                                                        self._children_name_map["key_0"] = "key-0"

                                                        self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6()
                                                        self.key_6.parent = self
                                                        self._children_name_map["key_6"] = "key-6"

                                                        self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7()
                                                        self.key_7.parent = self
                                                        self._children_name_map["key_7"] = "key-7"
                                                        self._segment_path = lambda: "key"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key, [], name, value)


                                                    class KeyPwd(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: unc_pwd
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                            self.yang_name = "key-pwd"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.unc_pwd = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-pwd"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key0(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_0
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                            self.yang_name = "key-0"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_0 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-0"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key6(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_6
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                            self.yang_name = "key-6"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_6 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-6"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key7(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_7
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                            self.yang_name = "key-7"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_7 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-7"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                            class AcceptMapRequestMapping(Entity):
                                                """
                                                
                                                
                                                .. attribute:: accept_mappping
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: verify
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                    self.yang_name = "accept-map-request-mapping"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                    ])
                                                    self.accept_mappping = None
                                                    self.verify = None
                                                    self._segment_path = lambda: "accept-map-request-mapping"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                        class MapCacheLimit(Entity):
                                            """
                                            Configures maximum size of map\-cache
                                            
                                            .. attribute:: max_map_cache_entries
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..100000
                                            
                                            .. attribute:: reserve_list
                                            
                                            	EID\-prefixes guaranteed to be stored in map\-cache
                                            	**type**\: str
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCacheLimit, self).__init__()

                                                self.yang_name = "map-cache-limit"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.max_map_cache_entries = None
                                                self.reserve_list = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "map-cache-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                        class SiteRegistration(Entity):
                                            """
                                            Site registrations configuration for a given instance\-id
                                            
                                            .. attribute:: limit
                                            
                                            	Maximum number of site registrations
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Warning threshold to issue system logging
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SiteRegistration, self).__init__()

                                                self.yang_name = "site-registration"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.limit = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "site-registration"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                        class SolicitMapRequest(Entity):
                                            """
                                            Configure Solicit\-Map\-Request handling
                                            
                                            .. attribute:: ignore
                                            
                                            	Ignore SMR bit in incoming Map\-Requests
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: max_per_entry
                                            
                                            	Maximum number of SMRs for addresses under a map\-cache entry
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: suppression_time
                                            
                                            	How long to suppress repeated SMRs for the same address
                                            	**type**\: int
                                            
                                            	**range:** 1..600
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SolicitMapRequest, self).__init__()

                                                self.yang_name = "solicit-map-request"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                                ])
                                                self.ignore = None
                                                self.max_per_entry = None
                                                self.suppression_time = None
                                                self._segment_path = lambda: "solicit-map-request"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: eid_cont
                                            
                                            	EID\-record for RLOC static mapping
                                            	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont))])
                                                self._leafs = OrderedDict()

                                                self.eid_cont = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache, [], name, value)


                                            class EidCont(Entity):
                                                """
                                                EID\-record for RLOC static mapping
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	xxxx.xxxx.xxxx 48 bit mac address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                                
                                                .. attribute:: etr_interface_ip
                                                
                                                	
                                                	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont, self).__init__()

                                                    self.yang_name = "eid-cont"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ])
                                                    self.eid_prefix = None

                                                    self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp()
                                                    self.etr_interface_ip.parent = self
                                                    self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                    self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont, ['eid_prefix'], name, value)


                                                class EtrInterfaceIp(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: etr_interface_ip_address
                                                    
                                                    	IP address of loopback or other ETR interface
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                        self.yang_name = "etr-interface-ip"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ])
                                                        self.etr_interface_ip_address = None
                                                        self.priority = None
                                                        self.weight = None
                                                        self._segment_path = lambda: "etr-interface-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN configuration
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ])
                                            self.vlan = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EidTable, ['vlan'], name, value)


                                    class BroadcastUnderlay(Entity):
                                        """
                                        Multicast group to use for underlay
                                        
                                        .. attribute:: ipv4_multicast
                                        
                                        	IPv4 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_multicast
                                        
                                        	IPv6 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.BroadcastUnderlay, self).__init__()

                                            self.yang_name = "broadcast-underlay"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                                ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                            ])
                                            self.ipv4_multicast = None
                                            self.ipv6_multicast = None
                                            self._segment_path = lambda: "broadcast-underlay"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                    class Flood(Entity):
                                        """
                                        Control flooding or local intercept of broadcast frames
                                        
                                        .. attribute:: arp_nd
                                        
                                        	IPv4 ARP / IPv6 ND
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Frames with unknown destination MAC
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Flood, self).__init__()

                                            self.yang_name = "flood"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                                ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                            ])
                                            self.arp_nd = None
                                            self.unknown_unicast = None
                                            self._segment_path = lambda: "flood"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: mac
                                        
                                        	L2 EID records
                                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Mac>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.mac = None
                                            self._children_name_map["mac"] = "mac"

                                            self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Mac(Entity):
                                            """
                                            L2 EID records
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Mac, self).__init__()

                                                self.yang_name = "mac"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.locator_set = None
                                                self._segment_path = lambda: "mac"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Mac, ['locator_set'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont))])
                                            self._leafs = OrderedDict()

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont, ['eid_prefix'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                        class Decapsulation(Entity):
                            """
                            Decapsulation behavior (e.g. filters)
                            
                            .. attribute:: filter
                            
                            	Filters traffic
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation, self).__init__()

                                self.yang_name = "decapsulation"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("filter", ("filter", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter))])
                                self._leafs = OrderedDict()

                                self.filter = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"
                                self._segment_path = lambda: "decapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation, [], name, value)


                            class Filter(Entity):
                                """
                                Filters traffic
                                
                                .. attribute:: rloc
                                
                                	Filter based on Routing Locator (RLOC) in packet header
                                	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "decapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc))])
                                    self._leafs = OrderedDict()

                                    self.rloc = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc()
                                    self.rloc.parent = self
                                    self._children_name_map["rloc"] = "rloc"
                                    self._segment_path = lambda: "filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter, [], name, value)


                                class Rloc(Entity):
                                    """
                                    Filter based on Routing Locator (RLOC) in packet header
                                    
                                    .. attribute:: source
                                    
                                    	Filters traffic based on RLOC source address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc, self).__init__()

                                        self.yang_name = "rloc"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "rloc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc, [], name, value)


                                    class Source(Entity):
                                        """
                                        Filters traffic based on RLOC source address
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator\-set Name
                                        	**type**\: str
                                        
                                        .. attribute:: member
                                        
                                        	Members learned from map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "rloc"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.member = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                        class DynamicEid(Entity):
                            """
                            Configure a dynamic EID
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: database_mapping
                            
                            	Configures EID\-prefix and locator\-set for dynamic\-EID
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping>`
                            
                            .. attribute:: eid_notify
                            
                            	Configure options for sending/receiving EID\-notify
                            	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify>`
                            
                            .. attribute:: map_notify_group
                            
                            	Multicast group which to send map\-notifies to
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid, self).__init__()

                                self.yang_name = "dynamic-eid"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                                ])
                                self.name = None
                                self.map_notify_group = None

                                self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.eid_notify = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify()
                                self.eid_notify.parent = self
                                self._children_name_map["eid_notify"] = "eid-notify"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid, ['name', 'map_notify_group'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures EID\-prefix and locator\-set for dynamic\-EID
                                
                                .. attribute:: ipv4_prefix
                                
                                	IPv4 EID\-prefix for dynamic\-EID
                                	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix))])
                                    self._leafs = OrderedDict()

                                    self.ipv4_prefix = YList(self)
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping, [], name, value)


                                class Ipv4Prefix(Entity):
                                    """
                                    IPv4 EID\-prefix for dynamic\-EID
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    .. attribute:: locator_set
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix, self).__init__()

                                        self.yang_name = "ipv4-prefix"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.eid_prefix = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "ipv4-prefix" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix, ['eid_prefix', 'locator_set'], name, value)


                            class EidNotify(Entity):
                                """
                                Configure options for sending/receiving EID\-notify
                                
                                .. attribute:: authentication_key
                                
                                	Authentication key used for validating received EID\-notify
                                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey>`
                                
                                .. attribute:: gateway_key
                                
                                	
                                	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify, self).__init__()

                                    self.yang_name = "eid-notify"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey))])
                                    self._leafs = OrderedDict()

                                    self.authentication_key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey()
                                    self.authentication_key.parent = self
                                    self._children_name_map["authentication_key"] = "authentication-key"

                                    self.gateway_key = YList(self)
                                    self._segment_path = lambda: "eid-notify"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify, [], name, value)


                                class AuthenticationKey(Entity):
                                    """
                                    Authentication key used for validating received EID\-notify
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: key_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                        self.yang_name = "authentication-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.key_0 = None
                                        self.key_6 = None
                                        self.key_7 = None
                                        self._segment_path = lambda: "authentication-key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                                class GatewayKey(Entity):
                                    """
                                    
                                    
                                    .. attribute:: gateway_ip  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                        self.yang_name = "gateway-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['gateway_ip']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key))])
                                        self._leafs = OrderedDict([
                                            ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                        ])
                                        self.gateway_ip = None

                                        self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey, ['gateway_ip'], name, value)


                                    class Key(Entity):
                                        """
                                        
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "gateway-key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction')])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, ['unc_pwd', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction')])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0, ['ak_0', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction')])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6, ['ak_6', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                        class LocReachAlgorithm(Entity):
                            """
                            Configure locator reachability algorithm
                            
                            .. attribute:: lsb_reports
                            
                            	Configure data packet LSB report handling
                            	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports>`
                            
                            .. attribute:: rloc_probing
                            
                            	Probe high priority RLOCs with Map\-Requests as last resort
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.LocReachAlgorithm, self).__init__()

                                self.yang_name = "loc-reach-algorithm"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.Lisp.Default.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports))])
                                self._leafs = OrderedDict([
                                    ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                                ])
                                self.rloc_probing = None

                                self.lsb_reports = Native.Router.Lisp.Default.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports()
                                self.lsb_reports.parent = self
                                self._children_name_map["lsb_reports"] = "lsb-reports"
                                self._segment_path = lambda: "loc-reach-algorithm"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.LocReachAlgorithm, ['rloc_probing'], name, value)


                            class LsbReports(Entity):
                                """
                                Configure data packet LSB report handling
                                
                                .. attribute:: do_not_transmit
                                
                                	Force the setting of the encapsulation header L bit to zero
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ignore
                                
                                	Ignore data packet LSB reports
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports, self).__init__()

                                    self.yang_name = "lsb-reports"
                                    self.yang_parent_name = "loc-reach-algorithm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ])
                                    self.do_not_transmit = None
                                    self.ignore = None
                                    self._segment_path = lambda: "lsb-reports"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                        class MapServer(Entity):
                            """
                            Map\-Server commands
                            
                            .. attribute:: rloc
                            
                            	EID instance RLOC membership
                            	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc>`
                            
                            .. attribute:: site_registration
                            
                            	Map\-server site registration options
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.SiteRegistration>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.SiteRegistration))])
                                self._leafs = OrderedDict()

                                self.rloc = Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc()
                                self.rloc.parent = self
                                self._children_name_map["rloc"] = "rloc"

                                self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer, [], name, value)


                            class Rloc(Entity):
                                """
                                EID instance RLOC membership
                                
                                .. attribute:: members
                                
                                	EID instance RLOC membership
                                	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc, self).__init__()

                                    self.yang_name = "rloc"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("members", ("members", Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members))])
                                    self._leafs = OrderedDict()

                                    self.members = Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members()
                                    self.members.parent = self
                                    self._children_name_map["members"] = "members"
                                    self._segment_path = lambda: "rloc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc, [], name, value)


                                class Members(Entity):
                                    """
                                    EID instance RLOC membership
                                    
                                    .. attribute:: distribute
                                    
                                    	EID instance RLOC membership distribution
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: modify_discovered
                                    
                                    	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                    	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members, self).__init__()

                                        self.yang_name = "members"
                                        self.yang_parent_name = "rloc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered))])
                                        self._leafs = OrderedDict([
                                            ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                        ])
                                        self.distribute = None

                                        self.modify_discovered = Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered()
                                        self.modify_discovered.parent = self
                                        self._children_name_map["modify_discovered"] = "modify-discovered"
                                        self._segment_path = lambda: "members"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members, ['distribute'], name, value)


                                    class ModifyDiscovered(Entity):
                                        """
                                        Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                        
                                        .. attribute:: operator
                                        
                                        	
                                        	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set from which to get member RLOC addresses
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                            self.yang_name = "modify-discovered"
                                            self.yang_parent_name = "members"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.operator = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "modify-discovered"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                        class Operator(Enum):
                                            """
                                            Operator (Enum Class)

                                            .. data:: add = 0

                                            .. data:: override = 1

                                            """

                                            add = Enum.YLeaf(0, "add")

                                            override = Enum.YLeaf(1, "override")



                            class SiteRegistration(Entity):
                                """
                                Map\-server site registration options
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations as a result of accept\-more\-specifics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class OtherXtrProbe(Entity):
                            """
                            Configure parameters for probing of other xTRs in our site
                            
                            .. attribute:: period
                            
                            	Period between probes in seconds
                            	**type**\: int
                            
                            	**range:** 5..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.OtherXtrProbe, self).__init__()

                                self.yang_name = "other-xtr-probe"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                ])
                                self.period = None
                                self._segment_path = lambda: "other-xtr-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.OtherXtrProbe, ['period'], name, value)


                        class RemoteRlocProbe(Entity):
                            """
                            Configure parameters for probing of remote RLOCs
                            
                            .. attribute:: on_membership_change
                            
                            	Trigger probing upon membership changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: on_route_change
                            
                            	Trigger probing upon routing changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.RemoteRlocProbe, self).__init__()

                                self.yang_name = "remote-rloc-probe"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                    ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                                ])
                                self.on_membership_change = None
                                self.on_route_change = None
                                self._segment_path = lambda: "remote-rloc-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                        class Service(Entity):
                            """
                            Configure lisp service type
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ipv6
                            
                            	
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ethernet
                            
                            	
                            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service, self).__init__()

                                self.yang_name = "service"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.ipv4 = None
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = None
                                self._children_name_map["ipv6"] = "ipv6"

                                self.ethernet = None
                                self._children_name_map["ethernet"] = "ethernet"
                                self._segment_path = lambda: "service"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service, [], name, value)


                            class Ipv4(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_)), ("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.EidTable)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt)), ("distance", ("distance", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import)), ("route-import", ("route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.default = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EidTable)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt)), ("distance", ("distance", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import)), ("route-import", ("route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping))])
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Ipv6(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_)), ("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.EidTable)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt)), ("distance", ("distance", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import)), ("route-import", ("route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.default = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EidTable)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt)), ("distance", ("distance", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr)), ("import", ("import_", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import)), ("route-import", ("route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping))])
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Ethernet(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.EidTable>`
                                
                                .. attribute:: broadcast_underlay
                                
                                	Multicast group to use for underlay
                                	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay>`
                                
                                .. attribute:: flood
                                
                                	Control flooding or local intercept of broadcast frames
                                	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Flood>`
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_)), ("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay)), ("flood", ("flood", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Flood)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                    ])
                                    self.map_request_source = None

                                    self.default = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.broadcast_underlay = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay()
                                    self.broadcast_underlay.parent = self
                                    self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                    self.flood = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Flood()
                                    self.flood.parent = self
                                    self._children_name_map["flood"] = "flood"

                                    self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"
                                    self._segment_path = lambda: "ethernet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet, ['map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EidTable>`
                                    
                                    .. attribute:: broadcast_underlay
                                    
                                    	Multicast group to use for underlay
                                    	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.BroadcastUnderlay>`
                                    
                                    .. attribute:: flood
                                    
                                    	Control flooding or local intercept of broadcast frames
                                    	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Flood>`
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.BroadcastUnderlay)), ("flood", ("flood", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Flood)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache))])
                                        self._leafs = OrderedDict([
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                        ])
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.broadcast_underlay = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.BroadcastUnderlay()
                                        self.broadcast_underlay.parent = self
                                        self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                        self.flood = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Flood()
                                        self.flood.parent = self
                                        self._children_name_map["flood"] = "flood"

                                        self.database_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.itr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.map_cache = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_, ['map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN configuration
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ])
                                            self.vlan = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EidTable, ['vlan'], name, value)


                                    class BroadcastUnderlay(Entity):
                                        """
                                        Multicast group to use for underlay
                                        
                                        .. attribute:: ipv4_multicast
                                        
                                        	IPv4 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_multicast
                                        
                                        	IPv6 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.BroadcastUnderlay, self).__init__()

                                            self.yang_name = "broadcast-underlay"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                                ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                            ])
                                            self.ipv4_multicast = None
                                            self.ipv6_multicast = None
                                            self._segment_path = lambda: "broadcast-underlay"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                    class Flood(Entity):
                                        """
                                        Control flooding or local intercept of broadcast frames
                                        
                                        .. attribute:: arp_nd
                                        
                                        	IPv4 ARP / IPv6 ND
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Frames with unknown destination MAC
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Flood, self).__init__()

                                            self.yang_name = "flood"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                                ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                            ])
                                            self.arp_nd = None
                                            self.unknown_unicast = None
                                            self._segment_path = lambda: "flood"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: mac
                                        
                                        	L2 EID records
                                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Mac>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.mac = None
                                            self._children_name_map["mac"] = "mac"

                                            self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Mac(Entity):
                                            """
                                            L2 EID records
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Mac, self).__init__()

                                                self.yang_name = "mac"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.locator_set = None
                                                self._segment_path = lambda: "mac"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Mac, ['locator_set'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont))])
                                            self._leafs = OrderedDict()

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont, ['eid_prefix'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN configuration
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.EidTable, ['vlan'], name, value)


                                class BroadcastUnderlay(Entity):
                                    """
                                    Multicast group to use for underlay
                                    
                                    .. attribute:: ipv4_multicast
                                    
                                    	IPv4 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_multicast
                                    
                                    	IPv6 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay, self).__init__()

                                        self.yang_name = "broadcast-underlay"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                            ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                        ])
                                        self.ipv4_multicast = None
                                        self.ipv6_multicast = None
                                        self._segment_path = lambda: "broadcast-underlay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                class Flood(Entity):
                                    """
                                    Control flooding or local intercept of broadcast frames
                                    
                                    .. attribute:: arp_nd
                                    
                                    	IPv4 ARP / IPv6 ND
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Frames with unknown destination MAC
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Flood, self).__init__()

                                        self.yang_name = "flood"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                            ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                        ])
                                        self.arp_nd = None
                                        self.unknown_unicast = None
                                        self._segment_path = lambda: "flood"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: mac
                                    
                                    	L2 EID records
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.mac = None
                                        self._children_name_map["mac"] = "mac"

                                        self.limit = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.locator_set_container = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Mac(Entity):
                                        """
                                        L2 EID records
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.locator_set = None
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac, ['locator_set'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont))])
                                        self._leafs = OrderedDict()

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.etr_interface_ip = Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont, ['eid_prefix'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                class Alt(Entity):
                    """
                    LISP Alternative Topology, LISP\-ALT
                    
                    .. attribute:: summary_route
                    
                    	Summary route to install into the ALT table
                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Alt.SummaryRoute>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Alt, self).__init__()

                        self.yang_name = "alt"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.Default.Alt.SummaryRoute))])
                        self._leafs = OrderedDict()

                        self.summary_route = YList(self)
                        self._segment_path = lambda: "alt"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Alt, [], name, value)


                    class SummaryRoute(Entity):
                        """
                        Summary route to install into the ALT table
                        
                        .. attribute:: eid_prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: route_tag
                        
                        	ALT RIB route tag for EID prefix
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Alt.SummaryRoute, self).__init__()

                            self.yang_name = "summary-route"
                            self.yang_parent_name = "alt"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['eid_prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                            ])
                            self.eid_prefix = None
                            self.route_tag = None
                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/alt/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                class ControlPacket(Entity):
                    """
                    Configure control packet tx option
                    
                    .. attribute:: mtu
                    
                    	Configure control packet MTU
                    	**type**\: int
                    
                    	**range:** 304..10000
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.ControlPacket, self).__init__()

                        self.yang_name = "control-packet"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                        ])
                        self.mtu = None
                        self._segment_path = lambda: "control-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.ControlPacket, ['mtu'], name, value)


                class Ddt(Entity):
                    """
                    Delegated Database Tree (DDT) mapping system
                    
                    .. attribute:: authoritative
                    
                    	DDT authoritative prefix
                    	**type**\:  :py:class:`Authoritative <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ddt.Authoritative>`
                    
                    .. attribute:: cache_limit
                    
                    	DDT resolver cache entry limit
                    	**type**\: int
                    
                    	**range:** 1..100000
                    
                    .. attribute:: root
                    
                    	DDT root node
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Ddt, self).__init__()

                        self.yang_name = "ddt"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authoritative", ("authoritative", Native.Router.Lisp.Default.Ddt.Authoritative))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cache_limit', (YLeaf(YType.uint32, 'cache-limit'), ['int'])),
                            ('root', (YLeaf(YType.str, 'root'), ['str','str'])),
                        ])
                        self.cache_limit = None
                        self.root = None

                        self.authoritative = Native.Router.Lisp.Default.Ddt.Authoritative()
                        self.authoritative.parent = self
                        self._children_name_map["authoritative"] = "authoritative"
                        self._segment_path = lambda: "ddt"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Ddt, ['cache_limit', 'root'], name, value)


                    class Authoritative(Entity):
                        """
                        DDT authoritative prefix
                        
                        .. attribute:: instance_id_eid_prefix_list
                        
                        	
                        	**type**\: list of  		 :py:class:`InstanceIdEidPrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdEidPrefixList>`
                        
                        .. attribute:: instance_id_list
                        
                        	
                        	**type**\: list of  		 :py:class:`InstanceIdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdList>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ddt.Authoritative, self).__init__()

                            self.yang_name = "authoritative"
                            self.yang_parent_name = "ddt"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("instance-id-eid-prefix-list", ("instance_id_eid_prefix_list", Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdEidPrefixList)), ("instance-id-list", ("instance_id_list", Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdList))])
                            self._leafs = OrderedDict()

                            self.instance_id_eid_prefix_list = YList(self)
                            self.instance_id_list = YList(self)
                            self._segment_path = lambda: "authoritative"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ddt/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ddt.Authoritative, [], name, value)


                        class InstanceIdEidPrefixList(Entity):
                            """
                            
                            
                            .. attribute:: instance_id  (key)
                            
                            	EID instance\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: eid_prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: delegate
                            
                            	DDT delegation to a child DDT node or map\-server
                            	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate>`
                            
                            .. attribute:: map_server_peer
                            
                            	Peer map\-servers that are authoritative for the same EID prefixes
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdEidPrefixList, self).__init__()

                                self.yang_name = "instance-id-eid-prefix-list"
                                self.yang_parent_name = "authoritative"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['instance_id','eid_prefix']
                                self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate))])
                                self._leafs = OrderedDict([
                                    ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                ])
                                self.instance_id = None
                                self.eid_prefix = None
                                self.map_server_peer = None

                                self.delegate = Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate()
                                self.delegate.parent = self
                                self._children_name_map["delegate"] = "delegate"
                                self._segment_path = lambda: "instance-id-eid-prefix-list" + "[instance-id='" + str(self.instance_id) + "']" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ddt/authoritative/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdEidPrefixList, ['instance_id', 'eid_prefix', 'map_server_peer'], name, value)


                            class Delegate(Entity):
                                """
                                DDT delegation to a child DDT node or map\-server
                                
                                .. attribute:: eid_prefix
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: instance_id
                                
                                	EID instance\-ID
                                	**type**\: str
                                
                                .. attribute:: to
                                
                                	DDT delegation to a child DDT node or map\-server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ip_address
                                
                                	IPv4/6 Child or map\-server node locator address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_server
                                
                                	Delegation points to a map\-server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, self).__init__()

                                    self.yang_name = "delegate"
                                    self.yang_parent_name = "instance-id-eid-prefix-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                        ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                        ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                        ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                    ])
                                    self.eid_prefix = None
                                    self.instance_id = None
                                    self.to = None
                                    self.ip_address = None
                                    self.map_server = None
                                    self._segment_path = lambda: "delegate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                        class InstanceIdList(Entity):
                            """
                            
                            
                            .. attribute:: instance_id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: delegate
                            
                            	DDT delegation to a child DDT node or map\-server
                            	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdList.Delegate>`
                            
                            .. attribute:: map_server_peer
                            
                            	Peer map\-servers that are authoritative for the same EID prefixes
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdList, self).__init__()

                                self.yang_name = "instance-id-list"
                                self.yang_parent_name = "authoritative"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['instance_id']
                                self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdList.Delegate))])
                                self._leafs = OrderedDict([
                                    ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                    ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                ])
                                self.instance_id = None
                                self.map_server_peer = None

                                self.delegate = Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdList.Delegate()
                                self.delegate.parent = self
                                self._children_name_map["delegate"] = "delegate"
                                self._segment_path = lambda: "instance-id-list" + "[instance-id='" + str(self.instance_id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ddt/authoritative/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdList, ['instance_id', 'map_server_peer'], name, value)


                            class Delegate(Entity):
                                """
                                DDT delegation to a child DDT node or map\-server
                                
                                .. attribute:: eid_prefix
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: instance_id
                                
                                	EID instance\-ID
                                	**type**\: str
                                
                                .. attribute:: to
                                
                                	DDT delegation to a child DDT node or map\-server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ip_address
                                
                                	IPv4/6 Child or map\-server node locator address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_server
                                
                                	Delegation points to a map\-server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdList.Delegate, self).__init__()

                                    self.yang_name = "delegate"
                                    self.yang_parent_name = "instance-id-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                        ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                        ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                        ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                    ])
                                    self.eid_prefix = None
                                    self.instance_id = None
                                    self.to = None
                                    self.ip_address = None
                                    self.map_server = None
                                    self._segment_path = lambda: "delegate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ddt.Authoritative.InstanceIdList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                class Decapsulation(Entity):
                    """
                    Decapsulation behavior (e.g. filters)
                    
                    .. attribute:: filter
                    
                    	Filters traffic
                    	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Decapsulation.Filter>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Decapsulation, self).__init__()

                        self.yang_name = "decapsulation"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("filter", ("filter", Native.Router.Lisp.Default.Decapsulation.Filter))])
                        self._leafs = OrderedDict()

                        self.filter = Native.Router.Lisp.Default.Decapsulation.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                        self._segment_path = lambda: "decapsulation"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Decapsulation, [], name, value)


                    class Filter(Entity):
                        """
                        Filters traffic
                        
                        .. attribute:: rloc
                        
                        	Filter based on Routing Locator (RLOC) in packet header
                        	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Decapsulation.Filter.Rloc>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Decapsulation.Filter, self).__init__()

                            self.yang_name = "filter"
                            self.yang_parent_name = "decapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.Default.Decapsulation.Filter.Rloc))])
                            self._leafs = OrderedDict()

                            self.rloc = Native.Router.Lisp.Default.Decapsulation.Filter.Rloc()
                            self.rloc.parent = self
                            self._children_name_map["rloc"] = "rloc"
                            self._segment_path = lambda: "filter"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/decapsulation/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Decapsulation.Filter, [], name, value)


                        class Rloc(Entity):
                            """
                            Filter based on Routing Locator (RLOC) in packet header
                            
                            .. attribute:: source
                            
                            	Filters traffic based on RLOC source address
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Decapsulation.Filter.Rloc.Source>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Decapsulation.Filter.Rloc, self).__init__()

                                self.yang_name = "rloc"
                                self.yang_parent_name = "filter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Decapsulation.Filter.Rloc.Source))])
                                self._leafs = OrderedDict()

                                self.source = Native.Router.Lisp.Default.Decapsulation.Filter.Rloc.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "rloc"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/decapsulation/filter/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Decapsulation.Filter.Rloc, [], name, value)


                            class Source(Entity):
                                """
                                Filters traffic based on RLOC source address
                                
                                .. attribute:: locator_set
                                
                                	Locator\-set Name
                                	**type**\: str
                                
                                .. attribute:: member
                                
                                	Members learned from map\-server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Decapsulation.Filter.Rloc.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "rloc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                    ])
                                    self.locator_set = None
                                    self.member = None
                                    self._segment_path = lambda: "source"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/decapsulation/filter/rloc/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                class Etr(Entity):
                    """
                    Configures a LISP Egress Tunnel Router (ETR)
                    
                    .. attribute:: map_server
                    
                    	Configures map server for ETR registration
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Etr.MapServer>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Etr, self).__init__()

                        self.yang_name = "etr"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.Etr.MapServer))])
                        self._leafs = OrderedDict()

                        self.map_server = Native.Router.Lisp.Default.Etr.MapServer()
                        self.map_server.parent = self
                        self._children_name_map["map_server"] = "map-server"
                        self._segment_path = lambda: "etr"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Etr, [], name, value)


                    class MapServer(Entity):
                        """
                        Configures map server for ETR registration
                        
                        .. attribute:: source_address
                        
                        	Configures map server source address
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Etr.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "etr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                            ])
                            self.source_address = None
                            self._segment_path = lambda: "map-server"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/etr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Etr.MapServer, ['source_address'], name, value)


                class Ipv4(Entity):
                    """
                    IPv4 address family
                    
                    .. attribute:: alt_vrf
                    
                    	Activate LISP\-ALT functionality in VRF
                    	**type**\: str
                    
                    	**status**\: deprecated
                    
                    .. attribute:: database_mapping
                    
                    	Address family specific local EID prefixes database configuration
                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.DatabaseMapping>`
                    
                    .. attribute:: distance
                    
                    	Administrative distance for RIB route installation
                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.Distance>`
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.Itr>`
                    
                    .. attribute:: itr_enable
                    
                    	
                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.ItrEnable>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.Etr>`
                    
                    .. attribute:: etr_enable
                    
                    	
                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.EtrEnable>`
                    
                    .. attribute:: locator
                    
                    	Locator related configuration
                    	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.Locator>`
                    
                    .. attribute:: map_cache
                    
                    	Address family specific map cache configuration
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.MapCache>`
                    
                    .. attribute:: map_cache_limit
                    
                    	Configures maximum size of map\-cache
                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.MapCacheLimit>`
                    
                    .. attribute:: map_cache_persistent
                    
                    	Dump map\-cache onto flash, making it persistent across reboots
                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.MapCachePersistent>`
                    
                    .. attribute:: map_request_source
                    
                    	Configures inner header source address in Map\-Request message
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: map_resolver
                    
                    	Configures a LISP Map Resolver (MR)
                    	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.MapResolver>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: map_server
                    
                    	Configures a LISP Map Server (MS)
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.MapServer>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: path_mtu_discovery
                    
                    	Path MTU discovery
                    	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.PathMtuDiscovery>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: proxy_etr
                    
                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: proxy_itr
                    
                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                    	**type**\: union of the below types:
                    
                    		**type**\: list of str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: list of str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: route_export
                    
                    	Export routes into RIB from LISP
                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteExport>`
                    
                    .. attribute:: route_import
                    
                    	Import RIB routes by a routing protocol into LISP
                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport>`
                    
                    .. attribute:: sgt
                    
                    	Enable security group tag propagation in LISP encapsulated traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: site_registration
                    
                    	Site registrations configuration for a given instance\-id
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.SiteRegistration>`
                    
                    .. attribute:: solicit_map_request
                    
                    	Configure Solicit\-Map\-Request handling
                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.SolicitMapRequest>`
                    
                    .. attribute:: source_locator
                    
                    	Source Locator configuration
                    	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.SourceLocator>`
                    
                    .. attribute:: use_petr
                    
                    	Encapsulate to Proxy ETR when matching forward\-native entry
                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.UsePetr>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Default.Ipv4.DatabaseMapping)), ("distance", ("distance", Native.Router.Lisp.Default.Ipv4.Distance)), ("itr", ("itr", Native.Router.Lisp.Default.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.Ipv4.ItrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.Ipv4.Etr)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.Ipv4.EtrEnable)), ("locator", ("locator", Native.Router.Lisp.Default.Ipv4.Locator)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.Ipv4.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.Ipv4.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.Ipv4.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Default.Ipv4.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Lisp.Default.Ipv4.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.Lisp.Default.Ipv4.RouteExport)), ("route-import", ("route_import", Native.Router.Lisp.Default.Ipv4.RouteImport)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.Ipv4.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.Lisp.Default.Ipv4.SourceLocator)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.Ipv4.UsePetr))])
                        self._leafs = OrderedDict([
                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                            ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                        ])
                        self.alt_vrf = None
                        self.map_request_source = None
                        self.proxy_etr = None
                        self.proxy_itr = []
                        self.sgt = None

                        self.database_mapping = Native.Router.Lisp.Default.Ipv4.DatabaseMapping()
                        self.database_mapping.parent = self
                        self._children_name_map["database_mapping"] = "database-mapping"

                        self.distance = Native.Router.Lisp.Default.Ipv4.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"

                        self.itr = Native.Router.Lisp.Default.Ipv4.Itr()
                        self.itr.parent = self
                        self._children_name_map["itr"] = "itr"

                        self.itr_enable = Native.Router.Lisp.Default.Ipv4.ItrEnable()
                        self.itr_enable.parent = self
                        self._children_name_map["itr_enable"] = "itr-enable"

                        self.etr = Native.Router.Lisp.Default.Ipv4.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.etr_enable = Native.Router.Lisp.Default.Ipv4.EtrEnable()
                        self.etr_enable.parent = self
                        self._children_name_map["etr_enable"] = "etr-enable"

                        self.locator = Native.Router.Lisp.Default.Ipv4.Locator()
                        self.locator.parent = self
                        self._children_name_map["locator"] = "locator"

                        self.map_cache = Native.Router.Lisp.Default.Ipv4.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"

                        self.map_cache_limit = Native.Router.Lisp.Default.Ipv4.MapCacheLimit()
                        self.map_cache_limit.parent = self
                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                        self.map_cache_persistent = Native.Router.Lisp.Default.Ipv4.MapCachePersistent()
                        self.map_cache_persistent.parent = self
                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                        self.map_resolver = None
                        self._children_name_map["map_resolver"] = "map-resolver"

                        self.map_server = None
                        self._children_name_map["map_server"] = "map-server"

                        self.path_mtu_discovery = None
                        self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                        self.route_export = Native.Router.Lisp.Default.Ipv4.RouteExport()
                        self.route_export.parent = self
                        self._children_name_map["route_export"] = "route-export"

                        self.route_import = Native.Router.Lisp.Default.Ipv4.RouteImport()
                        self.route_import.parent = self
                        self._children_name_map["route_import"] = "route-import"

                        self.site_registration = Native.Router.Lisp.Default.Ipv4.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.solicit_map_request = Native.Router.Lisp.Default.Ipv4.SolicitMapRequest()
                        self.solicit_map_request.parent = self
                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                        self.source_locator = Native.Router.Lisp.Default.Ipv4.SourceLocator()
                        self.source_locator.parent = self
                        self._children_name_map["source_locator"] = "source-locator"

                        self.use_petr = YList(self)
                        self._segment_path = lambda: "ipv4"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Address family specific local EID prefixes database configuration
                        
                        .. attribute:: limit
                        
                        	Configures the maximum size of local EID prefixes database
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.DatabaseMapping.Limit>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Default.Ipv4.DatabaseMapping.Limit))])
                            self._leafs = OrderedDict()

                            self.limit = Native.Router.Lisp.Default.Ipv4.DatabaseMapping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "database-mapping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.DatabaseMapping, [], name, value)


                        class Limit(Entity):
                            """
                            Configures the maximum size of local EID prefixes database
                            
                            .. attribute:: dynamic
                            
                            	Configures the maximum size of dynamic local EID prefixes database
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.DatabaseMapping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "database-mapping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.dynamic = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/database-mapping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                    class Distance(Entity):
                        """
                        Administrative distance for RIB route installation
                        
                        .. attribute:: alt
                        
                        	LISP routes installed in the ALT table
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dyn_eid
                        
                        	LISP installed routes of type dynamic\-EID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: site_registrations
                        
                        	LISP installed routes of type site\-registrations
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                            ])
                            self.alt = None
                            self.dyn_eid = None
                            self.site_registrations = None
                            self._segment_path = lambda: "distance"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                    class Itr(Entity):
                        """
                        Configures a LISP Ingress Tunnel Router (ITR)
                        
                        .. attribute:: map_resolver
                        
                        	Configures map\-resolver address for sending Map\-Requests
                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.Itr.MapResolver>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.Itr, self).__init__()

                            self.yang_name = "itr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Ipv4.Itr.MapResolver))])
                            self._leafs = OrderedDict()

                            self.map_resolver = YList(self)
                            self._segment_path = lambda: "itr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.Itr, [], name, value)


                        class MapResolver(Entity):
                            """
                            Configures map\-resolver address for sending Map\-Requests
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.Itr.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "itr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                ])
                                self.ip_addr = None
                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/itr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.Itr.MapResolver, ['ip_addr'], name, value)


                    class ItrEnable(Entity):
                        """
                        
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.ItrEnable, self).__init__()

                            self.yang_name = "itr-enable"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                            ])
                            self.itr = None
                            self._segment_path = lambda: "itr-enable"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.ItrEnable, ['itr'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.Etr.MapServer>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.Ipv4.Etr.MapServer))])
                            self._leafs = OrderedDict()

                            self.map_server = YList(self)
                            self._segment_path = lambda: "etr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.Etr, [], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.Etr.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.Ipv4.Etr.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.Lisp.Default.Ipv4.Etr.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/etr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: key_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: key_7
                                
                                	The HIDDEN password
                                	**type**\: str
                                
                                .. attribute:: pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.Etr.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                        ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                        ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                        ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                    ])
                                    self.key_0 = None
                                    self.key_6 = None
                                    self.key_7 = None
                                    self.pwd = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                    class EtrEnable(Entity):
                        """
                        
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.EtrEnable, self).__init__()

                            self.yang_name = "etr-enable"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                            ])
                            self.etr = None
                            self._segment_path = lambda: "etr-enable"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.EtrEnable, ['etr'], name, value)


                    class Locator(Entity):
                        """
                        Locator related configuration
                        
                        .. attribute:: reachability
                        
                        	Configuration realted to locator reachability
                        	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.Locator.Reachability>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.Locator, self).__init__()

                            self.yang_name = "locator"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.Lisp.Default.Ipv4.Locator.Reachability))])
                            self._leafs = OrderedDict()

                            self.reachability = Native.Router.Lisp.Default.Ipv4.Locator.Reachability()
                            self.reachability.parent = self
                            self._children_name_map["reachability"] = "reachability"
                            self._segment_path = lambda: "locator"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.Locator, [], name, value)


                        class Reachability(Entity):
                            """
                            Configuration realted to locator reachability
                            
                            .. attribute:: exclude_default
                            
                            	If a remote RLOC is reached via the default route, treat it as unreachable
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.Locator.Reachability, self).__init__()

                                self.yang_name = "reachability"
                                self.yang_parent_name = "locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                ])
                                self.exclude_default = None
                                self._segment_path = lambda: "reachability"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/locator/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.Locator.Reachability, ['exclude_default'], name, value)


                    class MapCache(Entity):
                        """
                        Address family specific map cache configuration
                        
                        .. attribute:: site_registration
                        
                        	Install map cache to map request for site registrations
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                            ])
                            self.site_registration = None
                            self._segment_path = lambda: "map-cache"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.MapCache, ['site_registration'], name, value)


                    class MapCacheLimit(Entity):
                        """
                        Configures maximum size of map\-cache
                        
                        .. attribute:: max_map_cache_entries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..100000
                        
                        .. attribute:: reserve_list
                        
                        	EID\-prefixes guaranteed to be stored in map\-cache
                        	**type**\: str
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.MapCacheLimit, self).__init__()

                            self.yang_name = "map-cache-limit"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.max_map_cache_entries = None
                            self.reserve_list = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "map-cache-limit"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                    class MapCachePersistent(Entity):
                        """
                        Dump map\-cache onto flash, making it persistent across reboots
                        
                        .. attribute:: interval
                        
                        	Interval in minutes of how often the map\-cache is saved
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.MapCachePersistent, self).__init__()

                            self.yang_name = "map-cache-persistent"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "map-cache-persistent"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.MapCachePersistent, ['interval'], name, value)


                    class MapResolver(Entity):
                        """
                        Configures a LISP Map Resolver (MR)
                        
                        .. attribute:: map_request
                        
                        	Map\-Request processing options
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_request = Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"
                            self._segment_path = lambda: "map-resolver"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.MapResolver, [], name, value)


                        class MapRequest(Entity):
                            """
                            Map\-Request processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "map-resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-request"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/map-resolver/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	Influence which source RLOCs map requests are accepted from
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/map-resolver/map-request/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    Influence which source RLOCs map requests are accepted from
                                    
                                    .. attribute:: list
                                    
                                    	Define allowed prefixes using an ip[v6] prefix list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: registered
                                    
                                    	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 prefixes
                                    	**type**\: str
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 prefixes
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                            ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.list = None
                                        self.registered = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "source"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/map-resolver/map-request/validate/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                    class MapServer(Entity):
                        """
                        Configures a LISP Map Server (MS)
                        
                        .. attribute:: map_register
                        
                        	Map\-Register processing options
                        	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_register = Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister()
                            self.map_register.parent = self
                            self._children_name_map["map_register"] = "map-register"
                            self._segment_path = lambda: "map-server"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.MapServer, [], name, value)


                        class MapRegister(Entity):
                            """
                            Map\-Register processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister, self).__init__()

                                self.yang_name = "map-register"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-register"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/map-server/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	RLOC Source IP address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-register"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/map-server/map-register/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    RLOC Source IP address
                                    
                                    .. attribute:: allowed_locator
                                    
                                    	Against sites' allowed\-locators policy
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                        ])
                                        self.allowed_locator = None
                                        self._segment_path = lambda: "source"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/map-server/map-register/validate/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                    class PathMtuDiscovery(Entity):
                        """
                        Path MTU discovery
                        
                        .. attribute:: max
                        
                        	Upper bound on the path MTU accepted
                        	**type**\: int
                        
                        	**range:** 68..65535
                        
                        .. attribute:: min
                        
                        	Lower bound on the path MTU accepted
                        	**type**\: int
                        
                        	**range:** 68..65535
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.PathMtuDiscovery, self).__init__()

                            self.yang_name = "path-mtu-discovery"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                            ])
                            self.max = None
                            self.min = None
                            self._segment_path = lambda: "path-mtu-discovery"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.PathMtuDiscovery, ['max', 'min'], name, value)


                    class RouteExport(Entity):
                        """
                        Export routes into RIB from LISP
                        
                        .. attribute:: site_registrations
                        
                        	Export LISP site registrations to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: away_eids
                        
                        	Export LISP away EIDs to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.RouteExport, self).__init__()

                            self.yang_name = "route-export"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                            ])
                            self.site_registrations = None
                            self.away_eids = None
                            self._segment_path = lambda: "route-export"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                    class RouteImport(Entity):
                        """
                        Import RIB routes by a routing protocol into LISP
                        
                        .. attribute:: database
                        
                        	Use RIB routes to define local EID database entries
                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database>`
                        
                        .. attribute:: map_cache
                        
                        	Use RIB routes to define EID address space in map\-cache
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.RouteImport, self).__init__()

                            self.yang_name = "route-import"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache))])
                            self._leafs = OrderedDict()

                            self.database = Native.Router.Lisp.Default.Ipv4.RouteImport.Database()
                            self.database.parent = self
                            self._children_name_map["database"] = "database"

                            self.map_cache = Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"
                            self._segment_path = lambda: "route-import"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport, [], name, value)


                        class Database(Entity):
                            """
                            Use RIB routes to define local EID database entries
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Connected>`
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Isis>`
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes to pick up from the RIB
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.MaximumPrefix>`
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospfv3>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Rip>`
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Static>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database, self).__init__()

                                self.yang_name = "database"
                                self.yang_parent_name = "route-import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Rip)), ("static", ("static", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Static))])
                                self._leafs = OrderedDict()

                                self.connected = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Connected()
                                self.connected.parent = self
                                self._children_name_map["connected"] = "connected"

                                self.maximum_prefix = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.rip = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Rip()
                                self.rip.parent = self
                                self._children_name_map["rip"] = "rip"

                                self.static = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Static()
                                self.static.parent = self
                                self._children_name_map["static"] = "static"

                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.isis = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self._segment_path = lambda: "database"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database, [], name, value)


                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "connected"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Connected, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/connected/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Isis, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes to pick up from the RIB
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: warning_only
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: threshold
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: warning_only1
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.warning_only = None
                                    self.threshold = None
                                    self.threshold1 = None
                                    self.warning_only1 = None
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Ospfv3(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospfv3, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospfv3, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "rip"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Rip, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/rip/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "static"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Static, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/database/static/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class MapCache(Entity):
                            """
                            Use RIB routes to define EID address space in map\-cache
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Isis>`
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes to pick up from the RIB
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospfv3>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Rip>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Static>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "route-import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Static))])
                                self._leafs = OrderedDict()

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.maximum_prefix = Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.rip = None
                                self._children_name_map["rip"] = "rip"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.isis = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self._segment_path = lambda: "map-cache"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache, [], name, value)


                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "connected"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/connected/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes to pick up from the RIB
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: warning_only
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: threshold
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: warning_only1
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.warning_only = None
                                    self.threshold = None
                                    self.threshold1 = None
                                    self.warning_only1 = None
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                            class Ospfv3(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospfv3, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "rip"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/rip/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "static"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/route-import/map-cache/static/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                    class SiteRegistration(Entity):
                        """
                        Site registrations configuration for a given instance\-id
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations for a given instance\-id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class SolicitMapRequest(Entity):
                        """
                        Configure Solicit\-Map\-Request handling
                        
                        .. attribute:: ignore
                        
                        	Ignore SMR bit in incoming Map\-Requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_per_entry
                        
                        	Maximum number of SMRs for addresses under a map\-cache entry
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: suppression_time
                        
                        	How long to suppress repeated SMRs for the same address
                        	**type**\: int
                        
                        	**range:** 1..600
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.SolicitMapRequest, self).__init__()

                            self.yang_name = "solicit-map-request"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                            ])
                            self.ignore = None
                            self.max_per_entry = None
                            self.suppression_time = None
                            self._segment_path = lambda: "solicit-map-request"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                    class SourceLocator(Entity):
                        """
                        Source Locator configuration
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.SourceLocator.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.SourceLocator.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.SourceLocator.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv4.SourceLocator.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.SourceLocator, self).__init__()

                            self.yang_name = "source-locator"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Lisp.Default.Ipv4.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Lisp.Default.Ipv4.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Lisp.Default.Ipv4.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Lisp.Default.Ipv4.SourceLocator.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Router.Lisp.Default.Ipv4.SourceLocator.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Router.Lisp.Default.Ipv4.SourceLocator.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Router.Lisp.Default.Ipv4.SourceLocator.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Router.Lisp.Default.Ipv4.SourceLocator.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "source-locator"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.SourceLocator.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/source-locator/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.SourceLocator.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/source-locator/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.SourceLocator.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/source-locator/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv4.SourceLocator.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/source-locator/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv4.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                    class UsePetr(Entity):
                        """
                        Encapsulate to Proxy ETR when matching forward\-native entry
                        
                        .. attribute:: locator_address  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	Configures which Locators from a set are preferred
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: weight
                        
                        	Traffic load\-spreading among Locators
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv4.UsePetr, self).__init__()

                            self.yang_name = "use-petr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['locator_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                            ])
                            self.locator_address = None
                            self.priority = None
                            self.weight = None
                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv4.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 address family
                    
                    .. attribute:: alt_vrf
                    
                    	Activate LISP\-ALT functionality in VRF
                    	**type**\: str
                    
                    	**status**\: deprecated
                    
                    .. attribute:: database_mapping
                    
                    	Address family specific local EID prefixes database configuration
                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.DatabaseMapping>`
                    
                    .. attribute:: distance
                    
                    	Administrative distance for RIB route installation
                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.Distance>`
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.Itr>`
                    
                    .. attribute:: itr_enable
                    
                    	
                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.ItrEnable>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.Etr>`
                    
                    .. attribute:: etr_enable
                    
                    	
                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.EtrEnable>`
                    
                    .. attribute:: locator
                    
                    	Locator related configuration
                    	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.Locator>`
                    
                    .. attribute:: map_cache
                    
                    	Address family specific map cache configuration
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.MapCache>`
                    
                    .. attribute:: map_cache_limit
                    
                    	Configures maximum size of map\-cache
                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.MapCacheLimit>`
                    
                    .. attribute:: map_cache_persistent
                    
                    	Dump map\-cache onto flash, making it persistent across reboots
                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.MapCachePersistent>`
                    
                    .. attribute:: map_request_source
                    
                    	Configures inner header source address in Map\-Request message
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: map_resolver
                    
                    	Configures a LISP Map Resolver (MR)
                    	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.MapResolver>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: map_server
                    
                    	Configures a LISP Map Server (MS)
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.MapServer>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: path_mtu_discovery
                    
                    	Path MTU discovery
                    	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.PathMtuDiscovery>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: proxy_etr
                    
                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: proxy_itr
                    
                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                    	**type**\: union of the below types:
                    
                    		**type**\: list of str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: list of str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: route_export
                    
                    	Export routes into RIB from LISP
                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteExport>`
                    
                    .. attribute:: route_import
                    
                    	Import RIB routes by a routing protocol into LISP
                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport>`
                    
                    .. attribute:: sgt
                    
                    	Enable security group tag propagation in LISP encapsulated traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: site_registration
                    
                    	Site registrations configuration for a given instance\-id
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.SiteRegistration>`
                    
                    .. attribute:: solicit_map_request
                    
                    	Configure Solicit\-Map\-Request handling
                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.SolicitMapRequest>`
                    
                    .. attribute:: source_locator
                    
                    	Source Locator configuration
                    	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.SourceLocator>`
                    
                    .. attribute:: use_petr
                    
                    	Encapsulate to Proxy ETR when matching forward\-native entry
                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.UsePetr>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Default.Ipv6.DatabaseMapping)), ("distance", ("distance", Native.Router.Lisp.Default.Ipv6.Distance)), ("itr", ("itr", Native.Router.Lisp.Default.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.Ipv6.ItrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.Ipv6.Etr)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.Ipv6.EtrEnable)), ("locator", ("locator", Native.Router.Lisp.Default.Ipv6.Locator)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.Ipv6.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.Ipv6.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.Ipv6.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Default.Ipv6.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Lisp.Default.Ipv6.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.Lisp.Default.Ipv6.RouteExport)), ("route-import", ("route_import", Native.Router.Lisp.Default.Ipv6.RouteImport)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.Ipv6.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.Lisp.Default.Ipv6.SourceLocator)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.Ipv6.UsePetr))])
                        self._leafs = OrderedDict([
                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                            ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                        ])
                        self.alt_vrf = None
                        self.map_request_source = None
                        self.proxy_etr = None
                        self.proxy_itr = []
                        self.sgt = None

                        self.database_mapping = Native.Router.Lisp.Default.Ipv6.DatabaseMapping()
                        self.database_mapping.parent = self
                        self._children_name_map["database_mapping"] = "database-mapping"

                        self.distance = Native.Router.Lisp.Default.Ipv6.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"

                        self.itr = Native.Router.Lisp.Default.Ipv6.Itr()
                        self.itr.parent = self
                        self._children_name_map["itr"] = "itr"

                        self.itr_enable = Native.Router.Lisp.Default.Ipv6.ItrEnable()
                        self.itr_enable.parent = self
                        self._children_name_map["itr_enable"] = "itr-enable"

                        self.etr = Native.Router.Lisp.Default.Ipv6.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.etr_enable = Native.Router.Lisp.Default.Ipv6.EtrEnable()
                        self.etr_enable.parent = self
                        self._children_name_map["etr_enable"] = "etr-enable"

                        self.locator = Native.Router.Lisp.Default.Ipv6.Locator()
                        self.locator.parent = self
                        self._children_name_map["locator"] = "locator"

                        self.map_cache = Native.Router.Lisp.Default.Ipv6.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"

                        self.map_cache_limit = Native.Router.Lisp.Default.Ipv6.MapCacheLimit()
                        self.map_cache_limit.parent = self
                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                        self.map_cache_persistent = Native.Router.Lisp.Default.Ipv6.MapCachePersistent()
                        self.map_cache_persistent.parent = self
                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                        self.map_resolver = None
                        self._children_name_map["map_resolver"] = "map-resolver"

                        self.map_server = None
                        self._children_name_map["map_server"] = "map-server"

                        self.path_mtu_discovery = None
                        self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                        self.route_export = Native.Router.Lisp.Default.Ipv6.RouteExport()
                        self.route_export.parent = self
                        self._children_name_map["route_export"] = "route-export"

                        self.route_import = Native.Router.Lisp.Default.Ipv6.RouteImport()
                        self.route_import.parent = self
                        self._children_name_map["route_import"] = "route-import"

                        self.site_registration = Native.Router.Lisp.Default.Ipv6.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.solicit_map_request = Native.Router.Lisp.Default.Ipv6.SolicitMapRequest()
                        self.solicit_map_request.parent = self
                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                        self.source_locator = Native.Router.Lisp.Default.Ipv6.SourceLocator()
                        self.source_locator.parent = self
                        self._children_name_map["source_locator"] = "source-locator"

                        self.use_petr = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Address family specific local EID prefixes database configuration
                        
                        .. attribute:: limit
                        
                        	Configures the maximum size of local EID prefixes database
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.DatabaseMapping.Limit>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Default.Ipv6.DatabaseMapping.Limit))])
                            self._leafs = OrderedDict()

                            self.limit = Native.Router.Lisp.Default.Ipv6.DatabaseMapping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "database-mapping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.DatabaseMapping, [], name, value)


                        class Limit(Entity):
                            """
                            Configures the maximum size of local EID prefixes database
                            
                            .. attribute:: dynamic
                            
                            	Configures the maximum size of dynamic local EID prefixes database
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.DatabaseMapping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "database-mapping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.dynamic = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/database-mapping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                    class Distance(Entity):
                        """
                        Administrative distance for RIB route installation
                        
                        .. attribute:: alt
                        
                        	LISP routes installed in the ALT table
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dyn_eid
                        
                        	LISP installed routes of type dynamic\-EID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: site_registrations
                        
                        	LISP installed routes of type site\-registrations
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                            ])
                            self.alt = None
                            self.dyn_eid = None
                            self.site_registrations = None
                            self._segment_path = lambda: "distance"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                    class Itr(Entity):
                        """
                        Configures a LISP Ingress Tunnel Router (ITR)
                        
                        .. attribute:: map_resolver
                        
                        	Configures map\-resolver address for sending Map\-Requests
                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.Itr.MapResolver>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.Itr, self).__init__()

                            self.yang_name = "itr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.Ipv6.Itr.MapResolver))])
                            self._leafs = OrderedDict()

                            self.map_resolver = YList(self)
                            self._segment_path = lambda: "itr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.Itr, [], name, value)


                        class MapResolver(Entity):
                            """
                            Configures map\-resolver address for sending Map\-Requests
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.Itr.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "itr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                ])
                                self.ip_addr = None
                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/itr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.Itr.MapResolver, ['ip_addr'], name, value)


                    class ItrEnable(Entity):
                        """
                        
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.ItrEnable, self).__init__()

                            self.yang_name = "itr-enable"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                            ])
                            self.itr = None
                            self._segment_path = lambda: "itr-enable"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.ItrEnable, ['itr'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.Etr.MapServer>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.Ipv6.Etr.MapServer))])
                            self._leafs = OrderedDict()

                            self.map_server = YList(self)
                            self._segment_path = lambda: "etr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.Etr, [], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.Etr.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.Ipv6.Etr.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.Lisp.Default.Ipv6.Etr.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/etr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: key_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: key_7
                                
                                	The HIDDEN password
                                	**type**\: str
                                
                                .. attribute:: pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.Etr.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                        ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                        ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                        ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                    ])
                                    self.key_0 = None
                                    self.key_6 = None
                                    self.key_7 = None
                                    self.pwd = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                    class EtrEnable(Entity):
                        """
                        
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.EtrEnable, self).__init__()

                            self.yang_name = "etr-enable"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                            ])
                            self.etr = None
                            self._segment_path = lambda: "etr-enable"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.EtrEnable, ['etr'], name, value)


                    class Locator(Entity):
                        """
                        Locator related configuration
                        
                        .. attribute:: reachability
                        
                        	Configuration realted to locator reachability
                        	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.Locator.Reachability>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.Locator, self).__init__()

                            self.yang_name = "locator"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.Lisp.Default.Ipv6.Locator.Reachability))])
                            self._leafs = OrderedDict()

                            self.reachability = Native.Router.Lisp.Default.Ipv6.Locator.Reachability()
                            self.reachability.parent = self
                            self._children_name_map["reachability"] = "reachability"
                            self._segment_path = lambda: "locator"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.Locator, [], name, value)


                        class Reachability(Entity):
                            """
                            Configuration realted to locator reachability
                            
                            .. attribute:: exclude_default
                            
                            	If a remote RLOC is reached via the default route, treat it as unreachable
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.Locator.Reachability, self).__init__()

                                self.yang_name = "reachability"
                                self.yang_parent_name = "locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                ])
                                self.exclude_default = None
                                self._segment_path = lambda: "reachability"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/locator/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.Locator.Reachability, ['exclude_default'], name, value)


                    class MapCache(Entity):
                        """
                        Address family specific map cache configuration
                        
                        .. attribute:: site_registration
                        
                        	Install map cache to map request for site registrations
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                            ])
                            self.site_registration = None
                            self._segment_path = lambda: "map-cache"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.MapCache, ['site_registration'], name, value)


                    class MapCacheLimit(Entity):
                        """
                        Configures maximum size of map\-cache
                        
                        .. attribute:: max_map_cache_entries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..100000
                        
                        .. attribute:: reserve_list
                        
                        	EID\-prefixes guaranteed to be stored in map\-cache
                        	**type**\: str
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.MapCacheLimit, self).__init__()

                            self.yang_name = "map-cache-limit"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.max_map_cache_entries = None
                            self.reserve_list = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "map-cache-limit"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                    class MapCachePersistent(Entity):
                        """
                        Dump map\-cache onto flash, making it persistent across reboots
                        
                        .. attribute:: interval
                        
                        	Interval in minutes of how often the map\-cache is saved
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.MapCachePersistent, self).__init__()

                            self.yang_name = "map-cache-persistent"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "map-cache-persistent"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.MapCachePersistent, ['interval'], name, value)


                    class MapResolver(Entity):
                        """
                        Configures a LISP Map Resolver (MR)
                        
                        .. attribute:: map_request
                        
                        	Map\-Request processing options
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_request = Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"
                            self._segment_path = lambda: "map-resolver"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.MapResolver, [], name, value)


                        class MapRequest(Entity):
                            """
                            Map\-Request processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "map-resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-request"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/map-resolver/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	Influence which source RLOCs map requests are accepted from
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/map-resolver/map-request/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    Influence which source RLOCs map requests are accepted from
                                    
                                    .. attribute:: list
                                    
                                    	Define allowed prefixes using an ip[v6] prefix list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: registered
                                    
                                    	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 prefixes
                                    	**type**\: str
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 prefixes
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                            ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.list = None
                                        self.registered = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "source"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/map-resolver/map-request/validate/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                    class MapServer(Entity):
                        """
                        Configures a LISP Map Server (MS)
                        
                        .. attribute:: map_register
                        
                        	Map\-Register processing options
                        	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_register = Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister()
                            self.map_register.parent = self
                            self._children_name_map["map_register"] = "map-register"
                            self._segment_path = lambda: "map-server"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.MapServer, [], name, value)


                        class MapRegister(Entity):
                            """
                            Map\-Register processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister, self).__init__()

                                self.yang_name = "map-register"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-register"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/map-server/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	RLOC Source IP address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-register"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/map-server/map-register/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    RLOC Source IP address
                                    
                                    .. attribute:: allowed_locator
                                    
                                    	Against sites' allowed\-locators policy
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                        ])
                                        self.allowed_locator = None
                                        self._segment_path = lambda: "source"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/map-server/map-register/validate/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                    class PathMtuDiscovery(Entity):
                        """
                        Path MTU discovery
                        
                        .. attribute:: max
                        
                        	Upper bound on the path MTU accepted
                        	**type**\: int
                        
                        	**range:** 68..65535
                        
                        .. attribute:: min
                        
                        	Lower bound on the path MTU accepted
                        	**type**\: int
                        
                        	**range:** 68..65535
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.PathMtuDiscovery, self).__init__()

                            self.yang_name = "path-mtu-discovery"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                            ])
                            self.max = None
                            self.min = None
                            self._segment_path = lambda: "path-mtu-discovery"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.PathMtuDiscovery, ['max', 'min'], name, value)


                    class RouteExport(Entity):
                        """
                        Export routes into RIB from LISP
                        
                        .. attribute:: site_registrations
                        
                        	Export LISP site registrations to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: away_eids
                        
                        	Export LISP away EIDs to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.RouteExport, self).__init__()

                            self.yang_name = "route-export"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                            ])
                            self.site_registrations = None
                            self.away_eids = None
                            self._segment_path = lambda: "route-export"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                    class RouteImport(Entity):
                        """
                        Import RIB routes by a routing protocol into LISP
                        
                        .. attribute:: database
                        
                        	Use RIB routes to define local EID database entries
                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database>`
                        
                        .. attribute:: map_cache
                        
                        	Use RIB routes to define EID address space in map\-cache
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.RouteImport, self).__init__()

                            self.yang_name = "route-import"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache))])
                            self._leafs = OrderedDict()

                            self.database = Native.Router.Lisp.Default.Ipv6.RouteImport.Database()
                            self.database.parent = self
                            self._children_name_map["database"] = "database"

                            self.map_cache = Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"
                            self._segment_path = lambda: "route-import"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport, [], name, value)


                        class Database(Entity):
                            """
                            Use RIB routes to define local EID database entries
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Connected>`
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Isis>`
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes to pick up from the RIB
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.MaximumPrefix>`
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospfv3>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Rip>`
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Static>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database, self).__init__()

                                self.yang_name = "database"
                                self.yang_parent_name = "route-import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Rip)), ("static", ("static", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Static))])
                                self._leafs = OrderedDict()

                                self.connected = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Connected()
                                self.connected.parent = self
                                self._children_name_map["connected"] = "connected"

                                self.maximum_prefix = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.rip = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Rip()
                                self.rip.parent = self
                                self._children_name_map["rip"] = "rip"

                                self.static = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Static()
                                self.static.parent = self
                                self._children_name_map["static"] = "static"

                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.isis = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self._segment_path = lambda: "database"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database, [], name, value)


                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "connected"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Connected, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/connected/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Isis, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes to pick up from the RIB
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: warning_only
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: threshold
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: warning_only1
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.warning_only = None
                                    self.threshold = None
                                    self.threshold1 = None
                                    self.warning_only1 = None
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Ospfv3(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospfv3, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospfv3, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "rip"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Rip, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/rip/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "static"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Static, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/database/static/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class MapCache(Entity):
                            """
                            Use RIB routes to define EID address space in map\-cache
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Isis>`
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes to pick up from the RIB
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospfv3>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Rip>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Static>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "route-import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Static))])
                                self._leafs = OrderedDict()

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.maximum_prefix = Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.rip = None
                                self._children_name_map["rip"] = "rip"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.isis = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self._segment_path = lambda: "map-cache"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache, [], name, value)


                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "connected"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/connected/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes to pick up from the RIB
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: warning_only
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: threshold
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: warning_only1
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.warning_only = None
                                    self.threshold = None
                                    self.threshold1 = None
                                    self.warning_only1 = None
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                            class Ospfv3(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospfv3, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "rip"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Rip, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/rip/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "static"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/route-import/map-cache/static/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                    class SiteRegistration(Entity):
                        """
                        Site registrations configuration for a given instance\-id
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations for a given instance\-id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class SolicitMapRequest(Entity):
                        """
                        Configure Solicit\-Map\-Request handling
                        
                        .. attribute:: ignore
                        
                        	Ignore SMR bit in incoming Map\-Requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_per_entry
                        
                        	Maximum number of SMRs for addresses under a map\-cache entry
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: suppression_time
                        
                        	How long to suppress repeated SMRs for the same address
                        	**type**\: int
                        
                        	**range:** 1..600
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.SolicitMapRequest, self).__init__()

                            self.yang_name = "solicit-map-request"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                            ])
                            self.ignore = None
                            self.max_per_entry = None
                            self.suppression_time = None
                            self._segment_path = lambda: "solicit-map-request"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                    class SourceLocator(Entity):
                        """
                        Source Locator configuration
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.SourceLocator.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.SourceLocator.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.SourceLocator.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Ipv6.SourceLocator.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.SourceLocator, self).__init__()

                            self.yang_name = "source-locator"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Lisp.Default.Ipv6.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Lisp.Default.Ipv6.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Lisp.Default.Ipv6.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Lisp.Default.Ipv6.SourceLocator.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Router.Lisp.Default.Ipv6.SourceLocator.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Router.Lisp.Default.Ipv6.SourceLocator.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Router.Lisp.Default.Ipv6.SourceLocator.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Router.Lisp.Default.Ipv6.SourceLocator.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "source-locator"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.SourceLocator.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/source-locator/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.SourceLocator.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/source-locator/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.SourceLocator.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/source-locator/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Ipv6.SourceLocator.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/source-locator/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Ipv6.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                    class UsePetr(Entity):
                        """
                        Encapsulate to Proxy ETR when matching forward\-native entry
                        
                        .. attribute:: locator_address  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	Configures which Locators from a set are preferred
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: weight
                        
                        	Traffic load\-spreading among Locators
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Ipv6.UsePetr, self).__init__()

                            self.yang_name = "use-petr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['locator_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                            ])
                            self.locator_address = None
                            self.priority = None
                            self.weight = None
                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Ipv6.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                class LocReachAlgorithm(Entity):
                    """
                    Configure locator reachability algorithm
                    
                    .. attribute:: lsb_reports
                    
                    	Configure data packet LSB report handling
                    	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.LocReachAlgorithm.LsbReports>`
                    
                    .. attribute:: rloc_probing
                    
                    	Probe high priority RLOCs with Map\-Requests as last resort
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.LocReachAlgorithm, self).__init__()

                        self.yang_name = "loc-reach-algorithm"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.Lisp.Default.LocReachAlgorithm.LsbReports))])
                        self._leafs = OrderedDict([
                            ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                        ])
                        self.rloc_probing = None

                        self.lsb_reports = Native.Router.Lisp.Default.LocReachAlgorithm.LsbReports()
                        self.lsb_reports.parent = self
                        self._children_name_map["lsb_reports"] = "lsb-reports"
                        self._segment_path = lambda: "loc-reach-algorithm"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.LocReachAlgorithm, ['rloc_probing'], name, value)


                    class LsbReports(Entity):
                        """
                        Configure data packet LSB report handling
                        
                        .. attribute:: do_not_transmit
                        
                        	Force the setting of the encapsulation header L bit to zero
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore data packet LSB reports
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.LocReachAlgorithm.LsbReports, self).__init__()

                            self.yang_name = "lsb-reports"
                            self.yang_parent_name = "loc-reach-algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.do_not_transmit = None
                            self.ignore = None
                            self._segment_path = lambda: "lsb-reports"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/loc-reach-algorithm/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                class LocatorDown(Entity):
                    """
                    Manually set locator status to down
                    
                    .. attribute:: address
                    
                    	IPv4/6 Locator address to be set down
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv4_interface
                    
                    	Use IPv4 address of interface as locator
                    	**type**\: str
                    
                    .. attribute:: ipv6_interface
                    
                    	Use IPv6 address of interface as locator
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.LocatorDown, self).__init__()

                        self.yang_name = "locator-down"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                            ('ipv4_interface', (YLeaf(YType.str, 'IPv4-interface'), ['str'])),
                            ('ipv6_interface', (YLeaf(YType.str, 'IPv6-interface'), ['str'])),
                        ])
                        self.address = None
                        self.ipv4_interface = None
                        self.ipv6_interface = None
                        self._segment_path = lambda: "locator-down"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.LocatorDown, ['address', 'ipv4_interface', 'ipv6_interface'], name, value)


                class LocatorTable(Entity):
                    """
                    Specify the RLOC table
                    
                    .. attribute:: vrf_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	Default VRF
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.LocatorTable, self).__init__()

                        self.yang_name = "locator-table"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.vrf_name = None
                        self.default = None
                        self.vrf = None
                        self._segment_path = lambda: "locator-table"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.LocatorTable, ['vrf_name', 'default', 'vrf'], name, value)


                class MapRequest(Entity):
                    """
                    Configure map\-request handling
                    
                    .. attribute:: itr_rlocs
                    
                    	Configure to use the specified RLOC set as ITR RLOC in map\-request
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.MapRequest, self).__init__()

                        self.yang_name = "map-request"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('itr_rlocs', (YLeaf(YType.str, 'itr-rlocs'), ['str'])),
                        ])
                        self.itr_rlocs = None
                        self._segment_path = lambda: "map-request"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.MapRequest, ['itr_rlocs'], name, value)


                class MapServer(Entity):
                    """
                    Map\-Server commands
                    
                    .. attribute:: rloc
                    
                    	EID instance RLOC membership
                    	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.MapServer.Rloc>`
                    
                    .. attribute:: site_registration
                    
                    	Map\-server site registration options
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.MapServer.SiteRegistration>`
                    
                    .. attribute:: nmr
                    
                    	Map\-server negative map\-reply optio
                    	**type**\:  :py:class:`Nmr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.MapServer.Nmr>`
                    
                    .. attribute:: session
                    
                    	Map\-server session
                    	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.MapServer.Session>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.MapServer, self).__init__()

                        self.yang_name = "map-server"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.Default.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.MapServer.SiteRegistration)), ("nmr", ("nmr", Native.Router.Lisp.Default.MapServer.Nmr)), ("session", ("session", Native.Router.Lisp.Default.MapServer.Session))])
                        self._leafs = OrderedDict()

                        self.rloc = Native.Router.Lisp.Default.MapServer.Rloc()
                        self.rloc.parent = self
                        self._children_name_map["rloc"] = "rloc"

                        self.site_registration = Native.Router.Lisp.Default.MapServer.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.nmr = Native.Router.Lisp.Default.MapServer.Nmr()
                        self.nmr.parent = self
                        self._children_name_map["nmr"] = "nmr"

                        self.session = Native.Router.Lisp.Default.MapServer.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                        self._segment_path = lambda: "map-server"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.MapServer, [], name, value)


                    class Rloc(Entity):
                        """
                        EID instance RLOC membership
                        
                        .. attribute:: members
                        
                        	EID instance RLOC membership
                        	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.MapServer.Rloc.Members>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.MapServer.Rloc, self).__init__()

                            self.yang_name = "rloc"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("members", ("members", Native.Router.Lisp.Default.MapServer.Rloc.Members))])
                            self._leafs = OrderedDict()

                            self.members = Native.Router.Lisp.Default.MapServer.Rloc.Members()
                            self.members.parent = self
                            self._children_name_map["members"] = "members"
                            self._segment_path = lambda: "rloc"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/map-server/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.MapServer.Rloc, [], name, value)


                        class Members(Entity):
                            """
                            EID instance RLOC membership
                            
                            .. attribute:: distribute
                            
                            	EID instance RLOC membership distribution
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: modify_discovered
                            
                            	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                            	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.MapServer.Rloc.Members.ModifyDiscovered>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.MapServer.Rloc.Members, self).__init__()

                                self.yang_name = "members"
                                self.yang_parent_name = "rloc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.Lisp.Default.MapServer.Rloc.Members.ModifyDiscovered))])
                                self._leafs = OrderedDict([
                                    ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                ])
                                self.distribute = None

                                self.modify_discovered = Native.Router.Lisp.Default.MapServer.Rloc.Members.ModifyDiscovered()
                                self.modify_discovered.parent = self
                                self._children_name_map["modify_discovered"] = "modify-discovered"
                                self._segment_path = lambda: "members"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/map-server/rloc/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.MapServer.Rloc.Members, ['distribute'], name, value)


                            class ModifyDiscovered(Entity):
                                """
                                Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                
                                .. attribute:: operator
                                
                                	
                                	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                
                                .. attribute:: locator_set
                                
                                	Locator set from which to get member RLOC addresses
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                    self.yang_name = "modify-discovered"
                                    self.yang_parent_name = "members"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.operator = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "modify-discovered"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/map-server/rloc/members/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                class Operator(Enum):
                                    """
                                    Operator (Enum Class)

                                    .. data:: add = 0

                                    .. data:: override = 1

                                    """

                                    add = Enum.YLeaf(0, "add")

                                    override = Enum.YLeaf(1, "override")



                    class SiteRegistration(Entity):
                        """
                        Map\-server site registration options
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations as a result of accept\-more\-specifics
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.MapServer.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/map-server/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class Nmr(Entity):
                        """
                        Map\-server negative map\-reply optio
                        
                        .. attribute:: non_site_ttl
                        
                        	Negative map\-reply TTL for non\-site EID
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.MapServer.Nmr, self).__init__()

                            self.yang_name = "nmr"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('non_site_ttl', (YLeaf(YType.uint16, 'non-site-ttl'), ['int'])),
                            ])
                            self.non_site_ttl = None
                            self._segment_path = lambda: "nmr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/map-server/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.MapServer.Nmr, ['non_site_ttl'], name, value)


                    class Session(Entity):
                        """
                        Map\-server session
                        
                        .. attribute:: passive_open
                        
                        	Open passive TCP sockets to listen for incoming connections
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.MapServer.Session, self).__init__()

                            self.yang_name = "session"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('passive_open', (YLeaf(YType.str, 'passive-open'), ['str'])),
                            ])
                            self.passive_open = None
                            self._segment_path = lambda: "session"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/map-server/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.MapServer.Session, ['passive_open'], name, value)


                class OtherXtrProbe(Entity):
                    """
                    Configure parameters for probing of other xTRs in our site
                    
                    .. attribute:: period
                    
                    	Period between probes in seconds
                    	**type**\: int
                    
                    	**range:** 5..900
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.OtherXtrProbe, self).__init__()

                        self.yang_name = "other-xtr-probe"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                        ])
                        self.period = None
                        self._segment_path = lambda: "other-xtr-probe"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.OtherXtrProbe, ['period'], name, value)


                class RemoteRlocProbe(Entity):
                    """
                    Configure parameters for probing of remote RLOCs
                    
                    .. attribute:: on_membership_change
                    
                    	Trigger probing upon membership changes for remote RLOC
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: on_route_change
                    
                    	Trigger probing upon routing changes for remote RLOC
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.RemoteRlocProbe, self).__init__()

                        self.yang_name = "remote-rloc-probe"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                            ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                        ])
                        self.on_membership_change = None
                        self.on_route_change = None
                        self._segment_path = lambda: "remote-rloc-probe"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                class EidTable(Entity):
                    """
                    Configure an EID instance for a VRF
                    
                    .. attribute:: instance_list
                    
                    	
                    	**type**\: list of  		 :py:class:`InstanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.EidTable, self).__init__()

                        self.yang_name = "eid-table"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("instance-list", ("instance_list", Native.Router.Lisp.Default.EidTable.InstanceList))])
                        self._leafs = OrderedDict()

                        self.instance_list = YList(self)
                        self._segment_path = lambda: "eid-table"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.EidTable, [], name, value)


                    class InstanceList(Entity):
                        """
                        
                        
                        .. attribute:: instance_id  (key)
                        
                        	EID instance\-ID
                        	**type**\: int
                        
                        	**range:** 0..16777214
                        
                        .. attribute:: vrf_name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: default
                        
                        	Default VRF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vrf
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: database_mapping
                        
                        	Configures Locator addresses for an ETR
                        	**type**\: list of  		 :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.DatabaseMapping>`
                        
                        .. attribute:: dynamic_eid
                        
                        	Configure a dynamic EID
                        	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid>`
                        
                        .. attribute:: alt
                        
                        	LISP Alternative Topology, LISP\-ALT
                        	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Alt>`
                        
                        .. attribute:: control_packet
                        
                        	Configure control packet tx option
                        	**type**\:  :py:class:`ControlPacket <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.ControlPacket>`
                        
                        .. attribute:: ddt
                        
                        	Delegated Database Tree (DDT) mapping system
                        	**type**\:  :py:class:`Ddt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ddt>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: decapsulation
                        
                        	Decapsulation behavior (e.g. filters)
                        	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation>`
                        
                        .. attribute:: disable_ttl_propagate
                        
                        	Disable ttl propagation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Etr>`
                        
                        .. attribute:: ipv4
                        
                        	IPv4 address family
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	IPv6 address family
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6>`
                        
                        .. attribute:: loc_reach_algorithm
                        
                        	Configure locator reachability algorithm
                        	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.LocReachAlgorithm>`
                        
                        .. attribute:: locator_down
                        
                        	Manually set locator status to down
                        	**type**\:  :py:class:`LocatorDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.LocatorDown>`
                        
                        .. attribute:: locator_table
                        
                        	Specify the RLOC table
                        	**type**\:  :py:class:`LocatorTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.LocatorTable>`
                        
                        .. attribute:: map_request
                        
                        	Configure map\-request handling
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.MapRequest>`
                        
                        .. attribute:: map_server
                        
                        	Map\-Server commands
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.MapServer>`
                        
                        .. attribute:: other_xtr_probe
                        
                        	Configure parameters for probing of other xTRs in our site
                        	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.OtherXtrProbe>`
                        
                        .. attribute:: remote_rloc_probe
                        
                        	Configure parameters for probing of remote RLOCs
                        	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.RemoteRlocProbe>`
                        
                        .. attribute:: map_cache
                        
                        	Configures static EID\-to\-RLOC mappings for an ITR
                        	**type**\: list of  		 :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.MapCache>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.EidTable.InstanceList, self).__init__()

                            self.yang_name = "instance-list"
                            self.yang_parent_name = "eid-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['instance_id']
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Default.EidTable.InstanceList.DatabaseMapping)), ("dynamic-eid", ("dynamic_eid", Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid)), ("alt", ("alt", Native.Router.Lisp.Default.EidTable.InstanceList.Alt)), ("control-packet", ("control_packet", Native.Router.Lisp.Default.EidTable.InstanceList.ControlPacket)), ("ddt", ("ddt", Native.Router.Lisp.Default.EidTable.InstanceList.Ddt)), ("decapsulation", ("decapsulation", Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation)), ("etr", ("etr", Native.Router.Lisp.Default.EidTable.InstanceList.Etr)), ("ipv4", ("ipv4", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4)), ("ipv6", ("ipv6", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.Lisp.Default.EidTable.InstanceList.LocReachAlgorithm)), ("locator-down", ("locator_down", Native.Router.Lisp.Default.EidTable.InstanceList.LocatorDown)), ("locator-table", ("locator_table", Native.Router.Lisp.Default.EidTable.InstanceList.LocatorTable)), ("map-request", ("map_request", Native.Router.Lisp.Default.EidTable.InstanceList.MapRequest)), ("map-server", ("map_server", Native.Router.Lisp.Default.EidTable.InstanceList.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.Lisp.Default.EidTable.InstanceList.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.Lisp.Default.EidTable.InstanceList.RemoteRlocProbe)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.EidTable.InstanceList.MapCache))])
                            self._leafs = OrderedDict([
                                ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                            ])
                            self.instance_id = None
                            self.vrf_name = None
                            self.default = None
                            self.vrf = None
                            self.disable_ttl_propagate = None

                            self.alt = Native.Router.Lisp.Default.EidTable.InstanceList.Alt()
                            self.alt.parent = self
                            self._children_name_map["alt"] = "alt"

                            self.control_packet = Native.Router.Lisp.Default.EidTable.InstanceList.ControlPacket()
                            self.control_packet.parent = self
                            self._children_name_map["control_packet"] = "control-packet"

                            self.ddt = None
                            self._children_name_map["ddt"] = "ddt"

                            self.decapsulation = Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation()
                            self.decapsulation.parent = self
                            self._children_name_map["decapsulation"] = "decapsulation"

                            self.etr = Native.Router.Lisp.Default.EidTable.InstanceList.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.ipv4 = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.loc_reach_algorithm = Native.Router.Lisp.Default.EidTable.InstanceList.LocReachAlgorithm()
                            self.loc_reach_algorithm.parent = self
                            self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                            self.locator_down = Native.Router.Lisp.Default.EidTable.InstanceList.LocatorDown()
                            self.locator_down.parent = self
                            self._children_name_map["locator_down"] = "locator-down"

                            self.locator_table = Native.Router.Lisp.Default.EidTable.InstanceList.LocatorTable()
                            self.locator_table.parent = self
                            self._children_name_map["locator_table"] = "locator-table"

                            self.map_request = Native.Router.Lisp.Default.EidTable.InstanceList.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"

                            self.map_server = Native.Router.Lisp.Default.EidTable.InstanceList.MapServer()
                            self.map_server.parent = self
                            self._children_name_map["map_server"] = "map-server"

                            self.other_xtr_probe = Native.Router.Lisp.Default.EidTable.InstanceList.OtherXtrProbe()
                            self.other_xtr_probe.parent = self
                            self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                            self.remote_rloc_probe = Native.Router.Lisp.Default.EidTable.InstanceList.RemoteRlocProbe()
                            self.remote_rloc_probe.parent = self
                            self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                            self.database_mapping = YList(self)
                            self.dynamic_eid = YList(self)
                            self.map_cache = YList(self)
                            self._segment_path = lambda: "instance-list" + "[instance-id='" + str(self.instance_id) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/eid-table/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList, ['instance_id', 'vrf_name', 'default', 'vrf', 'disable_ttl_propagate'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Configures Locator addresses for an ETR
                            
                            .. attribute:: eid_prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: locator_set
                            
                            	Use locators defined by locator\-set
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['eid_prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                ])
                                self.eid_prefix = None
                                self.locator_set = None
                                self._segment_path = lambda: "database-mapping" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.DatabaseMapping, ['eid_prefix', 'locator_set'], name, value)


                        class DynamicEid(Entity):
                            """
                            Configure a dynamic EID
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: database_mapping
                            
                            	Configures EID\-prefix and locator\-set for dynamic\-EID
                            	**type**\: list of  		 :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.DatabaseMapping>`
                            
                            .. attribute:: eid_notify
                            
                            	Configure options for sending/receiving EID\-notify
                            	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify>`
                            
                            .. attribute:: map_notify_group
                            
                            	Multicast group which to send map\-notifies to
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid, self).__init__()

                                self.yang_name = "dynamic-eid"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.MapServer))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                                ])
                                self.name = None
                                self.map_notify_group = None

                                self.eid_notify = Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify()
                                self.eid_notify.parent = self
                                self._children_name_map["eid_notify"] = "eid-notify"

                                self.database_mapping = YList(self)
                                self.map_server = YList(self)
                                self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid, ['name', 'map_notify_group'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures EID\-prefix and locator\-set for dynamic\-EID
                                
                                .. attribute:: eid_prefix  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                .. attribute:: locator_set
                                
                                	Use locators defined by locator\-set
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['eid_prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.eid_prefix = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "database-mapping" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.DatabaseMapping, ['eid_prefix', 'locator_set'], name, value)


                            class EidNotify(Entity):
                                """
                                Configure options for sending/receiving EID\-notify
                                
                                .. attribute:: authentication_key
                                
                                	Authentication key used for validating received EID\-notify
                                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey>`
                                
                                .. attribute:: gateway_key
                                
                                	
                                	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify, self).__init__()

                                    self.yang_name = "eid-notify"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey))])
                                    self._leafs = OrderedDict()

                                    self.authentication_key = Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey()
                                    self.authentication_key.parent = self
                                    self._children_name_map["authentication_key"] = "authentication-key"

                                    self.gateway_key = YList(self)
                                    self._segment_path = lambda: "eid-notify"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify, [], name, value)


                                class AuthenticationKey(Entity):
                                    """
                                    Authentication key used for validating received EID\-notify
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                        self.yang_name = "authentication-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                        ])
                                        self.ak_0 = None
                                        self.ak_6 = None
                                        self.unc_pwd = None
                                        self._segment_path = lambda: "authentication-key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey, ['ak_0', 'ak_6', 'unc_pwd'], name, value)


                                class GatewayKey(Entity):
                                    """
                                    
                                    
                                    .. attribute:: gateway_ip  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	EID\-notify authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey.HashFunction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                        self.yang_name = "gateway-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['gateway_ip']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey.HashFunction')])),
                                        ])
                                        self.gateway_ip = None
                                        self.ak_0 = None
                                        self.ak_6 = None
                                        self.unc_pwd = None
                                        self.hash_function = None
                                        self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey, ['gateway_ip', 'ak_0', 'ak_6', 'unc_pwd', 'hash_function'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        EID\-notify authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip='" + str(self.ip) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.MapServer, ['ip', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: key_7
                                    
                                    	The HIDDEN password
                                    	**type**\: str
                                    
                                    .. attribute:: pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	Map\-Register authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.MapServer.Key.HashFunction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                            ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.EidTable.InstanceList.DynamicEid.MapServer.Key.HashFunction')])),
                                        ])
                                        self.key_0 = None
                                        self.key_6 = None
                                        self.key_7 = None
                                        self.pwd = None
                                        self.hash_function = None
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.DynamicEid.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd', 'hash_function'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        Map\-Register authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                        class Alt(Entity):
                            """
                            LISP Alternative Topology, LISP\-ALT
                            
                            .. attribute:: summary_route
                            
                            	Summary route to install into the ALT table
                            	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Alt.SummaryRoute>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Alt, self).__init__()

                                self.yang_name = "alt"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.Default.EidTable.InstanceList.Alt.SummaryRoute))])
                                self._leafs = OrderedDict()

                                self.summary_route = YList(self)
                                self._segment_path = lambda: "alt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Alt, [], name, value)


                            class SummaryRoute(Entity):
                                """
                                Summary route to install into the ALT table
                                
                                .. attribute:: eid_prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: route_tag
                                
                                	ALT RIB route tag for EID prefix
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Alt.SummaryRoute, self).__init__()

                                    self.yang_name = "summary-route"
                                    self.yang_parent_name = "alt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['eid_prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.eid_prefix = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                        class ControlPacket(Entity):
                            """
                            Configure control packet tx option
                            
                            .. attribute:: mtu
                            
                            	Configure control packet MTU
                            	**type**\: int
                            
                            	**range:** 304..10000
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.ControlPacket, self).__init__()

                                self.yang_name = "control-packet"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                                ])
                                self.mtu = None
                                self._segment_path = lambda: "control-packet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.ControlPacket, ['mtu'], name, value)


                        class Ddt(Entity):
                            """
                            Delegated Database Tree (DDT) mapping system
                            
                            .. attribute:: authoritative
                            
                            	DDT authoritative prefix
                            	**type**\:  :py:class:`Authoritative <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative>`
                            
                            .. attribute:: cache_limit
                            
                            	DDT resolver cache entry limit
                            	**type**\: int
                            
                            	**range:** 1..100000
                            
                            .. attribute:: root
                            
                            	DDT root node
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt, self).__init__()

                                self.yang_name = "ddt"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authoritative", ("authoritative", Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('cache_limit', (YLeaf(YType.uint32, 'cache-limit'), ['int'])),
                                    ('root', (YLeaf(YType.str, 'root'), ['str','str'])),
                                ])
                                self.cache_limit = None
                                self.root = None

                                self.authoritative = Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative()
                                self.authoritative.parent = self
                                self._children_name_map["authoritative"] = "authoritative"
                                self._segment_path = lambda: "ddt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt, ['cache_limit', 'root'], name, value)


                            class Authoritative(Entity):
                                """
                                DDT authoritative prefix
                                
                                .. attribute:: instance_id_eid_prefix_list
                                
                                	
                                	**type**\: list of  		 :py:class:`InstanceIdEidPrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList>`
                                
                                .. attribute:: instance_id_list
                                
                                	
                                	**type**\: list of  		 :py:class:`InstanceIdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative, self).__init__()

                                    self.yang_name = "authoritative"
                                    self.yang_parent_name = "ddt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("instance-id-eid-prefix-list", ("instance_id_eid_prefix_list", Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList)), ("instance-id-list", ("instance_id_list", Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList))])
                                    self._leafs = OrderedDict()

                                    self.instance_id_eid_prefix_list = YList(self)
                                    self.instance_id_list = YList(self)
                                    self._segment_path = lambda: "authoritative"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative, [], name, value)


                                class InstanceIdEidPrefixList(Entity):
                                    """
                                    
                                    
                                    .. attribute:: instance_id  (key)
                                    
                                    	EID instance\-ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: delegate
                                    
                                    	DDT delegation to a child DDT node or map\-server
                                    	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate>`
                                    
                                    .. attribute:: map_server_peer
                                    
                                    	Peer map\-servers that are authoritative for the same EID prefixes
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList, self).__init__()

                                        self.yang_name = "instance-id-eid-prefix-list"
                                        self.yang_parent_name = "authoritative"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['instance_id','eid_prefix']
                                        self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate))])
                                        self._leafs = OrderedDict([
                                            ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                        ])
                                        self.instance_id = None
                                        self.eid_prefix = None
                                        self.map_server_peer = None

                                        self.delegate = Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate()
                                        self.delegate.parent = self
                                        self._children_name_map["delegate"] = "delegate"
                                        self._segment_path = lambda: "instance-id-eid-prefix-list" + "[instance-id='" + str(self.instance_id) + "']" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList, ['instance_id', 'eid_prefix', 'map_server_peer'], name, value)


                                    class Delegate(Entity):
                                        """
                                        DDT delegation to a child DDT node or map\-server
                                        
                                        .. attribute:: eid_prefix
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: instance_id
                                        
                                        	EID instance\-ID
                                        	**type**\: str
                                        
                                        .. attribute:: to
                                        
                                        	DDT delegation to a child DDT node or map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ip_address
                                        
                                        	IPv4/6 Child or map\-server node locator address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: map_server
                                        
                                        	Delegation points to a map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, self).__init__()

                                            self.yang_name = "delegate"
                                            self.yang_parent_name = "instance-id-eid-prefix-list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                                ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                                ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                                ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.instance_id = None
                                            self.to = None
                                            self.ip_address = None
                                            self.map_server = None
                                            self._segment_path = lambda: "delegate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                                class InstanceIdList(Entity):
                                    """
                                    
                                    
                                    .. attribute:: instance_id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: delegate
                                    
                                    	DDT delegation to a child DDT node or map\-server
                                    	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate>`
                                    
                                    .. attribute:: map_server_peer
                                    
                                    	Peer map\-servers that are authoritative for the same EID prefixes
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList, self).__init__()

                                        self.yang_name = "instance-id-list"
                                        self.yang_parent_name = "authoritative"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['instance_id']
                                        self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate))])
                                        self._leafs = OrderedDict([
                                            ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                            ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                        ])
                                        self.instance_id = None
                                        self.map_server_peer = None

                                        self.delegate = Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate()
                                        self.delegate.parent = self
                                        self._children_name_map["delegate"] = "delegate"
                                        self._segment_path = lambda: "instance-id-list" + "[instance-id='" + str(self.instance_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList, ['instance_id', 'map_server_peer'], name, value)


                                    class Delegate(Entity):
                                        """
                                        DDT delegation to a child DDT node or map\-server
                                        
                                        .. attribute:: eid_prefix
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: instance_id
                                        
                                        	EID instance\-ID
                                        	**type**\: str
                                        
                                        .. attribute:: to
                                        
                                        	DDT delegation to a child DDT node or map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ip_address
                                        
                                        	IPv4/6 Child or map\-server node locator address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: map_server
                                        
                                        	Delegation points to a map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate, self).__init__()

                                            self.yang_name = "delegate"
                                            self.yang_parent_name = "instance-id-list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                                ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                                ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                                ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.instance_id = None
                                            self.to = None
                                            self.ip_address = None
                                            self.map_server = None
                                            self._segment_path = lambda: "delegate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                        class Decapsulation(Entity):
                            """
                            Decapsulation behavior (e.g. filters)
                            
                            .. attribute:: filter
                            
                            	Filters traffic
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation, self).__init__()

                                self.yang_name = "decapsulation"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("filter", ("filter", Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter))])
                                self._leafs = OrderedDict()

                                self.filter = Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"
                                self._segment_path = lambda: "decapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation, [], name, value)


                            class Filter(Entity):
                                """
                                Filters traffic
                                
                                .. attribute:: rloc
                                
                                	Filter based on Routing Locator (RLOC) in packet header
                                	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "decapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc))])
                                    self._leafs = OrderedDict()

                                    self.rloc = Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc()
                                    self.rloc.parent = self
                                    self._children_name_map["rloc"] = "rloc"
                                    self._segment_path = lambda: "filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter, [], name, value)


                                class Rloc(Entity):
                                    """
                                    Filter based on Routing Locator (RLOC) in packet header
                                    
                                    .. attribute:: source
                                    
                                    	Filters traffic based on RLOC source address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc, self).__init__()

                                        self.yang_name = "rloc"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "rloc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc, [], name, value)


                                    class Source(Entity):
                                        """
                                        Filters traffic based on RLOC source address
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator\-set Name
                                        	**type**\: str
                                        
                                        .. attribute:: member
                                        
                                        	Members learned from map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "rloc"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.member = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Etr.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.EidTable.InstanceList.Etr.MapServer))])
                                self._leafs = OrderedDict()

                                self.map_server = Native.Router.Lisp.Default.EidTable.InstanceList.Etr.MapServer()
                                self.map_server.parent = self
                                self._children_name_map["map_server"] = "map-server"
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Etr, [], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: source_address
                                
                                	Configures map server source address
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                    ])
                                    self.source_address = None
                                    self._segment_path = lambda: "map-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Etr.MapServer, ['source_address'], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 address family
                            
                            .. attribute:: alt_vrf
                            
                            	Activate LISP\-ALT functionality in VRF
                            	**type**\: str
                            
                            	**status**\: deprecated
                            
                            .. attribute:: database_mapping
                            
                            	Address family specific local EID prefixes database configuration
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.DatabaseMapping>`
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Distance>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.ItrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.EtrEnable>`
                            
                            .. attribute:: locator
                            
                            	Locator related configuration
                            	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Locator>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCache>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCacheLimit>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCachePersistent>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_resolver
                            
                            	Configures a LISP Map Resolver (MR)
                            	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: map_server
                            
                            	Configures a LISP Map Server (MS)
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: path_mtu_discovery
                            
                            	Path MTU discovery
                            	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.PathMtuDiscovery>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteExport>`
                            
                            .. attribute:: route_import
                            
                            	Import RIB routes by a routing protocol into LISP
                            	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SolicitMapRequest>`
                            
                            .. attribute:: source_locator
                            
                            	Source Locator configuration
                            	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.UsePetr>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.DatabaseMapping)), ("distance", ("distance", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Distance)), ("itr", ("itr", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.ItrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.EtrEnable)), ("locator", ("locator", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Locator)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteExport)), ("route-import", ("route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.UsePetr))])
                                self._leafs = OrderedDict([
                                    ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ])
                                self.alt_vrf = None
                                self.map_request_source = None
                                self.proxy_etr = None
                                self.proxy_itr = []
                                self.sgt = None

                                self.database_mapping = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.distance = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.itr = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.etr_enable = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.locator = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Locator()
                                self.locator.parent = self
                                self._children_name_map["locator"] = "locator"

                                self.map_cache = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_limit = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.map_cache_persistent = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.map_resolver = None
                                self._children_name_map["map_resolver"] = "map-resolver"

                                self.map_server = None
                                self._children_name_map["map_server"] = "map-server"

                                self.path_mtu_discovery = None
                                self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                                self.route_export = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport()
                                self.route_import.parent = self
                                self._children_name_map["route_import"] = "route-import"

                                self.site_registration = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.source_locator = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator()
                                self.source_locator.parent = self
                                self._children_name_map["source_locator"] = "source-locator"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Address family specific local EID prefixes database configuration
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.DatabaseMapping, [], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Itr.MapResolver>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Itr.MapResolver))])
                                    self._leafs = OrderedDict()

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Itr, [], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ])
                                        self.ip_addr = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Itr.MapResolver, ['ip_addr'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.ItrEnable, ['itr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr.MapServer>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr.MapServer))])
                                    self._leafs = OrderedDict()

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr, [], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: key_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: key_7
                                        
                                        	The HIDDEN password
                                        	**type**\: str
                                        
                                        .. attribute:: pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                                ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                                ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                                ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                            ])
                                            self.key_0 = None
                                            self.key_6 = None
                                            self.key_7 = None
                                            self.pwd = None
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.EtrEnable, ['etr'], name, value)


                            class Locator(Entity):
                                """
                                Locator related configuration
                                
                                .. attribute:: reachability
                                
                                	Configuration realted to locator reachability
                                	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Locator.Reachability>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Locator, self).__init__()

                                    self.yang_name = "locator"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Locator.Reachability))])
                                    self._leafs = OrderedDict()

                                    self.reachability = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Locator.Reachability()
                                    self.reachability.parent = self
                                    self._children_name_map["reachability"] = "reachability"
                                    self._segment_path = lambda: "locator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Locator, [], name, value)


                                class Reachability(Entity):
                                    """
                                    Configuration realted to locator reachability
                                    
                                    .. attribute:: exclude_default
                                    
                                    	If a remote RLOC is reached via the default route, treat it as unreachable
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Locator.Reachability, self).__init__()

                                        self.yang_name = "reachability"
                                        self.yang_parent_name = "locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                        ])
                                        self.exclude_default = None
                                        self._segment_path = lambda: "reachability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.Locator.Reachability, ['exclude_default'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCache, ['site_registration'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapCachePersistent, ['interval'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures a LISP Map Resolver (MR)
                                
                                .. attribute:: map_request
                                
                                	Map\-Request processing options
                                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_request = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest()
                                    self.map_request.parent = self
                                    self._children_name_map["map_request"] = "map-request"
                                    self._segment_path = lambda: "map-resolver"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver, [], name, value)


                                class MapRequest(Entity):
                                    """
                                    Map\-Request processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest, self).__init__()

                                        self.yang_name = "map-request"
                                        self.yang_parent_name = "map-resolver"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	Influence which source RLOCs map requests are accepted from
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            Influence which source RLOCs map requests are accepted from
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: registered
                                            
                                            	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                                    ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.list = None
                                                self.registered = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                            class MapServer(Entity):
                                """
                                Configures a LISP Map Server (MS)
                                
                                .. attribute:: map_register
                                
                                	Map\-Register processing options
                                	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_register = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister()
                                    self.map_register.parent = self
                                    self._children_name_map["map_register"] = "map-register"
                                    self._segment_path = lambda: "map-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer, [], name, value)


                                class MapRegister(Entity):
                                    """
                                    Map\-Register processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister, self).__init__()

                                        self.yang_name = "map-register"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-register"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	RLOC Source IP address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-register"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            RLOC Source IP address
                                            
                                            .. attribute:: allowed_locator
                                            
                                            	Against sites' allowed\-locators policy
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                                ])
                                                self.allowed_locator = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                            class PathMtuDiscovery(Entity):
                                """
                                Path MTU discovery
                                
                                .. attribute:: max
                                
                                	Upper bound on the path MTU accepted
                                	**type**\: int
                                
                                	**range:** 68..65535
                                
                                .. attribute:: min
                                
                                	Lower bound on the path MTU accepted
                                	**type**\: int
                                
                                	**range:** 68..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.PathMtuDiscovery, self).__init__()

                                    self.yang_name = "path-mtu-discovery"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self._segment_path = lambda: "path-mtu-discovery"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.PathMtuDiscovery, ['max', 'min'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class RouteImport(Entity):
                                """
                                Import RIB routes by a routing protocol into LISP
                                
                                .. attribute:: database
                                
                                	Use RIB routes to define local EID database entries
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database>`
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport, self).__init__()

                                    self.yang_name = "route-import"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.map_cache = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"
                                    self._segment_path = lambda: "route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport, [], name, value)


                                class Database(Entity):
                                    """
                                    Use RIB routes to define local EID database entries
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected>`
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip)), ("static", ("static", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected()
                                        self.connected.parent = self
                                        self._children_name_map["connected"] = "connected"

                                        self.maximum_prefix = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.rip = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip()
                                        self.rip.parent = self
                                        self._children_name_map["rip"] = "rip"

                                        self.static = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static()
                                        self.static.parent = self
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.isis = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database, [], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.maximum_prefix = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.rip = None
                                        self._children_name_map["rip"] = "rip"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.isis = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache, [], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations for a given instance\-id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class SourceLocator(Entity):
                                """
                                Source Locator configuration
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator, self).__init__()

                                    self.yang_name = "source-locator"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "source-locator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.locator_address = None
                                    self.priority = None
                                    self.weight = None
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv4.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 address family
                            
                            .. attribute:: alt_vrf
                            
                            	Activate LISP\-ALT functionality in VRF
                            	**type**\: str
                            
                            	**status**\: deprecated
                            
                            .. attribute:: database_mapping
                            
                            	Address family specific local EID prefixes database configuration
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.DatabaseMapping>`
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Distance>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.ItrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.EtrEnable>`
                            
                            .. attribute:: locator
                            
                            	Locator related configuration
                            	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Locator>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCache>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCacheLimit>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCachePersistent>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_resolver
                            
                            	Configures a LISP Map Resolver (MR)
                            	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: map_server
                            
                            	Configures a LISP Map Server (MS)
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: path_mtu_discovery
                            
                            	Path MTU discovery
                            	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.PathMtuDiscovery>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteExport>`
                            
                            .. attribute:: route_import
                            
                            	Import RIB routes by a routing protocol into LISP
                            	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SolicitMapRequest>`
                            
                            .. attribute:: source_locator
                            
                            	Source Locator configuration
                            	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.UsePetr>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.DatabaseMapping)), ("distance", ("distance", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Distance)), ("itr", ("itr", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.ItrEnable)), ("etr", ("etr", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.EtrEnable)), ("locator", ("locator", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Locator)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteExport)), ("route-import", ("route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator)), ("use-petr", ("use_petr", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.UsePetr))])
                                self._leafs = OrderedDict([
                                    ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ])
                                self.alt_vrf = None
                                self.map_request_source = None
                                self.proxy_etr = None
                                self.proxy_itr = []
                                self.sgt = None

                                self.database_mapping = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.distance = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.itr = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.etr_enable = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.locator = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Locator()
                                self.locator.parent = self
                                self._children_name_map["locator"] = "locator"

                                self.map_cache = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_limit = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.map_cache_persistent = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.map_resolver = None
                                self._children_name_map["map_resolver"] = "map-resolver"

                                self.map_server = None
                                self._children_name_map["map_server"] = "map-server"

                                self.path_mtu_discovery = None
                                self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                                self.route_export = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport()
                                self.route_import.parent = self
                                self._children_name_map["route_import"] = "route-import"

                                self.site_registration = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.source_locator = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator()
                                self.source_locator.parent = self
                                self._children_name_map["source_locator"] = "source-locator"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Address family specific local EID prefixes database configuration
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.DatabaseMapping, [], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Itr.MapResolver>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Itr.MapResolver))])
                                    self._leafs = OrderedDict()

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Itr, [], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ])
                                        self.ip_addr = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Itr.MapResolver, ['ip_addr'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.ItrEnable, ['itr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr.MapServer>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr.MapServer))])
                                    self._leafs = OrderedDict()

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr, [], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: key_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: key_7
                                        
                                        	The HIDDEN password
                                        	**type**\: str
                                        
                                        .. attribute:: pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                                ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                                ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                                ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                            ])
                                            self.key_0 = None
                                            self.key_6 = None
                                            self.key_7 = None
                                            self.pwd = None
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.EtrEnable, ['etr'], name, value)


                            class Locator(Entity):
                                """
                                Locator related configuration
                                
                                .. attribute:: reachability
                                
                                	Configuration realted to locator reachability
                                	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Locator.Reachability>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Locator, self).__init__()

                                    self.yang_name = "locator"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Locator.Reachability))])
                                    self._leafs = OrderedDict()

                                    self.reachability = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Locator.Reachability()
                                    self.reachability.parent = self
                                    self._children_name_map["reachability"] = "reachability"
                                    self._segment_path = lambda: "locator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Locator, [], name, value)


                                class Reachability(Entity):
                                    """
                                    Configuration realted to locator reachability
                                    
                                    .. attribute:: exclude_default
                                    
                                    	If a remote RLOC is reached via the default route, treat it as unreachable
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Locator.Reachability, self).__init__()

                                        self.yang_name = "reachability"
                                        self.yang_parent_name = "locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                        ])
                                        self.exclude_default = None
                                        self._segment_path = lambda: "reachability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.Locator.Reachability, ['exclude_default'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCache, ['site_registration'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapCachePersistent, ['interval'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures a LISP Map Resolver (MR)
                                
                                .. attribute:: map_request
                                
                                	Map\-Request processing options
                                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_request = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest()
                                    self.map_request.parent = self
                                    self._children_name_map["map_request"] = "map-request"
                                    self._segment_path = lambda: "map-resolver"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver, [], name, value)


                                class MapRequest(Entity):
                                    """
                                    Map\-Request processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest, self).__init__()

                                        self.yang_name = "map-request"
                                        self.yang_parent_name = "map-resolver"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	Influence which source RLOCs map requests are accepted from
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            Influence which source RLOCs map requests are accepted from
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: registered
                                            
                                            	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                                    ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.list = None
                                                self.registered = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                            class MapServer(Entity):
                                """
                                Configures a LISP Map Server (MS)
                                
                                .. attribute:: map_register
                                
                                	Map\-Register processing options
                                	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_register = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister()
                                    self.map_register.parent = self
                                    self._children_name_map["map_register"] = "map-register"
                                    self._segment_path = lambda: "map-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer, [], name, value)


                                class MapRegister(Entity):
                                    """
                                    Map\-Register processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister, self).__init__()

                                        self.yang_name = "map-register"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-register"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	RLOC Source IP address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-register"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            RLOC Source IP address
                                            
                                            .. attribute:: allowed_locator
                                            
                                            	Against sites' allowed\-locators policy
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                                ])
                                                self.allowed_locator = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                            class PathMtuDiscovery(Entity):
                                """
                                Path MTU discovery
                                
                                .. attribute:: max
                                
                                	Upper bound on the path MTU accepted
                                	**type**\: int
                                
                                	**range:** 68..65535
                                
                                .. attribute:: min
                                
                                	Lower bound on the path MTU accepted
                                	**type**\: int
                                
                                	**range:** 68..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.PathMtuDiscovery, self).__init__()

                                    self.yang_name = "path-mtu-discovery"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self._segment_path = lambda: "path-mtu-discovery"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.PathMtuDiscovery, ['max', 'min'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class RouteImport(Entity):
                                """
                                Import RIB routes by a routing protocol into LISP
                                
                                .. attribute:: database
                                
                                	Use RIB routes to define local EID database entries
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database>`
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport, self).__init__()

                                    self.yang_name = "route-import"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.map_cache = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"
                                    self._segment_path = lambda: "route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport, [], name, value)


                                class Database(Entity):
                                    """
                                    Use RIB routes to define local EID database entries
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected>`
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip)), ("static", ("static", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected()
                                        self.connected.parent = self
                                        self._children_name_map["connected"] = "connected"

                                        self.maximum_prefix = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.rip = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip()
                                        self.rip.parent = self
                                        self._children_name_map["rip"] = "rip"

                                        self.static = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static()
                                        self.static.parent = self
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.isis = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database, [], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.maximum_prefix = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.rip = None
                                        self._children_name_map["rip"] = "rip"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.isis = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache, [], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations for a given instance\-id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class SourceLocator(Entity):
                                """
                                Source Locator configuration
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator, self).__init__()

                                    self.yang_name = "source-locator"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "source-locator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.locator_address = None
                                    self.priority = None
                                    self.weight = None
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.Ipv6.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                        class LocReachAlgorithm(Entity):
                            """
                            Configure locator reachability algorithm
                            
                            .. attribute:: lsb_reports
                            
                            	Configure data packet LSB report handling
                            	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.LocReachAlgorithm.LsbReports>`
                            
                            .. attribute:: rloc_probing
                            
                            	Probe high priority RLOCs with Map\-Requests as last resort
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.LocReachAlgorithm, self).__init__()

                                self.yang_name = "loc-reach-algorithm"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.Lisp.Default.EidTable.InstanceList.LocReachAlgorithm.LsbReports))])
                                self._leafs = OrderedDict([
                                    ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                                ])
                                self.rloc_probing = None

                                self.lsb_reports = Native.Router.Lisp.Default.EidTable.InstanceList.LocReachAlgorithm.LsbReports()
                                self.lsb_reports.parent = self
                                self._children_name_map["lsb_reports"] = "lsb-reports"
                                self._segment_path = lambda: "loc-reach-algorithm"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.LocReachAlgorithm, ['rloc_probing'], name, value)


                            class LsbReports(Entity):
                                """
                                Configure data packet LSB report handling
                                
                                .. attribute:: do_not_transmit
                                
                                	Force the setting of the encapsulation header L bit to zero
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ignore
                                
                                	Ignore data packet LSB reports
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.LocReachAlgorithm.LsbReports, self).__init__()

                                    self.yang_name = "lsb-reports"
                                    self.yang_parent_name = "loc-reach-algorithm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ])
                                    self.do_not_transmit = None
                                    self.ignore = None
                                    self._segment_path = lambda: "lsb-reports"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                        class LocatorDown(Entity):
                            """
                            Manually set locator status to down
                            
                            .. attribute:: address
                            
                            	IPv4/6 Locator address to be set down
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_interface
                            
                            	Use IPv4 address of interface as locator
                            	**type**\: str
                            
                            .. attribute:: ipv6_interface
                            
                            	Use IPv6 address of interface as locator
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.LocatorDown, self).__init__()

                                self.yang_name = "locator-down"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                    ('ipv4_interface', (YLeaf(YType.str, 'IPv4-interface'), ['str'])),
                                    ('ipv6_interface', (YLeaf(YType.str, 'IPv6-interface'), ['str'])),
                                ])
                                self.address = None
                                self.ipv4_interface = None
                                self.ipv6_interface = None
                                self._segment_path = lambda: "locator-down"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.LocatorDown, ['address', 'ipv4_interface', 'ipv6_interface'], name, value)


                        class LocatorTable(Entity):
                            """
                            Specify the RLOC table
                            
                            .. attribute:: vrf_name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: default
                            
                            	Default VRF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vrf
                            
                            	VRF name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.LocatorTable, self).__init__()

                                self.yang_name = "locator-table"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.vrf_name = None
                                self.default = None
                                self.vrf = None
                                self._segment_path = lambda: "locator-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.LocatorTable, ['vrf_name', 'default', 'vrf'], name, value)


                        class MapRequest(Entity):
                            """
                            Configure map\-request handling
                            
                            .. attribute:: itr_rlocs
                            
                            	Configure to use the specified RLOC set as ITR RLOC in map\-request
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr_rlocs', (YLeaf(YType.str, 'itr-rlocs'), ['str'])),
                                ])
                                self.itr_rlocs = None
                                self._segment_path = lambda: "map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.MapRequest, ['itr_rlocs'], name, value)


                        class MapServer(Entity):
                            """
                            Map\-Server commands
                            
                            .. attribute:: rloc
                            
                            	EID instance RLOC membership
                            	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc>`
                            
                            .. attribute:: site_registration
                            
                            	Map\-server site registration options
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.SiteRegistration>`
                            
                            .. attribute:: nmr
                            
                            	Map\-server negative map\-reply optio
                            	**type**\:  :py:class:`Nmr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Nmr>`
                            
                            .. attribute:: session
                            
                            	Map\-server session
                            	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Session>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.SiteRegistration)), ("nmr", ("nmr", Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Nmr)), ("session", ("session", Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Session))])
                                self._leafs = OrderedDict()

                                self.rloc = Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc()
                                self.rloc.parent = self
                                self._children_name_map["rloc"] = "rloc"

                                self.site_registration = Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.nmr = Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Nmr()
                                self.nmr.parent = self
                                self._children_name_map["nmr"] = "nmr"

                                self.session = Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Session()
                                self.session.parent = self
                                self._children_name_map["session"] = "session"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer, [], name, value)


                            class Rloc(Entity):
                                """
                                EID instance RLOC membership
                                
                                .. attribute:: members
                                
                                	EID instance RLOC membership
                                	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc, self).__init__()

                                    self.yang_name = "rloc"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("members", ("members", Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members))])
                                    self._leafs = OrderedDict()

                                    self.members = Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members()
                                    self.members.parent = self
                                    self._children_name_map["members"] = "members"
                                    self._segment_path = lambda: "rloc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc, [], name, value)


                                class Members(Entity):
                                    """
                                    EID instance RLOC membership
                                    
                                    .. attribute:: distribute
                                    
                                    	EID instance RLOC membership distribution
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: modify_discovered
                                    
                                    	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                    	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members, self).__init__()

                                        self.yang_name = "members"
                                        self.yang_parent_name = "rloc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered))])
                                        self._leafs = OrderedDict([
                                            ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                        ])
                                        self.distribute = None

                                        self.modify_discovered = Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered()
                                        self.modify_discovered.parent = self
                                        self._children_name_map["modify_discovered"] = "modify-discovered"
                                        self._segment_path = lambda: "members"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members, ['distribute'], name, value)


                                    class ModifyDiscovered(Entity):
                                        """
                                        Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                        
                                        .. attribute:: operator
                                        
                                        	
                                        	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set from which to get member RLOC addresses
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                            self.yang_name = "modify-discovered"
                                            self.yang_parent_name = "members"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.operator = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "modify-discovered"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                        class Operator(Enum):
                                            """
                                            Operator (Enum Class)

                                            .. data:: add = 0

                                            .. data:: override = 1

                                            """

                                            add = Enum.YLeaf(0, "add")

                                            override = Enum.YLeaf(1, "override")



                            class SiteRegistration(Entity):
                                """
                                Map\-server site registration options
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations as a result of accept\-more\-specifics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class Nmr(Entity):
                                """
                                Map\-server negative map\-reply optio
                                
                                .. attribute:: non_site_ttl
                                
                                	Negative map\-reply TTL for non\-site EID
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Nmr, self).__init__()

                                    self.yang_name = "nmr"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('non_site_ttl', (YLeaf(YType.uint16, 'non-site-ttl'), ['int'])),
                                    ])
                                    self.non_site_ttl = None
                                    self._segment_path = lambda: "nmr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Nmr, ['non_site_ttl'], name, value)


                            class Session(Entity):
                                """
                                Map\-server session
                                
                                .. attribute:: passive_open
                                
                                	Open passive TCP sockets to listen for incoming connections
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Session, self).__init__()

                                    self.yang_name = "session"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('passive_open', (YLeaf(YType.str, 'passive-open'), ['str'])),
                                    ])
                                    self.passive_open = None
                                    self._segment_path = lambda: "session"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.MapServer.Session, ['passive_open'], name, value)


                        class OtherXtrProbe(Entity):
                            """
                            Configure parameters for probing of other xTRs in our site
                            
                            .. attribute:: period
                            
                            	Period between probes in seconds
                            	**type**\: int
                            
                            	**range:** 5..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.OtherXtrProbe, self).__init__()

                                self.yang_name = "other-xtr-probe"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                ])
                                self.period = None
                                self._segment_path = lambda: "other-xtr-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.OtherXtrProbe, ['period'], name, value)


                        class RemoteRlocProbe(Entity):
                            """
                            Configure parameters for probing of remote RLOCs
                            
                            .. attribute:: on_membership_change
                            
                            	Trigger probing upon membership changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: on_route_change
                            
                            	Trigger probing upon routing changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.RemoteRlocProbe, self).__init__()

                                self.yang_name = "remote-rloc-probe"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                    ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                                ])
                                self.on_membership_change = None
                                self.on_route_change = None
                                self._segment_path = lambda: "remote-rloc-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                        class MapCache(Entity):
                            """
                            Configures static EID\-to\-RLOC mappings for an ITR
                            
                            .. attribute:: eid_prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: etr_interface_ip
                            
                            	
                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.EidTable.InstanceList.MapCache.EtrInterfaceIp>`
                            
                            .. attribute:: drop
                            
                            	Drop packets that match this map\-cache entry
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: map_request
                            
                            	Send Map\-Request for LISP destination EID
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: native_forward
                            
                            	Natively forward packets that match this map\-cache entry
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.EidTable.InstanceList.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['eid_prefix']
                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.Default.EidTable.InstanceList.MapCache.EtrInterfaceIp))])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                ])
                                self.eid_prefix = None
                                self.drop = None
                                self.map_request = None
                                self.native_forward = None

                                self.etr_interface_ip = Native.Router.Lisp.Default.EidTable.InstanceList.MapCache.EtrInterfaceIp()
                                self.etr_interface_ip.parent = self
                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                self._segment_path = lambda: "map-cache" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.MapCache, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                            class EtrInterfaceIp(Entity):
                                """
                                
                                
                                .. attribute:: etr_interface_ip_address
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.EidTable.InstanceList.MapCache.EtrInterfaceIp, self).__init__()

                                    self.yang_name = "etr-interface-ip"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.etr_interface_ip_address = None
                                    self.priority = None
                                    self.weight = None
                                    self._segment_path = lambda: "etr-interface-ip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.EidTable.InstanceList.MapCache.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                class Security(Entity):
                    """
                    Enable default LISP security and authentication in reply is optional
                    
                    .. attribute:: strong
                    
                    	Enable default LISP security and authentication in reply is required
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Security, self).__init__()

                        self.yang_name = "security"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('strong', (YLeaf(YType.empty, 'strong'), ['Empty'])),
                        ])
                        self.strong = None
                        self._segment_path = lambda: "security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Security, ['strong'], name, value)


                class Site(Entity):
                    """
                    Configure a LISP site on a map server (MS)
                    
                    .. attribute:: sname  (key)
                    
                    	The site name
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	
                    	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_>`
                    
                    .. attribute:: authentication_key
                    
                    	Authentication key used by LISP site
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.AuthenticationKey>`
                    
                    .. attribute:: description
                    
                    	Site description
                    	**type**\: str
                    
                    .. attribute:: allowed_locator
                    
                    	Locator from LISP site
                    	**type**\:  :py:class:`AllowedLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.AllowedLocator>`
                    
                    .. attribute:: eid_prefix
                    
                    	Site EID address prefix
                    	**type**\:  :py:class:`EidPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.EidPrefix>`
                    
                    .. attribute:: eid_record
                    
                    	Site EID address prefix
                    	**type**\:  :py:class:`EidRecord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.EidRecord>`
                    
                    .. attribute:: site_id
                    
                    	Configure a site\-id for this site
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Site, self).__init__()

                        self.yang_name = "site"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['sname']
                        self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Default.Site.Default_)), ("authentication-key", ("authentication_key", Native.Router.Lisp.Default.Site.AuthenticationKey)), ("allowed-locator", ("allowed_locator", Native.Router.Lisp.Default.Site.AllowedLocator)), ("eid-prefix", ("eid_prefix", Native.Router.Lisp.Default.Site.EidPrefix)), ("eid-record", ("eid_record", Native.Router.Lisp.Default.Site.EidRecord))])
                        self._leafs = OrderedDict([
                            ('sname', (YLeaf(YType.str, 'sname'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                        ])
                        self.sname = None
                        self.description = None
                        self.site_id = None

                        self.default = Native.Router.Lisp.Default.Site.Default_()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.authentication_key = Native.Router.Lisp.Default.Site.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.allowed_locator = Native.Router.Lisp.Default.Site.AllowedLocator()
                        self.allowed_locator.parent = self
                        self._children_name_map["allowed_locator"] = "allowed-locator"

                        self.eid_prefix = Native.Router.Lisp.Default.Site.EidPrefix()
                        self.eid_prefix.parent = self
                        self._children_name_map["eid_prefix"] = "eid-prefix"

                        self.eid_record = Native.Router.Lisp.Default.Site.EidRecord()
                        self.eid_record.parent = self
                        self._children_name_map["eid_record"] = "eid-record"
                        self._segment_path = lambda: "site" + "[sname='" + str(self.sname) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Site, ['sname', 'description', 'site_id'], name, value)


                    class Default_(Entity):
                        """
                        
                        
                        .. attribute:: authentication_key
                        
                        	Authentication key used by LISP site
                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_.AuthenticationKey>`
                        
                        .. attribute:: description
                        
                        	Site description
                        	**type**\: str
                        
                        .. attribute:: allowed_locator
                        
                        	Locator from LISP site
                        	**type**\:  :py:class:`AllowedLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_.AllowedLocator>`
                        
                        .. attribute:: eid_prefix
                        
                        	Site EID address prefix
                        	**type**\:  :py:class:`EidPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_.EidPrefix>`
                        
                        .. attribute:: eid_record
                        
                        	Site EID address prefix
                        	**type**\:  :py:class:`EidRecord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_.EidRecord>`
                        
                        .. attribute:: site_id
                        
                        	Configure a site\-id for this site
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Site.Default_, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "site"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Lisp.Default.Site.Default_.AuthenticationKey)), ("allowed-locator", ("allowed_locator", Native.Router.Lisp.Default.Site.Default_.AllowedLocator)), ("eid-prefix", ("eid_prefix", Native.Router.Lisp.Default.Site.Default_.EidPrefix)), ("eid-record", ("eid_record", Native.Router.Lisp.Default.Site.Default_.EidRecord))])
                            self._leafs = OrderedDict([
                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                            ])
                            self.description = None
                            self.site_id = None

                            self.authentication_key = Native.Router.Lisp.Default.Site.Default_.AuthenticationKey()
                            self.authentication_key.parent = self
                            self._children_name_map["authentication_key"] = "authentication-key"

                            self.allowed_locator = Native.Router.Lisp.Default.Site.Default_.AllowedLocator()
                            self.allowed_locator.parent = self
                            self._children_name_map["allowed_locator"] = "allowed-locator"

                            self.eid_prefix = Native.Router.Lisp.Default.Site.Default_.EidPrefix()
                            self.eid_prefix.parent = self
                            self._children_name_map["eid_prefix"] = "eid-prefix"

                            self.eid_record = Native.Router.Lisp.Default.Site.Default_.EidRecord()
                            self.eid_record.parent = self
                            self._children_name_map["eid_record"] = "eid-record"
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Site.Default_, ['description', 'site_id'], name, value)


                        class AuthenticationKey(Entity):
                            """
                            Authentication key used by LISP site
                            
                            .. attribute:: unc_pwd
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            .. attribute:: key_0
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            .. attribute:: key_6
                            
                            	The ENCRYPTED password
                            	**type**\: str
                            
                            .. attribute:: key_7
                            
                            	The ENCRYPTED password
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Site.Default_.AuthenticationKey, self).__init__()

                                self.yang_name = "authentication-key"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                    ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                    ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                    ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                ])
                                self.unc_pwd = None
                                self.key_0 = None
                                self.key_6 = None
                                self.key_7 = None
                                self._segment_path = lambda: "authentication-key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Site.Default_.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                        class AllowedLocator(Entity):
                            """
                            Locator from LISP site
                            
                            .. attribute:: ls_ipv4
                            
                            	IPv4 locator allowed in registered locator\-set
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ls_ipv6
                            
                            	IPv6 locator allowed in registered locator\-set
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: list
                            
                            	Prefixes allowed in registerd locator\-set
                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_.AllowedLocator.List>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Site.Default_.AllowedLocator, self).__init__()

                                self.yang_name = "allowed-locator"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Site.Default_.AllowedLocator.List))])
                                self._leafs = OrderedDict([
                                    ('ls_ipv4', (YLeaf(YType.str, 'ls-ipv4'), ['str'])),
                                    ('ls_ipv6', (YLeaf(YType.str, 'ls-ipv6'), ['str'])),
                                ])
                                self.ls_ipv4 = None
                                self.ls_ipv6 = None

                                self.list = Native.Router.Lisp.Default.Site.Default_.AllowedLocator.List()
                                self.list.parent = self
                                self._children_name_map["list"] = "list"
                                self._segment_path = lambda: "allowed-locator"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Site.Default_.AllowedLocator, ['ls_ipv4', 'ls_ipv6'], name, value)


                            class List(Entity):
                                """
                                Prefixes allowed in registerd locator\-set
                                
                                .. attribute:: ipv4
                                
                                	IPv4 prefix\-list name
                                	**type**\: str
                                
                                .. attribute:: ipv6
                                
                                	IPv6 prefix\-list name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Site.Default_.AllowedLocator.List, self).__init__()

                                    self.yang_name = "list"
                                    self.yang_parent_name = "allowed-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Site.Default_.AllowedLocator.List, ['ipv4', 'ipv6'], name, value)


                        class EidPrefix(Entity):
                            """
                            Site EID address prefix
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_.EidPrefix.Prefixes>`
                            
                            .. attribute:: instance_id
                            
                            	EID instance\-ID
                            	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_.EidPrefix.InstanceId>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Site.Default_.EidPrefix, self).__init__()

                                self.yang_name = "eid-prefix"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Default.Site.Default_.EidPrefix.Prefixes)), ("instance-id", ("instance_id", Native.Router.Lisp.Default.Site.Default_.EidPrefix.InstanceId))])
                                self._leafs = OrderedDict([
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self.instance_id = YList(self)
                                self._segment_path = lambda: "eid-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Site.Default_.EidPrefix, ['any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Site.Default_.EidPrefix.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "eid-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Site.Default_.EidPrefix.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                            class InstanceId(Entity):
                                """
                                EID instance\-ID
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: prefixes
                                
                                	
                                	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_.EidPrefix.InstanceId.Prefixes>`
                                
                                .. attribute:: any_mac
                                
                                	Accept registrations for any L2 EID records
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Site.Default_.EidPrefix.InstanceId, self).__init__()

                                    self.yang_name = "instance-id"
                                    self.yang_parent_name = "eid-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Default.Site.Default_.EidPrefix.InstanceId.Prefixes))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                    ])
                                    self.id = None
                                    self.any_mac = None

                                    self.prefixes = YList(self)
                                    self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Site.Default_.EidPrefix.InstanceId, ['id', 'any_mac'], name, value)


                                class Prefixes(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: accept_more_specifics
                                    
                                    	Accept registrations for more specific EID prefixes
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_tag
                                    
                                    	RIB route tag
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Site.Default_.EidPrefix.InstanceId.Prefixes, self).__init__()

                                        self.yang_name = "prefixes"
                                        self.yang_parent_name = "instance-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                            ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.accept_more_specifics = None
                                        self.route_tag = None
                                        self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Site.Default_.EidPrefix.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                        class EidRecord(Entity):
                            """
                            Site EID address prefix
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_.EidRecord.Prefixes>`
                            
                            .. attribute:: instance_id
                            
                            	EID instance\-ID
                            	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_.EidRecord.InstanceId>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Site.Default_.EidRecord, self).__init__()

                                self.yang_name = "eid-record"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Default.Site.Default_.EidRecord.Prefixes)), ("instance-id", ("instance_id", Native.Router.Lisp.Default.Site.Default_.EidRecord.InstanceId))])
                                self._leafs = OrderedDict([
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self.instance_id = YList(self)
                                self._segment_path = lambda: "eid-record"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Site.Default_.EidRecord, ['any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Site.Default_.EidRecord.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "eid-record"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Site.Default_.EidRecord.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                            class InstanceId(Entity):
                                """
                                EID instance\-ID
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: prefixes
                                
                                	
                                	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.Default_.EidRecord.InstanceId.Prefixes>`
                                
                                .. attribute:: any_mac
                                
                                	Accept registrations for any L2 EID records
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Site.Default_.EidRecord.InstanceId, self).__init__()

                                    self.yang_name = "instance-id"
                                    self.yang_parent_name = "eid-record"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Default.Site.Default_.EidRecord.InstanceId.Prefixes))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                    ])
                                    self.id = None
                                    self.any_mac = None

                                    self.prefixes = YList(self)
                                    self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Site.Default_.EidRecord.InstanceId, ['id', 'any_mac'], name, value)


                                class Prefixes(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: accept_more_specifics
                                    
                                    	Accept registrations for more specific EID prefixes
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_tag
                                    
                                    	RIB route tag
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Default.Site.Default_.EidRecord.InstanceId.Prefixes, self).__init__()

                                        self.yang_name = "prefixes"
                                        self.yang_parent_name = "instance-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                            ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.accept_more_specifics = None
                                        self.route_tag = None
                                        self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Default.Site.Default_.EidRecord.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Authentication key used by LISP site
                        
                        .. attribute:: unc_pwd
                        
                        	The UNENCRYPTED (cleartext) password
                        	**type**\: str
                        
                        .. attribute:: key_0
                        
                        	The UNENCRYPTED (cleartext) password
                        	**type**\: str
                        
                        .. attribute:: key_6
                        
                        	The ENCRYPTED password
                        	**type**\: str
                        
                        .. attribute:: key_7
                        
                        	The ENCRYPTED password
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Site.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "site"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                            ])
                            self.unc_pwd = None
                            self.key_0 = None
                            self.key_6 = None
                            self.key_7 = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Site.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                    class AllowedLocator(Entity):
                        """
                        Locator from LISP site
                        
                        .. attribute:: ls_ipv4
                        
                        	IPv4 locator allowed in registered locator\-set
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ls_ipv6
                        
                        	IPv6 locator allowed in registered locator\-set
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: list
                        
                        	Prefixes allowed in registerd locator\-set
                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.AllowedLocator.List>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Site.AllowedLocator, self).__init__()

                            self.yang_name = "allowed-locator"
                            self.yang_parent_name = "site"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Default.Site.AllowedLocator.List))])
                            self._leafs = OrderedDict([
                                ('ls_ipv4', (YLeaf(YType.str, 'ls-ipv4'), ['str'])),
                                ('ls_ipv6', (YLeaf(YType.str, 'ls-ipv6'), ['str'])),
                            ])
                            self.ls_ipv4 = None
                            self.ls_ipv6 = None

                            self.list = Native.Router.Lisp.Default.Site.AllowedLocator.List()
                            self.list.parent = self
                            self._children_name_map["list"] = "list"
                            self._segment_path = lambda: "allowed-locator"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Site.AllowedLocator, ['ls_ipv4', 'ls_ipv6'], name, value)


                        class List(Entity):
                            """
                            Prefixes allowed in registerd locator\-set
                            
                            .. attribute:: ipv4
                            
                            	IPv4 prefix\-list name
                            	**type**\: str
                            
                            .. attribute:: ipv6
                            
                            	IPv6 prefix\-list name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Site.AllowedLocator.List, self).__init__()

                                self.yang_name = "list"
                                self.yang_parent_name = "allowed-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "list"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Site.AllowedLocator.List, ['ipv4', 'ipv6'], name, value)


                    class EidPrefix(Entity):
                        """
                        Site EID address prefix
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.EidPrefix.Prefixes>`
                        
                        .. attribute:: instance_id
                        
                        	EID instance\-ID
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.EidPrefix.InstanceId>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Site.EidPrefix, self).__init__()

                            self.yang_name = "eid-prefix"
                            self.yang_parent_name = "site"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Default.Site.EidPrefix.Prefixes)), ("instance-id", ("instance_id", Native.Router.Lisp.Default.Site.EidPrefix.InstanceId))])
                            self._leafs = OrderedDict([
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self.instance_id = YList(self)
                            self._segment_path = lambda: "eid-prefix"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Site.EidPrefix, ['any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Site.EidPrefix.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "eid-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Site.EidPrefix.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                        class InstanceId(Entity):
                            """
                            EID instance\-ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.EidPrefix.InstanceId.Prefixes>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Site.EidPrefix.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "eid-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Default.Site.EidPrefix.InstanceId.Prefixes))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.id = None
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Site.EidPrefix.InstanceId, ['id', 'any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Site.EidPrefix.InstanceId.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "instance-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Site.EidPrefix.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                    class EidRecord(Entity):
                        """
                        Site EID address prefix
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.EidRecord.Prefixes>`
                        
                        .. attribute:: instance_id
                        
                        	EID instance\-ID
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.EidRecord.InstanceId>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Site.EidRecord, self).__init__()

                            self.yang_name = "eid-record"
                            self.yang_parent_name = "site"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Default.Site.EidRecord.Prefixes)), ("instance-id", ("instance_id", Native.Router.Lisp.Default.Site.EidRecord.InstanceId))])
                            self._leafs = OrderedDict([
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self.instance_id = YList(self)
                            self._segment_path = lambda: "eid-record"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Site.EidRecord, ['any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Site.EidRecord.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "eid-record"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Site.EidRecord.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                        class InstanceId(Entity):
                            """
                            EID instance\-ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Site.EidRecord.InstanceId.Prefixes>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Default.Site.EidRecord.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "eid-record"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Default.Site.EidRecord.InstanceId.Prefixes))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.id = None
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Default.Site.EidRecord.InstanceId, ['id', 'any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Default.Site.EidRecord.InstanceId.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "instance-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Default.Site.EidRecord.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                class Syslog(Entity):
                    """
                    Configure syslog option
                    
                    .. attribute:: session
                    
                    	Enable session syslog
                    	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Default.Syslog.Session>`
                    
                    .. attribute:: verbose
                    
                    	Enable verbose syslog
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Default.Syslog, self).__init__()

                        self.yang_name = "syslog"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("session", ("session", Native.Router.Lisp.Default.Syslog.Session))])
                        self._leafs = OrderedDict([
                            ('verbose', (YLeaf(YType.empty, 'verbose'), ['Empty'])),
                        ])
                        self.verbose = None

                        self.session = Native.Router.Lisp.Default.Syslog.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                        self._segment_path = lambda: "syslog"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Default.Syslog, ['verbose'], name, value)


                    class Session(Entity):
                        """
                        Enable session syslog
                        
                        .. attribute:: changes
                        
                        	Enable session change syslog
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Default.Syslog.Session, self).__init__()

                            self.yang_name = "session"
                            self.yang_parent_name = "syslog"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('changes', (YLeaf(YType.empty, 'changes'), ['Empty'])),
                            ])
                            self.changes = None
                            self._segment_path = lambda: "session"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/default/syslog/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Default.Syslog.Session, ['changes'], name, value)


            class Service(Entity):
                """
                Configure lisp service type
                
                .. attribute:: ipv4
                
                	
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4>`
                
                	**presence node**\: True
                
                .. attribute:: ipv6
                
                	
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6>`
                
                	**presence node**\: True
                
                .. attribute:: ethernet
                
                	
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Lisp.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.Lisp.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.Lisp.Service.Ethernet))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.ipv4 = None
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = None
                    self._children_name_map["ipv6"] = "ipv6"

                    self.ethernet = None
                    self._children_name_map["ethernet"] = "ethernet"
                    self._segment_path = lambda: "service"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Service, [], name, value)


                class Ipv4(Entity):
                    """
                    
                    
                    .. attribute:: default
                    
                    	
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default>`
                    
                    .. attribute:: database_mapping
                    
                    	Address family specific local EID prefixes database configuration
                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.DatabaseMapping>`
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Itr>`
                    
                    .. attribute:: itr_enable
                    
                    	
                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.ItrEnable>`
                    
                    .. attribute:: etr_enable
                    
                    	
                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.EtrEnable>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr>`
                    
                    .. attribute:: map_cache_limit
                    
                    	Configures maximum size of map\-cache
                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapCacheLimit>`
                    
                    .. attribute:: map_resolver
                    
                    	Configures a LISP Map Resolver (MR)
                    	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapResolver>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: map_server
                    
                    	Configures a LISP Map Server (MS)
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapServer>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: site_registration
                    
                    	Site registrations configuration for a given instance\-id
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.SiteRegistration>`
                    
                    .. attribute:: solicit_map_request
                    
                    	Configure Solicit\-Map\-Request handling
                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.SolicitMapRequest>`
                    
                    .. attribute:: distance
                    
                    	Administrative distance for RIB route installation
                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Distance>`
                    
                    .. attribute:: encapsulation
                    
                    	Select encapsulation type for data packets
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Encapsulation>`
                    
                    .. attribute:: map_cache
                    
                    	Address family specific map cache configuration
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapCache>`
                    
                    .. attribute:: map_cache_persistent
                    
                    	Dump map\-cache onto flash, making it persistent across reboots
                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapCachePersistent>`
                    
                    .. attribute:: proxy_etr
                    
                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: proxy_itr
                    
                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.ProxyItr>`
                    
                    .. attribute:: route_export
                    
                    	Export routes into RIB from LISP
                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.RouteExport>`
                    
                    .. attribute:: sgt
                    
                    	Enable security group tag propagation in LISP encapsulated traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: use_petr
                    
                    	Encapsulate to Proxy ETR when matching forward\-native entry
                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.UsePetr>`
                    
                    .. attribute:: import_
                    
                    	Redistribute LISP states internally
                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Import>`
                    
                    .. attribute:: map_request_source
                    
                    	Configures inner header source address in Map\-Request message
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Service.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Service.Ipv4.Default)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Service.Ipv4.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Service.Ipv4.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Service.Ipv4.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Service.Ipv4.SolicitMapRequest)), ("distance", ("distance", Native.Router.Lisp.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.Lisp.Service.Ipv4.Import))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv4.Encapsulation')])),
                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                        ])
                        self.encapsulation = None
                        self.proxy_etr = None
                        self.sgt = None
                        self.map_request_source = None

                        self.default = Native.Router.Lisp.Service.Ipv4.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.database_mapping = Native.Router.Lisp.Service.Ipv4.DatabaseMapping()
                        self.database_mapping.parent = self
                        self._children_name_map["database_mapping"] = "database-mapping"

                        self.itr = Native.Router.Lisp.Service.Ipv4.Itr()
                        self.itr.parent = self
                        self._children_name_map["itr"] = "itr"

                        self.itr_enable = Native.Router.Lisp.Service.Ipv4.ItrEnable()
                        self.itr_enable.parent = self
                        self._children_name_map["itr_enable"] = "itr-enable"

                        self.etr_enable = Native.Router.Lisp.Service.Ipv4.EtrEnable()
                        self.etr_enable.parent = self
                        self._children_name_map["etr_enable"] = "etr-enable"

                        self.etr = Native.Router.Lisp.Service.Ipv4.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.map_cache_limit = Native.Router.Lisp.Service.Ipv4.MapCacheLimit()
                        self.map_cache_limit.parent = self
                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                        self.map_resolver = None
                        self._children_name_map["map_resolver"] = "map-resolver"

                        self.map_server = None
                        self._children_name_map["map_server"] = "map-server"

                        self.site_registration = Native.Router.Lisp.Service.Ipv4.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.solicit_map_request = Native.Router.Lisp.Service.Ipv4.SolicitMapRequest()
                        self.solicit_map_request.parent = self
                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                        self.distance = Native.Router.Lisp.Service.Ipv4.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"

                        self.map_cache = Native.Router.Lisp.Service.Ipv4.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"

                        self.map_cache_persistent = Native.Router.Lisp.Service.Ipv4.MapCachePersistent()
                        self.map_cache_persistent.parent = self
                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                        self.proxy_itr = Native.Router.Lisp.Service.Ipv4.ProxyItr()
                        self.proxy_itr.parent = self
                        self._children_name_map["proxy_itr"] = "proxy-itr"

                        self.route_export = Native.Router.Lisp.Service.Ipv4.RouteExport()
                        self.route_export.parent = self
                        self._children_name_map["route_export"] = "route-export"

                        self.import_ = Native.Router.Lisp.Service.Ipv4.Import()
                        self.import_.parent = self
                        self._children_name_map["import_"] = "import"

                        self.use_petr = YList(self)
                        self._segment_path = lambda: "ipv4"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Service.Ipv4, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Select encapsulation type for data packets

                        .. data:: lisp = 0

                        .. data:: vxlan = 1

                        """

                        lisp = Enum.YLeaf(0, "lisp")

                        vxlan = Enum.YLeaf(1, "vxlan")



                    class Default(Entity):
                        """
                        
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.SolicitMapRequest>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Distance>`
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Encapsulation>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapCache>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapCachePersistent>`
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.ProxyItr>`
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.RouteExport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.UsePetr>`
                        
                        .. attribute:: import_
                        
                        	Redistribute LISP states internally
                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Import>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Service.Ipv4.Default.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Service.Ipv4.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Service.Ipv4.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Service.Ipv4.Default.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Service.Ipv4.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Service.Ipv4.Default.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ipv4.Default.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Service.Ipv4.Default.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Service.Ipv4.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Service.Ipv4.Default.SolicitMapRequest)), ("distance", ("distance", Native.Router.Lisp.Service.Ipv4.Default.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Service.Ipv4.Default.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Service.Ipv4.Default.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Service.Ipv4.Default.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Service.Ipv4.Default.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Service.Ipv4.Default.UsePetr)), ("import", ("import_", Native.Router.Lisp.Service.Ipv4.Default.Import))])
                            self._leafs = OrderedDict([
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv4.Default.Encapsulation')])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ])
                            self.encapsulation = None
                            self.proxy_etr = None
                            self.sgt = None
                            self.map_request_source = None

                            self.database_mapping = Native.Router.Lisp.Service.Ipv4.Default.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.Lisp.Service.Ipv4.Default.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.Lisp.Service.Ipv4.Default.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.Lisp.Service.Ipv4.Default.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.Lisp.Service.Ipv4.Default.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.Lisp.Service.Ipv4.Default.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.Lisp.Service.Ipv4.Default.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.Lisp.Service.Ipv4.Default.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.distance = Native.Router.Lisp.Service.Ipv4.Default.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.map_cache = Native.Router.Lisp.Service.Ipv4.Default.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_persistent = Native.Router.Lisp.Service.Ipv4.Default.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.proxy_itr = Native.Router.Lisp.Service.Ipv4.Default.ProxyItr()
                            self.proxy_itr.parent = self
                            self._children_name_map["proxy_itr"] = "proxy-itr"

                            self.route_export = Native.Router.Lisp.Service.Ipv4.Default.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.import_ = Native.Router.Lisp.Service.Ipv4.Default.Import()
                            self.import_.parent = self
                            self._children_name_map["import_"] = "import"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "default"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Select encapsulation type for data packets

                            .. data:: lisp = 0

                            .. data:: vxlan = 1

                            """

                            lisp = Enum.YLeaf(0, "lisp")

                            vxlan = Enum.YLeaf(1, "vxlan")



                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Service.Ipv4.Default.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.Lisp.Service.Ipv4.Default.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.Default.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/database-mapping/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ipv4.Default.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.Default.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/itr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Service.Ipv4.Default.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.Lisp.Service.Ipv4.Default.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/map-resolver/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/map-resolver/map-request/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/map-resolver/map-request/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/map-server/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/map-server/map-register/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/map-server/map-register/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: away
                            
                            	Administrative distance for RIB route installation
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.away = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: away_eids
                            
                            	Map cache configuration for the away table
                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.MapCache.AwayEids>`
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.Lisp.Service.Ipv4.Default.MapCache.AwayEids))])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None

                                self.away_eids = Native.Router.Lisp.Service.Ipv4.Default.MapCache.AwayEids()
                                self.away_eids.parent = self
                                self._children_name_map["away_eids"] = "away-eids"
                                self._segment_path = lambda: "map-cache"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapCache, ['site_registration'], name, value)


                            class AwayEids(Entity):
                                """
                                Map cache configuration for the away table
                                
                                .. attribute:: send_map_request
                                
                                	Export away table entries into the map cache with action set to send\-map\-request
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.Default.MapCache.AwayEids, self).__init__()

                                    self.yang_name = "away-eids"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                    ])
                                    self.send_map_request = None
                                    self._segment_path = lambda: "away-eids"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapCache.AwayEids, ['send_map_request'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.MapCachePersistent, ['interval'], name, value)


                        class ProxyItr(Entity):
                            """
                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            
                            .. attribute:: ipv4_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.ProxyItr, self).__init__()

                                self.yang_name = "proxy-itr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                ])
                                self.ipv4_addr = None
                                self.ipv6_addr = None
                                self._segment_path = lambda: "proxy-itr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	
                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.UsePetr.Priority>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Service.Ipv4.Default.UsePetr.Priority))])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ])
                                self.locator_address = None

                                self.priority = Native.Router.Lisp.Service.Ipv4.Default.UsePetr.Priority()
                                self.priority.parent = self
                                self._children_name_map["priority"] = "priority"
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.UsePetr, ['locator_address'], name, value)


                            class Priority(Entity):
                                """
                                
                                
                                .. attribute:: priority_value
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.Default.UsePetr.Priority, self).__init__()

                                    self.yang_name = "priority"
                                    self.yang_parent_name = "use-petr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.priority_value = None
                                    self.weight = None
                                    self._segment_path = lambda: "priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                        class Import(Entity):
                            """
                            Redistribute LISP states internally
                            
                            .. attribute:: database
                            
                            	Redistribute LISP internal states as database mapping
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Default.Import.Database>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Default.Import, self).__init__()

                                self.yang_name = "import"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Service.Ipv4.Default.Import.Database))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.Lisp.Service.Ipv4.Default.Import.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"
                                self._segment_path = lambda: "import"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Import, [], name, value)


                            class Database(Entity):
                                """
                                Redistribute LISP internal states as database mapping
                                
                                .. attribute:: site_registration
                                
                                	Import states from site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.Default.Import.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.site_registration = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "database"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/default/import/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Default.Import.Database, ['site_registration', 'locator_set'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Address family specific local EID prefixes database configuration
                        
                        .. attribute:: limit
                        
                        	Configures the maximum size of local EID prefixes database
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.DatabaseMapping.Limit>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Service.Ipv4.DatabaseMapping.Limit))])
                            self._leafs = OrderedDict()

                            self.limit = Native.Router.Lisp.Service.Ipv4.DatabaseMapping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "database-mapping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.DatabaseMapping, [], name, value)


                        class Limit(Entity):
                            """
                            Configures the maximum size of local EID prefixes database
                            
                            .. attribute:: dynamic
                            
                            	Configures the maximum size of dynamic local EID prefixes database
                            	**type**\: int
                            
                            	**range:** 1..5000
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "database-mapping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.dynamic = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/database-mapping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                    class Itr(Entity):
                        """
                        Configures a LISP Ingress Tunnel Router (ITR)
                        
                        .. attribute:: map_resolver
                        
                        	Configures map\-resolver address for sending Map\-Requests
                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Itr.MapResolver>`
                        
                        .. attribute:: nmr_ttl
                        
                        	verride negative map\-reply TTL for site EID
                        	**type**\: int
                        
                        	**range:** 1..900
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.Itr, self).__init__()

                            self.yang_name = "itr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ipv4.Itr.MapResolver))])
                            self._leafs = OrderedDict([
                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                            ])
                            self.nmr_ttl = None

                            self.map_resolver = YList(self)
                            self._segment_path = lambda: "itr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures map\-resolver address for sending Map\-Requests
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_list
                            
                            	Associates ITR/ETR with prefix list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Itr.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "itr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.ip_addr = None
                                self.prefix_list = None
                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/itr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                    class ItrEnable(Entity):
                        """
                        
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.ItrEnable, self).__init__()

                            self.yang_name = "itr-enable"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                            ])
                            self.itr = None
                            self._segment_path = lambda: "itr-enable"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.ItrEnable, ['itr'], name, value)


                    class EtrEnable(Entity):
                        """
                        
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.EtrEnable, self).__init__()

                            self.yang_name = "etr-enable"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                            ])
                            self.etr = None
                            self._segment_path = lambda: "etr-enable"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.EtrEnable, ['etr'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr.MapServer>`
                        
                        .. attribute:: map_cache_ttl
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..10080
                        
                        .. attribute:: accept_map_request_mapping
                        
                        	
                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                            self._leafs = OrderedDict([
                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                            ])
                            self.map_cache_ttl = None

                            self.accept_map_request_mapping = Native.Router.Lisp.Service.Ipv4.Etr.AcceptMapRequestMapping()
                            self.accept_map_request_mapping.parent = self
                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                            self.map_server = YList(self)
                            self._segment_path = lambda: "etr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/etr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_pwd
                                
                                	
                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                
                                .. attribute:: key_0
                                
                                	
                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                
                                .. attribute:: key_6
                                
                                	
                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                
                                .. attribute:: key_7
                                
                                	
                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                    self._leafs = OrderedDict()

                                    self.key_pwd = Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                    self.key_pwd.parent = self
                                    self._children_name_map["key_pwd"] = "key-pwd"

                                    self.key_0 = Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key0()
                                    self.key_0.parent = self
                                    self._children_name_map["key_0"] = "key-0"

                                    self.key_6 = Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key6()
                                    self.key_6.parent = self
                                    self._children_name_map["key_6"] = "key-6"

                                    self.key_7 = Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key7()
                                    self.key_7.parent = self
                                    self._children_name_map["key_7"] = "key-7"
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                class KeyPwd(Entity):
                                    """
                                    
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                        self.yang_name = "key-pwd"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-pwd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key0(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                        self.yang_name = "key-0"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_0 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-0"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                        self.yang_name = "key-6"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_6 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key7(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                        self.yang_name = "key-7"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_7 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-7"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                        class AcceptMapRequestMapping(Entity):
                            """
                            
                            
                            .. attribute:: accept_mappping
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: verify
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                self.yang_name = "accept-map-request-mapping"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                ])
                                self.accept_mappping = None
                                self.verify = None
                                self._segment_path = lambda: "accept-map-request-mapping"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/etr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                    class MapCacheLimit(Entity):
                        """
                        Configures maximum size of map\-cache
                        
                        .. attribute:: max_map_cache_entries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..100000
                        
                        .. attribute:: reserve_list
                        
                        	EID\-prefixes guaranteed to be stored in map\-cache
                        	**type**\: str
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.MapCacheLimit, self).__init__()

                            self.yang_name = "map-cache-limit"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.max_map_cache_entries = None
                            self.reserve_list = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "map-cache-limit"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                    class MapResolver(Entity):
                        """
                        Configures a LISP Map Resolver (MR)
                        
                        .. attribute:: map_request
                        
                        	Map\-Request processing options
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_request = Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"
                            self._segment_path = lambda: "map-resolver"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapResolver, [], name, value)


                        class MapRequest(Entity):
                            """
                            Map\-Request processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "map-resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-request"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/map-resolver/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	Influence which source RLOCs map requests are accepted from
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/map-resolver/map-request/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    Influence which source RLOCs map requests are accepted from
                                    
                                    .. attribute:: list
                                    
                                    	Define allowed prefixes using an ip[v6] prefix list
                                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List>`
                                    
                                    .. attribute:: registered
                                    
                                    	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                    	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered))])
                                        self._leafs = OrderedDict()

                                        self.list = Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List()
                                        self.list.parent = self
                                        self._children_name_map["list"] = "list"

                                        self.registered = Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered()
                                        self.registered.parent = self
                                        self._children_name_map["registered"] = "registered"
                                        self._segment_path = lambda: "source"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/map-resolver/map-request/validate/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source, [], name, value)


                                    class List(Entity):
                                        """
                                        Define allowed prefixes using an ip[v6] prefix list
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 prefixes
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 prefixes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                            self.yang_name = "list"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "list"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                    class Registered(Entity):
                                        """
                                        ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                            self.yang_name = "registered"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"
                                            self._segment_path = lambda: "registered"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "registered"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                    class MapServer(Entity):
                        """
                        Configures a LISP Map Server (MS)
                        
                        .. attribute:: map_register
                        
                        	Map\-Register processing options
                        	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_register = Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister()
                            self.map_register.parent = self
                            self._children_name_map["map_register"] = "map-register"
                            self._segment_path = lambda: "map-server"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapServer, [], name, value)


                        class MapRegister(Entity):
                            """
                            Map\-Register processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister, self).__init__()

                                self.yang_name = "map-register"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-register"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/map-server/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	RLOC Source IP address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-register"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/map-server/map-register/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    RLOC Source IP address
                                    
                                    .. attribute:: allowed_locator
                                    
                                    	Against sites' allowed\-locators policy
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                        ])
                                        self.allowed_locator = None
                                        self._segment_path = lambda: "source"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/map-server/map-register/validate/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                    class SiteRegistration(Entity):
                        """
                        Site registrations configuration for a given instance\-id
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class SolicitMapRequest(Entity):
                        """
                        Configure Solicit\-Map\-Request handling
                        
                        .. attribute:: ignore
                        
                        	Ignore SMR bit in incoming Map\-Requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_per_entry
                        
                        	Maximum number of SMRs for addresses under a map\-cache entry
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: suppression_time
                        
                        	How long to suppress repeated SMRs for the same address
                        	**type**\: int
                        
                        	**range:** 1..600
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.SolicitMapRequest, self).__init__()

                            self.yang_name = "solicit-map-request"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                            ])
                            self.ignore = None
                            self.max_per_entry = None
                            self.suppression_time = None
                            self._segment_path = lambda: "solicit-map-request"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                    class Distance(Entity):
                        """
                        Administrative distance for RIB route installation
                        
                        .. attribute:: alt
                        
                        	LISP routes installed in the ALT table
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: away
                        
                        	Administrative distance for RIB route installation
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: dyn_eid
                        
                        	LISP installed routes of type dynamic\-EID
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: site_registrations
                        
                        	LISP installed routes of type site\-registrations
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                            ])
                            self.alt = None
                            self.away = None
                            self.dyn_eid = None
                            self.site_registrations = None
                            self._segment_path = lambda: "distance"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                    class MapCache(Entity):
                        """
                        Address family specific map cache configuration
                        
                        .. attribute:: away_eids
                        
                        	Map cache configuration for the away table
                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.MapCache.AwayEids>`
                        
                        .. attribute:: site_registration
                        
                        	Install map cache to map request for site registrations
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.Lisp.Service.Ipv4.MapCache.AwayEids))])
                            self._leafs = OrderedDict([
                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                            ])
                            self.site_registration = None

                            self.away_eids = Native.Router.Lisp.Service.Ipv4.MapCache.AwayEids()
                            self.away_eids.parent = self
                            self._children_name_map["away_eids"] = "away-eids"
                            self._segment_path = lambda: "map-cache"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapCache, ['site_registration'], name, value)


                        class AwayEids(Entity):
                            """
                            Map cache configuration for the away table
                            
                            .. attribute:: send_map_request
                            
                            	Export away table entries into the map cache with action set to send\-map\-request
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                self.yang_name = "away-eids"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                ])
                                self.send_map_request = None
                                self._segment_path = lambda: "away-eids"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                    class MapCachePersistent(Entity):
                        """
                        Dump map\-cache onto flash, making it persistent across reboots
                        
                        .. attribute:: interval
                        
                        	Interval in minutes of how often the map\-cache is saved
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.MapCachePersistent, self).__init__()

                            self.yang_name = "map-cache-persistent"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "map-cache-persistent"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                    class ProxyItr(Entity):
                        """
                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        
                        .. attribute:: ipv4_addr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_addr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.ProxyItr, self).__init__()

                            self.yang_name = "proxy-itr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                            ])
                            self.ipv4_addr = None
                            self.ipv6_addr = None
                            self._segment_path = lambda: "proxy-itr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                    class RouteExport(Entity):
                        """
                        Export routes into RIB from LISP
                        
                        .. attribute:: site_registrations
                        
                        	Export LISP site registrations to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: away_eids
                        
                        	Export LISP away EIDs to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.RouteExport, self).__init__()

                            self.yang_name = "route-export"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                            ])
                            self.site_registrations = None
                            self.away_eids = None
                            self._segment_path = lambda: "route-export"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                    class UsePetr(Entity):
                        """
                        Encapsulate to Proxy ETR when matching forward\-native entry
                        
                        .. attribute:: locator_address  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.UsePetr.Priority>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.UsePetr, self).__init__()

                            self.yang_name = "use-petr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['locator_address']
                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Service.Ipv4.UsePetr.Priority))])
                            self._leafs = OrderedDict([
                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                            ])
                            self.locator_address = None

                            self.priority = Native.Router.Lisp.Service.Ipv4.UsePetr.Priority()
                            self.priority.parent = self
                            self._children_name_map["priority"] = "priority"
                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                        class Priority(Entity):
                            """
                            
                            
                            .. attribute:: priority_value
                            
                            	Configures which Locators from a set are preferred
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: weight
                            
                            	Traffic load\-spreading among Locators
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.UsePetr.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "use-petr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                ])
                                self.priority_value = None
                                self.weight = None
                                self._segment_path = lambda: "priority"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                    class Import(Entity):
                        """
                        Redistribute LISP states internally
                        
                        .. attribute:: database
                        
                        	Redistribute LISP internal states as database mapping
                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv4.Import.Database>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv4.Import, self).__init__()

                            self.yang_name = "import"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Service.Ipv4.Import.Database))])
                            self._leafs = OrderedDict()

                            self.database = Native.Router.Lisp.Service.Ipv4.Import.Database()
                            self.database.parent = self
                            self._children_name_map["database"] = "database"
                            self._segment_path = lambda: "import"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Import, [], name, value)


                        class Database(Entity):
                            """
                            Redistribute LISP internal states as database mapping
                            
                            .. attribute:: site_registration
                            
                            	Import states from site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: locator_set
                            
                            	Locator set to use with created database mapping entries
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv4.Import.Database, self).__init__()

                                self.yang_name = "database"
                                self.yang_parent_name = "import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                ])
                                self.site_registration = None
                                self.locator_set = None
                                self._segment_path = lambda: "database"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv4/import/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                class Ipv6(Entity):
                    """
                    
                    
                    .. attribute:: default
                    
                    	
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default>`
                    
                    .. attribute:: database_mapping
                    
                    	Address family specific local EID prefixes database configuration
                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.DatabaseMapping>`
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Itr>`
                    
                    .. attribute:: itr_enable
                    
                    	
                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.ItrEnable>`
                    
                    .. attribute:: etr_enable
                    
                    	
                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.EtrEnable>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr>`
                    
                    .. attribute:: map_cache_limit
                    
                    	Configures maximum size of map\-cache
                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapCacheLimit>`
                    
                    .. attribute:: map_resolver
                    
                    	Configures a LISP Map Resolver (MR)
                    	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapResolver>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: map_server
                    
                    	Configures a LISP Map Server (MS)
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapServer>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: site_registration
                    
                    	Site registrations configuration for a given instance\-id
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.SiteRegistration>`
                    
                    .. attribute:: solicit_map_request
                    
                    	Configure Solicit\-Map\-Request handling
                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.SolicitMapRequest>`
                    
                    .. attribute:: distance
                    
                    	Administrative distance for RIB route installation
                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Distance>`
                    
                    .. attribute:: encapsulation
                    
                    	Select encapsulation type for data packets
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Encapsulation>`
                    
                    .. attribute:: map_cache
                    
                    	Address family specific map cache configuration
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapCache>`
                    
                    .. attribute:: map_cache_persistent
                    
                    	Dump map\-cache onto flash, making it persistent across reboots
                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapCachePersistent>`
                    
                    .. attribute:: proxy_etr
                    
                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: proxy_itr
                    
                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.ProxyItr>`
                    
                    .. attribute:: route_export
                    
                    	Export routes into RIB from LISP
                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.RouteExport>`
                    
                    .. attribute:: sgt
                    
                    	Enable security group tag propagation in LISP encapsulated traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: use_petr
                    
                    	Encapsulate to Proxy ETR when matching forward\-native entry
                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.UsePetr>`
                    
                    .. attribute:: import_
                    
                    	Redistribute LISP states internally
                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Import>`
                    
                    .. attribute:: map_request_source
                    
                    	Configures inner header source address in Map\-Request message
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Service.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Service.Ipv6.Default)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Service.Ipv6.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Service.Ipv6.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Service.Ipv6.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Service.Ipv6.SolicitMapRequest)), ("distance", ("distance", Native.Router.Lisp.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.Lisp.Service.Ipv6.Import))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv6.Encapsulation')])),
                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                        ])
                        self.encapsulation = None
                        self.proxy_etr = None
                        self.sgt = None
                        self.map_request_source = None

                        self.default = Native.Router.Lisp.Service.Ipv6.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.database_mapping = Native.Router.Lisp.Service.Ipv6.DatabaseMapping()
                        self.database_mapping.parent = self
                        self._children_name_map["database_mapping"] = "database-mapping"

                        self.itr = Native.Router.Lisp.Service.Ipv6.Itr()
                        self.itr.parent = self
                        self._children_name_map["itr"] = "itr"

                        self.itr_enable = Native.Router.Lisp.Service.Ipv6.ItrEnable()
                        self.itr_enable.parent = self
                        self._children_name_map["itr_enable"] = "itr-enable"

                        self.etr_enable = Native.Router.Lisp.Service.Ipv6.EtrEnable()
                        self.etr_enable.parent = self
                        self._children_name_map["etr_enable"] = "etr-enable"

                        self.etr = Native.Router.Lisp.Service.Ipv6.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.map_cache_limit = Native.Router.Lisp.Service.Ipv6.MapCacheLimit()
                        self.map_cache_limit.parent = self
                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                        self.map_resolver = None
                        self._children_name_map["map_resolver"] = "map-resolver"

                        self.map_server = None
                        self._children_name_map["map_server"] = "map-server"

                        self.site_registration = Native.Router.Lisp.Service.Ipv6.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.solicit_map_request = Native.Router.Lisp.Service.Ipv6.SolicitMapRequest()
                        self.solicit_map_request.parent = self
                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                        self.distance = Native.Router.Lisp.Service.Ipv6.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"

                        self.map_cache = Native.Router.Lisp.Service.Ipv6.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"

                        self.map_cache_persistent = Native.Router.Lisp.Service.Ipv6.MapCachePersistent()
                        self.map_cache_persistent.parent = self
                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                        self.proxy_itr = Native.Router.Lisp.Service.Ipv6.ProxyItr()
                        self.proxy_itr.parent = self
                        self._children_name_map["proxy_itr"] = "proxy-itr"

                        self.route_export = Native.Router.Lisp.Service.Ipv6.RouteExport()
                        self.route_export.parent = self
                        self._children_name_map["route_export"] = "route-export"

                        self.import_ = Native.Router.Lisp.Service.Ipv6.Import()
                        self.import_.parent = self
                        self._children_name_map["import_"] = "import"

                        self.use_petr = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Service.Ipv6, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Select encapsulation type for data packets

                        .. data:: lisp = 0

                        .. data:: vxlan = 1

                        """

                        lisp = Enum.YLeaf(0, "lisp")

                        vxlan = Enum.YLeaf(1, "vxlan")



                    class Default(Entity):
                        """
                        
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.SolicitMapRequest>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Distance>`
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Encapsulation>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapCache>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapCachePersistent>`
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.ProxyItr>`
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.RouteExport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.UsePetr>`
                        
                        .. attribute:: import_
                        
                        	Redistribute LISP states internally
                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Import>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Service.Ipv6.Default.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Service.Ipv6.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Service.Ipv6.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Service.Ipv6.Default.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Service.Ipv6.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Service.Ipv6.Default.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ipv6.Default.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Service.Ipv6.Default.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Service.Ipv6.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Service.Ipv6.Default.SolicitMapRequest)), ("distance", ("distance", Native.Router.Lisp.Service.Ipv6.Default.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.Service.Ipv6.Default.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Service.Ipv6.Default.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.Service.Ipv6.Default.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.Service.Ipv6.Default.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.Service.Ipv6.Default.UsePetr)), ("import", ("import_", Native.Router.Lisp.Service.Ipv6.Default.Import))])
                            self._leafs = OrderedDict([
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv6.Default.Encapsulation')])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ])
                            self.encapsulation = None
                            self.proxy_etr = None
                            self.sgt = None
                            self.map_request_source = None

                            self.database_mapping = Native.Router.Lisp.Service.Ipv6.Default.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.Lisp.Service.Ipv6.Default.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.Lisp.Service.Ipv6.Default.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.Lisp.Service.Ipv6.Default.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.Lisp.Service.Ipv6.Default.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.Lisp.Service.Ipv6.Default.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.Lisp.Service.Ipv6.Default.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.Lisp.Service.Ipv6.Default.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.distance = Native.Router.Lisp.Service.Ipv6.Default.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.map_cache = Native.Router.Lisp.Service.Ipv6.Default.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_persistent = Native.Router.Lisp.Service.Ipv6.Default.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.proxy_itr = Native.Router.Lisp.Service.Ipv6.Default.ProxyItr()
                            self.proxy_itr.parent = self
                            self._children_name_map["proxy_itr"] = "proxy-itr"

                            self.route_export = Native.Router.Lisp.Service.Ipv6.Default.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.import_ = Native.Router.Lisp.Service.Ipv6.Default.Import()
                            self.import_.parent = self
                            self._children_name_map["import_"] = "import"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "default"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Select encapsulation type for data packets

                            .. data:: lisp = 0

                            .. data:: vxlan = 1

                            """

                            lisp = Enum.YLeaf(0, "lisp")

                            vxlan = Enum.YLeaf(1, "vxlan")



                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Service.Ipv6.Default.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.Lisp.Service.Ipv6.Default.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.Default.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/database-mapping/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ipv6.Default.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.Default.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/itr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Service.Ipv6.Default.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.Lisp.Service.Ipv6.Default.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/map-resolver/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/map-resolver/map-request/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/map-resolver/map-request/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/map-server/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/map-server/map-register/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/map-server/map-register/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: away
                            
                            	Administrative distance for RIB route installation
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.away = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: away_eids
                            
                            	Map cache configuration for the away table
                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.MapCache.AwayEids>`
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.Lisp.Service.Ipv6.Default.MapCache.AwayEids))])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None

                                self.away_eids = Native.Router.Lisp.Service.Ipv6.Default.MapCache.AwayEids()
                                self.away_eids.parent = self
                                self._children_name_map["away_eids"] = "away-eids"
                                self._segment_path = lambda: "map-cache"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapCache, ['site_registration'], name, value)


                            class AwayEids(Entity):
                                """
                                Map cache configuration for the away table
                                
                                .. attribute:: send_map_request
                                
                                	Export away table entries into the map cache with action set to send\-map\-request
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.Default.MapCache.AwayEids, self).__init__()

                                    self.yang_name = "away-eids"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                    ])
                                    self.send_map_request = None
                                    self._segment_path = lambda: "away-eids"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/map-cache/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapCache.AwayEids, ['send_map_request'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.MapCachePersistent, ['interval'], name, value)


                        class ProxyItr(Entity):
                            """
                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            
                            .. attribute:: ipv4_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.ProxyItr, self).__init__()

                                self.yang_name = "proxy-itr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                ])
                                self.ipv4_addr = None
                                self.ipv6_addr = None
                                self._segment_path = lambda: "proxy-itr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	
                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.UsePetr.Priority>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Service.Ipv6.Default.UsePetr.Priority))])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ])
                                self.locator_address = None

                                self.priority = Native.Router.Lisp.Service.Ipv6.Default.UsePetr.Priority()
                                self.priority.parent = self
                                self._children_name_map["priority"] = "priority"
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.UsePetr, ['locator_address'], name, value)


                            class Priority(Entity):
                                """
                                
                                
                                .. attribute:: priority_value
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.Default.UsePetr.Priority, self).__init__()

                                    self.yang_name = "priority"
                                    self.yang_parent_name = "use-petr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.priority_value = None
                                    self.weight = None
                                    self._segment_path = lambda: "priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                        class Import(Entity):
                            """
                            Redistribute LISP states internally
                            
                            .. attribute:: database
                            
                            	Redistribute LISP internal states as database mapping
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Default.Import.Database>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Default.Import, self).__init__()

                                self.yang_name = "import"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Service.Ipv6.Default.Import.Database))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.Lisp.Service.Ipv6.Default.Import.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"
                                self._segment_path = lambda: "import"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Import, [], name, value)


                            class Database(Entity):
                                """
                                Redistribute LISP internal states as database mapping
                                
                                .. attribute:: site_registration
                                
                                	Import states from site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.Default.Import.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.site_registration = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "database"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/default/import/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Default.Import.Database, ['site_registration', 'locator_set'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Address family specific local EID prefixes database configuration
                        
                        .. attribute:: limit
                        
                        	Configures the maximum size of local EID prefixes database
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.DatabaseMapping.Limit>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Service.Ipv6.DatabaseMapping.Limit))])
                            self._leafs = OrderedDict()

                            self.limit = Native.Router.Lisp.Service.Ipv6.DatabaseMapping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "database-mapping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.DatabaseMapping, [], name, value)


                        class Limit(Entity):
                            """
                            Configures the maximum size of local EID prefixes database
                            
                            .. attribute:: dynamic
                            
                            	Configures the maximum size of dynamic local EID prefixes database
                            	**type**\: int
                            
                            	**range:** 1..5000
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "database-mapping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.dynamic = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/database-mapping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                    class Itr(Entity):
                        """
                        Configures a LISP Ingress Tunnel Router (ITR)
                        
                        .. attribute:: map_resolver
                        
                        	Configures map\-resolver address for sending Map\-Requests
                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Itr.MapResolver>`
                        
                        .. attribute:: nmr_ttl
                        
                        	verride negative map\-reply TTL for site EID
                        	**type**\: int
                        
                        	**range:** 1..900
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.Itr, self).__init__()

                            self.yang_name = "itr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ipv6.Itr.MapResolver))])
                            self._leafs = OrderedDict([
                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                            ])
                            self.nmr_ttl = None

                            self.map_resolver = YList(self)
                            self._segment_path = lambda: "itr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures map\-resolver address for sending Map\-Requests
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_list
                            
                            	Associates ITR/ETR with prefix list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Itr.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "itr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.ip_addr = None
                                self.prefix_list = None
                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/itr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                    class ItrEnable(Entity):
                        """
                        
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.ItrEnable, self).__init__()

                            self.yang_name = "itr-enable"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                            ])
                            self.itr = None
                            self._segment_path = lambda: "itr-enable"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.ItrEnable, ['itr'], name, value)


                    class EtrEnable(Entity):
                        """
                        
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.EtrEnable, self).__init__()

                            self.yang_name = "etr-enable"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                            ])
                            self.etr = None
                            self._segment_path = lambda: "etr-enable"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.EtrEnable, ['etr'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr.MapServer>`
                        
                        .. attribute:: map_cache_ttl
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..10080
                        
                        .. attribute:: accept_map_request_mapping
                        
                        	
                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                            self._leafs = OrderedDict([
                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                            ])
                            self.map_cache_ttl = None

                            self.accept_map_request_mapping = Native.Router.Lisp.Service.Ipv6.Etr.AcceptMapRequestMapping()
                            self.accept_map_request_mapping.parent = self
                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                            self.map_server = YList(self)
                            self._segment_path = lambda: "etr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/etr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_pwd
                                
                                	
                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                
                                .. attribute:: key_0
                                
                                	
                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                
                                .. attribute:: key_6
                                
                                	
                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                
                                .. attribute:: key_7
                                
                                	
                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                    self._leafs = OrderedDict()

                                    self.key_pwd = Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                    self.key_pwd.parent = self
                                    self._children_name_map["key_pwd"] = "key-pwd"

                                    self.key_0 = Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key0()
                                    self.key_0.parent = self
                                    self._children_name_map["key_0"] = "key-0"

                                    self.key_6 = Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key6()
                                    self.key_6.parent = self
                                    self._children_name_map["key_6"] = "key-6"

                                    self.key_7 = Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key7()
                                    self.key_7.parent = self
                                    self._children_name_map["key_7"] = "key-7"
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                class KeyPwd(Entity):
                                    """
                                    
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                        self.yang_name = "key-pwd"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-pwd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key0(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                        self.yang_name = "key-0"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_0 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-0"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                        self.yang_name = "key-6"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_6 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key7(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                        self.yang_name = "key-7"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_7 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-7"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                        class AcceptMapRequestMapping(Entity):
                            """
                            
                            
                            .. attribute:: accept_mappping
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: verify
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                self.yang_name = "accept-map-request-mapping"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                ])
                                self.accept_mappping = None
                                self.verify = None
                                self._segment_path = lambda: "accept-map-request-mapping"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/etr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                    class MapCacheLimit(Entity):
                        """
                        Configures maximum size of map\-cache
                        
                        .. attribute:: max_map_cache_entries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..100000
                        
                        .. attribute:: reserve_list
                        
                        	EID\-prefixes guaranteed to be stored in map\-cache
                        	**type**\: str
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.MapCacheLimit, self).__init__()

                            self.yang_name = "map-cache-limit"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.max_map_cache_entries = None
                            self.reserve_list = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "map-cache-limit"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                    class MapResolver(Entity):
                        """
                        Configures a LISP Map Resolver (MR)
                        
                        .. attribute:: map_request
                        
                        	Map\-Request processing options
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_request = Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"
                            self._segment_path = lambda: "map-resolver"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapResolver, [], name, value)


                        class MapRequest(Entity):
                            """
                            Map\-Request processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "map-resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-request"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/map-resolver/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	Influence which source RLOCs map requests are accepted from
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/map-resolver/map-request/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    Influence which source RLOCs map requests are accepted from
                                    
                                    .. attribute:: list
                                    
                                    	Define allowed prefixes using an ip[v6] prefix list
                                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List>`
                                    
                                    .. attribute:: registered
                                    
                                    	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                    	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered))])
                                        self._leafs = OrderedDict()

                                        self.list = Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List()
                                        self.list.parent = self
                                        self._children_name_map["list"] = "list"

                                        self.registered = Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered()
                                        self.registered.parent = self
                                        self._children_name_map["registered"] = "registered"
                                        self._segment_path = lambda: "source"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/map-resolver/map-request/validate/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source, [], name, value)


                                    class List(Entity):
                                        """
                                        Define allowed prefixes using an ip[v6] prefix list
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 prefixes
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 prefixes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                            self.yang_name = "list"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "list"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                    class Registered(Entity):
                                        """
                                        ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                            self.yang_name = "registered"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"
                                            self._segment_path = lambda: "registered"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "registered"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                    class MapServer(Entity):
                        """
                        Configures a LISP Map Server (MS)
                        
                        .. attribute:: map_register
                        
                        	Map\-Register processing options
                        	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_register = Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister()
                            self.map_register.parent = self
                            self._children_name_map["map_register"] = "map-register"
                            self._segment_path = lambda: "map-server"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapServer, [], name, value)


                        class MapRegister(Entity):
                            """
                            Map\-Register processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister, self).__init__()

                                self.yang_name = "map-register"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-register"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/map-server/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	RLOC Source IP address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-register"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/map-server/map-register/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    RLOC Source IP address
                                    
                                    .. attribute:: allowed_locator
                                    
                                    	Against sites' allowed\-locators policy
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                        ])
                                        self.allowed_locator = None
                                        self._segment_path = lambda: "source"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/map-server/map-register/validate/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                    class SiteRegistration(Entity):
                        """
                        Site registrations configuration for a given instance\-id
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class SolicitMapRequest(Entity):
                        """
                        Configure Solicit\-Map\-Request handling
                        
                        .. attribute:: ignore
                        
                        	Ignore SMR bit in incoming Map\-Requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_per_entry
                        
                        	Maximum number of SMRs for addresses under a map\-cache entry
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: suppression_time
                        
                        	How long to suppress repeated SMRs for the same address
                        	**type**\: int
                        
                        	**range:** 1..600
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.SolicitMapRequest, self).__init__()

                            self.yang_name = "solicit-map-request"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                            ])
                            self.ignore = None
                            self.max_per_entry = None
                            self.suppression_time = None
                            self._segment_path = lambda: "solicit-map-request"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                    class Distance(Entity):
                        """
                        Administrative distance for RIB route installation
                        
                        .. attribute:: alt
                        
                        	LISP routes installed in the ALT table
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: away
                        
                        	Administrative distance for RIB route installation
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: dyn_eid
                        
                        	LISP installed routes of type dynamic\-EID
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: site_registrations
                        
                        	LISP installed routes of type site\-registrations
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                            ])
                            self.alt = None
                            self.away = None
                            self.dyn_eid = None
                            self.site_registrations = None
                            self._segment_path = lambda: "distance"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                    class MapCache(Entity):
                        """
                        Address family specific map cache configuration
                        
                        .. attribute:: away_eids
                        
                        	Map cache configuration for the away table
                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.MapCache.AwayEids>`
                        
                        .. attribute:: site_registration
                        
                        	Install map cache to map request for site registrations
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.Lisp.Service.Ipv6.MapCache.AwayEids))])
                            self._leafs = OrderedDict([
                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                            ])
                            self.site_registration = None

                            self.away_eids = Native.Router.Lisp.Service.Ipv6.MapCache.AwayEids()
                            self.away_eids.parent = self
                            self._children_name_map["away_eids"] = "away-eids"
                            self._segment_path = lambda: "map-cache"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapCache, ['site_registration'], name, value)


                        class AwayEids(Entity):
                            """
                            Map cache configuration for the away table
                            
                            .. attribute:: send_map_request
                            
                            	Export away table entries into the map cache with action set to send\-map\-request
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                self.yang_name = "away-eids"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                ])
                                self.send_map_request = None
                                self._segment_path = lambda: "away-eids"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                    class MapCachePersistent(Entity):
                        """
                        Dump map\-cache onto flash, making it persistent across reboots
                        
                        .. attribute:: interval
                        
                        	Interval in minutes of how often the map\-cache is saved
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.MapCachePersistent, self).__init__()

                            self.yang_name = "map-cache-persistent"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "map-cache-persistent"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                    class ProxyItr(Entity):
                        """
                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        
                        .. attribute:: ipv4_addr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_addr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.ProxyItr, self).__init__()

                            self.yang_name = "proxy-itr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                            ])
                            self.ipv4_addr = None
                            self.ipv6_addr = None
                            self._segment_path = lambda: "proxy-itr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                    class RouteExport(Entity):
                        """
                        Export routes into RIB from LISP
                        
                        .. attribute:: site_registrations
                        
                        	Export LISP site registrations to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: away_eids
                        
                        	Export LISP away EIDs to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.RouteExport, self).__init__()

                            self.yang_name = "route-export"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                            ])
                            self.site_registrations = None
                            self.away_eids = None
                            self._segment_path = lambda: "route-export"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                    class UsePetr(Entity):
                        """
                        Encapsulate to Proxy ETR when matching forward\-native entry
                        
                        .. attribute:: locator_address  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.UsePetr.Priority>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.UsePetr, self).__init__()

                            self.yang_name = "use-petr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['locator_address']
                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.Service.Ipv6.UsePetr.Priority))])
                            self._leafs = OrderedDict([
                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                            ])
                            self.locator_address = None

                            self.priority = Native.Router.Lisp.Service.Ipv6.UsePetr.Priority()
                            self.priority.parent = self
                            self._children_name_map["priority"] = "priority"
                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                        class Priority(Entity):
                            """
                            
                            
                            .. attribute:: priority_value
                            
                            	Configures which Locators from a set are preferred
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: weight
                            
                            	Traffic load\-spreading among Locators
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.UsePetr.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "use-petr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                ])
                                self.priority_value = None
                                self.weight = None
                                self._segment_path = lambda: "priority"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                    class Import(Entity):
                        """
                        Redistribute LISP states internally
                        
                        .. attribute:: database
                        
                        	Redistribute LISP internal states as database mapping
                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ipv6.Import.Database>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ipv6.Import, self).__init__()

                            self.yang_name = "import"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Service.Ipv6.Import.Database))])
                            self._leafs = OrderedDict()

                            self.database = Native.Router.Lisp.Service.Ipv6.Import.Database()
                            self.database.parent = self
                            self._children_name_map["database"] = "database"
                            self._segment_path = lambda: "import"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Import, [], name, value)


                        class Database(Entity):
                            """
                            Redistribute LISP internal states as database mapping
                            
                            .. attribute:: site_registration
                            
                            	Import states from site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: locator_set
                            
                            	Locator set to use with created database mapping entries
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ipv6.Import.Database, self).__init__()

                                self.yang_name = "database"
                                self.yang_parent_name = "import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                ])
                                self.site_registration = None
                                self.locator_set = None
                                self._segment_path = lambda: "database"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ipv6/import/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                class Ethernet(Entity):
                    """
                    
                    
                    .. attribute:: default
                    
                    	
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default>`
                    
                    .. attribute:: encapsulation
                    
                    	Select encapsulation type for data packets
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Encapsulation>`
                    
                    .. attribute:: map_request_source
                    
                    	Configures inner header source address in Map\-Request message
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: database_mapping
                    
                    	Address family specific local EID prefixes database configuration
                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.DatabaseMapping>`
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Itr>`
                    
                    .. attribute:: itr_enable
                    
                    	
                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.ItrEnable>`
                    
                    .. attribute:: etr_enable
                    
                    	
                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.EtrEnable>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr>`
                    
                    .. attribute:: map_cache_limit
                    
                    	Configures maximum size of map\-cache
                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapCacheLimit>`
                    
                    .. attribute:: map_resolver
                    
                    	Configures a LISP Map Resolver (MR)
                    	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapResolver>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: map_server
                    
                    	Configures a LISP Map Server (MS)
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapServer>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: site_registration
                    
                    	Site registrations configuration for a given instance\-id
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.SiteRegistration>`
                    
                    .. attribute:: solicit_map_request
                    
                    	Configure Solicit\-Map\-Request handling
                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.SolicitMapRequest>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Service.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Service.Ethernet.Default)), ("encapsulation", ("encapsulation", Native.Router.Lisp.Service.Ethernet.Encapsulation)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Service.Ethernet.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ethernet.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Service.Ethernet.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Service.Ethernet.SolicitMapRequest))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                        ])
                        self.map_request_source = None

                        self.default = Native.Router.Lisp.Service.Ethernet.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.encapsulation = Native.Router.Lisp.Service.Ethernet.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.database_mapping = Native.Router.Lisp.Service.Ethernet.DatabaseMapping()
                        self.database_mapping.parent = self
                        self._children_name_map["database_mapping"] = "database-mapping"

                        self.itr = Native.Router.Lisp.Service.Ethernet.Itr()
                        self.itr.parent = self
                        self._children_name_map["itr"] = "itr"

                        self.itr_enable = Native.Router.Lisp.Service.Ethernet.ItrEnable()
                        self.itr_enable.parent = self
                        self._children_name_map["itr_enable"] = "itr-enable"

                        self.etr_enable = Native.Router.Lisp.Service.Ethernet.EtrEnable()
                        self.etr_enable.parent = self
                        self._children_name_map["etr_enable"] = "etr-enable"

                        self.etr = Native.Router.Lisp.Service.Ethernet.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.map_cache_limit = Native.Router.Lisp.Service.Ethernet.MapCacheLimit()
                        self.map_cache_limit.parent = self
                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                        self.map_resolver = None
                        self._children_name_map["map_resolver"] = "map-resolver"

                        self.map_server = None
                        self._children_name_map["map_server"] = "map-server"

                        self.site_registration = Native.Router.Lisp.Service.Ethernet.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.solicit_map_request = Native.Router.Lisp.Service.Ethernet.SolicitMapRequest()
                        self.solicit_map_request.parent = self
                        self._children_name_map["solicit_map_request"] = "solicit-map-request"
                        self._segment_path = lambda: "ethernet"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Service.Ethernet, ['map_request_source'], name, value)


                    class Default(Entity):
                        """
                        
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Encapsulation>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.SolicitMapRequest>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Router.Lisp.Service.Ethernet.Default.Encapsulation)), ("database-mapping", ("database_mapping", Native.Router.Lisp.Service.Ethernet.Default.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.Service.Ethernet.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Service.Ethernet.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Service.Ethernet.Default.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.Service.Ethernet.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Service.Ethernet.Default.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ethernet.Default.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Service.Ethernet.Default.MapServer)), ("site-registration", ("site_registration", Native.Router.Lisp.Service.Ethernet.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Service.Ethernet.Default.SolicitMapRequest))])
                            self._leafs = OrderedDict([
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                            ])
                            self.map_request_source = None

                            self.encapsulation = Native.Router.Lisp.Service.Ethernet.Default.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.database_mapping = Native.Router.Lisp.Service.Ethernet.Default.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.Lisp.Service.Ethernet.Default.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.Lisp.Service.Ethernet.Default.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.Lisp.Service.Ethernet.Default.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.Lisp.Service.Ethernet.Default.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.Lisp.Service.Ethernet.Default.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.Lisp.Service.Ethernet.Default.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.Lisp.Service.Ethernet.Default.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"
                            self._segment_path = lambda: "default"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default, ['map_request_source'], name, value)


                        class Encapsulation(Entity):
                            """
                            Select encapsulation type for data packets
                            
                            .. attribute:: vxlan
                            
                            	Use VXLAN encapsulation for data packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Default.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                ])
                                self.vxlan = None
                                self._segment_path = lambda: "encapsulation"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.Encapsulation, ['vxlan'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Default.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Service.Ethernet.Default.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.Lisp.Service.Ethernet.Default.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ethernet.Default.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/database-mapping/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Default.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ethernet.Default.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ethernet.Default.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/itr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Default.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Default.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Default.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Service.Ethernet.Default.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.Lisp.Service.Ethernet.Default.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ethernet.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/etr/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Default.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Default.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/map-resolver/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/map-resolver/map-request/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/map-resolver/map-request/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Default.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/map-server/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/map-server/map-register/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/map-server/map-register/validate/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Default.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Default.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/default/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                    class Encapsulation(Entity):
                        """
                        Select encapsulation type for data packets
                        
                        .. attribute:: vxlan
                        
                        	Use VXLAN encapsulation for data packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                            ])
                            self.vxlan = None
                            self._segment_path = lambda: "encapsulation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Encapsulation, ['vxlan'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Address family specific local EID prefixes database configuration
                        
                        .. attribute:: limit
                        
                        	Configures the maximum size of local EID prefixes database
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.DatabaseMapping.Limit>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Service.Ethernet.DatabaseMapping.Limit))])
                            self._leafs = OrderedDict()

                            self.limit = Native.Router.Lisp.Service.Ethernet.DatabaseMapping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "database-mapping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.DatabaseMapping, [], name, value)


                        class Limit(Entity):
                            """
                            Configures the maximum size of local EID prefixes database
                            
                            .. attribute:: dynamic
                            
                            	Configures the maximum size of dynamic local EID prefixes database
                            	**type**\: int
                            
                            	**range:** 1..5000
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "database-mapping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.dynamic = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/database-mapping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                    class Itr(Entity):
                        """
                        Configures a LISP Ingress Tunnel Router (ITR)
                        
                        .. attribute:: map_resolver
                        
                        	Configures map\-resolver address for sending Map\-Requests
                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Itr.MapResolver>`
                        
                        .. attribute:: nmr_ttl
                        
                        	verride negative map\-reply TTL for site EID
                        	**type**\: int
                        
                        	**range:** 1..900
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.Itr, self).__init__()

                            self.yang_name = "itr"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Service.Ethernet.Itr.MapResolver))])
                            self._leafs = OrderedDict([
                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                            ])
                            self.nmr_ttl = None

                            self.map_resolver = YList(self)
                            self._segment_path = lambda: "itr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures map\-resolver address for sending Map\-Requests
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_list
                            
                            	Associates ITR/ETR with prefix list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Itr.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "itr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.ip_addr = None
                                self.prefix_list = None
                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/itr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                    class ItrEnable(Entity):
                        """
                        
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.ItrEnable, self).__init__()

                            self.yang_name = "itr-enable"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                            ])
                            self.itr = None
                            self._segment_path = lambda: "itr-enable"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.ItrEnable, ['itr'], name, value)


                    class EtrEnable(Entity):
                        """
                        
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.EtrEnable, self).__init__()

                            self.yang_name = "etr-enable"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                            ])
                            self.etr = None
                            self._segment_path = lambda: "etr-enable"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.EtrEnable, ['etr'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr.MapServer>`
                        
                        .. attribute:: map_cache_ttl
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..10080
                        
                        .. attribute:: accept_map_request_mapping
                        
                        	
                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                            self._leafs = OrderedDict([
                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                            ])
                            self.map_cache_ttl = None

                            self.accept_map_request_mapping = Native.Router.Lisp.Service.Ethernet.Etr.AcceptMapRequestMapping()
                            self.accept_map_request_mapping.parent = self
                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                            self.map_server = YList(self)
                            self._segment_path = lambda: "etr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/etr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_pwd
                                
                                	
                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                
                                .. attribute:: key_0
                                
                                	
                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                
                                .. attribute:: key_6
                                
                                	
                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                
                                .. attribute:: key_7
                                
                                	
                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                    self._leafs = OrderedDict()

                                    self.key_pwd = Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                    self.key_pwd.parent = self
                                    self._children_name_map["key_pwd"] = "key-pwd"

                                    self.key_0 = Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key0()
                                    self.key_0.parent = self
                                    self._children_name_map["key_0"] = "key-0"

                                    self.key_6 = Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key6()
                                    self.key_6.parent = self
                                    self._children_name_map["key_6"] = "key-6"

                                    self.key_7 = Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key7()
                                    self.key_7.parent = self
                                    self._children_name_map["key_7"] = "key-7"
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                class KeyPwd(Entity):
                                    """
                                    
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                        self.yang_name = "key-pwd"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-pwd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key0(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                        self.yang_name = "key-0"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_0 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-0"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                        self.yang_name = "key-6"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_6 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key7(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                        self.yang_name = "key-7"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_7 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-7"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                        class AcceptMapRequestMapping(Entity):
                            """
                            
                            
                            .. attribute:: accept_mappping
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: verify
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                self.yang_name = "accept-map-request-mapping"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                ])
                                self.accept_mappping = None
                                self.verify = None
                                self._segment_path = lambda: "accept-map-request-mapping"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/etr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                    class MapCacheLimit(Entity):
                        """
                        Configures maximum size of map\-cache
                        
                        .. attribute:: max_map_cache_entries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..100000
                        
                        .. attribute:: reserve_list
                        
                        	EID\-prefixes guaranteed to be stored in map\-cache
                        	**type**\: str
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.MapCacheLimit, self).__init__()

                            self.yang_name = "map-cache-limit"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.max_map_cache_entries = None
                            self.reserve_list = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "map-cache-limit"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                    class MapResolver(Entity):
                        """
                        Configures a LISP Map Resolver (MR)
                        
                        .. attribute:: map_request
                        
                        	Map\-Request processing options
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_request = Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"
                            self._segment_path = lambda: "map-resolver"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapResolver, [], name, value)


                        class MapRequest(Entity):
                            """
                            Map\-Request processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "map-resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-request"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/map-resolver/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	Influence which source RLOCs map requests are accepted from
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/map-resolver/map-request/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    Influence which source RLOCs map requests are accepted from
                                    
                                    .. attribute:: list
                                    
                                    	Define allowed prefixes using an ip[v6] prefix list
                                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List>`
                                    
                                    .. attribute:: registered
                                    
                                    	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                    	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered))])
                                        self._leafs = OrderedDict()

                                        self.list = Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List()
                                        self.list.parent = self
                                        self._children_name_map["list"] = "list"

                                        self.registered = Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered()
                                        self.registered.parent = self
                                        self._children_name_map["registered"] = "registered"
                                        self._segment_path = lambda: "source"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/map-resolver/map-request/validate/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source, [], name, value)


                                    class List(Entity):
                                        """
                                        Define allowed prefixes using an ip[v6] prefix list
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 prefixes
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 prefixes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                            self.yang_name = "list"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "list"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                    class Registered(Entity):
                                        """
                                        ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                            self.yang_name = "registered"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"
                                            self._segment_path = lambda: "registered"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/map-resolver/map-request/validate/source/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "registered"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/map-resolver/map-request/validate/source/registered/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                    class MapServer(Entity):
                        """
                        Configures a LISP Map Server (MS)
                        
                        .. attribute:: map_register
                        
                        	Map\-Register processing options
                        	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_register = Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister()
                            self.map_register.parent = self
                            self._children_name_map["map_register"] = "map-register"
                            self._segment_path = lambda: "map-server"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapServer, [], name, value)


                        class MapRegister(Entity):
                            """
                            Map\-Register processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister, self).__init__()

                                self.yang_name = "map-register"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-register"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/map-server/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	RLOC Source IP address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-register"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/map-server/map-register/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    RLOC Source IP address
                                    
                                    .. attribute:: allowed_locator
                                    
                                    	Against sites' allowed\-locators policy
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                        ])
                                        self.allowed_locator = None
                                        self._segment_path = lambda: "source"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/map-server/map-register/validate/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.Service.Ethernet.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                    class SiteRegistration(Entity):
                        """
                        Site registrations configuration for a given instance\-id
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class SolicitMapRequest(Entity):
                        """
                        Configure Solicit\-Map\-Request handling
                        
                        .. attribute:: ignore
                        
                        	Ignore SMR bit in incoming Map\-Requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_per_entry
                        
                        	Maximum number of SMRs for addresses under a map\-cache entry
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: suppression_time
                        
                        	How long to suppress repeated SMRs for the same address
                        	**type**\: int
                        
                        	**range:** 1..600
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Service.Ethernet.SolicitMapRequest, self).__init__()

                            self.yang_name = "solicit-map-request"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                            ])
                            self.ignore = None
                            self.max_per_entry = None
                            self.suppression_time = None
                            self._segment_path = lambda: "solicit-map-request"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/service/ethernet/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


            class Encapsulation(Entity):
                """
                Select encapsulation type for data packets
                
                .. attribute:: vxlan
                
                	Use VXLAN encapsulation for data packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                    ])
                    self.vxlan = None
                    self._segment_path = lambda: "encapsulation"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Encapsulation, ['vxlan'], name, value)


            class LocatorSet(Entity):
                """
                Configure a named locator set
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: auto_discover_rlocs
                
                	Auto discover locators registered by other xTRs
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ipv4_interface
                
                	Use IPv4 address of interface as locator
                	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.LocatorSet.IPv4Interface>`
                
                .. attribute:: ipv6_interface
                
                	Use IPv6 address of interface as locator
                	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.LocatorSet.IPv6Interface>`
                
                .. attribute:: ip_address
                
                	Use IPv6 address of interface as locator
                	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.LocatorSet.IpAddress>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.LocatorSet, self).__init__()

                    self.yang_name = "locator-set"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.LocatorSet.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.LocatorSet.IPv6Interface)), ("ip-address", ("ip_address", Native.Router.Lisp.LocatorSet.IpAddress))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                    ])
                    self.name = None
                    self.auto_discover_rlocs = None

                    self.ipv4_interface = YList(self)
                    self.ipv6_interface = YList(self)
                    self.ip_address = YList(self)
                    self._segment_path = lambda: "locator-set" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.LocatorSet, ['name', 'auto_discover_rlocs'], name, value)


                class IPv4Interface(Entity):
                    """
                    Use IPv4 address of interface as locator
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: priority
                    
                    	Configures which Locators from a set are preferred
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: weight
                    
                    	Traffic load\-spreading among Locators
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.LocatorSet.IPv4Interface, self).__init__()

                        self.yang_name = "IPv4-interface"
                        self.yang_parent_name = "locator-set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                        ])
                        self.name = None
                        self.priority = None
                        self.weight = None
                        self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.LocatorSet.IPv4Interface, ['name', 'priority', 'weight'], name, value)


                class IPv6Interface(Entity):
                    """
                    Use IPv6 address of interface as locator
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: priority
                    
                    	Configures which Locators from a set are preferred
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: weight
                    
                    	Traffic load\-spreading among Locators
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.LocatorSet.IPv6Interface, self).__init__()

                        self.yang_name = "IPv6-interface"
                        self.yang_parent_name = "locator-set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                        ])
                        self.name = None
                        self.priority = None
                        self.weight = None
                        self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.LocatorSet.IPv6Interface, ['name', 'priority', 'weight'], name, value)


                class IpAddress(Entity):
                    """
                    Use IPv6 address of interface as locator
                    
                    .. attribute:: ip  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: priority
                    
                    	Configures which Locators from a set are preferred
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: weight
                    
                    	Traffic load\-spreading among Locators
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.LocatorSet.IpAddress, self).__init__()

                        self.yang_name = "ip-address"
                        self.yang_parent_name = "locator-set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['ip']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                        ])
                        self.ip = None
                        self.priority = None
                        self.weight = None
                        self._segment_path = lambda: "ip-address" + "[ip='" + str(self.ip) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.LocatorSet.IpAddress, ['ip', 'priority', 'weight'], name, value)


            class Locator(Entity):
                """
                Locator configuration
                
                .. attribute:: default_set
                
                	Specify a default locator\-set
                	**type**\: str
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Locator, self).__init__()

                    self.yang_name = "locator"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default_set', (YLeaf(YType.str, 'default-set'), ['str'])),
                    ])
                    self.default_set = None
                    self._segment_path = lambda: "locator"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Locator, ['default_set'], name, value)


            class LocatorScope(Entity):
                """
                Configure a locator scope
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: rloc_prefix
                
                	RLOC prefix to check against ITR RLOC and ETR RLOC
                	**type**\: union of the below types:
                
                		**type**\: list of str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                
                		**type**\: list of str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                
                .. attribute:: rtr_locator_set
                
                	Locator\-set of RTR to use in proxy reply for disjoint/cross AF RLOC
                	**type**\: list of str
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.LocatorScope, self).__init__()

                    self.yang_name = "locator-scope"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('rloc_prefix', (YLeafList(YType.str, 'rloc-prefix'), ['str','str'])),
                        ('rtr_locator_set', (YLeafList(YType.str, 'rtr-locator-set'), ['str'])),
                    ])
                    self.name = None
                    self.rloc_prefix = []
                    self.rtr_locator_set = []
                    self._segment_path = lambda: "locator-scope" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.LocatorScope, ['name', 'rloc_prefix', 'rtr_locator_set'], name, value)


            class PrefixList(Entity):
                """
                Configure a named prefix list
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: ipv4_prefix
                
                	IPv4 EID\-prefix
                	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.PrefixList.Ipv4Prefix>`
                
                .. attribute:: ipv6_prefix
                
                	IPv6 EID\-prefix
                	**type**\: list of  		 :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.PrefixList.Ipv6Prefix>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.PrefixList, self).__init__()

                    self.yang_name = "prefix-list"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.Lisp.PrefixList.Ipv4Prefix)), ("ipv6-prefix", ("ipv6_prefix", Native.Router.Lisp.PrefixList.Ipv6Prefix))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.ipv4_prefix = YList(self)
                    self.ipv6_prefix = YList(self)
                    self._segment_path = lambda: "prefix-list" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.PrefixList, ['name'], name, value)


                class Ipv4Prefix(Entity):
                    """
                    IPv4 EID\-prefix
                    
                    .. attribute:: prefix  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.PrefixList.Ipv4Prefix, self).__init__()

                        self.yang_name = "ipv4-prefix"
                        self.yang_parent_name = "prefix-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['prefix']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "ipv4-prefix" + "[prefix='" + str(self.prefix) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.PrefixList.Ipv4Prefix, ['prefix'], name, value)


                class Ipv6Prefix(Entity):
                    """
                    IPv6 EID\-prefix
                    
                    .. attribute:: prefix  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.PrefixList.Ipv6Prefix, self).__init__()

                        self.yang_name = "ipv6-prefix"
                        self.yang_parent_name = "prefix-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['prefix']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + str(self.prefix) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.PrefixList.Ipv6Prefix, ['prefix'], name, value)


            class InstanceContainer(Entity):
                """
                EID instance\-ID
                
                .. attribute:: instance_list
                
                	
                	**type**\: list of  		 :py:class:`InstanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.InstanceContainer, self).__init__()

                    self.yang_name = "instance-container"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance-list", ("instance_list", Native.Router.Lisp.InstanceContainer.InstanceList))])
                    self._leafs = OrderedDict()

                    self.instance_list = YList(self)
                    self._segment_path = lambda: "instance-container"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.InstanceContainer, [], name, value)


                class InstanceList(Entity):
                    """
                    
                    
                    .. attribute:: instance_id  (key)
                    
                    	EID instance\-ID
                    	**type**\: int
                    
                    	**range:** 0..16777214
                    
                    .. attribute:: default
                    
                    	
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default>`
                    
                    .. attribute:: decapsulation
                    
                    	Decapsulation behavior (e.g. filters)
                    	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation>`
                    
                    .. attribute:: disable_ttl_propagate
                    
                    	Disable ttl propagation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dynamic_eid
                    
                    	Configure a dynamic EID
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid>`
                    
                    .. attribute:: loc_reach_algorithm
                    
                    	Configure locator reachability algorithm
                    	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.LocReachAlgorithm>`
                    
                    .. attribute:: map_server
                    
                    	Map\-Server commands
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.MapServer>`
                    
                    .. attribute:: other_xtr_probe
                    
                    	Configure parameters for probing of other xTRs in our site
                    	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.OtherXtrProbe>`
                    
                    .. attribute:: remote_rloc_probe
                    
                    	Configure parameters for probing of remote RLOCs
                    	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.RemoteRlocProbe>`
                    
                    .. attribute:: service
                    
                    	Configure lisp service type
                    	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.InstanceContainer.InstanceList, self).__init__()

                        self.yang_name = "instance-list"
                        self.yang_parent_name = "instance-container"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['instance_id']
                        self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.InstanceContainer.InstanceList.Default)), ("decapsulation", ("decapsulation", Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation)), ("dynamic-eid", ("dynamic_eid", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.Lisp.InstanceContainer.InstanceList.LocReachAlgorithm)), ("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.Lisp.InstanceContainer.InstanceList.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.Lisp.InstanceContainer.InstanceList.RemoteRlocProbe)), ("service", ("service", Native.Router.Lisp.InstanceContainer.InstanceList.Service))])
                        self._leafs = OrderedDict([
                            ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                            ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                        ])
                        self.instance_id = None
                        self.disable_ttl_propagate = None

                        self.default = Native.Router.Lisp.InstanceContainer.InstanceList.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.decapsulation = Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation()
                        self.decapsulation.parent = self
                        self._children_name_map["decapsulation"] = "decapsulation"

                        self.loc_reach_algorithm = Native.Router.Lisp.InstanceContainer.InstanceList.LocReachAlgorithm()
                        self.loc_reach_algorithm.parent = self
                        self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                        self.map_server = Native.Router.Lisp.InstanceContainer.InstanceList.MapServer()
                        self.map_server.parent = self
                        self._children_name_map["map_server"] = "map-server"

                        self.other_xtr_probe = Native.Router.Lisp.InstanceContainer.InstanceList.OtherXtrProbe()
                        self.other_xtr_probe.parent = self
                        self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                        self.remote_rloc_probe = Native.Router.Lisp.InstanceContainer.InstanceList.RemoteRlocProbe()
                        self.remote_rloc_probe.parent = self
                        self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                        self.service = None
                        self._children_name_map["service"] = "service"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "instance-list" + "[instance-id='" + str(self.instance_id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/instance-container/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList, ['instance_id', 'disable_ttl_propagate'], name, value)


                    class Default(Entity):
                        """
                        
                        
                        .. attribute:: decapsulation
                        
                        	Decapsulation behavior (e.g. filters)
                        	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation>`
                        
                        .. attribute:: disable_ttl_propagate
                        
                        	Disable ttl propagation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dynamic_eid
                        
                        	Configure a dynamic EID
                        	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid>`
                        
                        .. attribute:: loc_reach_algorithm
                        
                        	Configure locator reachability algorithm
                        	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.LocReachAlgorithm>`
                        
                        .. attribute:: map_server
                        
                        	Map\-Server commands
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer>`
                        
                        .. attribute:: other_xtr_probe
                        
                        	Configure parameters for probing of other xTRs in our site
                        	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.OtherXtrProbe>`
                        
                        .. attribute:: remote_rloc_probe
                        
                        	Configure parameters for probing of remote RLOCs
                        	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.RemoteRlocProbe>`
                        
                        .. attribute:: service
                        
                        	Configure lisp service type
                        	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("decapsulation", ("decapsulation", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation)), ("dynamic-eid", ("dynamic_eid", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.Lisp.InstanceContainer.InstanceList.Default.LocReachAlgorithm)), ("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.Lisp.InstanceContainer.InstanceList.Default.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.Lisp.InstanceContainer.InstanceList.Default.RemoteRlocProbe)), ("service", ("service", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service))])
                            self._leafs = OrderedDict([
                                ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                            ])
                            self.disable_ttl_propagate = None

                            self.decapsulation = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation()
                            self.decapsulation.parent = self
                            self._children_name_map["decapsulation"] = "decapsulation"

                            self.loc_reach_algorithm = Native.Router.Lisp.InstanceContainer.InstanceList.Default.LocReachAlgorithm()
                            self.loc_reach_algorithm.parent = self
                            self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                            self.map_server = Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer()
                            self.map_server.parent = self
                            self._children_name_map["map_server"] = "map-server"

                            self.other_xtr_probe = Native.Router.Lisp.InstanceContainer.InstanceList.Default.OtherXtrProbe()
                            self.other_xtr_probe.parent = self
                            self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                            self.remote_rloc_probe = Native.Router.Lisp.InstanceContainer.InstanceList.Default.RemoteRlocProbe()
                            self.remote_rloc_probe.parent = self
                            self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                            self.service = None
                            self._children_name_map["service"] = "service"

                            self.dynamic_eid = YList(self)
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default, ['disable_ttl_propagate'], name, value)


                        class Decapsulation(Entity):
                            """
                            Decapsulation behavior (e.g. filters)
                            
                            .. attribute:: filter
                            
                            	Filters traffic
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation, self).__init__()

                                self.yang_name = "decapsulation"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("filter", ("filter", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter))])
                                self._leafs = OrderedDict()

                                self.filter = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"
                                self._segment_path = lambda: "decapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation, [], name, value)


                            class Filter(Entity):
                                """
                                Filters traffic
                                
                                .. attribute:: rloc
                                
                                	Filter based on Routing Locator (RLOC) in packet header
                                	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "decapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc))])
                                    self._leafs = OrderedDict()

                                    self.rloc = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc()
                                    self.rloc.parent = self
                                    self._children_name_map["rloc"] = "rloc"
                                    self._segment_path = lambda: "filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter, [], name, value)


                                class Rloc(Entity):
                                    """
                                    Filter based on Routing Locator (RLOC) in packet header
                                    
                                    .. attribute:: source
                                    
                                    	Filters traffic based on RLOC source address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc, self).__init__()

                                        self.yang_name = "rloc"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "rloc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc, [], name, value)


                                    class Source(Entity):
                                        """
                                        Filters traffic based on RLOC source address
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator\-set Name
                                        	**type**\: str
                                        
                                        .. attribute:: member
                                        
                                        	Members learned from map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "rloc"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.member = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                        class DynamicEid(Entity):
                            """
                            Configure a dynamic EID
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: database_mapping
                            
                            	Configures EID\-prefix and locator\-set for dynamic\-EID
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping>`
                            
                            .. attribute:: eid_notify
                            
                            	Configure options for sending/receiving EID\-notify
                            	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify>`
                            
                            .. attribute:: map_notify_group
                            
                            	Multicast group which to send map\-notifies to
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid, self).__init__()

                                self.yang_name = "dynamic-eid"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                                ])
                                self.name = None
                                self.map_notify_group = None

                                self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.eid_notify = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify()
                                self.eid_notify.parent = self
                                self._children_name_map["eid_notify"] = "eid-notify"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid, ['name', 'map_notify_group'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures EID\-prefix and locator\-set for dynamic\-EID
                                
                                .. attribute:: ipv4_prefix
                                
                                	IPv4 EID\-prefix for dynamic\-EID
                                	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping.Ipv4Prefix>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping.Ipv4Prefix))])
                                    self._leafs = OrderedDict()

                                    self.ipv4_prefix = YList(self)
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping, [], name, value)


                                class Ipv4Prefix(Entity):
                                    """
                                    IPv4 EID\-prefix for dynamic\-EID
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    .. attribute:: locator_set
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping.Ipv4Prefix, self).__init__()

                                        self.yang_name = "ipv4-prefix"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.eid_prefix = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "ipv4-prefix" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping.Ipv4Prefix, ['eid_prefix', 'locator_set'], name, value)


                            class EidNotify(Entity):
                                """
                                Configure options for sending/receiving EID\-notify
                                
                                .. attribute:: authentication_key
                                
                                	Authentication key used for validating received EID\-notify
                                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.AuthenticationKey>`
                                
                                .. attribute:: gateway_key
                                
                                	
                                	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify, self).__init__()

                                    self.yang_name = "eid-notify"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey))])
                                    self._leafs = OrderedDict()

                                    self.authentication_key = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.AuthenticationKey()
                                    self.authentication_key.parent = self
                                    self._children_name_map["authentication_key"] = "authentication-key"

                                    self.gateway_key = YList(self)
                                    self._segment_path = lambda: "eid-notify"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify, [], name, value)


                                class AuthenticationKey(Entity):
                                    """
                                    Authentication key used for validating received EID\-notify
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: key_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                        self.yang_name = "authentication-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.key_0 = None
                                        self.key_6 = None
                                        self.key_7 = None
                                        self._segment_path = lambda: "authentication-key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                                class GatewayKey(Entity):
                                    """
                                    
                                    
                                    .. attribute:: gateway_ip  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                        self.yang_name = "gateway-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['gateway_ip']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key))])
                                        self._leafs = OrderedDict([
                                            ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                        ])
                                        self.gateway_ip = None

                                        self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey, ['gateway_ip'], name, value)


                                    class Key(Entity):
                                        """
                                        
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "gateway-key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction')])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, ['unc_pwd', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction')])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0, ['ak_0', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction')])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6, ['ak_6', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                        class LocReachAlgorithm(Entity):
                            """
                            Configure locator reachability algorithm
                            
                            .. attribute:: lsb_reports
                            
                            	Configure data packet LSB report handling
                            	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.LocReachAlgorithm.LsbReports>`
                            
                            .. attribute:: rloc_probing
                            
                            	Probe high priority RLOCs with Map\-Requests as last resort
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.LocReachAlgorithm, self).__init__()

                                self.yang_name = "loc-reach-algorithm"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.Lisp.InstanceContainer.InstanceList.Default.LocReachAlgorithm.LsbReports))])
                                self._leafs = OrderedDict([
                                    ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                                ])
                                self.rloc_probing = None

                                self.lsb_reports = Native.Router.Lisp.InstanceContainer.InstanceList.Default.LocReachAlgorithm.LsbReports()
                                self.lsb_reports.parent = self
                                self._children_name_map["lsb_reports"] = "lsb-reports"
                                self._segment_path = lambda: "loc-reach-algorithm"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.LocReachAlgorithm, ['rloc_probing'], name, value)


                            class LsbReports(Entity):
                                """
                                Configure data packet LSB report handling
                                
                                .. attribute:: do_not_transmit
                                
                                	Force the setting of the encapsulation header L bit to zero
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ignore
                                
                                	Ignore data packet LSB reports
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.LocReachAlgorithm.LsbReports, self).__init__()

                                    self.yang_name = "lsb-reports"
                                    self.yang_parent_name = "loc-reach-algorithm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ])
                                    self.do_not_transmit = None
                                    self.ignore = None
                                    self._segment_path = lambda: "lsb-reports"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                        class MapServer(Entity):
                            """
                            Map\-Server commands
                            
                            .. attribute:: rloc
                            
                            	EID instance RLOC membership
                            	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc>`
                            
                            .. attribute:: site_registration
                            
                            	Map\-server site registration options
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.SiteRegistration>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.SiteRegistration))])
                                self._leafs = OrderedDict()

                                self.rloc = Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc()
                                self.rloc.parent = self
                                self._children_name_map["rloc"] = "rloc"

                                self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer, [], name, value)


                            class Rloc(Entity):
                                """
                                EID instance RLOC membership
                                
                                .. attribute:: members
                                
                                	EID instance RLOC membership
                                	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc, self).__init__()

                                    self.yang_name = "rloc"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("members", ("members", Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members))])
                                    self._leafs = OrderedDict()

                                    self.members = Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members()
                                    self.members.parent = self
                                    self._children_name_map["members"] = "members"
                                    self._segment_path = lambda: "rloc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc, [], name, value)


                                class Members(Entity):
                                    """
                                    EID instance RLOC membership
                                    
                                    .. attribute:: distribute
                                    
                                    	EID instance RLOC membership distribution
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: modify_discovered
                                    
                                    	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                    	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members, self).__init__()

                                        self.yang_name = "members"
                                        self.yang_parent_name = "rloc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered))])
                                        self._leafs = OrderedDict([
                                            ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                        ])
                                        self.distribute = None

                                        self.modify_discovered = Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered()
                                        self.modify_discovered.parent = self
                                        self._children_name_map["modify_discovered"] = "modify-discovered"
                                        self._segment_path = lambda: "members"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members, ['distribute'], name, value)


                                    class ModifyDiscovered(Entity):
                                        """
                                        Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                        
                                        .. attribute:: operator
                                        
                                        	
                                        	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set from which to get member RLOC addresses
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                            self.yang_name = "modify-discovered"
                                            self.yang_parent_name = "members"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.operator = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "modify-discovered"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                        class Operator(Enum):
                                            """
                                            Operator (Enum Class)

                                            .. data:: add = 0

                                            .. data:: override = 1

                                            """

                                            add = Enum.YLeaf(0, "add")

                                            override = Enum.YLeaf(1, "override")



                            class SiteRegistration(Entity):
                                """
                                Map\-server site registration options
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations as a result of accept\-more\-specifics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class OtherXtrProbe(Entity):
                            """
                            Configure parameters for probing of other xTRs in our site
                            
                            .. attribute:: period
                            
                            	Period between probes in seconds
                            	**type**\: int
                            
                            	**range:** 5..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.OtherXtrProbe, self).__init__()

                                self.yang_name = "other-xtr-probe"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                ])
                                self.period = None
                                self._segment_path = lambda: "other-xtr-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.OtherXtrProbe, ['period'], name, value)


                        class RemoteRlocProbe(Entity):
                            """
                            Configure parameters for probing of remote RLOCs
                            
                            .. attribute:: on_membership_change
                            
                            	Trigger probing upon membership changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: on_route_change
                            
                            	Trigger probing upon routing changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.RemoteRlocProbe, self).__init__()

                                self.yang_name = "remote-rloc-probe"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                    ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                                ])
                                self.on_membership_change = None
                                self.on_route_change = None
                                self._segment_path = lambda: "remote-rloc-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                        class Service(Entity):
                            """
                            Configure lisp service type
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ipv6
                            
                            	
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ethernet
                            
                            	
                            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service, self).__init__()

                                self.yang_name = "service"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.ipv4 = None
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = None
                                self._children_name_map["ipv6"] = "ipv6"

                                self.ethernet = None
                                self._children_name_map["ethernet"] = "ethernet"
                                self._segment_path = lambda: "service"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service, [], name, value)


                            class Ipv4(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_)), ("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.EidTable)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt)), ("distance", ("distance", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import)), ("route-import", ("route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.default = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EidTable)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt)), ("distance", ("distance", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr)), ("import", ("import_", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import)), ("route-import", ("route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping))])
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Ipv6(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_)), ("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.EidTable)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt)), ("distance", ("distance", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import)), ("route-import", ("route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.default = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EidTable)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt)), ("distance", ("distance", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr)), ("import", ("import_", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import)), ("route-import", ("route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping))])
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Ethernet(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.EidTable>`
                                
                                .. attribute:: broadcast_underlay
                                
                                	Multicast group to use for underlay
                                	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.BroadcastUnderlay>`
                                
                                .. attribute:: flood
                                
                                	Control flooding or local intercept of broadcast frames
                                	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Flood>`
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.SolicitMapRequest>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_)), ("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.BroadcastUnderlay)), ("flood", ("flood", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Flood)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                    ])
                                    self.map_request_source = None

                                    self.default = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.broadcast_underlay = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.BroadcastUnderlay()
                                    self.broadcast_underlay.parent = self
                                    self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                    self.flood = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Flood()
                                    self.flood.parent = self
                                    self._children_name_map["flood"] = "flood"

                                    self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"
                                    self._segment_path = lambda: "ethernet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet, ['map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EidTable>`
                                    
                                    .. attribute:: broadcast_underlay
                                    
                                    	Multicast group to use for underlay
                                    	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.BroadcastUnderlay>`
                                    
                                    .. attribute:: flood
                                    
                                    	Control flooding or local intercept of broadcast frames
                                    	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Flood>`
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.BroadcastUnderlay)), ("flood", ("flood", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Flood)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache))])
                                        self._leafs = OrderedDict([
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                        ])
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.broadcast_underlay = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.BroadcastUnderlay()
                                        self.broadcast_underlay.parent = self
                                        self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                        self.flood = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Flood()
                                        self.flood.parent = self
                                        self._children_name_map["flood"] = "flood"

                                        self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_, ['map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN configuration
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ])
                                            self.vlan = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EidTable, ['vlan'], name, value)


                                    class BroadcastUnderlay(Entity):
                                        """
                                        Multicast group to use for underlay
                                        
                                        .. attribute:: ipv4_multicast
                                        
                                        	IPv4 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_multicast
                                        
                                        	IPv6 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.BroadcastUnderlay, self).__init__()

                                            self.yang_name = "broadcast-underlay"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                                ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                            ])
                                            self.ipv4_multicast = None
                                            self.ipv6_multicast = None
                                            self._segment_path = lambda: "broadcast-underlay"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                    class Flood(Entity):
                                        """
                                        Control flooding or local intercept of broadcast frames
                                        
                                        .. attribute:: arp_nd
                                        
                                        	IPv4 ARP / IPv6 ND
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Frames with unknown destination MAC
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Flood, self).__init__()

                                            self.yang_name = "flood"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                                ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                            ])
                                            self.arp_nd = None
                                            self.unknown_unicast = None
                                            self._segment_path = lambda: "flood"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: mac
                                        
                                        	L2 EID records
                                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Mac>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.mac = None
                                            self._children_name_map["mac"] = "mac"

                                            self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Mac(Entity):
                                            """
                                            L2 EID records
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Mac, self).__init__()

                                                self.yang_name = "mac"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.locator_set = None
                                                self._segment_path = lambda: "mac"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Mac, ['locator_set'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont))])
                                            self._leafs = OrderedDict()

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont, ['eid_prefix'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN configuration
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.EidTable, ['vlan'], name, value)


                                class BroadcastUnderlay(Entity):
                                    """
                                    Multicast group to use for underlay
                                    
                                    .. attribute:: ipv4_multicast
                                    
                                    	IPv4 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_multicast
                                    
                                    	IPv6 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.BroadcastUnderlay, self).__init__()

                                        self.yang_name = "broadcast-underlay"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                            ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                        ])
                                        self.ipv4_multicast = None
                                        self.ipv6_multicast = None
                                        self._segment_path = lambda: "broadcast-underlay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                class Flood(Entity):
                                    """
                                    Control flooding or local intercept of broadcast frames
                                    
                                    .. attribute:: arp_nd
                                    
                                    	IPv4 ARP / IPv6 ND
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Frames with unknown destination MAC
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Flood, self).__init__()

                                        self.yang_name = "flood"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                            ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                        ])
                                        self.arp_nd = None
                                        self.unknown_unicast = None
                                        self._segment_path = lambda: "flood"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: mac
                                    
                                    	L2 EID records
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Mac>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.mac = None
                                        self._children_name_map["mac"] = "mac"

                                        self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Mac(Entity):
                                        """
                                        L2 EID records
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.locator_set = None
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Mac, ['locator_set'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont))])
                                        self._leafs = OrderedDict()

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont, ['eid_prefix'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                    class Decapsulation(Entity):
                        """
                        Decapsulation behavior (e.g. filters)
                        
                        .. attribute:: filter
                        
                        	Filters traffic
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation, self).__init__()

                            self.yang_name = "decapsulation"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "decapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation, [], name, value)


                        class Filter(Entity):
                            """
                            Filters traffic
                            
                            .. attribute:: rloc
                            
                            	Filter based on Routing Locator (RLOC) in packet header
                            	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "decapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc))])
                                self._leafs = OrderedDict()

                                self.rloc = Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc()
                                self.rloc.parent = self
                                self._children_name_map["rloc"] = "rloc"
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter, [], name, value)


                            class Rloc(Entity):
                                """
                                Filter based on Routing Locator (RLOC) in packet header
                                
                                .. attribute:: source
                                
                                	Filters traffic based on RLOC source address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc, self).__init__()

                                    self.yang_name = "rloc"
                                    self.yang_parent_name = "filter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "rloc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc, [], name, value)


                                class Source(Entity):
                                    """
                                    Filters traffic based on RLOC source address
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator\-set Name
                                    	**type**\: str
                                    
                                    .. attribute:: member
                                    
                                    	Members learned from map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "rloc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                        ])
                                        self.locator_set = None
                                        self.member = None
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                    class DynamicEid(Entity):
                        """
                        Configure a dynamic EID
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: database_mapping
                        
                        	Configures EID\-prefix and locator\-set for dynamic\-EID
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping>`
                        
                        .. attribute:: eid_notify
                        
                        	Configure options for sending/receiving EID\-notify
                        	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify>`
                        
                        .. attribute:: map_notify_group
                        
                        	Multicast group which to send map\-notifies to
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                            ])
                            self.name = None
                            self.map_notify_group = None

                            self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.eid_notify = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify()
                            self.eid_notify.parent = self
                            self._children_name_map["eid_notify"] = "eid-notify"

                            self.map_server = YList(self)
                            self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid, ['name', 'map_notify_group'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Configures EID\-prefix and locator\-set for dynamic\-EID
                            
                            .. attribute:: ipv4_prefix
                            
                            	IPv4 EID\-prefix for dynamic\-EID
                            	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix))])
                                self._leafs = OrderedDict()

                                self.ipv4_prefix = YList(self)
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping, [], name, value)


                            class Ipv4Prefix(Entity):
                                """
                                IPv4 EID\-prefix for dynamic\-EID
                                
                                .. attribute:: eid_prefix  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                .. attribute:: locator_set
                                
                                	Use locators defined by locator\-set
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix, self).__init__()

                                    self.yang_name = "ipv4-prefix"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['eid_prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.eid_prefix = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "ipv4-prefix" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix, ['eid_prefix', 'locator_set'], name, value)


                        class EidNotify(Entity):
                            """
                            Configure options for sending/receiving EID\-notify
                            
                            .. attribute:: authentication_key
                            
                            	Authentication key used for validating received EID\-notify
                            	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey>`
                            
                            .. attribute:: gateway_key
                            
                            	
                            	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify, self).__init__()

                                self.yang_name = "eid-notify"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey))])
                                self._leafs = OrderedDict()

                                self.authentication_key = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey()
                                self.authentication_key.parent = self
                                self._children_name_map["authentication_key"] = "authentication-key"

                                self.gateway_key = YList(self)
                                self._segment_path = lambda: "eid-notify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify, [], name, value)


                            class AuthenticationKey(Entity):
                                """
                                Authentication key used for validating received EID\-notify
                                
                                .. attribute:: unc_pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: key_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: key_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: key_7
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                    self.yang_name = "authentication-key"
                                    self.yang_parent_name = "eid-notify"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                        ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                        ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                        ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                    ])
                                    self.unc_pwd = None
                                    self.key_0 = None
                                    self.key_6 = None
                                    self.key_7 = None
                                    self._segment_path = lambda: "authentication-key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                            class GatewayKey(Entity):
                                """
                                
                                
                                .. attribute:: gateway_ip  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                    self.yang_name = "gateway-key"
                                    self.yang_parent_name = "eid-notify"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['gateway_ip']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key))])
                                    self._leafs = OrderedDict([
                                        ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                    ])
                                    self.gateway_ip = None

                                    self.key = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey, ['gateway_ip'], name, value)


                                class Key(Entity):
                                    """
                                    
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "gateway-key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction')])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, ['unc_pwd', 'hash_function'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction')])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0, ['ak_0', 'hash_function'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction')])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6, ['ak_6', 'hash_function'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_pwd
                                
                                	
                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd>`
                                
                                .. attribute:: key_0
                                
                                	
                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0>`
                                
                                .. attribute:: key_6
                                
                                	
                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6>`
                                
                                .. attribute:: key_7
                                
                                	
                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7))])
                                    self._leafs = OrderedDict()

                                    self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd()
                                    self.key_pwd.parent = self
                                    self._children_name_map["key_pwd"] = "key-pwd"

                                    self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0()
                                    self.key_0.parent = self
                                    self._children_name_map["key_0"] = "key-0"

                                    self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6()
                                    self.key_6.parent = self
                                    self._children_name_map["key_6"] = "key-6"

                                    self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7()
                                    self.key_7.parent = self
                                    self._children_name_map["key_7"] = "key-7"
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key, [], name, value)


                                class KeyPwd(Entity):
                                    """
                                    
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd, self).__init__()

                                        self.yang_name = "key-pwd"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-pwd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key0(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0, self).__init__()

                                        self.yang_name = "key-0"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_0 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-0"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6, self).__init__()

                                        self.yang_name = "key-6"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_6 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key7(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7, self).__init__()

                                        self.yang_name = "key-7"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_7 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-7"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                    class LocReachAlgorithm(Entity):
                        """
                        Configure locator reachability algorithm
                        
                        .. attribute:: lsb_reports
                        
                        	Configure data packet LSB report handling
                        	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports>`
                        
                        .. attribute:: rloc_probing
                        
                        	Probe high priority RLOCs with Map\-Requests as last resort
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.InstanceContainer.InstanceList.LocReachAlgorithm, self).__init__()

                            self.yang_name = "loc-reach-algorithm"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.Lisp.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports))])
                            self._leafs = OrderedDict([
                                ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                            ])
                            self.rloc_probing = None

                            self.lsb_reports = Native.Router.Lisp.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports()
                            self.lsb_reports.parent = self
                            self._children_name_map["lsb_reports"] = "lsb-reports"
                            self._segment_path = lambda: "loc-reach-algorithm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.LocReachAlgorithm, ['rloc_probing'], name, value)


                        class LsbReports(Entity):
                            """
                            Configure data packet LSB report handling
                            
                            .. attribute:: do_not_transmit
                            
                            	Force the setting of the encapsulation header L bit to zero
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore data packet LSB reports
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports, self).__init__()

                                self.yang_name = "lsb-reports"
                                self.yang_parent_name = "loc-reach-algorithm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.do_not_transmit = None
                                self.ignore = None
                                self._segment_path = lambda: "lsb-reports"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                    class MapServer(Entity):
                        """
                        Map\-Server commands
                        
                        .. attribute:: rloc
                        
                        	EID instance RLOC membership
                        	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc>`
                        
                        .. attribute:: site_registration
                        
                        	Map\-server site registration options
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.SiteRegistration>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.InstanceContainer.InstanceList.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.SiteRegistration))])
                            self._leafs = OrderedDict()

                            self.rloc = Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc()
                            self.rloc.parent = self
                            self._children_name_map["rloc"] = "rloc"

                            self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"
                            self._segment_path = lambda: "map-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.MapServer, [], name, value)


                        class Rloc(Entity):
                            """
                            EID instance RLOC membership
                            
                            .. attribute:: members
                            
                            	EID instance RLOC membership
                            	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc, self).__init__()

                                self.yang_name = "rloc"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("members", ("members", Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members))])
                                self._leafs = OrderedDict()

                                self.members = Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members()
                                self.members.parent = self
                                self._children_name_map["members"] = "members"
                                self._segment_path = lambda: "rloc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc, [], name, value)


                            class Members(Entity):
                                """
                                EID instance RLOC membership
                                
                                .. attribute:: distribute
                                
                                	EID instance RLOC membership distribution
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: modify_discovered
                                
                                	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members, self).__init__()

                                    self.yang_name = "members"
                                    self.yang_parent_name = "rloc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered))])
                                    self._leafs = OrderedDict([
                                        ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                    ])
                                    self.distribute = None

                                    self.modify_discovered = Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered()
                                    self.modify_discovered.parent = self
                                    self._children_name_map["modify_discovered"] = "modify-discovered"
                                    self._segment_path = lambda: "members"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members, ['distribute'], name, value)


                                class ModifyDiscovered(Entity):
                                    """
                                    Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                    
                                    .. attribute:: operator
                                    
                                    	
                                    	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set from which to get member RLOC addresses
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                        self.yang_name = "modify-discovered"
                                        self.yang_parent_name = "members"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.operator = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "modify-discovered"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                    class Operator(Enum):
                                        """
                                        Operator (Enum Class)

                                        .. data:: add = 0

                                        .. data:: override = 1

                                        """

                                        add = Enum.YLeaf(0, "add")

                                        override = Enum.YLeaf(1, "override")



                        class SiteRegistration(Entity):
                            """
                            Map\-server site registration options
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations as a result of accept\-more\-specifics
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class OtherXtrProbe(Entity):
                        """
                        Configure parameters for probing of other xTRs in our site
                        
                        .. attribute:: period
                        
                        	Period between probes in seconds
                        	**type**\: int
                        
                        	**range:** 5..900
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.InstanceContainer.InstanceList.OtherXtrProbe, self).__init__()

                            self.yang_name = "other-xtr-probe"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ])
                            self.period = None
                            self._segment_path = lambda: "other-xtr-probe"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.OtherXtrProbe, ['period'], name, value)


                    class RemoteRlocProbe(Entity):
                        """
                        Configure parameters for probing of remote RLOCs
                        
                        .. attribute:: on_membership_change
                        
                        	Trigger probing upon membership changes for remote RLOC
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: on_route_change
                        
                        	Trigger probing upon routing changes for remote RLOC
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.InstanceContainer.InstanceList.RemoteRlocProbe, self).__init__()

                            self.yang_name = "remote-rloc-probe"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                            ])
                            self.on_membership_change = None
                            self.on_route_change = None
                            self._segment_path = lambda: "remote-rloc-probe"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                    class Service(Entity):
                        """
                        Configure lisp service type
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ethernet
                        
                        	
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service, self).__init__()

                            self.yang_name = "service"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = None
                            self._children_name_map["ipv6"] = "ipv6"

                            self.ethernet = None
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "service"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service, [], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: default
                            
                            	
                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default>`
                            
                            .. attribute:: eid_table
                            
                            	Bind an eid\-table
                            	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.EidTable>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit>`
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest>`
                            
                            .. attribute:: alt
                            
                            	LISP Alternative Topology, LISP\-ALT
                            	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Alt>`
                            
                            .. attribute:: alt_vrf
                            
                            	Activate LISP\-ALT functionality in VRF
                            	**type**\: str
                            
                            	**status**\: deprecated
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Distance>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent>`
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr>`
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteExport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.UsePetr>`
                            
                            .. attribute:: import_
                            
                            	Redistribute LISP states internally
                            	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import>`
                            
                            .. attribute:: route_import
                            
                            	Import RIB routes by a routing protocol into LISP
                            	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: database_mapping
                            
                            	Configures Locator addresses for an ETR
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "service"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default)), ("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.EidTable)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Alt)), ("distance", ("distance", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import)), ("route-import", ("route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ])
                                self.alt_vrf = None
                                self.proxy_etr = None
                                self.sgt = None
                                self.map_request_source = None

                                self.default = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default()
                                self.default.parent = self
                                self._children_name_map["default"] = "default"

                                self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.EidTable()
                                self.eid_table.parent = self
                                self._children_name_map["eid_table"] = "eid-table"

                                self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.alt = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Alt()
                                self.alt.parent = self
                                self._children_name_map["alt"] = "alt"

                                self.distance = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_persistent = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.proxy_itr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr()
                                self.proxy_itr.parent = self
                                self._children_name_map["proxy_itr"] = "proxy-itr"

                                self.route_export = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.import_ = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import()
                                self.import_.parent = self
                                self._children_name_map["import_"] = "import"

                                self.route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport()
                                self.route_import.parent = self
                                self._children_name_map["route_import"] = "route-import"

                                self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                            class Default(Entity):
                                """
                                
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default, self).__init__()

                                    self.yang_name = "default"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.EidTable)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt)), ("distance", ("distance", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr)), ("import", ("import_", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import)), ("route-import", ("route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping))])
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "default"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class EidTable(Entity):
                                """
                                Bind an eid\-table
                                
                                .. attribute:: vrf_name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: default
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: vrf
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.EidTable, self).__init__()

                                    self.yang_name = "eid-table"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.vrf_name = None
                                    self.default = None
                                    self.vrf = None
                                    self._segment_path = lambda: "eid-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class Alt(Entity):
                                """
                                LISP Alternative Topology, LISP\-ALT
                                
                                .. attribute:: summary_route
                                
                                	Summary route to install into the ALT table
                                	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Alt, self).__init__()

                                    self.yang_name = "alt"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute))])
                                    self._leafs = OrderedDict()

                                    self.summary_route = YList(self)
                                    self._segment_path = lambda: "alt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Alt, [], name, value)


                                class SummaryRoute(Entity):
                                    """
                                    Summary route to install into the ALT table
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: route_tag
                                    
                                    	ALT RIB route tag for EID prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute, self).__init__()

                                        self.yang_name = "summary-route"
                                        self.yang_parent_name = "alt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                        ])
                                        self.eid_prefix = None
                                        self.route_tag = None
                                        self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: away
                                
                                	Administrative distance for RIB route installation
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.away = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: eid_interface
                                
                                	Configures static EID\-to\-RLOC mappings for an ITR
                                	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface>`
                                
                                .. attribute:: away_eids
                                
                                	Map cache configuration for the away table
                                	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids>`
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids))])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None

                                    self.away_eids = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids()
                                    self.away_eids.parent = self
                                    self._children_name_map["away_eids"] = "away-eids"

                                    self.eid_interface = YList(self)
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache, ['site_registration'], name, value)


                                class EidInterface(Entity):
                                    """
                                    Configures static EID\-to\-RLOC mappings for an ITR
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: etr_interface_ip
                                    
                                    	
                                    	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop packets that match this map\-cache entry
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: map_request
                                    
                                    	Send Map\-Request for LISP destination EID
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: native_forward
                                    
                                    	Natively forward packets that match this map\-cache entry
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface, self).__init__()

                                        self.yang_name = "eid-interface"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                            ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.drop = None
                                        self.map_request = None
                                        self.native_forward = None

                                        self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp()
                                        self.etr_interface_ip.parent = self
                                        self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                        self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                    class EtrInterfaceIp(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr_interface_ip_address
                                        
                                        	IP address of loopback or other ETR interface
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                            self.yang_name = "etr-interface-ip"
                                            self.yang_parent_name = "eid-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.etr_interface_ip_address = None
                                            self.priority = None
                                            self.weight = None
                                            self._segment_path = lambda: "etr-interface-ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                class AwayEids(Entity):
                                    """
                                    Map cache configuration for the away table
                                    
                                    .. attribute:: send_map_request
                                    
                                    	Export away table entries into the map cache with action set to send\-map\-request
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                        self.yang_name = "away-eids"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                        ])
                                        self.send_map_request = None
                                        self._segment_path = lambda: "away-eids"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                            class ProxyItr(Entity):
                                """
                                Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                
                                .. attribute:: ipv4_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr, self).__init__()

                                    self.yang_name = "proxy-itr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                        ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                    ])
                                    self.ipv4_addr = None
                                    self.ipv6_addr = None
                                    self._segment_path = lambda: "proxy-itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	
                                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority))])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ])
                                    self.locator_address = None

                                    self.priority = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority()
                                    self.priority.parent = self
                                    self._children_name_map["priority"] = "priority"
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                                class Priority(Entity):
                                    """
                                    
                                    
                                    .. attribute:: priority_value
                                    
                                    	Configures which Locators from a set are preferred
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: weight
                                    
                                    	Traffic load\-spreading among Locators
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority, self).__init__()

                                        self.yang_name = "priority"
                                        self.yang_parent_name = "use-petr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                        ])
                                        self.priority_value = None
                                        self.weight = None
                                        self._segment_path = lambda: "priority"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                            class Import(Entity):
                                """
                                Redistribute LISP states internally
                                
                                .. attribute:: database
                                
                                	Redistribute LISP internal states as database mapping
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import.Database>`
                                
                                .. attribute:: prefix_list_container
                                
                                	Redistribute LISP internal states into LISP prefix\-list entries
                                	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import, self).__init__()

                                    self.yang_name = "import"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.prefix_list_container = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer()
                                    self.prefix_list_container.parent = self
                                    self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                    self._segment_path = lambda: "import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import, [], name, value)


                                class Database(Entity):
                                    """
                                    Redistribute LISP internal states as database mapping
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.site_registration = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                                class PrefixListContainer(Entity):
                                    """
                                    Redistribute LISP internal states into LISP prefix\-list entries
                                    
                                    .. attribute:: prefix_list
                                    
                                    	The name of the lisp prefix list
                                    	**type**\: str
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer, self).__init__()

                                        self.yang_name = "prefix-list-container"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.prefix_list = None
                                        self.site_registration = None
                                        self._segment_path = lambda: "prefix-list-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                            class RouteImport(Entity):
                                """
                                Import RIB routes by a routing protocol into LISP
                                
                                .. attribute:: database
                                
                                	Use RIB routes to define local EID database entries
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database>`
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache>`
                                
                                .. attribute:: prefix_list_proto
                                
                                	
                                	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport, self).__init__()

                                    self.yang_name = "route-import"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.prefix_list_proto = YList(self)
                                    self._segment_path = lambda: "route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport, [], name, value)


                                class Database(Entity):
                                    """
                                    Use RIB routes to define local EID database entries
                                    
                                    .. attribute:: application
                                    
                                    	Application Protocol
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected>`
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix>`
                                    
                                    .. attribute:: nd
                                    
                                    	Neighbor Discovery
                                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip))])
                                        self._leafs = OrderedDict()

                                        self.application = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application()
                                        self.application.parent = self
                                        self._children_name_map["application"] = "application"

                                        self.connected = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected()
                                        self.connected.parent = self
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis()
                                        self.isis.parent = self
                                        self._children_name_map["isis"] = "isis"

                                        self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.nd = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd()
                                        self.nd.parent = self
                                        self._children_name_map["nd"] = "nd"

                                        self.static = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static()
                                        self.static.parent = self
                                        self._children_name_map["static"] = "static"

                                        self.rip = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip()
                                        self.rip.parent = self
                                        self._children_name_map["rip"] = "rip"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application Protocol
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: process_id
                                        
                                        	Process name
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                            ])
                                            self.process_id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis, ['process_id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Nd(Entity):
                                        """
                                        Neighbor Discovery
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd, self).__init__()

                                            self.yang_name = "nd"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "nd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "nd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: application
                                    
                                    	Application Protocol
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                    
                                    .. attribute:: nd
                                    
                                    	Neighbour Discovery
                                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip))])
                                        self._leafs = OrderedDict()

                                        self.application = None
                                        self._children_name_map["application"] = "application"

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis()
                                        self.isis.parent = self
                                        self._children_name_map["isis"] = "isis"

                                        self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.nd = None
                                        self._children_name_map["nd"] = "nd"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.rip = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip()
                                        self.rip.parent = self
                                        self._children_name_map["rip"] = "rip"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application Protocol
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id
                                        
                                        	Process name
                                        	**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Nd(Entity):
                                        """
                                        Neighbour Discovery
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd, self).__init__()

                                            self.yang_name = "nd"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "nd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "nd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                class PrefixListProto(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix_list  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: protocol  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.Protocol>`
                                    
                                    .. attribute:: bgp_id
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId>`
                                    
                                    .. attribute:: eigrp_or_ospf_id
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                    
                                    .. attribute:: isis_id
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto, self).__init__()

                                        self.yang_name = "prefix-list-proto"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix_list','protocol']
                                        self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                        self._leafs = OrderedDict([
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.Protocol')])),
                                            ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.prefix_list = None
                                        self.protocol = None
                                        self.isis_id = None
                                        self.number = None
                                        self.threshold = None
                                        self.warning_only = None
                                        self.route_map = None

                                        self.bgp_id = YList(self)
                                        self.eigrp_or_ospf_id = YList(self)
                                        self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                    class Protocol(Enum):
                                        """
                                        Protocol (Enum Class)

                                        .. data:: application = 0

                                        .. data:: bgp = 1

                                        .. data:: connected = 2

                                        .. data:: eigrp = 3

                                        .. data:: isis = 4

                                        .. data:: maximum_prefix = 5

                                        .. data:: nd = 6

                                        .. data:: ospf = 7

                                        .. data:: static = 8

                                        .. data:: rip = 9

                                        """

                                        application = Enum.YLeaf(0, "application")

                                        bgp = Enum.YLeaf(1, "bgp")

                                        connected = Enum.YLeaf(2, "connected")

                                        eigrp = Enum.YLeaf(3, "eigrp")

                                        isis = Enum.YLeaf(4, "isis")

                                        maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                        nd = Enum.YLeaf(6, "nd")

                                        ospf = Enum.YLeaf(7, "ospf")

                                        static = Enum.YLeaf(8, "static")

                                        rip = Enum.YLeaf(9, "rip")



                                    class BgpId(Entity):
                                        """
                                        
                                        
                                        .. attribute:: bgp_id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId, self).__init__()

                                            self.yang_name = "bgp-id"
                                            self.yang_parent_name = "prefix-list-proto"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['bgp_id']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.bgp_id = None
                                            self.route_map = None
                                            self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                    class EigrpOrOspfId(Entity):
                                        """
                                        
                                        
                                        .. attribute:: int16_id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                            self.yang_name = "eigrp-or-ospf-id"
                                            self.yang_parent_name = "prefix-list-proto"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['int16_id']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.int16_id = None
                                            self.route_map = None
                                            self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures Locator addresses for an ETR
                                
                                .. attribute:: eid_cont
                                
                                	
                                	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont>`
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"

                                    self.eid_cont = YList(self)
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping, [], name, value)


                                class EidCont(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    .. attribute:: locator_set_container
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer>`
                                    
                                    .. attribute:: ipv4_addrees
                                    
                                    	IPv4 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees>`
                                    
                                    .. attribute:: ipv6_addrees
                                    
                                    	IPv6 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees>`
                                    
                                    .. attribute:: ipv4_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface>`
                                    
                                    .. attribute:: ipv6_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface>`
                                    
                                    .. attribute:: auto_discover_rlocs
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont, self).__init__()

                                        self.yang_name = "eid-cont"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.auto_discover_rlocs = None

                                        self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer()
                                        self.locator_set_container.parent = self
                                        self._children_name_map["locator_set_container"] = "locator-set-container"

                                        self.ipv4_addrees = YList(self)
                                        self.ipv6_addrees = YList(self)
                                        self.ipv4_interface = YList(self)
                                        self.ipv6_interface = YList(self)
                                        self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                    class LocatorSetContainer(Entity):
                                        """
                                        Use locators defined by locator\-set
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        .. attribute:: proxy
                                        
                                        	Enable configuration of static proxy database mapping
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                            self.yang_name = "locator-set-container"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.proxy = None
                                            self._segment_path = lambda: "locator-set-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                    class Ipv4Addrees(Entity):
                                        """
                                        IPv4 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                            self.yang_name = "ipv4-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv4-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Ipv6Addrees(Entity):
                                        """
                                        IPv6 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                            self.yang_name = "ipv6-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv6-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv4Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                            self.yang_name = "IPv4-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv4-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv6Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                            self.yang_name = "IPv6-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv6-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Ipv6(Entity):
                            """
                            
                            
                            .. attribute:: default
                            
                            	
                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default>`
                            
                            .. attribute:: eid_table
                            
                            	Bind an eid\-table
                            	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.EidTable>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit>`
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest>`
                            
                            .. attribute:: alt
                            
                            	LISP Alternative Topology, LISP\-ALT
                            	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Alt>`
                            
                            .. attribute:: alt_vrf
                            
                            	Activate LISP\-ALT functionality in VRF
                            	**type**\: str
                            
                            	**status**\: deprecated
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Distance>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent>`
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr>`
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteExport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.UsePetr>`
                            
                            .. attribute:: import_
                            
                            	Redistribute LISP states internally
                            	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import>`
                            
                            .. attribute:: route_import
                            
                            	Import RIB routes by a routing protocol into LISP
                            	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: database_mapping
                            
                            	Configures Locator addresses for an ETR
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "service"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default)), ("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.EidTable)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Alt)), ("distance", ("distance", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import)), ("route-import", ("route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ])
                                self.alt_vrf = None
                                self.proxy_etr = None
                                self.sgt = None
                                self.map_request_source = None

                                self.default = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default()
                                self.default.parent = self
                                self._children_name_map["default"] = "default"

                                self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.EidTable()
                                self.eid_table.parent = self
                                self._children_name_map["eid_table"] = "eid-table"

                                self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.alt = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Alt()
                                self.alt.parent = self
                                self._children_name_map["alt"] = "alt"

                                self.distance = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_persistent = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.proxy_itr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr()
                                self.proxy_itr.parent = self
                                self._children_name_map["proxy_itr"] = "proxy-itr"

                                self.route_export = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.import_ = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import()
                                self.import_.parent = self
                                self._children_name_map["import_"] = "import"

                                self.route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport()
                                self.route_import.parent = self
                                self._children_name_map["route_import"] = "route-import"

                                self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                            class Default(Entity):
                                """
                                
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default, self).__init__()

                                    self.yang_name = "default"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.EidTable)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.SolicitMapRequest)), ("alt", ("alt", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt)), ("distance", ("distance", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Distance)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.ProxyItr)), ("route-export", ("route_export", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteExport)), ("use-petr", ("use_petr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr)), ("import", ("import_", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import)), ("route-import", ("route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping))])
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "default"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class EidTable(Entity):
                                """
                                Bind an eid\-table
                                
                                .. attribute:: vrf_name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: default
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: vrf
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.EidTable, self).__init__()

                                    self.yang_name = "eid-table"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.vrf_name = None
                                    self.default = None
                                    self.vrf = None
                                    self._segment_path = lambda: "eid-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class Alt(Entity):
                                """
                                LISP Alternative Topology, LISP\-ALT
                                
                                .. attribute:: summary_route
                                
                                	Summary route to install into the ALT table
                                	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Alt, self).__init__()

                                    self.yang_name = "alt"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute))])
                                    self._leafs = OrderedDict()

                                    self.summary_route = YList(self)
                                    self._segment_path = lambda: "alt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Alt, [], name, value)


                                class SummaryRoute(Entity):
                                    """
                                    Summary route to install into the ALT table
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: route_tag
                                    
                                    	ALT RIB route tag for EID prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute, self).__init__()

                                        self.yang_name = "summary-route"
                                        self.yang_parent_name = "alt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                        ])
                                        self.eid_prefix = None
                                        self.route_tag = None
                                        self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: away
                                
                                	Administrative distance for RIB route installation
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.away = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: eid_interface
                                
                                	Configures static EID\-to\-RLOC mappings for an ITR
                                	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface>`
                                
                                .. attribute:: away_eids
                                
                                	Map cache configuration for the away table
                                	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids>`
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids))])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None

                                    self.away_eids = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids()
                                    self.away_eids.parent = self
                                    self._children_name_map["away_eids"] = "away-eids"

                                    self.eid_interface = YList(self)
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache, ['site_registration'], name, value)


                                class EidInterface(Entity):
                                    """
                                    Configures static EID\-to\-RLOC mappings for an ITR
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: etr_interface_ip
                                    
                                    	
                                    	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop packets that match this map\-cache entry
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: map_request
                                    
                                    	Send Map\-Request for LISP destination EID
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: native_forward
                                    
                                    	Natively forward packets that match this map\-cache entry
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface, self).__init__()

                                        self.yang_name = "eid-interface"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                            ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.drop = None
                                        self.map_request = None
                                        self.native_forward = None

                                        self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp()
                                        self.etr_interface_ip.parent = self
                                        self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                        self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                    class EtrInterfaceIp(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr_interface_ip_address
                                        
                                        	IP address of loopback or other ETR interface
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                            self.yang_name = "etr-interface-ip"
                                            self.yang_parent_name = "eid-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.etr_interface_ip_address = None
                                            self.priority = None
                                            self.weight = None
                                            self._segment_path = lambda: "etr-interface-ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                class AwayEids(Entity):
                                    """
                                    Map cache configuration for the away table
                                    
                                    .. attribute:: send_map_request
                                    
                                    	Export away table entries into the map cache with action set to send\-map\-request
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                        self.yang_name = "away-eids"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                        ])
                                        self.send_map_request = None
                                        self._segment_path = lambda: "away-eids"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                            class ProxyItr(Entity):
                                """
                                Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                
                                .. attribute:: ipv4_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr, self).__init__()

                                    self.yang_name = "proxy-itr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                        ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                    ])
                                    self.ipv4_addr = None
                                    self.ipv6_addr = None
                                    self._segment_path = lambda: "proxy-itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	
                                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([("priority", ("priority", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority))])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ])
                                    self.locator_address = None

                                    self.priority = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority()
                                    self.priority.parent = self
                                    self._children_name_map["priority"] = "priority"
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                                class Priority(Entity):
                                    """
                                    
                                    
                                    .. attribute:: priority_value
                                    
                                    	Configures which Locators from a set are preferred
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: weight
                                    
                                    	Traffic load\-spreading among Locators
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority, self).__init__()

                                        self.yang_name = "priority"
                                        self.yang_parent_name = "use-petr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                        ])
                                        self.priority_value = None
                                        self.weight = None
                                        self._segment_path = lambda: "priority"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                            class Import(Entity):
                                """
                                Redistribute LISP states internally
                                
                                .. attribute:: database
                                
                                	Redistribute LISP internal states as database mapping
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import.Database>`
                                
                                .. attribute:: prefix_list_container
                                
                                	Redistribute LISP internal states into LISP prefix\-list entries
                                	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import, self).__init__()

                                    self.yang_name = "import"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.prefix_list_container = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer()
                                    self.prefix_list_container.parent = self
                                    self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                    self._segment_path = lambda: "import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import, [], name, value)


                                class Database(Entity):
                                    """
                                    Redistribute LISP internal states as database mapping
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.site_registration = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                                class PrefixListContainer(Entity):
                                    """
                                    Redistribute LISP internal states into LISP prefix\-list entries
                                    
                                    .. attribute:: prefix_list
                                    
                                    	The name of the lisp prefix list
                                    	**type**\: str
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer, self).__init__()

                                        self.yang_name = "prefix-list-container"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.prefix_list = None
                                        self.site_registration = None
                                        self._segment_path = lambda: "prefix-list-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                            class RouteImport(Entity):
                                """
                                Import RIB routes by a routing protocol into LISP
                                
                                .. attribute:: database
                                
                                	Use RIB routes to define local EID database entries
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database>`
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache>`
                                
                                .. attribute:: prefix_list_proto
                                
                                	
                                	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport, self).__init__()

                                    self.yang_name = "route-import"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.prefix_list_proto = YList(self)
                                    self._segment_path = lambda: "route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport, [], name, value)


                                class Database(Entity):
                                    """
                                    Use RIB routes to define local EID database entries
                                    
                                    .. attribute:: application
                                    
                                    	Application Protocol
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected>`
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix>`
                                    
                                    .. attribute:: nd
                                    
                                    	Neighbor Discovery
                                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip))])
                                        self._leafs = OrderedDict()

                                        self.application = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application()
                                        self.application.parent = self
                                        self._children_name_map["application"] = "application"

                                        self.connected = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected()
                                        self.connected.parent = self
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis()
                                        self.isis.parent = self
                                        self._children_name_map["isis"] = "isis"

                                        self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.nd = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd()
                                        self.nd.parent = self
                                        self._children_name_map["nd"] = "nd"

                                        self.static = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static()
                                        self.static.parent = self
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application Protocol
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: process_id
                                        
                                        	Process name
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                            ])
                                            self.process_id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis, ['process_id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Nd(Entity):
                                        """
                                        Neighbor Discovery
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd, self).__init__()

                                            self.yang_name = "nd"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "nd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "nd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this process
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: application
                                    
                                    	Application Protocol
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                    
                                    .. attribute:: nd
                                    
                                    	Neighbour Discovery
                                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip))])
                                        self._leafs = OrderedDict()

                                        self.application = None
                                        self._children_name_map["application"] = "application"

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis()
                                        self.isis.parent = self
                                        self._children_name_map["isis"] = "isis"

                                        self.maximum_prefix = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.nd = None
                                        self._children_name_map["nd"] = "nd"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application Protocol
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id
                                        
                                        	Process name
                                        	**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Nd(Entity):
                                        """
                                        Neighbour Discovery
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd, self).__init__()

                                            self.yang_name = "nd"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "nd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "nd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this process
                                        	**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                class PrefixListProto(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix_list  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: protocol  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.Protocol>`
                                    
                                    .. attribute:: bgp_id
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId>`
                                    
                                    .. attribute:: eigrp_or_ospf_id
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                    
                                    .. attribute:: isis_id
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto, self).__init__()

                                        self.yang_name = "prefix-list-proto"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix_list','protocol']
                                        self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                        self._leafs = OrderedDict([
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.Protocol')])),
                                            ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.prefix_list = None
                                        self.protocol = None
                                        self.isis_id = None
                                        self.number = None
                                        self.threshold = None
                                        self.warning_only = None
                                        self.route_map = None

                                        self.bgp_id = YList(self)
                                        self.eigrp_or_ospf_id = YList(self)
                                        self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                    class Protocol(Enum):
                                        """
                                        Protocol (Enum Class)

                                        .. data:: application = 0

                                        .. data:: bgp = 1

                                        .. data:: connected = 2

                                        .. data:: eigrp = 3

                                        .. data:: isis = 4

                                        .. data:: maximum_prefix = 5

                                        .. data:: nd = 6

                                        .. data:: ospf = 7

                                        .. data:: static = 8

                                        .. data:: rip = 9

                                        """

                                        application = Enum.YLeaf(0, "application")

                                        bgp = Enum.YLeaf(1, "bgp")

                                        connected = Enum.YLeaf(2, "connected")

                                        eigrp = Enum.YLeaf(3, "eigrp")

                                        isis = Enum.YLeaf(4, "isis")

                                        maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                        nd = Enum.YLeaf(6, "nd")

                                        ospf = Enum.YLeaf(7, "ospf")

                                        static = Enum.YLeaf(8, "static")

                                        rip = Enum.YLeaf(9, "rip")



                                    class BgpId(Entity):
                                        """
                                        
                                        
                                        .. attribute:: bgp_id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId, self).__init__()

                                            self.yang_name = "bgp-id"
                                            self.yang_parent_name = "prefix-list-proto"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['bgp_id']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.bgp_id = None
                                            self.route_map = None
                                            self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                    class EigrpOrOspfId(Entity):
                                        """
                                        
                                        
                                        .. attribute:: int16_id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                            self.yang_name = "eigrp-or-ospf-id"
                                            self.yang_parent_name = "prefix-list-proto"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['int16_id']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.int16_id = None
                                            self.route_map = None
                                            self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures Locator addresses for an ETR
                                
                                .. attribute:: eid_cont
                                
                                	
                                	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont>`
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"

                                    self.eid_cont = YList(self)
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping, [], name, value)


                                class EidCont(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: locator_set_container
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer>`
                                    
                                    .. attribute:: ipv4_addrees
                                    
                                    	IPv4 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees>`
                                    
                                    .. attribute:: ipv6_addrees
                                    
                                    	IPv6 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees>`
                                    
                                    .. attribute:: ipv4_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface>`
                                    
                                    .. attribute:: ipv6_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface>`
                                    
                                    .. attribute:: auto_discover_rlocs
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont, self).__init__()

                                        self.yang_name = "eid-cont"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.auto_discover_rlocs = None

                                        self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer()
                                        self.locator_set_container.parent = self
                                        self._children_name_map["locator_set_container"] = "locator-set-container"

                                        self.ipv4_addrees = YList(self)
                                        self.ipv6_addrees = YList(self)
                                        self.ipv4_interface = YList(self)
                                        self.ipv6_interface = YList(self)
                                        self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                    class LocatorSetContainer(Entity):
                                        """
                                        Use locators defined by locator\-set
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        .. attribute:: proxy
                                        
                                        	Enable configuration of static proxy database mapping
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                            self.yang_name = "locator-set-container"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.proxy = None
                                            self._segment_path = lambda: "locator-set-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                    class Ipv4Addrees(Entity):
                                        """
                                        IPv4 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                            self.yang_name = "ipv4-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv4-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Ipv6Addrees(Entity):
                                        """
                                        IPv6 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                            self.yang_name = "ipv6-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv6-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv4Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                            self.yang_name = "IPv4-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv4-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv6Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                            self.yang_name = "IPv6-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv6-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Ethernet(Entity):
                            """
                            
                            
                            .. attribute:: default
                            
                            	
                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default>`
                            
                            .. attribute:: eid_table
                            
                            	Bind an eid\-table
                            	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.EidTable>`
                            
                            .. attribute:: broadcast_underlay
                            
                            	Multicast group to use for underlay
                            	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay>`
                            
                            .. attribute:: flood
                            
                            	Control flooding or local intercept of broadcast frames
                            	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Flood>`
                            
                            .. attribute:: database_mapping
                            
                            	Configures Locator addresses for an ETR
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit>`
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_cache
                            
                            	Use RIB routes to define EID address space in map\-cache
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "service"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default)), ("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay)), ("flood", ("flood", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Flood)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                ])
                                self.map_request_source = None

                                self.default = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default()
                                self.default.parent = self
                                self._children_name_map["default"] = "default"

                                self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.EidTable()
                                self.eid_table.parent = self
                                self._children_name_map["eid_table"] = "eid-table"

                                self.broadcast_underlay = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay()
                                self.broadcast_underlay.parent = self
                                self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                self.flood = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Flood()
                                self.flood.parent = self
                                self._children_name_map["flood"] = "flood"

                                self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet, ['map_request_source'], name, value)


                            class Default(Entity):
                                """
                                
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.EidTable>`
                                
                                .. attribute:: broadcast_underlay
                                
                                	Multicast group to use for underlay
                                	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.BroadcastUnderlay>`
                                
                                .. attribute:: flood
                                
                                	Control flooding or local intercept of broadcast frames
                                	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Flood>`
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.SolicitMapRequest>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default, self).__init__()

                                    self.yang_name = "default"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.BroadcastUnderlay)), ("flood", ("flood", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Flood)), ("database-mapping", ("database_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping)), ("itr", ("itr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.EtrEnable)), ("etr", ("etr", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache))])
                                    self._leafs = OrderedDict([
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                    ])
                                    self.map_request_source = None

                                    self.eid_table = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.broadcast_underlay = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.BroadcastUnderlay()
                                    self.broadcast_underlay.parent = self
                                    self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                    self.flood = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Flood()
                                    self.flood.parent = self
                                    self._children_name_map["flood"] = "flood"

                                    self.database_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.itr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.map_cache = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"
                                    self._segment_path = lambda: "default"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default, ['map_request_source'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN configuration
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.EidTable, ['vlan'], name, value)


                                class BroadcastUnderlay(Entity):
                                    """
                                    Multicast group to use for underlay
                                    
                                    .. attribute:: ipv4_multicast
                                    
                                    	IPv4 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_multicast
                                    
                                    	IPv6 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.BroadcastUnderlay, self).__init__()

                                        self.yang_name = "broadcast-underlay"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                            ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                        ])
                                        self.ipv4_multicast = None
                                        self.ipv6_multicast = None
                                        self._segment_path = lambda: "broadcast-underlay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                class Flood(Entity):
                                    """
                                    Control flooding or local intercept of broadcast frames
                                    
                                    .. attribute:: arp_nd
                                    
                                    	IPv4 ARP / IPv6 ND
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Frames with unknown destination MAC
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Flood, self).__init__()

                                        self.yang_name = "flood"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                            ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                        ])
                                        self.arp_nd = None
                                        self.unknown_unicast = None
                                        self._segment_path = lambda: "flood"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: mac
                                    
                                    	L2 EID records
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Mac>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.mac = None
                                        self._children_name_map["mac"] = "mac"

                                        self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Mac(Entity):
                                        """
                                        L2 EID records
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.locator_set = None
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Mac, ['locator_set'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont))])
                                        self._leafs = OrderedDict()

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont.EtrInterfaceIp>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont, ['eid_prefix'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                            class EidTable(Entity):
                                """
                                Bind an eid\-table
                                
                                .. attribute:: vlan
                                
                                	VLAN configuration
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.EidTable, self).__init__()

                                    self.yang_name = "eid-table"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "eid-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.EidTable, ['vlan'], name, value)


                            class BroadcastUnderlay(Entity):
                                """
                                Multicast group to use for underlay
                                
                                .. attribute:: ipv4_multicast
                                
                                	IPv4 multicast group address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_multicast
                                
                                	IPv6 multicast group address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay, self).__init__()

                                    self.yang_name = "broadcast-underlay"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                        ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                    ])
                                    self.ipv4_multicast = None
                                    self.ipv6_multicast = None
                                    self._segment_path = lambda: "broadcast-underlay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                            class Flood(Entity):
                                """
                                Control flooding or local intercept of broadcast frames
                                
                                .. attribute:: arp_nd
                                
                                	IPv4 ARP / IPv6 ND
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Frames with unknown destination MAC
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Flood, self).__init__()

                                    self.yang_name = "flood"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                        ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                    ])
                                    self.arp_nd = None
                                    self.unknown_unicast = None
                                    self._segment_path = lambda: "flood"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures Locator addresses for an ETR
                                
                                .. attribute:: eid_cont
                                
                                	EID\-record for RLOC static mapping
                                	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont>`
                                
                                .. attribute:: mac
                                
                                	L2 EID records
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.mac = None
                                    self._children_name_map["mac"] = "mac"

                                    self.limit = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"

                                    self.eid_cont = YList(self)
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping, [], name, value)


                                class EidCont(Entity):
                                    """
                                    EID\-record for RLOC static mapping
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	xxxx.xxxx.xxxx 48 bit mac address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                    
                                    .. attribute:: locator_set_container
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer>`
                                    
                                    .. attribute:: ipv4_addrees
                                    
                                    	IPv4 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees>`
                                    
                                    .. attribute:: ipv6_addrees
                                    
                                    	IPv6 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees>`
                                    
                                    .. attribute:: ipv4_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface>`
                                    
                                    .. attribute:: ipv6_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont, self).__init__()

                                        self.yang_name = "eid-cont"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                        ])
                                        self.eid_prefix = None

                                        self.locator_set_container = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer()
                                        self.locator_set_container.parent = self
                                        self._children_name_map["locator_set_container"] = "locator-set-container"

                                        self.ipv4_addrees = YList(self)
                                        self.ipv6_addrees = YList(self)
                                        self.ipv4_interface = YList(self)
                                        self.ipv6_interface = YList(self)
                                        self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                    class LocatorSetContainer(Entity):
                                        """
                                        Use locators defined by locator\-set
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        .. attribute:: proxy
                                        
                                        	Enable configuration of static proxy database mapping
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                            self.yang_name = "locator-set-container"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.proxy = None
                                            self._segment_path = lambda: "locator-set-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                    class Ipv4Addrees(Entity):
                                        """
                                        IPv4 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                            self.yang_name = "ipv4-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv4-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Ipv6Addrees(Entity):
                                        """
                                        IPv6 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                            self.yang_name = "ipv6-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv6-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv4Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                            self.yang_name = "IPv4-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv4-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv6Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                            self.yang_name = "IPv6-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv6-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                class Mac(Entity):
                                    """
                                    L2 EID records
                                    
                                    .. attribute:: locator_set
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.locator_set = None
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac, ['locator_set'], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class MapCache(Entity):
                                """
                                Use RIB routes to define EID address space in map\-cache
                                
                                .. attribute:: eid_cont
                                
                                	EID\-record for RLOC static mapping
                                	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont))])
                                    self._leafs = OrderedDict()

                                    self.eid_cont = YList(self)
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache, [], name, value)


                                class EidCont(Entity):
                                    """
                                    EID\-record for RLOC static mapping
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	xxxx.xxxx.xxxx 48 bit mac address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                    
                                    .. attribute:: etr_interface_ip
                                    
                                    	
                                    	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont, self).__init__()

                                        self.yang_name = "eid-cont"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                        ])
                                        self.eid_prefix = None

                                        self.etr_interface_ip = Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp()
                                        self.etr_interface_ip.parent = self
                                        self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                        self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont, ['eid_prefix'], name, value)


                                    class EtrInterfaceIp(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr_interface_ip_address
                                        
                                        	IP address of loopback or other ETR interface
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                            self.yang_name = "etr-interface-ip"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.etr_interface_ip_address = None
                                            self.priority = None
                                            self.weight = None
                                            self._segment_path = lambda: "etr-interface-ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


            class Alt(Entity):
                """
                LISP Alternative Topology, LISP\-ALT
                
                .. attribute:: summary_route
                
                	Summary route to install into the ALT table
                	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Alt.SummaryRoute>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Alt, self).__init__()

                    self.yang_name = "alt"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.Alt.SummaryRoute))])
                    self._leafs = OrderedDict()

                    self.summary_route = YList(self)
                    self._segment_path = lambda: "alt"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Alt, [], name, value)


                class SummaryRoute(Entity):
                    """
                    Summary route to install into the ALT table
                    
                    .. attribute:: eid_prefix  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    .. attribute:: route_tag
                    
                    	ALT RIB route tag for EID prefix
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Alt.SummaryRoute, self).__init__()

                        self.yang_name = "summary-route"
                        self.yang_parent_name = "alt"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['eid_prefix']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                            ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                        ])
                        self.eid_prefix = None
                        self.route_tag = None
                        self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/alt/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


            class ControlPacket(Entity):
                """
                Configure control packet tx option
                
                .. attribute:: mtu
                
                	Configure control packet MTU
                	**type**\: int
                
                	**range:** 304..10000
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.ControlPacket, self).__init__()

                    self.yang_name = "control-packet"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                    ])
                    self.mtu = None
                    self._segment_path = lambda: "control-packet"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.ControlPacket, ['mtu'], name, value)


            class Ddt(Entity):
                """
                Delegated Database Tree (DDT) mapping system
                
                .. attribute:: authoritative
                
                	DDT authoritative prefix
                	**type**\:  :py:class:`Authoritative <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ddt.Authoritative>`
                
                .. attribute:: cache_limit
                
                	DDT resolver cache entry limit
                	**type**\: int
                
                	**range:** 1..100000
                
                .. attribute:: root
                
                	DDT root node
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Ddt, self).__init__()

                    self.yang_name = "ddt"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authoritative", ("authoritative", Native.Router.Lisp.Ddt.Authoritative))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cache_limit', (YLeaf(YType.uint32, 'cache-limit'), ['int'])),
                        ('root', (YLeaf(YType.str, 'root'), ['str','str'])),
                    ])
                    self.cache_limit = None
                    self.root = None

                    self.authoritative = Native.Router.Lisp.Ddt.Authoritative()
                    self.authoritative.parent = self
                    self._children_name_map["authoritative"] = "authoritative"
                    self._segment_path = lambda: "ddt"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Ddt, ['cache_limit', 'root'], name, value)


                class Authoritative(Entity):
                    """
                    DDT authoritative prefix
                    
                    .. attribute:: instance_id_eid_prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`InstanceIdEidPrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ddt.Authoritative.InstanceIdEidPrefixList>`
                    
                    .. attribute:: instance_id_list
                    
                    	
                    	**type**\: list of  		 :py:class:`InstanceIdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ddt.Authoritative.InstanceIdList>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ddt.Authoritative, self).__init__()

                        self.yang_name = "authoritative"
                        self.yang_parent_name = "ddt"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("instance-id-eid-prefix-list", ("instance_id_eid_prefix_list", Native.Router.Lisp.Ddt.Authoritative.InstanceIdEidPrefixList)), ("instance-id-list", ("instance_id_list", Native.Router.Lisp.Ddt.Authoritative.InstanceIdList))])
                        self._leafs = OrderedDict()

                        self.instance_id_eid_prefix_list = YList(self)
                        self.instance_id_list = YList(self)
                        self._segment_path = lambda: "authoritative"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ddt/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ddt.Authoritative, [], name, value)


                    class InstanceIdEidPrefixList(Entity):
                        """
                        
                        
                        .. attribute:: instance_id  (key)
                        
                        	EID instance\-ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: eid_prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: delegate
                        
                        	DDT delegation to a child DDT node or map\-server
                        	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate>`
                        
                        .. attribute:: map_server_peer
                        
                        	Peer map\-servers that are authoritative for the same EID prefixes
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ddt.Authoritative.InstanceIdEidPrefixList, self).__init__()

                            self.yang_name = "instance-id-eid-prefix-list"
                            self.yang_parent_name = "authoritative"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['instance_id','eid_prefix']
                            self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.Lisp.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate))])
                            self._leafs = OrderedDict([
                                ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                            ])
                            self.instance_id = None
                            self.eid_prefix = None
                            self.map_server_peer = None

                            self.delegate = Native.Router.Lisp.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate()
                            self.delegate.parent = self
                            self._children_name_map["delegate"] = "delegate"
                            self._segment_path = lambda: "instance-id-eid-prefix-list" + "[instance-id='" + str(self.instance_id) + "']" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ddt/authoritative/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ddt.Authoritative.InstanceIdEidPrefixList, ['instance_id', 'eid_prefix', 'map_server_peer'], name, value)


                        class Delegate(Entity):
                            """
                            DDT delegation to a child DDT node or map\-server
                            
                            .. attribute:: eid_prefix
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: instance_id
                            
                            	EID instance\-ID
                            	**type**\: str
                            
                            .. attribute:: to
                            
                            	DDT delegation to a child DDT node or map\-server
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ip_address
                            
                            	IPv4/6 Child or map\-server node locator address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_server
                            
                            	Delegation points to a map\-server
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, self).__init__()

                                self.yang_name = "delegate"
                                self.yang_parent_name = "instance-id-eid-prefix-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                    ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                    ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                ])
                                self.eid_prefix = None
                                self.instance_id = None
                                self.to = None
                                self.ip_address = None
                                self.map_server = None
                                self._segment_path = lambda: "delegate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                    class InstanceIdList(Entity):
                        """
                        
                        
                        .. attribute:: instance_id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: delegate
                        
                        	DDT delegation to a child DDT node or map\-server
                        	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ddt.Authoritative.InstanceIdList.Delegate>`
                        
                        .. attribute:: map_server_peer
                        
                        	Peer map\-servers that are authoritative for the same EID prefixes
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ddt.Authoritative.InstanceIdList, self).__init__()

                            self.yang_name = "instance-id-list"
                            self.yang_parent_name = "authoritative"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['instance_id']
                            self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.Lisp.Ddt.Authoritative.InstanceIdList.Delegate))])
                            self._leafs = OrderedDict([
                                ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                            ])
                            self.instance_id = None
                            self.map_server_peer = None

                            self.delegate = Native.Router.Lisp.Ddt.Authoritative.InstanceIdList.Delegate()
                            self.delegate.parent = self
                            self._children_name_map["delegate"] = "delegate"
                            self._segment_path = lambda: "instance-id-list" + "[instance-id='" + str(self.instance_id) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ddt/authoritative/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ddt.Authoritative.InstanceIdList, ['instance_id', 'map_server_peer'], name, value)


                        class Delegate(Entity):
                            """
                            DDT delegation to a child DDT node or map\-server
                            
                            .. attribute:: eid_prefix
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: instance_id
                            
                            	EID instance\-ID
                            	**type**\: str
                            
                            .. attribute:: to
                            
                            	DDT delegation to a child DDT node or map\-server
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ip_address
                            
                            	IPv4/6 Child or map\-server node locator address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_server
                            
                            	Delegation points to a map\-server
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ddt.Authoritative.InstanceIdList.Delegate, self).__init__()

                                self.yang_name = "delegate"
                                self.yang_parent_name = "instance-id-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                    ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                    ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                ])
                                self.eid_prefix = None
                                self.instance_id = None
                                self.to = None
                                self.ip_address = None
                                self.map_server = None
                                self._segment_path = lambda: "delegate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ddt.Authoritative.InstanceIdList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


            class Decapsulation(Entity):
                """
                Decapsulation behavior (e.g. filters)
                
                .. attribute:: filter
                
                	Filters traffic
                	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Decapsulation.Filter>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Decapsulation, self).__init__()

                    self.yang_name = "decapsulation"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("filter", ("filter", Native.Router.Lisp.Decapsulation.Filter))])
                    self._leafs = OrderedDict()

                    self.filter = Native.Router.Lisp.Decapsulation.Filter()
                    self.filter.parent = self
                    self._children_name_map["filter"] = "filter"
                    self._segment_path = lambda: "decapsulation"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Decapsulation, [], name, value)


                class Filter(Entity):
                    """
                    Filters traffic
                    
                    .. attribute:: rloc
                    
                    	Filter based on Routing Locator (RLOC) in packet header
                    	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Decapsulation.Filter.Rloc>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Decapsulation.Filter, self).__init__()

                        self.yang_name = "filter"
                        self.yang_parent_name = "decapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.Decapsulation.Filter.Rloc))])
                        self._leafs = OrderedDict()

                        self.rloc = Native.Router.Lisp.Decapsulation.Filter.Rloc()
                        self.rloc.parent = self
                        self._children_name_map["rloc"] = "rloc"
                        self._segment_path = lambda: "filter"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/decapsulation/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Decapsulation.Filter, [], name, value)


                    class Rloc(Entity):
                        """
                        Filter based on Routing Locator (RLOC) in packet header
                        
                        .. attribute:: source
                        
                        	Filters traffic based on RLOC source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Decapsulation.Filter.Rloc.Source>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Decapsulation.Filter.Rloc, self).__init__()

                            self.yang_name = "rloc"
                            self.yang_parent_name = "filter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Decapsulation.Filter.Rloc.Source))])
                            self._leafs = OrderedDict()

                            self.source = Native.Router.Lisp.Decapsulation.Filter.Rloc.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "rloc"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/decapsulation/filter/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Decapsulation.Filter.Rloc, [], name, value)


                        class Source(Entity):
                            """
                            Filters traffic based on RLOC source address
                            
                            .. attribute:: locator_set
                            
                            	Locator\-set Name
                            	**type**\: str
                            
                            .. attribute:: member
                            
                            	Members learned from map\-server
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Decapsulation.Filter.Rloc.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "rloc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                ])
                                self.locator_set = None
                                self.member = None
                                self._segment_path = lambda: "source"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/decapsulation/filter/rloc/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


            class Etr(Entity):
                """
                Configures a LISP Egress Tunnel Router (ETR)
                
                .. attribute:: map_server
                
                	Configures map server for ETR registration
                	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Etr.MapServer>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Etr, self).__init__()

                    self.yang_name = "etr"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Etr.MapServer))])
                    self._leafs = OrderedDict()

                    self.map_server = Native.Router.Lisp.Etr.MapServer()
                    self.map_server.parent = self
                    self._children_name_map["map_server"] = "map-server"
                    self._segment_path = lambda: "etr"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Etr, [], name, value)


                class MapServer(Entity):
                    """
                    Configures map server for ETR registration
                    
                    .. attribute:: source_address
                    
                    	Configures map server source address
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Etr.MapServer, self).__init__()

                        self.yang_name = "map-server"
                        self.yang_parent_name = "etr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                        ])
                        self.source_address = None
                        self._segment_path = lambda: "map-server"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/etr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Etr.MapServer, ['source_address'], name, value)


            class Ipv4(Entity):
                """
                IPv4 address family
                
                .. attribute:: alt_vrf
                
                	Activate LISP\-ALT functionality in VRF
                	**type**\: str
                
                	**status**\: deprecated
                
                .. attribute:: database_mapping
                
                	Address family specific local EID prefixes database configuration
                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.DatabaseMapping>`
                
                .. attribute:: distance
                
                	Administrative distance for RIB route installation
                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.Distance>`
                
                .. attribute:: itr
                
                	Configures a LISP Ingress Tunnel Router (ITR)
                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.Itr>`
                
                .. attribute:: itr_enable
                
                	
                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.ItrEnable>`
                
                .. attribute:: etr
                
                	Configures a LISP Egress Tunnel Router (ETR)
                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.Etr>`
                
                .. attribute:: etr_enable
                
                	
                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.EtrEnable>`
                
                .. attribute:: locator
                
                	Locator related configuration
                	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.Locator>`
                
                .. attribute:: map_cache
                
                	Address family specific map cache configuration
                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.MapCache>`
                
                .. attribute:: map_cache_limit
                
                	Configures maximum size of map\-cache
                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.MapCacheLimit>`
                
                .. attribute:: map_cache_persistent
                
                	Dump map\-cache onto flash, making it persistent across reboots
                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.MapCachePersistent>`
                
                .. attribute:: map_request_source
                
                	Configures inner header source address in Map\-Request message
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: map_resolver
                
                	Configures a LISP Map Resolver (MR)
                	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.MapResolver>`
                
                	**presence node**\: True
                
                .. attribute:: map_server
                
                	Configures a LISP Map Server (MS)
                	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.MapServer>`
                
                	**presence node**\: True
                
                .. attribute:: path_mtu_discovery
                
                	Path MTU discovery
                	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.PathMtuDiscovery>`
                
                	**presence node**\: True
                
                .. attribute:: proxy_etr
                
                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_itr
                
                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                	**type**\: union of the below types:
                
                		**type**\: list of str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: list of str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: route_export
                
                	Export routes into RIB from LISP
                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteExport>`
                
                .. attribute:: route_import
                
                	Import RIB routes by a routing protocol into LISP
                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport>`
                
                .. attribute:: sgt
                
                	Enable security group tag propagation in LISP encapsulated traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: site_registration
                
                	Site registrations configuration for a given instance\-id
                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.SiteRegistration>`
                
                .. attribute:: solicit_map_request
                
                	Configure Solicit\-Map\-Request handling
                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.SolicitMapRequest>`
                
                .. attribute:: source_locator
                
                	Source Locator configuration
                	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.SourceLocator>`
                
                .. attribute:: use_petr
                
                	Encapsulate to Proxy ETR when matching forward\-native entry
                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.UsePetr>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Ipv4, self).__init__()

                    self.yang_name = "ipv4"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Ipv4.DatabaseMapping)), ("distance", ("distance", Native.Router.Lisp.Ipv4.Distance)), ("itr", ("itr", Native.Router.Lisp.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Ipv4.ItrEnable)), ("etr", ("etr", Native.Router.Lisp.Ipv4.Etr)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Ipv4.EtrEnable)), ("locator", ("locator", Native.Router.Lisp.Ipv4.Locator)), ("map-cache", ("map_cache", Native.Router.Lisp.Ipv4.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Ipv4.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Ipv4.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Ipv4.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Lisp.Ipv4.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.Lisp.Ipv4.RouteExport)), ("route-import", ("route_import", Native.Router.Lisp.Ipv4.RouteImport)), ("site-registration", ("site_registration", Native.Router.Lisp.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Ipv4.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.Lisp.Ipv4.SourceLocator)), ("use-petr", ("use_petr", Native.Router.Lisp.Ipv4.UsePetr))])
                    self._leafs = OrderedDict([
                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                        ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                    ])
                    self.alt_vrf = None
                    self.map_request_source = None
                    self.proxy_etr = None
                    self.proxy_itr = []
                    self.sgt = None

                    self.database_mapping = Native.Router.Lisp.Ipv4.DatabaseMapping()
                    self.database_mapping.parent = self
                    self._children_name_map["database_mapping"] = "database-mapping"

                    self.distance = Native.Router.Lisp.Ipv4.Distance()
                    self.distance.parent = self
                    self._children_name_map["distance"] = "distance"

                    self.itr = Native.Router.Lisp.Ipv4.Itr()
                    self.itr.parent = self
                    self._children_name_map["itr"] = "itr"

                    self.itr_enable = Native.Router.Lisp.Ipv4.ItrEnable()
                    self.itr_enable.parent = self
                    self._children_name_map["itr_enable"] = "itr-enable"

                    self.etr = Native.Router.Lisp.Ipv4.Etr()
                    self.etr.parent = self
                    self._children_name_map["etr"] = "etr"

                    self.etr_enable = Native.Router.Lisp.Ipv4.EtrEnable()
                    self.etr_enable.parent = self
                    self._children_name_map["etr_enable"] = "etr-enable"

                    self.locator = Native.Router.Lisp.Ipv4.Locator()
                    self.locator.parent = self
                    self._children_name_map["locator"] = "locator"

                    self.map_cache = Native.Router.Lisp.Ipv4.MapCache()
                    self.map_cache.parent = self
                    self._children_name_map["map_cache"] = "map-cache"

                    self.map_cache_limit = Native.Router.Lisp.Ipv4.MapCacheLimit()
                    self.map_cache_limit.parent = self
                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                    self.map_cache_persistent = Native.Router.Lisp.Ipv4.MapCachePersistent()
                    self.map_cache_persistent.parent = self
                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                    self.map_resolver = None
                    self._children_name_map["map_resolver"] = "map-resolver"

                    self.map_server = None
                    self._children_name_map["map_server"] = "map-server"

                    self.path_mtu_discovery = None
                    self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                    self.route_export = Native.Router.Lisp.Ipv4.RouteExport()
                    self.route_export.parent = self
                    self._children_name_map["route_export"] = "route-export"

                    self.route_import = Native.Router.Lisp.Ipv4.RouteImport()
                    self.route_import.parent = self
                    self._children_name_map["route_import"] = "route-import"

                    self.site_registration = Native.Router.Lisp.Ipv4.SiteRegistration()
                    self.site_registration.parent = self
                    self._children_name_map["site_registration"] = "site-registration"

                    self.solicit_map_request = Native.Router.Lisp.Ipv4.SolicitMapRequest()
                    self.solicit_map_request.parent = self
                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                    self.source_locator = Native.Router.Lisp.Ipv4.SourceLocator()
                    self.source_locator.parent = self
                    self._children_name_map["source_locator"] = "source-locator"

                    self.use_petr = YList(self)
                    self._segment_path = lambda: "ipv4"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Ipv4, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                class DatabaseMapping(Entity):
                    """
                    Address family specific local EID prefixes database configuration
                    
                    .. attribute:: limit
                    
                    	Configures the maximum size of local EID prefixes database
                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.DatabaseMapping.Limit>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.DatabaseMapping, self).__init__()

                        self.yang_name = "database-mapping"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Ipv4.DatabaseMapping.Limit))])
                        self._leafs = OrderedDict()

                        self.limit = Native.Router.Lisp.Ipv4.DatabaseMapping.Limit()
                        self.limit.parent = self
                        self._children_name_map["limit"] = "limit"
                        self._segment_path = lambda: "database-mapping"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.DatabaseMapping, [], name, value)


                    class Limit(Entity):
                        """
                        Configures the maximum size of local EID prefixes database
                        
                        .. attribute:: dynamic
                        
                        	Configures the maximum size of dynamic local EID prefixes database
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.DatabaseMapping.Limit, self).__init__()

                            self.yang_name = "limit"
                            self.yang_parent_name = "database-mapping"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.dynamic = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "limit"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/database-mapping/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                class Distance(Entity):
                    """
                    Administrative distance for RIB route installation
                    
                    .. attribute:: alt
                    
                    	LISP routes installed in the ALT table
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: dyn_eid
                    
                    	LISP installed routes of type dynamic\-EID
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: site_registrations
                    
                    	LISP installed routes of type site\-registrations
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.Distance, self).__init__()

                        self.yang_name = "distance"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                        ])
                        self.alt = None
                        self.dyn_eid = None
                        self.site_registrations = None
                        self._segment_path = lambda: "distance"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                class Itr(Entity):
                    """
                    Configures a LISP Ingress Tunnel Router (ITR)
                    
                    .. attribute:: map_resolver
                    
                    	Configures map\-resolver address for sending Map\-Requests
                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.Itr.MapResolver>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.Itr, self).__init__()

                        self.yang_name = "itr"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Ipv4.Itr.MapResolver))])
                        self._leafs = OrderedDict()

                        self.map_resolver = YList(self)
                        self._segment_path = lambda: "itr"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.Itr, [], name, value)


                    class MapResolver(Entity):
                        """
                        Configures map\-resolver address for sending Map\-Requests
                        
                        .. attribute:: ip_addr  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.Itr.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "itr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ip_addr']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                            ])
                            self.ip_addr = None
                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/itr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.Itr.MapResolver, ['ip_addr'], name, value)


                class ItrEnable(Entity):
                    """
                    
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.ItrEnable, self).__init__()

                        self.yang_name = "itr-enable"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                        ])
                        self.itr = None
                        self._segment_path = lambda: "itr-enable"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.ItrEnable, ['itr'], name, value)


                class Etr(Entity):
                    """
                    Configures a LISP Egress Tunnel Router (ETR)
                    
                    .. attribute:: map_server
                    
                    	Configures map server for ETR registration
                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.Etr.MapServer>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.Etr, self).__init__()

                        self.yang_name = "etr"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Ipv4.Etr.MapServer))])
                        self._leafs = OrderedDict()

                        self.map_server = YList(self)
                        self._segment_path = lambda: "etr"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.Etr, [], name, value)


                    class MapServer(Entity):
                        """
                        Configures map server for ETR registration
                        
                        .. attribute:: ip_addr  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: key
                        
                        	Authentication key used with map server
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.Etr.MapServer.Key>`
                        
                        .. attribute:: proxy_reply
                        
                        	Request Map\-Server to send Map\-Replies on behalf of site
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.Etr.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "etr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ip_addr']
                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Ipv4.Etr.MapServer.Key))])
                            self._leafs = OrderedDict([
                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                            ])
                            self.ip_addr = None
                            self.proxy_reply = None

                            self.key = Native.Router.Lisp.Ipv4.Etr.MapServer.Key()
                            self.key.parent = self
                            self._children_name_map["key"] = "key"
                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/etr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                        class Key(Entity):
                            """
                            Authentication key used with map server
                            
                            .. attribute:: key_0
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            .. attribute:: key_6
                            
                            	The ENCRYPTED password
                            	**type**\: str
                            
                            .. attribute:: key_7
                            
                            	The HIDDEN password
                            	**type**\: str
                            
                            .. attribute:: pwd
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.Etr.MapServer.Key, self).__init__()

                                self.yang_name = "key"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                    ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                    ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                    ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                ])
                                self.key_0 = None
                                self.key_6 = None
                                self.key_7 = None
                                self.pwd = None
                                self._segment_path = lambda: "key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                class EtrEnable(Entity):
                    """
                    
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.EtrEnable, self).__init__()

                        self.yang_name = "etr-enable"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                        ])
                        self.etr = None
                        self._segment_path = lambda: "etr-enable"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.EtrEnable, ['etr'], name, value)


                class Locator(Entity):
                    """
                    Locator related configuration
                    
                    .. attribute:: reachability
                    
                    	Configuration realted to locator reachability
                    	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.Locator.Reachability>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.Locator, self).__init__()

                        self.yang_name = "locator"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.Lisp.Ipv4.Locator.Reachability))])
                        self._leafs = OrderedDict()

                        self.reachability = Native.Router.Lisp.Ipv4.Locator.Reachability()
                        self.reachability.parent = self
                        self._children_name_map["reachability"] = "reachability"
                        self._segment_path = lambda: "locator"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.Locator, [], name, value)


                    class Reachability(Entity):
                        """
                        Configuration realted to locator reachability
                        
                        .. attribute:: exclude_default
                        
                        	If a remote RLOC is reached via the default route, treat it as unreachable
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.Locator.Reachability, self).__init__()

                            self.yang_name = "reachability"
                            self.yang_parent_name = "locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                            ])
                            self.exclude_default = None
                            self._segment_path = lambda: "reachability"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/locator/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.Locator.Reachability, ['exclude_default'], name, value)


                class MapCache(Entity):
                    """
                    Address family specific map cache configuration
                    
                    .. attribute:: site_registration
                    
                    	Install map cache to map request for site registrations
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.MapCache, self).__init__()

                        self.yang_name = "map-cache"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                        ])
                        self.site_registration = None
                        self._segment_path = lambda: "map-cache"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.MapCache, ['site_registration'], name, value)


                class MapCacheLimit(Entity):
                    """
                    Configures maximum size of map\-cache
                    
                    .. attribute:: max_map_cache_entries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..100000
                    
                    .. attribute:: reserve_list
                    
                    	EID\-prefixes guaranteed to be stored in map\-cache
                    	**type**\: str
                    
                    .. attribute:: warning_threshold
                    
                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.MapCacheLimit, self).__init__()

                        self.yang_name = "map-cache-limit"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                        ])
                        self.max_map_cache_entries = None
                        self.reserve_list = None
                        self.warning_threshold = None
                        self._segment_path = lambda: "map-cache-limit"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                class MapCachePersistent(Entity):
                    """
                    Dump map\-cache onto flash, making it persistent across reboots
                    
                    .. attribute:: interval
                    
                    	Interval in minutes of how often the map\-cache is saved
                    	**type**\: int
                    
                    	**range:** 1..1440
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.MapCachePersistent, self).__init__()

                        self.yang_name = "map-cache-persistent"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                        ])
                        self.interval = None
                        self._segment_path = lambda: "map-cache-persistent"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.MapCachePersistent, ['interval'], name, value)


                class MapResolver(Entity):
                    """
                    Configures a LISP Map Resolver (MR)
                    
                    .. attribute:: map_request
                    
                    	Map\-Request processing options
                    	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.MapResolver.MapRequest>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.MapResolver, self).__init__()

                        self.yang_name = "map-resolver"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Ipv4.MapResolver.MapRequest))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.map_request = Native.Router.Lisp.Ipv4.MapResolver.MapRequest()
                        self.map_request.parent = self
                        self._children_name_map["map_request"] = "map-request"
                        self._segment_path = lambda: "map-resolver"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.MapResolver, [], name, value)


                    class MapRequest(Entity):
                        """
                        Map\-Request processing options
                        
                        .. attribute:: validate
                        
                        	Validation options
                        	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.MapResolver.MapRequest.Validate>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.MapResolver.MapRequest, self).__init__()

                            self.yang_name = "map-request"
                            self.yang_parent_name = "map-resolver"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Ipv4.MapResolver.MapRequest.Validate))])
                            self._leafs = OrderedDict()

                            self.validate = Native.Router.Lisp.Ipv4.MapResolver.MapRequest.Validate()
                            self.validate.parent = self
                            self._children_name_map["validate"] = "validate"
                            self._segment_path = lambda: "map-request"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/map-resolver/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.MapResolver.MapRequest, [], name, value)


                        class Validate(Entity):
                            """
                            Validation options
                            
                            .. attribute:: source
                            
                            	Influence which source RLOCs map requests are accepted from
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.MapResolver.MapRequest.Validate.Source>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                self.yang_name = "validate"
                                self.yang_parent_name = "map-request"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                self._leafs = OrderedDict()

                                self.source = Native.Router.Lisp.Ipv4.MapResolver.MapRequest.Validate.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "validate"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/map-resolver/map-request/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                            class Source(Entity):
                                """
                                Influence which source RLOCs map requests are accepted from
                                
                                .. attribute:: list
                                
                                	Define allowed prefixes using an ip[v6] prefix list
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: registered
                                
                                	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ipv4
                                
                                	IPv4 prefixes
                                	**type**\: str
                                
                                .. attribute:: ipv6
                                
                                	IPv6 prefixes
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "validate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                        ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.list = None
                                    self.registered = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "source"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/map-resolver/map-request/validate/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                class MapServer(Entity):
                    """
                    Configures a LISP Map Server (MS)
                    
                    .. attribute:: map_register
                    
                    	Map\-Register processing options
                    	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.MapServer.MapRegister>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.MapServer, self).__init__()

                        self.yang_name = "map-server"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Ipv4.MapServer.MapRegister))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.map_register = Native.Router.Lisp.Ipv4.MapServer.MapRegister()
                        self.map_register.parent = self
                        self._children_name_map["map_register"] = "map-register"
                        self._segment_path = lambda: "map-server"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.MapServer, [], name, value)


                    class MapRegister(Entity):
                        """
                        Map\-Register processing options
                        
                        .. attribute:: validate
                        
                        	Validation options
                        	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.MapServer.MapRegister.Validate>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.MapServer.MapRegister, self).__init__()

                            self.yang_name = "map-register"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Ipv4.MapServer.MapRegister.Validate))])
                            self._leafs = OrderedDict()

                            self.validate = Native.Router.Lisp.Ipv4.MapServer.MapRegister.Validate()
                            self.validate.parent = self
                            self._children_name_map["validate"] = "validate"
                            self._segment_path = lambda: "map-register"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/map-server/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.MapServer.MapRegister, [], name, value)


                        class Validate(Entity):
                            """
                            Validation options
                            
                            .. attribute:: source
                            
                            	RLOC Source IP address
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.MapServer.MapRegister.Validate.Source>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                self.yang_name = "validate"
                                self.yang_parent_name = "map-register"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Ipv4.MapServer.MapRegister.Validate.Source))])
                                self._leafs = OrderedDict()

                                self.source = Native.Router.Lisp.Ipv4.MapServer.MapRegister.Validate.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "validate"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/map-server/map-register/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                            class Source(Entity):
                                """
                                RLOC Source IP address
                                
                                .. attribute:: allowed_locator
                                
                                	Against sites' allowed\-locators policy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "validate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                    ])
                                    self.allowed_locator = None
                                    self._segment_path = lambda: "source"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/map-server/map-register/validate/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                class PathMtuDiscovery(Entity):
                    """
                    Path MTU discovery
                    
                    .. attribute:: max
                    
                    	Upper bound on the path MTU accepted
                    	**type**\: int
                    
                    	**range:** 68..65535
                    
                    .. attribute:: min
                    
                    	Lower bound on the path MTU accepted
                    	**type**\: int
                    
                    	**range:** 68..65535
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.PathMtuDiscovery, self).__init__()

                        self.yang_name = "path-mtu-discovery"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                            ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                        ])
                        self.max = None
                        self.min = None
                        self._segment_path = lambda: "path-mtu-discovery"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.PathMtuDiscovery, ['max', 'min'], name, value)


                class RouteExport(Entity):
                    """
                    Export routes into RIB from LISP
                    
                    .. attribute:: site_registrations
                    
                    	Export LISP site registrations to RIB
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: away_eids
                    
                    	Export LISP away EIDs to RIB
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.RouteExport, self).__init__()

                        self.yang_name = "route-export"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                        ])
                        self.site_registrations = None
                        self.away_eids = None
                        self._segment_path = lambda: "route-export"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                class RouteImport(Entity):
                    """
                    Import RIB routes by a routing protocol into LISP
                    
                    .. attribute:: database
                    
                    	Use RIB routes to define local EID database entries
                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database>`
                    
                    .. attribute:: map_cache
                    
                    	Use RIB routes to define EID address space in map\-cache
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.RouteImport, self).__init__()

                        self.yang_name = "route-import"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Ipv4.RouteImport.MapCache))])
                        self._leafs = OrderedDict()

                        self.database = Native.Router.Lisp.Ipv4.RouteImport.Database()
                        self.database.parent = self
                        self._children_name_map["database"] = "database"

                        self.map_cache = Native.Router.Lisp.Ipv4.RouteImport.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"
                        self._segment_path = lambda: "route-import"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport, [], name, value)


                    class Database(Entity):
                        """
                        Use RIB routes to define local EID database entries
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Connected>`
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Isis>`
                        
                        .. attribute:: maximum_prefix
                        
                        	Maximum number of prefixes to pick up from the RIB
                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.MaximumPrefix>`
                        
                        .. attribute:: ospf
                        
                        	Open Shortest Path First (OSPF)
                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Ospf>`
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Rip>`
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Static>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.RouteImport.Database, self).__init__()

                            self.yang_name = "database"
                            self.yang_parent_name = "route-import"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Ipv4.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Ipv4.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Ipv4.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Ipv4.RouteImport.Database.Rip)), ("static", ("static", Native.Router.Lisp.Ipv4.RouteImport.Database.Static))])
                            self._leafs = OrderedDict()

                            self.connected = Native.Router.Lisp.Ipv4.RouteImport.Database.Connected()
                            self.connected.parent = self
                            self._children_name_map["connected"] = "connected"

                            self.maximum_prefix = Native.Router.Lisp.Ipv4.RouteImport.Database.MaximumPrefix()
                            self.maximum_prefix.parent = self
                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                            self.rip = Native.Router.Lisp.Ipv4.RouteImport.Database.Rip()
                            self.rip.parent = self
                            self._children_name_map["rip"] = "rip"

                            self.static = Native.Router.Lisp.Ipv4.RouteImport.Database.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"

                            self.bgp = YList(self)
                            self.eigrp = YList(self)
                            self.isis = YList(self)
                            self.ospf = YList(self)
                            self.ospfv3 = YList(self)
                            self._segment_path = lambda: "database"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database, [], name, value)


                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.Database.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "connected"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Connected, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "connected"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/connected/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.Database.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Isis, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class MaximumPrefix(Entity):
                            """
                            Maximum number of prefixes to pick up from the RIB
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: warning_only
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: warning_only1
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                self.yang_name = "maximum-prefix"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                ])
                                self.number = None
                                self.warning_only = None
                                self.threshold = None
                                self.threshold1 = None
                                self.warning_only1 = None
                                self._segment_path = lambda: "maximum-prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                        class Ospf(Entity):
                            """
                            Open Shortest Path First (OSPF)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                self.yang_name = "ospf"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "ospf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.Database.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Ospfv3, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.Database.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "rip"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Rip, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "rip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/rip/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.Database.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "static"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Static, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/database/static/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                    class MapCache(Entity):
                        """
                        Use RIB routes to define EID address space in map\-cache
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Connected>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Isis>`
                        
                        .. attribute:: maximum_prefix
                        
                        	Maximum number of prefixes to pick up from the RIB
                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                        
                        .. attribute:: ospf
                        
                        	Open Shortest Path First (OSPF)
                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospf>`
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Rip>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Static>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.RouteImport.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "route-import"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Static))])
                            self._leafs = OrderedDict()

                            self.connected = None
                            self._children_name_map["connected"] = "connected"

                            self.maximum_prefix = Native.Router.Lisp.Ipv4.RouteImport.MapCache.MaximumPrefix()
                            self.maximum_prefix.parent = self
                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                            self.rip = None
                            self._children_name_map["rip"] = "rip"

                            self.static = None
                            self._children_name_map["static"] = "static"

                            self.bgp = YList(self)
                            self.eigrp = YList(self)
                            self.isis = YList(self)
                            self.ospf = YList(self)
                            self.ospfv3 = YList(self)
                            self._segment_path = lambda: "map-cache"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache, [], name, value)


                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "connected"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "connected"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/connected/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                        class MaximumPrefix(Entity):
                            """
                            Maximum number of prefixes to pick up from the RIB
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: warning_only
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: warning_only1
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                self.yang_name = "maximum-prefix"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                ])
                                self.number = None
                                self.warning_only = None
                                self.threshold = None
                                self.threshold1 = None
                                self.warning_only1 = None
                                self._segment_path = lambda: "maximum-prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                        class Ospf(Entity):
                            """
                            Open Shortest Path First (OSPF)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                self.yang_name = "ospf"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "ospf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "rip"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "rip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/rip/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "static"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Static, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/route-import/map-cache/static/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                class SiteRegistration(Entity):
                    """
                    Site registrations configuration for a given instance\-id
                    
                    .. attribute:: limit
                    
                    	Maximum number of site registrations for a given instance\-id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: warning_threshold
                    
                    	Warning threshold to issue system logging
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.SiteRegistration, self).__init__()

                        self.yang_name = "site-registration"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                        ])
                        self.limit = None
                        self.warning_threshold = None
                        self._segment_path = lambda: "site-registration"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                class SolicitMapRequest(Entity):
                    """
                    Configure Solicit\-Map\-Request handling
                    
                    .. attribute:: ignore
                    
                    	Ignore SMR bit in incoming Map\-Requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: max_per_entry
                    
                    	Maximum number of SMRs for addresses under a map\-cache entry
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    .. attribute:: suppression_time
                    
                    	How long to suppress repeated SMRs for the same address
                    	**type**\: int
                    
                    	**range:** 1..600
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.SolicitMapRequest, self).__init__()

                        self.yang_name = "solicit-map-request"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                        ])
                        self.ignore = None
                        self.max_per_entry = None
                        self.suppression_time = None
                        self._segment_path = lambda: "solicit-map-request"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                class SourceLocator(Entity):
                    """
                    Source Locator configuration
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.SourceLocator.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.SourceLocator.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.SourceLocator.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv4.SourceLocator.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.SourceLocator, self).__init__()

                        self.yang_name = "source-locator"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Lisp.Ipv4.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Lisp.Ipv4.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Lisp.Ipv4.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Lisp.Ipv4.SourceLocator.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Router.Lisp.Ipv4.SourceLocator.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Router.Lisp.Ipv4.SourceLocator.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Router.Lisp.Ipv4.SourceLocator.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Router.Lisp.Ipv4.SourceLocator.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "source-locator"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.SourceLocator.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/source-locator/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.SourceLocator.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/source-locator/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.SourceLocator.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/source-locator/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv4.SourceLocator.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/source-locator/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv4.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                class UsePetr(Entity):
                    """
                    Encapsulate to Proxy ETR when matching forward\-native entry
                    
                    .. attribute:: locator_address  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: priority
                    
                    	Configures which Locators from a set are preferred
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: weight
                    
                    	Traffic load\-spreading among Locators
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv4.UsePetr, self).__init__()

                        self.yang_name = "use-petr"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['locator_address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                        ])
                        self.locator_address = None
                        self.priority = None
                        self.weight = None
                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv4.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


            class Ipv6(Entity):
                """
                IPv6 address family
                
                .. attribute:: alt_vrf
                
                	Activate LISP\-ALT functionality in VRF
                	**type**\: str
                
                	**status**\: deprecated
                
                .. attribute:: database_mapping
                
                	Address family specific local EID prefixes database configuration
                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.DatabaseMapping>`
                
                .. attribute:: distance
                
                	Administrative distance for RIB route installation
                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.Distance>`
                
                .. attribute:: itr
                
                	Configures a LISP Ingress Tunnel Router (ITR)
                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.Itr>`
                
                .. attribute:: itr_enable
                
                	
                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.ItrEnable>`
                
                .. attribute:: etr
                
                	Configures a LISP Egress Tunnel Router (ETR)
                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.Etr>`
                
                .. attribute:: etr_enable
                
                	
                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.EtrEnable>`
                
                .. attribute:: locator
                
                	Locator related configuration
                	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.Locator>`
                
                .. attribute:: map_cache
                
                	Address family specific map cache configuration
                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.MapCache>`
                
                .. attribute:: map_cache_limit
                
                	Configures maximum size of map\-cache
                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.MapCacheLimit>`
                
                .. attribute:: map_cache_persistent
                
                	Dump map\-cache onto flash, making it persistent across reboots
                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.MapCachePersistent>`
                
                .. attribute:: map_request_source
                
                	Configures inner header source address in Map\-Request message
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: map_resolver
                
                	Configures a LISP Map Resolver (MR)
                	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.MapResolver>`
                
                	**presence node**\: True
                
                .. attribute:: map_server
                
                	Configures a LISP Map Server (MS)
                	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.MapServer>`
                
                	**presence node**\: True
                
                .. attribute:: path_mtu_discovery
                
                	Path MTU discovery
                	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.PathMtuDiscovery>`
                
                	**presence node**\: True
                
                .. attribute:: proxy_etr
                
                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_itr
                
                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                	**type**\: union of the below types:
                
                		**type**\: list of str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: list of str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: route_export
                
                	Export routes into RIB from LISP
                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteExport>`
                
                .. attribute:: route_import
                
                	Import RIB routes by a routing protocol into LISP
                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport>`
                
                .. attribute:: sgt
                
                	Enable security group tag propagation in LISP encapsulated traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: site_registration
                
                	Site registrations configuration for a given instance\-id
                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.SiteRegistration>`
                
                .. attribute:: solicit_map_request
                
                	Configure Solicit\-Map\-Request handling
                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.SolicitMapRequest>`
                
                .. attribute:: source_locator
                
                	Source Locator configuration
                	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.SourceLocator>`
                
                .. attribute:: use_petr
                
                	Encapsulate to Proxy ETR when matching forward\-native entry
                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.UsePetr>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.Ipv6.DatabaseMapping)), ("distance", ("distance", Native.Router.Lisp.Ipv6.Distance)), ("itr", ("itr", Native.Router.Lisp.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.Ipv6.ItrEnable)), ("etr", ("etr", Native.Router.Lisp.Ipv6.Etr)), ("etr-enable", ("etr_enable", Native.Router.Lisp.Ipv6.EtrEnable)), ("locator", ("locator", Native.Router.Lisp.Ipv6.Locator)), ("map-cache", ("map_cache", Native.Router.Lisp.Ipv6.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.Ipv6.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.Ipv6.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.Lisp.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.Ipv6.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Lisp.Ipv6.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.Lisp.Ipv6.RouteExport)), ("route-import", ("route_import", Native.Router.Lisp.Ipv6.RouteImport)), ("site-registration", ("site_registration", Native.Router.Lisp.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.Ipv6.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.Lisp.Ipv6.SourceLocator)), ("use-petr", ("use_petr", Native.Router.Lisp.Ipv6.UsePetr))])
                    self._leafs = OrderedDict([
                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                        ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                    ])
                    self.alt_vrf = None
                    self.map_request_source = None
                    self.proxy_etr = None
                    self.proxy_itr = []
                    self.sgt = None

                    self.database_mapping = Native.Router.Lisp.Ipv6.DatabaseMapping()
                    self.database_mapping.parent = self
                    self._children_name_map["database_mapping"] = "database-mapping"

                    self.distance = Native.Router.Lisp.Ipv6.Distance()
                    self.distance.parent = self
                    self._children_name_map["distance"] = "distance"

                    self.itr = Native.Router.Lisp.Ipv6.Itr()
                    self.itr.parent = self
                    self._children_name_map["itr"] = "itr"

                    self.itr_enable = Native.Router.Lisp.Ipv6.ItrEnable()
                    self.itr_enable.parent = self
                    self._children_name_map["itr_enable"] = "itr-enable"

                    self.etr = Native.Router.Lisp.Ipv6.Etr()
                    self.etr.parent = self
                    self._children_name_map["etr"] = "etr"

                    self.etr_enable = Native.Router.Lisp.Ipv6.EtrEnable()
                    self.etr_enable.parent = self
                    self._children_name_map["etr_enable"] = "etr-enable"

                    self.locator = Native.Router.Lisp.Ipv6.Locator()
                    self.locator.parent = self
                    self._children_name_map["locator"] = "locator"

                    self.map_cache = Native.Router.Lisp.Ipv6.MapCache()
                    self.map_cache.parent = self
                    self._children_name_map["map_cache"] = "map-cache"

                    self.map_cache_limit = Native.Router.Lisp.Ipv6.MapCacheLimit()
                    self.map_cache_limit.parent = self
                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                    self.map_cache_persistent = Native.Router.Lisp.Ipv6.MapCachePersistent()
                    self.map_cache_persistent.parent = self
                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                    self.map_resolver = None
                    self._children_name_map["map_resolver"] = "map-resolver"

                    self.map_server = None
                    self._children_name_map["map_server"] = "map-server"

                    self.path_mtu_discovery = None
                    self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                    self.route_export = Native.Router.Lisp.Ipv6.RouteExport()
                    self.route_export.parent = self
                    self._children_name_map["route_export"] = "route-export"

                    self.route_import = Native.Router.Lisp.Ipv6.RouteImport()
                    self.route_import.parent = self
                    self._children_name_map["route_import"] = "route-import"

                    self.site_registration = Native.Router.Lisp.Ipv6.SiteRegistration()
                    self.site_registration.parent = self
                    self._children_name_map["site_registration"] = "site-registration"

                    self.solicit_map_request = Native.Router.Lisp.Ipv6.SolicitMapRequest()
                    self.solicit_map_request.parent = self
                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                    self.source_locator = Native.Router.Lisp.Ipv6.SourceLocator()
                    self.source_locator.parent = self
                    self._children_name_map["source_locator"] = "source-locator"

                    self.use_petr = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Ipv6, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                class DatabaseMapping(Entity):
                    """
                    Address family specific local EID prefixes database configuration
                    
                    .. attribute:: limit
                    
                    	Configures the maximum size of local EID prefixes database
                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.DatabaseMapping.Limit>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.DatabaseMapping, self).__init__()

                        self.yang_name = "database-mapping"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.Ipv6.DatabaseMapping.Limit))])
                        self._leafs = OrderedDict()

                        self.limit = Native.Router.Lisp.Ipv6.DatabaseMapping.Limit()
                        self.limit.parent = self
                        self._children_name_map["limit"] = "limit"
                        self._segment_path = lambda: "database-mapping"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.DatabaseMapping, [], name, value)


                    class Limit(Entity):
                        """
                        Configures the maximum size of local EID prefixes database
                        
                        .. attribute:: dynamic
                        
                        	Configures the maximum size of dynamic local EID prefixes database
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.DatabaseMapping.Limit, self).__init__()

                            self.yang_name = "limit"
                            self.yang_parent_name = "database-mapping"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.dynamic = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "limit"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/database-mapping/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                class Distance(Entity):
                    """
                    Administrative distance for RIB route installation
                    
                    .. attribute:: alt
                    
                    	LISP routes installed in the ALT table
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: dyn_eid
                    
                    	LISP installed routes of type dynamic\-EID
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: site_registrations
                    
                    	LISP installed routes of type site\-registrations
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.Distance, self).__init__()

                        self.yang_name = "distance"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                        ])
                        self.alt = None
                        self.dyn_eid = None
                        self.site_registrations = None
                        self._segment_path = lambda: "distance"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                class Itr(Entity):
                    """
                    Configures a LISP Ingress Tunnel Router (ITR)
                    
                    .. attribute:: map_resolver
                    
                    	Configures map\-resolver address for sending Map\-Requests
                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.Itr.MapResolver>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.Itr, self).__init__()

                        self.yang_name = "itr"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.Ipv6.Itr.MapResolver))])
                        self._leafs = OrderedDict()

                        self.map_resolver = YList(self)
                        self._segment_path = lambda: "itr"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.Itr, [], name, value)


                    class MapResolver(Entity):
                        """
                        Configures map\-resolver address for sending Map\-Requests
                        
                        .. attribute:: ip_addr  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.Itr.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "itr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ip_addr']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                            ])
                            self.ip_addr = None
                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/itr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.Itr.MapResolver, ['ip_addr'], name, value)


                class ItrEnable(Entity):
                    """
                    
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.ItrEnable, self).__init__()

                        self.yang_name = "itr-enable"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                        ])
                        self.itr = None
                        self._segment_path = lambda: "itr-enable"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.ItrEnable, ['itr'], name, value)


                class Etr(Entity):
                    """
                    Configures a LISP Egress Tunnel Router (ETR)
                    
                    .. attribute:: map_server
                    
                    	Configures map server for ETR registration
                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.Etr.MapServer>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.Etr, self).__init__()

                        self.yang_name = "etr"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.Ipv6.Etr.MapServer))])
                        self._leafs = OrderedDict()

                        self.map_server = YList(self)
                        self._segment_path = lambda: "etr"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.Etr, [], name, value)


                    class MapServer(Entity):
                        """
                        Configures map server for ETR registration
                        
                        .. attribute:: ip_addr  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: key
                        
                        	Authentication key used with map server
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.Etr.MapServer.Key>`
                        
                        .. attribute:: proxy_reply
                        
                        	Request Map\-Server to send Map\-Replies on behalf of site
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.Etr.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "etr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ip_addr']
                            self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.Ipv6.Etr.MapServer.Key))])
                            self._leafs = OrderedDict([
                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                            ])
                            self.ip_addr = None
                            self.proxy_reply = None

                            self.key = Native.Router.Lisp.Ipv6.Etr.MapServer.Key()
                            self.key.parent = self
                            self._children_name_map["key"] = "key"
                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/etr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                        class Key(Entity):
                            """
                            Authentication key used with map server
                            
                            .. attribute:: key_0
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            .. attribute:: key_6
                            
                            	The ENCRYPTED password
                            	**type**\: str
                            
                            .. attribute:: key_7
                            
                            	The HIDDEN password
                            	**type**\: str
                            
                            .. attribute:: pwd
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.Etr.MapServer.Key, self).__init__()

                                self.yang_name = "key"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                    ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                    ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                    ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                ])
                                self.key_0 = None
                                self.key_6 = None
                                self.key_7 = None
                                self.pwd = None
                                self._segment_path = lambda: "key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                class EtrEnable(Entity):
                    """
                    
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.EtrEnable, self).__init__()

                        self.yang_name = "etr-enable"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                        ])
                        self.etr = None
                        self._segment_path = lambda: "etr-enable"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.EtrEnable, ['etr'], name, value)


                class Locator(Entity):
                    """
                    Locator related configuration
                    
                    .. attribute:: reachability
                    
                    	Configuration realted to locator reachability
                    	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.Locator.Reachability>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.Locator, self).__init__()

                        self.yang_name = "locator"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.Lisp.Ipv6.Locator.Reachability))])
                        self._leafs = OrderedDict()

                        self.reachability = Native.Router.Lisp.Ipv6.Locator.Reachability()
                        self.reachability.parent = self
                        self._children_name_map["reachability"] = "reachability"
                        self._segment_path = lambda: "locator"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.Locator, [], name, value)


                    class Reachability(Entity):
                        """
                        Configuration realted to locator reachability
                        
                        .. attribute:: exclude_default
                        
                        	If a remote RLOC is reached via the default route, treat it as unreachable
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.Locator.Reachability, self).__init__()

                            self.yang_name = "reachability"
                            self.yang_parent_name = "locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                            ])
                            self.exclude_default = None
                            self._segment_path = lambda: "reachability"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/locator/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.Locator.Reachability, ['exclude_default'], name, value)


                class MapCache(Entity):
                    """
                    Address family specific map cache configuration
                    
                    .. attribute:: site_registration
                    
                    	Install map cache to map request for site registrations
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.MapCache, self).__init__()

                        self.yang_name = "map-cache"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                        ])
                        self.site_registration = None
                        self._segment_path = lambda: "map-cache"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.MapCache, ['site_registration'], name, value)


                class MapCacheLimit(Entity):
                    """
                    Configures maximum size of map\-cache
                    
                    .. attribute:: max_map_cache_entries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..100000
                    
                    .. attribute:: reserve_list
                    
                    	EID\-prefixes guaranteed to be stored in map\-cache
                    	**type**\: str
                    
                    .. attribute:: warning_threshold
                    
                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.MapCacheLimit, self).__init__()

                        self.yang_name = "map-cache-limit"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                        ])
                        self.max_map_cache_entries = None
                        self.reserve_list = None
                        self.warning_threshold = None
                        self._segment_path = lambda: "map-cache-limit"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                class MapCachePersistent(Entity):
                    """
                    Dump map\-cache onto flash, making it persistent across reboots
                    
                    .. attribute:: interval
                    
                    	Interval in minutes of how often the map\-cache is saved
                    	**type**\: int
                    
                    	**range:** 1..1440
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.MapCachePersistent, self).__init__()

                        self.yang_name = "map-cache-persistent"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                        ])
                        self.interval = None
                        self._segment_path = lambda: "map-cache-persistent"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.MapCachePersistent, ['interval'], name, value)


                class MapResolver(Entity):
                    """
                    Configures a LISP Map Resolver (MR)
                    
                    .. attribute:: map_request
                    
                    	Map\-Request processing options
                    	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.MapResolver.MapRequest>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.MapResolver, self).__init__()

                        self.yang_name = "map-resolver"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.Ipv6.MapResolver.MapRequest))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.map_request = Native.Router.Lisp.Ipv6.MapResolver.MapRequest()
                        self.map_request.parent = self
                        self._children_name_map["map_request"] = "map-request"
                        self._segment_path = lambda: "map-resolver"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.MapResolver, [], name, value)


                    class MapRequest(Entity):
                        """
                        Map\-Request processing options
                        
                        .. attribute:: validate
                        
                        	Validation options
                        	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.MapResolver.MapRequest.Validate>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.MapResolver.MapRequest, self).__init__()

                            self.yang_name = "map-request"
                            self.yang_parent_name = "map-resolver"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Ipv6.MapResolver.MapRequest.Validate))])
                            self._leafs = OrderedDict()

                            self.validate = Native.Router.Lisp.Ipv6.MapResolver.MapRequest.Validate()
                            self.validate.parent = self
                            self._children_name_map["validate"] = "validate"
                            self._segment_path = lambda: "map-request"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/map-resolver/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.MapResolver.MapRequest, [], name, value)


                        class Validate(Entity):
                            """
                            Validation options
                            
                            .. attribute:: source
                            
                            	Influence which source RLOCs map requests are accepted from
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.MapResolver.MapRequest.Validate.Source>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                self.yang_name = "validate"
                                self.yang_parent_name = "map-request"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                self._leafs = OrderedDict()

                                self.source = Native.Router.Lisp.Ipv6.MapResolver.MapRequest.Validate.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "validate"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/map-resolver/map-request/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                            class Source(Entity):
                                """
                                Influence which source RLOCs map requests are accepted from
                                
                                .. attribute:: list
                                
                                	Define allowed prefixes using an ip[v6] prefix list
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: registered
                                
                                	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ipv4
                                
                                	IPv4 prefixes
                                	**type**\: str
                                
                                .. attribute:: ipv6
                                
                                	IPv6 prefixes
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "validate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                        ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.list = None
                                    self.registered = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "source"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/map-resolver/map-request/validate/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                class MapServer(Entity):
                    """
                    Configures a LISP Map Server (MS)
                    
                    .. attribute:: map_register
                    
                    	Map\-Register processing options
                    	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.MapServer.MapRegister>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.MapServer, self).__init__()

                        self.yang_name = "map-server"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.Ipv6.MapServer.MapRegister))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.map_register = Native.Router.Lisp.Ipv6.MapServer.MapRegister()
                        self.map_register.parent = self
                        self._children_name_map["map_register"] = "map-register"
                        self._segment_path = lambda: "map-server"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.MapServer, [], name, value)


                    class MapRegister(Entity):
                        """
                        Map\-Register processing options
                        
                        .. attribute:: validate
                        
                        	Validation options
                        	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.MapServer.MapRegister.Validate>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.MapServer.MapRegister, self).__init__()

                            self.yang_name = "map-register"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.Ipv6.MapServer.MapRegister.Validate))])
                            self._leafs = OrderedDict()

                            self.validate = Native.Router.Lisp.Ipv6.MapServer.MapRegister.Validate()
                            self.validate.parent = self
                            self._children_name_map["validate"] = "validate"
                            self._segment_path = lambda: "map-register"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/map-server/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.MapServer.MapRegister, [], name, value)


                        class Validate(Entity):
                            """
                            Validation options
                            
                            .. attribute:: source
                            
                            	RLOC Source IP address
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.MapServer.MapRegister.Validate.Source>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                self.yang_name = "validate"
                                self.yang_parent_name = "map-register"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.Ipv6.MapServer.MapRegister.Validate.Source))])
                                self._leafs = OrderedDict()

                                self.source = Native.Router.Lisp.Ipv6.MapServer.MapRegister.Validate.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "validate"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/map-server/map-register/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                            class Source(Entity):
                                """
                                RLOC Source IP address
                                
                                .. attribute:: allowed_locator
                                
                                	Against sites' allowed\-locators policy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "validate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                    ])
                                    self.allowed_locator = None
                                    self._segment_path = lambda: "source"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/map-server/map-register/validate/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                class PathMtuDiscovery(Entity):
                    """
                    Path MTU discovery
                    
                    .. attribute:: max
                    
                    	Upper bound on the path MTU accepted
                    	**type**\: int
                    
                    	**range:** 68..65535
                    
                    .. attribute:: min
                    
                    	Lower bound on the path MTU accepted
                    	**type**\: int
                    
                    	**range:** 68..65535
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.PathMtuDiscovery, self).__init__()

                        self.yang_name = "path-mtu-discovery"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                            ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                        ])
                        self.max = None
                        self.min = None
                        self._segment_path = lambda: "path-mtu-discovery"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.PathMtuDiscovery, ['max', 'min'], name, value)


                class RouteExport(Entity):
                    """
                    Export routes into RIB from LISP
                    
                    .. attribute:: site_registrations
                    
                    	Export LISP site registrations to RIB
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: away_eids
                    
                    	Export LISP away EIDs to RIB
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.RouteExport, self).__init__()

                        self.yang_name = "route-export"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                        ])
                        self.site_registrations = None
                        self.away_eids = None
                        self._segment_path = lambda: "route-export"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                class RouteImport(Entity):
                    """
                    Import RIB routes by a routing protocol into LISP
                    
                    .. attribute:: database
                    
                    	Use RIB routes to define local EID database entries
                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database>`
                    
                    .. attribute:: map_cache
                    
                    	Use RIB routes to define EID address space in map\-cache
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.RouteImport, self).__init__()

                        self.yang_name = "route-import"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.Ipv6.RouteImport.MapCache))])
                        self._leafs = OrderedDict()

                        self.database = Native.Router.Lisp.Ipv6.RouteImport.Database()
                        self.database.parent = self
                        self._children_name_map["database"] = "database"

                        self.map_cache = Native.Router.Lisp.Ipv6.RouteImport.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"
                        self._segment_path = lambda: "route-import"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport, [], name, value)


                    class Database(Entity):
                        """
                        Use RIB routes to define local EID database entries
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Connected>`
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Isis>`
                        
                        .. attribute:: maximum_prefix
                        
                        	Maximum number of prefixes to pick up from the RIB
                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.MaximumPrefix>`
                        
                        .. attribute:: ospf
                        
                        	Open Shortest Path First (OSPF)
                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Ospf>`
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Rip>`
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Static>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.RouteImport.Database, self).__init__()

                            self.yang_name = "database"
                            self.yang_parent_name = "route-import"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Ipv6.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Ipv6.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Ipv6.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Ipv6.RouteImport.Database.Rip)), ("static", ("static", Native.Router.Lisp.Ipv6.RouteImport.Database.Static))])
                            self._leafs = OrderedDict()

                            self.connected = Native.Router.Lisp.Ipv6.RouteImport.Database.Connected()
                            self.connected.parent = self
                            self._children_name_map["connected"] = "connected"

                            self.maximum_prefix = Native.Router.Lisp.Ipv6.RouteImport.Database.MaximumPrefix()
                            self.maximum_prefix.parent = self
                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                            self.rip = Native.Router.Lisp.Ipv6.RouteImport.Database.Rip()
                            self.rip.parent = self
                            self._children_name_map["rip"] = "rip"

                            self.static = Native.Router.Lisp.Ipv6.RouteImport.Database.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"

                            self.bgp = YList(self)
                            self.eigrp = YList(self)
                            self.isis = YList(self)
                            self.ospf = YList(self)
                            self.ospfv3 = YList(self)
                            self._segment_path = lambda: "database"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database, [], name, value)


                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.Database.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "connected"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Connected, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "connected"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/connected/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.Database.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Isis, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class MaximumPrefix(Entity):
                            """
                            Maximum number of prefixes to pick up from the RIB
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: warning_only
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: warning_only1
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                self.yang_name = "maximum-prefix"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                ])
                                self.number = None
                                self.warning_only = None
                                self.threshold = None
                                self.threshold1 = None
                                self.warning_only1 = None
                                self._segment_path = lambda: "maximum-prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                        class Ospf(Entity):
                            """
                            Open Shortest Path First (OSPF)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                self.yang_name = "ospf"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "ospf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.Database.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Ospfv3, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.Database.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "rip"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Rip, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "rip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/rip/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.Database.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.Lisp.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "static"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Static, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/database/static/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                    class MapCache(Entity):
                        """
                        Use RIB routes to define EID address space in map\-cache
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Connected>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Isis>`
                        
                        .. attribute:: maximum_prefix
                        
                        	Maximum number of prefixes to pick up from the RIB
                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                        
                        .. attribute:: ospf
                        
                        	Open Shortest Path First (OSPF)
                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospf>`
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Rip>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Static>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.RouteImport.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "route-import"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Static))])
                            self._leafs = OrderedDict()

                            self.connected = None
                            self._children_name_map["connected"] = "connected"

                            self.maximum_prefix = Native.Router.Lisp.Ipv6.RouteImport.MapCache.MaximumPrefix()
                            self.maximum_prefix.parent = self
                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                            self.rip = None
                            self._children_name_map["rip"] = "rip"

                            self.static = None
                            self._children_name_map["static"] = "static"

                            self.bgp = YList(self)
                            self.eigrp = YList(self)
                            self.isis = YList(self)
                            self.ospf = YList(self)
                            self.ospfv3 = YList(self)
                            self._segment_path = lambda: "map-cache"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache, [], name, value)


                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "connected"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "connected"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/connected/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                        class MaximumPrefix(Entity):
                            """
                            Maximum number of prefixes to pick up from the RIB
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: warning_only
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: warning_only1
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                self.yang_name = "maximum-prefix"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                ])
                                self.number = None
                                self.warning_only = None
                                self.threshold = None
                                self.threshold1 = None
                                self.warning_only1 = None
                                self._segment_path = lambda: "maximum-prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                        class Ospf(Entity):
                            """
                            Open Shortest Path First (OSPF)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                self.yang_name = "ospf"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "ospf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "rip"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Rip, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "rip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/rip/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "static"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Static, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/route-import/map-cache/static/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                class SiteRegistration(Entity):
                    """
                    Site registrations configuration for a given instance\-id
                    
                    .. attribute:: limit
                    
                    	Maximum number of site registrations for a given instance\-id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: warning_threshold
                    
                    	Warning threshold to issue system logging
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.SiteRegistration, self).__init__()

                        self.yang_name = "site-registration"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                        ])
                        self.limit = None
                        self.warning_threshold = None
                        self._segment_path = lambda: "site-registration"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                class SolicitMapRequest(Entity):
                    """
                    Configure Solicit\-Map\-Request handling
                    
                    .. attribute:: ignore
                    
                    	Ignore SMR bit in incoming Map\-Requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: max_per_entry
                    
                    	Maximum number of SMRs for addresses under a map\-cache entry
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    .. attribute:: suppression_time
                    
                    	How long to suppress repeated SMRs for the same address
                    	**type**\: int
                    
                    	**range:** 1..600
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.SolicitMapRequest, self).__init__()

                        self.yang_name = "solicit-map-request"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                        ])
                        self.ignore = None
                        self.max_per_entry = None
                        self.suppression_time = None
                        self._segment_path = lambda: "solicit-map-request"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                class SourceLocator(Entity):
                    """
                    Source Locator configuration
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.SourceLocator.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.SourceLocator.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.SourceLocator.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Ipv6.SourceLocator.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.SourceLocator, self).__init__()

                        self.yang_name = "source-locator"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Lisp.Ipv6.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Lisp.Ipv6.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Lisp.Ipv6.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Lisp.Ipv6.SourceLocator.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Router.Lisp.Ipv6.SourceLocator.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Router.Lisp.Ipv6.SourceLocator.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Router.Lisp.Ipv6.SourceLocator.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Router.Lisp.Ipv6.SourceLocator.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "source-locator"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.SourceLocator.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/source-locator/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.SourceLocator.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/source-locator/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.SourceLocator.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/source-locator/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Ipv6.SourceLocator.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/source-locator/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Ipv6.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                class UsePetr(Entity):
                    """
                    Encapsulate to Proxy ETR when matching forward\-native entry
                    
                    .. attribute:: locator_address  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: priority
                    
                    	Configures which Locators from a set are preferred
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: weight
                    
                    	Traffic load\-spreading among Locators
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Ipv6.UsePetr, self).__init__()

                        self.yang_name = "use-petr"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['locator_address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                        ])
                        self.locator_address = None
                        self.priority = None
                        self.weight = None
                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Ipv6.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


            class LocReachAlgorithm(Entity):
                """
                Configure locator reachability algorithm
                
                .. attribute:: lsb_reports
                
                	Configure data packet LSB report handling
                	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.LocReachAlgorithm.LsbReports>`
                
                .. attribute:: rloc_probing
                
                	Probe high priority RLOCs with Map\-Requests as last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.LocReachAlgorithm, self).__init__()

                    self.yang_name = "loc-reach-algorithm"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.Lisp.LocReachAlgorithm.LsbReports))])
                    self._leafs = OrderedDict([
                        ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                    ])
                    self.rloc_probing = None

                    self.lsb_reports = Native.Router.Lisp.LocReachAlgorithm.LsbReports()
                    self.lsb_reports.parent = self
                    self._children_name_map["lsb_reports"] = "lsb-reports"
                    self._segment_path = lambda: "loc-reach-algorithm"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.LocReachAlgorithm, ['rloc_probing'], name, value)


                class LsbReports(Entity):
                    """
                    Configure data packet LSB report handling
                    
                    .. attribute:: do_not_transmit
                    
                    	Force the setting of the encapsulation header L bit to zero
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ignore
                    
                    	Ignore data packet LSB reports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.LocReachAlgorithm.LsbReports, self).__init__()

                        self.yang_name = "lsb-reports"
                        self.yang_parent_name = "loc-reach-algorithm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.do_not_transmit = None
                        self.ignore = None
                        self._segment_path = lambda: "lsb-reports"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/loc-reach-algorithm/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


            class LocatorDown(Entity):
                """
                Manually set locator status to down
                
                .. attribute:: address
                
                	IPv4/6 Locator address to be set down
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ipv4_interface
                
                	Use IPv4 address of interface as locator
                	**type**\: str
                
                .. attribute:: ipv6_interface
                
                	Use IPv6 address of interface as locator
                	**type**\: str
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.LocatorDown, self).__init__()

                    self.yang_name = "locator-down"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                        ('ipv4_interface', (YLeaf(YType.str, 'IPv4-interface'), ['str'])),
                        ('ipv6_interface', (YLeaf(YType.str, 'IPv6-interface'), ['str'])),
                    ])
                    self.address = None
                    self.ipv4_interface = None
                    self.ipv6_interface = None
                    self._segment_path = lambda: "locator-down"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.LocatorDown, ['address', 'ipv4_interface', 'ipv6_interface'], name, value)


            class LocatorTable(Entity):
                """
                Specify the RLOC table
                
                .. attribute:: vrf_name
                
                	
                	**type**\: str
                
                .. attribute:: default
                
                	Default VRF
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vrf
                
                	VRF name
                	**type**\: str
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.LocatorTable, self).__init__()

                    self.yang_name = "locator-table"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ])
                    self.vrf_name = None
                    self.default = None
                    self.vrf = None
                    self._segment_path = lambda: "locator-table"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.LocatorTable, ['vrf_name', 'default', 'vrf'], name, value)


            class MapRequest(Entity):
                """
                Configure map\-request handling
                
                .. attribute:: itr_rlocs
                
                	Configure to use the specified RLOC set as ITR RLOC in map\-request
                	**type**\: str
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.MapRequest, self).__init__()

                    self.yang_name = "map-request"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('itr_rlocs', (YLeaf(YType.str, 'itr-rlocs'), ['str'])),
                    ])
                    self.itr_rlocs = None
                    self._segment_path = lambda: "map-request"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.MapRequest, ['itr_rlocs'], name, value)


            class MapServer(Entity):
                """
                Map\-Server commands
                
                .. attribute:: rloc
                
                	EID instance RLOC membership
                	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.MapServer.Rloc>`
                
                .. attribute:: site_registration
                
                	Map\-server site registration options
                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.MapServer.SiteRegistration>`
                
                .. attribute:: nmr
                
                	Map\-server negative map\-reply optio
                	**type**\:  :py:class:`Nmr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.MapServer.Nmr>`
                
                .. attribute:: session
                
                	Map\-server session
                	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.MapServer.Session>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.MapServer, self).__init__()

                    self.yang_name = "map-server"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.Lisp.MapServer.SiteRegistration)), ("nmr", ("nmr", Native.Router.Lisp.MapServer.Nmr)), ("session", ("session", Native.Router.Lisp.MapServer.Session))])
                    self._leafs = OrderedDict()

                    self.rloc = Native.Router.Lisp.MapServer.Rloc()
                    self.rloc.parent = self
                    self._children_name_map["rloc"] = "rloc"

                    self.site_registration = Native.Router.Lisp.MapServer.SiteRegistration()
                    self.site_registration.parent = self
                    self._children_name_map["site_registration"] = "site-registration"

                    self.nmr = Native.Router.Lisp.MapServer.Nmr()
                    self.nmr.parent = self
                    self._children_name_map["nmr"] = "nmr"

                    self.session = Native.Router.Lisp.MapServer.Session()
                    self.session.parent = self
                    self._children_name_map["session"] = "session"
                    self._segment_path = lambda: "map-server"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.MapServer, [], name, value)


                class Rloc(Entity):
                    """
                    EID instance RLOC membership
                    
                    .. attribute:: members
                    
                    	EID instance RLOC membership
                    	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.MapServer.Rloc.Members>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.MapServer.Rloc, self).__init__()

                        self.yang_name = "rloc"
                        self.yang_parent_name = "map-server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("members", ("members", Native.Router.Lisp.MapServer.Rloc.Members))])
                        self._leafs = OrderedDict()

                        self.members = Native.Router.Lisp.MapServer.Rloc.Members()
                        self.members.parent = self
                        self._children_name_map["members"] = "members"
                        self._segment_path = lambda: "rloc"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/map-server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.MapServer.Rloc, [], name, value)


                    class Members(Entity):
                        """
                        EID instance RLOC membership
                        
                        .. attribute:: distribute
                        
                        	EID instance RLOC membership distribution
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: modify_discovered
                        
                        	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                        	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.MapServer.Rloc.Members.ModifyDiscovered>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.MapServer.Rloc.Members, self).__init__()

                            self.yang_name = "members"
                            self.yang_parent_name = "rloc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.Lisp.MapServer.Rloc.Members.ModifyDiscovered))])
                            self._leafs = OrderedDict([
                                ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                            ])
                            self.distribute = None

                            self.modify_discovered = Native.Router.Lisp.MapServer.Rloc.Members.ModifyDiscovered()
                            self.modify_discovered.parent = self
                            self._children_name_map["modify_discovered"] = "modify-discovered"
                            self._segment_path = lambda: "members"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/map-server/rloc/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.MapServer.Rloc.Members, ['distribute'], name, value)


                        class ModifyDiscovered(Entity):
                            """
                            Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                            
                            .. attribute:: operator
                            
                            	
                            	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                            
                            .. attribute:: locator_set
                            
                            	Locator set from which to get member RLOC addresses
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                self.yang_name = "modify-discovered"
                                self.yang_parent_name = "members"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                ])
                                self.operator = None
                                self.locator_set = None
                                self._segment_path = lambda: "modify-discovered"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/map-server/rloc/members/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                            class Operator(Enum):
                                """
                                Operator (Enum Class)

                                .. data:: add = 0

                                .. data:: override = 1

                                """

                                add = Enum.YLeaf(0, "add")

                                override = Enum.YLeaf(1, "override")



                class SiteRegistration(Entity):
                    """
                    Map\-server site registration options
                    
                    .. attribute:: limit
                    
                    	Maximum number of site registrations as a result of accept\-more\-specifics
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: warning_threshold
                    
                    	Warning threshold to issue system logging
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.MapServer.SiteRegistration, self).__init__()

                        self.yang_name = "site-registration"
                        self.yang_parent_name = "map-server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                        ])
                        self.limit = None
                        self.warning_threshold = None
                        self._segment_path = lambda: "site-registration"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/map-server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                class Nmr(Entity):
                    """
                    Map\-server negative map\-reply optio
                    
                    .. attribute:: non_site_ttl
                    
                    	Negative map\-reply TTL for non\-site EID
                    	**type**\: int
                    
                    	**range:** 1..1440
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.MapServer.Nmr, self).__init__()

                        self.yang_name = "nmr"
                        self.yang_parent_name = "map-server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('non_site_ttl', (YLeaf(YType.uint16, 'non-site-ttl'), ['int'])),
                        ])
                        self.non_site_ttl = None
                        self._segment_path = lambda: "nmr"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/map-server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.MapServer.Nmr, ['non_site_ttl'], name, value)


                class Session(Entity):
                    """
                    Map\-server session
                    
                    .. attribute:: passive_open
                    
                    	Open passive TCP sockets to listen for incoming connections
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.MapServer.Session, self).__init__()

                        self.yang_name = "session"
                        self.yang_parent_name = "map-server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('passive_open', (YLeaf(YType.str, 'passive-open'), ['str'])),
                        ])
                        self.passive_open = None
                        self._segment_path = lambda: "session"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/map-server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.MapServer.Session, ['passive_open'], name, value)


            class OtherXtrProbe(Entity):
                """
                Configure parameters for probing of other xTRs in our site
                
                .. attribute:: period
                
                	Period between probes in seconds
                	**type**\: int
                
                	**range:** 5..900
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.OtherXtrProbe, self).__init__()

                    self.yang_name = "other-xtr-probe"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                    ])
                    self.period = None
                    self._segment_path = lambda: "other-xtr-probe"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.OtherXtrProbe, ['period'], name, value)


            class RemoteRlocProbe(Entity):
                """
                Configure parameters for probing of remote RLOCs
                
                .. attribute:: on_membership_change
                
                	Trigger probing upon membership changes for remote RLOC
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: on_route_change
                
                	Trigger probing upon routing changes for remote RLOC
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.RemoteRlocProbe, self).__init__()

                    self.yang_name = "remote-rloc-probe"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                        ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                    ])
                    self.on_membership_change = None
                    self.on_route_change = None
                    self._segment_path = lambda: "remote-rloc-probe"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


            class EidTable(Entity):
                """
                Configure an EID instance for a VRF
                
                .. attribute:: instance_list
                
                	
                	**type**\: list of  		 :py:class:`InstanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.EidTable, self).__init__()

                    self.yang_name = "eid-table"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance-list", ("instance_list", Native.Router.Lisp.EidTable.InstanceList))])
                    self._leafs = OrderedDict()

                    self.instance_list = YList(self)
                    self._segment_path = lambda: "eid-table"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.EidTable, [], name, value)


                class InstanceList(Entity):
                    """
                    
                    
                    .. attribute:: instance_id  (key)
                    
                    	EID instance\-ID
                    	**type**\: int
                    
                    	**range:** 0..16777214
                    
                    .. attribute:: vrf_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	Default VRF
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: database_mapping
                    
                    	Configures Locator addresses for an ETR
                    	**type**\: list of  		 :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.DatabaseMapping>`
                    
                    .. attribute:: dynamic_eid
                    
                    	Configure a dynamic EID
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.DynamicEid>`
                    
                    .. attribute:: alt
                    
                    	LISP Alternative Topology, LISP\-ALT
                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Alt>`
                    
                    .. attribute:: control_packet
                    
                    	Configure control packet tx option
                    	**type**\:  :py:class:`ControlPacket <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.ControlPacket>`
                    
                    .. attribute:: ddt
                    
                    	Delegated Database Tree (DDT) mapping system
                    	**type**\:  :py:class:`Ddt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ddt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: decapsulation
                    
                    	Decapsulation behavior (e.g. filters)
                    	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Decapsulation>`
                    
                    .. attribute:: disable_ttl_propagate
                    
                    	Disable ttl propagation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Etr>`
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address family
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address family
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6>`
                    
                    .. attribute:: loc_reach_algorithm
                    
                    	Configure locator reachability algorithm
                    	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.LocReachAlgorithm>`
                    
                    .. attribute:: locator_down
                    
                    	Manually set locator status to down
                    	**type**\:  :py:class:`LocatorDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.LocatorDown>`
                    
                    .. attribute:: locator_table
                    
                    	Specify the RLOC table
                    	**type**\:  :py:class:`LocatorTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.LocatorTable>`
                    
                    .. attribute:: map_request
                    
                    	Configure map\-request handling
                    	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.MapRequest>`
                    
                    .. attribute:: map_server
                    
                    	Map\-Server commands
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.MapServer>`
                    
                    .. attribute:: other_xtr_probe
                    
                    	Configure parameters for probing of other xTRs in our site
                    	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.OtherXtrProbe>`
                    
                    .. attribute:: remote_rloc_probe
                    
                    	Configure parameters for probing of remote RLOCs
                    	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.RemoteRlocProbe>`
                    
                    .. attribute:: map_cache
                    
                    	Configures static EID\-to\-RLOC mappings for an ITR
                    	**type**\: list of  		 :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.MapCache>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.EidTable.InstanceList, self).__init__()

                        self.yang_name = "instance-list"
                        self.yang_parent_name = "eid-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['instance_id']
                        self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.EidTable.InstanceList.DatabaseMapping)), ("dynamic-eid", ("dynamic_eid", Native.Router.Lisp.EidTable.InstanceList.DynamicEid)), ("alt", ("alt", Native.Router.Lisp.EidTable.InstanceList.Alt)), ("control-packet", ("control_packet", Native.Router.Lisp.EidTable.InstanceList.ControlPacket)), ("ddt", ("ddt", Native.Router.Lisp.EidTable.InstanceList.Ddt)), ("decapsulation", ("decapsulation", Native.Router.Lisp.EidTable.InstanceList.Decapsulation)), ("etr", ("etr", Native.Router.Lisp.EidTable.InstanceList.Etr)), ("ipv4", ("ipv4", Native.Router.Lisp.EidTable.InstanceList.Ipv4)), ("ipv6", ("ipv6", Native.Router.Lisp.EidTable.InstanceList.Ipv6)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.Lisp.EidTable.InstanceList.LocReachAlgorithm)), ("locator-down", ("locator_down", Native.Router.Lisp.EidTable.InstanceList.LocatorDown)), ("locator-table", ("locator_table", Native.Router.Lisp.EidTable.InstanceList.LocatorTable)), ("map-request", ("map_request", Native.Router.Lisp.EidTable.InstanceList.MapRequest)), ("map-server", ("map_server", Native.Router.Lisp.EidTable.InstanceList.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.Lisp.EidTable.InstanceList.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.Lisp.EidTable.InstanceList.RemoteRlocProbe)), ("map-cache", ("map_cache", Native.Router.Lisp.EidTable.InstanceList.MapCache))])
                        self._leafs = OrderedDict([
                            ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                        ])
                        self.instance_id = None
                        self.vrf_name = None
                        self.default = None
                        self.vrf = None
                        self.disable_ttl_propagate = None

                        self.alt = Native.Router.Lisp.EidTable.InstanceList.Alt()
                        self.alt.parent = self
                        self._children_name_map["alt"] = "alt"

                        self.control_packet = Native.Router.Lisp.EidTable.InstanceList.ControlPacket()
                        self.control_packet.parent = self
                        self._children_name_map["control_packet"] = "control-packet"

                        self.ddt = None
                        self._children_name_map["ddt"] = "ddt"

                        self.decapsulation = Native.Router.Lisp.EidTable.InstanceList.Decapsulation()
                        self.decapsulation.parent = self
                        self._children_name_map["decapsulation"] = "decapsulation"

                        self.etr = Native.Router.Lisp.EidTable.InstanceList.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.ipv4 = Native.Router.Lisp.EidTable.InstanceList.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Router.Lisp.EidTable.InstanceList.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.loc_reach_algorithm = Native.Router.Lisp.EidTable.InstanceList.LocReachAlgorithm()
                        self.loc_reach_algorithm.parent = self
                        self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                        self.locator_down = Native.Router.Lisp.EidTable.InstanceList.LocatorDown()
                        self.locator_down.parent = self
                        self._children_name_map["locator_down"] = "locator-down"

                        self.locator_table = Native.Router.Lisp.EidTable.InstanceList.LocatorTable()
                        self.locator_table.parent = self
                        self._children_name_map["locator_table"] = "locator-table"

                        self.map_request = Native.Router.Lisp.EidTable.InstanceList.MapRequest()
                        self.map_request.parent = self
                        self._children_name_map["map_request"] = "map-request"

                        self.map_server = Native.Router.Lisp.EidTable.InstanceList.MapServer()
                        self.map_server.parent = self
                        self._children_name_map["map_server"] = "map-server"

                        self.other_xtr_probe = Native.Router.Lisp.EidTable.InstanceList.OtherXtrProbe()
                        self.other_xtr_probe.parent = self
                        self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                        self.remote_rloc_probe = Native.Router.Lisp.EidTable.InstanceList.RemoteRlocProbe()
                        self.remote_rloc_probe.parent = self
                        self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                        self.database_mapping = YList(self)
                        self.dynamic_eid = YList(self)
                        self.map_cache = YList(self)
                        self._segment_path = lambda: "instance-list" + "[instance-id='" + str(self.instance_id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/eid-table/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList, ['instance_id', 'vrf_name', 'default', 'vrf', 'disable_ttl_propagate'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Configures Locator addresses for an ETR
                        
                        .. attribute:: eid_prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: locator_set
                        
                        	Use locators defined by locator\-set
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['eid_prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                            ])
                            self.eid_prefix = None
                            self.locator_set = None
                            self._segment_path = lambda: "database-mapping" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.DatabaseMapping, ['eid_prefix', 'locator_set'], name, value)


                    class DynamicEid(Entity):
                        """
                        Configure a dynamic EID
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: database_mapping
                        
                        	Configures EID\-prefix and locator\-set for dynamic\-EID
                        	**type**\: list of  		 :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.DynamicEid.DatabaseMapping>`
                        
                        .. attribute:: eid_notify
                        
                        	Configure options for sending/receiving EID\-notify
                        	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify>`
                        
                        .. attribute:: map_notify_group
                        
                        	Multicast group which to send map\-notifies to
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.DynamicEid.MapServer>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.EidTable.InstanceList.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.Lisp.EidTable.InstanceList.DynamicEid.MapServer))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                            ])
                            self.name = None
                            self.map_notify_group = None

                            self.eid_notify = Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify()
                            self.eid_notify.parent = self
                            self._children_name_map["eid_notify"] = "eid-notify"

                            self.database_mapping = YList(self)
                            self.map_server = YList(self)
                            self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.DynamicEid, ['name', 'map_notify_group'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Configures EID\-prefix and locator\-set for dynamic\-EID
                            
                            .. attribute:: eid_prefix  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            .. attribute:: locator_set
                            
                            	Use locators defined by locator\-set
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['eid_prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                ])
                                self.eid_prefix = None
                                self.locator_set = None
                                self._segment_path = lambda: "database-mapping" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.DatabaseMapping, ['eid_prefix', 'locator_set'], name, value)


                        class EidNotify(Entity):
                            """
                            Configure options for sending/receiving EID\-notify
                            
                            .. attribute:: authentication_key
                            
                            	Authentication key used for validating received EID\-notify
                            	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey>`
                            
                            .. attribute:: gateway_key
                            
                            	
                            	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify, self).__init__()

                                self.yang_name = "eid-notify"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey))])
                                self._leafs = OrderedDict()

                                self.authentication_key = Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey()
                                self.authentication_key.parent = self
                                self._children_name_map["authentication_key"] = "authentication-key"

                                self.gateway_key = YList(self)
                                self._segment_path = lambda: "eid-notify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify, [], name, value)


                            class AuthenticationKey(Entity):
                                """
                                Authentication key used for validating received EID\-notify
                                
                                .. attribute:: ak_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: ak_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: unc_pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                    self.yang_name = "authentication-key"
                                    self.yang_parent_name = "eid-notify"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                    ])
                                    self.ak_0 = None
                                    self.ak_6 = None
                                    self.unc_pwd = None
                                    self._segment_path = lambda: "authentication-key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey, ['ak_0', 'ak_6', 'unc_pwd'], name, value)


                            class GatewayKey(Entity):
                                """
                                
                                
                                .. attribute:: gateway_ip  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ak_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: ak_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: unc_pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: hash_function
                                
                                	EID\-notify authentication type
                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey.HashFunction>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                    self.yang_name = "gateway-key"
                                    self.yang_parent_name = "eid-notify"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['gateway_ip']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey.HashFunction')])),
                                    ])
                                    self.gateway_ip = None
                                    self.ak_0 = None
                                    self.ak_6 = None
                                    self.unc_pwd = None
                                    self.hash_function = None
                                    self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey, ['gateway_ip', 'ak_0', 'ak_6', 'unc_pwd', 'hash_function'], name, value)

                                class HashFunction(Enum):
                                    """
                                    HashFunction (Enum Class)

                                    EID\-notify authentication type

                                    .. data:: sha1 = 0

                                    .. data:: sha2 = 1

                                    """

                                    sha1 = Enum.YLeaf(0, "sha1")

                                    sha2 = Enum.YLeaf(1, "sha2")



                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.DynamicEid.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.EidTable.InstanceList.DynamicEid.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip = None
                                self.proxy_reply = None

                                self.key = Native.Router.Lisp.EidTable.InstanceList.DynamicEid.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip='" + str(self.ip) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.MapServer, ['ip', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: key_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: key_7
                                
                                	The HIDDEN password
                                	**type**\: str
                                
                                .. attribute:: pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: hash_function
                                
                                	Map\-Register authentication type
                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.DynamicEid.MapServer.Key.HashFunction>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                        ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                        ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                        ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.EidTable.InstanceList.DynamicEid.MapServer.Key.HashFunction')])),
                                    ])
                                    self.key_0 = None
                                    self.key_6 = None
                                    self.key_7 = None
                                    self.pwd = None
                                    self.hash_function = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.DynamicEid.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd', 'hash_function'], name, value)

                                class HashFunction(Enum):
                                    """
                                    HashFunction (Enum Class)

                                    Map\-Register authentication type

                                    .. data:: sha1 = 0

                                    .. data:: sha2 = 1

                                    """

                                    sha1 = Enum.YLeaf(0, "sha1")

                                    sha2 = Enum.YLeaf(1, "sha2")



                    class Alt(Entity):
                        """
                        LISP Alternative Topology, LISP\-ALT
                        
                        .. attribute:: summary_route
                        
                        	Summary route to install into the ALT table
                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Alt.SummaryRoute>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.Alt, self).__init__()

                            self.yang_name = "alt"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.Lisp.EidTable.InstanceList.Alt.SummaryRoute))])
                            self._leafs = OrderedDict()

                            self.summary_route = YList(self)
                            self._segment_path = lambda: "alt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Alt, [], name, value)


                        class SummaryRoute(Entity):
                            """
                            Summary route to install into the ALT table
                            
                            .. attribute:: eid_prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: route_tag
                            
                            	ALT RIB route tag for EID prefix
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Alt.SummaryRoute, self).__init__()

                                self.yang_name = "summary-route"
                                self.yang_parent_name = "alt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['eid_prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.eid_prefix = None
                                self.route_tag = None
                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                    class ControlPacket(Entity):
                        """
                        Configure control packet tx option
                        
                        .. attribute:: mtu
                        
                        	Configure control packet MTU
                        	**type**\: int
                        
                        	**range:** 304..10000
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.ControlPacket, self).__init__()

                            self.yang_name = "control-packet"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.mtu = None
                            self._segment_path = lambda: "control-packet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.ControlPacket, ['mtu'], name, value)


                    class Ddt(Entity):
                        """
                        Delegated Database Tree (DDT) mapping system
                        
                        .. attribute:: authoritative
                        
                        	DDT authoritative prefix
                        	**type**\:  :py:class:`Authoritative <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative>`
                        
                        .. attribute:: cache_limit
                        
                        	DDT resolver cache entry limit
                        	**type**\: int
                        
                        	**range:** 1..100000
                        
                        .. attribute:: root
                        
                        	DDT root node
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.Ddt, self).__init__()

                            self.yang_name = "ddt"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authoritative", ("authoritative", Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cache_limit', (YLeaf(YType.uint32, 'cache-limit'), ['int'])),
                                ('root', (YLeaf(YType.str, 'root'), ['str','str'])),
                            ])
                            self.cache_limit = None
                            self.root = None

                            self.authoritative = Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative()
                            self.authoritative.parent = self
                            self._children_name_map["authoritative"] = "authoritative"
                            self._segment_path = lambda: "ddt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ddt, ['cache_limit', 'root'], name, value)


                        class Authoritative(Entity):
                            """
                            DDT authoritative prefix
                            
                            .. attribute:: instance_id_eid_prefix_list
                            
                            	
                            	**type**\: list of  		 :py:class:`InstanceIdEidPrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList>`
                            
                            .. attribute:: instance_id_list
                            
                            	
                            	**type**\: list of  		 :py:class:`InstanceIdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative, self).__init__()

                                self.yang_name = "authoritative"
                                self.yang_parent_name = "ddt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("instance-id-eid-prefix-list", ("instance_id_eid_prefix_list", Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList)), ("instance-id-list", ("instance_id_list", Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList))])
                                self._leafs = OrderedDict()

                                self.instance_id_eid_prefix_list = YList(self)
                                self.instance_id_list = YList(self)
                                self._segment_path = lambda: "authoritative"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative, [], name, value)


                            class InstanceIdEidPrefixList(Entity):
                                """
                                
                                
                                .. attribute:: instance_id  (key)
                                
                                	EID instance\-ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: eid_prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: delegate
                                
                                	DDT delegation to a child DDT node or map\-server
                                	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate>`
                                
                                .. attribute:: map_server_peer
                                
                                	Peer map\-servers that are authoritative for the same EID prefixes
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList, self).__init__()

                                    self.yang_name = "instance-id-eid-prefix-list"
                                    self.yang_parent_name = "authoritative"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['instance_id','eid_prefix']
                                    self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate))])
                                    self._leafs = OrderedDict([
                                        ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                        ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                    ])
                                    self.instance_id = None
                                    self.eid_prefix = None
                                    self.map_server_peer = None

                                    self.delegate = Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate()
                                    self.delegate.parent = self
                                    self._children_name_map["delegate"] = "delegate"
                                    self._segment_path = lambda: "instance-id-eid-prefix-list" + "[instance-id='" + str(self.instance_id) + "']" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList, ['instance_id', 'eid_prefix', 'map_server_peer'], name, value)


                                class Delegate(Entity):
                                    """
                                    DDT delegation to a child DDT node or map\-server
                                    
                                    .. attribute:: eid_prefix
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: instance_id
                                    
                                    	EID instance\-ID
                                    	**type**\: str
                                    
                                    .. attribute:: to
                                    
                                    	DDT delegation to a child DDT node or map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ip_address
                                    
                                    	IPv4/6 Child or map\-server node locator address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: map_server
                                    
                                    	Delegation points to a map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, self).__init__()

                                        self.yang_name = "delegate"
                                        self.yang_parent_name = "instance-id-eid-prefix-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                            ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                            ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.instance_id = None
                                        self.to = None
                                        self.ip_address = None
                                        self.map_server = None
                                        self._segment_path = lambda: "delegate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                            class InstanceIdList(Entity):
                                """
                                
                                
                                .. attribute:: instance_id  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: delegate
                                
                                	DDT delegation to a child DDT node or map\-server
                                	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate>`
                                
                                .. attribute:: map_server_peer
                                
                                	Peer map\-servers that are authoritative for the same EID prefixes
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList, self).__init__()

                                    self.yang_name = "instance-id-list"
                                    self.yang_parent_name = "authoritative"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['instance_id']
                                    self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate))])
                                    self._leafs = OrderedDict([
                                        ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                        ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                    ])
                                    self.instance_id = None
                                    self.map_server_peer = None

                                    self.delegate = Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate()
                                    self.delegate.parent = self
                                    self._children_name_map["delegate"] = "delegate"
                                    self._segment_path = lambda: "instance-id-list" + "[instance-id='" + str(self.instance_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList, ['instance_id', 'map_server_peer'], name, value)


                                class Delegate(Entity):
                                    """
                                    DDT delegation to a child DDT node or map\-server
                                    
                                    .. attribute:: eid_prefix
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: instance_id
                                    
                                    	EID instance\-ID
                                    	**type**\: str
                                    
                                    .. attribute:: to
                                    
                                    	DDT delegation to a child DDT node or map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ip_address
                                    
                                    	IPv4/6 Child or map\-server node locator address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: map_server
                                    
                                    	Delegation points to a map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate, self).__init__()

                                        self.yang_name = "delegate"
                                        self.yang_parent_name = "instance-id-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                            ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                            ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.instance_id = None
                                        self.to = None
                                        self.ip_address = None
                                        self.map_server = None
                                        self._segment_path = lambda: "delegate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                    class Decapsulation(Entity):
                        """
                        Decapsulation behavior (e.g. filters)
                        
                        .. attribute:: filter
                        
                        	Filters traffic
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.Decapsulation, self).__init__()

                            self.yang_name = "decapsulation"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "decapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Decapsulation, [], name, value)


                        class Filter(Entity):
                            """
                            Filters traffic
                            
                            .. attribute:: rloc
                            
                            	Filter based on Routing Locator (RLOC) in packet header
                            	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter.Rloc>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "decapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter.Rloc))])
                                self._leafs = OrderedDict()

                                self.rloc = Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter.Rloc()
                                self.rloc.parent = self
                                self._children_name_map["rloc"] = "rloc"
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter, [], name, value)


                            class Rloc(Entity):
                                """
                                Filter based on Routing Locator (RLOC) in packet header
                                
                                .. attribute:: source
                                
                                	Filters traffic based on RLOC source address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter.Rloc, self).__init__()

                                    self.yang_name = "rloc"
                                    self.yang_parent_name = "filter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "rloc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter.Rloc, [], name, value)


                                class Source(Entity):
                                    """
                                    Filters traffic based on RLOC source address
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator\-set Name
                                    	**type**\: str
                                    
                                    .. attribute:: member
                                    
                                    	Members learned from map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "rloc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                        ])
                                        self.locator_set = None
                                        self.member = None
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Etr.MapServer>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.EidTable.InstanceList.Etr.MapServer))])
                            self._leafs = OrderedDict()

                            self.map_server = Native.Router.Lisp.EidTable.InstanceList.Etr.MapServer()
                            self.map_server.parent = self
                            self._children_name_map["map_server"] = "map-server"
                            self._segment_path = lambda: "etr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Etr, [], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: source_address
                            
                            	Configures map server source address
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                ])
                                self.source_address = None
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Etr.MapServer, ['source_address'], name, value)


                    class Ipv4(Entity):
                        """
                        IPv4 address family
                        
                        .. attribute:: alt_vrf
                        
                        	Activate LISP\-ALT functionality in VRF
                        	**type**\: str
                        
                        	**status**\: deprecated
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.DatabaseMapping>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.Distance>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.ItrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.EtrEnable>`
                        
                        .. attribute:: locator
                        
                        	Locator related configuration
                        	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.Locator>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCache>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCacheLimit>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCachePersistent>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: path_mtu_discovery
                        
                        	Path MTU discovery
                        	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.PathMtuDiscovery>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\: union of the below types:
                        
                        		**type**\: list of str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: list of str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteExport>`
                        
                        .. attribute:: route_import
                        
                        	Import RIB routes by a routing protocol into LISP
                        	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.SolicitMapRequest>`
                        
                        .. attribute:: source_locator
                        
                        	Source Locator configuration
                        	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.UsePetr>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.EidTable.InstanceList.Ipv4.DatabaseMapping)), ("distance", ("distance", Native.Router.Lisp.EidTable.InstanceList.Ipv4.Distance)), ("itr", ("itr", Native.Router.Lisp.EidTable.InstanceList.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.EidTable.InstanceList.Ipv4.ItrEnable)), ("etr", ("etr", Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr)), ("etr-enable", ("etr_enable", Native.Router.Lisp.EidTable.InstanceList.Ipv4.EtrEnable)), ("locator", ("locator", Native.Router.Lisp.EidTable.InstanceList.Ipv4.Locator)), ("map-cache", ("map_cache", Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Lisp.EidTable.InstanceList.Ipv4.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteExport)), ("route-import", ("route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport)), ("site-registration", ("site_registration", Native.Router.Lisp.EidTable.InstanceList.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.EidTable.InstanceList.Ipv4.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator)), ("use-petr", ("use_petr", Native.Router.Lisp.EidTable.InstanceList.Ipv4.UsePetr))])
                            self._leafs = OrderedDict([
                                ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                            ])
                            self.alt_vrf = None
                            self.map_request_source = None
                            self.proxy_etr = None
                            self.proxy_itr = []
                            self.sgt = None

                            self.database_mapping = Native.Router.Lisp.EidTable.InstanceList.Ipv4.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.distance = Native.Router.Lisp.EidTable.InstanceList.Ipv4.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.itr = Native.Router.Lisp.EidTable.InstanceList.Ipv4.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.Lisp.EidTable.InstanceList.Ipv4.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr = Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.etr_enable = Native.Router.Lisp.EidTable.InstanceList.Ipv4.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.locator = Native.Router.Lisp.EidTable.InstanceList.Ipv4.Locator()
                            self.locator.parent = self
                            self._children_name_map["locator"] = "locator"

                            self.map_cache = Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_limit = Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_cache_persistent = Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.path_mtu_discovery = None
                            self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                            self.route_export = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport()
                            self.route_import.parent = self
                            self._children_name_map["route_import"] = "route-import"

                            self.site_registration = Native.Router.Lisp.EidTable.InstanceList.Ipv4.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.Lisp.EidTable.InstanceList.Ipv4.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.source_locator = Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator()
                            self.source_locator.parent = self
                            self._children_name_map["source_locator"] = "source-locator"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.Lisp.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.Itr.MapResolver>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.EidTable.InstanceList.Ipv4.Itr.MapResolver))])
                                self._leafs = OrderedDict()

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Itr, [], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ])
                                    self.ip_addr = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Itr.MapResolver, ['ip_addr'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.ItrEnable, ['itr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr.MapServer))])
                                self._leafs = OrderedDict()

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr, [], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: key_7
                                    
                                    	The HIDDEN password
                                    	**type**\: str
                                    
                                    .. attribute:: pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                            ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                        ])
                                        self.key_0 = None
                                        self.key_6 = None
                                        self.key_7 = None
                                        self.pwd = None
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.EtrEnable, ['etr'], name, value)


                        class Locator(Entity):
                            """
                            Locator related configuration
                            
                            .. attribute:: reachability
                            
                            	Configuration realted to locator reachability
                            	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.Locator.Reachability>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Locator, self).__init__()

                                self.yang_name = "locator"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.Lisp.EidTable.InstanceList.Ipv4.Locator.Reachability))])
                                self._leafs = OrderedDict()

                                self.reachability = Native.Router.Lisp.EidTable.InstanceList.Ipv4.Locator.Reachability()
                                self.reachability.parent = self
                                self._children_name_map["reachability"] = "reachability"
                                self._segment_path = lambda: "locator"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Locator, [], name, value)


                            class Reachability(Entity):
                                """
                                Configuration realted to locator reachability
                                
                                .. attribute:: exclude_default
                                
                                	If a remote RLOC is reached via the default route, treat it as unreachable
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Locator.Reachability, self).__init__()

                                    self.yang_name = "reachability"
                                    self.yang_parent_name = "locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                    ])
                                    self.exclude_default = None
                                    self._segment_path = lambda: "reachability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.Locator.Reachability, ['exclude_default'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None
                                self._segment_path = lambda: "map-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCache, ['site_registration'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapCachePersistent, ['interval'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 prefixes
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 prefixes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                                ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.list = None
                                            self.registered = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class PathMtuDiscovery(Entity):
                            """
                            Path MTU discovery
                            
                            .. attribute:: max
                            
                            	Upper bound on the path MTU accepted
                            	**type**\: int
                            
                            	**range:** 68..65535
                            
                            .. attribute:: min
                            
                            	Lower bound on the path MTU accepted
                            	**type**\: int
                            
                            	**range:** 68..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.PathMtuDiscovery, self).__init__()

                                self.yang_name = "path-mtu-discovery"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                    ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                ])
                                self.max = None
                                self.min = None
                                self._segment_path = lambda: "path-mtu-discovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.PathMtuDiscovery, ['max', 'min'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class RouteImport(Entity):
                            """
                            Import RIB routes by a routing protocol into LISP
                            
                            .. attribute:: database
                            
                            	Use RIB routes to define local EID database entries
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database>`
                            
                            .. attribute:: map_cache
                            
                            	Use RIB routes to define EID address space in map\-cache
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport, self).__init__()

                                self.yang_name = "route-import"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"

                                self.map_cache = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"
                                self._segment_path = lambda: "route-import"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport, [], name, value)


                            class Database(Entity):
                                """
                                Use RIB routes to define local EID database entries
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected>`
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes to pick up from the RIB
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix>`
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip>`
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Static>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "route-import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip)), ("static", ("static", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Static))])
                                    self._leafs = OrderedDict()

                                    self.connected = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected()
                                    self.connected.parent = self
                                    self._children_name_map["connected"] = "connected"

                                    self.maximum_prefix = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.rip = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip()
                                    self.rip.parent = self
                                    self._children_name_map["rip"] = "rip"

                                    self.static = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Static()
                                    self.static.parent = self
                                    self._children_name_map["static"] = "static"

                                    self.bgp = YList(self)
                                    self.eigrp = YList(self)
                                    self.isis = YList(self)
                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "database"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database, [], name, value)


                                class Bgp(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "connected"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes to pick up from the RIB
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold1
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only1
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.warning_only = None
                                        self.threshold = None
                                        self.threshold1 = None
                                        self.warning_only1 = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "rip"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Static, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class MapCache(Entity):
                                """
                                Use RIB routes to define EID address space in map\-cache
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes to pick up from the RIB
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "route-import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static))])
                                    self._leafs = OrderedDict()

                                    self.connected = None
                                    self._children_name_map["connected"] = "connected"

                                    self.maximum_prefix = Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.rip = None
                                    self._children_name_map["rip"] = "rip"

                                    self.static = None
                                    self._children_name_map["static"] = "static"

                                    self.bgp = YList(self)
                                    self.eigrp = YList(self)
                                    self.isis = YList(self)
                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache, [], name, value)


                                class Bgp(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "connected"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes to pick up from the RIB
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold1
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only1
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.warning_only = None
                                        self.threshold = None
                                        self.threshold1 = None
                                        self.warning_only1 = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "rip"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations for a given instance\-id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class SourceLocator(Entity):
                            """
                            Source Locator configuration
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator, self).__init__()

                                self.yang_name = "source-locator"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "source-locator"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	Configures which Locators from a set are preferred
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: weight
                            
                            	Traffic load\-spreading among Locators
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv4.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                ])
                                self.locator_address = None
                                self.priority = None
                                self.weight = None
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv4.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 address family
                        
                        .. attribute:: alt_vrf
                        
                        	Activate LISP\-ALT functionality in VRF
                        	**type**\: str
                        
                        	**status**\: deprecated
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.DatabaseMapping>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.Distance>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.ItrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.EtrEnable>`
                        
                        .. attribute:: locator
                        
                        	Locator related configuration
                        	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.Locator>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCache>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCacheLimit>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCachePersistent>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: path_mtu_discovery
                        
                        	Path MTU discovery
                        	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.PathMtuDiscovery>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\: union of the below types:
                        
                        		**type**\: list of str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: list of str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteExport>`
                        
                        .. attribute:: route_import
                        
                        	Import RIB routes by a routing protocol into LISP
                        	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.SolicitMapRequest>`
                        
                        .. attribute:: source_locator
                        
                        	Source Locator configuration
                        	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.UsePetr>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.Lisp.EidTable.InstanceList.Ipv6.DatabaseMapping)), ("distance", ("distance", Native.Router.Lisp.EidTable.InstanceList.Ipv6.Distance)), ("itr", ("itr", Native.Router.Lisp.EidTable.InstanceList.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.Lisp.EidTable.InstanceList.Ipv6.ItrEnable)), ("etr", ("etr", Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr)), ("etr-enable", ("etr_enable", Native.Router.Lisp.EidTable.InstanceList.Ipv6.EtrEnable)), ("locator", ("locator", Native.Router.Lisp.EidTable.InstanceList.Ipv6.Locator)), ("map-cache", ("map_cache", Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Lisp.EidTable.InstanceList.Ipv6.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteExport)), ("route-import", ("route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport)), ("site-registration", ("site_registration", Native.Router.Lisp.EidTable.InstanceList.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.Lisp.EidTable.InstanceList.Ipv6.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator)), ("use-petr", ("use_petr", Native.Router.Lisp.EidTable.InstanceList.Ipv6.UsePetr))])
                            self._leafs = OrderedDict([
                                ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                            ])
                            self.alt_vrf = None
                            self.map_request_source = None
                            self.proxy_etr = None
                            self.proxy_itr = []
                            self.sgt = None

                            self.database_mapping = Native.Router.Lisp.EidTable.InstanceList.Ipv6.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.distance = Native.Router.Lisp.EidTable.InstanceList.Ipv6.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.itr = Native.Router.Lisp.EidTable.InstanceList.Ipv6.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.Lisp.EidTable.InstanceList.Ipv6.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr = Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.etr_enable = Native.Router.Lisp.EidTable.InstanceList.Ipv6.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.locator = Native.Router.Lisp.EidTable.InstanceList.Ipv6.Locator()
                            self.locator.parent = self
                            self._children_name_map["locator"] = "locator"

                            self.map_cache = Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_limit = Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_cache_persistent = Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.path_mtu_discovery = None
                            self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                            self.route_export = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport()
                            self.route_import.parent = self
                            self._children_name_map["route_import"] = "route-import"

                            self.site_registration = Native.Router.Lisp.EidTable.InstanceList.Ipv6.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.Lisp.EidTable.InstanceList.Ipv6.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.source_locator = Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator()
                            self.source_locator.parent = self
                            self._children_name_map["source_locator"] = "source-locator"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.Lisp.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.Lisp.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.Itr.MapResolver>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.Lisp.EidTable.InstanceList.Ipv6.Itr.MapResolver))])
                                self._leafs = OrderedDict()

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Itr, [], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ])
                                    self.ip_addr = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Itr.MapResolver, ['ip_addr'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.ItrEnable, ['itr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr.MapServer))])
                                self._leafs = OrderedDict()

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr, [], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: key_7
                                    
                                    	The HIDDEN password
                                    	**type**\: str
                                    
                                    .. attribute:: pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                            ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                        ])
                                        self.key_0 = None
                                        self.key_6 = None
                                        self.key_7 = None
                                        self.pwd = None
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.EtrEnable, ['etr'], name, value)


                        class Locator(Entity):
                            """
                            Locator related configuration
                            
                            .. attribute:: reachability
                            
                            	Configuration realted to locator reachability
                            	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.Locator.Reachability>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Locator, self).__init__()

                                self.yang_name = "locator"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.Lisp.EidTable.InstanceList.Ipv6.Locator.Reachability))])
                                self._leafs = OrderedDict()

                                self.reachability = Native.Router.Lisp.EidTable.InstanceList.Ipv6.Locator.Reachability()
                                self.reachability.parent = self
                                self._children_name_map["reachability"] = "reachability"
                                self._segment_path = lambda: "locator"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Locator, [], name, value)


                            class Reachability(Entity):
                                """
                                Configuration realted to locator reachability
                                
                                .. attribute:: exclude_default
                                
                                	If a remote RLOC is reached via the default route, treat it as unreachable
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Locator.Reachability, self).__init__()

                                    self.yang_name = "reachability"
                                    self.yang_parent_name = "locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                    ])
                                    self.exclude_default = None
                                    self._segment_path = lambda: "reachability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.Locator.Reachability, ['exclude_default'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None
                                self._segment_path = lambda: "map-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCache, ['site_registration'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapCachePersistent, ['interval'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 prefixes
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 prefixes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                                ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.list = None
                                            self.registered = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class PathMtuDiscovery(Entity):
                            """
                            Path MTU discovery
                            
                            .. attribute:: max
                            
                            	Upper bound on the path MTU accepted
                            	**type**\: int
                            
                            	**range:** 68..65535
                            
                            .. attribute:: min
                            
                            	Lower bound on the path MTU accepted
                            	**type**\: int
                            
                            	**range:** 68..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.PathMtuDiscovery, self).__init__()

                                self.yang_name = "path-mtu-discovery"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                    ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                ])
                                self.max = None
                                self.min = None
                                self._segment_path = lambda: "path-mtu-discovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.PathMtuDiscovery, ['max', 'min'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class RouteImport(Entity):
                            """
                            Import RIB routes by a routing protocol into LISP
                            
                            .. attribute:: database
                            
                            	Use RIB routes to define local EID database entries
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database>`
                            
                            .. attribute:: map_cache
                            
                            	Use RIB routes to define EID address space in map\-cache
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport, self).__init__()

                                self.yang_name = "route-import"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"

                                self.map_cache = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"
                                self._segment_path = lambda: "route-import"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport, [], name, value)


                            class Database(Entity):
                                """
                                Use RIB routes to define local EID database entries
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected>`
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes to pick up from the RIB
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix>`
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip>`
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Static>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "route-import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip)), ("static", ("static", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Static))])
                                    self._leafs = OrderedDict()

                                    self.connected = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected()
                                    self.connected.parent = self
                                    self._children_name_map["connected"] = "connected"

                                    self.maximum_prefix = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.rip = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip()
                                    self.rip.parent = self
                                    self._children_name_map["rip"] = "rip"

                                    self.static = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Static()
                                    self.static.parent = self
                                    self._children_name_map["static"] = "static"

                                    self.bgp = YList(self)
                                    self.eigrp = YList(self)
                                    self.isis = YList(self)
                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "database"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database, [], name, value)


                                class Bgp(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "connected"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes to pick up from the RIB
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold1
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only1
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.warning_only = None
                                        self.threshold = None
                                        self.threshold1 = None
                                        self.warning_only1 = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "rip"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Static, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class MapCache(Entity):
                                """
                                Use RIB routes to define EID address space in map\-cache
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes to pick up from the RIB
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "route-import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static))])
                                    self._leafs = OrderedDict()

                                    self.connected = None
                                    self._children_name_map["connected"] = "connected"

                                    self.maximum_prefix = Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.rip = None
                                    self._children_name_map["rip"] = "rip"

                                    self.static = None
                                    self._children_name_map["static"] = "static"

                                    self.bgp = YList(self)
                                    self.eigrp = YList(self)
                                    self.isis = YList(self)
                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache, [], name, value)


                                class Bgp(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "connected"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes to pick up from the RIB
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold1
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only1
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.warning_only = None
                                        self.threshold = None
                                        self.threshold1 = None
                                        self.warning_only1 = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "rip"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations for a given instance\-id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class SourceLocator(Entity):
                            """
                            Source Locator configuration
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator, self).__init__()

                                self.yang_name = "source-locator"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "source-locator"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	Configures which Locators from a set are preferred
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: weight
                            
                            	Traffic load\-spreading among Locators
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.Ipv6.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                ])
                                self.locator_address = None
                                self.priority = None
                                self.weight = None
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.Ipv6.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                    class LocReachAlgorithm(Entity):
                        """
                        Configure locator reachability algorithm
                        
                        .. attribute:: lsb_reports
                        
                        	Configure data packet LSB report handling
                        	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.LocReachAlgorithm.LsbReports>`
                        
                        .. attribute:: rloc_probing
                        
                        	Probe high priority RLOCs with Map\-Requests as last resort
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.LocReachAlgorithm, self).__init__()

                            self.yang_name = "loc-reach-algorithm"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.Lisp.EidTable.InstanceList.LocReachAlgorithm.LsbReports))])
                            self._leafs = OrderedDict([
                                ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                            ])
                            self.rloc_probing = None

                            self.lsb_reports = Native.Router.Lisp.EidTable.InstanceList.LocReachAlgorithm.LsbReports()
                            self.lsb_reports.parent = self
                            self._children_name_map["lsb_reports"] = "lsb-reports"
                            self._segment_path = lambda: "loc-reach-algorithm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.LocReachAlgorithm, ['rloc_probing'], name, value)


                        class LsbReports(Entity):
                            """
                            Configure data packet LSB report handling
                            
                            .. attribute:: do_not_transmit
                            
                            	Force the setting of the encapsulation header L bit to zero
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore data packet LSB reports
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.LocReachAlgorithm.LsbReports, self).__init__()

                                self.yang_name = "lsb-reports"
                                self.yang_parent_name = "loc-reach-algorithm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.do_not_transmit = None
                                self.ignore = None
                                self._segment_path = lambda: "lsb-reports"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                    class LocatorDown(Entity):
                        """
                        Manually set locator status to down
                        
                        .. attribute:: address
                        
                        	IPv4/6 Locator address to be set down
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv4_interface
                        
                        	Use IPv4 address of interface as locator
                        	**type**\: str
                        
                        .. attribute:: ipv6_interface
                        
                        	Use IPv6 address of interface as locator
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.LocatorDown, self).__init__()

                            self.yang_name = "locator-down"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                ('ipv4_interface', (YLeaf(YType.str, 'IPv4-interface'), ['str'])),
                                ('ipv6_interface', (YLeaf(YType.str, 'IPv6-interface'), ['str'])),
                            ])
                            self.address = None
                            self.ipv4_interface = None
                            self.ipv6_interface = None
                            self._segment_path = lambda: "locator-down"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.LocatorDown, ['address', 'ipv4_interface', 'ipv6_interface'], name, value)


                    class LocatorTable(Entity):
                        """
                        Specify the RLOC table
                        
                        .. attribute:: vrf_name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: default
                        
                        	Default VRF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vrf
                        
                        	VRF name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.LocatorTable, self).__init__()

                            self.yang_name = "locator-table"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.vrf_name = None
                            self.default = None
                            self.vrf = None
                            self._segment_path = lambda: "locator-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.LocatorTable, ['vrf_name', 'default', 'vrf'], name, value)


                    class MapRequest(Entity):
                        """
                        Configure map\-request handling
                        
                        .. attribute:: itr_rlocs
                        
                        	Configure to use the specified RLOC set as ITR RLOC in map\-request
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.MapRequest, self).__init__()

                            self.yang_name = "map-request"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr_rlocs', (YLeaf(YType.str, 'itr-rlocs'), ['str'])),
                            ])
                            self.itr_rlocs = None
                            self._segment_path = lambda: "map-request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.MapRequest, ['itr_rlocs'], name, value)


                    class MapServer(Entity):
                        """
                        Map\-Server commands
                        
                        .. attribute:: rloc
                        
                        	EID instance RLOC membership
                        	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc>`
                        
                        .. attribute:: site_registration
                        
                        	Map\-server site registration options
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.MapServer.SiteRegistration>`
                        
                        .. attribute:: nmr
                        
                        	Map\-server negative map\-reply optio
                        	**type**\:  :py:class:`Nmr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.MapServer.Nmr>`
                        
                        .. attribute:: session
                        
                        	Map\-server session
                        	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.MapServer.Session>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.Lisp.EidTable.InstanceList.MapServer.SiteRegistration)), ("nmr", ("nmr", Native.Router.Lisp.EidTable.InstanceList.MapServer.Nmr)), ("session", ("session", Native.Router.Lisp.EidTable.InstanceList.MapServer.Session))])
                            self._leafs = OrderedDict()

                            self.rloc = Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc()
                            self.rloc.parent = self
                            self._children_name_map["rloc"] = "rloc"

                            self.site_registration = Native.Router.Lisp.EidTable.InstanceList.MapServer.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.nmr = Native.Router.Lisp.EidTable.InstanceList.MapServer.Nmr()
                            self.nmr.parent = self
                            self._children_name_map["nmr"] = "nmr"

                            self.session = Native.Router.Lisp.EidTable.InstanceList.MapServer.Session()
                            self.session.parent = self
                            self._children_name_map["session"] = "session"
                            self._segment_path = lambda: "map-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.MapServer, [], name, value)


                        class Rloc(Entity):
                            """
                            EID instance RLOC membership
                            
                            .. attribute:: members
                            
                            	EID instance RLOC membership
                            	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc, self).__init__()

                                self.yang_name = "rloc"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("members", ("members", Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members))])
                                self._leafs = OrderedDict()

                                self.members = Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members()
                                self.members.parent = self
                                self._children_name_map["members"] = "members"
                                self._segment_path = lambda: "rloc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc, [], name, value)


                            class Members(Entity):
                                """
                                EID instance RLOC membership
                                
                                .. attribute:: distribute
                                
                                	EID instance RLOC membership distribution
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: modify_discovered
                                
                                	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members, self).__init__()

                                    self.yang_name = "members"
                                    self.yang_parent_name = "rloc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered))])
                                    self._leafs = OrderedDict([
                                        ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                    ])
                                    self.distribute = None

                                    self.modify_discovered = Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered()
                                    self.modify_discovered.parent = self
                                    self._children_name_map["modify_discovered"] = "modify-discovered"
                                    self._segment_path = lambda: "members"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members, ['distribute'], name, value)


                                class ModifyDiscovered(Entity):
                                    """
                                    Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                    
                                    .. attribute:: operator
                                    
                                    	
                                    	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set from which to get member RLOC addresses
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                        self.yang_name = "modify-discovered"
                                        self.yang_parent_name = "members"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.operator = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "modify-discovered"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                    class Operator(Enum):
                                        """
                                        Operator (Enum Class)

                                        .. data:: add = 0

                                        .. data:: override = 1

                                        """

                                        add = Enum.YLeaf(0, "add")

                                        override = Enum.YLeaf(1, "override")



                        class SiteRegistration(Entity):
                            """
                            Map\-server site registration options
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations as a result of accept\-more\-specifics
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.MapServer.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class Nmr(Entity):
                            """
                            Map\-server negative map\-reply optio
                            
                            .. attribute:: non_site_ttl
                            
                            	Negative map\-reply TTL for non\-site EID
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.MapServer.Nmr, self).__init__()

                                self.yang_name = "nmr"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('non_site_ttl', (YLeaf(YType.uint16, 'non-site-ttl'), ['int'])),
                                ])
                                self.non_site_ttl = None
                                self._segment_path = lambda: "nmr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.MapServer.Nmr, ['non_site_ttl'], name, value)


                        class Session(Entity):
                            """
                            Map\-server session
                            
                            .. attribute:: passive_open
                            
                            	Open passive TCP sockets to listen for incoming connections
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.MapServer.Session, self).__init__()

                                self.yang_name = "session"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('passive_open', (YLeaf(YType.str, 'passive-open'), ['str'])),
                                ])
                                self.passive_open = None
                                self._segment_path = lambda: "session"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.MapServer.Session, ['passive_open'], name, value)


                    class OtherXtrProbe(Entity):
                        """
                        Configure parameters for probing of other xTRs in our site
                        
                        .. attribute:: period
                        
                        	Period between probes in seconds
                        	**type**\: int
                        
                        	**range:** 5..900
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.OtherXtrProbe, self).__init__()

                            self.yang_name = "other-xtr-probe"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ])
                            self.period = None
                            self._segment_path = lambda: "other-xtr-probe"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.OtherXtrProbe, ['period'], name, value)


                    class RemoteRlocProbe(Entity):
                        """
                        Configure parameters for probing of remote RLOCs
                        
                        .. attribute:: on_membership_change
                        
                        	Trigger probing upon membership changes for remote RLOC
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: on_route_change
                        
                        	Trigger probing upon routing changes for remote RLOC
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.RemoteRlocProbe, self).__init__()

                            self.yang_name = "remote-rloc-probe"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                            ])
                            self.on_membership_change = None
                            self.on_route_change = None
                            self._segment_path = lambda: "remote-rloc-probe"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                    class MapCache(Entity):
                        """
                        Configures static EID\-to\-RLOC mappings for an ITR
                        
                        .. attribute:: eid_prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: etr_interface_ip
                        
                        	
                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.EidTable.InstanceList.MapCache.EtrInterfaceIp>`
                        
                        .. attribute:: drop
                        
                        	Drop packets that match this map\-cache entry
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: map_request
                        
                        	Send Map\-Request for LISP destination EID
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: native_forward
                        
                        	Natively forward packets that match this map\-cache entry
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.EidTable.InstanceList.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['eid_prefix']
                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.Lisp.EidTable.InstanceList.MapCache.EtrInterfaceIp))])
                            self._leafs = OrderedDict([
                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                            ])
                            self.eid_prefix = None
                            self.drop = None
                            self.map_request = None
                            self.native_forward = None

                            self.etr_interface_ip = Native.Router.Lisp.EidTable.InstanceList.MapCache.EtrInterfaceIp()
                            self.etr_interface_ip.parent = self
                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                            self._segment_path = lambda: "map-cache" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.MapCache, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                        class EtrInterfaceIp(Entity):
                            """
                            
                            
                            .. attribute:: etr_interface_ip_address
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	Configures which Locators from a set are preferred
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: weight
                            
                            	Traffic load\-spreading among Locators
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.EidTable.InstanceList.MapCache.EtrInterfaceIp, self).__init__()

                                self.yang_name = "etr-interface-ip"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                ])
                                self.etr_interface_ip_address = None
                                self.priority = None
                                self.weight = None
                                self._segment_path = lambda: "etr-interface-ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.EidTable.InstanceList.MapCache.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


            class Security(Entity):
                """
                Enable default LISP security and authentication in reply is optional
                
                .. attribute:: strong
                
                	Enable default LISP security and authentication in reply is required
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Security, self).__init__()

                    self.yang_name = "security"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('strong', (YLeaf(YType.empty, 'strong'), ['Empty'])),
                    ])
                    self.strong = None
                    self._segment_path = lambda: "security"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Security, ['strong'], name, value)


            class Site(Entity):
                """
                Configure a LISP site on a map server (MS)
                
                .. attribute:: sname  (key)
                
                	The site name
                	**type**\: str
                
                .. attribute:: default
                
                	
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default>`
                
                .. attribute:: authentication_key
                
                	Authentication key used by LISP site
                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.AuthenticationKey>`
                
                .. attribute:: description
                
                	Site description
                	**type**\: str
                
                .. attribute:: allowed_locator
                
                	Locator from LISP site
                	**type**\:  :py:class:`AllowedLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.AllowedLocator>`
                
                .. attribute:: eid_prefix
                
                	Site EID address prefix
                	**type**\:  :py:class:`EidPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.EidPrefix>`
                
                .. attribute:: eid_record
                
                	Site EID address prefix
                	**type**\:  :py:class:`EidRecord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.EidRecord>`
                
                .. attribute:: site_id
                
                	Configure a site\-id for this site
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Site, self).__init__()

                    self.yang_name = "site"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['sname']
                    self._child_classes = OrderedDict([("default", ("default", Native.Router.Lisp.Site.Default)), ("authentication-key", ("authentication_key", Native.Router.Lisp.Site.AuthenticationKey)), ("allowed-locator", ("allowed_locator", Native.Router.Lisp.Site.AllowedLocator)), ("eid-prefix", ("eid_prefix", Native.Router.Lisp.Site.EidPrefix)), ("eid-record", ("eid_record", Native.Router.Lisp.Site.EidRecord))])
                    self._leafs = OrderedDict([
                        ('sname', (YLeaf(YType.str, 'sname'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                    ])
                    self.sname = None
                    self.description = None
                    self.site_id = None

                    self.default = Native.Router.Lisp.Site.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.authentication_key = Native.Router.Lisp.Site.AuthenticationKey()
                    self.authentication_key.parent = self
                    self._children_name_map["authentication_key"] = "authentication-key"

                    self.allowed_locator = Native.Router.Lisp.Site.AllowedLocator()
                    self.allowed_locator.parent = self
                    self._children_name_map["allowed_locator"] = "allowed-locator"

                    self.eid_prefix = Native.Router.Lisp.Site.EidPrefix()
                    self.eid_prefix.parent = self
                    self._children_name_map["eid_prefix"] = "eid-prefix"

                    self.eid_record = Native.Router.Lisp.Site.EidRecord()
                    self.eid_record.parent = self
                    self._children_name_map["eid_record"] = "eid-record"
                    self._segment_path = lambda: "site" + "[sname='" + str(self.sname) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Site, ['sname', 'description', 'site_id'], name, value)


                class Default(Entity):
                    """
                    
                    
                    .. attribute:: authentication_key
                    
                    	Authentication key used by LISP site
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default.AuthenticationKey>`
                    
                    .. attribute:: description
                    
                    	Site description
                    	**type**\: str
                    
                    .. attribute:: allowed_locator
                    
                    	Locator from LISP site
                    	**type**\:  :py:class:`AllowedLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default.AllowedLocator>`
                    
                    .. attribute:: eid_prefix
                    
                    	Site EID address prefix
                    	**type**\:  :py:class:`EidPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default.EidPrefix>`
                    
                    .. attribute:: eid_record
                    
                    	Site EID address prefix
                    	**type**\:  :py:class:`EidRecord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default.EidRecord>`
                    
                    .. attribute:: site_id
                    
                    	Configure a site\-id for this site
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Site.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Lisp.Site.Default.AuthenticationKey)), ("allowed-locator", ("allowed_locator", Native.Router.Lisp.Site.Default.AllowedLocator)), ("eid-prefix", ("eid_prefix", Native.Router.Lisp.Site.Default.EidPrefix)), ("eid-record", ("eid_record", Native.Router.Lisp.Site.Default.EidRecord))])
                        self._leafs = OrderedDict([
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                        ])
                        self.description = None
                        self.site_id = None

                        self.authentication_key = Native.Router.Lisp.Site.Default.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.allowed_locator = Native.Router.Lisp.Site.Default.AllowedLocator()
                        self.allowed_locator.parent = self
                        self._children_name_map["allowed_locator"] = "allowed-locator"

                        self.eid_prefix = Native.Router.Lisp.Site.Default.EidPrefix()
                        self.eid_prefix.parent = self
                        self._children_name_map["eid_prefix"] = "eid-prefix"

                        self.eid_record = Native.Router.Lisp.Site.Default.EidRecord()
                        self.eid_record.parent = self
                        self._children_name_map["eid_record"] = "eid-record"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Site.Default, ['description', 'site_id'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Authentication key used by LISP site
                        
                        .. attribute:: unc_pwd
                        
                        	The UNENCRYPTED (cleartext) password
                        	**type**\: str
                        
                        .. attribute:: key_0
                        
                        	The UNENCRYPTED (cleartext) password
                        	**type**\: str
                        
                        .. attribute:: key_6
                        
                        	The ENCRYPTED password
                        	**type**\: str
                        
                        .. attribute:: key_7
                        
                        	The ENCRYPTED password
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Site.Default.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                            ])
                            self.unc_pwd = None
                            self.key_0 = None
                            self.key_6 = None
                            self.key_7 = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Site.Default.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                    class AllowedLocator(Entity):
                        """
                        Locator from LISP site
                        
                        .. attribute:: ls_ipv4
                        
                        	IPv4 locator allowed in registered locator\-set
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ls_ipv6
                        
                        	IPv6 locator allowed in registered locator\-set
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: list
                        
                        	Prefixes allowed in registerd locator\-set
                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default.AllowedLocator.List>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Site.Default.AllowedLocator, self).__init__()

                            self.yang_name = "allowed-locator"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Site.Default.AllowedLocator.List))])
                            self._leafs = OrderedDict([
                                ('ls_ipv4', (YLeaf(YType.str, 'ls-ipv4'), ['str'])),
                                ('ls_ipv6', (YLeaf(YType.str, 'ls-ipv6'), ['str'])),
                            ])
                            self.ls_ipv4 = None
                            self.ls_ipv6 = None

                            self.list = Native.Router.Lisp.Site.Default.AllowedLocator.List()
                            self.list.parent = self
                            self._children_name_map["list"] = "list"
                            self._segment_path = lambda: "allowed-locator"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Site.Default.AllowedLocator, ['ls_ipv4', 'ls_ipv6'], name, value)


                        class List(Entity):
                            """
                            Prefixes allowed in registerd locator\-set
                            
                            .. attribute:: ipv4
                            
                            	IPv4 prefix\-list name
                            	**type**\: str
                            
                            .. attribute:: ipv6
                            
                            	IPv6 prefix\-list name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Site.Default.AllowedLocator.List, self).__init__()

                                self.yang_name = "list"
                                self.yang_parent_name = "allowed-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "list"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Site.Default.AllowedLocator.List, ['ipv4', 'ipv6'], name, value)


                    class EidPrefix(Entity):
                        """
                        Site EID address prefix
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default.EidPrefix.Prefixes>`
                        
                        .. attribute:: instance_id
                        
                        	EID instance\-ID
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default.EidPrefix.InstanceId>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Site.Default.EidPrefix, self).__init__()

                            self.yang_name = "eid-prefix"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Site.Default.EidPrefix.Prefixes)), ("instance-id", ("instance_id", Native.Router.Lisp.Site.Default.EidPrefix.InstanceId))])
                            self._leafs = OrderedDict([
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self.instance_id = YList(self)
                            self._segment_path = lambda: "eid-prefix"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Site.Default.EidPrefix, ['any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Site.Default.EidPrefix.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "eid-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Site.Default.EidPrefix.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                        class InstanceId(Entity):
                            """
                            EID instance\-ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default.EidPrefix.InstanceId.Prefixes>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Site.Default.EidPrefix.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "eid-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Site.Default.EidPrefix.InstanceId.Prefixes))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.id = None
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Site.Default.EidPrefix.InstanceId, ['id', 'any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Site.Default.EidPrefix.InstanceId.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "instance-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Site.Default.EidPrefix.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                    class EidRecord(Entity):
                        """
                        Site EID address prefix
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default.EidRecord.Prefixes>`
                        
                        .. attribute:: instance_id
                        
                        	EID instance\-ID
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default.EidRecord.InstanceId>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Site.Default.EidRecord, self).__init__()

                            self.yang_name = "eid-record"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Site.Default.EidRecord.Prefixes)), ("instance-id", ("instance_id", Native.Router.Lisp.Site.Default.EidRecord.InstanceId))])
                            self._leafs = OrderedDict([
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self.instance_id = YList(self)
                            self._segment_path = lambda: "eid-record"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Site.Default.EidRecord, ['any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Site.Default.EidRecord.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "eid-record"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Site.Default.EidRecord.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                        class InstanceId(Entity):
                            """
                            EID instance\-ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.Default.EidRecord.InstanceId.Prefixes>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Site.Default.EidRecord.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "eid-record"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Site.Default.EidRecord.InstanceId.Prefixes))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.id = None
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Site.Default.EidRecord.InstanceId, ['id', 'any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.Lisp.Site.Default.EidRecord.InstanceId.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "instance-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Lisp.Site.Default.EidRecord.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                class AuthenticationKey(Entity):
                    """
                    Authentication key used by LISP site
                    
                    .. attribute:: unc_pwd
                    
                    	The UNENCRYPTED (cleartext) password
                    	**type**\: str
                    
                    .. attribute:: key_0
                    
                    	The UNENCRYPTED (cleartext) password
                    	**type**\: str
                    
                    .. attribute:: key_6
                    
                    	The ENCRYPTED password
                    	**type**\: str
                    
                    .. attribute:: key_7
                    
                    	The ENCRYPTED password
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Site.AuthenticationKey, self).__init__()

                        self.yang_name = "authentication-key"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                        ])
                        self.unc_pwd = None
                        self.key_0 = None
                        self.key_6 = None
                        self.key_7 = None
                        self._segment_path = lambda: "authentication-key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Site.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                class AllowedLocator(Entity):
                    """
                    Locator from LISP site
                    
                    .. attribute:: ls_ipv4
                    
                    	IPv4 locator allowed in registered locator\-set
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ls_ipv6
                    
                    	IPv6 locator allowed in registered locator\-set
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: list
                    
                    	Prefixes allowed in registerd locator\-set
                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.AllowedLocator.List>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Site.AllowedLocator, self).__init__()

                        self.yang_name = "allowed-locator"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("list", ("list", Native.Router.Lisp.Site.AllowedLocator.List))])
                        self._leafs = OrderedDict([
                            ('ls_ipv4', (YLeaf(YType.str, 'ls-ipv4'), ['str'])),
                            ('ls_ipv6', (YLeaf(YType.str, 'ls-ipv6'), ['str'])),
                        ])
                        self.ls_ipv4 = None
                        self.ls_ipv6 = None

                        self.list = Native.Router.Lisp.Site.AllowedLocator.List()
                        self.list.parent = self
                        self._children_name_map["list"] = "list"
                        self._segment_path = lambda: "allowed-locator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Site.AllowedLocator, ['ls_ipv4', 'ls_ipv6'], name, value)


                    class List(Entity):
                        """
                        Prefixes allowed in registerd locator\-set
                        
                        .. attribute:: ipv4
                        
                        	IPv4 prefix\-list name
                        	**type**\: str
                        
                        .. attribute:: ipv6
                        
                        	IPv6 prefix\-list name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Site.AllowedLocator.List, self).__init__()

                            self.yang_name = "list"
                            self.yang_parent_name = "allowed-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                            ])
                            self.ipv4 = None
                            self.ipv6 = None
                            self._segment_path = lambda: "list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Site.AllowedLocator.List, ['ipv4', 'ipv6'], name, value)


                class EidPrefix(Entity):
                    """
                    Site EID address prefix
                    
                    .. attribute:: prefixes
                    
                    	
                    	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.EidPrefix.Prefixes>`
                    
                    .. attribute:: instance_id
                    
                    	EID instance\-ID
                    	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.EidPrefix.InstanceId>`
                    
                    .. attribute:: any_mac
                    
                    	Accept registrations for any L2 EID records
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Site.EidPrefix, self).__init__()

                        self.yang_name = "eid-prefix"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Site.EidPrefix.Prefixes)), ("instance-id", ("instance_id", Native.Router.Lisp.Site.EidPrefix.InstanceId))])
                        self._leafs = OrderedDict([
                            ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                        ])
                        self.any_mac = None

                        self.prefixes = YList(self)
                        self.instance_id = YList(self)
                        self._segment_path = lambda: "eid-prefix"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Site.EidPrefix, ['any_mac'], name, value)


                    class Prefixes(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: accept_more_specifics
                        
                        	Accept registrations for more specific EID prefixes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_tag
                        
                        	RIB route tag
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Site.EidPrefix.Prefixes, self).__init__()

                            self.yang_name = "prefixes"
                            self.yang_parent_name = "eid-prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                            ])
                            self.prefix = None
                            self.accept_more_specifics = None
                            self.route_tag = None
                            self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Site.EidPrefix.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                    class InstanceId(Entity):
                        """
                        EID instance\-ID
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.EidPrefix.InstanceId.Prefixes>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Site.EidPrefix.InstanceId, self).__init__()

                            self.yang_name = "instance-id"
                            self.yang_parent_name = "eid-prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Site.EidPrefix.InstanceId.Prefixes))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.id = None
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Site.EidPrefix.InstanceId, ['id', 'any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Site.EidPrefix.InstanceId.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "instance-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Site.EidPrefix.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                class EidRecord(Entity):
                    """
                    Site EID address prefix
                    
                    .. attribute:: prefixes
                    
                    	
                    	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.EidRecord.Prefixes>`
                    
                    .. attribute:: instance_id
                    
                    	EID instance\-ID
                    	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.EidRecord.InstanceId>`
                    
                    .. attribute:: any_mac
                    
                    	Accept registrations for any L2 EID records
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Site.EidRecord, self).__init__()

                        self.yang_name = "eid-record"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Site.EidRecord.Prefixes)), ("instance-id", ("instance_id", Native.Router.Lisp.Site.EidRecord.InstanceId))])
                        self._leafs = OrderedDict([
                            ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                        ])
                        self.any_mac = None

                        self.prefixes = YList(self)
                        self.instance_id = YList(self)
                        self._segment_path = lambda: "eid-record"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Site.EidRecord, ['any_mac'], name, value)


                    class Prefixes(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: accept_more_specifics
                        
                        	Accept registrations for more specific EID prefixes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_tag
                        
                        	RIB route tag
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Site.EidRecord.Prefixes, self).__init__()

                            self.yang_name = "prefixes"
                            self.yang_parent_name = "eid-record"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                            ])
                            self.prefix = None
                            self.accept_more_specifics = None
                            self.route_tag = None
                            self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Site.EidRecord.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                    class InstanceId(Entity):
                        """
                        EID instance\-ID
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Site.EidRecord.InstanceId.Prefixes>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.Lisp.Site.EidRecord.InstanceId, self).__init__()

                            self.yang_name = "instance-id"
                            self.yang_parent_name = "eid-record"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.Lisp.Site.EidRecord.InstanceId.Prefixes))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.id = None
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Lisp.Site.EidRecord.InstanceId, ['id', 'any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.Lisp.Site.EidRecord.InstanceId.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "instance-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Lisp.Site.EidRecord.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


            class Syslog(Entity):
                """
                Configure syslog option
                
                .. attribute:: session
                
                	Enable session syslog
                	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Lisp.Syslog.Session>`
                
                .. attribute:: verbose
                
                	Enable verbose syslog
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.Lisp.Syslog, self).__init__()

                    self.yang_name = "syslog"
                    self.yang_parent_name = "lisp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("session", ("session", Native.Router.Lisp.Syslog.Session))])
                    self._leafs = OrderedDict([
                        ('verbose', (YLeaf(YType.empty, 'verbose'), ['Empty'])),
                    ])
                    self.verbose = None

                    self.session = Native.Router.Lisp.Syslog.Session()
                    self.session.parent = self
                    self._children_name_map["session"] = "session"
                    self._segment_path = lambda: "syslog"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Lisp.Syslog, ['verbose'], name, value)


                class Session(Entity):
                    """
                    Enable session syslog
                    
                    .. attribute:: changes
                    
                    	Enable session change syslog
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.Lisp.Syslog.Session, self).__init__()

                        self.yang_name = "session"
                        self.yang_parent_name = "syslog"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('changes', (YLeaf(YType.empty, 'changes'), ['Empty'])),
                        ])
                        self.changes = None
                        self._segment_path = lambda: "session"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-lisp:lisp/syslog/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Lisp.Syslog.Session, ['changes'], name, value)


        class LispList(Entity):
            """
            Locator/ID Separation Protocol
            
            .. attribute:: lisp  (key)
            
            	Locator/ID Separation Protocol
            	**type**\: int
            
            	**range:** 1..65520
            
            .. attribute:: default
            
            	
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default>`
            
            .. attribute:: service
            
            	Configure lisp service type
            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service>`
            
            	**presence node**\: True
            
            .. attribute:: encapsulation
            
            	Select encapsulation type for data packets
            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Encapsulation>`
            
            .. attribute:: locator_set
            
            	Configure a named locator set
            	**type**\: list of  		 :py:class:`LocatorSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.LocatorSet>`
            
            .. attribute:: locator
            
            	Locator configuration
            	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Locator>`
            
            .. attribute:: locator_scope
            
            	Configure a locator scope
            	**type**\: list of  		 :py:class:`LocatorScope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.LocatorScope>`
            
            .. attribute:: prefix_list
            
            	Configure a named prefix list
            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.PrefixList>`
            
            .. attribute:: instance_container
            
            	EID instance\-ID
            	**type**\:  :py:class:`InstanceContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer>`
            
            .. attribute:: alt
            
            	LISP Alternative Topology, LISP\-ALT
            	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Alt>`
            
            .. attribute:: control_packet
            
            	Configure control packet tx option
            	**type**\:  :py:class:`ControlPacket <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.ControlPacket>`
            
            .. attribute:: ddt
            
            	Delegated Database Tree (DDT) mapping system
            	**type**\:  :py:class:`Ddt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ddt>`
            
            	**presence node**\: True
            
            .. attribute:: decapsulation
            
            	Decapsulation behavior (e.g. filters)
            	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Decapsulation>`
            
            .. attribute:: disable_ttl_propagate
            
            	Disable ttl propagation
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: etr
            
            	Configures a LISP Egress Tunnel Router (ETR)
            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Etr>`
            
            .. attribute:: ipv4
            
            	IPv4 address family
            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4>`
            
            .. attribute:: ipv6
            
            	IPv6 address family
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6>`
            
            .. attribute:: loc_reach_algorithm
            
            	Configure locator reachability algorithm
            	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.LocReachAlgorithm>`
            
            .. attribute:: locator_down
            
            	Manually set locator status to down
            	**type**\:  :py:class:`LocatorDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.LocatorDown>`
            
            .. attribute:: locator_table
            
            	Specify the RLOC table
            	**type**\:  :py:class:`LocatorTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.LocatorTable>`
            
            .. attribute:: map_request
            
            	Configure map\-request handling
            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.MapRequest>`
            
            .. attribute:: map_server
            
            	Map\-Server commands
            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.MapServer>`
            
            .. attribute:: other_xtr_probe
            
            	Configure parameters for probing of other xTRs in our site
            	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.OtherXtrProbe>`
            
            .. attribute:: remote_rloc_probe
            
            	Configure parameters for probing of remote RLOCs
            	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.RemoteRlocProbe>`
            
            .. attribute:: eid_table
            
            	Configure an EID instance for a VRF
            	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable>`
            
            .. attribute:: security
            
            	Enable default LISP security and authentication in reply is optional
            	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Security>`
            
            	**presence node**\: True
            
            .. attribute:: site
            
            	Configure a LISP site on a map server (MS)
            	**type**\: list of  		 :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site>`
            
            .. attribute:: site_id
            
            	Configure a site\-id for this site
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: syslog
            
            	Configure syslog option
            	**type**\:  :py:class:`Syslog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Syslog>`
            
            

            """

            _prefix = 'ios-lisp'
            _revision = '2018-04-17'

            def __init__(self):
                super(Native.Router.LispList, self).__init__()

                self.yang_name = "lisp-list"
                self.yang_parent_name = "router"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['lisp']
                self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default)), ("service", ("service", Native.Router.LispList.Service)), ("encapsulation", ("encapsulation", Native.Router.LispList.Encapsulation)), ("locator-set", ("locator_set", Native.Router.LispList.LocatorSet)), ("locator", ("locator", Native.Router.LispList.Locator)), ("locator-scope", ("locator_scope", Native.Router.LispList.LocatorScope)), ("prefix-list", ("prefix_list", Native.Router.LispList.PrefixList)), ("instance-container", ("instance_container", Native.Router.LispList.InstanceContainer)), ("alt", ("alt", Native.Router.LispList.Alt)), ("control-packet", ("control_packet", Native.Router.LispList.ControlPacket)), ("ddt", ("ddt", Native.Router.LispList.Ddt)), ("decapsulation", ("decapsulation", Native.Router.LispList.Decapsulation)), ("etr", ("etr", Native.Router.LispList.Etr)), ("ipv4", ("ipv4", Native.Router.LispList.Ipv4)), ("ipv6", ("ipv6", Native.Router.LispList.Ipv6)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.LispList.LocReachAlgorithm)), ("locator-down", ("locator_down", Native.Router.LispList.LocatorDown)), ("locator-table", ("locator_table", Native.Router.LispList.LocatorTable)), ("map-request", ("map_request", Native.Router.LispList.MapRequest)), ("map-server", ("map_server", Native.Router.LispList.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.LispList.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.LispList.RemoteRlocProbe)), ("eid-table", ("eid_table", Native.Router.LispList.EidTable)), ("security", ("security", Native.Router.LispList.Security)), ("site", ("site", Native.Router.LispList.Site)), ("syslog", ("syslog", Native.Router.LispList.Syslog))])
                self._leafs = OrderedDict([
                    ('lisp', (YLeaf(YType.uint16, 'lisp'), ['int'])),
                    ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                    ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                ])
                self.lisp = None
                self.disable_ttl_propagate = None
                self.site_id = None

                self.default = Native.Router.LispList.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.service = None
                self._children_name_map["service"] = "service"

                self.encapsulation = Native.Router.LispList.Encapsulation()
                self.encapsulation.parent = self
                self._children_name_map["encapsulation"] = "encapsulation"

                self.locator = Native.Router.LispList.Locator()
                self.locator.parent = self
                self._children_name_map["locator"] = "locator"

                self.instance_container = Native.Router.LispList.InstanceContainer()
                self.instance_container.parent = self
                self._children_name_map["instance_container"] = "instance-container"

                self.alt = Native.Router.LispList.Alt()
                self.alt.parent = self
                self._children_name_map["alt"] = "alt"

                self.control_packet = Native.Router.LispList.ControlPacket()
                self.control_packet.parent = self
                self._children_name_map["control_packet"] = "control-packet"

                self.ddt = None
                self._children_name_map["ddt"] = "ddt"

                self.decapsulation = Native.Router.LispList.Decapsulation()
                self.decapsulation.parent = self
                self._children_name_map["decapsulation"] = "decapsulation"

                self.etr = Native.Router.LispList.Etr()
                self.etr.parent = self
                self._children_name_map["etr"] = "etr"

                self.ipv4 = Native.Router.LispList.Ipv4()
                self.ipv4.parent = self
                self._children_name_map["ipv4"] = "ipv4"

                self.ipv6 = Native.Router.LispList.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.loc_reach_algorithm = Native.Router.LispList.LocReachAlgorithm()
                self.loc_reach_algorithm.parent = self
                self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                self.locator_down = Native.Router.LispList.LocatorDown()
                self.locator_down.parent = self
                self._children_name_map["locator_down"] = "locator-down"

                self.locator_table = Native.Router.LispList.LocatorTable()
                self.locator_table.parent = self
                self._children_name_map["locator_table"] = "locator-table"

                self.map_request = Native.Router.LispList.MapRequest()
                self.map_request.parent = self
                self._children_name_map["map_request"] = "map-request"

                self.map_server = Native.Router.LispList.MapServer()
                self.map_server.parent = self
                self._children_name_map["map_server"] = "map-server"

                self.other_xtr_probe = Native.Router.LispList.OtherXtrProbe()
                self.other_xtr_probe.parent = self
                self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                self.remote_rloc_probe = Native.Router.LispList.RemoteRlocProbe()
                self.remote_rloc_probe.parent = self
                self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                self.eid_table = Native.Router.LispList.EidTable()
                self.eid_table.parent = self
                self._children_name_map["eid_table"] = "eid-table"

                self.security = None
                self._children_name_map["security"] = "security"

                self.syslog = Native.Router.LispList.Syslog()
                self.syslog.parent = self
                self._children_name_map["syslog"] = "syslog"

                self.locator_set = YList(self)
                self.locator_scope = YList(self)
                self.prefix_list = YList(self)
                self.site = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-lisp:lisp-list" + "[lisp='" + str(self.lisp) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Router.LispList, ['lisp', 'disable_ttl_propagate', 'site_id'], name, value)


            class Default(Entity):
                """
                
                
                .. attribute:: service
                
                	Configure lisp service type
                	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service>`
                
                	**presence node**\: True
                
                .. attribute:: encapsulation
                
                	Select encapsulation type for data packets
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Encapsulation>`
                
                .. attribute:: locator_set
                
                	Configure a named locator set
                	**type**\: list of  		 :py:class:`LocatorSet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.LocatorSet>`
                
                .. attribute:: locator
                
                	Locator configuration
                	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Locator>`
                
                .. attribute:: locator_scope
                
                	Configure a locator scope
                	**type**\: list of  		 :py:class:`LocatorScope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.LocatorScope>`
                
                .. attribute:: prefix_list
                
                	Configure a named prefix list
                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.PrefixList>`
                
                .. attribute:: instance_container
                
                	EID instance\-ID
                	**type**\:  :py:class:`InstanceContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer>`
                
                .. attribute:: alt
                
                	LISP Alternative Topology, LISP\-ALT
                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Alt>`
                
                .. attribute:: control_packet
                
                	Configure control packet tx option
                	**type**\:  :py:class:`ControlPacket <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.ControlPacket>`
                
                .. attribute:: ddt
                
                	Delegated Database Tree (DDT) mapping system
                	**type**\:  :py:class:`Ddt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ddt>`
                
                	**presence node**\: True
                
                .. attribute:: decapsulation
                
                	Decapsulation behavior (e.g. filters)
                	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Decapsulation>`
                
                .. attribute:: disable_ttl_propagate
                
                	Disable ttl propagation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: etr
                
                	Configures a LISP Egress Tunnel Router (ETR)
                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Etr>`
                
                .. attribute:: ipv4
                
                	IPv4 address family
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4>`
                
                .. attribute:: ipv6
                
                	IPv6 address family
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6>`
                
                .. attribute:: loc_reach_algorithm
                
                	Configure locator reachability algorithm
                	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.LocReachAlgorithm>`
                
                .. attribute:: locator_down
                
                	Manually set locator status to down
                	**type**\:  :py:class:`LocatorDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.LocatorDown>`
                
                .. attribute:: locator_table
                
                	Specify the RLOC table
                	**type**\:  :py:class:`LocatorTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.LocatorTable>`
                
                .. attribute:: map_request
                
                	Configure map\-request handling
                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.MapRequest>`
                
                .. attribute:: map_server
                
                	Map\-Server commands
                	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.MapServer>`
                
                .. attribute:: other_xtr_probe
                
                	Configure parameters for probing of other xTRs in our site
                	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.OtherXtrProbe>`
                
                .. attribute:: remote_rloc_probe
                
                	Configure parameters for probing of remote RLOCs
                	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.RemoteRlocProbe>`
                
                .. attribute:: eid_table
                
                	Configure an EID instance for a VRF
                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable>`
                
                .. attribute:: security
                
                	Enable default LISP security and authentication in reply is optional
                	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Security>`
                
                	**presence node**\: True
                
                .. attribute:: site
                
                	Configure a LISP site on a map server (MS)
                	**type**\: list of  		 :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site>`
                
                .. attribute:: site_id
                
                	Configure a site\-id for this site
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: syslog
                
                	Configure syslog option
                	**type**\:  :py:class:`Syslog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Syslog>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("service", ("service", Native.Router.LispList.Default.Service)), ("encapsulation", ("encapsulation", Native.Router.LispList.Default.Encapsulation)), ("locator-set", ("locator_set", Native.Router.LispList.Default.LocatorSet)), ("locator", ("locator", Native.Router.LispList.Default.Locator)), ("locator-scope", ("locator_scope", Native.Router.LispList.Default.LocatorScope)), ("prefix-list", ("prefix_list", Native.Router.LispList.Default.PrefixList)), ("instance-container", ("instance_container", Native.Router.LispList.Default.InstanceContainer)), ("alt", ("alt", Native.Router.LispList.Default.Alt)), ("control-packet", ("control_packet", Native.Router.LispList.Default.ControlPacket)), ("ddt", ("ddt", Native.Router.LispList.Default.Ddt)), ("decapsulation", ("decapsulation", Native.Router.LispList.Default.Decapsulation)), ("etr", ("etr", Native.Router.LispList.Default.Etr)), ("ipv4", ("ipv4", Native.Router.LispList.Default.Ipv4)), ("ipv6", ("ipv6", Native.Router.LispList.Default.Ipv6)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.LispList.Default.LocReachAlgorithm)), ("locator-down", ("locator_down", Native.Router.LispList.Default.LocatorDown)), ("locator-table", ("locator_table", Native.Router.LispList.Default.LocatorTable)), ("map-request", ("map_request", Native.Router.LispList.Default.MapRequest)), ("map-server", ("map_server", Native.Router.LispList.Default.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.LispList.Default.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.LispList.Default.RemoteRlocProbe)), ("eid-table", ("eid_table", Native.Router.LispList.Default.EidTable)), ("security", ("security", Native.Router.LispList.Default.Security)), ("site", ("site", Native.Router.LispList.Default.Site)), ("syslog", ("syslog", Native.Router.LispList.Default.Syslog))])
                    self._leafs = OrderedDict([
                        ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                        ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                    ])
                    self.disable_ttl_propagate = None
                    self.site_id = None

                    self.service = None
                    self._children_name_map["service"] = "service"

                    self.encapsulation = Native.Router.LispList.Default.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"

                    self.locator = Native.Router.LispList.Default.Locator()
                    self.locator.parent = self
                    self._children_name_map["locator"] = "locator"

                    self.instance_container = Native.Router.LispList.Default.InstanceContainer()
                    self.instance_container.parent = self
                    self._children_name_map["instance_container"] = "instance-container"

                    self.alt = Native.Router.LispList.Default.Alt()
                    self.alt.parent = self
                    self._children_name_map["alt"] = "alt"

                    self.control_packet = Native.Router.LispList.Default.ControlPacket()
                    self.control_packet.parent = self
                    self._children_name_map["control_packet"] = "control-packet"

                    self.ddt = None
                    self._children_name_map["ddt"] = "ddt"

                    self.decapsulation = Native.Router.LispList.Default.Decapsulation()
                    self.decapsulation.parent = self
                    self._children_name_map["decapsulation"] = "decapsulation"

                    self.etr = Native.Router.LispList.Default.Etr()
                    self.etr.parent = self
                    self._children_name_map["etr"] = "etr"

                    self.ipv4 = Native.Router.LispList.Default.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = Native.Router.LispList.Default.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"

                    self.loc_reach_algorithm = Native.Router.LispList.Default.LocReachAlgorithm()
                    self.loc_reach_algorithm.parent = self
                    self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                    self.locator_down = Native.Router.LispList.Default.LocatorDown()
                    self.locator_down.parent = self
                    self._children_name_map["locator_down"] = "locator-down"

                    self.locator_table = Native.Router.LispList.Default.LocatorTable()
                    self.locator_table.parent = self
                    self._children_name_map["locator_table"] = "locator-table"

                    self.map_request = Native.Router.LispList.Default.MapRequest()
                    self.map_request.parent = self
                    self._children_name_map["map_request"] = "map-request"

                    self.map_server = Native.Router.LispList.Default.MapServer()
                    self.map_server.parent = self
                    self._children_name_map["map_server"] = "map-server"

                    self.other_xtr_probe = Native.Router.LispList.Default.OtherXtrProbe()
                    self.other_xtr_probe.parent = self
                    self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                    self.remote_rloc_probe = Native.Router.LispList.Default.RemoteRlocProbe()
                    self.remote_rloc_probe.parent = self
                    self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                    self.eid_table = Native.Router.LispList.Default.EidTable()
                    self.eid_table.parent = self
                    self._children_name_map["eid_table"] = "eid-table"

                    self.security = None
                    self._children_name_map["security"] = "security"

                    self.syslog = Native.Router.LispList.Default.Syslog()
                    self.syslog.parent = self
                    self._children_name_map["syslog"] = "syslog"

                    self.locator_set = YList(self)
                    self.locator_scope = YList(self)
                    self.prefix_list = YList(self)
                    self.site = YList(self)
                    self._segment_path = lambda: "default"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Default, ['disable_ttl_propagate', 'site_id'], name, value)


                class Service(Entity):
                    """
                    Configure lisp service type
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv6
                    
                    	
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ethernet
                    
                    	
                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Service, self).__init__()

                        self.yang_name = "service"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.LispList.Default.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.LispList.Default.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.LispList.Default.Service.Ethernet))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.ipv4 = None
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = None
                        self._children_name_map["ipv6"] = "ipv6"

                        self.ethernet = None
                        self._children_name_map["ethernet"] = "ethernet"
                        self._segment_path = lambda: "service"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Service, [], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: default
                        
                        	
                        	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_>`
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.SolicitMapRequest>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Distance>`
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Encapsulation>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapCache>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapCachePersistent>`
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.ProxyItr>`
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.RouteExport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.UsePetr>`
                        
                        .. attribute:: import_
                        
                        	Redistribute LISP states internally
                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Import>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Service.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "service"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default.Service.Ipv4.Default_)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.Service.Ipv4.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Default.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.Service.Ipv4.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Default.Service.Ipv4.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Default.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.Service.Ipv4.SolicitMapRequest)), ("distance", ("distance", Native.Router.LispList.Default.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.Service.Ipv4.Import))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv4.Encapsulation')])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ])
                            self.encapsulation = None
                            self.proxy_etr = None
                            self.sgt = None
                            self.map_request_source = None

                            self.default = Native.Router.LispList.Default.Service.Ipv4.Default_()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"

                            self.database_mapping = Native.Router.LispList.Default.Service.Ipv4.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.LispList.Default.Service.Ipv4.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.LispList.Default.Service.Ipv4.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.LispList.Default.Service.Ipv4.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.LispList.Default.Service.Ipv4.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.LispList.Default.Service.Ipv4.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.LispList.Default.Service.Ipv4.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.LispList.Default.Service.Ipv4.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.distance = Native.Router.LispList.Default.Service.Ipv4.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.map_cache = Native.Router.LispList.Default.Service.Ipv4.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_persistent = Native.Router.LispList.Default.Service.Ipv4.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.proxy_itr = Native.Router.LispList.Default.Service.Ipv4.ProxyItr()
                            self.proxy_itr.parent = self
                            self._children_name_map["proxy_itr"] = "proxy-itr"

                            self.route_export = Native.Router.LispList.Default.Service.Ipv4.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.import_ = Native.Router.LispList.Default.Service.Ipv4.Import()
                            self.import_.parent = self
                            self._children_name_map["import_"] = "import"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Select encapsulation type for data packets

                            .. data:: lisp = 0

                            .. data:: vxlan = 1

                            """

                            lisp = Enum.YLeaf(0, "lisp")

                            vxlan = Enum.YLeaf(1, "vxlan")



                        class Default_(Entity):
                            """
                            
                            
                            .. attribute:: database_mapping
                            
                            	Address family specific local EID prefixes database configuration
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.DatabaseMapping>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapCacheLimit>`
                            
                            .. attribute:: map_resolver
                            
                            	Configures a LISP Map Resolver (MR)
                            	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: map_server
                            
                            	Configures a LISP Map Server (MS)
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.SolicitMapRequest>`
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Distance>`
                            
                            .. attribute:: encapsulation
                            
                            	Select encapsulation type for data packets
                            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Encapsulation>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapCache>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapCachePersistent>`
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.ProxyItr>`
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.RouteExport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.UsePetr>`
                            
                            .. attribute:: import_
                            
                            	Redistribute LISP states internally
                            	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Import>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.Default_, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Default.Service.Ipv4.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Default.Service.Ipv4.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.Service.Ipv4.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.Service.Ipv4.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.Service.Ipv4.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.Service.Ipv4.Default_.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Default.Service.Ipv4.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.Service.Ipv4.Default_.SolicitMapRequest)), ("distance", ("distance", Native.Router.LispList.Default.Service.Ipv4.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.Service.Ipv4.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.Service.Ipv4.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.Service.Ipv4.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.Service.Ipv4.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.Service.Ipv4.Default_.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.Service.Ipv4.Default_.Import))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv4.Default_.Encapsulation')])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ])
                                self.encapsulation = None
                                self.proxy_etr = None
                                self.sgt = None
                                self.map_request_source = None

                                self.database_mapping = Native.Router.LispList.Default.Service.Ipv4.Default_.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.itr = Native.Router.LispList.Default.Service.Ipv4.Default_.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.LispList.Default.Service.Ipv4.Default_.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.LispList.Default.Service.Ipv4.Default_.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.LispList.Default.Service.Ipv4.Default_.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.LispList.Default.Service.Ipv4.Default_.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.map_resolver = None
                                self._children_name_map["map_resolver"] = "map-resolver"

                                self.map_server = None
                                self._children_name_map["map_server"] = "map-server"

                                self.site_registration = Native.Router.LispList.Default.Service.Ipv4.Default_.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.LispList.Default.Service.Ipv4.Default_.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.distance = Native.Router.LispList.Default.Service.Ipv4.Default_.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.map_cache = Native.Router.LispList.Default.Service.Ipv4.Default_.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_persistent = Native.Router.LispList.Default.Service.Ipv4.Default_.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.proxy_itr = Native.Router.LispList.Default.Service.Ipv4.Default_.ProxyItr()
                                self.proxy_itr.parent = self
                                self._children_name_map["proxy_itr"] = "proxy-itr"

                                self.route_export = Native.Router.LispList.Default.Service.Ipv4.Default_.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.import_ = Native.Router.LispList.Default.Service.Ipv4.Default_.Import()
                                self.import_.parent = self
                                self._children_name_map["import_"] = "import"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "default"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                            class Encapsulation(Enum):
                                """
                                Encapsulation (Enum Class)

                                Select encapsulation type for data packets

                                .. data:: lisp = 0

                                .. data:: vxlan = 1

                                """

                                lisp = Enum.YLeaf(0, "lisp")

                                vxlan = Enum.YLeaf(1, "vxlan")



                            class DatabaseMapping(Entity):
                                """
                                Address family specific local EID prefixes database configuration
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.LispList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.DatabaseMapping, [], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ipv4.Default_.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.Default_.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures a LISP Map Resolver (MR)
                                
                                .. attribute:: map_request
                                
                                	Map\-Request processing options
                                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_request = Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest()
                                    self.map_request.parent = self
                                    self._children_name_map["map_request"] = "map-request"
                                    self._segment_path = lambda: "map-resolver"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver, [], name, value)


                                class MapRequest(Entity):
                                    """
                                    Map\-Request processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest, self).__init__()

                                        self.yang_name = "map-request"
                                        self.yang_parent_name = "map-resolver"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	Influence which source RLOCs map requests are accepted from
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            Influence which source RLOCs map requests are accepted from
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.List>`
                                            
                                            .. attribute:: registered
                                            
                                            	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"

                                                self.registered = Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered()
                                                self.registered.parent = self
                                                self._children_name_map["registered"] = "registered"
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                            class Registered(Entity):
                                                """
                                                ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                                
                                                .. attribute:: list
                                                
                                                	Define allowed prefixes using an ip[v6] prefix list
                                                	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                    self.yang_name = "registered"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                    self._leafs = OrderedDict()

                                                    self.list = Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                    self.list.parent = self
                                                    self._children_name_map["list"] = "list"
                                                    self._segment_path = lambda: "registered"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                                class List(Entity):
                                                    """
                                                    Define allowed prefixes using an ip[v6] prefix list
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 prefixes
                                                    	**type**\: str
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 prefixes
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                        self.yang_name = "list"
                                                        self.yang_parent_name = "registered"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "list"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                            class MapServer(Entity):
                                """
                                Configures a LISP Map Server (MS)
                                
                                .. attribute:: map_register
                                
                                	Map\-Register processing options
                                	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_register = Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister()
                                    self.map_register.parent = self
                                    self._children_name_map["map_register"] = "map-register"
                                    self._segment_path = lambda: "map-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer, [], name, value)


                                class MapRegister(Entity):
                                    """
                                    Map\-Register processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister, self).__init__()

                                        self.yang_name = "map-register"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-register"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	RLOC Source IP address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-register"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            RLOC Source IP address
                                            
                                            .. attribute:: allowed_locator
                                            
                                            	Against sites' allowed\-locators policy
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                                ])
                                                self.allowed_locator = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: away
                                
                                	Administrative distance for RIB route installation
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.away = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: away_eids
                                
                                	Map cache configuration for the away table
                                	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.MapCache.AwayEids>`
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.LispList.Default.Service.Ipv4.Default_.MapCache.AwayEids))])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None

                                    self.away_eids = Native.Router.LispList.Default.Service.Ipv4.Default_.MapCache.AwayEids()
                                    self.away_eids.parent = self
                                    self._children_name_map["away_eids"] = "away-eids"
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapCache, ['site_registration'], name, value)


                                class AwayEids(Entity):
                                    """
                                    Map cache configuration for the away table
                                    
                                    .. attribute:: send_map_request
                                    
                                    	Export away table entries into the map cache with action set to send\-map\-request
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapCache.AwayEids, self).__init__()

                                        self.yang_name = "away-eids"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                        ])
                                        self.send_map_request = None
                                        self._segment_path = lambda: "away-eids"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.MapCachePersistent, ['interval'], name, value)


                            class ProxyItr(Entity):
                                """
                                Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                
                                .. attribute:: ipv4_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.ProxyItr, self).__init__()

                                    self.yang_name = "proxy-itr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                        ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                    ])
                                    self.ipv4_addr = None
                                    self.ipv6_addr = None
                                    self._segment_path = lambda: "proxy-itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	
                                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.UsePetr.Priority>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.Service.Ipv4.Default_.UsePetr.Priority))])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ])
                                    self.locator_address = None

                                    self.priority = Native.Router.LispList.Default.Service.Ipv4.Default_.UsePetr.Priority()
                                    self.priority.parent = self
                                    self._children_name_map["priority"] = "priority"
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.UsePetr, ['locator_address'], name, value)


                                class Priority(Entity):
                                    """
                                    
                                    
                                    .. attribute:: priority_value
                                    
                                    	Configures which Locators from a set are preferred
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: weight
                                    
                                    	Traffic load\-spreading among Locators
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.Default_.UsePetr.Priority, self).__init__()

                                        self.yang_name = "priority"
                                        self.yang_parent_name = "use-petr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                        ])
                                        self.priority_value = None
                                        self.weight = None
                                        self._segment_path = lambda: "priority"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                            class Import(Entity):
                                """
                                Redistribute LISP states internally
                                
                                .. attribute:: database
                                
                                	Redistribute LISP internal states as database mapping
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Default_.Import.Database>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Default_.Import, self).__init__()

                                    self.yang_name = "import"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.Service.Ipv4.Default_.Import.Database))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.LispList.Default.Service.Ipv4.Default_.Import.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"
                                    self._segment_path = lambda: "import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Import, [], name, value)


                                class Database(Entity):
                                    """
                                    Redistribute LISP internal states as database mapping
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.Default_.Import.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.site_registration = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Default.Service.Ipv4.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.LispList.Default.Service.Ipv4.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ipv4.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.LispList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: away
                            
                            	Administrative distance for RIB route installation
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.away = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: away_eids
                            
                            	Map cache configuration for the away table
                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.MapCache.AwayEids>`
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.LispList.Default.Service.Ipv4.MapCache.AwayEids))])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None

                                self.away_eids = Native.Router.LispList.Default.Service.Ipv4.MapCache.AwayEids()
                                self.away_eids.parent = self
                                self._children_name_map["away_eids"] = "away-eids"
                                self._segment_path = lambda: "map-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapCache, ['site_registration'], name, value)


                            class AwayEids(Entity):
                                """
                                Map cache configuration for the away table
                                
                                .. attribute:: send_map_request
                                
                                	Export away table entries into the map cache with action set to send\-map\-request
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                    self.yang_name = "away-eids"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                    ])
                                    self.send_map_request = None
                                    self._segment_path = lambda: "away-eids"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                        class ProxyItr(Entity):
                            """
                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            
                            .. attribute:: ipv4_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.ProxyItr, self).__init__()

                                self.yang_name = "proxy-itr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                ])
                                self.ipv4_addr = None
                                self.ipv6_addr = None
                                self._segment_path = lambda: "proxy-itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	
                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.UsePetr.Priority>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.Service.Ipv4.UsePetr.Priority))])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ])
                                self.locator_address = None

                                self.priority = Native.Router.LispList.Default.Service.Ipv4.UsePetr.Priority()
                                self.priority.parent = self
                                self._children_name_map["priority"] = "priority"
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                            class Priority(Entity):
                                """
                                
                                
                                .. attribute:: priority_value
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.UsePetr.Priority, self).__init__()

                                    self.yang_name = "priority"
                                    self.yang_parent_name = "use-petr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.priority_value = None
                                    self.weight = None
                                    self._segment_path = lambda: "priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                        class Import(Entity):
                            """
                            Redistribute LISP states internally
                            
                            .. attribute:: database
                            
                            	Redistribute LISP internal states as database mapping
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv4.Import.Database>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv4.Import, self).__init__()

                                self.yang_name = "import"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.Service.Ipv4.Import.Database))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.LispList.Default.Service.Ipv4.Import.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"
                                self._segment_path = lambda: "import"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Import, [], name, value)


                            class Database(Entity):
                                """
                                Redistribute LISP internal states as database mapping
                                
                                .. attribute:: site_registration
                                
                                	Import states from site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv4.Import.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.site_registration = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "database"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                    class Ipv6(Entity):
                        """
                        
                        
                        .. attribute:: default
                        
                        	
                        	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_>`
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.SolicitMapRequest>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Distance>`
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Encapsulation>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapCache>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapCachePersistent>`
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.ProxyItr>`
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.RouteExport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.UsePetr>`
                        
                        .. attribute:: import_
                        
                        	Redistribute LISP states internally
                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Import>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Service.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "service"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default.Service.Ipv6.Default_)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.Service.Ipv6.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Default.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.Service.Ipv6.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Default.Service.Ipv6.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Default.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.Service.Ipv6.SolicitMapRequest)), ("distance", ("distance", Native.Router.LispList.Default.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.Service.Ipv6.Import))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv6.Encapsulation')])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ])
                            self.encapsulation = None
                            self.proxy_etr = None
                            self.sgt = None
                            self.map_request_source = None

                            self.default = Native.Router.LispList.Default.Service.Ipv6.Default_()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"

                            self.database_mapping = Native.Router.LispList.Default.Service.Ipv6.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.LispList.Default.Service.Ipv6.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.LispList.Default.Service.Ipv6.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.LispList.Default.Service.Ipv6.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.LispList.Default.Service.Ipv6.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.LispList.Default.Service.Ipv6.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.LispList.Default.Service.Ipv6.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.LispList.Default.Service.Ipv6.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.distance = Native.Router.LispList.Default.Service.Ipv6.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.map_cache = Native.Router.LispList.Default.Service.Ipv6.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_persistent = Native.Router.LispList.Default.Service.Ipv6.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.proxy_itr = Native.Router.LispList.Default.Service.Ipv6.ProxyItr()
                            self.proxy_itr.parent = self
                            self._children_name_map["proxy_itr"] = "proxy-itr"

                            self.route_export = Native.Router.LispList.Default.Service.Ipv6.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.import_ = Native.Router.LispList.Default.Service.Ipv6.Import()
                            self.import_.parent = self
                            self._children_name_map["import_"] = "import"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Select encapsulation type for data packets

                            .. data:: lisp = 0

                            .. data:: vxlan = 1

                            """

                            lisp = Enum.YLeaf(0, "lisp")

                            vxlan = Enum.YLeaf(1, "vxlan")



                        class Default_(Entity):
                            """
                            
                            
                            .. attribute:: database_mapping
                            
                            	Address family specific local EID prefixes database configuration
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.DatabaseMapping>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapCacheLimit>`
                            
                            .. attribute:: map_resolver
                            
                            	Configures a LISP Map Resolver (MR)
                            	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: map_server
                            
                            	Configures a LISP Map Server (MS)
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.SolicitMapRequest>`
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Distance>`
                            
                            .. attribute:: encapsulation
                            
                            	Select encapsulation type for data packets
                            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Encapsulation>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapCache>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapCachePersistent>`
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.ProxyItr>`
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.RouteExport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.UsePetr>`
                            
                            .. attribute:: import_
                            
                            	Redistribute LISP states internally
                            	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Import>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.Default_, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Default.Service.Ipv6.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Default.Service.Ipv6.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.Service.Ipv6.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.Service.Ipv6.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.Service.Ipv6.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.Service.Ipv6.Default_.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Default.Service.Ipv6.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.Service.Ipv6.Default_.SolicitMapRequest)), ("distance", ("distance", Native.Router.LispList.Default.Service.Ipv6.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.Service.Ipv6.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.Service.Ipv6.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.Service.Ipv6.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.Service.Ipv6.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.Service.Ipv6.Default_.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.Service.Ipv6.Default_.Import))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv6.Default_.Encapsulation')])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ])
                                self.encapsulation = None
                                self.proxy_etr = None
                                self.sgt = None
                                self.map_request_source = None

                                self.database_mapping = Native.Router.LispList.Default.Service.Ipv6.Default_.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.itr = Native.Router.LispList.Default.Service.Ipv6.Default_.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.LispList.Default.Service.Ipv6.Default_.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.LispList.Default.Service.Ipv6.Default_.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.LispList.Default.Service.Ipv6.Default_.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.LispList.Default.Service.Ipv6.Default_.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.map_resolver = None
                                self._children_name_map["map_resolver"] = "map-resolver"

                                self.map_server = None
                                self._children_name_map["map_server"] = "map-server"

                                self.site_registration = Native.Router.LispList.Default.Service.Ipv6.Default_.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.LispList.Default.Service.Ipv6.Default_.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.distance = Native.Router.LispList.Default.Service.Ipv6.Default_.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.map_cache = Native.Router.LispList.Default.Service.Ipv6.Default_.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_persistent = Native.Router.LispList.Default.Service.Ipv6.Default_.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.proxy_itr = Native.Router.LispList.Default.Service.Ipv6.Default_.ProxyItr()
                                self.proxy_itr.parent = self
                                self._children_name_map["proxy_itr"] = "proxy-itr"

                                self.route_export = Native.Router.LispList.Default.Service.Ipv6.Default_.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.import_ = Native.Router.LispList.Default.Service.Ipv6.Default_.Import()
                                self.import_.parent = self
                                self._children_name_map["import_"] = "import"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "default"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                            class Encapsulation(Enum):
                                """
                                Encapsulation (Enum Class)

                                Select encapsulation type for data packets

                                .. data:: lisp = 0

                                .. data:: vxlan = 1

                                """

                                lisp = Enum.YLeaf(0, "lisp")

                                vxlan = Enum.YLeaf(1, "vxlan")



                            class DatabaseMapping(Entity):
                                """
                                Address family specific local EID prefixes database configuration
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.LispList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.DatabaseMapping, [], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ipv6.Default_.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.Default_.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures a LISP Map Resolver (MR)
                                
                                .. attribute:: map_request
                                
                                	Map\-Request processing options
                                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_request = Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest()
                                    self.map_request.parent = self
                                    self._children_name_map["map_request"] = "map-request"
                                    self._segment_path = lambda: "map-resolver"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver, [], name, value)


                                class MapRequest(Entity):
                                    """
                                    Map\-Request processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest, self).__init__()

                                        self.yang_name = "map-request"
                                        self.yang_parent_name = "map-resolver"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	Influence which source RLOCs map requests are accepted from
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            Influence which source RLOCs map requests are accepted from
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.List>`
                                            
                                            .. attribute:: registered
                                            
                                            	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"

                                                self.registered = Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered()
                                                self.registered.parent = self
                                                self._children_name_map["registered"] = "registered"
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                            class Registered(Entity):
                                                """
                                                ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                                
                                                .. attribute:: list
                                                
                                                	Define allowed prefixes using an ip[v6] prefix list
                                                	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                    self.yang_name = "registered"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                    self._leafs = OrderedDict()

                                                    self.list = Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                    self.list.parent = self
                                                    self._children_name_map["list"] = "list"
                                                    self._segment_path = lambda: "registered"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                                class List(Entity):
                                                    """
                                                    Define allowed prefixes using an ip[v6] prefix list
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 prefixes
                                                    	**type**\: str
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 prefixes
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                        self.yang_name = "list"
                                                        self.yang_parent_name = "registered"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "list"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                            class MapServer(Entity):
                                """
                                Configures a LISP Map Server (MS)
                                
                                .. attribute:: map_register
                                
                                	Map\-Register processing options
                                	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_register = Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister()
                                    self.map_register.parent = self
                                    self._children_name_map["map_register"] = "map-register"
                                    self._segment_path = lambda: "map-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer, [], name, value)


                                class MapRegister(Entity):
                                    """
                                    Map\-Register processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister, self).__init__()

                                        self.yang_name = "map-register"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-register"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	RLOC Source IP address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-register"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            RLOC Source IP address
                                            
                                            .. attribute:: allowed_locator
                                            
                                            	Against sites' allowed\-locators policy
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                                ])
                                                self.allowed_locator = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: away
                                
                                	Administrative distance for RIB route installation
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.away = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: away_eids
                                
                                	Map cache configuration for the away table
                                	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.MapCache.AwayEids>`
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.LispList.Default.Service.Ipv6.Default_.MapCache.AwayEids))])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None

                                    self.away_eids = Native.Router.LispList.Default.Service.Ipv6.Default_.MapCache.AwayEids()
                                    self.away_eids.parent = self
                                    self._children_name_map["away_eids"] = "away-eids"
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapCache, ['site_registration'], name, value)


                                class AwayEids(Entity):
                                    """
                                    Map cache configuration for the away table
                                    
                                    .. attribute:: send_map_request
                                    
                                    	Export away table entries into the map cache with action set to send\-map\-request
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapCache.AwayEids, self).__init__()

                                        self.yang_name = "away-eids"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                        ])
                                        self.send_map_request = None
                                        self._segment_path = lambda: "away-eids"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.MapCachePersistent, ['interval'], name, value)


                            class ProxyItr(Entity):
                                """
                                Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                
                                .. attribute:: ipv4_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.ProxyItr, self).__init__()

                                    self.yang_name = "proxy-itr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                        ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                    ])
                                    self.ipv4_addr = None
                                    self.ipv6_addr = None
                                    self._segment_path = lambda: "proxy-itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	
                                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.UsePetr.Priority>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.Service.Ipv6.Default_.UsePetr.Priority))])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ])
                                    self.locator_address = None

                                    self.priority = Native.Router.LispList.Default.Service.Ipv6.Default_.UsePetr.Priority()
                                    self.priority.parent = self
                                    self._children_name_map["priority"] = "priority"
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.UsePetr, ['locator_address'], name, value)


                                class Priority(Entity):
                                    """
                                    
                                    
                                    .. attribute:: priority_value
                                    
                                    	Configures which Locators from a set are preferred
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: weight
                                    
                                    	Traffic load\-spreading among Locators
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.Default_.UsePetr.Priority, self).__init__()

                                        self.yang_name = "priority"
                                        self.yang_parent_name = "use-petr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                        ])
                                        self.priority_value = None
                                        self.weight = None
                                        self._segment_path = lambda: "priority"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                            class Import(Entity):
                                """
                                Redistribute LISP states internally
                                
                                .. attribute:: database
                                
                                	Redistribute LISP internal states as database mapping
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Default_.Import.Database>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Default_.Import, self).__init__()

                                    self.yang_name = "import"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.Service.Ipv6.Default_.Import.Database))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.LispList.Default.Service.Ipv6.Default_.Import.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"
                                    self._segment_path = lambda: "import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Import, [], name, value)


                                class Database(Entity):
                                    """
                                    Redistribute LISP internal states as database mapping
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.Default_.Import.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.site_registration = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Default.Service.Ipv6.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.LispList.Default.Service.Ipv6.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ipv6.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.LispList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: away
                            
                            	Administrative distance for RIB route installation
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.away = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: away_eids
                            
                            	Map cache configuration for the away table
                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.MapCache.AwayEids>`
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.LispList.Default.Service.Ipv6.MapCache.AwayEids))])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None

                                self.away_eids = Native.Router.LispList.Default.Service.Ipv6.MapCache.AwayEids()
                                self.away_eids.parent = self
                                self._children_name_map["away_eids"] = "away-eids"
                                self._segment_path = lambda: "map-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapCache, ['site_registration'], name, value)


                            class AwayEids(Entity):
                                """
                                Map cache configuration for the away table
                                
                                .. attribute:: send_map_request
                                
                                	Export away table entries into the map cache with action set to send\-map\-request
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                    self.yang_name = "away-eids"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                    ])
                                    self.send_map_request = None
                                    self._segment_path = lambda: "away-eids"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                        class ProxyItr(Entity):
                            """
                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            
                            .. attribute:: ipv4_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.ProxyItr, self).__init__()

                                self.yang_name = "proxy-itr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                ])
                                self.ipv4_addr = None
                                self.ipv6_addr = None
                                self._segment_path = lambda: "proxy-itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	
                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.UsePetr.Priority>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.Service.Ipv6.UsePetr.Priority))])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ])
                                self.locator_address = None

                                self.priority = Native.Router.LispList.Default.Service.Ipv6.UsePetr.Priority()
                                self.priority.parent = self
                                self._children_name_map["priority"] = "priority"
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                            class Priority(Entity):
                                """
                                
                                
                                .. attribute:: priority_value
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.UsePetr.Priority, self).__init__()

                                    self.yang_name = "priority"
                                    self.yang_parent_name = "use-petr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.priority_value = None
                                    self.weight = None
                                    self._segment_path = lambda: "priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                        class Import(Entity):
                            """
                            Redistribute LISP states internally
                            
                            .. attribute:: database
                            
                            	Redistribute LISP internal states as database mapping
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ipv6.Import.Database>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ipv6.Import, self).__init__()

                                self.yang_name = "import"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.Service.Ipv6.Import.Database))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.LispList.Default.Service.Ipv6.Import.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"
                                self._segment_path = lambda: "import"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Import, [], name, value)


                            class Database(Entity):
                                """
                                Redistribute LISP internal states as database mapping
                                
                                .. attribute:: site_registration
                                
                                	Import states from site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ipv6.Import.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.site_registration = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "database"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                    class Ethernet(Entity):
                        """
                        
                        
                        .. attribute:: default
                        
                        	
                        	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_>`
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Encapsulation>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.SolicitMapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Service.Ethernet, self).__init__()

                            self.yang_name = "ethernet"
                            self.yang_parent_name = "service"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default.Service.Ethernet.Default_)), ("encapsulation", ("encapsulation", Native.Router.LispList.Default.Service.Ethernet.Encapsulation)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Default.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.Service.Ethernet.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ethernet.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Default.Service.Ethernet.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Default.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.Service.Ethernet.SolicitMapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                            ])
                            self.map_request_source = None

                            self.default = Native.Router.LispList.Default.Service.Ethernet.Default_()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"

                            self.encapsulation = Native.Router.LispList.Default.Service.Ethernet.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.database_mapping = Native.Router.LispList.Default.Service.Ethernet.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.LispList.Default.Service.Ethernet.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.LispList.Default.Service.Ethernet.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.LispList.Default.Service.Ethernet.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.LispList.Default.Service.Ethernet.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.LispList.Default.Service.Ethernet.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.LispList.Default.Service.Ethernet.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.LispList.Default.Service.Ethernet.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"
                            self._segment_path = lambda: "ethernet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet, ['map_request_source'], name, value)


                        class Default_(Entity):
                            """
                            
                            
                            .. attribute:: encapsulation
                            
                            	Select encapsulation type for data packets
                            	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Encapsulation>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: database_mapping
                            
                            	Address family specific local EID prefixes database configuration
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.DatabaseMapping>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapCacheLimit>`
                            
                            .. attribute:: map_resolver
                            
                            	Configures a LISP Map Resolver (MR)
                            	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: map_server
                            
                            	Configures a LISP Map Server (MS)
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.SolicitMapRequest>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.Default_, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Router.LispList.Default.Service.Ethernet.Default_.Encapsulation)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.Service.Ethernet.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Default.Service.Ethernet.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.Service.Ethernet.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.Service.Ethernet.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.Service.Ethernet.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.Service.Ethernet.Default_.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Default.Service.Ethernet.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.Service.Ethernet.Default_.SolicitMapRequest))])
                                self._leafs = OrderedDict([
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                ])
                                self.map_request_source = None

                                self.encapsulation = Native.Router.LispList.Default.Service.Ethernet.Default_.Encapsulation()
                                self.encapsulation.parent = self
                                self._children_name_map["encapsulation"] = "encapsulation"

                                self.database_mapping = Native.Router.LispList.Default.Service.Ethernet.Default_.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.itr = Native.Router.LispList.Default.Service.Ethernet.Default_.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.LispList.Default.Service.Ethernet.Default_.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.LispList.Default.Service.Ethernet.Default_.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.LispList.Default.Service.Ethernet.Default_.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.LispList.Default.Service.Ethernet.Default_.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.map_resolver = None
                                self._children_name_map["map_resolver"] = "map-resolver"

                                self.map_server = None
                                self._children_name_map["map_server"] = "map-server"

                                self.site_registration = Native.Router.LispList.Default.Service.Ethernet.Default_.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.LispList.Default.Service.Ethernet.Default_.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"
                                self._segment_path = lambda: "default"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_, ['map_request_source'], name, value)


                            class Encapsulation(Entity):
                                """
                                Select encapsulation type for data packets
                                
                                .. attribute:: vxlan
                                
                                	Use VXLAN encapsulation for data packets
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.Encapsulation, self).__init__()

                                    self.yang_name = "encapsulation"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                    ])
                                    self.vxlan = None
                                    self._segment_path = lambda: "encapsulation"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.Encapsulation, ['vxlan'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Address family specific local EID prefixes database configuration
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.LispList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.DatabaseMapping, [], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ethernet.Default_.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ethernet.Default_.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures a LISP Map Resolver (MR)
                                
                                .. attribute:: map_request
                                
                                	Map\-Request processing options
                                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_request = Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest()
                                    self.map_request.parent = self
                                    self._children_name_map["map_request"] = "map-request"
                                    self._segment_path = lambda: "map-resolver"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver, [], name, value)


                                class MapRequest(Entity):
                                    """
                                    Map\-Request processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest, self).__init__()

                                        self.yang_name = "map-request"
                                        self.yang_parent_name = "map-resolver"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	Influence which source RLOCs map requests are accepted from
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            Influence which source RLOCs map requests are accepted from
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.List>`
                                            
                                            .. attribute:: registered
                                            
                                            	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"

                                                self.registered = Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered()
                                                self.registered.parent = self
                                                self._children_name_map["registered"] = "registered"
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                            class Registered(Entity):
                                                """
                                                ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                                
                                                .. attribute:: list
                                                
                                                	Define allowed prefixes using an ip[v6] prefix list
                                                	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                    self.yang_name = "registered"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                    self._leafs = OrderedDict()

                                                    self.list = Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                    self.list.parent = self
                                                    self._children_name_map["list"] = "list"
                                                    self._segment_path = lambda: "registered"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                                class List(Entity):
                                                    """
                                                    Define allowed prefixes using an ip[v6] prefix list
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 prefixes
                                                    	**type**\: str
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 prefixes
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                        self.yang_name = "list"
                                                        self.yang_parent_name = "registered"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "list"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                            class MapServer(Entity):
                                """
                                Configures a LISP Map Server (MS)
                                
                                .. attribute:: map_register
                                
                                	Map\-Register processing options
                                	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_register = Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister()
                                    self.map_register.parent = self
                                    self._children_name_map["map_register"] = "map-register"
                                    self._segment_path = lambda: "map-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer, [], name, value)


                                class MapRegister(Entity):
                                    """
                                    Map\-Register processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister, self).__init__()

                                        self.yang_name = "map-register"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-register"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	RLOC Source IP address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-register"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            RLOC Source IP address
                                            
                                            .. attribute:: allowed_locator
                                            
                                            	Against sites' allowed\-locators policy
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                                ])
                                                self.allowed_locator = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Default_.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class Encapsulation(Entity):
                            """
                            Select encapsulation type for data packets
                            
                            .. attribute:: vxlan
                            
                            	Use VXLAN encapsulation for data packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                ])
                                self.vxlan = None
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Encapsulation, ['vxlan'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Default.Service.Ethernet.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.LispList.Default.Service.Ethernet.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.Service.Ethernet.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.LispList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Service.Ethernet.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                class Encapsulation(Entity):
                    """
                    Select encapsulation type for data packets
                    
                    .. attribute:: vxlan
                    
                    	Use VXLAN encapsulation for data packets
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Encapsulation, self).__init__()

                        self.yang_name = "encapsulation"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                        ])
                        self.vxlan = None
                        self._segment_path = lambda: "encapsulation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Encapsulation, ['vxlan'], name, value)


                class LocatorSet(Entity):
                    """
                    Configure a named locator set
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: auto_discover_rlocs
                    
                    	Auto discover locators registered by other xTRs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipv4_interface
                    
                    	Use IPv4 address of interface as locator
                    	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.LocatorSet.IPv4Interface>`
                    
                    .. attribute:: ipv6_interface
                    
                    	Use IPv6 address of interface as locator
                    	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.LocatorSet.IPv6Interface>`
                    
                    .. attribute:: ip_address
                    
                    	Use IPv6 address of interface as locator
                    	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.LocatorSet.IpAddress>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.LocatorSet, self).__init__()

                        self.yang_name = "locator-set"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.LocatorSet.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.LocatorSet.IPv6Interface)), ("ip-address", ("ip_address", Native.Router.LispList.Default.LocatorSet.IpAddress))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                        ])
                        self.name = None
                        self.auto_discover_rlocs = None

                        self.ipv4_interface = YList(self)
                        self.ipv6_interface = YList(self)
                        self.ip_address = YList(self)
                        self._segment_path = lambda: "locator-set" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.LocatorSet, ['name', 'auto_discover_rlocs'], name, value)


                    class IPv4Interface(Entity):
                        """
                        Use IPv4 address of interface as locator
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: priority
                        
                        	Configures which Locators from a set are preferred
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: weight
                        
                        	Traffic load\-spreading among Locators
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.LocatorSet.IPv4Interface, self).__init__()

                            self.yang_name = "IPv4-interface"
                            self.yang_parent_name = "locator-set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                            ])
                            self.name = None
                            self.priority = None
                            self.weight = None
                            self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.LocatorSet.IPv4Interface, ['name', 'priority', 'weight'], name, value)


                    class IPv6Interface(Entity):
                        """
                        Use IPv6 address of interface as locator
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: priority
                        
                        	Configures which Locators from a set are preferred
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: weight
                        
                        	Traffic load\-spreading among Locators
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.LocatorSet.IPv6Interface, self).__init__()

                            self.yang_name = "IPv6-interface"
                            self.yang_parent_name = "locator-set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                            ])
                            self.name = None
                            self.priority = None
                            self.weight = None
                            self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.LocatorSet.IPv6Interface, ['name', 'priority', 'weight'], name, value)


                    class IpAddress(Entity):
                        """
                        Use IPv6 address of interface as locator
                        
                        .. attribute:: ip  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	Configures which Locators from a set are preferred
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: weight
                        
                        	Traffic load\-spreading among Locators
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.LocatorSet.IpAddress, self).__init__()

                            self.yang_name = "ip-address"
                            self.yang_parent_name = "locator-set"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                            ])
                            self.ip = None
                            self.priority = None
                            self.weight = None
                            self._segment_path = lambda: "ip-address" + "[ip='" + str(self.ip) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.LocatorSet.IpAddress, ['ip', 'priority', 'weight'], name, value)


                class Locator(Entity):
                    """
                    Locator configuration
                    
                    .. attribute:: default_set
                    
                    	Specify a default locator\-set
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Locator, self).__init__()

                        self.yang_name = "locator"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default_set', (YLeaf(YType.str, 'default-set'), ['str'])),
                        ])
                        self.default_set = None
                        self._segment_path = lambda: "locator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Locator, ['default_set'], name, value)


                class LocatorScope(Entity):
                    """
                    Configure a locator scope
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: rloc_prefix
                    
                    	RLOC prefix to check against ITR RLOC and ETR RLOC
                    	**type**\: union of the below types:
                    
                    		**type**\: list of str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                    
                    		**type**\: list of str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    .. attribute:: rtr_locator_set
                    
                    	Locator\-set of RTR to use in proxy reply for disjoint/cross AF RLOC
                    	**type**\: list of str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.LocatorScope, self).__init__()

                        self.yang_name = "locator-scope"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('rloc_prefix', (YLeafList(YType.str, 'rloc-prefix'), ['str','str'])),
                            ('rtr_locator_set', (YLeafList(YType.str, 'rtr-locator-set'), ['str'])),
                        ])
                        self.name = None
                        self.rloc_prefix = []
                        self.rtr_locator_set = []
                        self._segment_path = lambda: "locator-scope" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.LocatorScope, ['name', 'rloc_prefix', 'rtr_locator_set'], name, value)


                class PrefixList(Entity):
                    """
                    Configure a named prefix list
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: ipv4_prefix
                    
                    	IPv4 EID\-prefix
                    	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.PrefixList.Ipv4Prefix>`
                    
                    .. attribute:: ipv6_prefix
                    
                    	IPv6 EID\-prefix
                    	**type**\: list of  		 :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.PrefixList.Ipv6Prefix>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.PrefixList, self).__init__()

                        self.yang_name = "prefix-list"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.LispList.Default.PrefixList.Ipv4Prefix)), ("ipv6-prefix", ("ipv6_prefix", Native.Router.LispList.Default.PrefixList.Ipv6Prefix))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.ipv4_prefix = YList(self)
                        self.ipv6_prefix = YList(self)
                        self._segment_path = lambda: "prefix-list" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.PrefixList, ['name'], name, value)


                    class Ipv4Prefix(Entity):
                        """
                        IPv4 EID\-prefix
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.PrefixList.Ipv4Prefix, self).__init__()

                            self.yang_name = "ipv4-prefix"
                            self.yang_parent_name = "prefix-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ])
                            self.prefix = None
                            self._segment_path = lambda: "ipv4-prefix" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.PrefixList.Ipv4Prefix, ['prefix'], name, value)


                    class Ipv6Prefix(Entity):
                        """
                        IPv6 EID\-prefix
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.PrefixList.Ipv6Prefix, self).__init__()

                            self.yang_name = "ipv6-prefix"
                            self.yang_parent_name = "prefix-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ])
                            self.prefix = None
                            self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.PrefixList.Ipv6Prefix, ['prefix'], name, value)


                class InstanceContainer(Entity):
                    """
                    EID instance\-ID
                    
                    .. attribute:: instance_list
                    
                    	
                    	**type**\: list of  		 :py:class:`InstanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.InstanceContainer, self).__init__()

                        self.yang_name = "instance-container"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("instance-list", ("instance_list", Native.Router.LispList.Default.InstanceContainer.InstanceList))])
                        self._leafs = OrderedDict()

                        self.instance_list = YList(self)
                        self._segment_path = lambda: "instance-container"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer, [], name, value)


                    class InstanceList(Entity):
                        """
                        
                        
                        .. attribute:: instance_id  (key)
                        
                        	EID instance\-ID
                        	**type**\: int
                        
                        	**range:** 0..16777214
                        
                        .. attribute:: default
                        
                        	
                        	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_>`
                        
                        .. attribute:: decapsulation
                        
                        	Decapsulation behavior (e.g. filters)
                        	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation>`
                        
                        .. attribute:: disable_ttl_propagate
                        
                        	Disable ttl propagation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dynamic_eid
                        
                        	Configure a dynamic EID
                        	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid>`
                        
                        .. attribute:: loc_reach_algorithm
                        
                        	Configure locator reachability algorithm
                        	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.LocReachAlgorithm>`
                        
                        .. attribute:: map_server
                        
                        	Map\-Server commands
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer>`
                        
                        .. attribute:: other_xtr_probe
                        
                        	Configure parameters for probing of other xTRs in our site
                        	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.OtherXtrProbe>`
                        
                        .. attribute:: remote_rloc_probe
                        
                        	Configure parameters for probing of remote RLOCs
                        	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.RemoteRlocProbe>`
                        
                        .. attribute:: service
                        
                        	Configure lisp service type
                        	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList, self).__init__()

                            self.yang_name = "instance-list"
                            self.yang_parent_name = "instance-container"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance_id']
                            self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_)), ("decapsulation", ("decapsulation", Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation)), ("dynamic-eid", ("dynamic_eid", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.LispList.Default.InstanceContainer.InstanceList.LocReachAlgorithm)), ("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.LispList.Default.InstanceContainer.InstanceList.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.LispList.Default.InstanceContainer.InstanceList.RemoteRlocProbe)), ("service", ("service", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service))])
                            self._leafs = OrderedDict([
                                ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                            ])
                            self.instance_id = None
                            self.disable_ttl_propagate = None

                            self.default = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_()
                            self.default.parent = self
                            self._children_name_map["default"] = "default"

                            self.decapsulation = Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation()
                            self.decapsulation.parent = self
                            self._children_name_map["decapsulation"] = "decapsulation"

                            self.loc_reach_algorithm = Native.Router.LispList.Default.InstanceContainer.InstanceList.LocReachAlgorithm()
                            self.loc_reach_algorithm.parent = self
                            self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                            self.map_server = Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer()
                            self.map_server.parent = self
                            self._children_name_map["map_server"] = "map-server"

                            self.other_xtr_probe = Native.Router.LispList.Default.InstanceContainer.InstanceList.OtherXtrProbe()
                            self.other_xtr_probe.parent = self
                            self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                            self.remote_rloc_probe = Native.Router.LispList.Default.InstanceContainer.InstanceList.RemoteRlocProbe()
                            self.remote_rloc_probe.parent = self
                            self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                            self.service = None
                            self._children_name_map["service"] = "service"

                            self.dynamic_eid = YList(self)
                            self._segment_path = lambda: "instance-list" + "[instance-id='" + str(self.instance_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList, ['instance_id', 'disable_ttl_propagate'], name, value)


                        class Default_(Entity):
                            """
                            
                            
                            .. attribute:: decapsulation
                            
                            	Decapsulation behavior (e.g. filters)
                            	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation>`
                            
                            .. attribute:: disable_ttl_propagate
                            
                            	Disable ttl propagation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dynamic_eid
                            
                            	Configure a dynamic EID
                            	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid>`
                            
                            .. attribute:: loc_reach_algorithm
                            
                            	Configure locator reachability algorithm
                            	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm>`
                            
                            .. attribute:: map_server
                            
                            	Map\-Server commands
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer>`
                            
                            .. attribute:: other_xtr_probe
                            
                            	Configure parameters for probing of other xTRs in our site
                            	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.OtherXtrProbe>`
                            
                            .. attribute:: remote_rloc_probe
                            
                            	Configure parameters for probing of remote RLOCs
                            	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.RemoteRlocProbe>`
                            
                            .. attribute:: service
                            
                            	Configure lisp service type
                            	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_, self).__init__()

                                self.yang_name = "default"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("decapsulation", ("decapsulation", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation)), ("dynamic-eid", ("dynamic_eid", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm)), ("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.RemoteRlocProbe)), ("service", ("service", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service))])
                                self._leafs = OrderedDict([
                                    ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                                ])
                                self.disable_ttl_propagate = None

                                self.decapsulation = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation()
                                self.decapsulation.parent = self
                                self._children_name_map["decapsulation"] = "decapsulation"

                                self.loc_reach_algorithm = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm()
                                self.loc_reach_algorithm.parent = self
                                self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                                self.map_server = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer()
                                self.map_server.parent = self
                                self._children_name_map["map_server"] = "map-server"

                                self.other_xtr_probe = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.OtherXtrProbe()
                                self.other_xtr_probe.parent = self
                                self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                                self.remote_rloc_probe = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.RemoteRlocProbe()
                                self.remote_rloc_probe.parent = self
                                self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                                self.service = None
                                self._children_name_map["service"] = "service"

                                self.dynamic_eid = YList(self)
                                self._segment_path = lambda: "default"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_, ['disable_ttl_propagate'], name, value)


                            class Decapsulation(Entity):
                                """
                                Decapsulation behavior (e.g. filters)
                                
                                .. attribute:: filter
                                
                                	Filters traffic
                                	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation, self).__init__()

                                    self.yang_name = "decapsulation"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("filter", ("filter", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter))])
                                    self._leafs = OrderedDict()

                                    self.filter = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter()
                                    self.filter.parent = self
                                    self._children_name_map["filter"] = "filter"
                                    self._segment_path = lambda: "decapsulation"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation, [], name, value)


                                class Filter(Entity):
                                    """
                                    Filters traffic
                                    
                                    .. attribute:: rloc
                                    
                                    	Filter based on Routing Locator (RLOC) in packet header
                                    	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter, self).__init__()

                                        self.yang_name = "filter"
                                        self.yang_parent_name = "decapsulation"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc))])
                                        self._leafs = OrderedDict()

                                        self.rloc = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc()
                                        self.rloc.parent = self
                                        self._children_name_map["rloc"] = "rloc"
                                        self._segment_path = lambda: "filter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter, [], name, value)


                                    class Rloc(Entity):
                                        """
                                        Filter based on Routing Locator (RLOC) in packet header
                                        
                                        .. attribute:: source
                                        
                                        	Filters traffic based on RLOC source address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc, self).__init__()

                                            self.yang_name = "rloc"
                                            self.yang_parent_name = "filter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "rloc"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc, [], name, value)


                                        class Source(Entity):
                                            """
                                            Filters traffic based on RLOC source address
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator\-set Name
                                            	**type**\: str
                                            
                                            .. attribute:: member
                                            
                                            	Members learned from map\-server
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "rloc"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.member = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                            class DynamicEid(Entity):
                                """
                                Configure a dynamic EID
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: database_mapping
                                
                                	Configures EID\-prefix and locator\-set for dynamic\-EID
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping>`
                                
                                .. attribute:: eid_notify
                                
                                	Configure options for sending/receiving EID\-notify
                                	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify>`
                                
                                .. attribute:: map_notify_group
                                
                                	Multicast group which to send map\-notifies to
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid, self).__init__()

                                    self.yang_name = "dynamic-eid"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                                    ])
                                    self.name = None
                                    self.map_notify_group = None

                                    self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.eid_notify = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify()
                                    self.eid_notify.parent = self
                                    self._children_name_map["eid_notify"] = "eid-notify"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid, ['name', 'map_notify_group'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures EID\-prefix and locator\-set for dynamic\-EID
                                    
                                    .. attribute:: ipv4_prefix
                                    
                                    	IPv4 EID\-prefix for dynamic\-EID
                                    	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping.Ipv4Prefix>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "dynamic-eid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping.Ipv4Prefix))])
                                        self._leafs = OrderedDict()

                                        self.ipv4_prefix = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping, [], name, value)


                                    class Ipv4Prefix(Entity):
                                        """
                                        IPv4 EID\-prefix for dynamic\-EID
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping.Ipv4Prefix, self).__init__()

                                            self.yang_name = "ipv4-prefix"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.eid_prefix = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "ipv4-prefix" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.DatabaseMapping.Ipv4Prefix, ['eid_prefix', 'locator_set'], name, value)


                                class EidNotify(Entity):
                                    """
                                    Configure options for sending/receiving EID\-notify
                                    
                                    .. attribute:: authentication_key
                                    
                                    	Authentication key used for validating received EID\-notify
                                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.AuthenticationKey>`
                                    
                                    .. attribute:: gateway_key
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify, self).__init__()

                                        self.yang_name = "eid-notify"
                                        self.yang_parent_name = "dynamic-eid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey))])
                                        self._leafs = OrderedDict()

                                        self.authentication_key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.AuthenticationKey()
                                        self.authentication_key.parent = self
                                        self._children_name_map["authentication_key"] = "authentication-key"

                                        self.gateway_key = YList(self)
                                        self._segment_path = lambda: "eid-notify"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify, [], name, value)


                                    class AuthenticationKey(Entity):
                                        """
                                        Authentication key used for validating received EID\-notify
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: key_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: key_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: key_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                            self.yang_name = "authentication-key"
                                            self.yang_parent_name = "eid-notify"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                                ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                                ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.key_0 = None
                                            self.key_6 = None
                                            self.key_7 = None
                                            self._segment_path = lambda: "authentication-key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                                    class GatewayKey(Entity):
                                        """
                                        
                                        
                                        .. attribute:: gateway_ip  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                            self.yang_name = "gateway-key"
                                            self.yang_parent_name = "eid-notify"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['gateway_ip']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key))])
                                            self._leafs = OrderedDict([
                                                ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                            ])
                                            self.gateway_ip = None

                                            self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey, ['gateway_ip'], name, value)


                                        class Key(Entity):
                                            """
                                            
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "gateway-key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction')])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, ['unc_pwd', 'hash_function'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction')])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key0, ['ak_0', 'hash_function'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction')])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.EidNotify.GatewayKey.Key.Key6, ['ak_6', 'hash_function'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "dynamic-eid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.DynamicEid.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                            class LocReachAlgorithm(Entity):
                                """
                                Configure locator reachability algorithm
                                
                                .. attribute:: lsb_reports
                                
                                	Configure data packet LSB report handling
                                	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm.LsbReports>`
                                
                                .. attribute:: rloc_probing
                                
                                	Probe high priority RLOCs with Map\-Requests as last resort
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm, self).__init__()

                                    self.yang_name = "loc-reach-algorithm"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm.LsbReports))])
                                    self._leafs = OrderedDict([
                                        ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                                    ])
                                    self.rloc_probing = None

                                    self.lsb_reports = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm.LsbReports()
                                    self.lsb_reports.parent = self
                                    self._children_name_map["lsb_reports"] = "lsb-reports"
                                    self._segment_path = lambda: "loc-reach-algorithm"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm, ['rloc_probing'], name, value)


                                class LsbReports(Entity):
                                    """
                                    Configure data packet LSB report handling
                                    
                                    .. attribute:: do_not_transmit
                                    
                                    	Force the setting of the encapsulation header L bit to zero
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore data packet LSB reports
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm.LsbReports, self).__init__()

                                        self.yang_name = "lsb-reports"
                                        self.yang_parent_name = "loc-reach-algorithm"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ])
                                        self.do_not_transmit = None
                                        self.ignore = None
                                        self._segment_path = lambda: "lsb-reports"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                            class MapServer(Entity):
                                """
                                Map\-Server commands
                                
                                .. attribute:: rloc
                                
                                	EID instance RLOC membership
                                	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc>`
                                
                                .. attribute:: site_registration
                                
                                	Map\-server site registration options
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.SiteRegistration>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.SiteRegistration))])
                                    self._leafs = OrderedDict()

                                    self.rloc = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc()
                                    self.rloc.parent = self
                                    self._children_name_map["rloc"] = "rloc"

                                    self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"
                                    self._segment_path = lambda: "map-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer, [], name, value)


                                class Rloc(Entity):
                                    """
                                    EID instance RLOC membership
                                    
                                    .. attribute:: members
                                    
                                    	EID instance RLOC membership
                                    	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc, self).__init__()

                                        self.yang_name = "rloc"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("members", ("members", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members))])
                                        self._leafs = OrderedDict()

                                        self.members = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members()
                                        self.members.parent = self
                                        self._children_name_map["members"] = "members"
                                        self._segment_path = lambda: "rloc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc, [], name, value)


                                    class Members(Entity):
                                        """
                                        EID instance RLOC membership
                                        
                                        .. attribute:: distribute
                                        
                                        	EID instance RLOC membership distribution
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: modify_discovered
                                        
                                        	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                        	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members, self).__init__()

                                            self.yang_name = "members"
                                            self.yang_parent_name = "rloc"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered))])
                                            self._leafs = OrderedDict([
                                                ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                            ])
                                            self.distribute = None

                                            self.modify_discovered = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered()
                                            self.modify_discovered.parent = self
                                            self._children_name_map["modify_discovered"] = "modify-discovered"
                                            self._segment_path = lambda: "members"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members, ['distribute'], name, value)


                                        class ModifyDiscovered(Entity):
                                            """
                                            Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                            
                                            .. attribute:: operator
                                            
                                            	
                                            	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set from which to get member RLOC addresses
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                                self.yang_name = "modify-discovered"
                                                self.yang_parent_name = "members"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.operator = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "modify-discovered"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                            class Operator(Enum):
                                                """
                                                Operator (Enum Class)

                                                .. data:: add = 0

                                                .. data:: override = 1

                                                """

                                                add = Enum.YLeaf(0, "add")

                                                override = Enum.YLeaf(1, "override")



                                class SiteRegistration(Entity):
                                    """
                                    Map\-server site registration options
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations as a result of accept\-more\-specifics
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class OtherXtrProbe(Entity):
                                """
                                Configure parameters for probing of other xTRs in our site
                                
                                .. attribute:: period
                                
                                	Period between probes in seconds
                                	**type**\: int
                                
                                	**range:** 5..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.OtherXtrProbe, self).__init__()

                                    self.yang_name = "other-xtr-probe"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                    ])
                                    self.period = None
                                    self._segment_path = lambda: "other-xtr-probe"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.OtherXtrProbe, ['period'], name, value)


                            class RemoteRlocProbe(Entity):
                                """
                                Configure parameters for probing of remote RLOCs
                                
                                .. attribute:: on_membership_change
                                
                                	Trigger probing upon membership changes for remote RLOC
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: on_route_change
                                
                                	Trigger probing upon routing changes for remote RLOC
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.RemoteRlocProbe, self).__init__()

                                    self.yang_name = "remote-rloc-probe"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                        ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                                    ])
                                    self.on_membership_change = None
                                    self.on_route_change = None
                                    self._segment_path = lambda: "remote-rloc-probe"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                            class Service(Entity):
                                """
                                Configure lisp service type
                                
                                .. attribute:: ipv4
                                
                                	
                                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ipv6
                                
                                	
                                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ethernet
                                
                                	
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service, self).__init__()

                                    self.yang_name = "service"
                                    self.yang_parent_name = "default"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.ipv4 = None
                                    self._children_name_map["ipv4"] = "ipv4"

                                    self.ipv6 = None
                                    self._children_name_map["ipv6"] = "ipv6"

                                    self.ethernet = None
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._segment_path = lambda: "service"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service, [], name, value)


                                class Ipv4(Entity):
                                    """
                                    
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_>`
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4, self).__init__()

                                        self.yang_name = "ipv4"
                                        self.yang_parent_name = "service"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_)), ("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EidTable)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt)), ("distance", ("distance", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import)), ("route-import", ("route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.default = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "ipv4"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class Default_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_table
                                        
                                        	Bind an eid\-table
                                        	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EidTable>`
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr>`
                                        
                                        .. attribute:: itr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ItrEnable>`
                                        
                                        .. attribute:: etr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EtrEnable>`
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr>`
                                        
                                        .. attribute:: map_cache_limit
                                        
                                        	Configures maximum size of map\-cache
                                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCacheLimit>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Site registrations configuration for a given instance\-id
                                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SiteRegistration>`
                                        
                                        .. attribute:: solicit_map_request
                                        
                                        	Configure Solicit\-Map\-Request handling
                                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SolicitMapRequest>`
                                        
                                        .. attribute:: alt
                                        
                                        	LISP Alternative Topology, LISP\-ALT
                                        	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt>`
                                        
                                        .. attribute:: alt_vrf
                                        
                                        	Activate LISP\-ALT functionality in VRF
                                        	**type**\: str
                                        
                                        	**status**\: deprecated
                                        
                                        .. attribute:: distance
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Distance>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Address family specific map cache configuration
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache>`
                                        
                                        .. attribute:: map_cache_persistent
                                        
                                        	Dump map\-cache onto flash, making it persistent across reboots
                                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCachePersistent>`
                                        
                                        .. attribute:: proxy_etr
                                        
                                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: proxy_itr
                                        
                                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ProxyItr>`
                                        
                                        .. attribute:: route_export
                                        
                                        	Export routes into RIB from LISP
                                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteExport>`
                                        
                                        .. attribute:: sgt
                                        
                                        	Enable security group tag propagation in LISP encapsulated traffic
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: use_petr
                                        
                                        	Encapsulate to Proxy ETR when matching forward\-native entry
                                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr>`
                                        
                                        .. attribute:: import_
                                        
                                        	Redistribute LISP states internally
                                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import>`
                                        
                                        .. attribute:: route_import
                                        
                                        	Import RIB routes by a routing protocol into LISP
                                        	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport>`
                                        
                                        .. attribute:: map_request_source
                                        
                                        	Configures inner header source address in Map\-Request message
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping
                                        
                                        	Configures Locator addresses for an ETR
                                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EidTable)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt)), ("distance", ("distance", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import)), ("route-import", ("route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping))])
                                            self._leafs = OrderedDict([
                                                ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                            ])
                                            self.alt_vrf = None
                                            self.proxy_etr = None
                                            self.sgt = None
                                            self.map_request_source = None

                                            self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EidTable()
                                            self.eid_table.parent = self
                                            self._children_name_map["eid_table"] = "eid-table"

                                            self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr()
                                            self.itr.parent = self
                                            self._children_name_map["itr"] = "itr"

                                            self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ItrEnable()
                                            self.itr_enable.parent = self
                                            self._children_name_map["itr_enable"] = "itr-enable"

                                            self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EtrEnable()
                                            self.etr_enable.parent = self
                                            self._children_name_map["etr_enable"] = "etr-enable"

                                            self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr()
                                            self.etr.parent = self
                                            self._children_name_map["etr"] = "etr"

                                            self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCacheLimit()
                                            self.map_cache_limit.parent = self
                                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                            self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SiteRegistration()
                                            self.site_registration.parent = self
                                            self._children_name_map["site_registration"] = "site-registration"

                                            self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SolicitMapRequest()
                                            self.solicit_map_request.parent = self
                                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                            self.alt = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt()
                                            self.alt.parent = self
                                            self._children_name_map["alt"] = "alt"

                                            self.distance = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Distance()
                                            self.distance.parent = self
                                            self._children_name_map["distance"] = "distance"

                                            self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.map_cache_persistent = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCachePersistent()
                                            self.map_cache_persistent.parent = self
                                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                            self.proxy_itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ProxyItr()
                                            self.proxy_itr.parent = self
                                            self._children_name_map["proxy_itr"] = "proxy-itr"

                                            self.route_export = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteExport()
                                            self.route_export.parent = self
                                            self._children_name_map["route_export"] = "route-export"

                                            self.import_ = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"

                                            self.route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport()
                                            self.route_import.parent = self
                                            self._children_name_map["route_import"] = "route-import"

                                            self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping()
                                            self.database_mapping.parent = self
                                            self._children_name_map["database_mapping"] = "database-mapping"

                                            self.use_petr = YList(self)
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                        class EidTable(Entity):
                                            """
                                            Bind an eid\-table
                                            
                                            .. attribute:: vrf_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: vrf
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EidTable, self).__init__()

                                                self.yang_name = "eid-table"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                ])
                                                self.vrf_name = None
                                                self.default = None
                                                self.vrf = None
                                                self._segment_path = lambda: "eid-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                        class Itr(Entity):
                                            """
                                            Configures a LISP Ingress Tunnel Router (ITR)
                                            
                                            .. attribute:: map_resolver
                                            
                                            	Configures map\-resolver address for sending Map\-Requests
                                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr.MapResolver>`
                                            
                                            .. attribute:: nmr_ttl
                                            
                                            	verride negative map\-reply TTL for site EID
                                            	**type**\: int
                                            
                                            	**range:** 1..900
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr, self).__init__()

                                                self.yang_name = "itr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr.MapResolver))])
                                                self._leafs = OrderedDict([
                                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                                ])
                                                self.nmr_ttl = None

                                                self.map_resolver = YList(self)
                                                self._segment_path = lambda: "itr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr, ['nmr_ttl'], name, value)


                                            class MapResolver(Entity):
                                                """
                                                Configures map\-resolver address for sending Map\-Requests
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr.MapResolver, self).__init__()

                                                    self.yang_name = "map-resolver"
                                                    self.yang_parent_name = "itr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                        class ItrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: itr
                                            
                                            	Configures a LISP Ingress Tunnel Router (ITR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ItrEnable, self).__init__()

                                                self.yang_name = "itr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                                ])
                                                self.itr = None
                                                self._segment_path = lambda: "itr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ItrEnable, ['itr'], name, value)


                                        class EtrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr
                                            
                                            	Configures a LISP Egress Tunnel Router (ETR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EtrEnable, self).__init__()

                                                self.yang_name = "etr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                                ])
                                                self.etr = None
                                                self._segment_path = lambda: "etr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.EtrEnable, ['etr'], name, value)


                                        class Etr(Entity):
                                            """
                                            Configures a LISP Egress Tunnel Router (ETR)
                                            
                                            .. attribute:: map_server
                                            
                                            	Configures map server for ETR registration
                                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer>`
                                            
                                            .. attribute:: map_cache_ttl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 60..10080
                                            
                                            .. attribute:: accept_map_request_mapping
                                            
                                            	
                                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr, self).__init__()

                                                self.yang_name = "etr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping))])
                                                self._leafs = OrderedDict([
                                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                                ])
                                                self.map_cache_ttl = None

                                                self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping()
                                                self.accept_map_request_mapping.parent = self
                                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                                self.map_server = YList(self)
                                                self._segment_path = lambda: "etr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr, ['map_cache_ttl'], name, value)


                                            class MapServer(Entity):
                                                """
                                                Configures map server for ETR registration
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: key
                                                
                                                	Authentication key used with map server
                                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key>`
                                                
                                                .. attribute:: proxy_reply
                                                
                                                	Request Map\-Server to send Map\-Replies on behalf of site
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer, self).__init__()

                                                    self.yang_name = "map-server"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key))])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.proxy_reply = None

                                                    self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key()
                                                    self.key.parent = self
                                                    self._children_name_map["key"] = "key"
                                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                                class Key(Entity):
                                                    """
                                                    Authentication key used with map server
                                                    
                                                    .. attribute:: key_pwd
                                                    
                                                    	
                                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd>`
                                                    
                                                    .. attribute:: key_0
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0>`
                                                    
                                                    .. attribute:: key_6
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6>`
                                                    
                                                    .. attribute:: key_7
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key, self).__init__()

                                                        self.yang_name = "key"
                                                        self.yang_parent_name = "map-server"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7))])
                                                        self._leafs = OrderedDict()

                                                        self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd()
                                                        self.key_pwd.parent = self
                                                        self._children_name_map["key_pwd"] = "key-pwd"

                                                        self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0()
                                                        self.key_0.parent = self
                                                        self._children_name_map["key_0"] = "key-0"

                                                        self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6()
                                                        self.key_6.parent = self
                                                        self._children_name_map["key_6"] = "key-6"

                                                        self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7()
                                                        self.key_7.parent = self
                                                        self._children_name_map["key_7"] = "key-7"
                                                        self._segment_path = lambda: "key"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key, [], name, value)


                                                    class KeyPwd(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: unc_pwd
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                            self.yang_name = "key-pwd"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.unc_pwd = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-pwd"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key0(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_0
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                            self.yang_name = "key-0"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_0 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-0"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key6(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_6
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                            self.yang_name = "key-6"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_6 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-6"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key7(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_7
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                            self.yang_name = "key-7"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_7 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-7"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                            class AcceptMapRequestMapping(Entity):
                                                """
                                                
                                                
                                                .. attribute:: accept_mappping
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: verify
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                    self.yang_name = "accept-map-request-mapping"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                    ])
                                                    self.accept_mappping = None
                                                    self.verify = None
                                                    self._segment_path = lambda: "accept-map-request-mapping"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                        class MapCacheLimit(Entity):
                                            """
                                            Configures maximum size of map\-cache
                                            
                                            .. attribute:: max_map_cache_entries
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..100000
                                            
                                            .. attribute:: reserve_list
                                            
                                            	EID\-prefixes guaranteed to be stored in map\-cache
                                            	**type**\: str
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCacheLimit, self).__init__()

                                                self.yang_name = "map-cache-limit"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.max_map_cache_entries = None
                                                self.reserve_list = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "map-cache-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                        class SiteRegistration(Entity):
                                            """
                                            Site registrations configuration for a given instance\-id
                                            
                                            .. attribute:: limit
                                            
                                            	Maximum number of site registrations
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Warning threshold to issue system logging
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SiteRegistration, self).__init__()

                                                self.yang_name = "site-registration"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.limit = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "site-registration"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                        class SolicitMapRequest(Entity):
                                            """
                                            Configure Solicit\-Map\-Request handling
                                            
                                            .. attribute:: ignore
                                            
                                            	Ignore SMR bit in incoming Map\-Requests
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: max_per_entry
                                            
                                            	Maximum number of SMRs for addresses under a map\-cache entry
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: suppression_time
                                            
                                            	How long to suppress repeated SMRs for the same address
                                            	**type**\: int
                                            
                                            	**range:** 1..600
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SolicitMapRequest, self).__init__()

                                                self.yang_name = "solicit-map-request"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                                ])
                                                self.ignore = None
                                                self.max_per_entry = None
                                                self.suppression_time = None
                                                self._segment_path = lambda: "solicit-map-request"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                        class Alt(Entity):
                                            """
                                            LISP Alternative Topology, LISP\-ALT
                                            
                                            .. attribute:: summary_route
                                            
                                            	Summary route to install into the ALT table
                                            	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt.SummaryRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt, self).__init__()

                                                self.yang_name = "alt"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt.SummaryRoute))])
                                                self._leafs = OrderedDict()

                                                self.summary_route = YList(self)
                                                self._segment_path = lambda: "alt"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt, [], name, value)


                                            class SummaryRoute(Entity):
                                                """
                                                Summary route to install into the ALT table
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                
                                                .. attribute:: route_tag
                                                
                                                	ALT RIB route tag for EID prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt.SummaryRoute, self).__init__()

                                                    self.yang_name = "summary-route"
                                                    self.yang_parent_name = "alt"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.route_tag = None
                                                    self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                        class Distance(Entity):
                                            """
                                            Administrative distance for RIB route installation
                                            
                                            .. attribute:: alt
                                            
                                            	LISP routes installed in the ALT table
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: away
                                            
                                            	Administrative distance for RIB route installation
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: dyn_eid
                                            
                                            	LISP installed routes of type dynamic\-EID
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: site_registrations
                                            
                                            	LISP installed routes of type site\-registrations
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Distance, self).__init__()

                                                self.yang_name = "distance"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                                ])
                                                self.alt = None
                                                self.away = None
                                                self.dyn_eid = None
                                                self.site_registrations = None
                                                self._segment_path = lambda: "distance"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Address family specific map cache configuration
                                            
                                            .. attribute:: eid_interface
                                            
                                            	Configures static EID\-to\-RLOC mappings for an ITR
                                            	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface>`
                                            
                                            .. attribute:: away_eids
                                            
                                            	Map cache configuration for the away table
                                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.AwayEids>`
                                            
                                            .. attribute:: site_registration
                                            
                                            	Install map cache to map request for site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.AwayEids))])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.site_registration = None

                                                self.away_eids = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.AwayEids()
                                                self.away_eids.parent = self
                                                self._children_name_map["away_eids"] = "away-eids"

                                                self.eid_interface = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache, ['site_registration'], name, value)


                                            class EidInterface(Entity):
                                                """
                                                Configures static EID\-to\-RLOC mappings for an ITR
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                
                                                .. attribute:: etr_interface_ip
                                                
                                                	
                                                	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                                
                                                .. attribute:: drop
                                                
                                                	Drop packets that match this map\-cache entry
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: map_request
                                                
                                                	Send Map\-Request for LISP destination EID
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: native_forward
                                                
                                                	Natively forward packets that match this map\-cache entry
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface, self).__init__()

                                                    self.yang_name = "eid-interface"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                        ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                        ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.drop = None
                                                    self.map_request = None
                                                    self.native_forward = None

                                                    self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                    self.etr_interface_ip.parent = self
                                                    self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                    self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                                class EtrInterfaceIp(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: etr_interface_ip_address
                                                    
                                                    	IP address of loopback or other ETR interface
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                        self.yang_name = "etr-interface-ip"
                                                        self.yang_parent_name = "eid-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ])
                                                        self.etr_interface_ip_address = None
                                                        self.priority = None
                                                        self.weight = None
                                                        self._segment_path = lambda: "etr-interface-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                            class AwayEids(Entity):
                                                """
                                                Map cache configuration for the away table
                                                
                                                .. attribute:: send_map_request
                                                
                                                	Export away table entries into the map cache with action set to send\-map\-request
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.AwayEids, self).__init__()

                                                    self.yang_name = "away-eids"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                    ])
                                                    self.send_map_request = None
                                                    self._segment_path = lambda: "away-eids"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                        class MapCachePersistent(Entity):
                                            """
                                            Dump map\-cache onto flash, making it persistent across reboots
                                            
                                            .. attribute:: interval
                                            
                                            	Interval in minutes of how often the map\-cache is saved
                                            	**type**\: int
                                            
                                            	**range:** 1..1440
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCachePersistent, self).__init__()

                                                self.yang_name = "map-cache-persistent"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                                ])
                                                self.interval = None
                                                self._segment_path = lambda: "map-cache-persistent"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.MapCachePersistent, ['interval'], name, value)


                                        class ProxyItr(Entity):
                                            """
                                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                            
                                            .. attribute:: ipv4_addr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_addr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ProxyItr, self).__init__()

                                                self.yang_name = "proxy-itr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                                ])
                                                self.ipv4_addr = None
                                                self.ipv6_addr = None
                                                self._segment_path = lambda: "proxy-itr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                        class RouteExport(Entity):
                                            """
                                            Export routes into RIB from LISP
                                            
                                            .. attribute:: site_registrations
                                            
                                            	Export LISP site registrations to RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: away_eids
                                            
                                            	Export LISP away EIDs to RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteExport, self).__init__()

                                                self.yang_name = "route-export"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                                ])
                                                self.site_registrations = None
                                                self.away_eids = None
                                                self._segment_path = lambda: "route-export"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                        class UsePetr(Entity):
                                            """
                                            Encapsulate to Proxy ETR when matching forward\-native entry
                                            
                                            .. attribute:: locator_address  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	
                                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr.Priority>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr, self).__init__()

                                                self.yang_name = "use-petr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['locator_address']
                                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr.Priority))])
                                                self._leafs = OrderedDict([
                                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                                ])
                                                self.locator_address = None

                                                self.priority = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr.Priority()
                                                self.priority.parent = self
                                                self._children_name_map["priority"] = "priority"
                                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr, ['locator_address'], name, value)


                                            class Priority(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority_value
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr.Priority, self).__init__()

                                                    self.yang_name = "priority"
                                                    self.yang_parent_name = "use-petr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.priority_value = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "priority"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                        class Import(Entity):
                                            """
                                            Redistribute LISP states internally
                                            
                                            .. attribute:: database
                                            
                                            	Redistribute LISP internal states as database mapping
                                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.Database>`
                                            
                                            .. attribute:: prefix_list_container
                                            
                                            	Redistribute LISP internal states into LISP prefix\-list entries
                                            	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.PrefixListContainer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.PrefixListContainer))])
                                                self._leafs = OrderedDict()

                                                self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.Database()
                                                self.database.parent = self
                                                self._children_name_map["database"] = "database"

                                                self.prefix_list_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.PrefixListContainer()
                                                self.prefix_list_container.parent = self
                                                self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                                self._segment_path = lambda: "import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import, [], name, value)


                                            class Database(Entity):
                                                """
                                                Redistribute LISP internal states as database mapping
                                                
                                                .. attribute:: site_registration
                                                
                                                	Import states from site registrations
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.Database, self).__init__()

                                                    self.yang_name = "database"
                                                    self.yang_parent_name = "import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.site_registration = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "database"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                            class PrefixListContainer(Entity):
                                                """
                                                Redistribute LISP internal states into LISP prefix\-list entries
                                                
                                                .. attribute:: prefix_list
                                                
                                                	The name of the lisp prefix list
                                                	**type**\: str
                                                
                                                .. attribute:: site_registration
                                                
                                                	Import states from site registrations
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.PrefixListContainer, self).__init__()

                                                    self.yang_name = "prefix-list-container"
                                                    self.yang_parent_name = "import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ])
                                                    self.prefix_list = None
                                                    self.site_registration = None
                                                    self._segment_path = lambda: "prefix-list-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                        class RouteImport(Entity):
                                            """
                                            Import RIB routes by a routing protocol into LISP
                                            
                                            .. attribute:: database
                                            
                                            	Use RIB routes to define local EID database entries
                                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database>`
                                            
                                            .. attribute:: map_cache
                                            
                                            	Use RIB routes to define EID address space in map\-cache
                                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache>`
                                            
                                            .. attribute:: prefix_list_proto
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport, self).__init__()

                                                self.yang_name = "route-import"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto))])
                                                self._leafs = OrderedDict()

                                                self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database()
                                                self.database.parent = self
                                                self._children_name_map["database"] = "database"

                                                self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache()
                                                self.map_cache.parent = self
                                                self._children_name_map["map_cache"] = "map-cache"

                                                self.prefix_list_proto = YList(self)
                                                self._segment_path = lambda: "route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport, [], name, value)


                                            class Database(Entity):
                                                """
                                                Use RIB routes to define local EID database entries
                                                
                                                .. attribute:: application
                                                
                                                	Application Protocol
                                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application>`
                                                
                                                .. attribute:: bgp
                                                
                                                	Border Gateway Protocol (BGP)
                                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp>`
                                                
                                                .. attribute:: connected
                                                
                                                	Connected
                                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected>`
                                                
                                                .. attribute:: eigrp
                                                
                                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp>`
                                                
                                                .. attribute:: isis
                                                
                                                	ISO IS\-IS
                                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis>`
                                                
                                                .. attribute:: maximum_prefix
                                                
                                                	Maximum number of prefixes to pick up from the RIB
                                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix>`
                                                
                                                .. attribute:: nd
                                                
                                                	Neighbor Discovery
                                                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd>`
                                                
                                                .. attribute:: ospf
                                                
                                                	Open Shortest Path First (OSPF)
                                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf>`
                                                
                                                .. attribute:: static
                                                
                                                	Static routes
                                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static>`
                                                
                                                .. attribute:: rip
                                                
                                                	Routing Information Protocol (RIP)
                                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database, self).__init__()

                                                    self.yang_name = "database"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip))])
                                                    self._leafs = OrderedDict()

                                                    self.application = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application()
                                                    self.application.parent = self
                                                    self._children_name_map["application"] = "application"

                                                    self.connected = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected()
                                                    self.connected.parent = self
                                                    self._children_name_map["connected"] = "connected"

                                                    self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis()
                                                    self.isis.parent = self
                                                    self._children_name_map["isis"] = "isis"

                                                    self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix()
                                                    self.maximum_prefix.parent = self
                                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                    self.nd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd()
                                                    self.nd.parent = self
                                                    self._children_name_map["nd"] = "nd"

                                                    self.static = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static()
                                                    self.static.parent = self
                                                    self._children_name_map["static"] = "static"

                                                    self.rip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip()
                                                    self.rip.parent = self
                                                    self._children_name_map["rip"] = "rip"

                                                    self.bgp = YList(self)
                                                    self.eigrp = YList(self)
                                                    self.ospf = YList(self)
                                                    self._segment_path = lambda: "database"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database, [], name, value)


                                                class Application(Entity):
                                                    """
                                                    Application Protocol
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application, self).__init__()

                                                        self.yang_name = "application"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "application"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "application"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Bgp(Entity):
                                                    """
                                                    Border Gateway Protocol (BGP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp, self).__init__()

                                                        self.yang_name = "bgp"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "bgp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Connected(Entity):
                                                    """
                                                    Connected
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected, self).__init__()

                                                        self.yang_name = "connected"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "connected"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "connected"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Eigrp(Entity):
                                                    """
                                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                        self.yang_name = "eigrp"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "eigrp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Isis(Entity):
                                                    """
                                                    ISO IS\-IS
                                                    
                                                    .. attribute:: process_id
                                                    
                                                    	Process name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis, self).__init__()

                                                        self.yang_name = "isis"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                        ])
                                                        self.process_id = None

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "isis"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "isis"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class MaximumPrefix(Entity):
                                                    """
                                                    Maximum number of prefixes to pick up from the RIB
                                                    
                                                    .. attribute:: number
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: warning_only
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: threshold1
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: warning_only1
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                        self.yang_name = "maximum-prefix"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                        ])
                                                        self.number = None
                                                        self.warning_only = None
                                                        self.threshold = None
                                                        self.threshold1 = None
                                                        self.warning_only1 = None
                                                        self._segment_path = lambda: "maximum-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                                class Nd(Entity):
                                                    """
                                                    Neighbor Discovery
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd, self).__init__()

                                                        self.yang_name = "nd"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "nd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "nd"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Ospf(Entity):
                                                    """
                                                    Open Shortest Path First (OSPF)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf, self).__init__()

                                                        self.yang_name = "ospf"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "ospf"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Static(Entity):
                                                    """
                                                    Static routes
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static, self).__init__()

                                                        self.yang_name = "static"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "static"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "static"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Rip(Entity):
                                                    """
                                                    Routing Information Protocol (RIP)
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip, self).__init__()

                                                        self.yang_name = "rip"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "rip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "rip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MapCache(Entity):
                                                """
                                                Use RIB routes to define EID address space in map\-cache
                                                
                                                .. attribute:: application
                                                
                                                	Application Protocol
                                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: bgp
                                                
                                                	Border Gateway Protocol (BGP)
                                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp>`
                                                
                                                .. attribute:: connected
                                                
                                                	Connected
                                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: eigrp
                                                
                                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp>`
                                                
                                                .. attribute:: isis
                                                
                                                	ISO IS\-IS
                                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis>`
                                                
                                                .. attribute:: maximum_prefix
                                                
                                                	Maximum number of prefixes to pick up from the RIB
                                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix>`
                                                
                                                .. attribute:: nd
                                                
                                                	Neighbour Discovery
                                                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: ospf
                                                
                                                	Open Shortest Path First (OSPF)
                                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf>`
                                                
                                                .. attribute:: static
                                                
                                                	Static routes
                                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: rip
                                                
                                                	Routing Information Protocol (RIP)
                                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache, self).__init__()

                                                    self.yang_name = "map-cache"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip))])
                                                    self._leafs = OrderedDict()

                                                    self.application = None
                                                    self._children_name_map["application"] = "application"

                                                    self.connected = None
                                                    self._children_name_map["connected"] = "connected"

                                                    self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis()
                                                    self.isis.parent = self
                                                    self._children_name_map["isis"] = "isis"

                                                    self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix()
                                                    self.maximum_prefix.parent = self
                                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                    self.nd = None
                                                    self._children_name_map["nd"] = "nd"

                                                    self.static = None
                                                    self._children_name_map["static"] = "static"

                                                    self.rip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip()
                                                    self.rip.parent = self
                                                    self._children_name_map["rip"] = "rip"

                                                    self.bgp = YList(self)
                                                    self.eigrp = YList(self)
                                                    self.ospf = YList(self)
                                                    self._segment_path = lambda: "map-cache"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache, [], name, value)


                                                class Application(Entity):
                                                    """
                                                    Application Protocol
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application, self).__init__()

                                                        self.yang_name = "application"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "application"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "application"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                                class Bgp(Entity):
                                                    """
                                                    Border Gateway Protocol (BGP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                        self.yang_name = "bgp"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "bgp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                                class Connected(Entity):
                                                    """
                                                    Connected
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                        self.yang_name = "connected"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "connected"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "connected"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                                class Eigrp(Entity):
                                                    """
                                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                        self.yang_name = "eigrp"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "eigrp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                                class Isis(Entity):
                                                    """
                                                    ISO IS\-IS
                                                    
                                                    .. attribute:: id
                                                    
                                                    	Process name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                        self.yang_name = "isis"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "isis"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "isis"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                                class MaximumPrefix(Entity):
                                                    """
                                                    Maximum number of prefixes to pick up from the RIB
                                                    
                                                    .. attribute:: number
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: warning_only
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: threshold1
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: warning_only1
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                        self.yang_name = "maximum-prefix"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                        ])
                                                        self.number = None
                                                        self.warning_only = None
                                                        self.threshold = None
                                                        self.threshold1 = None
                                                        self.warning_only1 = None
                                                        self._segment_path = lambda: "maximum-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                                class Nd(Entity):
                                                    """
                                                    Neighbour Discovery
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                        self.yang_name = "nd"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "nd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "nd"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                                class Ospf(Entity):
                                                    """
                                                    Open Shortest Path First (OSPF)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                        self.yang_name = "ospf"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "ospf"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                                class Static(Entity):
                                                    """
                                                    Static routes
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static, self).__init__()

                                                        self.yang_name = "static"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "static"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "static"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                                class Rip(Entity):
                                                    """
                                                    Routing Information Protocol (RIP)
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                        self.yang_name = "rip"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "rip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "rip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                            class PrefixListProto(Entity):
                                                """
                                                
                                                
                                                .. attribute:: prefix_list  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: protocol  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol>`
                                                
                                                .. attribute:: bgp_id
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId>`
                                                
                                                .. attribute:: eigrp_or_ospf_id
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                                
                                                .. attribute:: isis_id
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto, self).__init__()

                                                    self.yang_name = "prefix-list-proto"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['prefix_list','protocol']
                                                    self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                        ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.prefix_list = None
                                                    self.protocol = None
                                                    self.isis_id = None
                                                    self.number = None
                                                    self.threshold = None
                                                    self.warning_only = None
                                                    self.route_map = None

                                                    self.bgp_id = YList(self)
                                                    self.eigrp_or_ospf_id = YList(self)
                                                    self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                                class Protocol(Enum):
                                                    """
                                                    Protocol (Enum Class)

                                                    .. data:: application = 0

                                                    .. data:: bgp = 1

                                                    .. data:: connected = 2

                                                    .. data:: eigrp = 3

                                                    .. data:: isis = 4

                                                    .. data:: maximum_prefix = 5

                                                    .. data:: nd = 6

                                                    .. data:: ospf = 7

                                                    .. data:: static = 8

                                                    .. data:: rip = 9

                                                    """

                                                    application = Enum.YLeaf(0, "application")

                                                    bgp = Enum.YLeaf(1, "bgp")

                                                    connected = Enum.YLeaf(2, "connected")

                                                    eigrp = Enum.YLeaf(3, "eigrp")

                                                    isis = Enum.YLeaf(4, "isis")

                                                    maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                    nd = Enum.YLeaf(6, "nd")

                                                    ospf = Enum.YLeaf(7, "ospf")

                                                    static = Enum.YLeaf(8, "static")

                                                    rip = Enum.YLeaf(9, "rip")



                                                class BgpId(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: bgp_id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                        self.yang_name = "bgp-id"
                                                        self.yang_parent_name = "prefix-list-proto"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['bgp_id']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.bgp_id = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                                class EigrpOrOspfId(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: int16_id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                        self.yang_name = "eigrp-or-ospf-id"
                                                        self.yang_parent_name = "prefix-list-proto"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['int16_id']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.int16_id = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                        class DatabaseMapping(Entity):
                                            """
                                            Configures Locator addresses for an ETR
                                            
                                            .. attribute:: eid_cont
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont>`
                                            
                                            .. attribute:: limit
                                            
                                            	Configures the maximum size of local EID prefixes database
                                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.Limit>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping, self).__init__()

                                                self.yang_name = "database-mapping"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.Limit))])
                                                self._leafs = OrderedDict()

                                                self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.Limit()
                                                self.limit.parent = self
                                                self._children_name_map["limit"] = "limit"

                                                self.eid_cont = YList(self)
                                                self._segment_path = lambda: "database-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping, [], name, value)


                                            class EidCont(Entity):
                                                """
                                                
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                
                                                .. attribute:: locator_set_container
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                                
                                                .. attribute:: ipv4_addrees
                                                
                                                	IPv4 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                                
                                                .. attribute:: ipv6_addrees
                                                
                                                	IPv6 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                                
                                                .. attribute:: ipv4_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                                
                                                .. attribute:: ipv6_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                                
                                                .. attribute:: auto_discover_rlocs
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont, self).__init__()

                                                    self.yang_name = "eid-cont"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                        ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.auto_discover_rlocs = None

                                                    self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                    self.locator_set_container.parent = self
                                                    self._children_name_map["locator_set_container"] = "locator-set-container"

                                                    self.ipv4_addrees = YList(self)
                                                    self.ipv6_addrees = YList(self)
                                                    self.ipv4_interface = YList(self)
                                                    self.ipv6_interface = YList(self)
                                                    self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                                class LocatorSetContainer(Entity):
                                                    """
                                                    Use locators defined by locator\-set
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Use locators defined by locator\-set
                                                    	**type**\: str
                                                    
                                                    .. attribute:: proxy
                                                    
                                                    	Enable configuration of static proxy database mapping
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                        self.yang_name = "locator-set-container"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                        ])
                                                        self.locator_set = None
                                                        self.proxy = None
                                                        self._segment_path = lambda: "locator-set-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                                class Ipv4Addrees(Entity):
                                                    """
                                                    IPv4 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                        self.yang_name = "ipv4-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv4-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class Ipv6Addrees(Entity):
                                                    """
                                                    IPv6 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                        self.yang_name = "ipv6-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv6-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv4Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                        self.yang_name = "IPv4-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv4-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv6Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                        self.yang_name = "IPv6-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv6-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Limit(Entity):
                                                """
                                                Configures the maximum size of local EID prefixes database
                                                
                                                .. attribute:: dynamic
                                                
                                                	Configures the maximum size of dynamic local EID prefixes database
                                                	**type**\: int
                                                
                                                	**range:** 1..5000
                                                
                                                .. attribute:: warning_threshold
                                                
                                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.Limit, self).__init__()

                                                    self.yang_name = "limit"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                    ])
                                                    self.dynamic = None
                                                    self.warning_threshold = None
                                                    self._segment_path = lambda: "limit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class Ipv6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_>`
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6, self).__init__()

                                        self.yang_name = "ipv6"
                                        self.yang_parent_name = "service"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_)), ("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EidTable)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt)), ("distance", ("distance", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import)), ("route-import", ("route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.default = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "ipv6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class Default_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_table
                                        
                                        	Bind an eid\-table
                                        	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EidTable>`
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr>`
                                        
                                        .. attribute:: itr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ItrEnable>`
                                        
                                        .. attribute:: etr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EtrEnable>`
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr>`
                                        
                                        .. attribute:: map_cache_limit
                                        
                                        	Configures maximum size of map\-cache
                                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCacheLimit>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Site registrations configuration for a given instance\-id
                                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SiteRegistration>`
                                        
                                        .. attribute:: solicit_map_request
                                        
                                        	Configure Solicit\-Map\-Request handling
                                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SolicitMapRequest>`
                                        
                                        .. attribute:: alt
                                        
                                        	LISP Alternative Topology, LISP\-ALT
                                        	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt>`
                                        
                                        .. attribute:: alt_vrf
                                        
                                        	Activate LISP\-ALT functionality in VRF
                                        	**type**\: str
                                        
                                        	**status**\: deprecated
                                        
                                        .. attribute:: distance
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Distance>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Address family specific map cache configuration
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache>`
                                        
                                        .. attribute:: map_cache_persistent
                                        
                                        	Dump map\-cache onto flash, making it persistent across reboots
                                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCachePersistent>`
                                        
                                        .. attribute:: proxy_etr
                                        
                                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: proxy_itr
                                        
                                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ProxyItr>`
                                        
                                        .. attribute:: route_export
                                        
                                        	Export routes into RIB from LISP
                                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteExport>`
                                        
                                        .. attribute:: sgt
                                        
                                        	Enable security group tag propagation in LISP encapsulated traffic
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: use_petr
                                        
                                        	Encapsulate to Proxy ETR when matching forward\-native entry
                                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr>`
                                        
                                        .. attribute:: import_
                                        
                                        	Redistribute LISP states internally
                                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import>`
                                        
                                        .. attribute:: route_import
                                        
                                        	Import RIB routes by a routing protocol into LISP
                                        	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport>`
                                        
                                        .. attribute:: map_request_source
                                        
                                        	Configures inner header source address in Map\-Request message
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping
                                        
                                        	Configures Locator addresses for an ETR
                                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EidTable)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt)), ("distance", ("distance", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import)), ("route-import", ("route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping))])
                                            self._leafs = OrderedDict([
                                                ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                            ])
                                            self.alt_vrf = None
                                            self.proxy_etr = None
                                            self.sgt = None
                                            self.map_request_source = None

                                            self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EidTable()
                                            self.eid_table.parent = self
                                            self._children_name_map["eid_table"] = "eid-table"

                                            self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr()
                                            self.itr.parent = self
                                            self._children_name_map["itr"] = "itr"

                                            self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ItrEnable()
                                            self.itr_enable.parent = self
                                            self._children_name_map["itr_enable"] = "itr-enable"

                                            self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EtrEnable()
                                            self.etr_enable.parent = self
                                            self._children_name_map["etr_enable"] = "etr-enable"

                                            self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr()
                                            self.etr.parent = self
                                            self._children_name_map["etr"] = "etr"

                                            self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCacheLimit()
                                            self.map_cache_limit.parent = self
                                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                            self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SiteRegistration()
                                            self.site_registration.parent = self
                                            self._children_name_map["site_registration"] = "site-registration"

                                            self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SolicitMapRequest()
                                            self.solicit_map_request.parent = self
                                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                            self.alt = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt()
                                            self.alt.parent = self
                                            self._children_name_map["alt"] = "alt"

                                            self.distance = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Distance()
                                            self.distance.parent = self
                                            self._children_name_map["distance"] = "distance"

                                            self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.map_cache_persistent = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCachePersistent()
                                            self.map_cache_persistent.parent = self
                                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                            self.proxy_itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ProxyItr()
                                            self.proxy_itr.parent = self
                                            self._children_name_map["proxy_itr"] = "proxy-itr"

                                            self.route_export = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteExport()
                                            self.route_export.parent = self
                                            self._children_name_map["route_export"] = "route-export"

                                            self.import_ = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"

                                            self.route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport()
                                            self.route_import.parent = self
                                            self._children_name_map["route_import"] = "route-import"

                                            self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping()
                                            self.database_mapping.parent = self
                                            self._children_name_map["database_mapping"] = "database-mapping"

                                            self.use_petr = YList(self)
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                        class EidTable(Entity):
                                            """
                                            Bind an eid\-table
                                            
                                            .. attribute:: vrf_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: vrf
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EidTable, self).__init__()

                                                self.yang_name = "eid-table"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                                ])
                                                self.vrf_name = None
                                                self.default = None
                                                self.vrf = None
                                                self._segment_path = lambda: "eid-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                        class Itr(Entity):
                                            """
                                            Configures a LISP Ingress Tunnel Router (ITR)
                                            
                                            .. attribute:: map_resolver
                                            
                                            	Configures map\-resolver address for sending Map\-Requests
                                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr.MapResolver>`
                                            
                                            .. attribute:: nmr_ttl
                                            
                                            	verride negative map\-reply TTL for site EID
                                            	**type**\: int
                                            
                                            	**range:** 1..900
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr, self).__init__()

                                                self.yang_name = "itr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr.MapResolver))])
                                                self._leafs = OrderedDict([
                                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                                ])
                                                self.nmr_ttl = None

                                                self.map_resolver = YList(self)
                                                self._segment_path = lambda: "itr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr, ['nmr_ttl'], name, value)


                                            class MapResolver(Entity):
                                                """
                                                Configures map\-resolver address for sending Map\-Requests
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr.MapResolver, self).__init__()

                                                    self.yang_name = "map-resolver"
                                                    self.yang_parent_name = "itr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                        class ItrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: itr
                                            
                                            	Configures a LISP Ingress Tunnel Router (ITR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ItrEnable, self).__init__()

                                                self.yang_name = "itr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                                ])
                                                self.itr = None
                                                self._segment_path = lambda: "itr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ItrEnable, ['itr'], name, value)


                                        class EtrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr
                                            
                                            	Configures a LISP Egress Tunnel Router (ETR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EtrEnable, self).__init__()

                                                self.yang_name = "etr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                                ])
                                                self.etr = None
                                                self._segment_path = lambda: "etr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.EtrEnable, ['etr'], name, value)


                                        class Etr(Entity):
                                            """
                                            Configures a LISP Egress Tunnel Router (ETR)
                                            
                                            .. attribute:: map_server
                                            
                                            	Configures map server for ETR registration
                                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer>`
                                            
                                            .. attribute:: map_cache_ttl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 60..10080
                                            
                                            .. attribute:: accept_map_request_mapping
                                            
                                            	
                                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr, self).__init__()

                                                self.yang_name = "etr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping))])
                                                self._leafs = OrderedDict([
                                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                                ])
                                                self.map_cache_ttl = None

                                                self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping()
                                                self.accept_map_request_mapping.parent = self
                                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                                self.map_server = YList(self)
                                                self._segment_path = lambda: "etr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr, ['map_cache_ttl'], name, value)


                                            class MapServer(Entity):
                                                """
                                                Configures map server for ETR registration
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: key
                                                
                                                	Authentication key used with map server
                                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key>`
                                                
                                                .. attribute:: proxy_reply
                                                
                                                	Request Map\-Server to send Map\-Replies on behalf of site
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer, self).__init__()

                                                    self.yang_name = "map-server"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key))])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.proxy_reply = None

                                                    self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key()
                                                    self.key.parent = self
                                                    self._children_name_map["key"] = "key"
                                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                                class Key(Entity):
                                                    """
                                                    Authentication key used with map server
                                                    
                                                    .. attribute:: key_pwd
                                                    
                                                    	
                                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd>`
                                                    
                                                    .. attribute:: key_0
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0>`
                                                    
                                                    .. attribute:: key_6
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6>`
                                                    
                                                    .. attribute:: key_7
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key, self).__init__()

                                                        self.yang_name = "key"
                                                        self.yang_parent_name = "map-server"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7))])
                                                        self._leafs = OrderedDict()

                                                        self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd()
                                                        self.key_pwd.parent = self
                                                        self._children_name_map["key_pwd"] = "key-pwd"

                                                        self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0()
                                                        self.key_0.parent = self
                                                        self._children_name_map["key_0"] = "key-0"

                                                        self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6()
                                                        self.key_6.parent = self
                                                        self._children_name_map["key_6"] = "key-6"

                                                        self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7()
                                                        self.key_7.parent = self
                                                        self._children_name_map["key_7"] = "key-7"
                                                        self._segment_path = lambda: "key"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key, [], name, value)


                                                    class KeyPwd(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: unc_pwd
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                            self.yang_name = "key-pwd"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.unc_pwd = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-pwd"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key0(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_0
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                            self.yang_name = "key-0"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_0 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-0"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key6(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_6
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                            self.yang_name = "key-6"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_6 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-6"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key7(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_7
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                            self.yang_name = "key-7"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_7 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-7"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                            class AcceptMapRequestMapping(Entity):
                                                """
                                                
                                                
                                                .. attribute:: accept_mappping
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: verify
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                    self.yang_name = "accept-map-request-mapping"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                    ])
                                                    self.accept_mappping = None
                                                    self.verify = None
                                                    self._segment_path = lambda: "accept-map-request-mapping"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                        class MapCacheLimit(Entity):
                                            """
                                            Configures maximum size of map\-cache
                                            
                                            .. attribute:: max_map_cache_entries
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..100000
                                            
                                            .. attribute:: reserve_list
                                            
                                            	EID\-prefixes guaranteed to be stored in map\-cache
                                            	**type**\: str
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCacheLimit, self).__init__()

                                                self.yang_name = "map-cache-limit"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.max_map_cache_entries = None
                                                self.reserve_list = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "map-cache-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                        class SiteRegistration(Entity):
                                            """
                                            Site registrations configuration for a given instance\-id
                                            
                                            .. attribute:: limit
                                            
                                            	Maximum number of site registrations
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Warning threshold to issue system logging
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SiteRegistration, self).__init__()

                                                self.yang_name = "site-registration"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.limit = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "site-registration"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                        class SolicitMapRequest(Entity):
                                            """
                                            Configure Solicit\-Map\-Request handling
                                            
                                            .. attribute:: ignore
                                            
                                            	Ignore SMR bit in incoming Map\-Requests
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: max_per_entry
                                            
                                            	Maximum number of SMRs for addresses under a map\-cache entry
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: suppression_time
                                            
                                            	How long to suppress repeated SMRs for the same address
                                            	**type**\: int
                                            
                                            	**range:** 1..600
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SolicitMapRequest, self).__init__()

                                                self.yang_name = "solicit-map-request"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                                ])
                                                self.ignore = None
                                                self.max_per_entry = None
                                                self.suppression_time = None
                                                self._segment_path = lambda: "solicit-map-request"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                        class Alt(Entity):
                                            """
                                            LISP Alternative Topology, LISP\-ALT
                                            
                                            .. attribute:: summary_route
                                            
                                            	Summary route to install into the ALT table
                                            	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt.SummaryRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt, self).__init__()

                                                self.yang_name = "alt"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt.SummaryRoute))])
                                                self._leafs = OrderedDict()

                                                self.summary_route = YList(self)
                                                self._segment_path = lambda: "alt"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt, [], name, value)


                                            class SummaryRoute(Entity):
                                                """
                                                Summary route to install into the ALT table
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                
                                                .. attribute:: route_tag
                                                
                                                	ALT RIB route tag for EID prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt.SummaryRoute, self).__init__()

                                                    self.yang_name = "summary-route"
                                                    self.yang_parent_name = "alt"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.route_tag = None
                                                    self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                        class Distance(Entity):
                                            """
                                            Administrative distance for RIB route installation
                                            
                                            .. attribute:: alt
                                            
                                            	LISP routes installed in the ALT table
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: away
                                            
                                            	Administrative distance for RIB route installation
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: dyn_eid
                                            
                                            	LISP installed routes of type dynamic\-EID
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: site_registrations
                                            
                                            	LISP installed routes of type site\-registrations
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Distance, self).__init__()

                                                self.yang_name = "distance"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                                ])
                                                self.alt = None
                                                self.away = None
                                                self.dyn_eid = None
                                                self.site_registrations = None
                                                self._segment_path = lambda: "distance"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Address family specific map cache configuration
                                            
                                            .. attribute:: eid_interface
                                            
                                            	Configures static EID\-to\-RLOC mappings for an ITR
                                            	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface>`
                                            
                                            .. attribute:: away_eids
                                            
                                            	Map cache configuration for the away table
                                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.AwayEids>`
                                            
                                            .. attribute:: site_registration
                                            
                                            	Install map cache to map request for site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.AwayEids))])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.site_registration = None

                                                self.away_eids = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.AwayEids()
                                                self.away_eids.parent = self
                                                self._children_name_map["away_eids"] = "away-eids"

                                                self.eid_interface = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache, ['site_registration'], name, value)


                                            class EidInterface(Entity):
                                                """
                                                Configures static EID\-to\-RLOC mappings for an ITR
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                
                                                .. attribute:: etr_interface_ip
                                                
                                                	
                                                	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                                
                                                .. attribute:: drop
                                                
                                                	Drop packets that match this map\-cache entry
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: map_request
                                                
                                                	Send Map\-Request for LISP destination EID
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: native_forward
                                                
                                                	Natively forward packets that match this map\-cache entry
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface, self).__init__()

                                                    self.yang_name = "eid-interface"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                        ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                        ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                        ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.drop = None
                                                    self.map_request = None
                                                    self.native_forward = None

                                                    self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                    self.etr_interface_ip.parent = self
                                                    self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                    self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                                class EtrInterfaceIp(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: etr_interface_ip_address
                                                    
                                                    	IP address of loopback or other ETR interface
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                        self.yang_name = "etr-interface-ip"
                                                        self.yang_parent_name = "eid-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ])
                                                        self.etr_interface_ip_address = None
                                                        self.priority = None
                                                        self.weight = None
                                                        self._segment_path = lambda: "etr-interface-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                            class AwayEids(Entity):
                                                """
                                                Map cache configuration for the away table
                                                
                                                .. attribute:: send_map_request
                                                
                                                	Export away table entries into the map cache with action set to send\-map\-request
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.AwayEids, self).__init__()

                                                    self.yang_name = "away-eids"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                    ])
                                                    self.send_map_request = None
                                                    self._segment_path = lambda: "away-eids"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                        class MapCachePersistent(Entity):
                                            """
                                            Dump map\-cache onto flash, making it persistent across reboots
                                            
                                            .. attribute:: interval
                                            
                                            	Interval in minutes of how often the map\-cache is saved
                                            	**type**\: int
                                            
                                            	**range:** 1..1440
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCachePersistent, self).__init__()

                                                self.yang_name = "map-cache-persistent"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                                ])
                                                self.interval = None
                                                self._segment_path = lambda: "map-cache-persistent"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.MapCachePersistent, ['interval'], name, value)


                                        class ProxyItr(Entity):
                                            """
                                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                            
                                            .. attribute:: ipv4_addr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_addr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ProxyItr, self).__init__()

                                                self.yang_name = "proxy-itr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                                ])
                                                self.ipv4_addr = None
                                                self.ipv6_addr = None
                                                self._segment_path = lambda: "proxy-itr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                        class RouteExport(Entity):
                                            """
                                            Export routes into RIB from LISP
                                            
                                            .. attribute:: site_registrations
                                            
                                            	Export LISP site registrations to RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: away_eids
                                            
                                            	Export LISP away EIDs to RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteExport, self).__init__()

                                                self.yang_name = "route-export"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                                ])
                                                self.site_registrations = None
                                                self.away_eids = None
                                                self._segment_path = lambda: "route-export"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                        class UsePetr(Entity):
                                            """
                                            Encapsulate to Proxy ETR when matching forward\-native entry
                                            
                                            .. attribute:: locator_address  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	
                                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr.Priority>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr, self).__init__()

                                                self.yang_name = "use-petr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['locator_address']
                                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr.Priority))])
                                                self._leafs = OrderedDict([
                                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                                ])
                                                self.locator_address = None

                                                self.priority = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr.Priority()
                                                self.priority.parent = self
                                                self._children_name_map["priority"] = "priority"
                                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr, ['locator_address'], name, value)


                                            class Priority(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority_value
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr.Priority, self).__init__()

                                                    self.yang_name = "priority"
                                                    self.yang_parent_name = "use-petr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.priority_value = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "priority"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                        class Import(Entity):
                                            """
                                            Redistribute LISP states internally
                                            
                                            .. attribute:: database
                                            
                                            	Redistribute LISP internal states as database mapping
                                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.Database>`
                                            
                                            .. attribute:: prefix_list_container
                                            
                                            	Redistribute LISP internal states into LISP prefix\-list entries
                                            	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.PrefixListContainer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.PrefixListContainer))])
                                                self._leafs = OrderedDict()

                                                self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.Database()
                                                self.database.parent = self
                                                self._children_name_map["database"] = "database"

                                                self.prefix_list_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.PrefixListContainer()
                                                self.prefix_list_container.parent = self
                                                self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                                self._segment_path = lambda: "import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import, [], name, value)


                                            class Database(Entity):
                                                """
                                                Redistribute LISP internal states as database mapping
                                                
                                                .. attribute:: site_registration
                                                
                                                	Import states from site registrations
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.Database, self).__init__()

                                                    self.yang_name = "database"
                                                    self.yang_parent_name = "import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.site_registration = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "database"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                            class PrefixListContainer(Entity):
                                                """
                                                Redistribute LISP internal states into LISP prefix\-list entries
                                                
                                                .. attribute:: prefix_list
                                                
                                                	The name of the lisp prefix list
                                                	**type**\: str
                                                
                                                .. attribute:: site_registration
                                                
                                                	Import states from site registrations
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.PrefixListContainer, self).__init__()

                                                    self.yang_name = "prefix-list-container"
                                                    self.yang_parent_name = "import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ])
                                                    self.prefix_list = None
                                                    self.site_registration = None
                                                    self._segment_path = lambda: "prefix-list-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                        class RouteImport(Entity):
                                            """
                                            Import RIB routes by a routing protocol into LISP
                                            
                                            .. attribute:: database
                                            
                                            	Use RIB routes to define local EID database entries
                                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database>`
                                            
                                            .. attribute:: map_cache
                                            
                                            	Use RIB routes to define EID address space in map\-cache
                                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache>`
                                            
                                            .. attribute:: prefix_list_proto
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport, self).__init__()

                                                self.yang_name = "route-import"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto))])
                                                self._leafs = OrderedDict()

                                                self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database()
                                                self.database.parent = self
                                                self._children_name_map["database"] = "database"

                                                self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache()
                                                self.map_cache.parent = self
                                                self._children_name_map["map_cache"] = "map-cache"

                                                self.prefix_list_proto = YList(self)
                                                self._segment_path = lambda: "route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport, [], name, value)


                                            class Database(Entity):
                                                """
                                                Use RIB routes to define local EID database entries
                                                
                                                .. attribute:: application
                                                
                                                	Application Protocol
                                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application>`
                                                
                                                .. attribute:: bgp
                                                
                                                	Border Gateway Protocol (BGP)
                                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp>`
                                                
                                                .. attribute:: connected
                                                
                                                	Connected
                                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected>`
                                                
                                                .. attribute:: eigrp
                                                
                                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp>`
                                                
                                                .. attribute:: isis
                                                
                                                	ISO IS\-IS
                                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis>`
                                                
                                                .. attribute:: maximum_prefix
                                                
                                                	Maximum number of prefixes to pick up from the RIB
                                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix>`
                                                
                                                .. attribute:: nd
                                                
                                                	Neighbor Discovery
                                                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd>`
                                                
                                                .. attribute:: ospf
                                                
                                                	Open Shortest Path First (OSPF)
                                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf>`
                                                
                                                .. attribute:: static
                                                
                                                	Static routes
                                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static>`
                                                
                                                .. attribute:: rip
                                                
                                                	Routing Information Protocol (RIP)
                                                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database, self).__init__()

                                                    self.yang_name = "database"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip))])
                                                    self._leafs = OrderedDict()

                                                    self.application = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application()
                                                    self.application.parent = self
                                                    self._children_name_map["application"] = "application"

                                                    self.connected = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected()
                                                    self.connected.parent = self
                                                    self._children_name_map["connected"] = "connected"

                                                    self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis()
                                                    self.isis.parent = self
                                                    self._children_name_map["isis"] = "isis"

                                                    self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix()
                                                    self.maximum_prefix.parent = self
                                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                    self.nd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd()
                                                    self.nd.parent = self
                                                    self._children_name_map["nd"] = "nd"

                                                    self.static = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static()
                                                    self.static.parent = self
                                                    self._children_name_map["static"] = "static"

                                                    self.bgp = YList(self)
                                                    self.eigrp = YList(self)
                                                    self.ospf = YList(self)
                                                    self.rip = YList(self)
                                                    self._segment_path = lambda: "database"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database, [], name, value)


                                                class Application(Entity):
                                                    """
                                                    Application Protocol
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application, self).__init__()

                                                        self.yang_name = "application"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "application"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "application"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Bgp(Entity):
                                                    """
                                                    Border Gateway Protocol (BGP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp, self).__init__()

                                                        self.yang_name = "bgp"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "bgp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Connected(Entity):
                                                    """
                                                    Connected
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected, self).__init__()

                                                        self.yang_name = "connected"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "connected"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "connected"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Eigrp(Entity):
                                                    """
                                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                        self.yang_name = "eigrp"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "eigrp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Isis(Entity):
                                                    """
                                                    ISO IS\-IS
                                                    
                                                    .. attribute:: process_id
                                                    
                                                    	Process name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis, self).__init__()

                                                        self.yang_name = "isis"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                        ])
                                                        self.process_id = None

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "isis"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "isis"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class MaximumPrefix(Entity):
                                                    """
                                                    Maximum number of prefixes to pick up from the RIB
                                                    
                                                    .. attribute:: number
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: warning_only
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: threshold1
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: warning_only1
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                        self.yang_name = "maximum-prefix"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                        ])
                                                        self.number = None
                                                        self.warning_only = None
                                                        self.threshold = None
                                                        self.threshold1 = None
                                                        self.warning_only1 = None
                                                        self._segment_path = lambda: "maximum-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                                class Nd(Entity):
                                                    """
                                                    Neighbor Discovery
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd, self).__init__()

                                                        self.yang_name = "nd"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "nd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "nd"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Ospf(Entity):
                                                    """
                                                    Open Shortest Path First (OSPF)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf, self).__init__()

                                                        self.yang_name = "ospf"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "ospf"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Static(Entity):
                                                    """
                                                    Static routes
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static, self).__init__()

                                                        self.yang_name = "static"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                        self._leafs = OrderedDict()

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "static"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static, [], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "static"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                                class Rip(Entity):
                                                    """
                                                    Routing Information Protocol (RIP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	User selected string identifying this process
                                                    	**type**\: str
                                                    
                                                    .. attribute:: lisp_ip_route_import
                                                    
                                                    	
                                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip, self).__init__()

                                                        self.yang_name = "rip"
                                                        self.yang_parent_name = "database"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                        ])
                                                        self.id = None

                                                        self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                        self.lisp_ip_route_import.parent = self
                                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                        self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip, ['id'], name, value)


                                                    class LispIpRouteImport(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        .. attribute:: locator_set
                                                        
                                                        	Locator set to use with created database mapping entries
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                            self.yang_name = "lisp-ip-route-import"
                                                            self.yang_parent_name = "rip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self.locator_set = None
                                                            self._segment_path = lambda: "lisp-ip-route-import"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MapCache(Entity):
                                                """
                                                Use RIB routes to define EID address space in map\-cache
                                                
                                                .. attribute:: application
                                                
                                                	Application Protocol
                                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: bgp
                                                
                                                	Border Gateway Protocol (BGP)
                                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp>`
                                                
                                                .. attribute:: connected
                                                
                                                	Connected
                                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: eigrp
                                                
                                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp>`
                                                
                                                .. attribute:: isis
                                                
                                                	ISO IS\-IS
                                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis>`
                                                
                                                .. attribute:: maximum_prefix
                                                
                                                	Maximum number of prefixes to pick up from the RIB
                                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix>`
                                                
                                                .. attribute:: nd
                                                
                                                	Neighbour Discovery
                                                	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: ospf
                                                
                                                	Open Shortest Path First (OSPF)
                                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf>`
                                                
                                                .. attribute:: static
                                                
                                                	Static routes
                                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: rip
                                                
                                                	Routing Information Protocol (RIP)
                                                	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache, self).__init__()

                                                    self.yang_name = "map-cache"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip))])
                                                    self._leafs = OrderedDict()

                                                    self.application = None
                                                    self._children_name_map["application"] = "application"

                                                    self.connected = None
                                                    self._children_name_map["connected"] = "connected"

                                                    self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis()
                                                    self.isis.parent = self
                                                    self._children_name_map["isis"] = "isis"

                                                    self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix()
                                                    self.maximum_prefix.parent = self
                                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                    self.nd = None
                                                    self._children_name_map["nd"] = "nd"

                                                    self.static = None
                                                    self._children_name_map["static"] = "static"

                                                    self.bgp = YList(self)
                                                    self.eigrp = YList(self)
                                                    self.ospf = YList(self)
                                                    self.rip = YList(self)
                                                    self._segment_path = lambda: "map-cache"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache, [], name, value)


                                                class Application(Entity):
                                                    """
                                                    Application Protocol
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application, self).__init__()

                                                        self.yang_name = "application"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "application"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "application"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                                class Bgp(Entity):
                                                    """
                                                    Border Gateway Protocol (BGP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                        self.yang_name = "bgp"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "bgp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                                class Connected(Entity):
                                                    """
                                                    Connected
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                        self.yang_name = "connected"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "connected"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "connected"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                                class Eigrp(Entity):
                                                    """
                                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                        self.yang_name = "eigrp"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "eigrp"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                                class Isis(Entity):
                                                    """
                                                    ISO IS\-IS
                                                    
                                                    .. attribute:: id
                                                    
                                                    	Process name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                        self.yang_name = "isis"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "isis"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "isis"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                                class MaximumPrefix(Entity):
                                                    """
                                                    Maximum number of prefixes to pick up from the RIB
                                                    
                                                    .. attribute:: number
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: warning_only
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: threshold1
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..100
                                                    
                                                    .. attribute:: warning_only1
                                                    
                                                    	Only give a warning message and do not limit entries
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                        self.yang_name = "maximum-prefix"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                        ])
                                                        self.number = None
                                                        self.warning_only = None
                                                        self.threshold = None
                                                        self.threshold1 = None
                                                        self.warning_only1 = None
                                                        self._segment_path = lambda: "maximum-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                                class Nd(Entity):
                                                    """
                                                    Neighbour Discovery
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                        self.yang_name = "nd"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "nd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "nd"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                                class Ospf(Entity):
                                                    """
                                                    Open Shortest Path First (OSPF)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                        self.yang_name = "ospf"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "ospf"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                                class Static(Entity):
                                                    """
                                                    Static routes
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static, self).__init__()

                                                        self.yang_name = "static"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "static"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static, [], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "static"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                                class Rip(Entity):
                                                    """
                                                    Routing Information Protocol (RIP)
                                                    
                                                    .. attribute:: id  (key)
                                                    
                                                    	User selected string identifying this process
                                                    	**type**\: str
                                                    
                                                    .. attribute:: map_cache_container
                                                    
                                                    	
                                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                        self.yang_name = "rip"
                                                        self.yang_parent_name = "map-cache"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['id']
                                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                        self._leafs = OrderedDict([
                                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                        ])
                                                        self.id = None

                                                        self.map_cache_container = None
                                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                                        self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip, ['id'], name, value)


                                                    class MapCacheContainer(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: route_map
                                                        
                                                        	Route map for route selection filtering
                                                        	**type**\: str
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                            self.yang_name = "map-cache-container"
                                                            self.yang_parent_name = "rip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ])
                                                            self.route_map = None
                                                            self._segment_path = lambda: "map-cache-container"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                            class PrefixListProto(Entity):
                                                """
                                                
                                                
                                                .. attribute:: prefix_list  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: protocol  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol>`
                                                
                                                .. attribute:: bgp_id
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId>`
                                                
                                                .. attribute:: eigrp_or_ospf_id
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                                
                                                .. attribute:: isis_id
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto, self).__init__()

                                                    self.yang_name = "prefix-list-proto"
                                                    self.yang_parent_name = "route-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['prefix_list','protocol']
                                                    self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                        ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.prefix_list = None
                                                    self.protocol = None
                                                    self.isis_id = None
                                                    self.number = None
                                                    self.threshold = None
                                                    self.warning_only = None
                                                    self.route_map = None

                                                    self.bgp_id = YList(self)
                                                    self.eigrp_or_ospf_id = YList(self)
                                                    self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                                class Protocol(Enum):
                                                    """
                                                    Protocol (Enum Class)

                                                    .. data:: application = 0

                                                    .. data:: bgp = 1

                                                    .. data:: connected = 2

                                                    .. data:: eigrp = 3

                                                    .. data:: isis = 4

                                                    .. data:: maximum_prefix = 5

                                                    .. data:: nd = 6

                                                    .. data:: ospf = 7

                                                    .. data:: static = 8

                                                    .. data:: rip = 9

                                                    """

                                                    application = Enum.YLeaf(0, "application")

                                                    bgp = Enum.YLeaf(1, "bgp")

                                                    connected = Enum.YLeaf(2, "connected")

                                                    eigrp = Enum.YLeaf(3, "eigrp")

                                                    isis = Enum.YLeaf(4, "isis")

                                                    maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                    nd = Enum.YLeaf(6, "nd")

                                                    ospf = Enum.YLeaf(7, "ospf")

                                                    static = Enum.YLeaf(8, "static")

                                                    rip = Enum.YLeaf(9, "rip")



                                                class BgpId(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: bgp_id  (key)
                                                    
                                                    	
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: int
                                                    
                                                    			**range:** 1..4294967295
                                                    
                                                    		**type**\: str
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                        self.yang_name = "bgp-id"
                                                        self.yang_parent_name = "prefix-list-proto"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['bgp_id']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.bgp_id = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                                class EigrpOrOspfId(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: int16_id  (key)
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                        self.yang_name = "eigrp-or-ospf-id"
                                                        self.yang_parent_name = "prefix-list-proto"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['int16_id']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.int16_id = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                        class DatabaseMapping(Entity):
                                            """
                                            Configures Locator addresses for an ETR
                                            
                                            .. attribute:: eid_cont
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont>`
                                            
                                            .. attribute:: limit
                                            
                                            	Configures the maximum size of local EID prefixes database
                                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.Limit>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping, self).__init__()

                                                self.yang_name = "database-mapping"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.Limit))])
                                                self._leafs = OrderedDict()

                                                self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.Limit()
                                                self.limit.parent = self
                                                self._children_name_map["limit"] = "limit"

                                                self.eid_cont = YList(self)
                                                self._segment_path = lambda: "database-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping, [], name, value)


                                            class EidCont(Entity):
                                                """
                                                
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                
                                                .. attribute:: locator_set_container
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                                
                                                .. attribute:: ipv4_addrees
                                                
                                                	IPv4 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                                
                                                .. attribute:: ipv6_addrees
                                                
                                                	IPv6 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                                
                                                .. attribute:: ipv4_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                                
                                                .. attribute:: ipv6_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                                
                                                .. attribute:: auto_discover_rlocs
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont, self).__init__()

                                                    self.yang_name = "eid-cont"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                        ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                    ])
                                                    self.eid_prefix = None
                                                    self.auto_discover_rlocs = None

                                                    self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                    self.locator_set_container.parent = self
                                                    self._children_name_map["locator_set_container"] = "locator-set-container"

                                                    self.ipv4_addrees = YList(self)
                                                    self.ipv6_addrees = YList(self)
                                                    self.ipv4_interface = YList(self)
                                                    self.ipv6_interface = YList(self)
                                                    self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                                class LocatorSetContainer(Entity):
                                                    """
                                                    Use locators defined by locator\-set
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Use locators defined by locator\-set
                                                    	**type**\: str
                                                    
                                                    .. attribute:: proxy
                                                    
                                                    	Enable configuration of static proxy database mapping
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                        self.yang_name = "locator-set-container"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                        ])
                                                        self.locator_set = None
                                                        self.proxy = None
                                                        self._segment_path = lambda: "locator-set-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                                class Ipv4Addrees(Entity):
                                                    """
                                                    IPv4 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                        self.yang_name = "ipv4-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv4-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class Ipv6Addrees(Entity):
                                                    """
                                                    IPv6 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                        self.yang_name = "ipv6-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv6-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv4Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                        self.yang_name = "IPv4-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv4-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv6Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                        self.yang_name = "IPv6-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv6-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Limit(Entity):
                                                """
                                                Configures the maximum size of local EID prefixes database
                                                
                                                .. attribute:: dynamic
                                                
                                                	Configures the maximum size of dynamic local EID prefixes database
                                                	**type**\: int
                                                
                                                	**range:** 1..5000
                                                
                                                .. attribute:: warning_threshold
                                                
                                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.Limit, self).__init__()

                                                    self.yang_name = "limit"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                    ])
                                                    self.dynamic = None
                                                    self.warning_threshold = None
                                                    self._segment_path = lambda: "limit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class Ethernet(Entity):
                                    """
                                    
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_>`
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EidTable>`
                                    
                                    .. attribute:: broadcast_underlay
                                    
                                    	Multicast group to use for underlay
                                    	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.BroadcastUnderlay>`
                                    
                                    .. attribute:: flood
                                    
                                    	Control flooding or local intercept of broadcast frames
                                    	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Flood>`
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SolicitMapRequest>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "service"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_)), ("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.BroadcastUnderlay)), ("flood", ("flood", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Flood)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                        ])
                                        self.map_request_source = None

                                        self.default = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.broadcast_underlay = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.BroadcastUnderlay()
                                        self.broadcast_underlay.parent = self
                                        self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                        self.flood = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Flood()
                                        self.flood.parent = self
                                        self._children_name_map["flood"] = "flood"

                                        self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"
                                        self._segment_path = lambda: "ethernet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet, ['map_request_source'], name, value)


                                    class Default_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_table
                                        
                                        	Bind an eid\-table
                                        	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EidTable>`
                                        
                                        .. attribute:: broadcast_underlay
                                        
                                        	Multicast group to use for underlay
                                        	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.BroadcastUnderlay>`
                                        
                                        .. attribute:: flood
                                        
                                        	Control flooding or local intercept of broadcast frames
                                        	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Flood>`
                                        
                                        .. attribute:: database_mapping
                                        
                                        	Configures Locator addresses for an ETR
                                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping>`
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr>`
                                        
                                        .. attribute:: itr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.ItrEnable>`
                                        
                                        .. attribute:: etr_enable
                                        
                                        	
                                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EtrEnable>`
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr>`
                                        
                                        .. attribute:: map_cache_limit
                                        
                                        	Configures maximum size of map\-cache
                                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCacheLimit>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Site registrations configuration for a given instance\-id
                                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SiteRegistration>`
                                        
                                        .. attribute:: solicit_map_request
                                        
                                        	Configure Solicit\-Map\-Request handling
                                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SolicitMapRequest>`
                                        
                                        .. attribute:: map_request_source
                                        
                                        	Configures inner header source address in Map\-Request message
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.BroadcastUnderlay)), ("flood", ("flood", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Flood)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache))])
                                            self._leafs = OrderedDict([
                                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                            ])
                                            self.map_request_source = None

                                            self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EidTable()
                                            self.eid_table.parent = self
                                            self._children_name_map["eid_table"] = "eid-table"

                                            self.broadcast_underlay = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.BroadcastUnderlay()
                                            self.broadcast_underlay.parent = self
                                            self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                            self.flood = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Flood()
                                            self.flood.parent = self
                                            self._children_name_map["flood"] = "flood"

                                            self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping()
                                            self.database_mapping.parent = self
                                            self._children_name_map["database_mapping"] = "database-mapping"

                                            self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr()
                                            self.itr.parent = self
                                            self._children_name_map["itr"] = "itr"

                                            self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.ItrEnable()
                                            self.itr_enable.parent = self
                                            self._children_name_map["itr_enable"] = "itr-enable"

                                            self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EtrEnable()
                                            self.etr_enable.parent = self
                                            self._children_name_map["etr_enable"] = "etr-enable"

                                            self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr()
                                            self.etr.parent = self
                                            self._children_name_map["etr"] = "etr"

                                            self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCacheLimit()
                                            self.map_cache_limit.parent = self
                                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                            self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SiteRegistration()
                                            self.site_registration.parent = self
                                            self._children_name_map["site_registration"] = "site-registration"

                                            self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SolicitMapRequest()
                                            self.solicit_map_request.parent = self
                                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                            self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_, ['map_request_source'], name, value)


                                        class EidTable(Entity):
                                            """
                                            Bind an eid\-table
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN configuration
                                            	**type**\: int
                                            
                                            	**range:** 1..4094
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EidTable, self).__init__()

                                                self.yang_name = "eid-table"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                                ])
                                                self.vlan = None
                                                self._segment_path = lambda: "eid-table"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EidTable, ['vlan'], name, value)


                                        class BroadcastUnderlay(Entity):
                                            """
                                            Multicast group to use for underlay
                                            
                                            .. attribute:: ipv4_multicast
                                            
                                            	IPv4 multicast group address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_multicast
                                            
                                            	IPv6 multicast group address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.BroadcastUnderlay, self).__init__()

                                                self.yang_name = "broadcast-underlay"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                                    ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                                ])
                                                self.ipv4_multicast = None
                                                self.ipv6_multicast = None
                                                self._segment_path = lambda: "broadcast-underlay"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                        class Flood(Entity):
                                            """
                                            Control flooding or local intercept of broadcast frames
                                            
                                            .. attribute:: arp_nd
                                            
                                            	IPv4 ARP / IPv6 ND
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: unknown_unicast
                                            
                                            	Frames with unknown destination MAC
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Flood, self).__init__()

                                                self.yang_name = "flood"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                                    ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                                ])
                                                self.arp_nd = None
                                                self.unknown_unicast = None
                                                self._segment_path = lambda: "flood"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                        class DatabaseMapping(Entity):
                                            """
                                            Configures Locator addresses for an ETR
                                            
                                            .. attribute:: eid_cont
                                            
                                            	EID\-record for RLOC static mapping
                                            	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont>`
                                            
                                            .. attribute:: mac
                                            
                                            	L2 EID records
                                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Mac>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: limit
                                            
                                            	Configures the maximum size of local EID prefixes database
                                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Limit>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping, self).__init__()

                                                self.yang_name = "database-mapping"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Limit))])
                                                self._leafs = OrderedDict()

                                                self.mac = None
                                                self._children_name_map["mac"] = "mac"

                                                self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Limit()
                                                self.limit.parent = self
                                                self._children_name_map["limit"] = "limit"

                                                self.eid_cont = YList(self)
                                                self._segment_path = lambda: "database-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping, [], name, value)


                                            class EidCont(Entity):
                                                """
                                                EID\-record for RLOC static mapping
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	xxxx.xxxx.xxxx 48 bit mac address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                                
                                                .. attribute:: locator_set_container
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                                
                                                .. attribute:: ipv4_addrees
                                                
                                                	IPv4 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                                
                                                .. attribute:: ipv6_addrees
                                                
                                                	IPv6 Address of loopback or other ETR interface
                                                	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                                
                                                .. attribute:: ipv4_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                                
                                                .. attribute:: ipv6_interface
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont, self).__init__()

                                                    self.yang_name = "eid-cont"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ])
                                                    self.eid_prefix = None

                                                    self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                    self.locator_set_container.parent = self
                                                    self._children_name_map["locator_set_container"] = "locator-set-container"

                                                    self.ipv4_addrees = YList(self)
                                                    self.ipv6_addrees = YList(self)
                                                    self.ipv4_interface = YList(self)
                                                    self.ipv6_interface = YList(self)
                                                    self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                                class LocatorSetContainer(Entity):
                                                    """
                                                    Use locators defined by locator\-set
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Use locators defined by locator\-set
                                                    	**type**\: str
                                                    
                                                    .. attribute:: proxy
                                                    
                                                    	Enable configuration of static proxy database mapping
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                        self.yang_name = "locator-set-container"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                            ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                        ])
                                                        self.locator_set = None
                                                        self.proxy = None
                                                        self._segment_path = lambda: "locator-set-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                                class Ipv4Addrees(Entity):
                                                    """
                                                    IPv4 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                        self.yang_name = "ipv4-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv4-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class Ipv6Addrees(Entity):
                                                    """
                                                    IPv6 Address of loopback or other ETR interface
                                                    
                                                    .. attribute:: address  (key)
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                        self.yang_name = "ipv6-addrees"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['address']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "ipv6-addrees"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv4Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                        self.yang_name = "IPv4-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv4-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                                class IPv6Interface(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: name  (key)
                                                    
                                                    	Use IPv4 address of interface as locator
                                                    	**type**\: str
                                                    
                                                    .. attribute:: database_mapping_option
                                                    
                                                    	
                                                    	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                        self.yang_name = "IPv6-interface"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['name']
                                                        self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                        self.database_mapping_option.parent = self
                                                        self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                        self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                    class DatabaseMappingOption(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Configures which Locators from a set are preferred
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Traffic load\-spreading among Locators
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..100
                                                        
                                                        .. attribute:: down
                                                        
                                                        	Configure this database mapping down
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                            self.yang_name = "database-mapping-option"
                                                            self.yang_parent_name = "IPv6-interface"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                            ])
                                                            self.priority = None
                                                            self.weight = None
                                                            self.down = None
                                                            self._segment_path = lambda: "database-mapping-option"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Mac(Entity):
                                                """
                                                L2 EID records
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Mac, self).__init__()

                                                    self.yang_name = "mac"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "mac"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Mac, ['locator_set'], name, value)


                                            class Limit(Entity):
                                                """
                                                Configures the maximum size of local EID prefixes database
                                                
                                                .. attribute:: dynamic
                                                
                                                	Configures the maximum size of dynamic local EID prefixes database
                                                	**type**\: int
                                                
                                                	**range:** 1..5000
                                                
                                                .. attribute:: warning_threshold
                                                
                                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Limit, self).__init__()

                                                    self.yang_name = "limit"
                                                    self.yang_parent_name = "database-mapping"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                    ])
                                                    self.dynamic = None
                                                    self.warning_threshold = None
                                                    self._segment_path = lambda: "limit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                        class Itr(Entity):
                                            """
                                            Configures a LISP Ingress Tunnel Router (ITR)
                                            
                                            .. attribute:: map_resolver
                                            
                                            	Configures map\-resolver address for sending Map\-Requests
                                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr.MapResolver>`
                                            
                                            .. attribute:: nmr_ttl
                                            
                                            	verride negative map\-reply TTL for site EID
                                            	**type**\: int
                                            
                                            	**range:** 1..900
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr, self).__init__()

                                                self.yang_name = "itr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr.MapResolver))])
                                                self._leafs = OrderedDict([
                                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                                ])
                                                self.nmr_ttl = None

                                                self.map_resolver = YList(self)
                                                self._segment_path = lambda: "itr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr, ['nmr_ttl'], name, value)


                                            class MapResolver(Entity):
                                                """
                                                Configures map\-resolver address for sending Map\-Requests
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr.MapResolver, self).__init__()

                                                    self.yang_name = "map-resolver"
                                                    self.yang_parent_name = "itr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                        class ItrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: itr
                                            
                                            	Configures a LISP Ingress Tunnel Router (ITR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.ItrEnable, self).__init__()

                                                self.yang_name = "itr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                                ])
                                                self.itr = None
                                                self._segment_path = lambda: "itr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.ItrEnable, ['itr'], name, value)


                                        class EtrEnable(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr
                                            
                                            	Configures a LISP Egress Tunnel Router (ETR)
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EtrEnable, self).__init__()

                                                self.yang_name = "etr-enable"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                                ])
                                                self.etr = None
                                                self._segment_path = lambda: "etr-enable"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.EtrEnable, ['etr'], name, value)


                                        class Etr(Entity):
                                            """
                                            Configures a LISP Egress Tunnel Router (ETR)
                                            
                                            .. attribute:: map_server
                                            
                                            	Configures map server for ETR registration
                                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer>`
                                            
                                            .. attribute:: map_cache_ttl
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 60..10080
                                            
                                            .. attribute:: accept_map_request_mapping
                                            
                                            	
                                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr, self).__init__()

                                                self.yang_name = "etr"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping))])
                                                self._leafs = OrderedDict([
                                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                                ])
                                                self.map_cache_ttl = None

                                                self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping()
                                                self.accept_map_request_mapping.parent = self
                                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                                self.map_server = YList(self)
                                                self._segment_path = lambda: "etr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr, ['map_cache_ttl'], name, value)


                                            class MapServer(Entity):
                                                """
                                                Configures map server for ETR registration
                                                
                                                .. attribute:: ip_addr  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: key
                                                
                                                	Authentication key used with map server
                                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key>`
                                                
                                                .. attribute:: proxy_reply
                                                
                                                	Request Map\-Server to send Map\-Replies on behalf of site
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer, self).__init__()

                                                    self.yang_name = "map-server"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['ip_addr']
                                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key))])
                                                    self._leafs = OrderedDict([
                                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                    ])
                                                    self.ip_addr = None
                                                    self.proxy_reply = None

                                                    self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key()
                                                    self.key.parent = self
                                                    self._children_name_map["key"] = "key"
                                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                                class Key(Entity):
                                                    """
                                                    Authentication key used with map server
                                                    
                                                    .. attribute:: key_pwd
                                                    
                                                    	
                                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd>`
                                                    
                                                    .. attribute:: key_0
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0>`
                                                    
                                                    .. attribute:: key_6
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6>`
                                                    
                                                    .. attribute:: key_7
                                                    
                                                    	
                                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key, self).__init__()

                                                        self.yang_name = "key"
                                                        self.yang_parent_name = "map-server"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7))])
                                                        self._leafs = OrderedDict()

                                                        self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd()
                                                        self.key_pwd.parent = self
                                                        self._children_name_map["key_pwd"] = "key-pwd"

                                                        self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0()
                                                        self.key_0.parent = self
                                                        self._children_name_map["key_0"] = "key-0"

                                                        self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6()
                                                        self.key_6.parent = self
                                                        self._children_name_map["key_6"] = "key-6"

                                                        self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7()
                                                        self.key_7.parent = self
                                                        self._children_name_map["key_7"] = "key-7"
                                                        self._segment_path = lambda: "key"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key, [], name, value)


                                                    class KeyPwd(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: unc_pwd
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                            self.yang_name = "key-pwd"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.unc_pwd = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-pwd"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key0(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_0
                                                        
                                                        	The UNENCRYPTED (cleartext) password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                            self.yang_name = "key-0"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_0 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-0"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key6(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_6
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                            self.yang_name = "key-6"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_6 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-6"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                                    class Key7(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: ak_7
                                                        
                                                        	The ENCRYPTED password
                                                        	**type**\: str
                                                        
                                                        .. attribute:: hash_function
                                                        
                                                        	authentication type
                                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                        
                                                        .. attribute:: prefix_list
                                                        
                                                        	Associates ITR/ETR with prefix list
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-lisp'
                                                        _revision = '2018-04-17'

                                                        def __init__(self):
                                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                            self.yang_name = "key-7"
                                                            self.yang_parent_name = "key"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                            ])
                                                            self.ak_7 = None
                                                            self.hash_function = None
                                                            self.prefix_list = None
                                                            self._segment_path = lambda: "key-7"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                        class HashFunction(Enum):
                                                            """
                                                            HashFunction (Enum Class)

                                                            authentication type

                                                            .. data:: sha1 = 0

                                                            .. data:: sha2 = 1

                                                            """

                                                            sha1 = Enum.YLeaf(0, "sha1")

                                                            sha2 = Enum.YLeaf(1, "sha2")



                                            class AcceptMapRequestMapping(Entity):
                                                """
                                                
                                                
                                                .. attribute:: accept_mappping
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: verify
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                    self.yang_name = "accept-map-request-mapping"
                                                    self.yang_parent_name = "etr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                    ])
                                                    self.accept_mappping = None
                                                    self.verify = None
                                                    self._segment_path = lambda: "accept-map-request-mapping"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                        class MapCacheLimit(Entity):
                                            """
                                            Configures maximum size of map\-cache
                                            
                                            .. attribute:: max_map_cache_entries
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..100000
                                            
                                            .. attribute:: reserve_list
                                            
                                            	EID\-prefixes guaranteed to be stored in map\-cache
                                            	**type**\: str
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCacheLimit, self).__init__()

                                                self.yang_name = "map-cache-limit"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.max_map_cache_entries = None
                                                self.reserve_list = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "map-cache-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                        class SiteRegistration(Entity):
                                            """
                                            Site registrations configuration for a given instance\-id
                                            
                                            .. attribute:: limit
                                            
                                            	Maximum number of site registrations
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Warning threshold to issue system logging
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SiteRegistration, self).__init__()

                                                self.yang_name = "site-registration"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.limit = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "site-registration"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                        class SolicitMapRequest(Entity):
                                            """
                                            Configure Solicit\-Map\-Request handling
                                            
                                            .. attribute:: ignore
                                            
                                            	Ignore SMR bit in incoming Map\-Requests
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: max_per_entry
                                            
                                            	Maximum number of SMRs for addresses under a map\-cache entry
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: suppression_time
                                            
                                            	How long to suppress repeated SMRs for the same address
                                            	**type**\: int
                                            
                                            	**range:** 1..600
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SolicitMapRequest, self).__init__()

                                                self.yang_name = "solicit-map-request"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                                ])
                                                self.ignore = None
                                                self.max_per_entry = None
                                                self.suppression_time = None
                                                self._segment_path = lambda: "solicit-map-request"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: eid_cont
                                            
                                            	EID\-record for RLOC static mapping
                                            	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "default"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont))])
                                                self._leafs = OrderedDict()

                                                self.eid_cont = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache, [], name, value)


                                            class EidCont(Entity):
                                                """
                                                EID\-record for RLOC static mapping
                                                
                                                .. attribute:: eid_prefix  (key)
                                                
                                                	xxxx.xxxx.xxxx 48 bit mac address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                                
                                                .. attribute:: etr_interface_ip
                                                
                                                	
                                                	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont, self).__init__()

                                                    self.yang_name = "eid-cont"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['eid_prefix']
                                                    self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp))])
                                                    self._leafs = OrderedDict([
                                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ])
                                                    self.eid_prefix = None

                                                    self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp()
                                                    self.etr_interface_ip.parent = self
                                                    self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                    self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont, ['eid_prefix'], name, value)


                                                class EtrInterfaceIp(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: etr_interface_ip_address
                                                    
                                                    	IP address of loopback or other ETR interface
                                                    	**type**\: union of the below types:
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    		**type**\: str
                                                    
                                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                        self.yang_name = "etr-interface-ip"
                                                        self.yang_parent_name = "eid-cont"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ])
                                                        self.etr_interface_ip_address = None
                                                        self.priority = None
                                                        self.weight = None
                                                        self._segment_path = lambda: "etr-interface-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN configuration
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ])
                                            self.vlan = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EidTable, ['vlan'], name, value)


                                    class BroadcastUnderlay(Entity):
                                        """
                                        Multicast group to use for underlay
                                        
                                        .. attribute:: ipv4_multicast
                                        
                                        	IPv4 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_multicast
                                        
                                        	IPv6 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.BroadcastUnderlay, self).__init__()

                                            self.yang_name = "broadcast-underlay"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                                ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                            ])
                                            self.ipv4_multicast = None
                                            self.ipv6_multicast = None
                                            self._segment_path = lambda: "broadcast-underlay"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                    class Flood(Entity):
                                        """
                                        Control flooding or local intercept of broadcast frames
                                        
                                        .. attribute:: arp_nd
                                        
                                        	IPv4 ARP / IPv6 ND
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Frames with unknown destination MAC
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Flood, self).__init__()

                                            self.yang_name = "flood"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                                ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                            ])
                                            self.arp_nd = None
                                            self.unknown_unicast = None
                                            self._segment_path = lambda: "flood"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: mac
                                        
                                        	L2 EID records
                                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Mac>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.mac = None
                                            self._children_name_map["mac"] = "mac"

                                            self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Mac(Entity):
                                            """
                                            L2 EID records
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Mac, self).__init__()

                                                self.yang_name = "mac"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.locator_set = None
                                                self._segment_path = lambda: "mac"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Mac, ['locator_set'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "ethernet"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont))])
                                            self._leafs = OrderedDict()

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont, ['eid_prefix'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Default_.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                        class Decapsulation(Entity):
                            """
                            Decapsulation behavior (e.g. filters)
                            
                            .. attribute:: filter
                            
                            	Filters traffic
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation, self).__init__()

                                self.yang_name = "decapsulation"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("filter", ("filter", Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter))])
                                self._leafs = OrderedDict()

                                self.filter = Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"
                                self._segment_path = lambda: "decapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation, [], name, value)


                            class Filter(Entity):
                                """
                                Filters traffic
                                
                                .. attribute:: rloc
                                
                                	Filter based on Routing Locator (RLOC) in packet header
                                	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "decapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc))])
                                    self._leafs = OrderedDict()

                                    self.rloc = Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc()
                                    self.rloc.parent = self
                                    self._children_name_map["rloc"] = "rloc"
                                    self._segment_path = lambda: "filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter, [], name, value)


                                class Rloc(Entity):
                                    """
                                    Filter based on Routing Locator (RLOC) in packet header
                                    
                                    .. attribute:: source
                                    
                                    	Filters traffic based on RLOC source address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc, self).__init__()

                                        self.yang_name = "rloc"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "rloc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc, [], name, value)


                                    class Source(Entity):
                                        """
                                        Filters traffic based on RLOC source address
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator\-set Name
                                        	**type**\: str
                                        
                                        .. attribute:: member
                                        
                                        	Members learned from map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "rloc"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.member = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                        class DynamicEid(Entity):
                            """
                            Configure a dynamic EID
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: database_mapping
                            
                            	Configures EID\-prefix and locator\-set for dynamic\-EID
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping>`
                            
                            .. attribute:: eid_notify
                            
                            	Configure options for sending/receiving EID\-notify
                            	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify>`
                            
                            .. attribute:: map_notify_group
                            
                            	Multicast group which to send map\-notifies to
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid, self).__init__()

                                self.yang_name = "dynamic-eid"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                                ])
                                self.name = None
                                self.map_notify_group = None

                                self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.eid_notify = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify()
                                self.eid_notify.parent = self
                                self._children_name_map["eid_notify"] = "eid-notify"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid, ['name', 'map_notify_group'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures EID\-prefix and locator\-set for dynamic\-EID
                                
                                .. attribute:: ipv4_prefix
                                
                                	IPv4 EID\-prefix for dynamic\-EID
                                	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix))])
                                    self._leafs = OrderedDict()

                                    self.ipv4_prefix = YList(self)
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping, [], name, value)


                                class Ipv4Prefix(Entity):
                                    """
                                    IPv4 EID\-prefix for dynamic\-EID
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    .. attribute:: locator_set
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix, self).__init__()

                                        self.yang_name = "ipv4-prefix"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.eid_prefix = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "ipv4-prefix" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix, ['eid_prefix', 'locator_set'], name, value)


                            class EidNotify(Entity):
                                """
                                Configure options for sending/receiving EID\-notify
                                
                                .. attribute:: authentication_key
                                
                                	Authentication key used for validating received EID\-notify
                                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey>`
                                
                                .. attribute:: gateway_key
                                
                                	
                                	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify, self).__init__()

                                    self.yang_name = "eid-notify"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey))])
                                    self._leafs = OrderedDict()

                                    self.authentication_key = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey()
                                    self.authentication_key.parent = self
                                    self._children_name_map["authentication_key"] = "authentication-key"

                                    self.gateway_key = YList(self)
                                    self._segment_path = lambda: "eid-notify"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify, [], name, value)


                                class AuthenticationKey(Entity):
                                    """
                                    Authentication key used for validating received EID\-notify
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: key_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                        self.yang_name = "authentication-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.key_0 = None
                                        self.key_6 = None
                                        self.key_7 = None
                                        self._segment_path = lambda: "authentication-key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                                class GatewayKey(Entity):
                                    """
                                    
                                    
                                    .. attribute:: gateway_ip  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                        self.yang_name = "gateway-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['gateway_ip']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key))])
                                        self._leafs = OrderedDict([
                                            ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                        ])
                                        self.gateway_ip = None

                                        self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey, ['gateway_ip'], name, value)


                                    class Key(Entity):
                                        """
                                        
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "gateway-key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction')])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, ['unc_pwd', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction')])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0, ['ak_0', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction')])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6, ['ak_6', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                        class LocReachAlgorithm(Entity):
                            """
                            Configure locator reachability algorithm
                            
                            .. attribute:: lsb_reports
                            
                            	Configure data packet LSB report handling
                            	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports>`
                            
                            .. attribute:: rloc_probing
                            
                            	Probe high priority RLOCs with Map\-Requests as last resort
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.LocReachAlgorithm, self).__init__()

                                self.yang_name = "loc-reach-algorithm"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.LispList.Default.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports))])
                                self._leafs = OrderedDict([
                                    ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                                ])
                                self.rloc_probing = None

                                self.lsb_reports = Native.Router.LispList.Default.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports()
                                self.lsb_reports.parent = self
                                self._children_name_map["lsb_reports"] = "lsb-reports"
                                self._segment_path = lambda: "loc-reach-algorithm"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.LocReachAlgorithm, ['rloc_probing'], name, value)


                            class LsbReports(Entity):
                                """
                                Configure data packet LSB report handling
                                
                                .. attribute:: do_not_transmit
                                
                                	Force the setting of the encapsulation header L bit to zero
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ignore
                                
                                	Ignore data packet LSB reports
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports, self).__init__()

                                    self.yang_name = "lsb-reports"
                                    self.yang_parent_name = "loc-reach-algorithm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ])
                                    self.do_not_transmit = None
                                    self.ignore = None
                                    self._segment_path = lambda: "lsb-reports"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                        class MapServer(Entity):
                            """
                            Map\-Server commands
                            
                            .. attribute:: rloc
                            
                            	EID instance RLOC membership
                            	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc>`
                            
                            .. attribute:: site_registration
                            
                            	Map\-server site registration options
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.SiteRegistration>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.SiteRegistration))])
                                self._leafs = OrderedDict()

                                self.rloc = Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc()
                                self.rloc.parent = self
                                self._children_name_map["rloc"] = "rloc"

                                self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer, [], name, value)


                            class Rloc(Entity):
                                """
                                EID instance RLOC membership
                                
                                .. attribute:: members
                                
                                	EID instance RLOC membership
                                	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc, self).__init__()

                                    self.yang_name = "rloc"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("members", ("members", Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members))])
                                    self._leafs = OrderedDict()

                                    self.members = Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members()
                                    self.members.parent = self
                                    self._children_name_map["members"] = "members"
                                    self._segment_path = lambda: "rloc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc, [], name, value)


                                class Members(Entity):
                                    """
                                    EID instance RLOC membership
                                    
                                    .. attribute:: distribute
                                    
                                    	EID instance RLOC membership distribution
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: modify_discovered
                                    
                                    	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                    	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members, self).__init__()

                                        self.yang_name = "members"
                                        self.yang_parent_name = "rloc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered))])
                                        self._leafs = OrderedDict([
                                            ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                        ])
                                        self.distribute = None

                                        self.modify_discovered = Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered()
                                        self.modify_discovered.parent = self
                                        self._children_name_map["modify_discovered"] = "modify-discovered"
                                        self._segment_path = lambda: "members"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members, ['distribute'], name, value)


                                    class ModifyDiscovered(Entity):
                                        """
                                        Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                        
                                        .. attribute:: operator
                                        
                                        	
                                        	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set from which to get member RLOC addresses
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                            self.yang_name = "modify-discovered"
                                            self.yang_parent_name = "members"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.operator = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "modify-discovered"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                        class Operator(Enum):
                                            """
                                            Operator (Enum Class)

                                            .. data:: add = 0

                                            .. data:: override = 1

                                            """

                                            add = Enum.YLeaf(0, "add")

                                            override = Enum.YLeaf(1, "override")



                            class SiteRegistration(Entity):
                                """
                                Map\-server site registration options
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations as a result of accept\-more\-specifics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class OtherXtrProbe(Entity):
                            """
                            Configure parameters for probing of other xTRs in our site
                            
                            .. attribute:: period
                            
                            	Period between probes in seconds
                            	**type**\: int
                            
                            	**range:** 5..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.OtherXtrProbe, self).__init__()

                                self.yang_name = "other-xtr-probe"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                ])
                                self.period = None
                                self._segment_path = lambda: "other-xtr-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.OtherXtrProbe, ['period'], name, value)


                        class RemoteRlocProbe(Entity):
                            """
                            Configure parameters for probing of remote RLOCs
                            
                            .. attribute:: on_membership_change
                            
                            	Trigger probing upon membership changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: on_route_change
                            
                            	Trigger probing upon routing changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.RemoteRlocProbe, self).__init__()

                                self.yang_name = "remote-rloc-probe"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                    ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                                ])
                                self.on_membership_change = None
                                self.on_route_change = None
                                self._segment_path = lambda: "remote-rloc-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                        class Service(Entity):
                            """
                            Configure lisp service type
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ipv6
                            
                            	
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ethernet
                            
                            	
                            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service, self).__init__()

                                self.yang_name = "service"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.ipv4 = None
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = None
                                self._children_name_map["ipv6"] = "ipv6"

                                self.ethernet = None
                                self._children_name_map["ethernet"] = "ethernet"
                                self._segment_path = lambda: "service"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service, [], name, value)


                            class Ipv4(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_)), ("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.EidTable)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt)), ("distance", ("distance", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import)), ("route-import", ("route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.default = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EidTable)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt)), ("distance", ("distance", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import)), ("route-import", ("route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping))])
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Ipv6(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_)), ("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.EidTable)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt)), ("distance", ("distance", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import)), ("route-import", ("route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.default = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EidTable)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt)), ("distance", ("distance", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr)), ("import", ("import_", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import)), ("route-import", ("route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping))])
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Ethernet(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.EidTable>`
                                
                                .. attribute:: broadcast_underlay
                                
                                	Multicast group to use for underlay
                                	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay>`
                                
                                .. attribute:: flood
                                
                                	Control flooding or local intercept of broadcast frames
                                	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Flood>`
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_)), ("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay)), ("flood", ("flood", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Flood)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                    ])
                                    self.map_request_source = None

                                    self.default = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.broadcast_underlay = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay()
                                    self.broadcast_underlay.parent = self
                                    self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                    self.flood = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Flood()
                                    self.flood.parent = self
                                    self._children_name_map["flood"] = "flood"

                                    self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"
                                    self._segment_path = lambda: "ethernet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet, ['map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EidTable>`
                                    
                                    .. attribute:: broadcast_underlay
                                    
                                    	Multicast group to use for underlay
                                    	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.BroadcastUnderlay>`
                                    
                                    .. attribute:: flood
                                    
                                    	Control flooding or local intercept of broadcast frames
                                    	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Flood>`
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.BroadcastUnderlay)), ("flood", ("flood", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Flood)), ("database-mapping", ("database_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache))])
                                        self._leafs = OrderedDict([
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                        ])
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.broadcast_underlay = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.BroadcastUnderlay()
                                        self.broadcast_underlay.parent = self
                                        self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                        self.flood = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Flood()
                                        self.flood.parent = self
                                        self._children_name_map["flood"] = "flood"

                                        self.database_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.itr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.map_cache = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_, ['map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN configuration
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ])
                                            self.vlan = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EidTable, ['vlan'], name, value)


                                    class BroadcastUnderlay(Entity):
                                        """
                                        Multicast group to use for underlay
                                        
                                        .. attribute:: ipv4_multicast
                                        
                                        	IPv4 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_multicast
                                        
                                        	IPv6 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.BroadcastUnderlay, self).__init__()

                                            self.yang_name = "broadcast-underlay"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                                ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                            ])
                                            self.ipv4_multicast = None
                                            self.ipv6_multicast = None
                                            self._segment_path = lambda: "broadcast-underlay"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                    class Flood(Entity):
                                        """
                                        Control flooding or local intercept of broadcast frames
                                        
                                        .. attribute:: arp_nd
                                        
                                        	IPv4 ARP / IPv6 ND
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Frames with unknown destination MAC
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Flood, self).__init__()

                                            self.yang_name = "flood"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                                ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                            ])
                                            self.arp_nd = None
                                            self.unknown_unicast = None
                                            self._segment_path = lambda: "flood"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: mac
                                        
                                        	L2 EID records
                                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Mac>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.mac = None
                                            self._children_name_map["mac"] = "mac"

                                            self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Mac(Entity):
                                            """
                                            L2 EID records
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Mac, self).__init__()

                                                self.yang_name = "mac"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.locator_set = None
                                                self._segment_path = lambda: "mac"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Mac, ['locator_set'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont))])
                                            self._leafs = OrderedDict()

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont, ['eid_prefix'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN configuration
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.EidTable, ['vlan'], name, value)


                                class BroadcastUnderlay(Entity):
                                    """
                                    Multicast group to use for underlay
                                    
                                    .. attribute:: ipv4_multicast
                                    
                                    	IPv4 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_multicast
                                    
                                    	IPv6 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay, self).__init__()

                                        self.yang_name = "broadcast-underlay"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                            ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                        ])
                                        self.ipv4_multicast = None
                                        self.ipv6_multicast = None
                                        self._segment_path = lambda: "broadcast-underlay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                class Flood(Entity):
                                    """
                                    Control flooding or local intercept of broadcast frames
                                    
                                    .. attribute:: arp_nd
                                    
                                    	IPv4 ARP / IPv6 ND
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Frames with unknown destination MAC
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Flood, self).__init__()

                                        self.yang_name = "flood"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                            ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                        ])
                                        self.arp_nd = None
                                        self.unknown_unicast = None
                                        self._segment_path = lambda: "flood"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: mac
                                    
                                    	L2 EID records
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.mac = None
                                        self._children_name_map["mac"] = "mac"

                                        self.limit = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.locator_set_container = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Mac(Entity):
                                        """
                                        L2 EID records
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.locator_set = None
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac, ['locator_set'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont))])
                                        self._leafs = OrderedDict()

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.etr_interface_ip = Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont, ['eid_prefix'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                class Alt(Entity):
                    """
                    LISP Alternative Topology, LISP\-ALT
                    
                    .. attribute:: summary_route
                    
                    	Summary route to install into the ALT table
                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Alt.SummaryRoute>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Alt, self).__init__()

                        self.yang_name = "alt"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.Default.Alt.SummaryRoute))])
                        self._leafs = OrderedDict()

                        self.summary_route = YList(self)
                        self._segment_path = lambda: "alt"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Alt, [], name, value)


                    class SummaryRoute(Entity):
                        """
                        Summary route to install into the ALT table
                        
                        .. attribute:: eid_prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: route_tag
                        
                        	ALT RIB route tag for EID prefix
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Alt.SummaryRoute, self).__init__()

                            self.yang_name = "summary-route"
                            self.yang_parent_name = "alt"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['eid_prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                            ])
                            self.eid_prefix = None
                            self.route_tag = None
                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                class ControlPacket(Entity):
                    """
                    Configure control packet tx option
                    
                    .. attribute:: mtu
                    
                    	Configure control packet MTU
                    	**type**\: int
                    
                    	**range:** 304..10000
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.ControlPacket, self).__init__()

                        self.yang_name = "control-packet"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                        ])
                        self.mtu = None
                        self._segment_path = lambda: "control-packet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.ControlPacket, ['mtu'], name, value)


                class Ddt(Entity):
                    """
                    Delegated Database Tree (DDT) mapping system
                    
                    .. attribute:: authoritative
                    
                    	DDT authoritative prefix
                    	**type**\:  :py:class:`Authoritative <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ddt.Authoritative>`
                    
                    .. attribute:: cache_limit
                    
                    	DDT resolver cache entry limit
                    	**type**\: int
                    
                    	**range:** 1..100000
                    
                    .. attribute:: root
                    
                    	DDT root node
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Ddt, self).__init__()

                        self.yang_name = "ddt"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authoritative", ("authoritative", Native.Router.LispList.Default.Ddt.Authoritative))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('cache_limit', (YLeaf(YType.uint32, 'cache-limit'), ['int'])),
                            ('root', (YLeaf(YType.str, 'root'), ['str','str'])),
                        ])
                        self.cache_limit = None
                        self.root = None

                        self.authoritative = Native.Router.LispList.Default.Ddt.Authoritative()
                        self.authoritative.parent = self
                        self._children_name_map["authoritative"] = "authoritative"
                        self._segment_path = lambda: "ddt"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Ddt, ['cache_limit', 'root'], name, value)


                    class Authoritative(Entity):
                        """
                        DDT authoritative prefix
                        
                        .. attribute:: instance_id_eid_prefix_list
                        
                        	
                        	**type**\: list of  		 :py:class:`InstanceIdEidPrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdEidPrefixList>`
                        
                        .. attribute:: instance_id_list
                        
                        	
                        	**type**\: list of  		 :py:class:`InstanceIdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdList>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ddt.Authoritative, self).__init__()

                            self.yang_name = "authoritative"
                            self.yang_parent_name = "ddt"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("instance-id-eid-prefix-list", ("instance_id_eid_prefix_list", Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdEidPrefixList)), ("instance-id-list", ("instance_id_list", Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdList))])
                            self._leafs = OrderedDict()

                            self.instance_id_eid_prefix_list = YList(self)
                            self.instance_id_list = YList(self)
                            self._segment_path = lambda: "authoritative"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ddt.Authoritative, [], name, value)


                        class InstanceIdEidPrefixList(Entity):
                            """
                            
                            
                            .. attribute:: instance_id  (key)
                            
                            	EID instance\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: eid_prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: delegate
                            
                            	DDT delegation to a child DDT node or map\-server
                            	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate>`
                            
                            .. attribute:: map_server_peer
                            
                            	Peer map\-servers that are authoritative for the same EID prefixes
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdEidPrefixList, self).__init__()

                                self.yang_name = "instance-id-eid-prefix-list"
                                self.yang_parent_name = "authoritative"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['instance_id','eid_prefix']
                                self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate))])
                                self._leafs = OrderedDict([
                                    ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                ])
                                self.instance_id = None
                                self.eid_prefix = None
                                self.map_server_peer = None

                                self.delegate = Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate()
                                self.delegate.parent = self
                                self._children_name_map["delegate"] = "delegate"
                                self._segment_path = lambda: "instance-id-eid-prefix-list" + "[instance-id='" + str(self.instance_id) + "']" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdEidPrefixList, ['instance_id', 'eid_prefix', 'map_server_peer'], name, value)


                            class Delegate(Entity):
                                """
                                DDT delegation to a child DDT node or map\-server
                                
                                .. attribute:: eid_prefix
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: instance_id
                                
                                	EID instance\-ID
                                	**type**\: str
                                
                                .. attribute:: to
                                
                                	DDT delegation to a child DDT node or map\-server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ip_address
                                
                                	IPv4/6 Child or map\-server node locator address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_server
                                
                                	Delegation points to a map\-server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, self).__init__()

                                    self.yang_name = "delegate"
                                    self.yang_parent_name = "instance-id-eid-prefix-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                        ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                        ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                        ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                    ])
                                    self.eid_prefix = None
                                    self.instance_id = None
                                    self.to = None
                                    self.ip_address = None
                                    self.map_server = None
                                    self._segment_path = lambda: "delegate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                        class InstanceIdList(Entity):
                            """
                            
                            
                            .. attribute:: instance_id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: delegate
                            
                            	DDT delegation to a child DDT node or map\-server
                            	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdList.Delegate>`
                            
                            .. attribute:: map_server_peer
                            
                            	Peer map\-servers that are authoritative for the same EID prefixes
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdList, self).__init__()

                                self.yang_name = "instance-id-list"
                                self.yang_parent_name = "authoritative"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['instance_id']
                                self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdList.Delegate))])
                                self._leafs = OrderedDict([
                                    ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                    ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                ])
                                self.instance_id = None
                                self.map_server_peer = None

                                self.delegate = Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdList.Delegate()
                                self.delegate.parent = self
                                self._children_name_map["delegate"] = "delegate"
                                self._segment_path = lambda: "instance-id-list" + "[instance-id='" + str(self.instance_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdList, ['instance_id', 'map_server_peer'], name, value)


                            class Delegate(Entity):
                                """
                                DDT delegation to a child DDT node or map\-server
                                
                                .. attribute:: eid_prefix
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: instance_id
                                
                                	EID instance\-ID
                                	**type**\: str
                                
                                .. attribute:: to
                                
                                	DDT delegation to a child DDT node or map\-server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ip_address
                                
                                	IPv4/6 Child or map\-server node locator address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_server
                                
                                	Delegation points to a map\-server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdList.Delegate, self).__init__()

                                    self.yang_name = "delegate"
                                    self.yang_parent_name = "instance-id-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                        ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                        ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                        ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                    ])
                                    self.eid_prefix = None
                                    self.instance_id = None
                                    self.to = None
                                    self.ip_address = None
                                    self.map_server = None
                                    self._segment_path = lambda: "delegate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ddt.Authoritative.InstanceIdList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                class Decapsulation(Entity):
                    """
                    Decapsulation behavior (e.g. filters)
                    
                    .. attribute:: filter
                    
                    	Filters traffic
                    	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Decapsulation.Filter>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Decapsulation, self).__init__()

                        self.yang_name = "decapsulation"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("filter", ("filter", Native.Router.LispList.Default.Decapsulation.Filter))])
                        self._leafs = OrderedDict()

                        self.filter = Native.Router.LispList.Default.Decapsulation.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                        self._segment_path = lambda: "decapsulation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Decapsulation, [], name, value)


                    class Filter(Entity):
                        """
                        Filters traffic
                        
                        .. attribute:: rloc
                        
                        	Filter based on Routing Locator (RLOC) in packet header
                        	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Decapsulation.Filter.Rloc>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Decapsulation.Filter, self).__init__()

                            self.yang_name = "filter"
                            self.yang_parent_name = "decapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.Default.Decapsulation.Filter.Rloc))])
                            self._leafs = OrderedDict()

                            self.rloc = Native.Router.LispList.Default.Decapsulation.Filter.Rloc()
                            self.rloc.parent = self
                            self._children_name_map["rloc"] = "rloc"
                            self._segment_path = lambda: "filter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Decapsulation.Filter, [], name, value)


                        class Rloc(Entity):
                            """
                            Filter based on Routing Locator (RLOC) in packet header
                            
                            .. attribute:: source
                            
                            	Filters traffic based on RLOC source address
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Decapsulation.Filter.Rloc.Source>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Decapsulation.Filter.Rloc, self).__init__()

                                self.yang_name = "rloc"
                                self.yang_parent_name = "filter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Decapsulation.Filter.Rloc.Source))])
                                self._leafs = OrderedDict()

                                self.source = Native.Router.LispList.Default.Decapsulation.Filter.Rloc.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "rloc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Decapsulation.Filter.Rloc, [], name, value)


                            class Source(Entity):
                                """
                                Filters traffic based on RLOC source address
                                
                                .. attribute:: locator_set
                                
                                	Locator\-set Name
                                	**type**\: str
                                
                                .. attribute:: member
                                
                                	Members learned from map\-server
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Decapsulation.Filter.Rloc.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "rloc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                    ])
                                    self.locator_set = None
                                    self.member = None
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                class Etr(Entity):
                    """
                    Configures a LISP Egress Tunnel Router (ETR)
                    
                    .. attribute:: map_server
                    
                    	Configures map server for ETR registration
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Etr.MapServer>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Etr, self).__init__()

                        self.yang_name = "etr"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.Etr.MapServer))])
                        self._leafs = OrderedDict()

                        self.map_server = Native.Router.LispList.Default.Etr.MapServer()
                        self.map_server.parent = self
                        self._children_name_map["map_server"] = "map-server"
                        self._segment_path = lambda: "etr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Etr, [], name, value)


                    class MapServer(Entity):
                        """
                        Configures map server for ETR registration
                        
                        .. attribute:: source_address
                        
                        	Configures map server source address
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Etr.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "etr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                            ])
                            self.source_address = None
                            self._segment_path = lambda: "map-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Etr.MapServer, ['source_address'], name, value)


                class Ipv4(Entity):
                    """
                    IPv4 address family
                    
                    .. attribute:: alt_vrf
                    
                    	Activate LISP\-ALT functionality in VRF
                    	**type**\: str
                    
                    	**status**\: deprecated
                    
                    .. attribute:: database_mapping
                    
                    	Address family specific local EID prefixes database configuration
                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.DatabaseMapping>`
                    
                    .. attribute:: distance
                    
                    	Administrative distance for RIB route installation
                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.Distance>`
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.Itr>`
                    
                    .. attribute:: itr_enable
                    
                    	
                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.ItrEnable>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.Etr>`
                    
                    .. attribute:: etr_enable
                    
                    	
                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.EtrEnable>`
                    
                    .. attribute:: locator
                    
                    	Locator related configuration
                    	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.Locator>`
                    
                    .. attribute:: map_cache
                    
                    	Address family specific map cache configuration
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.MapCache>`
                    
                    .. attribute:: map_cache_limit
                    
                    	Configures maximum size of map\-cache
                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.MapCacheLimit>`
                    
                    .. attribute:: map_cache_persistent
                    
                    	Dump map\-cache onto flash, making it persistent across reboots
                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.MapCachePersistent>`
                    
                    .. attribute:: map_request_source
                    
                    	Configures inner header source address in Map\-Request message
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: map_resolver
                    
                    	Configures a LISP Map Resolver (MR)
                    	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.MapResolver>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: map_server
                    
                    	Configures a LISP Map Server (MS)
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.MapServer>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: path_mtu_discovery
                    
                    	Path MTU discovery
                    	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.PathMtuDiscovery>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: proxy_etr
                    
                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: proxy_itr
                    
                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                    	**type**\: union of the below types:
                    
                    		**type**\: list of str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: list of str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: route_export
                    
                    	Export routes into RIB from LISP
                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteExport>`
                    
                    .. attribute:: route_import
                    
                    	Import RIB routes by a routing protocol into LISP
                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport>`
                    
                    .. attribute:: sgt
                    
                    	Enable security group tag propagation in LISP encapsulated traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: site_registration
                    
                    	Site registrations configuration for a given instance\-id
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.SiteRegistration>`
                    
                    .. attribute:: solicit_map_request
                    
                    	Configure Solicit\-Map\-Request handling
                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.SolicitMapRequest>`
                    
                    .. attribute:: source_locator
                    
                    	Source Locator configuration
                    	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.SourceLocator>`
                    
                    .. attribute:: use_petr
                    
                    	Encapsulate to Proxy ETR when matching forward\-native entry
                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.UsePetr>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Default.Ipv4.DatabaseMapping)), ("distance", ("distance", Native.Router.LispList.Default.Ipv4.Distance)), ("itr", ("itr", Native.Router.LispList.Default.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.Ipv4.ItrEnable)), ("etr", ("etr", Native.Router.LispList.Default.Ipv4.Etr)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.Ipv4.EtrEnable)), ("locator", ("locator", Native.Router.LispList.Default.Ipv4.Locator)), ("map-cache", ("map_cache", Native.Router.LispList.Default.Ipv4.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.Ipv4.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.Ipv4.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.LispList.Default.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Default.Ipv4.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.LispList.Default.Ipv4.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.LispList.Default.Ipv4.RouteExport)), ("route-import", ("route_import", Native.Router.LispList.Default.Ipv4.RouteImport)), ("site-registration", ("site_registration", Native.Router.LispList.Default.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.Ipv4.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.LispList.Default.Ipv4.SourceLocator)), ("use-petr", ("use_petr", Native.Router.LispList.Default.Ipv4.UsePetr))])
                        self._leafs = OrderedDict([
                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                            ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                        ])
                        self.alt_vrf = None
                        self.map_request_source = None
                        self.proxy_etr = None
                        self.proxy_itr = []
                        self.sgt = None

                        self.database_mapping = Native.Router.LispList.Default.Ipv4.DatabaseMapping()
                        self.database_mapping.parent = self
                        self._children_name_map["database_mapping"] = "database-mapping"

                        self.distance = Native.Router.LispList.Default.Ipv4.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"

                        self.itr = Native.Router.LispList.Default.Ipv4.Itr()
                        self.itr.parent = self
                        self._children_name_map["itr"] = "itr"

                        self.itr_enable = Native.Router.LispList.Default.Ipv4.ItrEnable()
                        self.itr_enable.parent = self
                        self._children_name_map["itr_enable"] = "itr-enable"

                        self.etr = Native.Router.LispList.Default.Ipv4.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.etr_enable = Native.Router.LispList.Default.Ipv4.EtrEnable()
                        self.etr_enable.parent = self
                        self._children_name_map["etr_enable"] = "etr-enable"

                        self.locator = Native.Router.LispList.Default.Ipv4.Locator()
                        self.locator.parent = self
                        self._children_name_map["locator"] = "locator"

                        self.map_cache = Native.Router.LispList.Default.Ipv4.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"

                        self.map_cache_limit = Native.Router.LispList.Default.Ipv4.MapCacheLimit()
                        self.map_cache_limit.parent = self
                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                        self.map_cache_persistent = Native.Router.LispList.Default.Ipv4.MapCachePersistent()
                        self.map_cache_persistent.parent = self
                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                        self.map_resolver = None
                        self._children_name_map["map_resolver"] = "map-resolver"

                        self.map_server = None
                        self._children_name_map["map_server"] = "map-server"

                        self.path_mtu_discovery = None
                        self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                        self.route_export = Native.Router.LispList.Default.Ipv4.RouteExport()
                        self.route_export.parent = self
                        self._children_name_map["route_export"] = "route-export"

                        self.route_import = Native.Router.LispList.Default.Ipv4.RouteImport()
                        self.route_import.parent = self
                        self._children_name_map["route_import"] = "route-import"

                        self.site_registration = Native.Router.LispList.Default.Ipv4.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.solicit_map_request = Native.Router.LispList.Default.Ipv4.SolicitMapRequest()
                        self.solicit_map_request.parent = self
                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                        self.source_locator = Native.Router.LispList.Default.Ipv4.SourceLocator()
                        self.source_locator.parent = self
                        self._children_name_map["source_locator"] = "source-locator"

                        self.use_petr = YList(self)
                        self._segment_path = lambda: "ipv4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Ipv4, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Address family specific local EID prefixes database configuration
                        
                        .. attribute:: limit
                        
                        	Configures the maximum size of local EID prefixes database
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.DatabaseMapping.Limit>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Default.Ipv4.DatabaseMapping.Limit))])
                            self._leafs = OrderedDict()

                            self.limit = Native.Router.LispList.Default.Ipv4.DatabaseMapping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "database-mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.DatabaseMapping, [], name, value)


                        class Limit(Entity):
                            """
                            Configures the maximum size of local EID prefixes database
                            
                            .. attribute:: dynamic
                            
                            	Configures the maximum size of dynamic local EID prefixes database
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.DatabaseMapping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "database-mapping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.dynamic = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                    class Distance(Entity):
                        """
                        Administrative distance for RIB route installation
                        
                        .. attribute:: alt
                        
                        	LISP routes installed in the ALT table
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dyn_eid
                        
                        	LISP installed routes of type dynamic\-EID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: site_registrations
                        
                        	LISP installed routes of type site\-registrations
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                            ])
                            self.alt = None
                            self.dyn_eid = None
                            self.site_registrations = None
                            self._segment_path = lambda: "distance"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                    class Itr(Entity):
                        """
                        Configures a LISP Ingress Tunnel Router (ITR)
                        
                        .. attribute:: map_resolver
                        
                        	Configures map\-resolver address for sending Map\-Requests
                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.Itr.MapResolver>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.Itr, self).__init__()

                            self.yang_name = "itr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.Ipv4.Itr.MapResolver))])
                            self._leafs = OrderedDict()

                            self.map_resolver = YList(self)
                            self._segment_path = lambda: "itr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.Itr, [], name, value)


                        class MapResolver(Entity):
                            """
                            Configures map\-resolver address for sending Map\-Requests
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.Itr.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "itr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                ])
                                self.ip_addr = None
                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.Itr.MapResolver, ['ip_addr'], name, value)


                    class ItrEnable(Entity):
                        """
                        
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.ItrEnable, self).__init__()

                            self.yang_name = "itr-enable"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                            ])
                            self.itr = None
                            self._segment_path = lambda: "itr-enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.ItrEnable, ['itr'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.Etr.MapServer>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.Ipv4.Etr.MapServer))])
                            self._leafs = OrderedDict()

                            self.map_server = YList(self)
                            self._segment_path = lambda: "etr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.Etr, [], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.Etr.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.Ipv4.Etr.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.LispList.Default.Ipv4.Etr.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: key_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: key_7
                                
                                	The HIDDEN password
                                	**type**\: str
                                
                                .. attribute:: pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.Etr.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                        ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                        ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                        ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                    ])
                                    self.key_0 = None
                                    self.key_6 = None
                                    self.key_7 = None
                                    self.pwd = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                    class EtrEnable(Entity):
                        """
                        
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.EtrEnable, self).__init__()

                            self.yang_name = "etr-enable"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                            ])
                            self.etr = None
                            self._segment_path = lambda: "etr-enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.EtrEnable, ['etr'], name, value)


                    class Locator(Entity):
                        """
                        Locator related configuration
                        
                        .. attribute:: reachability
                        
                        	Configuration realted to locator reachability
                        	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.Locator.Reachability>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.Locator, self).__init__()

                            self.yang_name = "locator"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.LispList.Default.Ipv4.Locator.Reachability))])
                            self._leafs = OrderedDict()

                            self.reachability = Native.Router.LispList.Default.Ipv4.Locator.Reachability()
                            self.reachability.parent = self
                            self._children_name_map["reachability"] = "reachability"
                            self._segment_path = lambda: "locator"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.Locator, [], name, value)


                        class Reachability(Entity):
                            """
                            Configuration realted to locator reachability
                            
                            .. attribute:: exclude_default
                            
                            	If a remote RLOC is reached via the default route, treat it as unreachable
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.Locator.Reachability, self).__init__()

                                self.yang_name = "reachability"
                                self.yang_parent_name = "locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                ])
                                self.exclude_default = None
                                self._segment_path = lambda: "reachability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.Locator.Reachability, ['exclude_default'], name, value)


                    class MapCache(Entity):
                        """
                        Address family specific map cache configuration
                        
                        .. attribute:: site_registration
                        
                        	Install map cache to map request for site registrations
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                            ])
                            self.site_registration = None
                            self._segment_path = lambda: "map-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.MapCache, ['site_registration'], name, value)


                    class MapCacheLimit(Entity):
                        """
                        Configures maximum size of map\-cache
                        
                        .. attribute:: max_map_cache_entries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..100000
                        
                        .. attribute:: reserve_list
                        
                        	EID\-prefixes guaranteed to be stored in map\-cache
                        	**type**\: str
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.MapCacheLimit, self).__init__()

                            self.yang_name = "map-cache-limit"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.max_map_cache_entries = None
                            self.reserve_list = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "map-cache-limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                    class MapCachePersistent(Entity):
                        """
                        Dump map\-cache onto flash, making it persistent across reboots
                        
                        .. attribute:: interval
                        
                        	Interval in minutes of how often the map\-cache is saved
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.MapCachePersistent, self).__init__()

                            self.yang_name = "map-cache-persistent"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "map-cache-persistent"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.MapCachePersistent, ['interval'], name, value)


                    class MapResolver(Entity):
                        """
                        Configures a LISP Map Resolver (MR)
                        
                        .. attribute:: map_request
                        
                        	Map\-Request processing options
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_request = Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"
                            self._segment_path = lambda: "map-resolver"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.MapResolver, [], name, value)


                        class MapRequest(Entity):
                            """
                            Map\-Request processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "map-resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	Influence which source RLOCs map requests are accepted from
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    Influence which source RLOCs map requests are accepted from
                                    
                                    .. attribute:: list
                                    
                                    	Define allowed prefixes using an ip[v6] prefix list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: registered
                                    
                                    	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 prefixes
                                    	**type**\: str
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 prefixes
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                            ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.list = None
                                        self.registered = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                    class MapServer(Entity):
                        """
                        Configures a LISP Map Server (MS)
                        
                        .. attribute:: map_register
                        
                        	Map\-Register processing options
                        	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.MapServer.MapRegister>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Default.Ipv4.MapServer.MapRegister))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_register = Native.Router.LispList.Default.Ipv4.MapServer.MapRegister()
                            self.map_register.parent = self
                            self._children_name_map["map_register"] = "map-register"
                            self._segment_path = lambda: "map-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.MapServer, [], name, value)


                        class MapRegister(Entity):
                            """
                            Map\-Register processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.MapServer.MapRegister.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.MapServer.MapRegister, self).__init__()

                                self.yang_name = "map-register"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Ipv4.MapServer.MapRegister.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.LispList.Default.Ipv4.MapServer.MapRegister.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-register"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.MapServer.MapRegister, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	RLOC Source IP address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.MapServer.MapRegister.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-register"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Ipv4.MapServer.MapRegister.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.Default.Ipv4.MapServer.MapRegister.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    RLOC Source IP address
                                    
                                    .. attribute:: allowed_locator
                                    
                                    	Against sites' allowed\-locators policy
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                        ])
                                        self.allowed_locator = None
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                    class PathMtuDiscovery(Entity):
                        """
                        Path MTU discovery
                        
                        .. attribute:: max
                        
                        	Upper bound on the path MTU accepted
                        	**type**\: int
                        
                        	**range:** 68..65535
                        
                        .. attribute:: min
                        
                        	Lower bound on the path MTU accepted
                        	**type**\: int
                        
                        	**range:** 68..65535
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.PathMtuDiscovery, self).__init__()

                            self.yang_name = "path-mtu-discovery"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                            ])
                            self.max = None
                            self.min = None
                            self._segment_path = lambda: "path-mtu-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.PathMtuDiscovery, ['max', 'min'], name, value)


                    class RouteExport(Entity):
                        """
                        Export routes into RIB from LISP
                        
                        .. attribute:: site_registrations
                        
                        	Export LISP site registrations to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: away_eids
                        
                        	Export LISP away EIDs to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.RouteExport, self).__init__()

                            self.yang_name = "route-export"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                            ])
                            self.site_registrations = None
                            self.away_eids = None
                            self._segment_path = lambda: "route-export"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                    class RouteImport(Entity):
                        """
                        Import RIB routes by a routing protocol into LISP
                        
                        .. attribute:: database
                        
                        	Use RIB routes to define local EID database entries
                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database>`
                        
                        .. attribute:: map_cache
                        
                        	Use RIB routes to define EID address space in map\-cache
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.RouteImport, self).__init__()

                            self.yang_name = "route-import"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache))])
                            self._leafs = OrderedDict()

                            self.database = Native.Router.LispList.Default.Ipv4.RouteImport.Database()
                            self.database.parent = self
                            self._children_name_map["database"] = "database"

                            self.map_cache = Native.Router.LispList.Default.Ipv4.RouteImport.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"
                            self._segment_path = lambda: "route-import"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport, [], name, value)


                        class Database(Entity):
                            """
                            Use RIB routes to define local EID database entries
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Connected>`
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Isis>`
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes to pick up from the RIB
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.MaximumPrefix>`
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospfv3>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Rip>`
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Static>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.RouteImport.Database, self).__init__()

                                self.yang_name = "database"
                                self.yang_parent_name = "route-import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.Ipv4.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Rip)), ("static", ("static", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Static))])
                                self._leafs = OrderedDict()

                                self.connected = Native.Router.LispList.Default.Ipv4.RouteImport.Database.Connected()
                                self.connected.parent = self
                                self._children_name_map["connected"] = "connected"

                                self.maximum_prefix = Native.Router.LispList.Default.Ipv4.RouteImport.Database.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.rip = Native.Router.LispList.Default.Ipv4.RouteImport.Database.Rip()
                                self.rip.parent = self
                                self._children_name_map["rip"] = "rip"

                                self.static = Native.Router.LispList.Default.Ipv4.RouteImport.Database.Static()
                                self.static.parent = self
                                self._children_name_map["static"] = "static"

                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.isis = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self._segment_path = lambda: "database"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database, [], name, value)


                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Connected, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Isis, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes to pick up from the RIB
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: warning_only
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: threshold
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: warning_only1
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.warning_only = None
                                    self.threshold = None
                                    self.threshold1 = None
                                    self.warning_only1 = None
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Ospfv3(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospfv3, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospfv3, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "rip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Rip, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Static, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class MapCache(Entity):
                            """
                            Use RIB routes to define EID address space in map\-cache
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Isis>`
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes to pick up from the RIB
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospfv3>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Rip>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Static>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "route-import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Static))])
                                self._leafs = OrderedDict()

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.maximum_prefix = Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.rip = None
                                self._children_name_map["rip"] = "rip"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.isis = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self._segment_path = lambda: "map-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache, [], name, value)


                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes to pick up from the RIB
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: warning_only
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: threshold
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: warning_only1
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.warning_only = None
                                    self.threshold = None
                                    self.threshold1 = None
                                    self.warning_only1 = None
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                            class Ospfv3(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospfv3, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "rip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                    class SiteRegistration(Entity):
                        """
                        Site registrations configuration for a given instance\-id
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations for a given instance\-id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class SolicitMapRequest(Entity):
                        """
                        Configure Solicit\-Map\-Request handling
                        
                        .. attribute:: ignore
                        
                        	Ignore SMR bit in incoming Map\-Requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_per_entry
                        
                        	Maximum number of SMRs for addresses under a map\-cache entry
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: suppression_time
                        
                        	How long to suppress repeated SMRs for the same address
                        	**type**\: int
                        
                        	**range:** 1..600
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.SolicitMapRequest, self).__init__()

                            self.yang_name = "solicit-map-request"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                            ])
                            self.ignore = None
                            self.max_per_entry = None
                            self.suppression_time = None
                            self._segment_path = lambda: "solicit-map-request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                    class SourceLocator(Entity):
                        """
                        Source Locator configuration
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.SourceLocator.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.SourceLocator.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.SourceLocator.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv4.SourceLocator.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.SourceLocator, self).__init__()

                            self.yang_name = "source-locator"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.LispList.Default.Ipv4.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.LispList.Default.Ipv4.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.LispList.Default.Ipv4.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.LispList.Default.Ipv4.SourceLocator.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Router.LispList.Default.Ipv4.SourceLocator.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Router.LispList.Default.Ipv4.SourceLocator.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Router.LispList.Default.Ipv4.SourceLocator.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Router.LispList.Default.Ipv4.SourceLocator.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "source-locator"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.SourceLocator.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.SourceLocator.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.SourceLocator.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv4.SourceLocator.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv4.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                    class UsePetr(Entity):
                        """
                        Encapsulate to Proxy ETR when matching forward\-native entry
                        
                        .. attribute:: locator_address  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	Configures which Locators from a set are preferred
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: weight
                        
                        	Traffic load\-spreading among Locators
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv4.UsePetr, self).__init__()

                            self.yang_name = "use-petr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['locator_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                            ])
                            self.locator_address = None
                            self.priority = None
                            self.weight = None
                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv4.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 address family
                    
                    .. attribute:: alt_vrf
                    
                    	Activate LISP\-ALT functionality in VRF
                    	**type**\: str
                    
                    	**status**\: deprecated
                    
                    .. attribute:: database_mapping
                    
                    	Address family specific local EID prefixes database configuration
                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.DatabaseMapping>`
                    
                    .. attribute:: distance
                    
                    	Administrative distance for RIB route installation
                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.Distance>`
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.Itr>`
                    
                    .. attribute:: itr_enable
                    
                    	
                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.ItrEnable>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.Etr>`
                    
                    .. attribute:: etr_enable
                    
                    	
                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.EtrEnable>`
                    
                    .. attribute:: locator
                    
                    	Locator related configuration
                    	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.Locator>`
                    
                    .. attribute:: map_cache
                    
                    	Address family specific map cache configuration
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.MapCache>`
                    
                    .. attribute:: map_cache_limit
                    
                    	Configures maximum size of map\-cache
                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.MapCacheLimit>`
                    
                    .. attribute:: map_cache_persistent
                    
                    	Dump map\-cache onto flash, making it persistent across reboots
                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.MapCachePersistent>`
                    
                    .. attribute:: map_request_source
                    
                    	Configures inner header source address in Map\-Request message
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: map_resolver
                    
                    	Configures a LISP Map Resolver (MR)
                    	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.MapResolver>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: map_server
                    
                    	Configures a LISP Map Server (MS)
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.MapServer>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: path_mtu_discovery
                    
                    	Path MTU discovery
                    	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.PathMtuDiscovery>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: proxy_etr
                    
                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: proxy_itr
                    
                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                    	**type**\: union of the below types:
                    
                    		**type**\: list of str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: list of str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: route_export
                    
                    	Export routes into RIB from LISP
                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteExport>`
                    
                    .. attribute:: route_import
                    
                    	Import RIB routes by a routing protocol into LISP
                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport>`
                    
                    .. attribute:: sgt
                    
                    	Enable security group tag propagation in LISP encapsulated traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: site_registration
                    
                    	Site registrations configuration for a given instance\-id
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.SiteRegistration>`
                    
                    .. attribute:: solicit_map_request
                    
                    	Configure Solicit\-Map\-Request handling
                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.SolicitMapRequest>`
                    
                    .. attribute:: source_locator
                    
                    	Source Locator configuration
                    	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.SourceLocator>`
                    
                    .. attribute:: use_petr
                    
                    	Encapsulate to Proxy ETR when matching forward\-native entry
                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.UsePetr>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Default.Ipv6.DatabaseMapping)), ("distance", ("distance", Native.Router.LispList.Default.Ipv6.Distance)), ("itr", ("itr", Native.Router.LispList.Default.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.Ipv6.ItrEnable)), ("etr", ("etr", Native.Router.LispList.Default.Ipv6.Etr)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.Ipv6.EtrEnable)), ("locator", ("locator", Native.Router.LispList.Default.Ipv6.Locator)), ("map-cache", ("map_cache", Native.Router.LispList.Default.Ipv6.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.Ipv6.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.Ipv6.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.LispList.Default.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Default.Ipv6.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.LispList.Default.Ipv6.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.LispList.Default.Ipv6.RouteExport)), ("route-import", ("route_import", Native.Router.LispList.Default.Ipv6.RouteImport)), ("site-registration", ("site_registration", Native.Router.LispList.Default.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.Ipv6.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.LispList.Default.Ipv6.SourceLocator)), ("use-petr", ("use_petr", Native.Router.LispList.Default.Ipv6.UsePetr))])
                        self._leafs = OrderedDict([
                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                            ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                        ])
                        self.alt_vrf = None
                        self.map_request_source = None
                        self.proxy_etr = None
                        self.proxy_itr = []
                        self.sgt = None

                        self.database_mapping = Native.Router.LispList.Default.Ipv6.DatabaseMapping()
                        self.database_mapping.parent = self
                        self._children_name_map["database_mapping"] = "database-mapping"

                        self.distance = Native.Router.LispList.Default.Ipv6.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"

                        self.itr = Native.Router.LispList.Default.Ipv6.Itr()
                        self.itr.parent = self
                        self._children_name_map["itr"] = "itr"

                        self.itr_enable = Native.Router.LispList.Default.Ipv6.ItrEnable()
                        self.itr_enable.parent = self
                        self._children_name_map["itr_enable"] = "itr-enable"

                        self.etr = Native.Router.LispList.Default.Ipv6.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.etr_enable = Native.Router.LispList.Default.Ipv6.EtrEnable()
                        self.etr_enable.parent = self
                        self._children_name_map["etr_enable"] = "etr-enable"

                        self.locator = Native.Router.LispList.Default.Ipv6.Locator()
                        self.locator.parent = self
                        self._children_name_map["locator"] = "locator"

                        self.map_cache = Native.Router.LispList.Default.Ipv6.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"

                        self.map_cache_limit = Native.Router.LispList.Default.Ipv6.MapCacheLimit()
                        self.map_cache_limit.parent = self
                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                        self.map_cache_persistent = Native.Router.LispList.Default.Ipv6.MapCachePersistent()
                        self.map_cache_persistent.parent = self
                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                        self.map_resolver = None
                        self._children_name_map["map_resolver"] = "map-resolver"

                        self.map_server = None
                        self._children_name_map["map_server"] = "map-server"

                        self.path_mtu_discovery = None
                        self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                        self.route_export = Native.Router.LispList.Default.Ipv6.RouteExport()
                        self.route_export.parent = self
                        self._children_name_map["route_export"] = "route-export"

                        self.route_import = Native.Router.LispList.Default.Ipv6.RouteImport()
                        self.route_import.parent = self
                        self._children_name_map["route_import"] = "route-import"

                        self.site_registration = Native.Router.LispList.Default.Ipv6.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.solicit_map_request = Native.Router.LispList.Default.Ipv6.SolicitMapRequest()
                        self.solicit_map_request.parent = self
                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                        self.source_locator = Native.Router.LispList.Default.Ipv6.SourceLocator()
                        self.source_locator.parent = self
                        self._children_name_map["source_locator"] = "source-locator"

                        self.use_petr = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Ipv6, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Address family specific local EID prefixes database configuration
                        
                        .. attribute:: limit
                        
                        	Configures the maximum size of local EID prefixes database
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.DatabaseMapping.Limit>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Default.Ipv6.DatabaseMapping.Limit))])
                            self._leafs = OrderedDict()

                            self.limit = Native.Router.LispList.Default.Ipv6.DatabaseMapping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "database-mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.DatabaseMapping, [], name, value)


                        class Limit(Entity):
                            """
                            Configures the maximum size of local EID prefixes database
                            
                            .. attribute:: dynamic
                            
                            	Configures the maximum size of dynamic local EID prefixes database
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.DatabaseMapping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "database-mapping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.dynamic = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                    class Distance(Entity):
                        """
                        Administrative distance for RIB route installation
                        
                        .. attribute:: alt
                        
                        	LISP routes installed in the ALT table
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dyn_eid
                        
                        	LISP installed routes of type dynamic\-EID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: site_registrations
                        
                        	LISP installed routes of type site\-registrations
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                            ])
                            self.alt = None
                            self.dyn_eid = None
                            self.site_registrations = None
                            self._segment_path = lambda: "distance"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                    class Itr(Entity):
                        """
                        Configures a LISP Ingress Tunnel Router (ITR)
                        
                        .. attribute:: map_resolver
                        
                        	Configures map\-resolver address for sending Map\-Requests
                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.Itr.MapResolver>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.Itr, self).__init__()

                            self.yang_name = "itr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.Ipv6.Itr.MapResolver))])
                            self._leafs = OrderedDict()

                            self.map_resolver = YList(self)
                            self._segment_path = lambda: "itr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.Itr, [], name, value)


                        class MapResolver(Entity):
                            """
                            Configures map\-resolver address for sending Map\-Requests
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.Itr.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "itr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                ])
                                self.ip_addr = None
                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.Itr.MapResolver, ['ip_addr'], name, value)


                    class ItrEnable(Entity):
                        """
                        
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.ItrEnable, self).__init__()

                            self.yang_name = "itr-enable"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                            ])
                            self.itr = None
                            self._segment_path = lambda: "itr-enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.ItrEnable, ['itr'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.Etr.MapServer>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.Ipv6.Etr.MapServer))])
                            self._leafs = OrderedDict()

                            self.map_server = YList(self)
                            self._segment_path = lambda: "etr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.Etr, [], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.Etr.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.Ipv6.Etr.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.LispList.Default.Ipv6.Etr.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: key_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: key_7
                                
                                	The HIDDEN password
                                	**type**\: str
                                
                                .. attribute:: pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.Etr.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                        ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                        ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                        ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                    ])
                                    self.key_0 = None
                                    self.key_6 = None
                                    self.key_7 = None
                                    self.pwd = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                    class EtrEnable(Entity):
                        """
                        
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.EtrEnable, self).__init__()

                            self.yang_name = "etr-enable"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                            ])
                            self.etr = None
                            self._segment_path = lambda: "etr-enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.EtrEnable, ['etr'], name, value)


                    class Locator(Entity):
                        """
                        Locator related configuration
                        
                        .. attribute:: reachability
                        
                        	Configuration realted to locator reachability
                        	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.Locator.Reachability>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.Locator, self).__init__()

                            self.yang_name = "locator"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.LispList.Default.Ipv6.Locator.Reachability))])
                            self._leafs = OrderedDict()

                            self.reachability = Native.Router.LispList.Default.Ipv6.Locator.Reachability()
                            self.reachability.parent = self
                            self._children_name_map["reachability"] = "reachability"
                            self._segment_path = lambda: "locator"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.Locator, [], name, value)


                        class Reachability(Entity):
                            """
                            Configuration realted to locator reachability
                            
                            .. attribute:: exclude_default
                            
                            	If a remote RLOC is reached via the default route, treat it as unreachable
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.Locator.Reachability, self).__init__()

                                self.yang_name = "reachability"
                                self.yang_parent_name = "locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                ])
                                self.exclude_default = None
                                self._segment_path = lambda: "reachability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.Locator.Reachability, ['exclude_default'], name, value)


                    class MapCache(Entity):
                        """
                        Address family specific map cache configuration
                        
                        .. attribute:: site_registration
                        
                        	Install map cache to map request for site registrations
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                            ])
                            self.site_registration = None
                            self._segment_path = lambda: "map-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.MapCache, ['site_registration'], name, value)


                    class MapCacheLimit(Entity):
                        """
                        Configures maximum size of map\-cache
                        
                        .. attribute:: max_map_cache_entries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..100000
                        
                        .. attribute:: reserve_list
                        
                        	EID\-prefixes guaranteed to be stored in map\-cache
                        	**type**\: str
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.MapCacheLimit, self).__init__()

                            self.yang_name = "map-cache-limit"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.max_map_cache_entries = None
                            self.reserve_list = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "map-cache-limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                    class MapCachePersistent(Entity):
                        """
                        Dump map\-cache onto flash, making it persistent across reboots
                        
                        .. attribute:: interval
                        
                        	Interval in minutes of how often the map\-cache is saved
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.MapCachePersistent, self).__init__()

                            self.yang_name = "map-cache-persistent"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "map-cache-persistent"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.MapCachePersistent, ['interval'], name, value)


                    class MapResolver(Entity):
                        """
                        Configures a LISP Map Resolver (MR)
                        
                        .. attribute:: map_request
                        
                        	Map\-Request processing options
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_request = Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"
                            self._segment_path = lambda: "map-resolver"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.MapResolver, [], name, value)


                        class MapRequest(Entity):
                            """
                            Map\-Request processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "map-resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	Influence which source RLOCs map requests are accepted from
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    Influence which source RLOCs map requests are accepted from
                                    
                                    .. attribute:: list
                                    
                                    	Define allowed prefixes using an ip[v6] prefix list
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: registered
                                    
                                    	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 prefixes
                                    	**type**\: str
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 prefixes
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                            ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.list = None
                                        self.registered = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                    class MapServer(Entity):
                        """
                        Configures a LISP Map Server (MS)
                        
                        .. attribute:: map_register
                        
                        	Map\-Register processing options
                        	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.MapServer.MapRegister>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Default.Ipv6.MapServer.MapRegister))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_register = Native.Router.LispList.Default.Ipv6.MapServer.MapRegister()
                            self.map_register.parent = self
                            self._children_name_map["map_register"] = "map-register"
                            self._segment_path = lambda: "map-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.MapServer, [], name, value)


                        class MapRegister(Entity):
                            """
                            Map\-Register processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.MapServer.MapRegister.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.MapServer.MapRegister, self).__init__()

                                self.yang_name = "map-register"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.Ipv6.MapServer.MapRegister.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.LispList.Default.Ipv6.MapServer.MapRegister.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-register"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.MapServer.MapRegister, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	RLOC Source IP address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.MapServer.MapRegister.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-register"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.Ipv6.MapServer.MapRegister.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.Default.Ipv6.MapServer.MapRegister.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    RLOC Source IP address
                                    
                                    .. attribute:: allowed_locator
                                    
                                    	Against sites' allowed\-locators policy
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                        ])
                                        self.allowed_locator = None
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                    class PathMtuDiscovery(Entity):
                        """
                        Path MTU discovery
                        
                        .. attribute:: max
                        
                        	Upper bound on the path MTU accepted
                        	**type**\: int
                        
                        	**range:** 68..65535
                        
                        .. attribute:: min
                        
                        	Lower bound on the path MTU accepted
                        	**type**\: int
                        
                        	**range:** 68..65535
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.PathMtuDiscovery, self).__init__()

                            self.yang_name = "path-mtu-discovery"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                            ])
                            self.max = None
                            self.min = None
                            self._segment_path = lambda: "path-mtu-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.PathMtuDiscovery, ['max', 'min'], name, value)


                    class RouteExport(Entity):
                        """
                        Export routes into RIB from LISP
                        
                        .. attribute:: site_registrations
                        
                        	Export LISP site registrations to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: away_eids
                        
                        	Export LISP away EIDs to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.RouteExport, self).__init__()

                            self.yang_name = "route-export"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                            ])
                            self.site_registrations = None
                            self.away_eids = None
                            self._segment_path = lambda: "route-export"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                    class RouteImport(Entity):
                        """
                        Import RIB routes by a routing protocol into LISP
                        
                        .. attribute:: database
                        
                        	Use RIB routes to define local EID database entries
                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database>`
                        
                        .. attribute:: map_cache
                        
                        	Use RIB routes to define EID address space in map\-cache
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.RouteImport, self).__init__()

                            self.yang_name = "route-import"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache))])
                            self._leafs = OrderedDict()

                            self.database = Native.Router.LispList.Default.Ipv6.RouteImport.Database()
                            self.database.parent = self
                            self._children_name_map["database"] = "database"

                            self.map_cache = Native.Router.LispList.Default.Ipv6.RouteImport.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"
                            self._segment_path = lambda: "route-import"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport, [], name, value)


                        class Database(Entity):
                            """
                            Use RIB routes to define local EID database entries
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Connected>`
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Isis>`
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes to pick up from the RIB
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.MaximumPrefix>`
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospfv3>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Rip>`
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Static>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.RouteImport.Database, self).__init__()

                                self.yang_name = "database"
                                self.yang_parent_name = "route-import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.Ipv6.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Rip)), ("static", ("static", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Static))])
                                self._leafs = OrderedDict()

                                self.connected = Native.Router.LispList.Default.Ipv6.RouteImport.Database.Connected()
                                self.connected.parent = self
                                self._children_name_map["connected"] = "connected"

                                self.maximum_prefix = Native.Router.LispList.Default.Ipv6.RouteImport.Database.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.rip = Native.Router.LispList.Default.Ipv6.RouteImport.Database.Rip()
                                self.rip.parent = self
                                self._children_name_map["rip"] = "rip"

                                self.static = Native.Router.LispList.Default.Ipv6.RouteImport.Database.Static()
                                self.static.parent = self
                                self._children_name_map["static"] = "static"

                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.isis = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self._segment_path = lambda: "database"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database, [], name, value)


                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Connected, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Isis, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes to pick up from the RIB
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: warning_only
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: threshold
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: warning_only1
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.warning_only = None
                                    self.threshold = None
                                    self.threshold1 = None
                                    self.warning_only1 = None
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Ospfv3(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospfv3, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospfv3, ['id'], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "rip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Rip, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: lisp_ip_route_import
                                
                                	
                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                    self._leafs = OrderedDict()

                                    self.lisp_ip_route_import = Native.Router.LispList.Default.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                    self.lisp_ip_route_import.parent = self
                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Static, [], name, value)


                                class LispIpRouteImport(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                        self.yang_name = "lisp-ip-route-import"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "lisp-ip-route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class MapCache(Entity):
                            """
                            Use RIB routes to define EID address space in map\-cache
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Isis>`
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes to pick up from the RIB
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospfv3>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Rip>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Static>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "route-import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Static))])
                                self._leafs = OrderedDict()

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.maximum_prefix = Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.rip = None
                                self._children_name_map["rip"] = "rip"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.isis = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self._segment_path = lambda: "map-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache, [], name, value)


                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes to pick up from the RIB
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: warning_only
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: threshold
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: threshold1
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: warning_only1
                                
                                	Only give a warning message and do not limit entries
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.warning_only = None
                                    self.threshold = None
                                    self.threshold1 = None
                                    self.warning_only1 = None
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                            class Ospfv3(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospfv3, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "rip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Rip, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: map_cache_container
                                
                                	
                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_cache_container = None
                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                class MapCacheContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for route selection filtering
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                        self.yang_name = "map-cache-container"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "map-cache-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                    class SiteRegistration(Entity):
                        """
                        Site registrations configuration for a given instance\-id
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations for a given instance\-id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class SolicitMapRequest(Entity):
                        """
                        Configure Solicit\-Map\-Request handling
                        
                        .. attribute:: ignore
                        
                        	Ignore SMR bit in incoming Map\-Requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_per_entry
                        
                        	Maximum number of SMRs for addresses under a map\-cache entry
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: suppression_time
                        
                        	How long to suppress repeated SMRs for the same address
                        	**type**\: int
                        
                        	**range:** 1..600
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.SolicitMapRequest, self).__init__()

                            self.yang_name = "solicit-map-request"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                            ])
                            self.ignore = None
                            self.max_per_entry = None
                            self.suppression_time = None
                            self._segment_path = lambda: "solicit-map-request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                    class SourceLocator(Entity):
                        """
                        Source Locator configuration
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.SourceLocator.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.SourceLocator.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.SourceLocator.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Ipv6.SourceLocator.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.SourceLocator, self).__init__()

                            self.yang_name = "source-locator"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.LispList.Default.Ipv6.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.LispList.Default.Ipv6.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.LispList.Default.Ipv6.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.LispList.Default.Ipv6.SourceLocator.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Router.LispList.Default.Ipv6.SourceLocator.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Router.LispList.Default.Ipv6.SourceLocator.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Router.LispList.Default.Ipv6.SourceLocator.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Router.LispList.Default.Ipv6.SourceLocator.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "source-locator"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.SourceLocator.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.SourceLocator.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.SourceLocator.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Ipv6.SourceLocator.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "source-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Ipv6.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                    class UsePetr(Entity):
                        """
                        Encapsulate to Proxy ETR when matching forward\-native entry
                        
                        .. attribute:: locator_address  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	Configures which Locators from a set are preferred
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: weight
                        
                        	Traffic load\-spreading among Locators
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Ipv6.UsePetr, self).__init__()

                            self.yang_name = "use-petr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['locator_address']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                            ])
                            self.locator_address = None
                            self.priority = None
                            self.weight = None
                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Ipv6.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                class LocReachAlgorithm(Entity):
                    """
                    Configure locator reachability algorithm
                    
                    .. attribute:: lsb_reports
                    
                    	Configure data packet LSB report handling
                    	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.LocReachAlgorithm.LsbReports>`
                    
                    .. attribute:: rloc_probing
                    
                    	Probe high priority RLOCs with Map\-Requests as last resort
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.LocReachAlgorithm, self).__init__()

                        self.yang_name = "loc-reach-algorithm"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.LispList.Default.LocReachAlgorithm.LsbReports))])
                        self._leafs = OrderedDict([
                            ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                        ])
                        self.rloc_probing = None

                        self.lsb_reports = Native.Router.LispList.Default.LocReachAlgorithm.LsbReports()
                        self.lsb_reports.parent = self
                        self._children_name_map["lsb_reports"] = "lsb-reports"
                        self._segment_path = lambda: "loc-reach-algorithm"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.LocReachAlgorithm, ['rloc_probing'], name, value)


                    class LsbReports(Entity):
                        """
                        Configure data packet LSB report handling
                        
                        .. attribute:: do_not_transmit
                        
                        	Force the setting of the encapsulation header L bit to zero
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ignore
                        
                        	Ignore data packet LSB reports
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.LocReachAlgorithm.LsbReports, self).__init__()

                            self.yang_name = "lsb-reports"
                            self.yang_parent_name = "loc-reach-algorithm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.do_not_transmit = None
                            self.ignore = None
                            self._segment_path = lambda: "lsb-reports"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                class LocatorDown(Entity):
                    """
                    Manually set locator status to down
                    
                    .. attribute:: address
                    
                    	IPv4/6 Locator address to be set down
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv4_interface
                    
                    	Use IPv4 address of interface as locator
                    	**type**\: str
                    
                    .. attribute:: ipv6_interface
                    
                    	Use IPv6 address of interface as locator
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.LocatorDown, self).__init__()

                        self.yang_name = "locator-down"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                            ('ipv4_interface', (YLeaf(YType.str, 'IPv4-interface'), ['str'])),
                            ('ipv6_interface', (YLeaf(YType.str, 'IPv6-interface'), ['str'])),
                        ])
                        self.address = None
                        self.ipv4_interface = None
                        self.ipv6_interface = None
                        self._segment_path = lambda: "locator-down"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.LocatorDown, ['address', 'ipv4_interface', 'ipv6_interface'], name, value)


                class LocatorTable(Entity):
                    """
                    Specify the RLOC table
                    
                    .. attribute:: vrf_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	Default VRF
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	VRF name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.LocatorTable, self).__init__()

                        self.yang_name = "locator-table"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.vrf_name = None
                        self.default = None
                        self.vrf = None
                        self._segment_path = lambda: "locator-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.LocatorTable, ['vrf_name', 'default', 'vrf'], name, value)


                class MapRequest(Entity):
                    """
                    Configure map\-request handling
                    
                    .. attribute:: itr_rlocs
                    
                    	Configure to use the specified RLOC set as ITR RLOC in map\-request
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.MapRequest, self).__init__()

                        self.yang_name = "map-request"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('itr_rlocs', (YLeaf(YType.str, 'itr-rlocs'), ['str'])),
                        ])
                        self.itr_rlocs = None
                        self._segment_path = lambda: "map-request"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.MapRequest, ['itr_rlocs'], name, value)


                class MapServer(Entity):
                    """
                    Map\-Server commands
                    
                    .. attribute:: rloc
                    
                    	EID instance RLOC membership
                    	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.MapServer.Rloc>`
                    
                    .. attribute:: site_registration
                    
                    	Map\-server site registration options
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.MapServer.SiteRegistration>`
                    
                    .. attribute:: nmr
                    
                    	Map\-server negative map\-reply optio
                    	**type**\:  :py:class:`Nmr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.MapServer.Nmr>`
                    
                    .. attribute:: session
                    
                    	Map\-server session
                    	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.MapServer.Session>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.MapServer, self).__init__()

                        self.yang_name = "map-server"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.Default.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.LispList.Default.MapServer.SiteRegistration)), ("nmr", ("nmr", Native.Router.LispList.Default.MapServer.Nmr)), ("session", ("session", Native.Router.LispList.Default.MapServer.Session))])
                        self._leafs = OrderedDict()

                        self.rloc = Native.Router.LispList.Default.MapServer.Rloc()
                        self.rloc.parent = self
                        self._children_name_map["rloc"] = "rloc"

                        self.site_registration = Native.Router.LispList.Default.MapServer.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.nmr = Native.Router.LispList.Default.MapServer.Nmr()
                        self.nmr.parent = self
                        self._children_name_map["nmr"] = "nmr"

                        self.session = Native.Router.LispList.Default.MapServer.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                        self._segment_path = lambda: "map-server"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.MapServer, [], name, value)


                    class Rloc(Entity):
                        """
                        EID instance RLOC membership
                        
                        .. attribute:: members
                        
                        	EID instance RLOC membership
                        	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.MapServer.Rloc.Members>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.MapServer.Rloc, self).__init__()

                            self.yang_name = "rloc"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("members", ("members", Native.Router.LispList.Default.MapServer.Rloc.Members))])
                            self._leafs = OrderedDict()

                            self.members = Native.Router.LispList.Default.MapServer.Rloc.Members()
                            self.members.parent = self
                            self._children_name_map["members"] = "members"
                            self._segment_path = lambda: "rloc"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.MapServer.Rloc, [], name, value)


                        class Members(Entity):
                            """
                            EID instance RLOC membership
                            
                            .. attribute:: distribute
                            
                            	EID instance RLOC membership distribution
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: modify_discovered
                            
                            	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                            	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.MapServer.Rloc.Members.ModifyDiscovered>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.MapServer.Rloc.Members, self).__init__()

                                self.yang_name = "members"
                                self.yang_parent_name = "rloc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.LispList.Default.MapServer.Rloc.Members.ModifyDiscovered))])
                                self._leafs = OrderedDict([
                                    ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                ])
                                self.distribute = None

                                self.modify_discovered = Native.Router.LispList.Default.MapServer.Rloc.Members.ModifyDiscovered()
                                self.modify_discovered.parent = self
                                self._children_name_map["modify_discovered"] = "modify-discovered"
                                self._segment_path = lambda: "members"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.MapServer.Rloc.Members, ['distribute'], name, value)


                            class ModifyDiscovered(Entity):
                                """
                                Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                
                                .. attribute:: operator
                                
                                	
                                	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                
                                .. attribute:: locator_set
                                
                                	Locator set from which to get member RLOC addresses
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                    self.yang_name = "modify-discovered"
                                    self.yang_parent_name = "members"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.operator = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "modify-discovered"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                class Operator(Enum):
                                    """
                                    Operator (Enum Class)

                                    .. data:: add = 0

                                    .. data:: override = 1

                                    """

                                    add = Enum.YLeaf(0, "add")

                                    override = Enum.YLeaf(1, "override")



                    class SiteRegistration(Entity):
                        """
                        Map\-server site registration options
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations as a result of accept\-more\-specifics
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.MapServer.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class Nmr(Entity):
                        """
                        Map\-server negative map\-reply optio
                        
                        .. attribute:: non_site_ttl
                        
                        	Negative map\-reply TTL for non\-site EID
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.MapServer.Nmr, self).__init__()

                            self.yang_name = "nmr"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('non_site_ttl', (YLeaf(YType.uint16, 'non-site-ttl'), ['int'])),
                            ])
                            self.non_site_ttl = None
                            self._segment_path = lambda: "nmr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.MapServer.Nmr, ['non_site_ttl'], name, value)


                    class Session(Entity):
                        """
                        Map\-server session
                        
                        .. attribute:: passive_open
                        
                        	Open passive TCP sockets to listen for incoming connections
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.MapServer.Session, self).__init__()

                            self.yang_name = "session"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('passive_open', (YLeaf(YType.str, 'passive-open'), ['str'])),
                            ])
                            self.passive_open = None
                            self._segment_path = lambda: "session"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.MapServer.Session, ['passive_open'], name, value)


                class OtherXtrProbe(Entity):
                    """
                    Configure parameters for probing of other xTRs in our site
                    
                    .. attribute:: period
                    
                    	Period between probes in seconds
                    	**type**\: int
                    
                    	**range:** 5..900
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.OtherXtrProbe, self).__init__()

                        self.yang_name = "other-xtr-probe"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                        ])
                        self.period = None
                        self._segment_path = lambda: "other-xtr-probe"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.OtherXtrProbe, ['period'], name, value)


                class RemoteRlocProbe(Entity):
                    """
                    Configure parameters for probing of remote RLOCs
                    
                    .. attribute:: on_membership_change
                    
                    	Trigger probing upon membership changes for remote RLOC
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: on_route_change
                    
                    	Trigger probing upon routing changes for remote RLOC
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.RemoteRlocProbe, self).__init__()

                        self.yang_name = "remote-rloc-probe"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                            ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                        ])
                        self.on_membership_change = None
                        self.on_route_change = None
                        self._segment_path = lambda: "remote-rloc-probe"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                class EidTable(Entity):
                    """
                    Configure an EID instance for a VRF
                    
                    .. attribute:: instance_list
                    
                    	
                    	**type**\: list of  		 :py:class:`InstanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.EidTable, self).__init__()

                        self.yang_name = "eid-table"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("instance-list", ("instance_list", Native.Router.LispList.Default.EidTable.InstanceList))])
                        self._leafs = OrderedDict()

                        self.instance_list = YList(self)
                        self._segment_path = lambda: "eid-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.EidTable, [], name, value)


                    class InstanceList(Entity):
                        """
                        
                        
                        .. attribute:: instance_id  (key)
                        
                        	EID instance\-ID
                        	**type**\: int
                        
                        	**range:** 0..16777214
                        
                        .. attribute:: vrf_name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: default
                        
                        	Default VRF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vrf
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: database_mapping
                        
                        	Configures Locator addresses for an ETR
                        	**type**\: list of  		 :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.DatabaseMapping>`
                        
                        .. attribute:: dynamic_eid
                        
                        	Configure a dynamic EID
                        	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid>`
                        
                        .. attribute:: alt
                        
                        	LISP Alternative Topology, LISP\-ALT
                        	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Alt>`
                        
                        .. attribute:: control_packet
                        
                        	Configure control packet tx option
                        	**type**\:  :py:class:`ControlPacket <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.ControlPacket>`
                        
                        .. attribute:: ddt
                        
                        	Delegated Database Tree (DDT) mapping system
                        	**type**\:  :py:class:`Ddt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ddt>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: decapsulation
                        
                        	Decapsulation behavior (e.g. filters)
                        	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation>`
                        
                        .. attribute:: disable_ttl_propagate
                        
                        	Disable ttl propagation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Etr>`
                        
                        .. attribute:: ipv4
                        
                        	IPv4 address family
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	IPv6 address family
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6>`
                        
                        .. attribute:: loc_reach_algorithm
                        
                        	Configure locator reachability algorithm
                        	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.LocReachAlgorithm>`
                        
                        .. attribute:: locator_down
                        
                        	Manually set locator status to down
                        	**type**\:  :py:class:`LocatorDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.LocatorDown>`
                        
                        .. attribute:: locator_table
                        
                        	Specify the RLOC table
                        	**type**\:  :py:class:`LocatorTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.LocatorTable>`
                        
                        .. attribute:: map_request
                        
                        	Configure map\-request handling
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.MapRequest>`
                        
                        .. attribute:: map_server
                        
                        	Map\-Server commands
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.MapServer>`
                        
                        .. attribute:: other_xtr_probe
                        
                        	Configure parameters for probing of other xTRs in our site
                        	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.OtherXtrProbe>`
                        
                        .. attribute:: remote_rloc_probe
                        
                        	Configure parameters for probing of remote RLOCs
                        	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.RemoteRlocProbe>`
                        
                        .. attribute:: map_cache
                        
                        	Configures static EID\-to\-RLOC mappings for an ITR
                        	**type**\: list of  		 :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.MapCache>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.EidTable.InstanceList, self).__init__()

                            self.yang_name = "instance-list"
                            self.yang_parent_name = "eid-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance_id']
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Default.EidTable.InstanceList.DatabaseMapping)), ("dynamic-eid", ("dynamic_eid", Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid)), ("alt", ("alt", Native.Router.LispList.Default.EidTable.InstanceList.Alt)), ("control-packet", ("control_packet", Native.Router.LispList.Default.EidTable.InstanceList.ControlPacket)), ("ddt", ("ddt", Native.Router.LispList.Default.EidTable.InstanceList.Ddt)), ("decapsulation", ("decapsulation", Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation)), ("etr", ("etr", Native.Router.LispList.Default.EidTable.InstanceList.Etr)), ("ipv4", ("ipv4", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4)), ("ipv6", ("ipv6", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.LispList.Default.EidTable.InstanceList.LocReachAlgorithm)), ("locator-down", ("locator_down", Native.Router.LispList.Default.EidTable.InstanceList.LocatorDown)), ("locator-table", ("locator_table", Native.Router.LispList.Default.EidTable.InstanceList.LocatorTable)), ("map-request", ("map_request", Native.Router.LispList.Default.EidTable.InstanceList.MapRequest)), ("map-server", ("map_server", Native.Router.LispList.Default.EidTable.InstanceList.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.LispList.Default.EidTable.InstanceList.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.LispList.Default.EidTable.InstanceList.RemoteRlocProbe)), ("map-cache", ("map_cache", Native.Router.LispList.Default.EidTable.InstanceList.MapCache))])
                            self._leafs = OrderedDict([
                                ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                            ])
                            self.instance_id = None
                            self.vrf_name = None
                            self.default = None
                            self.vrf = None
                            self.disable_ttl_propagate = None

                            self.alt = Native.Router.LispList.Default.EidTable.InstanceList.Alt()
                            self.alt.parent = self
                            self._children_name_map["alt"] = "alt"

                            self.control_packet = Native.Router.LispList.Default.EidTable.InstanceList.ControlPacket()
                            self.control_packet.parent = self
                            self._children_name_map["control_packet"] = "control-packet"

                            self.ddt = None
                            self._children_name_map["ddt"] = "ddt"

                            self.decapsulation = Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation()
                            self.decapsulation.parent = self
                            self._children_name_map["decapsulation"] = "decapsulation"

                            self.etr = Native.Router.LispList.Default.EidTable.InstanceList.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.ipv4 = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"

                            self.loc_reach_algorithm = Native.Router.LispList.Default.EidTable.InstanceList.LocReachAlgorithm()
                            self.loc_reach_algorithm.parent = self
                            self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                            self.locator_down = Native.Router.LispList.Default.EidTable.InstanceList.LocatorDown()
                            self.locator_down.parent = self
                            self._children_name_map["locator_down"] = "locator-down"

                            self.locator_table = Native.Router.LispList.Default.EidTable.InstanceList.LocatorTable()
                            self.locator_table.parent = self
                            self._children_name_map["locator_table"] = "locator-table"

                            self.map_request = Native.Router.LispList.Default.EidTable.InstanceList.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"

                            self.map_server = Native.Router.LispList.Default.EidTable.InstanceList.MapServer()
                            self.map_server.parent = self
                            self._children_name_map["map_server"] = "map-server"

                            self.other_xtr_probe = Native.Router.LispList.Default.EidTable.InstanceList.OtherXtrProbe()
                            self.other_xtr_probe.parent = self
                            self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                            self.remote_rloc_probe = Native.Router.LispList.Default.EidTable.InstanceList.RemoteRlocProbe()
                            self.remote_rloc_probe.parent = self
                            self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                            self.database_mapping = YList(self)
                            self.dynamic_eid = YList(self)
                            self.map_cache = YList(self)
                            self._segment_path = lambda: "instance-list" + "[instance-id='" + str(self.instance_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList, ['instance_id', 'vrf_name', 'default', 'vrf', 'disable_ttl_propagate'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Configures Locator addresses for an ETR
                            
                            .. attribute:: eid_prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: locator_set
                            
                            	Use locators defined by locator\-set
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['eid_prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                ])
                                self.eid_prefix = None
                                self.locator_set = None
                                self._segment_path = lambda: "database-mapping" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.DatabaseMapping, ['eid_prefix', 'locator_set'], name, value)


                        class DynamicEid(Entity):
                            """
                            Configure a dynamic EID
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: database_mapping
                            
                            	Configures EID\-prefix and locator\-set for dynamic\-EID
                            	**type**\: list of  		 :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.DatabaseMapping>`
                            
                            .. attribute:: eid_notify
                            
                            	Configure options for sending/receiving EID\-notify
                            	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify>`
                            
                            .. attribute:: map_notify_group
                            
                            	Multicast group which to send map\-notifies to
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid, self).__init__()

                                self.yang_name = "dynamic-eid"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.MapServer))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                                ])
                                self.name = None
                                self.map_notify_group = None

                                self.eid_notify = Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify()
                                self.eid_notify.parent = self
                                self._children_name_map["eid_notify"] = "eid-notify"

                                self.database_mapping = YList(self)
                                self.map_server = YList(self)
                                self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid, ['name', 'map_notify_group'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures EID\-prefix and locator\-set for dynamic\-EID
                                
                                .. attribute:: eid_prefix  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                .. attribute:: locator_set
                                
                                	Use locators defined by locator\-set
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['eid_prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.eid_prefix = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "database-mapping" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.DatabaseMapping, ['eid_prefix', 'locator_set'], name, value)


                            class EidNotify(Entity):
                                """
                                Configure options for sending/receiving EID\-notify
                                
                                .. attribute:: authentication_key
                                
                                	Authentication key used for validating received EID\-notify
                                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey>`
                                
                                .. attribute:: gateway_key
                                
                                	
                                	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify, self).__init__()

                                    self.yang_name = "eid-notify"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey))])
                                    self._leafs = OrderedDict()

                                    self.authentication_key = Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey()
                                    self.authentication_key.parent = self
                                    self._children_name_map["authentication_key"] = "authentication-key"

                                    self.gateway_key = YList(self)
                                    self._segment_path = lambda: "eid-notify"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify, [], name, value)


                                class AuthenticationKey(Entity):
                                    """
                                    Authentication key used for validating received EID\-notify
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                        self.yang_name = "authentication-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                        ])
                                        self.ak_0 = None
                                        self.ak_6 = None
                                        self.unc_pwd = None
                                        self._segment_path = lambda: "authentication-key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey, ['ak_0', 'ak_6', 'unc_pwd'], name, value)


                                class GatewayKey(Entity):
                                    """
                                    
                                    
                                    .. attribute:: gateway_ip  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	EID\-notify authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey.HashFunction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                        self.yang_name = "gateway-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['gateway_ip']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey.HashFunction')])),
                                        ])
                                        self.gateway_ip = None
                                        self.ak_0 = None
                                        self.ak_6 = None
                                        self.unc_pwd = None
                                        self.hash_function = None
                                        self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey, ['gateway_ip', 'ak_0', 'ak_6', 'unc_pwd', 'hash_function'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        EID\-notify authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip='" + str(self.ip) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.MapServer, ['ip', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: key_7
                                    
                                    	The HIDDEN password
                                    	**type**\: str
                                    
                                    .. attribute:: pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	Map\-Register authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.MapServer.Key.HashFunction>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                            ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.EidTable.InstanceList.DynamicEid.MapServer.Key.HashFunction')])),
                                        ])
                                        self.key_0 = None
                                        self.key_6 = None
                                        self.key_7 = None
                                        self.pwd = None
                                        self.hash_function = None
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.DynamicEid.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd', 'hash_function'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        Map\-Register authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                        class Alt(Entity):
                            """
                            LISP Alternative Topology, LISP\-ALT
                            
                            .. attribute:: summary_route
                            
                            	Summary route to install into the ALT table
                            	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Alt.SummaryRoute>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.Alt, self).__init__()

                                self.yang_name = "alt"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.Default.EidTable.InstanceList.Alt.SummaryRoute))])
                                self._leafs = OrderedDict()

                                self.summary_route = YList(self)
                                self._segment_path = lambda: "alt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Alt, [], name, value)


                            class SummaryRoute(Entity):
                                """
                                Summary route to install into the ALT table
                                
                                .. attribute:: eid_prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: route_tag
                                
                                	ALT RIB route tag for EID prefix
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Alt.SummaryRoute, self).__init__()

                                    self.yang_name = "summary-route"
                                    self.yang_parent_name = "alt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['eid_prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.eid_prefix = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                        class ControlPacket(Entity):
                            """
                            Configure control packet tx option
                            
                            .. attribute:: mtu
                            
                            	Configure control packet MTU
                            	**type**\: int
                            
                            	**range:** 304..10000
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.ControlPacket, self).__init__()

                                self.yang_name = "control-packet"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                                ])
                                self.mtu = None
                                self._segment_path = lambda: "control-packet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.ControlPacket, ['mtu'], name, value)


                        class Ddt(Entity):
                            """
                            Delegated Database Tree (DDT) mapping system
                            
                            .. attribute:: authoritative
                            
                            	DDT authoritative prefix
                            	**type**\:  :py:class:`Authoritative <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative>`
                            
                            .. attribute:: cache_limit
                            
                            	DDT resolver cache entry limit
                            	**type**\: int
                            
                            	**range:** 1..100000
                            
                            .. attribute:: root
                            
                            	DDT root node
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ddt, self).__init__()

                                self.yang_name = "ddt"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authoritative", ("authoritative", Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('cache_limit', (YLeaf(YType.uint32, 'cache-limit'), ['int'])),
                                    ('root', (YLeaf(YType.str, 'root'), ['str','str'])),
                                ])
                                self.cache_limit = None
                                self.root = None

                                self.authoritative = Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative()
                                self.authoritative.parent = self
                                self._children_name_map["authoritative"] = "authoritative"
                                self._segment_path = lambda: "ddt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ddt, ['cache_limit', 'root'], name, value)


                            class Authoritative(Entity):
                                """
                                DDT authoritative prefix
                                
                                .. attribute:: instance_id_eid_prefix_list
                                
                                	
                                	**type**\: list of  		 :py:class:`InstanceIdEidPrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList>`
                                
                                .. attribute:: instance_id_list
                                
                                	
                                	**type**\: list of  		 :py:class:`InstanceIdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative, self).__init__()

                                    self.yang_name = "authoritative"
                                    self.yang_parent_name = "ddt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("instance-id-eid-prefix-list", ("instance_id_eid_prefix_list", Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList)), ("instance-id-list", ("instance_id_list", Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList))])
                                    self._leafs = OrderedDict()

                                    self.instance_id_eid_prefix_list = YList(self)
                                    self.instance_id_list = YList(self)
                                    self._segment_path = lambda: "authoritative"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative, [], name, value)


                                class InstanceIdEidPrefixList(Entity):
                                    """
                                    
                                    
                                    .. attribute:: instance_id  (key)
                                    
                                    	EID instance\-ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: delegate
                                    
                                    	DDT delegation to a child DDT node or map\-server
                                    	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate>`
                                    
                                    .. attribute:: map_server_peer
                                    
                                    	Peer map\-servers that are authoritative for the same EID prefixes
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList, self).__init__()

                                        self.yang_name = "instance-id-eid-prefix-list"
                                        self.yang_parent_name = "authoritative"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['instance_id','eid_prefix']
                                        self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate))])
                                        self._leafs = OrderedDict([
                                            ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                        ])
                                        self.instance_id = None
                                        self.eid_prefix = None
                                        self.map_server_peer = None

                                        self.delegate = Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate()
                                        self.delegate.parent = self
                                        self._children_name_map["delegate"] = "delegate"
                                        self._segment_path = lambda: "instance-id-eid-prefix-list" + "[instance-id='" + str(self.instance_id) + "']" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList, ['instance_id', 'eid_prefix', 'map_server_peer'], name, value)


                                    class Delegate(Entity):
                                        """
                                        DDT delegation to a child DDT node or map\-server
                                        
                                        .. attribute:: eid_prefix
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: instance_id
                                        
                                        	EID instance\-ID
                                        	**type**\: str
                                        
                                        .. attribute:: to
                                        
                                        	DDT delegation to a child DDT node or map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ip_address
                                        
                                        	IPv4/6 Child or map\-server node locator address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: map_server
                                        
                                        	Delegation points to a map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, self).__init__()

                                            self.yang_name = "delegate"
                                            self.yang_parent_name = "instance-id-eid-prefix-list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                                ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                                ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                                ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.instance_id = None
                                            self.to = None
                                            self.ip_address = None
                                            self.map_server = None
                                            self._segment_path = lambda: "delegate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                                class InstanceIdList(Entity):
                                    """
                                    
                                    
                                    .. attribute:: instance_id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: delegate
                                    
                                    	DDT delegation to a child DDT node or map\-server
                                    	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate>`
                                    
                                    .. attribute:: map_server_peer
                                    
                                    	Peer map\-servers that are authoritative for the same EID prefixes
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList, self).__init__()

                                        self.yang_name = "instance-id-list"
                                        self.yang_parent_name = "authoritative"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['instance_id']
                                        self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate))])
                                        self._leafs = OrderedDict([
                                            ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                            ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                        ])
                                        self.instance_id = None
                                        self.map_server_peer = None

                                        self.delegate = Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate()
                                        self.delegate.parent = self
                                        self._children_name_map["delegate"] = "delegate"
                                        self._segment_path = lambda: "instance-id-list" + "[instance-id='" + str(self.instance_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList, ['instance_id', 'map_server_peer'], name, value)


                                    class Delegate(Entity):
                                        """
                                        DDT delegation to a child DDT node or map\-server
                                        
                                        .. attribute:: eid_prefix
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: instance_id
                                        
                                        	EID instance\-ID
                                        	**type**\: str
                                        
                                        .. attribute:: to
                                        
                                        	DDT delegation to a child DDT node or map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ip_address
                                        
                                        	IPv4/6 Child or map\-server node locator address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: map_server
                                        
                                        	Delegation points to a map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate, self).__init__()

                                            self.yang_name = "delegate"
                                            self.yang_parent_name = "instance-id-list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                                ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                                ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                                ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.instance_id = None
                                            self.to = None
                                            self.ip_address = None
                                            self.map_server = None
                                            self._segment_path = lambda: "delegate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                        class Decapsulation(Entity):
                            """
                            Decapsulation behavior (e.g. filters)
                            
                            .. attribute:: filter
                            
                            	Filters traffic
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation, self).__init__()

                                self.yang_name = "decapsulation"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("filter", ("filter", Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter))])
                                self._leafs = OrderedDict()

                                self.filter = Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"
                                self._segment_path = lambda: "decapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation, [], name, value)


                            class Filter(Entity):
                                """
                                Filters traffic
                                
                                .. attribute:: rloc
                                
                                	Filter based on Routing Locator (RLOC) in packet header
                                	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "decapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc))])
                                    self._leafs = OrderedDict()

                                    self.rloc = Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc()
                                    self.rloc.parent = self
                                    self._children_name_map["rloc"] = "rloc"
                                    self._segment_path = lambda: "filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter, [], name, value)


                                class Rloc(Entity):
                                    """
                                    Filter based on Routing Locator (RLOC) in packet header
                                    
                                    .. attribute:: source
                                    
                                    	Filters traffic based on RLOC source address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc, self).__init__()

                                        self.yang_name = "rloc"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "rloc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc, [], name, value)


                                    class Source(Entity):
                                        """
                                        Filters traffic based on RLOC source address
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator\-set Name
                                        	**type**\: str
                                        
                                        .. attribute:: member
                                        
                                        	Members learned from map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "rloc"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.member = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Etr.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.EidTable.InstanceList.Etr.MapServer))])
                                self._leafs = OrderedDict()

                                self.map_server = Native.Router.LispList.Default.EidTable.InstanceList.Etr.MapServer()
                                self.map_server.parent = self
                                self._children_name_map["map_server"] = "map-server"
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Etr, [], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: source_address
                                
                                	Configures map server source address
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                    ])
                                    self.source_address = None
                                    self._segment_path = lambda: "map-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Etr.MapServer, ['source_address'], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 address family
                            
                            .. attribute:: alt_vrf
                            
                            	Activate LISP\-ALT functionality in VRF
                            	**type**\: str
                            
                            	**status**\: deprecated
                            
                            .. attribute:: database_mapping
                            
                            	Address family specific local EID prefixes database configuration
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.DatabaseMapping>`
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Distance>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.ItrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.EtrEnable>`
                            
                            .. attribute:: locator
                            
                            	Locator related configuration
                            	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Locator>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCache>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCacheLimit>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCachePersistent>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_resolver
                            
                            	Configures a LISP Map Resolver (MR)
                            	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: map_server
                            
                            	Configures a LISP Map Server (MS)
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: path_mtu_discovery
                            
                            	Path MTU discovery
                            	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.PathMtuDiscovery>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteExport>`
                            
                            .. attribute:: route_import
                            
                            	Import RIB routes by a routing protocol into LISP
                            	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SolicitMapRequest>`
                            
                            .. attribute:: source_locator
                            
                            	Source Locator configuration
                            	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.UsePetr>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.DatabaseMapping)), ("distance", ("distance", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Distance)), ("itr", ("itr", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.ItrEnable)), ("etr", ("etr", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.EtrEnable)), ("locator", ("locator", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Locator)), ("map-cache", ("map_cache", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteExport)), ("route-import", ("route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport)), ("site-registration", ("site_registration", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator)), ("use-petr", ("use_petr", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.UsePetr))])
                                self._leafs = OrderedDict([
                                    ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ])
                                self.alt_vrf = None
                                self.map_request_source = None
                                self.proxy_etr = None
                                self.proxy_itr = []
                                self.sgt = None

                                self.database_mapping = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.distance = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.itr = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.etr_enable = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.locator = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Locator()
                                self.locator.parent = self
                                self._children_name_map["locator"] = "locator"

                                self.map_cache = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_limit = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.map_cache_persistent = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.map_resolver = None
                                self._children_name_map["map_resolver"] = "map-resolver"

                                self.map_server = None
                                self._children_name_map["map_server"] = "map-server"

                                self.path_mtu_discovery = None
                                self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                                self.route_export = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport()
                                self.route_import.parent = self
                                self._children_name_map["route_import"] = "route-import"

                                self.site_registration = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.source_locator = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator()
                                self.source_locator.parent = self
                                self._children_name_map["source_locator"] = "source-locator"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Address family specific local EID prefixes database configuration
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.DatabaseMapping, [], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Itr.MapResolver>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Itr.MapResolver))])
                                    self._leafs = OrderedDict()

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Itr, [], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ])
                                        self.ip_addr = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Itr.MapResolver, ['ip_addr'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.ItrEnable, ['itr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr.MapServer>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr.MapServer))])
                                    self._leafs = OrderedDict()

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr, [], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: key_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: key_7
                                        
                                        	The HIDDEN password
                                        	**type**\: str
                                        
                                        .. attribute:: pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                                ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                                ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                                ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                            ])
                                            self.key_0 = None
                                            self.key_6 = None
                                            self.key_7 = None
                                            self.pwd = None
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.EtrEnable, ['etr'], name, value)


                            class Locator(Entity):
                                """
                                Locator related configuration
                                
                                .. attribute:: reachability
                                
                                	Configuration realted to locator reachability
                                	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Locator.Reachability>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Locator, self).__init__()

                                    self.yang_name = "locator"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Locator.Reachability))])
                                    self._leafs = OrderedDict()

                                    self.reachability = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Locator.Reachability()
                                    self.reachability.parent = self
                                    self._children_name_map["reachability"] = "reachability"
                                    self._segment_path = lambda: "locator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Locator, [], name, value)


                                class Reachability(Entity):
                                    """
                                    Configuration realted to locator reachability
                                    
                                    .. attribute:: exclude_default
                                    
                                    	If a remote RLOC is reached via the default route, treat it as unreachable
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Locator.Reachability, self).__init__()

                                        self.yang_name = "reachability"
                                        self.yang_parent_name = "locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                        ])
                                        self.exclude_default = None
                                        self._segment_path = lambda: "reachability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.Locator.Reachability, ['exclude_default'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCache, ['site_registration'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapCachePersistent, ['interval'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures a LISP Map Resolver (MR)
                                
                                .. attribute:: map_request
                                
                                	Map\-Request processing options
                                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_request = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest()
                                    self.map_request.parent = self
                                    self._children_name_map["map_request"] = "map-request"
                                    self._segment_path = lambda: "map-resolver"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver, [], name, value)


                                class MapRequest(Entity):
                                    """
                                    Map\-Request processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest, self).__init__()

                                        self.yang_name = "map-request"
                                        self.yang_parent_name = "map-resolver"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	Influence which source RLOCs map requests are accepted from
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            Influence which source RLOCs map requests are accepted from
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: registered
                                            
                                            	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                                    ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.list = None
                                                self.registered = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                            class MapServer(Entity):
                                """
                                Configures a LISP Map Server (MS)
                                
                                .. attribute:: map_register
                                
                                	Map\-Register processing options
                                	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_register = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister()
                                    self.map_register.parent = self
                                    self._children_name_map["map_register"] = "map-register"
                                    self._segment_path = lambda: "map-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer, [], name, value)


                                class MapRegister(Entity):
                                    """
                                    Map\-Register processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister, self).__init__()

                                        self.yang_name = "map-register"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-register"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	RLOC Source IP address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-register"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            RLOC Source IP address
                                            
                                            .. attribute:: allowed_locator
                                            
                                            	Against sites' allowed\-locators policy
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                                ])
                                                self.allowed_locator = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                            class PathMtuDiscovery(Entity):
                                """
                                Path MTU discovery
                                
                                .. attribute:: max
                                
                                	Upper bound on the path MTU accepted
                                	**type**\: int
                                
                                	**range:** 68..65535
                                
                                .. attribute:: min
                                
                                	Lower bound on the path MTU accepted
                                	**type**\: int
                                
                                	**range:** 68..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.PathMtuDiscovery, self).__init__()

                                    self.yang_name = "path-mtu-discovery"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self._segment_path = lambda: "path-mtu-discovery"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.PathMtuDiscovery, ['max', 'min'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class RouteImport(Entity):
                                """
                                Import RIB routes by a routing protocol into LISP
                                
                                .. attribute:: database
                                
                                	Use RIB routes to define local EID database entries
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database>`
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport, self).__init__()

                                    self.yang_name = "route-import"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.map_cache = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"
                                    self._segment_path = lambda: "route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport, [], name, value)


                                class Database(Entity):
                                    """
                                    Use RIB routes to define local EID database entries
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected>`
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip)), ("static", ("static", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected()
                                        self.connected.parent = self
                                        self._children_name_map["connected"] = "connected"

                                        self.maximum_prefix = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.rip = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip()
                                        self.rip.parent = self
                                        self._children_name_map["rip"] = "rip"

                                        self.static = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static()
                                        self.static.parent = self
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.isis = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database, [], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.maximum_prefix = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.rip = None
                                        self._children_name_map["rip"] = "rip"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.isis = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache, [], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations for a given instance\-id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class SourceLocator(Entity):
                                """
                                Source Locator configuration
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator, self).__init__()

                                    self.yang_name = "source-locator"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "source-locator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.locator_address = None
                                    self.priority = None
                                    self.weight = None
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv4.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 address family
                            
                            .. attribute:: alt_vrf
                            
                            	Activate LISP\-ALT functionality in VRF
                            	**type**\: str
                            
                            	**status**\: deprecated
                            
                            .. attribute:: database_mapping
                            
                            	Address family specific local EID prefixes database configuration
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.DatabaseMapping>`
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Distance>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.ItrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.EtrEnable>`
                            
                            .. attribute:: locator
                            
                            	Locator related configuration
                            	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Locator>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCache>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCacheLimit>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCachePersistent>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_resolver
                            
                            	Configures a LISP Map Resolver (MR)
                            	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: map_server
                            
                            	Configures a LISP Map Server (MS)
                            	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: path_mtu_discovery
                            
                            	Path MTU discovery
                            	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.PathMtuDiscovery>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\: union of the below types:
                            
                            		**type**\: list of str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: list of str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteExport>`
                            
                            .. attribute:: route_import
                            
                            	Import RIB routes by a routing protocol into LISP
                            	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SolicitMapRequest>`
                            
                            .. attribute:: source_locator
                            
                            	Source Locator configuration
                            	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.UsePetr>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.DatabaseMapping)), ("distance", ("distance", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Distance)), ("itr", ("itr", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.ItrEnable)), ("etr", ("etr", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr)), ("etr-enable", ("etr_enable", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.EtrEnable)), ("locator", ("locator", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Locator)), ("map-cache", ("map_cache", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteExport)), ("route-import", ("route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport)), ("site-registration", ("site_registration", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator)), ("use-petr", ("use_petr", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.UsePetr))])
                                self._leafs = OrderedDict([
                                    ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ])
                                self.alt_vrf = None
                                self.map_request_source = None
                                self.proxy_etr = None
                                self.proxy_itr = []
                                self.sgt = None

                                self.database_mapping = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.distance = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.itr = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.etr_enable = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.locator = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Locator()
                                self.locator.parent = self
                                self._children_name_map["locator"] = "locator"

                                self.map_cache = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_limit = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.map_cache_persistent = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.map_resolver = None
                                self._children_name_map["map_resolver"] = "map-resolver"

                                self.map_server = None
                                self._children_name_map["map_server"] = "map-server"

                                self.path_mtu_discovery = None
                                self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                                self.route_export = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport()
                                self.route_import.parent = self
                                self._children_name_map["route_import"] = "route-import"

                                self.site_registration = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.source_locator = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator()
                                self.source_locator.parent = self
                                self._children_name_map["source_locator"] = "source-locator"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Address family specific local EID prefixes database configuration
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.DatabaseMapping, [], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Itr.MapResolver>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Itr.MapResolver))])
                                    self._leafs = OrderedDict()

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Itr, [], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ])
                                        self.ip_addr = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Itr.MapResolver, ['ip_addr'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.ItrEnable, ['itr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr.MapServer>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr.MapServer))])
                                    self._leafs = OrderedDict()

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr, [], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: key_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: key_7
                                        
                                        	The HIDDEN password
                                        	**type**\: str
                                        
                                        .. attribute:: pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                                ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                                ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                                ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                            ])
                                            self.key_0 = None
                                            self.key_6 = None
                                            self.key_7 = None
                                            self.pwd = None
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.EtrEnable, ['etr'], name, value)


                            class Locator(Entity):
                                """
                                Locator related configuration
                                
                                .. attribute:: reachability
                                
                                	Configuration realted to locator reachability
                                	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Locator.Reachability>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Locator, self).__init__()

                                    self.yang_name = "locator"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Locator.Reachability))])
                                    self._leafs = OrderedDict()

                                    self.reachability = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Locator.Reachability()
                                    self.reachability.parent = self
                                    self._children_name_map["reachability"] = "reachability"
                                    self._segment_path = lambda: "locator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Locator, [], name, value)


                                class Reachability(Entity):
                                    """
                                    Configuration realted to locator reachability
                                    
                                    .. attribute:: exclude_default
                                    
                                    	If a remote RLOC is reached via the default route, treat it as unreachable
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Locator.Reachability, self).__init__()

                                        self.yang_name = "reachability"
                                        self.yang_parent_name = "locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                        ])
                                        self.exclude_default = None
                                        self._segment_path = lambda: "reachability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.Locator.Reachability, ['exclude_default'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCache, ['site_registration'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapCachePersistent, ['interval'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures a LISP Map Resolver (MR)
                                
                                .. attribute:: map_request
                                
                                	Map\-Request processing options
                                	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_request = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest()
                                    self.map_request.parent = self
                                    self._children_name_map["map_request"] = "map-request"
                                    self._segment_path = lambda: "map-resolver"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver, [], name, value)


                                class MapRequest(Entity):
                                    """
                                    Map\-Request processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest, self).__init__()

                                        self.yang_name = "map-request"
                                        self.yang_parent_name = "map-resolver"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	Influence which source RLOCs map requests are accepted from
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            Influence which source RLOCs map requests are accepted from
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: registered
                                            
                                            	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                                    ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.list = None
                                                self.registered = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                            class MapServer(Entity):
                                """
                                Configures a LISP Map Server (MS)
                                
                                .. attribute:: map_register
                                
                                	Map\-Register processing options
                                	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.map_register = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister()
                                    self.map_register.parent = self
                                    self._children_name_map["map_register"] = "map-register"
                                    self._segment_path = lambda: "map-server"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer, [], name, value)


                                class MapRegister(Entity):
                                    """
                                    Map\-Register processing options
                                    
                                    .. attribute:: validate
                                    
                                    	Validation options
                                    	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister, self).__init__()

                                        self.yang_name = "map-register"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate))])
                                        self._leafs = OrderedDict()

                                        self.validate = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate()
                                        self.validate.parent = self
                                        self._children_name_map["validate"] = "validate"
                                        self._segment_path = lambda: "map-register"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister, [], name, value)


                                    class Validate(Entity):
                                        """
                                        Validation options
                                        
                                        .. attribute:: source
                                        
                                        	RLOC Source IP address
                                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                            self.yang_name = "validate"
                                            self.yang_parent_name = "map-register"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source))])
                                            self._leafs = OrderedDict()

                                            self.source = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source()
                                            self.source.parent = self
                                            self._children_name_map["source"] = "source"
                                            self._segment_path = lambda: "validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                                        class Source(Entity):
                                            """
                                            RLOC Source IP address
                                            
                                            .. attribute:: allowed_locator
                                            
                                            	Against sites' allowed\-locators policy
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "validate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                                ])
                                                self.allowed_locator = None
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                            class PathMtuDiscovery(Entity):
                                """
                                Path MTU discovery
                                
                                .. attribute:: max
                                
                                	Upper bound on the path MTU accepted
                                	**type**\: int
                                
                                	**range:** 68..65535
                                
                                .. attribute:: min
                                
                                	Lower bound on the path MTU accepted
                                	**type**\: int
                                
                                	**range:** 68..65535
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.PathMtuDiscovery, self).__init__()

                                    self.yang_name = "path-mtu-discovery"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                    ])
                                    self.max = None
                                    self.min = None
                                    self._segment_path = lambda: "path-mtu-discovery"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.PathMtuDiscovery, ['max', 'min'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class RouteImport(Entity):
                                """
                                Import RIB routes by a routing protocol into LISP
                                
                                .. attribute:: database
                                
                                	Use RIB routes to define local EID database entries
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database>`
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport, self).__init__()

                                    self.yang_name = "route-import"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.map_cache = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"
                                    self._segment_path = lambda: "route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport, [], name, value)


                                class Database(Entity):
                                    """
                                    Use RIB routes to define local EID database entries
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected>`
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip)), ("static", ("static", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected()
                                        self.connected.parent = self
                                        self._children_name_map["connected"] = "connected"

                                        self.maximum_prefix = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.rip = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip()
                                        self.rip.parent = self
                                        self._children_name_map["rip"] = "rip"

                                        self.static = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static()
                                        self.static.parent = self
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.isis = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database, [], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.maximum_prefix = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.rip = None
                                        self._children_name_map["rip"] = "rip"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.isis = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache, [], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations for a given instance\-id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class SourceLocator(Entity):
                                """
                                Source Locator configuration
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator, self).__init__()

                                    self.yang_name = "source-locator"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "source-locator"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "source-locator"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.locator_address = None
                                    self.priority = None
                                    self.weight = None
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.Ipv6.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                        class LocReachAlgorithm(Entity):
                            """
                            Configure locator reachability algorithm
                            
                            .. attribute:: lsb_reports
                            
                            	Configure data packet LSB report handling
                            	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.LocReachAlgorithm.LsbReports>`
                            
                            .. attribute:: rloc_probing
                            
                            	Probe high priority RLOCs with Map\-Requests as last resort
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.LocReachAlgorithm, self).__init__()

                                self.yang_name = "loc-reach-algorithm"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.LispList.Default.EidTable.InstanceList.LocReachAlgorithm.LsbReports))])
                                self._leafs = OrderedDict([
                                    ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                                ])
                                self.rloc_probing = None

                                self.lsb_reports = Native.Router.LispList.Default.EidTable.InstanceList.LocReachAlgorithm.LsbReports()
                                self.lsb_reports.parent = self
                                self._children_name_map["lsb_reports"] = "lsb-reports"
                                self._segment_path = lambda: "loc-reach-algorithm"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.LocReachAlgorithm, ['rloc_probing'], name, value)


                            class LsbReports(Entity):
                                """
                                Configure data packet LSB report handling
                                
                                .. attribute:: do_not_transmit
                                
                                	Force the setting of the encapsulation header L bit to zero
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ignore
                                
                                	Ignore data packet LSB reports
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.LocReachAlgorithm.LsbReports, self).__init__()

                                    self.yang_name = "lsb-reports"
                                    self.yang_parent_name = "loc-reach-algorithm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ])
                                    self.do_not_transmit = None
                                    self.ignore = None
                                    self._segment_path = lambda: "lsb-reports"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                        class LocatorDown(Entity):
                            """
                            Manually set locator status to down
                            
                            .. attribute:: address
                            
                            	IPv4/6 Locator address to be set down
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_interface
                            
                            	Use IPv4 address of interface as locator
                            	**type**\: str
                            
                            .. attribute:: ipv6_interface
                            
                            	Use IPv6 address of interface as locator
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.LocatorDown, self).__init__()

                                self.yang_name = "locator-down"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                    ('ipv4_interface', (YLeaf(YType.str, 'IPv4-interface'), ['str'])),
                                    ('ipv6_interface', (YLeaf(YType.str, 'IPv6-interface'), ['str'])),
                                ])
                                self.address = None
                                self.ipv4_interface = None
                                self.ipv6_interface = None
                                self._segment_path = lambda: "locator-down"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.LocatorDown, ['address', 'ipv4_interface', 'ipv6_interface'], name, value)


                        class LocatorTable(Entity):
                            """
                            Specify the RLOC table
                            
                            .. attribute:: vrf_name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: default
                            
                            	Default VRF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: vrf
                            
                            	VRF name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.LocatorTable, self).__init__()

                                self.yang_name = "locator-table"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ])
                                self.vrf_name = None
                                self.default = None
                                self.vrf = None
                                self._segment_path = lambda: "locator-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.LocatorTable, ['vrf_name', 'default', 'vrf'], name, value)


                        class MapRequest(Entity):
                            """
                            Configure map\-request handling
                            
                            .. attribute:: itr_rlocs
                            
                            	Configure to use the specified RLOC set as ITR RLOC in map\-request
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr_rlocs', (YLeaf(YType.str, 'itr-rlocs'), ['str'])),
                                ])
                                self.itr_rlocs = None
                                self._segment_path = lambda: "map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.MapRequest, ['itr_rlocs'], name, value)


                        class MapServer(Entity):
                            """
                            Map\-Server commands
                            
                            .. attribute:: rloc
                            
                            	EID instance RLOC membership
                            	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc>`
                            
                            .. attribute:: site_registration
                            
                            	Map\-server site registration options
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.MapServer.SiteRegistration>`
                            
                            .. attribute:: nmr
                            
                            	Map\-server negative map\-reply optio
                            	**type**\:  :py:class:`Nmr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Nmr>`
                            
                            .. attribute:: session
                            
                            	Map\-server session
                            	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Session>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.LispList.Default.EidTable.InstanceList.MapServer.SiteRegistration)), ("nmr", ("nmr", Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Nmr)), ("session", ("session", Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Session))])
                                self._leafs = OrderedDict()

                                self.rloc = Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc()
                                self.rloc.parent = self
                                self._children_name_map["rloc"] = "rloc"

                                self.site_registration = Native.Router.LispList.Default.EidTable.InstanceList.MapServer.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.nmr = Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Nmr()
                                self.nmr.parent = self
                                self._children_name_map["nmr"] = "nmr"

                                self.session = Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Session()
                                self.session.parent = self
                                self._children_name_map["session"] = "session"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.MapServer, [], name, value)


                            class Rloc(Entity):
                                """
                                EID instance RLOC membership
                                
                                .. attribute:: members
                                
                                	EID instance RLOC membership
                                	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc, self).__init__()

                                    self.yang_name = "rloc"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("members", ("members", Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members))])
                                    self._leafs = OrderedDict()

                                    self.members = Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members()
                                    self.members.parent = self
                                    self._children_name_map["members"] = "members"
                                    self._segment_path = lambda: "rloc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc, [], name, value)


                                class Members(Entity):
                                    """
                                    EID instance RLOC membership
                                    
                                    .. attribute:: distribute
                                    
                                    	EID instance RLOC membership distribution
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: modify_discovered
                                    
                                    	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                    	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members, self).__init__()

                                        self.yang_name = "members"
                                        self.yang_parent_name = "rloc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered))])
                                        self._leafs = OrderedDict([
                                            ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                        ])
                                        self.distribute = None

                                        self.modify_discovered = Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered()
                                        self.modify_discovered.parent = self
                                        self._children_name_map["modify_discovered"] = "modify-discovered"
                                        self._segment_path = lambda: "members"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members, ['distribute'], name, value)


                                    class ModifyDiscovered(Entity):
                                        """
                                        Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                        
                                        .. attribute:: operator
                                        
                                        	
                                        	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set from which to get member RLOC addresses
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                            self.yang_name = "modify-discovered"
                                            self.yang_parent_name = "members"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.operator = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "modify-discovered"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                        class Operator(Enum):
                                            """
                                            Operator (Enum Class)

                                            .. data:: add = 0

                                            .. data:: override = 1

                                            """

                                            add = Enum.YLeaf(0, "add")

                                            override = Enum.YLeaf(1, "override")



                            class SiteRegistration(Entity):
                                """
                                Map\-server site registration options
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations as a result of accept\-more\-specifics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class Nmr(Entity):
                                """
                                Map\-server negative map\-reply optio
                                
                                .. attribute:: non_site_ttl
                                
                                	Negative map\-reply TTL for non\-site EID
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Nmr, self).__init__()

                                    self.yang_name = "nmr"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('non_site_ttl', (YLeaf(YType.uint16, 'non-site-ttl'), ['int'])),
                                    ])
                                    self.non_site_ttl = None
                                    self._segment_path = lambda: "nmr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Nmr, ['non_site_ttl'], name, value)


                            class Session(Entity):
                                """
                                Map\-server session
                                
                                .. attribute:: passive_open
                                
                                	Open passive TCP sockets to listen for incoming connections
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Session, self).__init__()

                                    self.yang_name = "session"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('passive_open', (YLeaf(YType.str, 'passive-open'), ['str'])),
                                    ])
                                    self.passive_open = None
                                    self._segment_path = lambda: "session"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.MapServer.Session, ['passive_open'], name, value)


                        class OtherXtrProbe(Entity):
                            """
                            Configure parameters for probing of other xTRs in our site
                            
                            .. attribute:: period
                            
                            	Period between probes in seconds
                            	**type**\: int
                            
                            	**range:** 5..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.OtherXtrProbe, self).__init__()

                                self.yang_name = "other-xtr-probe"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                ])
                                self.period = None
                                self._segment_path = lambda: "other-xtr-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.OtherXtrProbe, ['period'], name, value)


                        class RemoteRlocProbe(Entity):
                            """
                            Configure parameters for probing of remote RLOCs
                            
                            .. attribute:: on_membership_change
                            
                            	Trigger probing upon membership changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: on_route_change
                            
                            	Trigger probing upon routing changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.RemoteRlocProbe, self).__init__()

                                self.yang_name = "remote-rloc-probe"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                    ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                                ])
                                self.on_membership_change = None
                                self.on_route_change = None
                                self._segment_path = lambda: "remote-rloc-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                        class MapCache(Entity):
                            """
                            Configures static EID\-to\-RLOC mappings for an ITR
                            
                            .. attribute:: eid_prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: etr_interface_ip
                            
                            	
                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.EidTable.InstanceList.MapCache.EtrInterfaceIp>`
                            
                            .. attribute:: drop
                            
                            	Drop packets that match this map\-cache entry
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: map_request
                            
                            	Send Map\-Request for LISP destination EID
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: native_forward
                            
                            	Natively forward packets that match this map\-cache entry
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.EidTable.InstanceList.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "instance-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['eid_prefix']
                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.Default.EidTable.InstanceList.MapCache.EtrInterfaceIp))])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                ])
                                self.eid_prefix = None
                                self.drop = None
                                self.map_request = None
                                self.native_forward = None

                                self.etr_interface_ip = Native.Router.LispList.Default.EidTable.InstanceList.MapCache.EtrInterfaceIp()
                                self.etr_interface_ip.parent = self
                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                self._segment_path = lambda: "map-cache" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.MapCache, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                            class EtrInterfaceIp(Entity):
                                """
                                
                                
                                .. attribute:: etr_interface_ip_address
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.EidTable.InstanceList.MapCache.EtrInterfaceIp, self).__init__()

                                    self.yang_name = "etr-interface-ip"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.etr_interface_ip_address = None
                                    self.priority = None
                                    self.weight = None
                                    self._segment_path = lambda: "etr-interface-ip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.EidTable.InstanceList.MapCache.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                class Security(Entity):
                    """
                    Enable default LISP security and authentication in reply is optional
                    
                    .. attribute:: strong
                    
                    	Enable default LISP security and authentication in reply is required
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Security, self).__init__()

                        self.yang_name = "security"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('strong', (YLeaf(YType.empty, 'strong'), ['Empty'])),
                        ])
                        self.strong = None
                        self._segment_path = lambda: "security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Security, ['strong'], name, value)


                class Site(Entity):
                    """
                    Configure a LISP site on a map server (MS)
                    
                    .. attribute:: sname  (key)
                    
                    	The site name
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	
                    	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_>`
                    
                    .. attribute:: authentication_key
                    
                    	Authentication key used by LISP site
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.AuthenticationKey>`
                    
                    .. attribute:: description
                    
                    	Site description
                    	**type**\: str
                    
                    .. attribute:: allowed_locator
                    
                    	Locator from LISP site
                    	**type**\:  :py:class:`AllowedLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.AllowedLocator>`
                    
                    .. attribute:: eid_prefix
                    
                    	Site EID address prefix
                    	**type**\:  :py:class:`EidPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.EidPrefix>`
                    
                    .. attribute:: eid_record
                    
                    	Site EID address prefix
                    	**type**\:  :py:class:`EidRecord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.EidRecord>`
                    
                    .. attribute:: site_id
                    
                    	Configure a site\-id for this site
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Site, self).__init__()

                        self.yang_name = "site"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['sname']
                        self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Default.Site.Default_)), ("authentication-key", ("authentication_key", Native.Router.LispList.Default.Site.AuthenticationKey)), ("allowed-locator", ("allowed_locator", Native.Router.LispList.Default.Site.AllowedLocator)), ("eid-prefix", ("eid_prefix", Native.Router.LispList.Default.Site.EidPrefix)), ("eid-record", ("eid_record", Native.Router.LispList.Default.Site.EidRecord))])
                        self._leafs = OrderedDict([
                            ('sname', (YLeaf(YType.str, 'sname'), ['str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                        ])
                        self.sname = None
                        self.description = None
                        self.site_id = None

                        self.default = Native.Router.LispList.Default.Site.Default_()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.authentication_key = Native.Router.LispList.Default.Site.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.allowed_locator = Native.Router.LispList.Default.Site.AllowedLocator()
                        self.allowed_locator.parent = self
                        self._children_name_map["allowed_locator"] = "allowed-locator"

                        self.eid_prefix = Native.Router.LispList.Default.Site.EidPrefix()
                        self.eid_prefix.parent = self
                        self._children_name_map["eid_prefix"] = "eid-prefix"

                        self.eid_record = Native.Router.LispList.Default.Site.EidRecord()
                        self.eid_record.parent = self
                        self._children_name_map["eid_record"] = "eid-record"
                        self._segment_path = lambda: "site" + "[sname='" + str(self.sname) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Site, ['sname', 'description', 'site_id'], name, value)


                    class Default_(Entity):
                        """
                        
                        
                        .. attribute:: authentication_key
                        
                        	Authentication key used by LISP site
                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_.AuthenticationKey>`
                        
                        .. attribute:: description
                        
                        	Site description
                        	**type**\: str
                        
                        .. attribute:: allowed_locator
                        
                        	Locator from LISP site
                        	**type**\:  :py:class:`AllowedLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_.AllowedLocator>`
                        
                        .. attribute:: eid_prefix
                        
                        	Site EID address prefix
                        	**type**\:  :py:class:`EidPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_.EidPrefix>`
                        
                        .. attribute:: eid_record
                        
                        	Site EID address prefix
                        	**type**\:  :py:class:`EidRecord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_.EidRecord>`
                        
                        .. attribute:: site_id
                        
                        	Configure a site\-id for this site
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Site.Default_, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "site"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.LispList.Default.Site.Default_.AuthenticationKey)), ("allowed-locator", ("allowed_locator", Native.Router.LispList.Default.Site.Default_.AllowedLocator)), ("eid-prefix", ("eid_prefix", Native.Router.LispList.Default.Site.Default_.EidPrefix)), ("eid-record", ("eid_record", Native.Router.LispList.Default.Site.Default_.EidRecord))])
                            self._leafs = OrderedDict([
                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                            ])
                            self.description = None
                            self.site_id = None

                            self.authentication_key = Native.Router.LispList.Default.Site.Default_.AuthenticationKey()
                            self.authentication_key.parent = self
                            self._children_name_map["authentication_key"] = "authentication-key"

                            self.allowed_locator = Native.Router.LispList.Default.Site.Default_.AllowedLocator()
                            self.allowed_locator.parent = self
                            self._children_name_map["allowed_locator"] = "allowed-locator"

                            self.eid_prefix = Native.Router.LispList.Default.Site.Default_.EidPrefix()
                            self.eid_prefix.parent = self
                            self._children_name_map["eid_prefix"] = "eid-prefix"

                            self.eid_record = Native.Router.LispList.Default.Site.Default_.EidRecord()
                            self.eid_record.parent = self
                            self._children_name_map["eid_record"] = "eid-record"
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Site.Default_, ['description', 'site_id'], name, value)


                        class AuthenticationKey(Entity):
                            """
                            Authentication key used by LISP site
                            
                            .. attribute:: unc_pwd
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            .. attribute:: key_0
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            .. attribute:: key_6
                            
                            	The ENCRYPTED password
                            	**type**\: str
                            
                            .. attribute:: key_7
                            
                            	The ENCRYPTED password
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Site.Default_.AuthenticationKey, self).__init__()

                                self.yang_name = "authentication-key"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                    ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                    ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                    ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                ])
                                self.unc_pwd = None
                                self.key_0 = None
                                self.key_6 = None
                                self.key_7 = None
                                self._segment_path = lambda: "authentication-key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Site.Default_.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                        class AllowedLocator(Entity):
                            """
                            Locator from LISP site
                            
                            .. attribute:: ls_ipv4
                            
                            	IPv4 locator allowed in registered locator\-set
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ls_ipv6
                            
                            	IPv6 locator allowed in registered locator\-set
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: list
                            
                            	Prefixes allowed in registerd locator\-set
                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_.AllowedLocator.List>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Site.Default_.AllowedLocator, self).__init__()

                                self.yang_name = "allowed-locator"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Site.Default_.AllowedLocator.List))])
                                self._leafs = OrderedDict([
                                    ('ls_ipv4', (YLeaf(YType.str, 'ls-ipv4'), ['str'])),
                                    ('ls_ipv6', (YLeaf(YType.str, 'ls-ipv6'), ['str'])),
                                ])
                                self.ls_ipv4 = None
                                self.ls_ipv6 = None

                                self.list = Native.Router.LispList.Default.Site.Default_.AllowedLocator.List()
                                self.list.parent = self
                                self._children_name_map["list"] = "list"
                                self._segment_path = lambda: "allowed-locator"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Site.Default_.AllowedLocator, ['ls_ipv4', 'ls_ipv6'], name, value)


                            class List(Entity):
                                """
                                Prefixes allowed in registerd locator\-set
                                
                                .. attribute:: ipv4
                                
                                	IPv4 prefix\-list name
                                	**type**\: str
                                
                                .. attribute:: ipv6
                                
                                	IPv6 prefix\-list name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Site.Default_.AllowedLocator.List, self).__init__()

                                    self.yang_name = "list"
                                    self.yang_parent_name = "allowed-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Site.Default_.AllowedLocator.List, ['ipv4', 'ipv6'], name, value)


                        class EidPrefix(Entity):
                            """
                            Site EID address prefix
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_.EidPrefix.Prefixes>`
                            
                            .. attribute:: instance_id
                            
                            	EID instance\-ID
                            	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_.EidPrefix.InstanceId>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Site.Default_.EidPrefix, self).__init__()

                                self.yang_name = "eid-prefix"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Default.Site.Default_.EidPrefix.Prefixes)), ("instance-id", ("instance_id", Native.Router.LispList.Default.Site.Default_.EidPrefix.InstanceId))])
                                self._leafs = OrderedDict([
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self.instance_id = YList(self)
                                self._segment_path = lambda: "eid-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Site.Default_.EidPrefix, ['any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Site.Default_.EidPrefix.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "eid-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Site.Default_.EidPrefix.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                            class InstanceId(Entity):
                                """
                                EID instance\-ID
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: prefixes
                                
                                	
                                	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_.EidPrefix.InstanceId.Prefixes>`
                                
                                .. attribute:: any_mac
                                
                                	Accept registrations for any L2 EID records
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Site.Default_.EidPrefix.InstanceId, self).__init__()

                                    self.yang_name = "instance-id"
                                    self.yang_parent_name = "eid-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Default.Site.Default_.EidPrefix.InstanceId.Prefixes))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                    ])
                                    self.id = None
                                    self.any_mac = None

                                    self.prefixes = YList(self)
                                    self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Site.Default_.EidPrefix.InstanceId, ['id', 'any_mac'], name, value)


                                class Prefixes(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: accept_more_specifics
                                    
                                    	Accept registrations for more specific EID prefixes
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_tag
                                    
                                    	RIB route tag
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Site.Default_.EidPrefix.InstanceId.Prefixes, self).__init__()

                                        self.yang_name = "prefixes"
                                        self.yang_parent_name = "instance-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                            ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.accept_more_specifics = None
                                        self.route_tag = None
                                        self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Site.Default_.EidPrefix.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                        class EidRecord(Entity):
                            """
                            Site EID address prefix
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_.EidRecord.Prefixes>`
                            
                            .. attribute:: instance_id
                            
                            	EID instance\-ID
                            	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_.EidRecord.InstanceId>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Site.Default_.EidRecord, self).__init__()

                                self.yang_name = "eid-record"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Default.Site.Default_.EidRecord.Prefixes)), ("instance-id", ("instance_id", Native.Router.LispList.Default.Site.Default_.EidRecord.InstanceId))])
                                self._leafs = OrderedDict([
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self.instance_id = YList(self)
                                self._segment_path = lambda: "eid-record"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Site.Default_.EidRecord, ['any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Site.Default_.EidRecord.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "eid-record"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Site.Default_.EidRecord.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                            class InstanceId(Entity):
                                """
                                EID instance\-ID
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: prefixes
                                
                                	
                                	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.Default_.EidRecord.InstanceId.Prefixes>`
                                
                                .. attribute:: any_mac
                                
                                	Accept registrations for any L2 EID records
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Site.Default_.EidRecord.InstanceId, self).__init__()

                                    self.yang_name = "instance-id"
                                    self.yang_parent_name = "eid-record"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Default.Site.Default_.EidRecord.InstanceId.Prefixes))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                    ])
                                    self.id = None
                                    self.any_mac = None

                                    self.prefixes = YList(self)
                                    self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Site.Default_.EidRecord.InstanceId, ['id', 'any_mac'], name, value)


                                class Prefixes(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: accept_more_specifics
                                    
                                    	Accept registrations for more specific EID prefixes
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_tag
                                    
                                    	RIB route tag
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Default.Site.Default_.EidRecord.InstanceId.Prefixes, self).__init__()

                                        self.yang_name = "prefixes"
                                        self.yang_parent_name = "instance-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                            ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.accept_more_specifics = None
                                        self.route_tag = None
                                        self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Default.Site.Default_.EidRecord.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Authentication key used by LISP site
                        
                        .. attribute:: unc_pwd
                        
                        	The UNENCRYPTED (cleartext) password
                        	**type**\: str
                        
                        .. attribute:: key_0
                        
                        	The UNENCRYPTED (cleartext) password
                        	**type**\: str
                        
                        .. attribute:: key_6
                        
                        	The ENCRYPTED password
                        	**type**\: str
                        
                        .. attribute:: key_7
                        
                        	The ENCRYPTED password
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Site.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "site"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                            ])
                            self.unc_pwd = None
                            self.key_0 = None
                            self.key_6 = None
                            self.key_7 = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Site.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                    class AllowedLocator(Entity):
                        """
                        Locator from LISP site
                        
                        .. attribute:: ls_ipv4
                        
                        	IPv4 locator allowed in registered locator\-set
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ls_ipv6
                        
                        	IPv6 locator allowed in registered locator\-set
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: list
                        
                        	Prefixes allowed in registerd locator\-set
                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.AllowedLocator.List>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Site.AllowedLocator, self).__init__()

                            self.yang_name = "allowed-locator"
                            self.yang_parent_name = "site"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Default.Site.AllowedLocator.List))])
                            self._leafs = OrderedDict([
                                ('ls_ipv4', (YLeaf(YType.str, 'ls-ipv4'), ['str'])),
                                ('ls_ipv6', (YLeaf(YType.str, 'ls-ipv6'), ['str'])),
                            ])
                            self.ls_ipv4 = None
                            self.ls_ipv6 = None

                            self.list = Native.Router.LispList.Default.Site.AllowedLocator.List()
                            self.list.parent = self
                            self._children_name_map["list"] = "list"
                            self._segment_path = lambda: "allowed-locator"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Site.AllowedLocator, ['ls_ipv4', 'ls_ipv6'], name, value)


                        class List(Entity):
                            """
                            Prefixes allowed in registerd locator\-set
                            
                            .. attribute:: ipv4
                            
                            	IPv4 prefix\-list name
                            	**type**\: str
                            
                            .. attribute:: ipv6
                            
                            	IPv6 prefix\-list name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Site.AllowedLocator.List, self).__init__()

                                self.yang_name = "list"
                                self.yang_parent_name = "allowed-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "list"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Site.AllowedLocator.List, ['ipv4', 'ipv6'], name, value)


                    class EidPrefix(Entity):
                        """
                        Site EID address prefix
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.EidPrefix.Prefixes>`
                        
                        .. attribute:: instance_id
                        
                        	EID instance\-ID
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.EidPrefix.InstanceId>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Site.EidPrefix, self).__init__()

                            self.yang_name = "eid-prefix"
                            self.yang_parent_name = "site"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Default.Site.EidPrefix.Prefixes)), ("instance-id", ("instance_id", Native.Router.LispList.Default.Site.EidPrefix.InstanceId))])
                            self._leafs = OrderedDict([
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self.instance_id = YList(self)
                            self._segment_path = lambda: "eid-prefix"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Site.EidPrefix, ['any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Site.EidPrefix.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "eid-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Site.EidPrefix.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                        class InstanceId(Entity):
                            """
                            EID instance\-ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.EidPrefix.InstanceId.Prefixes>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Site.EidPrefix.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "eid-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Default.Site.EidPrefix.InstanceId.Prefixes))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.id = None
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Site.EidPrefix.InstanceId, ['id', 'any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Site.EidPrefix.InstanceId.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "instance-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Site.EidPrefix.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                    class EidRecord(Entity):
                        """
                        Site EID address prefix
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.EidRecord.Prefixes>`
                        
                        .. attribute:: instance_id
                        
                        	EID instance\-ID
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.EidRecord.InstanceId>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Site.EidRecord, self).__init__()

                            self.yang_name = "eid-record"
                            self.yang_parent_name = "site"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Default.Site.EidRecord.Prefixes)), ("instance-id", ("instance_id", Native.Router.LispList.Default.Site.EidRecord.InstanceId))])
                            self._leafs = OrderedDict([
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self.instance_id = YList(self)
                            self._segment_path = lambda: "eid-record"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Site.EidRecord, ['any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Site.EidRecord.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "eid-record"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Site.EidRecord.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                        class InstanceId(Entity):
                            """
                            EID instance\-ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Site.EidRecord.InstanceId.Prefixes>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Default.Site.EidRecord.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "eid-record"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Default.Site.EidRecord.InstanceId.Prefixes))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.id = None
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Default.Site.EidRecord.InstanceId, ['id', 'any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Default.Site.EidRecord.InstanceId.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "instance-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Default.Site.EidRecord.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                class Syslog(Entity):
                    """
                    Configure syslog option
                    
                    .. attribute:: session
                    
                    	Enable session syslog
                    	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Default.Syslog.Session>`
                    
                    .. attribute:: verbose
                    
                    	Enable verbose syslog
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Default.Syslog, self).__init__()

                        self.yang_name = "syslog"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("session", ("session", Native.Router.LispList.Default.Syslog.Session))])
                        self._leafs = OrderedDict([
                            ('verbose', (YLeaf(YType.empty, 'verbose'), ['Empty'])),
                        ])
                        self.verbose = None

                        self.session = Native.Router.LispList.Default.Syslog.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                        self._segment_path = lambda: "syslog"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Default.Syslog, ['verbose'], name, value)


                    class Session(Entity):
                        """
                        Enable session syslog
                        
                        .. attribute:: changes
                        
                        	Enable session change syslog
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Default.Syslog.Session, self).__init__()

                            self.yang_name = "session"
                            self.yang_parent_name = "syslog"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('changes', (YLeaf(YType.empty, 'changes'), ['Empty'])),
                            ])
                            self.changes = None
                            self._segment_path = lambda: "session"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Default.Syslog.Session, ['changes'], name, value)


            class Service(Entity):
                """
                Configure lisp service type
                
                .. attribute:: ipv4
                
                	
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4>`
                
                	**presence node**\: True
                
                .. attribute:: ipv6
                
                	
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6>`
                
                	**presence node**\: True
                
                .. attribute:: ethernet
                
                	
                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Service, self).__init__()

                    self.yang_name = "service"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.LispList.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.LispList.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.LispList.Service.Ethernet))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.ipv4 = None
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = None
                    self._children_name_map["ipv6"] = "ipv6"

                    self.ethernet = None
                    self._children_name_map["ethernet"] = "ethernet"
                    self._segment_path = lambda: "service"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Service, [], name, value)


                class Ipv4(Entity):
                    """
                    
                    
                    .. attribute:: default
                    
                    	
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default>`
                    
                    .. attribute:: database_mapping
                    
                    	Address family specific local EID prefixes database configuration
                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.DatabaseMapping>`
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Itr>`
                    
                    .. attribute:: itr_enable
                    
                    	
                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.ItrEnable>`
                    
                    .. attribute:: etr_enable
                    
                    	
                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.EtrEnable>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr>`
                    
                    .. attribute:: map_cache_limit
                    
                    	Configures maximum size of map\-cache
                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapCacheLimit>`
                    
                    .. attribute:: map_resolver
                    
                    	Configures a LISP Map Resolver (MR)
                    	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapResolver>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: map_server
                    
                    	Configures a LISP Map Server (MS)
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapServer>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: site_registration
                    
                    	Site registrations configuration for a given instance\-id
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.SiteRegistration>`
                    
                    .. attribute:: solicit_map_request
                    
                    	Configure Solicit\-Map\-Request handling
                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.SolicitMapRequest>`
                    
                    .. attribute:: distance
                    
                    	Administrative distance for RIB route installation
                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Distance>`
                    
                    .. attribute:: encapsulation
                    
                    	Select encapsulation type for data packets
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Encapsulation>`
                    
                    .. attribute:: map_cache
                    
                    	Address family specific map cache configuration
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapCache>`
                    
                    .. attribute:: map_cache_persistent
                    
                    	Dump map\-cache onto flash, making it persistent across reboots
                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapCachePersistent>`
                    
                    .. attribute:: proxy_etr
                    
                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: proxy_itr
                    
                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.ProxyItr>`
                    
                    .. attribute:: route_export
                    
                    	Export routes into RIB from LISP
                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.RouteExport>`
                    
                    .. attribute:: sgt
                    
                    	Enable security group tag propagation in LISP encapsulated traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: use_petr
                    
                    	Encapsulate to Proxy ETR when matching forward\-native entry
                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.UsePetr>`
                    
                    .. attribute:: import_
                    
                    	Redistribute LISP states internally
                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Import>`
                    
                    .. attribute:: map_request_source
                    
                    	Configures inner header source address in Map\-Request message
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Service.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Service.Ipv4.Default)), ("database-mapping", ("database_mapping", Native.Router.LispList.Service.Ipv4.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Service.Ipv4.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Service.Ipv4.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Service.Ipv4.SolicitMapRequest)), ("distance", ("distance", Native.Router.LispList.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.LispList.Service.Ipv4.Import))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv4.Encapsulation')])),
                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                        ])
                        self.encapsulation = None
                        self.proxy_etr = None
                        self.sgt = None
                        self.map_request_source = None

                        self.default = Native.Router.LispList.Service.Ipv4.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.database_mapping = Native.Router.LispList.Service.Ipv4.DatabaseMapping()
                        self.database_mapping.parent = self
                        self._children_name_map["database_mapping"] = "database-mapping"

                        self.itr = Native.Router.LispList.Service.Ipv4.Itr()
                        self.itr.parent = self
                        self._children_name_map["itr"] = "itr"

                        self.itr_enable = Native.Router.LispList.Service.Ipv4.ItrEnable()
                        self.itr_enable.parent = self
                        self._children_name_map["itr_enable"] = "itr-enable"

                        self.etr_enable = Native.Router.LispList.Service.Ipv4.EtrEnable()
                        self.etr_enable.parent = self
                        self._children_name_map["etr_enable"] = "etr-enable"

                        self.etr = Native.Router.LispList.Service.Ipv4.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.map_cache_limit = Native.Router.LispList.Service.Ipv4.MapCacheLimit()
                        self.map_cache_limit.parent = self
                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                        self.map_resolver = None
                        self._children_name_map["map_resolver"] = "map-resolver"

                        self.map_server = None
                        self._children_name_map["map_server"] = "map-server"

                        self.site_registration = Native.Router.LispList.Service.Ipv4.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.solicit_map_request = Native.Router.LispList.Service.Ipv4.SolicitMapRequest()
                        self.solicit_map_request.parent = self
                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                        self.distance = Native.Router.LispList.Service.Ipv4.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"

                        self.map_cache = Native.Router.LispList.Service.Ipv4.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"

                        self.map_cache_persistent = Native.Router.LispList.Service.Ipv4.MapCachePersistent()
                        self.map_cache_persistent.parent = self
                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                        self.proxy_itr = Native.Router.LispList.Service.Ipv4.ProxyItr()
                        self.proxy_itr.parent = self
                        self._children_name_map["proxy_itr"] = "proxy-itr"

                        self.route_export = Native.Router.LispList.Service.Ipv4.RouteExport()
                        self.route_export.parent = self
                        self._children_name_map["route_export"] = "route-export"

                        self.import_ = Native.Router.LispList.Service.Ipv4.Import()
                        self.import_.parent = self
                        self._children_name_map["import_"] = "import"

                        self.use_petr = YList(self)
                        self._segment_path = lambda: "ipv4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Service.Ipv4, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Select encapsulation type for data packets

                        .. data:: lisp = 0

                        .. data:: vxlan = 1

                        """

                        lisp = Enum.YLeaf(0, "lisp")

                        vxlan = Enum.YLeaf(1, "vxlan")



                    class Default(Entity):
                        """
                        
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.SolicitMapRequest>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Distance>`
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Encapsulation>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapCache>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapCachePersistent>`
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.ProxyItr>`
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.RouteExport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.UsePetr>`
                        
                        .. attribute:: import_
                        
                        	Redistribute LISP states internally
                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Import>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Service.Ipv4.Default.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Service.Ipv4.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Service.Ipv4.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Service.Ipv4.Default.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Service.Ipv4.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Service.Ipv4.Default.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ipv4.Default.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Service.Ipv4.Default.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Service.Ipv4.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Service.Ipv4.Default.SolicitMapRequest)), ("distance", ("distance", Native.Router.LispList.Service.Ipv4.Default.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Service.Ipv4.Default.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Service.Ipv4.Default.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Service.Ipv4.Default.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Service.Ipv4.Default.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Service.Ipv4.Default.UsePetr)), ("import", ("import_", Native.Router.LispList.Service.Ipv4.Default.Import))])
                            self._leafs = OrderedDict([
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv4.Default.Encapsulation')])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ])
                            self.encapsulation = None
                            self.proxy_etr = None
                            self.sgt = None
                            self.map_request_source = None

                            self.database_mapping = Native.Router.LispList.Service.Ipv4.Default.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.LispList.Service.Ipv4.Default.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.LispList.Service.Ipv4.Default.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.LispList.Service.Ipv4.Default.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.LispList.Service.Ipv4.Default.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.LispList.Service.Ipv4.Default.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.LispList.Service.Ipv4.Default.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.LispList.Service.Ipv4.Default.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.distance = Native.Router.LispList.Service.Ipv4.Default.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.map_cache = Native.Router.LispList.Service.Ipv4.Default.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_persistent = Native.Router.LispList.Service.Ipv4.Default.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.proxy_itr = Native.Router.LispList.Service.Ipv4.Default.ProxyItr()
                            self.proxy_itr.parent = self
                            self._children_name_map["proxy_itr"] = "proxy-itr"

                            self.route_export = Native.Router.LispList.Service.Ipv4.Default.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.import_ = Native.Router.LispList.Service.Ipv4.Default.Import()
                            self.import_.parent = self
                            self._children_name_map["import_"] = "import"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Select encapsulation type for data packets

                            .. data:: lisp = 0

                            .. data:: vxlan = 1

                            """

                            lisp = Enum.YLeaf(0, "lisp")

                            vxlan = Enum.YLeaf(1, "vxlan")



                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Service.Ipv4.Default.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.LispList.Service.Ipv4.Default.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.Default.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ipv4.Default.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.Default.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.LispList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: away
                            
                            	Administrative distance for RIB route installation
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.away = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: away_eids
                            
                            	Map cache configuration for the away table
                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.MapCache.AwayEids>`
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.LispList.Service.Ipv4.Default.MapCache.AwayEids))])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None

                                self.away_eids = Native.Router.LispList.Service.Ipv4.Default.MapCache.AwayEids()
                                self.away_eids.parent = self
                                self._children_name_map["away_eids"] = "away-eids"
                                self._segment_path = lambda: "map-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapCache, ['site_registration'], name, value)


                            class AwayEids(Entity):
                                """
                                Map cache configuration for the away table
                                
                                .. attribute:: send_map_request
                                
                                	Export away table entries into the map cache with action set to send\-map\-request
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.Default.MapCache.AwayEids, self).__init__()

                                    self.yang_name = "away-eids"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                    ])
                                    self.send_map_request = None
                                    self._segment_path = lambda: "away-eids"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapCache.AwayEids, ['send_map_request'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.MapCachePersistent, ['interval'], name, value)


                        class ProxyItr(Entity):
                            """
                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            
                            .. attribute:: ipv4_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.ProxyItr, self).__init__()

                                self.yang_name = "proxy-itr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                ])
                                self.ipv4_addr = None
                                self.ipv6_addr = None
                                self._segment_path = lambda: "proxy-itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	
                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.UsePetr.Priority>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Service.Ipv4.Default.UsePetr.Priority))])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ])
                                self.locator_address = None

                                self.priority = Native.Router.LispList.Service.Ipv4.Default.UsePetr.Priority()
                                self.priority.parent = self
                                self._children_name_map["priority"] = "priority"
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.UsePetr, ['locator_address'], name, value)


                            class Priority(Entity):
                                """
                                
                                
                                .. attribute:: priority_value
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.Default.UsePetr.Priority, self).__init__()

                                    self.yang_name = "priority"
                                    self.yang_parent_name = "use-petr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.priority_value = None
                                    self.weight = None
                                    self._segment_path = lambda: "priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                        class Import(Entity):
                            """
                            Redistribute LISP states internally
                            
                            .. attribute:: database
                            
                            	Redistribute LISP internal states as database mapping
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Default.Import.Database>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Default.Import, self).__init__()

                                self.yang_name = "import"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Service.Ipv4.Default.Import.Database))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.LispList.Service.Ipv4.Default.Import.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"
                                self._segment_path = lambda: "import"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Import, [], name, value)


                            class Database(Entity):
                                """
                                Redistribute LISP internal states as database mapping
                                
                                .. attribute:: site_registration
                                
                                	Import states from site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.Default.Import.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.site_registration = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "database"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.Default.Import.Database, ['site_registration', 'locator_set'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Address family specific local EID prefixes database configuration
                        
                        .. attribute:: limit
                        
                        	Configures the maximum size of local EID prefixes database
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.DatabaseMapping.Limit>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Service.Ipv4.DatabaseMapping.Limit))])
                            self._leafs = OrderedDict()

                            self.limit = Native.Router.LispList.Service.Ipv4.DatabaseMapping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "database-mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.DatabaseMapping, [], name, value)


                        class Limit(Entity):
                            """
                            Configures the maximum size of local EID prefixes database
                            
                            .. attribute:: dynamic
                            
                            	Configures the maximum size of dynamic local EID prefixes database
                            	**type**\: int
                            
                            	**range:** 1..5000
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "database-mapping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.dynamic = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                    class Itr(Entity):
                        """
                        Configures a LISP Ingress Tunnel Router (ITR)
                        
                        .. attribute:: map_resolver
                        
                        	Configures map\-resolver address for sending Map\-Requests
                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Itr.MapResolver>`
                        
                        .. attribute:: nmr_ttl
                        
                        	verride negative map\-reply TTL for site EID
                        	**type**\: int
                        
                        	**range:** 1..900
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.Itr, self).__init__()

                            self.yang_name = "itr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ipv4.Itr.MapResolver))])
                            self._leafs = OrderedDict([
                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                            ])
                            self.nmr_ttl = None

                            self.map_resolver = YList(self)
                            self._segment_path = lambda: "itr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures map\-resolver address for sending Map\-Requests
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_list
                            
                            	Associates ITR/ETR with prefix list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Itr.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "itr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.ip_addr = None
                                self.prefix_list = None
                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                    class ItrEnable(Entity):
                        """
                        
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.ItrEnable, self).__init__()

                            self.yang_name = "itr-enable"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                            ])
                            self.itr = None
                            self._segment_path = lambda: "itr-enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.ItrEnable, ['itr'], name, value)


                    class EtrEnable(Entity):
                        """
                        
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.EtrEnable, self).__init__()

                            self.yang_name = "etr-enable"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                            ])
                            self.etr = None
                            self._segment_path = lambda: "etr-enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.EtrEnable, ['etr'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr.MapServer>`
                        
                        .. attribute:: map_cache_ttl
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..10080
                        
                        .. attribute:: accept_map_request_mapping
                        
                        	
                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                            self._leafs = OrderedDict([
                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                            ])
                            self.map_cache_ttl = None

                            self.accept_map_request_mapping = Native.Router.LispList.Service.Ipv4.Etr.AcceptMapRequestMapping()
                            self.accept_map_request_mapping.parent = self
                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                            self.map_server = YList(self)
                            self._segment_path = lambda: "etr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_pwd
                                
                                	
                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                
                                .. attribute:: key_0
                                
                                	
                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                
                                .. attribute:: key_6
                                
                                	
                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                
                                .. attribute:: key_7
                                
                                	
                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                    self._leafs = OrderedDict()

                                    self.key_pwd = Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                    self.key_pwd.parent = self
                                    self._children_name_map["key_pwd"] = "key-pwd"

                                    self.key_0 = Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key0()
                                    self.key_0.parent = self
                                    self._children_name_map["key_0"] = "key-0"

                                    self.key_6 = Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key6()
                                    self.key_6.parent = self
                                    self._children_name_map["key_6"] = "key-6"

                                    self.key_7 = Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key7()
                                    self.key_7.parent = self
                                    self._children_name_map["key_7"] = "key-7"
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                class KeyPwd(Entity):
                                    """
                                    
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                        self.yang_name = "key-pwd"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-pwd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key0(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                        self.yang_name = "key-0"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_0 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-0"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                        self.yang_name = "key-6"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_6 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key7(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                        self.yang_name = "key-7"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_7 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-7"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                        class AcceptMapRequestMapping(Entity):
                            """
                            
                            
                            .. attribute:: accept_mappping
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: verify
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                self.yang_name = "accept-map-request-mapping"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                ])
                                self.accept_mappping = None
                                self.verify = None
                                self._segment_path = lambda: "accept-map-request-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                    class MapCacheLimit(Entity):
                        """
                        Configures maximum size of map\-cache
                        
                        .. attribute:: max_map_cache_entries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..100000
                        
                        .. attribute:: reserve_list
                        
                        	EID\-prefixes guaranteed to be stored in map\-cache
                        	**type**\: str
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.MapCacheLimit, self).__init__()

                            self.yang_name = "map-cache-limit"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.max_map_cache_entries = None
                            self.reserve_list = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "map-cache-limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                    class MapResolver(Entity):
                        """
                        Configures a LISP Map Resolver (MR)
                        
                        .. attribute:: map_request
                        
                        	Map\-Request processing options
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_request = Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"
                            self._segment_path = lambda: "map-resolver"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapResolver, [], name, value)


                        class MapRequest(Entity):
                            """
                            Map\-Request processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "map-resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	Influence which source RLOCs map requests are accepted from
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    Influence which source RLOCs map requests are accepted from
                                    
                                    .. attribute:: list
                                    
                                    	Define allowed prefixes using an ip[v6] prefix list
                                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List>`
                                    
                                    .. attribute:: registered
                                    
                                    	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                    	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered))])
                                        self._leafs = OrderedDict()

                                        self.list = Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List()
                                        self.list.parent = self
                                        self._children_name_map["list"] = "list"

                                        self.registered = Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered()
                                        self.registered.parent = self
                                        self._children_name_map["registered"] = "registered"
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source, [], name, value)


                                    class List(Entity):
                                        """
                                        Define allowed prefixes using an ip[v6] prefix list
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 prefixes
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 prefixes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                            self.yang_name = "list"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "list"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                    class Registered(Entity):
                                        """
                                        ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                            self.yang_name = "registered"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"
                                            self._segment_path = lambda: "registered"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "registered"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                    class MapServer(Entity):
                        """
                        Configures a LISP Map Server (MS)
                        
                        .. attribute:: map_register
                        
                        	Map\-Register processing options
                        	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapServer.MapRegister>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Service.Ipv4.MapServer.MapRegister))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_register = Native.Router.LispList.Service.Ipv4.MapServer.MapRegister()
                            self.map_register.parent = self
                            self._children_name_map["map_register"] = "map-register"
                            self._segment_path = lambda: "map-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapServer, [], name, value)


                        class MapRegister(Entity):
                            """
                            Map\-Register processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapServer.MapRegister.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.MapServer.MapRegister, self).__init__()

                                self.yang_name = "map-register"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ipv4.MapServer.MapRegister.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.LispList.Service.Ipv4.MapServer.MapRegister.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-register"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapServer.MapRegister, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	RLOC Source IP address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapServer.MapRegister.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-register"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ipv4.MapServer.MapRegister.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.Service.Ipv4.MapServer.MapRegister.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    RLOC Source IP address
                                    
                                    .. attribute:: allowed_locator
                                    
                                    	Against sites' allowed\-locators policy
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                        ])
                                        self.allowed_locator = None
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                    class SiteRegistration(Entity):
                        """
                        Site registrations configuration for a given instance\-id
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class SolicitMapRequest(Entity):
                        """
                        Configure Solicit\-Map\-Request handling
                        
                        .. attribute:: ignore
                        
                        	Ignore SMR bit in incoming Map\-Requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_per_entry
                        
                        	Maximum number of SMRs for addresses under a map\-cache entry
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: suppression_time
                        
                        	How long to suppress repeated SMRs for the same address
                        	**type**\: int
                        
                        	**range:** 1..600
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.SolicitMapRequest, self).__init__()

                            self.yang_name = "solicit-map-request"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                            ])
                            self.ignore = None
                            self.max_per_entry = None
                            self.suppression_time = None
                            self._segment_path = lambda: "solicit-map-request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                    class Distance(Entity):
                        """
                        Administrative distance for RIB route installation
                        
                        .. attribute:: alt
                        
                        	LISP routes installed in the ALT table
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: away
                        
                        	Administrative distance for RIB route installation
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: dyn_eid
                        
                        	LISP installed routes of type dynamic\-EID
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: site_registrations
                        
                        	LISP installed routes of type site\-registrations
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                            ])
                            self.alt = None
                            self.away = None
                            self.dyn_eid = None
                            self.site_registrations = None
                            self._segment_path = lambda: "distance"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                    class MapCache(Entity):
                        """
                        Address family specific map cache configuration
                        
                        .. attribute:: away_eids
                        
                        	Map cache configuration for the away table
                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.MapCache.AwayEids>`
                        
                        .. attribute:: site_registration
                        
                        	Install map cache to map request for site registrations
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.LispList.Service.Ipv4.MapCache.AwayEids))])
                            self._leafs = OrderedDict([
                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                            ])
                            self.site_registration = None

                            self.away_eids = Native.Router.LispList.Service.Ipv4.MapCache.AwayEids()
                            self.away_eids.parent = self
                            self._children_name_map["away_eids"] = "away-eids"
                            self._segment_path = lambda: "map-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapCache, ['site_registration'], name, value)


                        class AwayEids(Entity):
                            """
                            Map cache configuration for the away table
                            
                            .. attribute:: send_map_request
                            
                            	Export away table entries into the map cache with action set to send\-map\-request
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                self.yang_name = "away-eids"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                ])
                                self.send_map_request = None
                                self._segment_path = lambda: "away-eids"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                    class MapCachePersistent(Entity):
                        """
                        Dump map\-cache onto flash, making it persistent across reboots
                        
                        .. attribute:: interval
                        
                        	Interval in minutes of how often the map\-cache is saved
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.MapCachePersistent, self).__init__()

                            self.yang_name = "map-cache-persistent"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "map-cache-persistent"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                    class ProxyItr(Entity):
                        """
                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        
                        .. attribute:: ipv4_addr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_addr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.ProxyItr, self).__init__()

                            self.yang_name = "proxy-itr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                            ])
                            self.ipv4_addr = None
                            self.ipv6_addr = None
                            self._segment_path = lambda: "proxy-itr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                    class RouteExport(Entity):
                        """
                        Export routes into RIB from LISP
                        
                        .. attribute:: site_registrations
                        
                        	Export LISP site registrations to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: away_eids
                        
                        	Export LISP away EIDs to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.RouteExport, self).__init__()

                            self.yang_name = "route-export"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                            ])
                            self.site_registrations = None
                            self.away_eids = None
                            self._segment_path = lambda: "route-export"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                    class UsePetr(Entity):
                        """
                        Encapsulate to Proxy ETR when matching forward\-native entry
                        
                        .. attribute:: locator_address  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.UsePetr.Priority>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.UsePetr, self).__init__()

                            self.yang_name = "use-petr"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['locator_address']
                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Service.Ipv4.UsePetr.Priority))])
                            self._leafs = OrderedDict([
                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                            ])
                            self.locator_address = None

                            self.priority = Native.Router.LispList.Service.Ipv4.UsePetr.Priority()
                            self.priority.parent = self
                            self._children_name_map["priority"] = "priority"
                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                        class Priority(Entity):
                            """
                            
                            
                            .. attribute:: priority_value
                            
                            	Configures which Locators from a set are preferred
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: weight
                            
                            	Traffic load\-spreading among Locators
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.UsePetr.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "use-petr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                ])
                                self.priority_value = None
                                self.weight = None
                                self._segment_path = lambda: "priority"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                    class Import(Entity):
                        """
                        Redistribute LISP states internally
                        
                        .. attribute:: database
                        
                        	Redistribute LISP internal states as database mapping
                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv4.Import.Database>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv4.Import, self).__init__()

                            self.yang_name = "import"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Service.Ipv4.Import.Database))])
                            self._leafs = OrderedDict()

                            self.database = Native.Router.LispList.Service.Ipv4.Import.Database()
                            self.database.parent = self
                            self._children_name_map["database"] = "database"
                            self._segment_path = lambda: "import"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv4.Import, [], name, value)


                        class Database(Entity):
                            """
                            Redistribute LISP internal states as database mapping
                            
                            .. attribute:: site_registration
                            
                            	Import states from site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: locator_set
                            
                            	Locator set to use with created database mapping entries
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv4.Import.Database, self).__init__()

                                self.yang_name = "database"
                                self.yang_parent_name = "import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                ])
                                self.site_registration = None
                                self.locator_set = None
                                self._segment_path = lambda: "database"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                class Ipv6(Entity):
                    """
                    
                    
                    .. attribute:: default
                    
                    	
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default>`
                    
                    .. attribute:: database_mapping
                    
                    	Address family specific local EID prefixes database configuration
                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.DatabaseMapping>`
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Itr>`
                    
                    .. attribute:: itr_enable
                    
                    	
                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.ItrEnable>`
                    
                    .. attribute:: etr_enable
                    
                    	
                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.EtrEnable>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr>`
                    
                    .. attribute:: map_cache_limit
                    
                    	Configures maximum size of map\-cache
                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapCacheLimit>`
                    
                    .. attribute:: map_resolver
                    
                    	Configures a LISP Map Resolver (MR)
                    	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapResolver>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: map_server
                    
                    	Configures a LISP Map Server (MS)
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapServer>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: site_registration
                    
                    	Site registrations configuration for a given instance\-id
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.SiteRegistration>`
                    
                    .. attribute:: solicit_map_request
                    
                    	Configure Solicit\-Map\-Request handling
                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.SolicitMapRequest>`
                    
                    .. attribute:: distance
                    
                    	Administrative distance for RIB route installation
                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Distance>`
                    
                    .. attribute:: encapsulation
                    
                    	Select encapsulation type for data packets
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Encapsulation>`
                    
                    .. attribute:: map_cache
                    
                    	Address family specific map cache configuration
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapCache>`
                    
                    .. attribute:: map_cache_persistent
                    
                    	Dump map\-cache onto flash, making it persistent across reboots
                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapCachePersistent>`
                    
                    .. attribute:: proxy_etr
                    
                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: proxy_itr
                    
                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.ProxyItr>`
                    
                    .. attribute:: route_export
                    
                    	Export routes into RIB from LISP
                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.RouteExport>`
                    
                    .. attribute:: sgt
                    
                    	Enable security group tag propagation in LISP encapsulated traffic
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: use_petr
                    
                    	Encapsulate to Proxy ETR when matching forward\-native entry
                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.UsePetr>`
                    
                    .. attribute:: import_
                    
                    	Redistribute LISP states internally
                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Import>`
                    
                    .. attribute:: map_request_source
                    
                    	Configures inner header source address in Map\-Request message
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Service.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Service.Ipv6.Default)), ("database-mapping", ("database_mapping", Native.Router.LispList.Service.Ipv6.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Service.Ipv6.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Service.Ipv6.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Service.Ipv6.SolicitMapRequest)), ("distance", ("distance", Native.Router.LispList.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.LispList.Service.Ipv6.Import))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv6.Encapsulation')])),
                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                        ])
                        self.encapsulation = None
                        self.proxy_etr = None
                        self.sgt = None
                        self.map_request_source = None

                        self.default = Native.Router.LispList.Service.Ipv6.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.database_mapping = Native.Router.LispList.Service.Ipv6.DatabaseMapping()
                        self.database_mapping.parent = self
                        self._children_name_map["database_mapping"] = "database-mapping"

                        self.itr = Native.Router.LispList.Service.Ipv6.Itr()
                        self.itr.parent = self
                        self._children_name_map["itr"] = "itr"

                        self.itr_enable = Native.Router.LispList.Service.Ipv6.ItrEnable()
                        self.itr_enable.parent = self
                        self._children_name_map["itr_enable"] = "itr-enable"

                        self.etr_enable = Native.Router.LispList.Service.Ipv6.EtrEnable()
                        self.etr_enable.parent = self
                        self._children_name_map["etr_enable"] = "etr-enable"

                        self.etr = Native.Router.LispList.Service.Ipv6.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.map_cache_limit = Native.Router.LispList.Service.Ipv6.MapCacheLimit()
                        self.map_cache_limit.parent = self
                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                        self.map_resolver = None
                        self._children_name_map["map_resolver"] = "map-resolver"

                        self.map_server = None
                        self._children_name_map["map_server"] = "map-server"

                        self.site_registration = Native.Router.LispList.Service.Ipv6.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.solicit_map_request = Native.Router.LispList.Service.Ipv6.SolicitMapRequest()
                        self.solicit_map_request.parent = self
                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                        self.distance = Native.Router.LispList.Service.Ipv6.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"

                        self.map_cache = Native.Router.LispList.Service.Ipv6.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"

                        self.map_cache_persistent = Native.Router.LispList.Service.Ipv6.MapCachePersistent()
                        self.map_cache_persistent.parent = self
                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                        self.proxy_itr = Native.Router.LispList.Service.Ipv6.ProxyItr()
                        self.proxy_itr.parent = self
                        self._children_name_map["proxy_itr"] = "proxy-itr"

                        self.route_export = Native.Router.LispList.Service.Ipv6.RouteExport()
                        self.route_export.parent = self
                        self._children_name_map["route_export"] = "route-export"

                        self.import_ = Native.Router.LispList.Service.Ipv6.Import()
                        self.import_.parent = self
                        self._children_name_map["import_"] = "import"

                        self.use_petr = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Service.Ipv6, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                    class Encapsulation(Enum):
                        """
                        Encapsulation (Enum Class)

                        Select encapsulation type for data packets

                        .. data:: lisp = 0

                        .. data:: vxlan = 1

                        """

                        lisp = Enum.YLeaf(0, "lisp")

                        vxlan = Enum.YLeaf(1, "vxlan")



                    class Default(Entity):
                        """
                        
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.SolicitMapRequest>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Distance>`
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Encapsulation>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapCache>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapCachePersistent>`
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.ProxyItr>`
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.RouteExport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.UsePetr>`
                        
                        .. attribute:: import_
                        
                        	Redistribute LISP states internally
                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Import>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Service.Ipv6.Default.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Service.Ipv6.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Service.Ipv6.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Service.Ipv6.Default.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Service.Ipv6.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Service.Ipv6.Default.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ipv6.Default.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Service.Ipv6.Default.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Service.Ipv6.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Service.Ipv6.Default.SolicitMapRequest)), ("distance", ("distance", Native.Router.LispList.Service.Ipv6.Default.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.Service.Ipv6.Default.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Service.Ipv6.Default.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.Service.Ipv6.Default.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.Service.Ipv6.Default.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.Service.Ipv6.Default.UsePetr)), ("import", ("import_", Native.Router.LispList.Service.Ipv6.Default.Import))])
                            self._leafs = OrderedDict([
                                ('encapsulation', (YLeaf(YType.enumeration, 'encapsulation'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv6.Default.Encapsulation')])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                            ])
                            self.encapsulation = None
                            self.proxy_etr = None
                            self.sgt = None
                            self.map_request_source = None

                            self.database_mapping = Native.Router.LispList.Service.Ipv6.Default.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.LispList.Service.Ipv6.Default.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.LispList.Service.Ipv6.Default.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.LispList.Service.Ipv6.Default.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.LispList.Service.Ipv6.Default.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.LispList.Service.Ipv6.Default.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.LispList.Service.Ipv6.Default.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.LispList.Service.Ipv6.Default.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.distance = Native.Router.LispList.Service.Ipv6.Default.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.map_cache = Native.Router.LispList.Service.Ipv6.Default.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_persistent = Native.Router.LispList.Service.Ipv6.Default.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.proxy_itr = Native.Router.LispList.Service.Ipv6.Default.ProxyItr()
                            self.proxy_itr.parent = self
                            self._children_name_map["proxy_itr"] = "proxy-itr"

                            self.route_export = Native.Router.LispList.Service.Ipv6.Default.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.import_ = Native.Router.LispList.Service.Ipv6.Default.Import()
                            self.import_.parent = self
                            self._children_name_map["import_"] = "import"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default, ['encapsulation', 'proxy_etr', 'sgt', 'map_request_source'], name, value)

                        class Encapsulation(Enum):
                            """
                            Encapsulation (Enum Class)

                            Select encapsulation type for data packets

                            .. data:: lisp = 0

                            .. data:: vxlan = 1

                            """

                            lisp = Enum.YLeaf(0, "lisp")

                            vxlan = Enum.YLeaf(1, "vxlan")



                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Service.Ipv6.Default.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.LispList.Service.Ipv6.Default.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.Default.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ipv6.Default.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.Default.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.LispList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: away
                            
                            	Administrative distance for RIB route installation
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.away = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: away_eids
                            
                            	Map cache configuration for the away table
                            	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.MapCache.AwayEids>`
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.LispList.Service.Ipv6.Default.MapCache.AwayEids))])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None

                                self.away_eids = Native.Router.LispList.Service.Ipv6.Default.MapCache.AwayEids()
                                self.away_eids.parent = self
                                self._children_name_map["away_eids"] = "away-eids"
                                self._segment_path = lambda: "map-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapCache, ['site_registration'], name, value)


                            class AwayEids(Entity):
                                """
                                Map cache configuration for the away table
                                
                                .. attribute:: send_map_request
                                
                                	Export away table entries into the map cache with action set to send\-map\-request
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.Default.MapCache.AwayEids, self).__init__()

                                    self.yang_name = "away-eids"
                                    self.yang_parent_name = "map-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                    ])
                                    self.send_map_request = None
                                    self._segment_path = lambda: "away-eids"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapCache.AwayEids, ['send_map_request'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.MapCachePersistent, ['interval'], name, value)


                        class ProxyItr(Entity):
                            """
                            Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            
                            .. attribute:: ipv4_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_addr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.ProxyItr, self).__init__()

                                self.yang_name = "proxy-itr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                    ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                ])
                                self.ipv4_addr = None
                                self.ipv6_addr = None
                                self._segment_path = lambda: "proxy-itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	
                            	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.UsePetr.Priority>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Service.Ipv6.Default.UsePetr.Priority))])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                ])
                                self.locator_address = None

                                self.priority = Native.Router.LispList.Service.Ipv6.Default.UsePetr.Priority()
                                self.priority.parent = self
                                self._children_name_map["priority"] = "priority"
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.UsePetr, ['locator_address'], name, value)


                            class Priority(Entity):
                                """
                                
                                
                                .. attribute:: priority_value
                                
                                	Configures which Locators from a set are preferred
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: weight
                                
                                	Traffic load\-spreading among Locators
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.Default.UsePetr.Priority, self).__init__()

                                    self.yang_name = "priority"
                                    self.yang_parent_name = "use-petr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                    ])
                                    self.priority_value = None
                                    self.weight = None
                                    self._segment_path = lambda: "priority"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                        class Import(Entity):
                            """
                            Redistribute LISP states internally
                            
                            .. attribute:: database
                            
                            	Redistribute LISP internal states as database mapping
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Default.Import.Database>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Default.Import, self).__init__()

                                self.yang_name = "import"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Service.Ipv6.Default.Import.Database))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.LispList.Service.Ipv6.Default.Import.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"
                                self._segment_path = lambda: "import"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Import, [], name, value)


                            class Database(Entity):
                                """
                                Redistribute LISP internal states as database mapping
                                
                                .. attribute:: site_registration
                                
                                	Import states from site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.Default.Import.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.site_registration = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "database"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.Default.Import.Database, ['site_registration', 'locator_set'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Address family specific local EID prefixes database configuration
                        
                        .. attribute:: limit
                        
                        	Configures the maximum size of local EID prefixes database
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.DatabaseMapping.Limit>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Service.Ipv6.DatabaseMapping.Limit))])
                            self._leafs = OrderedDict()

                            self.limit = Native.Router.LispList.Service.Ipv6.DatabaseMapping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "database-mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.DatabaseMapping, [], name, value)


                        class Limit(Entity):
                            """
                            Configures the maximum size of local EID prefixes database
                            
                            .. attribute:: dynamic
                            
                            	Configures the maximum size of dynamic local EID prefixes database
                            	**type**\: int
                            
                            	**range:** 1..5000
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "database-mapping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.dynamic = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                    class Itr(Entity):
                        """
                        Configures a LISP Ingress Tunnel Router (ITR)
                        
                        .. attribute:: map_resolver
                        
                        	Configures map\-resolver address for sending Map\-Requests
                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Itr.MapResolver>`
                        
                        .. attribute:: nmr_ttl
                        
                        	verride negative map\-reply TTL for site EID
                        	**type**\: int
                        
                        	**range:** 1..900
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.Itr, self).__init__()

                            self.yang_name = "itr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ipv6.Itr.MapResolver))])
                            self._leafs = OrderedDict([
                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                            ])
                            self.nmr_ttl = None

                            self.map_resolver = YList(self)
                            self._segment_path = lambda: "itr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures map\-resolver address for sending Map\-Requests
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_list
                            
                            	Associates ITR/ETR with prefix list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Itr.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "itr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.ip_addr = None
                                self.prefix_list = None
                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                    class ItrEnable(Entity):
                        """
                        
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.ItrEnable, self).__init__()

                            self.yang_name = "itr-enable"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                            ])
                            self.itr = None
                            self._segment_path = lambda: "itr-enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.ItrEnable, ['itr'], name, value)


                    class EtrEnable(Entity):
                        """
                        
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.EtrEnable, self).__init__()

                            self.yang_name = "etr-enable"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                            ])
                            self.etr = None
                            self._segment_path = lambda: "etr-enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.EtrEnable, ['etr'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr.MapServer>`
                        
                        .. attribute:: map_cache_ttl
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..10080
                        
                        .. attribute:: accept_map_request_mapping
                        
                        	
                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                            self._leafs = OrderedDict([
                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                            ])
                            self.map_cache_ttl = None

                            self.accept_map_request_mapping = Native.Router.LispList.Service.Ipv6.Etr.AcceptMapRequestMapping()
                            self.accept_map_request_mapping.parent = self
                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                            self.map_server = YList(self)
                            self._segment_path = lambda: "etr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_pwd
                                
                                	
                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                
                                .. attribute:: key_0
                                
                                	
                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                
                                .. attribute:: key_6
                                
                                	
                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                
                                .. attribute:: key_7
                                
                                	
                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                    self._leafs = OrderedDict()

                                    self.key_pwd = Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                    self.key_pwd.parent = self
                                    self._children_name_map["key_pwd"] = "key-pwd"

                                    self.key_0 = Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key0()
                                    self.key_0.parent = self
                                    self._children_name_map["key_0"] = "key-0"

                                    self.key_6 = Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key6()
                                    self.key_6.parent = self
                                    self._children_name_map["key_6"] = "key-6"

                                    self.key_7 = Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key7()
                                    self.key_7.parent = self
                                    self._children_name_map["key_7"] = "key-7"
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                class KeyPwd(Entity):
                                    """
                                    
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                        self.yang_name = "key-pwd"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-pwd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key0(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                        self.yang_name = "key-0"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_0 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-0"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                        self.yang_name = "key-6"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_6 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key7(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                        self.yang_name = "key-7"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_7 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-7"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                        class AcceptMapRequestMapping(Entity):
                            """
                            
                            
                            .. attribute:: accept_mappping
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: verify
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                self.yang_name = "accept-map-request-mapping"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                ])
                                self.accept_mappping = None
                                self.verify = None
                                self._segment_path = lambda: "accept-map-request-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                    class MapCacheLimit(Entity):
                        """
                        Configures maximum size of map\-cache
                        
                        .. attribute:: max_map_cache_entries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..100000
                        
                        .. attribute:: reserve_list
                        
                        	EID\-prefixes guaranteed to be stored in map\-cache
                        	**type**\: str
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.MapCacheLimit, self).__init__()

                            self.yang_name = "map-cache-limit"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.max_map_cache_entries = None
                            self.reserve_list = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "map-cache-limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                    class MapResolver(Entity):
                        """
                        Configures a LISP Map Resolver (MR)
                        
                        .. attribute:: map_request
                        
                        	Map\-Request processing options
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_request = Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"
                            self._segment_path = lambda: "map-resolver"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapResolver, [], name, value)


                        class MapRequest(Entity):
                            """
                            Map\-Request processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "map-resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	Influence which source RLOCs map requests are accepted from
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    Influence which source RLOCs map requests are accepted from
                                    
                                    .. attribute:: list
                                    
                                    	Define allowed prefixes using an ip[v6] prefix list
                                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List>`
                                    
                                    .. attribute:: registered
                                    
                                    	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                    	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered))])
                                        self._leafs = OrderedDict()

                                        self.list = Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List()
                                        self.list.parent = self
                                        self._children_name_map["list"] = "list"

                                        self.registered = Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered()
                                        self.registered.parent = self
                                        self._children_name_map["registered"] = "registered"
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source, [], name, value)


                                    class List(Entity):
                                        """
                                        Define allowed prefixes using an ip[v6] prefix list
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 prefixes
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 prefixes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                            self.yang_name = "list"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "list"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                    class Registered(Entity):
                                        """
                                        ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                            self.yang_name = "registered"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"
                                            self._segment_path = lambda: "registered"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "registered"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                    class MapServer(Entity):
                        """
                        Configures a LISP Map Server (MS)
                        
                        .. attribute:: map_register
                        
                        	Map\-Register processing options
                        	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapServer.MapRegister>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Service.Ipv6.MapServer.MapRegister))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_register = Native.Router.LispList.Service.Ipv6.MapServer.MapRegister()
                            self.map_register.parent = self
                            self._children_name_map["map_register"] = "map-register"
                            self._segment_path = lambda: "map-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapServer, [], name, value)


                        class MapRegister(Entity):
                            """
                            Map\-Register processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapServer.MapRegister.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.MapServer.MapRegister, self).__init__()

                                self.yang_name = "map-register"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ipv6.MapServer.MapRegister.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.LispList.Service.Ipv6.MapServer.MapRegister.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-register"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapServer.MapRegister, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	RLOC Source IP address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapServer.MapRegister.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-register"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ipv6.MapServer.MapRegister.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.Service.Ipv6.MapServer.MapRegister.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    RLOC Source IP address
                                    
                                    .. attribute:: allowed_locator
                                    
                                    	Against sites' allowed\-locators policy
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                        ])
                                        self.allowed_locator = None
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                    class SiteRegistration(Entity):
                        """
                        Site registrations configuration for a given instance\-id
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class SolicitMapRequest(Entity):
                        """
                        Configure Solicit\-Map\-Request handling
                        
                        .. attribute:: ignore
                        
                        	Ignore SMR bit in incoming Map\-Requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_per_entry
                        
                        	Maximum number of SMRs for addresses under a map\-cache entry
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: suppression_time
                        
                        	How long to suppress repeated SMRs for the same address
                        	**type**\: int
                        
                        	**range:** 1..600
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.SolicitMapRequest, self).__init__()

                            self.yang_name = "solicit-map-request"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                            ])
                            self.ignore = None
                            self.max_per_entry = None
                            self.suppression_time = None
                            self._segment_path = lambda: "solicit-map-request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                    class Distance(Entity):
                        """
                        Administrative distance for RIB route installation
                        
                        .. attribute:: alt
                        
                        	LISP routes installed in the ALT table
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: away
                        
                        	Administrative distance for RIB route installation
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: dyn_eid
                        
                        	LISP installed routes of type dynamic\-EID
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: site_registrations
                        
                        	LISP installed routes of type site\-registrations
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                            ])
                            self.alt = None
                            self.away = None
                            self.dyn_eid = None
                            self.site_registrations = None
                            self._segment_path = lambda: "distance"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                    class MapCache(Entity):
                        """
                        Address family specific map cache configuration
                        
                        .. attribute:: away_eids
                        
                        	Map cache configuration for the away table
                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.MapCache.AwayEids>`
                        
                        .. attribute:: site_registration
                        
                        	Install map cache to map request for site registrations
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("away-eids", ("away_eids", Native.Router.LispList.Service.Ipv6.MapCache.AwayEids))])
                            self._leafs = OrderedDict([
                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                            ])
                            self.site_registration = None

                            self.away_eids = Native.Router.LispList.Service.Ipv6.MapCache.AwayEids()
                            self.away_eids.parent = self
                            self._children_name_map["away_eids"] = "away-eids"
                            self._segment_path = lambda: "map-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapCache, ['site_registration'], name, value)


                        class AwayEids(Entity):
                            """
                            Map cache configuration for the away table
                            
                            .. attribute:: send_map_request
                            
                            	Export away table entries into the map cache with action set to send\-map\-request
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                self.yang_name = "away-eids"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                ])
                                self.send_map_request = None
                                self._segment_path = lambda: "away-eids"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                    class MapCachePersistent(Entity):
                        """
                        Dump map\-cache onto flash, making it persistent across reboots
                        
                        .. attribute:: interval
                        
                        	Interval in minutes of how often the map\-cache is saved
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.MapCachePersistent, self).__init__()

                            self.yang_name = "map-cache-persistent"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "map-cache-persistent"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                    class ProxyItr(Entity):
                        """
                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        
                        .. attribute:: ipv4_addr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_addr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.ProxyItr, self).__init__()

                            self.yang_name = "proxy-itr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                            ])
                            self.ipv4_addr = None
                            self.ipv6_addr = None
                            self._segment_path = lambda: "proxy-itr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                    class RouteExport(Entity):
                        """
                        Export routes into RIB from LISP
                        
                        .. attribute:: site_registrations
                        
                        	Export LISP site registrations to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: away_eids
                        
                        	Export LISP away EIDs to RIB
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.RouteExport, self).__init__()

                            self.yang_name = "route-export"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                            ])
                            self.site_registrations = None
                            self.away_eids = None
                            self._segment_path = lambda: "route-export"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                    class UsePetr(Entity):
                        """
                        Encapsulate to Proxy ETR when matching forward\-native entry
                        
                        .. attribute:: locator_address  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	
                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.UsePetr.Priority>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.UsePetr, self).__init__()

                            self.yang_name = "use-petr"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['locator_address']
                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.Service.Ipv6.UsePetr.Priority))])
                            self._leafs = OrderedDict([
                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                            ])
                            self.locator_address = None

                            self.priority = Native.Router.LispList.Service.Ipv6.UsePetr.Priority()
                            self.priority.parent = self
                            self._children_name_map["priority"] = "priority"
                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                        class Priority(Entity):
                            """
                            
                            
                            .. attribute:: priority_value
                            
                            	Configures which Locators from a set are preferred
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: weight
                            
                            	Traffic load\-spreading among Locators
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.UsePetr.Priority, self).__init__()

                                self.yang_name = "priority"
                                self.yang_parent_name = "use-petr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                ])
                                self.priority_value = None
                                self.weight = None
                                self._segment_path = lambda: "priority"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                    class Import(Entity):
                        """
                        Redistribute LISP states internally
                        
                        .. attribute:: database
                        
                        	Redistribute LISP internal states as database mapping
                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ipv6.Import.Database>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ipv6.Import, self).__init__()

                            self.yang_name = "import"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Service.Ipv6.Import.Database))])
                            self._leafs = OrderedDict()

                            self.database = Native.Router.LispList.Service.Ipv6.Import.Database()
                            self.database.parent = self
                            self._children_name_map["database"] = "database"
                            self._segment_path = lambda: "import"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ipv6.Import, [], name, value)


                        class Database(Entity):
                            """
                            Redistribute LISP internal states as database mapping
                            
                            .. attribute:: site_registration
                            
                            	Import states from site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: locator_set
                            
                            	Locator set to use with created database mapping entries
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ipv6.Import.Database, self).__init__()

                                self.yang_name = "database"
                                self.yang_parent_name = "import"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                ])
                                self.site_registration = None
                                self.locator_set = None
                                self._segment_path = lambda: "database"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                class Ethernet(Entity):
                    """
                    
                    
                    .. attribute:: default
                    
                    	
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default>`
                    
                    .. attribute:: encapsulation
                    
                    	Select encapsulation type for data packets
                    	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Encapsulation>`
                    
                    .. attribute:: map_request_source
                    
                    	Configures inner header source address in Map\-Request message
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: database_mapping
                    
                    	Address family specific local EID prefixes database configuration
                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.DatabaseMapping>`
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Itr>`
                    
                    .. attribute:: itr_enable
                    
                    	
                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.ItrEnable>`
                    
                    .. attribute:: etr_enable
                    
                    	
                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.EtrEnable>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr>`
                    
                    .. attribute:: map_cache_limit
                    
                    	Configures maximum size of map\-cache
                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapCacheLimit>`
                    
                    .. attribute:: map_resolver
                    
                    	Configures a LISP Map Resolver (MR)
                    	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapResolver>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: map_server
                    
                    	Configures a LISP Map Server (MS)
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapServer>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: site_registration
                    
                    	Site registrations configuration for a given instance\-id
                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.SiteRegistration>`
                    
                    .. attribute:: solicit_map_request
                    
                    	Configure Solicit\-Map\-Request handling
                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.SolicitMapRequest>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Service.Ethernet, self).__init__()

                        self.yang_name = "ethernet"
                        self.yang_parent_name = "service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Service.Ethernet.Default)), ("encapsulation", ("encapsulation", Native.Router.LispList.Service.Ethernet.Encapsulation)), ("database-mapping", ("database_mapping", Native.Router.LispList.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Service.Ethernet.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ethernet.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Service.Ethernet.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Service.Ethernet.SolicitMapRequest))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                        ])
                        self.map_request_source = None

                        self.default = Native.Router.LispList.Service.Ethernet.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.encapsulation = Native.Router.LispList.Service.Ethernet.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"

                        self.database_mapping = Native.Router.LispList.Service.Ethernet.DatabaseMapping()
                        self.database_mapping.parent = self
                        self._children_name_map["database_mapping"] = "database-mapping"

                        self.itr = Native.Router.LispList.Service.Ethernet.Itr()
                        self.itr.parent = self
                        self._children_name_map["itr"] = "itr"

                        self.itr_enable = Native.Router.LispList.Service.Ethernet.ItrEnable()
                        self.itr_enable.parent = self
                        self._children_name_map["itr_enable"] = "itr-enable"

                        self.etr_enable = Native.Router.LispList.Service.Ethernet.EtrEnable()
                        self.etr_enable.parent = self
                        self._children_name_map["etr_enable"] = "etr-enable"

                        self.etr = Native.Router.LispList.Service.Ethernet.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.map_cache_limit = Native.Router.LispList.Service.Ethernet.MapCacheLimit()
                        self.map_cache_limit.parent = self
                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                        self.map_resolver = None
                        self._children_name_map["map_resolver"] = "map-resolver"

                        self.map_server = None
                        self._children_name_map["map_server"] = "map-server"

                        self.site_registration = Native.Router.LispList.Service.Ethernet.SiteRegistration()
                        self.site_registration.parent = self
                        self._children_name_map["site_registration"] = "site-registration"

                        self.solicit_map_request = Native.Router.LispList.Service.Ethernet.SolicitMapRequest()
                        self.solicit_map_request.parent = self
                        self._children_name_map["solicit_map_request"] = "solicit-map-request"
                        self._segment_path = lambda: "ethernet"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Service.Ethernet, ['map_request_source'], name, value)


                    class Default(Entity):
                        """
                        
                        
                        .. attribute:: encapsulation
                        
                        	Select encapsulation type for data packets
                        	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Encapsulation>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.DatabaseMapping>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.ItrEnable>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.EtrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapCacheLimit>`
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.SolicitMapRequest>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Router.LispList.Service.Ethernet.Default.Encapsulation)), ("database-mapping", ("database_mapping", Native.Router.LispList.Service.Ethernet.Default.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.Service.Ethernet.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Service.Ethernet.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.Service.Ethernet.Default.EtrEnable)), ("etr", ("etr", Native.Router.LispList.Service.Ethernet.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Service.Ethernet.Default.MapCacheLimit)), ("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ethernet.Default.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Service.Ethernet.Default.MapServer)), ("site-registration", ("site_registration", Native.Router.LispList.Service.Ethernet.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Service.Ethernet.Default.SolicitMapRequest))])
                            self._leafs = OrderedDict([
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                            ])
                            self.map_request_source = None

                            self.encapsulation = Native.Router.LispList.Service.Ethernet.Default.Encapsulation()
                            self.encapsulation.parent = self
                            self._children_name_map["encapsulation"] = "encapsulation"

                            self.database_mapping = Native.Router.LispList.Service.Ethernet.Default.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.itr = Native.Router.LispList.Service.Ethernet.Default.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.LispList.Service.Ethernet.Default.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr_enable = Native.Router.LispList.Service.Ethernet.Default.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.etr = Native.Router.LispList.Service.Ethernet.Default.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.map_cache_limit = Native.Router.LispList.Service.Ethernet.Default.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.site_registration = Native.Router.LispList.Service.Ethernet.Default.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.LispList.Service.Ethernet.Default.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default, ['map_request_source'], name, value)


                        class Encapsulation(Entity):
                            """
                            Select encapsulation type for data packets
                            
                            .. attribute:: vxlan
                            
                            	Use VXLAN encapsulation for data packets
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Default.Encapsulation, self).__init__()

                                self.yang_name = "encapsulation"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                ])
                                self.vxlan = None
                                self._segment_path = lambda: "encapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.Encapsulation, ['vxlan'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Default.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Service.Ethernet.Default.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.LispList.Service.Ethernet.Default.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 1..5000
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ethernet.Default.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Itr.MapResolver>`
                            
                            .. attribute:: nmr_ttl
                            
                            	verride negative map\-reply TTL for site EID
                            	**type**\: int
                            
                            	**range:** 1..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Default.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ethernet.Default.Itr.MapResolver))])
                                self._leafs = OrderedDict([
                                    ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                ])
                                self.nmr_ttl = None

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.Itr, ['nmr_ttl'], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_list
                                
                                	Associates ITR/ETR with prefix list
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ethernet.Default.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                    ])
                                    self.ip_addr = None
                                    self.prefix_list = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Default.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.ItrEnable, ['itr'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Default.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.EtrEnable, ['etr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer>`
                            
                            .. attribute:: map_cache_ttl
                            
                            	
                            	**type**\: int
                            
                            	**range:** 60..10080
                            
                            .. attribute:: accept_map_request_mapping
                            
                            	
                            	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Default.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping))])
                                self._leafs = OrderedDict([
                                    ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                ])
                                self.map_cache_ttl = None

                                self.accept_map_request_mapping = Native.Router.LispList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping()
                                self.accept_map_request_mapping.parent = self
                                self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.Etr, ['map_cache_ttl'], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                            class AcceptMapRequestMapping(Entity):
                                """
                                
                                
                                .. attribute:: accept_mappping
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: verify
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                    self.yang_name = "accept-map-request-mapping"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                        ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                    ])
                                    self.accept_mappping = None
                                    self.verify = None
                                    self._segment_path = lambda: "accept-map-request-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Default.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Default.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.List>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"

                                            self.registered = Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered()
                                            self.registered.parent = self
                                            self._children_name_map["registered"] = "registered"
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                        class Registered(Entity):
                                            """
                                            ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                            
                                            .. attribute:: list
                                            
                                            	Define allowed prefixes using an ip[v6] prefix list
                                            	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                                self.yang_name = "registered"
                                                self.yang_parent_name = "source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                                self._leafs = OrderedDict()

                                                self.list = Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered.List()
                                                self.list.parent = self
                                                self._children_name_map["list"] = "list"
                                                self._segment_path = lambda: "registered"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                            class List(Entity):
                                                """
                                                Define allowed prefixes using an ip[v6] prefix list
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 prefixes
                                                	**type**\: str
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 prefixes
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                    self.yang_name = "list"
                                                    self.yang_parent_name = "registered"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "list"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Default.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Default.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Default.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                    class Encapsulation(Entity):
                        """
                        Select encapsulation type for data packets
                        
                        .. attribute:: vxlan
                        
                        	Use VXLAN encapsulation for data packets
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.Encapsulation, self).__init__()

                            self.yang_name = "encapsulation"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                            ])
                            self.vxlan = None
                            self._segment_path = lambda: "encapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.Encapsulation, ['vxlan'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Address family specific local EID prefixes database configuration
                        
                        .. attribute:: limit
                        
                        	Configures the maximum size of local EID prefixes database
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.DatabaseMapping.Limit>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Service.Ethernet.DatabaseMapping.Limit))])
                            self._leafs = OrderedDict()

                            self.limit = Native.Router.LispList.Service.Ethernet.DatabaseMapping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "database-mapping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.DatabaseMapping, [], name, value)


                        class Limit(Entity):
                            """
                            Configures the maximum size of local EID prefixes database
                            
                            .. attribute:: dynamic
                            
                            	Configures the maximum size of dynamic local EID prefixes database
                            	**type**\: int
                            
                            	**range:** 1..5000
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "database-mapping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.dynamic = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                    class Itr(Entity):
                        """
                        Configures a LISP Ingress Tunnel Router (ITR)
                        
                        .. attribute:: map_resolver
                        
                        	Configures map\-resolver address for sending Map\-Requests
                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Itr.MapResolver>`
                        
                        .. attribute:: nmr_ttl
                        
                        	verride negative map\-reply TTL for site EID
                        	**type**\: int
                        
                        	**range:** 1..900
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.Itr, self).__init__()

                            self.yang_name = "itr"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Service.Ethernet.Itr.MapResolver))])
                            self._leafs = OrderedDict([
                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                            ])
                            self.nmr_ttl = None

                            self.map_resolver = YList(self)
                            self._segment_path = lambda: "itr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures map\-resolver address for sending Map\-Requests
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_list
                            
                            	Associates ITR/ETR with prefix list
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Itr.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "itr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.ip_addr = None
                                self.prefix_list = None
                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                    class ItrEnable(Entity):
                        """
                        
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.ItrEnable, self).__init__()

                            self.yang_name = "itr-enable"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                            ])
                            self.itr = None
                            self._segment_path = lambda: "itr-enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.ItrEnable, ['itr'], name, value)


                    class EtrEnable(Entity):
                        """
                        
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.EtrEnable, self).__init__()

                            self.yang_name = "etr-enable"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                            ])
                            self.etr = None
                            self._segment_path = lambda: "etr-enable"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.EtrEnable, ['etr'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr.MapServer>`
                        
                        .. attribute:: map_cache_ttl
                        
                        	
                        	**type**\: int
                        
                        	**range:** 60..10080
                        
                        .. attribute:: accept_map_request_mapping
                        
                        	
                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                            self._leafs = OrderedDict([
                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                            ])
                            self.map_cache_ttl = None

                            self.accept_map_request_mapping = Native.Router.LispList.Service.Ethernet.Etr.AcceptMapRequestMapping()
                            self.accept_map_request_mapping.parent = self
                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                            self.map_server = YList(self)
                            self._segment_path = lambda: "etr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_pwd
                                
                                	
                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                
                                .. attribute:: key_0
                                
                                	
                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                
                                .. attribute:: key_6
                                
                                	
                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                
                                .. attribute:: key_7
                                
                                	
                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                    self._leafs = OrderedDict()

                                    self.key_pwd = Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                    self.key_pwd.parent = self
                                    self._children_name_map["key_pwd"] = "key-pwd"

                                    self.key_0 = Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key0()
                                    self.key_0.parent = self
                                    self._children_name_map["key_0"] = "key-0"

                                    self.key_6 = Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key6()
                                    self.key_6.parent = self
                                    self._children_name_map["key_6"] = "key-6"

                                    self.key_7 = Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key7()
                                    self.key_7.parent = self
                                    self._children_name_map["key_7"] = "key-7"
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                class KeyPwd(Entity):
                                    """
                                    
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                        self.yang_name = "key-pwd"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-pwd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key0(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                        self.yang_name = "key-0"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_0 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-0"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                        self.yang_name = "key-6"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_6 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key7(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                        self.yang_name = "key-7"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_7 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-7"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                        class AcceptMapRequestMapping(Entity):
                            """
                            
                            
                            .. attribute:: accept_mappping
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: verify
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                self.yang_name = "accept-map-request-mapping"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                ])
                                self.accept_mappping = None
                                self.verify = None
                                self._segment_path = lambda: "accept-map-request-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                    class MapCacheLimit(Entity):
                        """
                        Configures maximum size of map\-cache
                        
                        .. attribute:: max_map_cache_entries
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..100000
                        
                        .. attribute:: reserve_list
                        
                        	EID\-prefixes guaranteed to be stored in map\-cache
                        	**type**\: str
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.MapCacheLimit, self).__init__()

                            self.yang_name = "map-cache-limit"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.max_map_cache_entries = None
                            self.reserve_list = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "map-cache-limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                    class MapResolver(Entity):
                        """
                        Configures a LISP Map Resolver (MR)
                        
                        .. attribute:: map_request
                        
                        	Map\-Request processing options
                        	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_request = Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest()
                            self.map_request.parent = self
                            self._children_name_map["map_request"] = "map-request"
                            self._segment_path = lambda: "map-resolver"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapResolver, [], name, value)


                        class MapRequest(Entity):
                            """
                            Map\-Request processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest, self).__init__()

                                self.yang_name = "map-request"
                                self.yang_parent_name = "map-resolver"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	Influence which source RLOCs map requests are accepted from
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    Influence which source RLOCs map requests are accepted from
                                    
                                    .. attribute:: list
                                    
                                    	Define allowed prefixes using an ip[v6] prefix list
                                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List>`
                                    
                                    .. attribute:: registered
                                    
                                    	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                    	**type**\:  :py:class:`Registered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List)), ("registered", ("registered", Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered))])
                                        self._leafs = OrderedDict()

                                        self.list = Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List()
                                        self.list.parent = self
                                        self._children_name_map["list"] = "list"

                                        self.registered = Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered()
                                        self.registered.parent = self
                                        self._children_name_map["registered"] = "registered"
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source, [], name, value)


                                    class List(Entity):
                                        """
                                        Define allowed prefixes using an ip[v6] prefix list
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 prefixes
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 prefixes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List, self).__init__()

                                            self.yang_name = "list"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "list"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.List, ['ipv4', 'ipv6'], name, value)


                                    class Registered(Entity):
                                        """
                                        ...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered, self).__init__()

                                            self.yang_name = "registered"
                                            self.yang_parent_name = "source"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List))])
                                            self._leafs = OrderedDict()

                                            self.list = Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List()
                                            self.list.parent = self
                                            self._children_name_map["list"] = "list"
                                            self._segment_path = lambda: "registered"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered, [], name, value)


                                        class List(Entity):
                                            """
                                            Define allowed prefixes using an ip[v6] prefix list
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 prefixes
                                            	**type**\: str
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 prefixes
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List, self).__init__()

                                                self.yang_name = "list"
                                                self.yang_parent_name = "registered"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapResolver.MapRequest.Validate.Source.Registered.List, ['ipv4', 'ipv6'], name, value)


                    class MapServer(Entity):
                        """
                        Configures a LISP Map Server (MS)
                        
                        .. attribute:: map_register
                        
                        	Map\-Register processing options
                        	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapServer.MapRegister>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Service.Ethernet.MapServer.MapRegister))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.map_register = Native.Router.LispList.Service.Ethernet.MapServer.MapRegister()
                            self.map_register.parent = self
                            self._children_name_map["map_register"] = "map-register"
                            self._segment_path = lambda: "map-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapServer, [], name, value)


                        class MapRegister(Entity):
                            """
                            Map\-Register processing options
                            
                            .. attribute:: validate
                            
                            	Validation options
                            	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapServer.MapRegister.Validate>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Service.Ethernet.MapServer.MapRegister, self).__init__()

                                self.yang_name = "map-register"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Service.Ethernet.MapServer.MapRegister.Validate))])
                                self._leafs = OrderedDict()

                                self.validate = Native.Router.LispList.Service.Ethernet.MapServer.MapRegister.Validate()
                                self.validate.parent = self
                                self._children_name_map["validate"] = "validate"
                                self._segment_path = lambda: "map-register"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapServer.MapRegister, [], name, value)


                            class Validate(Entity):
                                """
                                Validation options
                                
                                .. attribute:: source
                                
                                	RLOC Source IP address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Service.Ethernet.MapServer.MapRegister.Validate.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Service.Ethernet.MapServer.MapRegister.Validate, self).__init__()

                                    self.yang_name = "validate"
                                    self.yang_parent_name = "map-register"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Service.Ethernet.MapServer.MapRegister.Validate.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.Service.Ethernet.MapServer.MapRegister.Validate.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "validate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapServer.MapRegister.Validate, [], name, value)


                                class Source(Entity):
                                    """
                                    RLOC Source IP address
                                    
                                    .. attribute:: allowed_locator
                                    
                                    	Against sites' allowed\-locators policy
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.Service.Ethernet.MapServer.MapRegister.Validate.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "validate"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                        ])
                                        self.allowed_locator = None
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.Service.Ethernet.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                    class SiteRegistration(Entity):
                        """
                        Site registrations configuration for a given instance\-id
                        
                        .. attribute:: limit
                        
                        	Maximum number of site registrations
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Warning threshold to issue system logging
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.SiteRegistration, self).__init__()

                            self.yang_name = "site-registration"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.limit = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "site-registration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class SolicitMapRequest(Entity):
                        """
                        Configure Solicit\-Map\-Request handling
                        
                        .. attribute:: ignore
                        
                        	Ignore SMR bit in incoming Map\-Requests
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_per_entry
                        
                        	Maximum number of SMRs for addresses under a map\-cache entry
                        	**type**\: int
                        
                        	**range:** 1..100
                        
                        .. attribute:: suppression_time
                        
                        	How long to suppress repeated SMRs for the same address
                        	**type**\: int
                        
                        	**range:** 1..600
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Service.Ethernet.SolicitMapRequest, self).__init__()

                            self.yang_name = "solicit-map-request"
                            self.yang_parent_name = "ethernet"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                            ])
                            self.ignore = None
                            self.max_per_entry = None
                            self.suppression_time = None
                            self._segment_path = lambda: "solicit-map-request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


            class Encapsulation(Entity):
                """
                Select encapsulation type for data packets
                
                .. attribute:: vxlan
                
                	Use VXLAN encapsulation for data packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                    ])
                    self.vxlan = None
                    self._segment_path = lambda: "encapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Encapsulation, ['vxlan'], name, value)


            class LocatorSet(Entity):
                """
                Configure a named locator set
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: auto_discover_rlocs
                
                	Auto discover locators registered by other xTRs
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ipv4_interface
                
                	Use IPv4 address of interface as locator
                	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.LocatorSet.IPv4Interface>`
                
                .. attribute:: ipv6_interface
                
                	Use IPv6 address of interface as locator
                	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.LocatorSet.IPv6Interface>`
                
                .. attribute:: ip_address
                
                	Use IPv6 address of interface as locator
                	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.LocatorSet.IpAddress>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.LocatorSet, self).__init__()

                    self.yang_name = "locator-set"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("IPv4-interface", ("ipv4_interface", Native.Router.LispList.LocatorSet.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.LocatorSet.IPv6Interface)), ("ip-address", ("ip_address", Native.Router.LispList.LocatorSet.IpAddress))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                    ])
                    self.name = None
                    self.auto_discover_rlocs = None

                    self.ipv4_interface = YList(self)
                    self.ipv6_interface = YList(self)
                    self.ip_address = YList(self)
                    self._segment_path = lambda: "locator-set" + "[name='" + str(self.name) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.LocatorSet, ['name', 'auto_discover_rlocs'], name, value)


                class IPv4Interface(Entity):
                    """
                    Use IPv4 address of interface as locator
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: priority
                    
                    	Configures which Locators from a set are preferred
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: weight
                    
                    	Traffic load\-spreading among Locators
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.LocatorSet.IPv4Interface, self).__init__()

                        self.yang_name = "IPv4-interface"
                        self.yang_parent_name = "locator-set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                        ])
                        self.name = None
                        self.priority = None
                        self.weight = None
                        self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.LocatorSet.IPv4Interface, ['name', 'priority', 'weight'], name, value)


                class IPv6Interface(Entity):
                    """
                    Use IPv6 address of interface as locator
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: priority
                    
                    	Configures which Locators from a set are preferred
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: weight
                    
                    	Traffic load\-spreading among Locators
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.LocatorSet.IPv6Interface, self).__init__()

                        self.yang_name = "IPv6-interface"
                        self.yang_parent_name = "locator-set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                        ])
                        self.name = None
                        self.priority = None
                        self.weight = None
                        self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.LocatorSet.IPv6Interface, ['name', 'priority', 'weight'], name, value)


                class IpAddress(Entity):
                    """
                    Use IPv6 address of interface as locator
                    
                    .. attribute:: ip  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: priority
                    
                    	Configures which Locators from a set are preferred
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: weight
                    
                    	Traffic load\-spreading among Locators
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.LocatorSet.IpAddress, self).__init__()

                        self.yang_name = "ip-address"
                        self.yang_parent_name = "locator-set"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['ip']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                        ])
                        self.ip = None
                        self.priority = None
                        self.weight = None
                        self._segment_path = lambda: "ip-address" + "[ip='" + str(self.ip) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.LocatorSet.IpAddress, ['ip', 'priority', 'weight'], name, value)


            class Locator(Entity):
                """
                Locator configuration
                
                .. attribute:: default_set
                
                	Specify a default locator\-set
                	**type**\: str
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Locator, self).__init__()

                    self.yang_name = "locator"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default_set', (YLeaf(YType.str, 'default-set'), ['str'])),
                    ])
                    self.default_set = None
                    self._segment_path = lambda: "locator"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Locator, ['default_set'], name, value)


            class LocatorScope(Entity):
                """
                Configure a locator scope
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: rloc_prefix
                
                	RLOC prefix to check against ITR RLOC and ETR RLOC
                	**type**\: union of the below types:
                
                		**type**\: list of str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                
                		**type**\: list of str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                
                .. attribute:: rtr_locator_set
                
                	Locator\-set of RTR to use in proxy reply for disjoint/cross AF RLOC
                	**type**\: list of str
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.LocatorScope, self).__init__()

                    self.yang_name = "locator-scope"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('rloc_prefix', (YLeafList(YType.str, 'rloc-prefix'), ['str','str'])),
                        ('rtr_locator_set', (YLeafList(YType.str, 'rtr-locator-set'), ['str'])),
                    ])
                    self.name = None
                    self.rloc_prefix = []
                    self.rtr_locator_set = []
                    self._segment_path = lambda: "locator-scope" + "[name='" + str(self.name) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.LocatorScope, ['name', 'rloc_prefix', 'rtr_locator_set'], name, value)


            class PrefixList(Entity):
                """
                Configure a named prefix list
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: ipv4_prefix
                
                	IPv4 EID\-prefix
                	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.PrefixList.Ipv4Prefix>`
                
                .. attribute:: ipv6_prefix
                
                	IPv6 EID\-prefix
                	**type**\: list of  		 :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.PrefixList.Ipv6Prefix>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.PrefixList, self).__init__()

                    self.yang_name = "prefix-list"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.LispList.PrefixList.Ipv4Prefix)), ("ipv6-prefix", ("ipv6_prefix", Native.Router.LispList.PrefixList.Ipv6Prefix))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.ipv4_prefix = YList(self)
                    self.ipv6_prefix = YList(self)
                    self._segment_path = lambda: "prefix-list" + "[name='" + str(self.name) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.PrefixList, ['name'], name, value)


                class Ipv4Prefix(Entity):
                    """
                    IPv4 EID\-prefix
                    
                    .. attribute:: prefix  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.PrefixList.Ipv4Prefix, self).__init__()

                        self.yang_name = "ipv4-prefix"
                        self.yang_parent_name = "prefix-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['prefix']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "ipv4-prefix" + "[prefix='" + str(self.prefix) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.PrefixList.Ipv4Prefix, ['prefix'], name, value)


                class Ipv6Prefix(Entity):
                    """
                    IPv6 EID\-prefix
                    
                    .. attribute:: prefix  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.PrefixList.Ipv6Prefix, self).__init__()

                        self.yang_name = "ipv6-prefix"
                        self.yang_parent_name = "prefix-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['prefix']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                        ])
                        self.prefix = None
                        self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + str(self.prefix) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.PrefixList.Ipv6Prefix, ['prefix'], name, value)


            class InstanceContainer(Entity):
                """
                EID instance\-ID
                
                .. attribute:: instance_list
                
                	
                	**type**\: list of  		 :py:class:`InstanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.InstanceContainer, self).__init__()

                    self.yang_name = "instance-container"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance-list", ("instance_list", Native.Router.LispList.InstanceContainer.InstanceList))])
                    self._leafs = OrderedDict()

                    self.instance_list = YList(self)
                    self._segment_path = lambda: "instance-container"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.InstanceContainer, [], name, value)


                class InstanceList(Entity):
                    """
                    
                    
                    .. attribute:: instance_id  (key)
                    
                    	EID instance\-ID
                    	**type**\: int
                    
                    	**range:** 0..16777214
                    
                    .. attribute:: default
                    
                    	
                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default>`
                    
                    .. attribute:: decapsulation
                    
                    	Decapsulation behavior (e.g. filters)
                    	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation>`
                    
                    .. attribute:: disable_ttl_propagate
                    
                    	Disable ttl propagation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dynamic_eid
                    
                    	Configure a dynamic EID
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid>`
                    
                    .. attribute:: loc_reach_algorithm
                    
                    	Configure locator reachability algorithm
                    	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.LocReachAlgorithm>`
                    
                    .. attribute:: map_server
                    
                    	Map\-Server commands
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.MapServer>`
                    
                    .. attribute:: other_xtr_probe
                    
                    	Configure parameters for probing of other xTRs in our site
                    	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.OtherXtrProbe>`
                    
                    .. attribute:: remote_rloc_probe
                    
                    	Configure parameters for probing of remote RLOCs
                    	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.RemoteRlocProbe>`
                    
                    .. attribute:: service
                    
                    	Configure lisp service type
                    	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.InstanceContainer.InstanceList, self).__init__()

                        self.yang_name = "instance-list"
                        self.yang_parent_name = "instance-container"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['instance_id']
                        self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.InstanceContainer.InstanceList.Default)), ("decapsulation", ("decapsulation", Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation)), ("dynamic-eid", ("dynamic_eid", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.LispList.InstanceContainer.InstanceList.LocReachAlgorithm)), ("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.LispList.InstanceContainer.InstanceList.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.LispList.InstanceContainer.InstanceList.RemoteRlocProbe)), ("service", ("service", Native.Router.LispList.InstanceContainer.InstanceList.Service))])
                        self._leafs = OrderedDict([
                            ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                            ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                        ])
                        self.instance_id = None
                        self.disable_ttl_propagate = None

                        self.default = Native.Router.LispList.InstanceContainer.InstanceList.Default()
                        self.default.parent = self
                        self._children_name_map["default"] = "default"

                        self.decapsulation = Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation()
                        self.decapsulation.parent = self
                        self._children_name_map["decapsulation"] = "decapsulation"

                        self.loc_reach_algorithm = Native.Router.LispList.InstanceContainer.InstanceList.LocReachAlgorithm()
                        self.loc_reach_algorithm.parent = self
                        self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                        self.map_server = Native.Router.LispList.InstanceContainer.InstanceList.MapServer()
                        self.map_server.parent = self
                        self._children_name_map["map_server"] = "map-server"

                        self.other_xtr_probe = Native.Router.LispList.InstanceContainer.InstanceList.OtherXtrProbe()
                        self.other_xtr_probe.parent = self
                        self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                        self.remote_rloc_probe = Native.Router.LispList.InstanceContainer.InstanceList.RemoteRlocProbe()
                        self.remote_rloc_probe.parent = self
                        self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                        self.service = None
                        self._children_name_map["service"] = "service"

                        self.dynamic_eid = YList(self)
                        self._segment_path = lambda: "instance-list" + "[instance-id='" + str(self.instance_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList, ['instance_id', 'disable_ttl_propagate'], name, value)


                    class Default(Entity):
                        """
                        
                        
                        .. attribute:: decapsulation
                        
                        	Decapsulation behavior (e.g. filters)
                        	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation>`
                        
                        .. attribute:: disable_ttl_propagate
                        
                        	Disable ttl propagation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dynamic_eid
                        
                        	Configure a dynamic EID
                        	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid>`
                        
                        .. attribute:: loc_reach_algorithm
                        
                        	Configure locator reachability algorithm
                        	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.LocReachAlgorithm>`
                        
                        .. attribute:: map_server
                        
                        	Map\-Server commands
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer>`
                        
                        .. attribute:: other_xtr_probe
                        
                        	Configure parameters for probing of other xTRs in our site
                        	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.OtherXtrProbe>`
                        
                        .. attribute:: remote_rloc_probe
                        
                        	Configure parameters for probing of remote RLOCs
                        	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.RemoteRlocProbe>`
                        
                        .. attribute:: service
                        
                        	Configure lisp service type
                        	**type**\:  :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default, self).__init__()

                            self.yang_name = "default"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("decapsulation", ("decapsulation", Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation)), ("dynamic-eid", ("dynamic_eid", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.LispList.InstanceContainer.InstanceList.Default.LocReachAlgorithm)), ("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.LispList.InstanceContainer.InstanceList.Default.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.LispList.InstanceContainer.InstanceList.Default.RemoteRlocProbe)), ("service", ("service", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service))])
                            self._leafs = OrderedDict([
                                ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                            ])
                            self.disable_ttl_propagate = None

                            self.decapsulation = Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation()
                            self.decapsulation.parent = self
                            self._children_name_map["decapsulation"] = "decapsulation"

                            self.loc_reach_algorithm = Native.Router.LispList.InstanceContainer.InstanceList.Default.LocReachAlgorithm()
                            self.loc_reach_algorithm.parent = self
                            self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                            self.map_server = Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer()
                            self.map_server.parent = self
                            self._children_name_map["map_server"] = "map-server"

                            self.other_xtr_probe = Native.Router.LispList.InstanceContainer.InstanceList.Default.OtherXtrProbe()
                            self.other_xtr_probe.parent = self
                            self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                            self.remote_rloc_probe = Native.Router.LispList.InstanceContainer.InstanceList.Default.RemoteRlocProbe()
                            self.remote_rloc_probe.parent = self
                            self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                            self.service = None
                            self._children_name_map["service"] = "service"

                            self.dynamic_eid = YList(self)
                            self._segment_path = lambda: "default"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default, ['disable_ttl_propagate'], name, value)


                        class Decapsulation(Entity):
                            """
                            Decapsulation behavior (e.g. filters)
                            
                            .. attribute:: filter
                            
                            	Filters traffic
                            	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation, self).__init__()

                                self.yang_name = "decapsulation"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("filter", ("filter", Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter))])
                                self._leafs = OrderedDict()

                                self.filter = Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter()
                                self.filter.parent = self
                                self._children_name_map["filter"] = "filter"
                                self._segment_path = lambda: "decapsulation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation, [], name, value)


                            class Filter(Entity):
                                """
                                Filters traffic
                                
                                .. attribute:: rloc
                                
                                	Filter based on Routing Locator (RLOC) in packet header
                                	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter, self).__init__()

                                    self.yang_name = "filter"
                                    self.yang_parent_name = "decapsulation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc))])
                                    self._leafs = OrderedDict()

                                    self.rloc = Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc()
                                    self.rloc.parent = self
                                    self._children_name_map["rloc"] = "rloc"
                                    self._segment_path = lambda: "filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter, [], name, value)


                                class Rloc(Entity):
                                    """
                                    Filter based on Routing Locator (RLOC) in packet header
                                    
                                    .. attribute:: source
                                    
                                    	Filters traffic based on RLOC source address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc, self).__init__()

                                        self.yang_name = "rloc"
                                        self.yang_parent_name = "filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "rloc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc, [], name, value)


                                    class Source(Entity):
                                        """
                                        Filters traffic based on RLOC source address
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator\-set Name
                                        	**type**\: str
                                        
                                        .. attribute:: member
                                        
                                        	Members learned from map\-server
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "rloc"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.member = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                        class DynamicEid(Entity):
                            """
                            Configure a dynamic EID
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: database_mapping
                            
                            	Configures EID\-prefix and locator\-set for dynamic\-EID
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping>`
                            
                            .. attribute:: eid_notify
                            
                            	Configure options for sending/receiving EID\-notify
                            	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify>`
                            
                            .. attribute:: map_notify_group
                            
                            	Multicast group which to send map\-notifies to
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid, self).__init__()

                                self.yang_name = "dynamic-eid"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                                ])
                                self.name = None
                                self.map_notify_group = None

                                self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.eid_notify = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify()
                                self.eid_notify.parent = self
                                self._children_name_map["eid_notify"] = "eid-notify"

                                self.map_server = YList(self)
                                self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid, ['name', 'map_notify_group'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures EID\-prefix and locator\-set for dynamic\-EID
                                
                                .. attribute:: ipv4_prefix
                                
                                	IPv4 EID\-prefix for dynamic\-EID
                                	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping.Ipv4Prefix>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping.Ipv4Prefix))])
                                    self._leafs = OrderedDict()

                                    self.ipv4_prefix = YList(self)
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping, [], name, value)


                                class Ipv4Prefix(Entity):
                                    """
                                    IPv4 EID\-prefix for dynamic\-EID
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    .. attribute:: locator_set
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping.Ipv4Prefix, self).__init__()

                                        self.yang_name = "ipv4-prefix"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.eid_prefix = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "ipv4-prefix" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.DatabaseMapping.Ipv4Prefix, ['eid_prefix', 'locator_set'], name, value)


                            class EidNotify(Entity):
                                """
                                Configure options for sending/receiving EID\-notify
                                
                                .. attribute:: authentication_key
                                
                                	Authentication key used for validating received EID\-notify
                                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.AuthenticationKey>`
                                
                                .. attribute:: gateway_key
                                
                                	
                                	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify, self).__init__()

                                    self.yang_name = "eid-notify"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey))])
                                    self._leafs = OrderedDict()

                                    self.authentication_key = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.AuthenticationKey()
                                    self.authentication_key.parent = self
                                    self._children_name_map["authentication_key"] = "authentication-key"

                                    self.gateway_key = YList(self)
                                    self._segment_path = lambda: "eid-notify"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify, [], name, value)


                                class AuthenticationKey(Entity):
                                    """
                                    Authentication key used for validating received EID\-notify
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: key_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                        self.yang_name = "authentication-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.key_0 = None
                                        self.key_6 = None
                                        self.key_7 = None
                                        self._segment_path = lambda: "authentication-key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                                class GatewayKey(Entity):
                                    """
                                    
                                    
                                    .. attribute:: gateway_ip  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                        self.yang_name = "gateway-key"
                                        self.yang_parent_name = "eid-notify"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['gateway_ip']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key))])
                                        self._leafs = OrderedDict([
                                            ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                        ])
                                        self.gateway_ip = None

                                        self.key = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey, ['gateway_ip'], name, value)


                                    class Key(Entity):
                                        """
                                        
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "gateway-key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction')])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, ['unc_pwd', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction')])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key0, ['ak_0', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction')])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.EidNotify.GatewayKey.Key.Key6, ['ak_6', 'hash_function'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "dynamic-eid"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6>`
                                    
                                    .. attribute:: key_7
                                    
                                    	
                                    	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"

                                        self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7()
                                        self.key_7.parent = self
                                        self._children_name_map["key_7"] = "key-7"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key7(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_7
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7.HashFunction>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7, self).__init__()

                                            self.yang_name = "key-7"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7.HashFunction')])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ak_7 = None
                                            self.hash_function = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "key-7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.DynamicEid.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                        class LocReachAlgorithm(Entity):
                            """
                            Configure locator reachability algorithm
                            
                            .. attribute:: lsb_reports
                            
                            	Configure data packet LSB report handling
                            	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.LocReachAlgorithm.LsbReports>`
                            
                            .. attribute:: rloc_probing
                            
                            	Probe high priority RLOCs with Map\-Requests as last resort
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.LocReachAlgorithm, self).__init__()

                                self.yang_name = "loc-reach-algorithm"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.LispList.InstanceContainer.InstanceList.Default.LocReachAlgorithm.LsbReports))])
                                self._leafs = OrderedDict([
                                    ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                                ])
                                self.rloc_probing = None

                                self.lsb_reports = Native.Router.LispList.InstanceContainer.InstanceList.Default.LocReachAlgorithm.LsbReports()
                                self.lsb_reports.parent = self
                                self._children_name_map["lsb_reports"] = "lsb-reports"
                                self._segment_path = lambda: "loc-reach-algorithm"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.LocReachAlgorithm, ['rloc_probing'], name, value)


                            class LsbReports(Entity):
                                """
                                Configure data packet LSB report handling
                                
                                .. attribute:: do_not_transmit
                                
                                	Force the setting of the encapsulation header L bit to zero
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ignore
                                
                                	Ignore data packet LSB reports
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.LocReachAlgorithm.LsbReports, self).__init__()

                                    self.yang_name = "lsb-reports"
                                    self.yang_parent_name = "loc-reach-algorithm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ])
                                    self.do_not_transmit = None
                                    self.ignore = None
                                    self._segment_path = lambda: "lsb-reports"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                        class MapServer(Entity):
                            """
                            Map\-Server commands
                            
                            .. attribute:: rloc
                            
                            	EID instance RLOC membership
                            	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc>`
                            
                            .. attribute:: site_registration
                            
                            	Map\-server site registration options
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.SiteRegistration>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.SiteRegistration))])
                                self._leafs = OrderedDict()

                                self.rloc = Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc()
                                self.rloc.parent = self
                                self._children_name_map["rloc"] = "rloc"

                                self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer, [], name, value)


                            class Rloc(Entity):
                                """
                                EID instance RLOC membership
                                
                                .. attribute:: members
                                
                                	EID instance RLOC membership
                                	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc, self).__init__()

                                    self.yang_name = "rloc"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("members", ("members", Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members))])
                                    self._leafs = OrderedDict()

                                    self.members = Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members()
                                    self.members.parent = self
                                    self._children_name_map["members"] = "members"
                                    self._segment_path = lambda: "rloc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc, [], name, value)


                                class Members(Entity):
                                    """
                                    EID instance RLOC membership
                                    
                                    .. attribute:: distribute
                                    
                                    	EID instance RLOC membership distribution
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: modify_discovered
                                    
                                    	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                    	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members, self).__init__()

                                        self.yang_name = "members"
                                        self.yang_parent_name = "rloc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered))])
                                        self._leafs = OrderedDict([
                                            ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                        ])
                                        self.distribute = None

                                        self.modify_discovered = Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered()
                                        self.modify_discovered.parent = self
                                        self._children_name_map["modify_discovered"] = "modify-discovered"
                                        self._segment_path = lambda: "members"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members, ['distribute'], name, value)


                                    class ModifyDiscovered(Entity):
                                        """
                                        Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                        
                                        .. attribute:: operator
                                        
                                        	
                                        	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set from which to get member RLOC addresses
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                            self.yang_name = "modify-discovered"
                                            self.yang_parent_name = "members"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.operator = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "modify-discovered"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                        class Operator(Enum):
                                            """
                                            Operator (Enum Class)

                                            .. data:: add = 0

                                            .. data:: override = 1

                                            """

                                            add = Enum.YLeaf(0, "add")

                                            override = Enum.YLeaf(1, "override")



                            class SiteRegistration(Entity):
                                """
                                Map\-server site registration options
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations as a result of accept\-more\-specifics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class OtherXtrProbe(Entity):
                            """
                            Configure parameters for probing of other xTRs in our site
                            
                            .. attribute:: period
                            
                            	Period between probes in seconds
                            	**type**\: int
                            
                            	**range:** 5..900
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.OtherXtrProbe, self).__init__()

                                self.yang_name = "other-xtr-probe"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                ])
                                self.period = None
                                self._segment_path = lambda: "other-xtr-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.OtherXtrProbe, ['period'], name, value)


                        class RemoteRlocProbe(Entity):
                            """
                            Configure parameters for probing of remote RLOCs
                            
                            .. attribute:: on_membership_change
                            
                            	Trigger probing upon membership changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: on_route_change
                            
                            	Trigger probing upon routing changes for remote RLOC
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.RemoteRlocProbe, self).__init__()

                                self.yang_name = "remote-rloc-probe"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                    ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                                ])
                                self.on_membership_change = None
                                self.on_route_change = None
                                self._segment_path = lambda: "remote-rloc-probe"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                        class Service(Entity):
                            """
                            Configure lisp service type
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ipv6
                            
                            	
                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ethernet
                            
                            	
                            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service, self).__init__()

                                self.yang_name = "service"
                                self.yang_parent_name = "default"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.ipv4 = None
                                self._children_name_map["ipv4"] = "ipv4"

                                self.ipv6 = None
                                self._children_name_map["ipv6"] = "ipv6"

                                self.ethernet = None
                                self._children_name_map["ethernet"] = "ethernet"
                                self._segment_path = lambda: "service"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service, [], name, value)


                            class Ipv4(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_)), ("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.EidTable)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt)), ("distance", ("distance", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import)), ("route-import", ("route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.default = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "ipv4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EidTable)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt)), ("distance", ("distance", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr)), ("import", ("import_", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import)), ("route-import", ("route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping))])
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.rip = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip()
                                                self.rip.parent = self
                                                self._children_name_map["rip"] = "rip"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Ipv6(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_)), ("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.EidTable)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt)), ("distance", ("distance", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import)), ("route-import", ("route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.default = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "ipv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EidTable>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: alt
                                    
                                    	LISP Alternative Topology, LISP\-ALT
                                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt>`
                                    
                                    .. attribute:: alt_vrf
                                    
                                    	Activate LISP\-ALT functionality in VRF
                                    	**type**\: str
                                    
                                    	**status**\: deprecated
                                    
                                    .. attribute:: distance
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Distance>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Address family specific map cache configuration
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache>`
                                    
                                    .. attribute:: map_cache_persistent
                                    
                                    	Dump map\-cache onto flash, making it persistent across reboots
                                    	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCachePersistent>`
                                    
                                    .. attribute:: proxy_etr
                                    
                                    	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: proxy_itr
                                    
                                    	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ProxyItr>`
                                    
                                    .. attribute:: route_export
                                    
                                    	Export routes into RIB from LISP
                                    	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteExport>`
                                    
                                    .. attribute:: sgt
                                    
                                    	Enable security group tag propagation in LISP encapsulated traffic
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: use_petr
                                    
                                    	Encapsulate to Proxy ETR when matching forward\-native entry
                                    	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr>`
                                    
                                    .. attribute:: import_
                                    
                                    	Redistribute LISP states internally
                                    	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import>`
                                    
                                    .. attribute:: route_import
                                    
                                    	Import RIB routes by a routing protocol into LISP
                                    	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EidTable)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt)), ("distance", ("distance", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr)), ("import", ("import_", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import)), ("route-import", ("route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping))])
                                        self._leafs = OrderedDict([
                                            ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                            ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                            ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                        ])
                                        self.alt_vrf = None
                                        self.proxy_etr = None
                                        self.sgt = None
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.alt = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt()
                                        self.alt.parent = self
                                        self._children_name_map["alt"] = "alt"

                                        self.distance = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.map_cache_persistent = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCachePersistent()
                                        self.map_cache_persistent.parent = self
                                        self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                        self.proxy_itr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ProxyItr()
                                        self.proxy_itr.parent = self
                                        self._children_name_map["proxy_itr"] = "proxy-itr"

                                        self.route_export = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteExport()
                                        self.route_export.parent = self
                                        self._children_name_map["route_export"] = "route-export"

                                        self.import_ = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import()
                                        self.import_.parent = self
                                        self._children_name_map["import_"] = "import"

                                        self.route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport()
                                        self.route_import.parent = self
                                        self._children_name_map["route_import"] = "route-import"

                                        self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.use_petr = YList(self)
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vrf_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vrf
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.vrf_name = None
                                            self.default = None
                                            self.vrf = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class Alt(Entity):
                                        """
                                        LISP Alternative Topology, LISP\-ALT
                                        
                                        .. attribute:: summary_route
                                        
                                        	Summary route to install into the ALT table
                                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt.SummaryRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt, self).__init__()

                                            self.yang_name = "alt"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt.SummaryRoute))])
                                            self._leafs = OrderedDict()

                                            self.summary_route = YList(self)
                                            self._segment_path = lambda: "alt"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt, [], name, value)


                                        class SummaryRoute(Entity):
                                            """
                                            Summary route to install into the ALT table
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: route_tag
                                            
                                            	ALT RIB route tag for EID prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt.SummaryRoute, self).__init__()

                                                self.yang_name = "summary-route"
                                                self.yang_parent_name = "alt"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                                ])
                                                self.eid_prefix = None
                                                self.route_tag = None
                                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                    class Distance(Entity):
                                        """
                                        Administrative distance for RIB route installation
                                        
                                        .. attribute:: alt
                                        
                                        	LISP routes installed in the ALT table
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: away
                                        
                                        	Administrative distance for RIB route installation
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: dyn_eid
                                        
                                        	LISP installed routes of type dynamic\-EID
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: site_registrations
                                        
                                        	LISP installed routes of type site\-registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                                ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                                ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                                ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                            ])
                                            self.alt = None
                                            self.away = None
                                            self.dyn_eid = None
                                            self.site_registrations = None
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Address family specific map cache configuration
                                        
                                        .. attribute:: eid_interface
                                        
                                        	Configures static EID\-to\-RLOC mappings for an ITR
                                        	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Map cache configuration for the away table
                                        	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.AwayEids>`
                                        
                                        .. attribute:: site_registration
                                        
                                        	Install map cache to map request for site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.AwayEids))])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.site_registration = None

                                            self.away_eids = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.AwayEids()
                                            self.away_eids.parent = self
                                            self._children_name_map["away_eids"] = "away-eids"

                                            self.eid_interface = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache, ['site_registration'], name, value)


                                        class EidInterface(Entity):
                                            """
                                            Configures static EID\-to\-RLOC mappings for an ITR
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp>`
                                            
                                            .. attribute:: drop
                                            
                                            	Drop packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: map_request
                                            
                                            	Send Map\-Request for LISP destination EID
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: native_forward
                                            
                                            	Natively forward packets that match this map\-cache entry
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface, self).__init__()

                                                self.yang_name = "eid-interface"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                    ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                    ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                    ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.drop = None
                                                self.map_request = None
                                                self.native_forward = None

                                                self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                        class AwayEids(Entity):
                                            """
                                            Map cache configuration for the away table
                                            
                                            .. attribute:: send_map_request
                                            
                                            	Export away table entries into the map cache with action set to send\-map\-request
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.AwayEids, self).__init__()

                                                self.yang_name = "away-eids"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                                ])
                                                self.send_map_request = None
                                                self._segment_path = lambda: "away-eids"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCache.AwayEids, ['send_map_request'], name, value)


                                    class MapCachePersistent(Entity):
                                        """
                                        Dump map\-cache onto flash, making it persistent across reboots
                                        
                                        .. attribute:: interval
                                        
                                        	Interval in minutes of how often the map\-cache is saved
                                        	**type**\: int
                                        
                                        	**range:** 1..1440
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCachePersistent, self).__init__()

                                            self.yang_name = "map-cache-persistent"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                            ])
                                            self.interval = None
                                            self._segment_path = lambda: "map-cache-persistent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.MapCachePersistent, ['interval'], name, value)


                                    class ProxyItr(Entity):
                                        """
                                        Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                        
                                        .. attribute:: ipv4_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_addr
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ProxyItr, self).__init__()

                                            self.yang_name = "proxy-itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                                ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                            ])
                                            self.ipv4_addr = None
                                            self.ipv6_addr = None
                                            self._segment_path = lambda: "proxy-itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                    class RouteExport(Entity):
                                        """
                                        Export routes into RIB from LISP
                                        
                                        .. attribute:: site_registrations
                                        
                                        	Export LISP site registrations to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: away_eids
                                        
                                        	Export LISP away EIDs to RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteExport, self).__init__()

                                            self.yang_name = "route-export"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                                ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                            ])
                                            self.site_registrations = None
                                            self.away_eids = None
                                            self._segment_path = lambda: "route-export"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                    class UsePetr(Entity):
                                        """
                                        Encapsulate to Proxy ETR when matching forward\-native entry
                                        
                                        .. attribute:: locator_address  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	
                                        	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr.Priority>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr, self).__init__()

                                            self.yang_name = "use-petr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['locator_address']
                                            self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr.Priority))])
                                            self._leafs = OrderedDict([
                                                ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                            ])
                                            self.locator_address = None

                                            self.priority = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr.Priority()
                                            self.priority.parent = self
                                            self._children_name_map["priority"] = "priority"
                                            self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr, ['locator_address'], name, value)


                                        class Priority(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority_value
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr.Priority, self).__init__()

                                                self.yang_name = "priority"
                                                self.yang_parent_name = "use-petr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.priority_value = None
                                                self.weight = None
                                                self._segment_path = lambda: "priority"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                    class Import(Entity):
                                        """
                                        Redistribute LISP states internally
                                        
                                        .. attribute:: database
                                        
                                        	Redistribute LISP internal states as database mapping
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.Database>`
                                        
                                        .. attribute:: prefix_list_container
                                        
                                        	Redistribute LISP internal states into LISP prefix\-list entries
                                        	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.PrefixListContainer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import, self).__init__()

                                            self.yang_name = "import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.PrefixListContainer))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.prefix_list_container = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.PrefixListContainer()
                                            self.prefix_list_container.parent = self
                                            self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                            self._segment_path = lambda: "import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import, [], name, value)


                                        class Database(Entity):
                                            """
                                            Redistribute LISP internal states as database mapping
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.site_registration = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.Database, ['site_registration', 'locator_set'], name, value)


                                        class PrefixListContainer(Entity):
                                            """
                                            Redistribute LISP internal states into LISP prefix\-list entries
                                            
                                            .. attribute:: prefix_list
                                            
                                            	The name of the lisp prefix list
                                            	**type**\: str
                                            
                                            .. attribute:: site_registration
                                            
                                            	Import states from site registrations
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.PrefixListContainer, self).__init__()

                                                self.yang_name = "prefix-list-container"
                                                self.yang_parent_name = "import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ])
                                                self.prefix_list = None
                                                self.site_registration = None
                                                self._segment_path = lambda: "prefix-list-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                    class RouteImport(Entity):
                                        """
                                        Import RIB routes by a routing protocol into LISP
                                        
                                        .. attribute:: database
                                        
                                        	Use RIB routes to define local EID database entries
                                        	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database>`
                                        
                                        .. attribute:: map_cache
                                        
                                        	Use RIB routes to define EID address space in map\-cache
                                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache>`
                                        
                                        .. attribute:: prefix_list_proto
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport, self).__init__()

                                            self.yang_name = "route-import"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto))])
                                            self._leafs = OrderedDict()

                                            self.database = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database()
                                            self.database.parent = self
                                            self._children_name_map["database"] = "database"

                                            self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache()
                                            self.map_cache.parent = self
                                            self._children_name_map["map_cache"] = "map-cache"

                                            self.prefix_list_proto = YList(self)
                                            self._segment_path = lambda: "route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport, [], name, value)


                                        class Database(Entity):
                                            """
                                            Use RIB routes to define local EID database entries
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application>`
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected>`
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbor Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd>`
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static>`
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database, self).__init__()

                                                self.yang_name = "database"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application()
                                                self.application.parent = self
                                                self._children_name_map["application"] = "application"

                                                self.connected = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected()
                                                self.connected.parent = self
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd()
                                                self.nd.parent = self
                                                self._children_name_map["nd"] = "nd"

                                                self.static = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static()
                                                self.static.parent = self
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "database"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: process_id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                    ])
                                                    self.process_id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis, ['process_id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbor Discovery
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport))])
                                                    self._leafs = OrderedDict()

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static, [], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: lisp_ip_route_import
                                                
                                                	
                                                	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "database"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport()
                                                    self.lisp_ip_route_import.parent = self
                                                    self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip, ['id'], name, value)


                                                class LispIpRouteImport(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    .. attribute:: locator_set
                                                    
                                                    	Locator set to use with created database mapping entries
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                        self.yang_name = "lisp-ip-route-import"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self.locator_set = None
                                                        self._segment_path = lambda: "lisp-ip-route-import"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MapCache(Entity):
                                            """
                                            Use RIB routes to define EID address space in map\-cache
                                            
                                            .. attribute:: application
                                            
                                            	Application Protocol
                                            	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: bgp
                                            
                                            	Border Gateway Protocol (BGP)
                                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp>`
                                            
                                            .. attribute:: connected
                                            
                                            	Connected
                                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: eigrp
                                            
                                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp>`
                                            
                                            .. attribute:: isis
                                            
                                            	ISO IS\-IS
                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes to pick up from the RIB
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix>`
                                            
                                            .. attribute:: nd
                                            
                                            	Neighbour Discovery
                                            	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ospf
                                            
                                            	Open Shortest Path First (OSPF)
                                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf>`
                                            
                                            .. attribute:: static
                                            
                                            	Static routes
                                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: rip
                                            
                                            	Routing Information Protocol (RIP)
                                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache, self).__init__()

                                                self.yang_name = "map-cache"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip))])
                                                self._leafs = OrderedDict()

                                                self.application = None
                                                self._children_name_map["application"] = "application"

                                                self.connected = None
                                                self._children_name_map["connected"] = "connected"

                                                self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis()
                                                self.isis.parent = self
                                                self._children_name_map["isis"] = "isis"

                                                self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.nd = None
                                                self._children_name_map["nd"] = "nd"

                                                self.static = None
                                                self._children_name_map["static"] = "static"

                                                self.bgp = YList(self)
                                                self.eigrp = YList(self)
                                                self.ospf = YList(self)
                                                self.rip = YList(self)
                                                self._segment_path = lambda: "map-cache"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache, [], name, value)


                                            class Application(Entity):
                                                """
                                                Application Protocol
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application, self).__init__()

                                                    self.yang_name = "application"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "application"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "application"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                            class Bgp(Entity):
                                                """
                                                Border Gateway Protocol (BGP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, self).__init__()

                                                    self.yang_name = "bgp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "bgp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                            class Connected(Entity):
                                                """
                                                Connected
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected, self).__init__()

                                                    self.yang_name = "connected"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "connected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "connected"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                            class Eigrp(Entity):
                                                """
                                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, self).__init__()

                                                    self.yang_name = "eigrp"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "eigrp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                            class Isis(Entity):
                                                """
                                                ISO IS\-IS
                                                
                                                .. attribute:: id
                                                
                                                	Process name
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis, self).__init__()

                                                    self.yang_name = "isis"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "isis"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "isis"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes to pick up from the RIB
                                                
                                                .. attribute:: number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: threshold1
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: warning_only1
                                                
                                                	Only give a warning message and do not limit entries
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                        ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                    ])
                                                    self.number = None
                                                    self.warning_only = None
                                                    self.threshold = None
                                                    self.threshold1 = None
                                                    self.warning_only1 = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                            class Nd(Entity):
                                                """
                                                Neighbour Discovery
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd, self).__init__()

                                                    self.yang_name = "nd"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "nd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "nd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                            class Ospf(Entity):
                                                """
                                                Open Shortest Path First (OSPF)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, self).__init__()

                                                    self.yang_name = "ospf"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "ospf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                            class Static(Entity):
                                                """
                                                Static routes
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static, self).__init__()

                                                    self.yang_name = "static"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "static"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static, [], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "static"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                            class Rip(Entity):
                                                """
                                                Routing Information Protocol (RIP)
                                                
                                                .. attribute:: id  (key)
                                                
                                                	User selected string identifying this process
                                                	**type**\: str
                                                
                                                .. attribute:: map_cache_container
                                                
                                                	
                                                	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip, self).__init__()

                                                    self.yang_name = "rip"
                                                    self.yang_parent_name = "map-cache"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['id']
                                                    self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                    self._leafs = OrderedDict([
                                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ])
                                                    self.id = None

                                                    self.map_cache_container = None
                                                    self._children_name_map["map_cache_container"] = "map-cache-container"
                                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip, ['id'], name, value)


                                                class MapCacheContainer(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map for route selection filtering
                                                    	**type**\: str
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                        self.yang_name = "map-cache-container"
                                                        self.yang_parent_name = "rip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.route_map = None
                                                        self._segment_path = lambda: "map-cache-container"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                        class PrefixListProto(Entity):
                                            """
                                            
                                            
                                            .. attribute:: prefix_list  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: protocol  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol>`
                                            
                                            .. attribute:: bgp_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId>`
                                            
                                            .. attribute:: eigrp_or_ospf_id
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                            
                                            .. attribute:: isis_id
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto, self).__init__()

                                                self.yang_name = "prefix-list-proto"
                                                self.yang_parent_name = "route-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['prefix_list','protocol']
                                                self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.Protocol')])),
                                                    ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.prefix_list = None
                                                self.protocol = None
                                                self.isis_id = None
                                                self.number = None
                                                self.threshold = None
                                                self.warning_only = None
                                                self.route_map = None

                                                self.bgp_id = YList(self)
                                                self.eigrp_or_ospf_id = YList(self)
                                                self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                            class Protocol(Enum):
                                                """
                                                Protocol (Enum Class)

                                                .. data:: application = 0

                                                .. data:: bgp = 1

                                                .. data:: connected = 2

                                                .. data:: eigrp = 3

                                                .. data:: isis = 4

                                                .. data:: maximum_prefix = 5

                                                .. data:: nd = 6

                                                .. data:: ospf = 7

                                                .. data:: static = 8

                                                .. data:: rip = 9

                                                """

                                                application = Enum.YLeaf(0, "application")

                                                bgp = Enum.YLeaf(1, "bgp")

                                                connected = Enum.YLeaf(2, "connected")

                                                eigrp = Enum.YLeaf(3, "eigrp")

                                                isis = Enum.YLeaf(4, "isis")

                                                maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                                nd = Enum.YLeaf(6, "nd")

                                                ospf = Enum.YLeaf(7, "ospf")

                                                static = Enum.YLeaf(8, "static")

                                                rip = Enum.YLeaf(9, "rip")



                                            class BgpId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: bgp_id  (key)
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..4294967295
                                                
                                                		**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                    self.yang_name = "bgp-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['bgp_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.bgp_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                            class EigrpOrOspfId(Entity):
                                                """
                                                
                                                
                                                .. attribute:: int16_id  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: route_map
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                    self.yang_name = "eigrp-or-ospf-id"
                                                    self.yang_parent_name = "prefix-list-proto"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['int16_id']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.int16_id = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            .. attribute:: auto_discover_rlocs
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                    ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                                ])
                                                self.eid_prefix = None
                                                self.auto_discover_rlocs = None

                                                self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Ethernet(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	
                                	**type**\:  :py:class:`Default_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_>`
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.EidTable>`
                                
                                .. attribute:: broadcast_underlay
                                
                                	Multicast group to use for underlay
                                	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.BroadcastUnderlay>`
                                
                                .. attribute:: flood
                                
                                	Control flooding or local intercept of broadcast frames
                                	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Flood>`
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.SolicitMapRequest>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "service"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_)), ("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.BroadcastUnderlay)), ("flood", ("flood", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Flood)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                    ])
                                    self.map_request_source = None

                                    self.default = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.broadcast_underlay = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.BroadcastUnderlay()
                                    self.broadcast_underlay.parent = self
                                    self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                    self.flood = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Flood()
                                    self.flood.parent = self
                                    self._children_name_map["flood"] = "flood"

                                    self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"
                                    self._segment_path = lambda: "ethernet"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet, ['map_request_source'], name, value)


                                class Default_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_table
                                    
                                    	Bind an eid\-table
                                    	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EidTable>`
                                    
                                    .. attribute:: broadcast_underlay
                                    
                                    	Multicast group to use for underlay
                                    	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.BroadcastUnderlay>`
                                    
                                    .. attribute:: flood
                                    
                                    	Control flooding or local intercept of broadcast frames
                                    	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Flood>`
                                    
                                    .. attribute:: database_mapping
                                    
                                    	Configures Locator addresses for an ETR
                                    	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping>`
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr>`
                                    
                                    .. attribute:: itr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.ItrEnable>`
                                    
                                    .. attribute:: etr_enable
                                    
                                    	
                                    	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EtrEnable>`
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr>`
                                    
                                    .. attribute:: map_cache_limit
                                    
                                    	Configures maximum size of map\-cache
                                    	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCacheLimit>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Site registrations configuration for a given instance\-id
                                    	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SiteRegistration>`
                                    
                                    .. attribute:: solicit_map_request
                                    
                                    	Configure Solicit\-Map\-Request handling
                                    	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SolicitMapRequest>`
                                    
                                    .. attribute:: map_request_source
                                    
                                    	Configures inner header source address in Map\-Request message
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.BroadcastUnderlay)), ("flood", ("flood", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Flood)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache))])
                                        self._leafs = OrderedDict([
                                            ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                        ])
                                        self.map_request_source = None

                                        self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EidTable()
                                        self.eid_table.parent = self
                                        self._children_name_map["eid_table"] = "eid-table"

                                        self.broadcast_underlay = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.BroadcastUnderlay()
                                        self.broadcast_underlay.parent = self
                                        self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                        self.flood = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Flood()
                                        self.flood.parent = self
                                        self._children_name_map["flood"] = "flood"

                                        self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping()
                                        self.database_mapping.parent = self
                                        self._children_name_map["database_mapping"] = "database-mapping"

                                        self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr()
                                        self.itr.parent = self
                                        self._children_name_map["itr"] = "itr"

                                        self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.ItrEnable()
                                        self.itr_enable.parent = self
                                        self._children_name_map["itr_enable"] = "itr-enable"

                                        self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EtrEnable()
                                        self.etr_enable.parent = self
                                        self._children_name_map["etr_enable"] = "etr-enable"

                                        self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr()
                                        self.etr.parent = self
                                        self._children_name_map["etr"] = "etr"

                                        self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCacheLimit()
                                        self.map_cache_limit.parent = self
                                        self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                        self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SiteRegistration()
                                        self.site_registration.parent = self
                                        self._children_name_map["site_registration"] = "site-registration"

                                        self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SolicitMapRequest()
                                        self.solicit_map_request.parent = self
                                        self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                        self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_, ['map_request_source'], name, value)


                                    class EidTable(Entity):
                                        """
                                        Bind an eid\-table
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN configuration
                                        	**type**\: int
                                        
                                        	**range:** 1..4094
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EidTable, self).__init__()

                                            self.yang_name = "eid-table"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                            ])
                                            self.vlan = None
                                            self._segment_path = lambda: "eid-table"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EidTable, ['vlan'], name, value)


                                    class BroadcastUnderlay(Entity):
                                        """
                                        Multicast group to use for underlay
                                        
                                        .. attribute:: ipv4_multicast
                                        
                                        	IPv4 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_multicast
                                        
                                        	IPv6 multicast group address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.BroadcastUnderlay, self).__init__()

                                            self.yang_name = "broadcast-underlay"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                                ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                            ])
                                            self.ipv4_multicast = None
                                            self.ipv6_multicast = None
                                            self._segment_path = lambda: "broadcast-underlay"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                    class Flood(Entity):
                                        """
                                        Control flooding or local intercept of broadcast frames
                                        
                                        .. attribute:: arp_nd
                                        
                                        	IPv4 ARP / IPv6 ND
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Frames with unknown destination MAC
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Flood, self).__init__()

                                            self.yang_name = "flood"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                                ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                            ])
                                            self.arp_nd = None
                                            self.unknown_unicast = None
                                            self._segment_path = lambda: "flood"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                    class DatabaseMapping(Entity):
                                        """
                                        Configures Locator addresses for an ETR
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont>`
                                        
                                        .. attribute:: mac
                                        
                                        	L2 EID records
                                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Mac>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: limit
                                        
                                        	Configures the maximum size of local EID prefixes database
                                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping, self).__init__()

                                            self.yang_name = "database-mapping"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit))])
                                            self._leafs = OrderedDict()

                                            self.mac = None
                                            self._children_name_map["mac"] = "mac"

                                            self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit()
                                            self.limit.parent = self
                                            self._children_name_map["limit"] = "limit"

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "database-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: locator_set_container
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer>`
                                            
                                            .. attribute:: ipv4_addrees
                                            
                                            	IPv4 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees>`
                                            
                                            .. attribute:: ipv6_addrees
                                            
                                            	IPv6 Address of loopback or other ETR interface
                                            	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees>`
                                            
                                            .. attribute:: ipv4_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface>`
                                            
                                            .. attribute:: ipv6_interface
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer()
                                                self.locator_set_container.parent = self
                                                self._children_name_map["locator_set_container"] = "locator-set-container"

                                                self.ipv4_addrees = YList(self)
                                                self.ipv6_addrees = YList(self)
                                                self.ipv4_interface = YList(self)
                                                self.ipv6_interface = YList(self)
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                            class LocatorSetContainer(Entity):
                                                """
                                                Use locators defined by locator\-set
                                                
                                                .. attribute:: locator_set
                                                
                                                	Use locators defined by locator\-set
                                                	**type**\: str
                                                
                                                .. attribute:: proxy
                                                
                                                	Enable configuration of static proxy database mapping
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                    self.yang_name = "locator-set-container"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                        ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                    ])
                                                    self.locator_set = None
                                                    self.proxy = None
                                                    self._segment_path = lambda: "locator-set-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                            class Ipv4Addrees(Entity):
                                                """
                                                IPv4 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                    self.yang_name = "ipv4-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv4-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class Ipv6Addrees(Entity):
                                                """
                                                IPv6 Address of loopback or other ETR interface
                                                
                                                .. attribute:: address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                    self.yang_name = "ipv6-addrees"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ])
                                                    self.address = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "ipv6-addrees"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv4Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                    self.yang_name = "IPv4-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv4-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                            class IPv6Interface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	Use IPv4 address of interface as locator
                                                	**type**\: str
                                                
                                                .. attribute:: database_mapping_option
                                                
                                                	
                                                	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                    self.yang_name = "IPv6-interface"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ])
                                                    self.name = None

                                                    self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                    self.database_mapping_option.parent = self
                                                    self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                    self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                                class DatabaseMappingOption(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Configures which Locators from a set are preferred
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Traffic load\-spreading among Locators
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..100
                                                    
                                                    .. attribute:: down
                                                    
                                                    	Configure this database mapping down
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                        self.yang_name = "database-mapping-option"
                                                        self.yang_parent_name = "IPv6-interface"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                        ])
                                                        self.priority = None
                                                        self.weight = None
                                                        self.down = None
                                                        self._segment_path = lambda: "database-mapping-option"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Mac(Entity):
                                            """
                                            L2 EID records
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Mac, self).__init__()

                                                self.yang_name = "mac"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.locator_set = None
                                                self._segment_path = lambda: "mac"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Mac, ['locator_set'], name, value)


                                        class Limit(Entity):
                                            """
                                            Configures the maximum size of local EID prefixes database
                                            
                                            .. attribute:: dynamic
                                            
                                            	Configures the maximum size of dynamic local EID prefixes database
                                            	**type**\: int
                                            
                                            	**range:** 1..5000
                                            
                                            .. attribute:: warning_threshold
                                            
                                            	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit, self).__init__()

                                                self.yang_name = "limit"
                                                self.yang_parent_name = "database-mapping"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                                ])
                                                self.dynamic = None
                                                self.warning_threshold = None
                                                self._segment_path = lambda: "limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                    class Itr(Entity):
                                        """
                                        Configures a LISP Ingress Tunnel Router (ITR)
                                        
                                        .. attribute:: map_resolver
                                        
                                        	Configures map\-resolver address for sending Map\-Requests
                                        	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr.MapResolver>`
                                        
                                        .. attribute:: nmr_ttl
                                        
                                        	verride negative map\-reply TTL for site EID
                                        	**type**\: int
                                        
                                        	**range:** 1..900
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr, self).__init__()

                                            self.yang_name = "itr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr.MapResolver))])
                                            self._leafs = OrderedDict([
                                                ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                            ])
                                            self.nmr_ttl = None

                                            self.map_resolver = YList(self)
                                            self._segment_path = lambda: "itr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr, ['nmr_ttl'], name, value)


                                        class MapResolver(Entity):
                                            """
                                            Configures map\-resolver address for sending Map\-Requests
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr.MapResolver, self).__init__()

                                                self.yang_name = "map-resolver"
                                                self.yang_parent_name = "itr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ip_addr = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                    class ItrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: itr
                                        
                                        	Configures a LISP Ingress Tunnel Router (ITR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.ItrEnable, self).__init__()

                                            self.yang_name = "itr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                            ])
                                            self.itr = None
                                            self._segment_path = lambda: "itr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.ItrEnable, ['itr'], name, value)


                                    class EtrEnable(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr
                                        
                                        	Configures a LISP Egress Tunnel Router (ETR)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EtrEnable, self).__init__()

                                            self.yang_name = "etr-enable"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                            ])
                                            self.etr = None
                                            self._segment_path = lambda: "etr-enable"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.EtrEnable, ['etr'], name, value)


                                    class Etr(Entity):
                                        """
                                        Configures a LISP Egress Tunnel Router (ETR)
                                        
                                        .. attribute:: map_server
                                        
                                        	Configures map server for ETR registration
                                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer>`
                                        
                                        .. attribute:: map_cache_ttl
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 60..10080
                                        
                                        .. attribute:: accept_map_request_mapping
                                        
                                        	
                                        	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr, self).__init__()

                                            self.yang_name = "etr"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping))])
                                            self._leafs = OrderedDict([
                                                ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                            ])
                                            self.map_cache_ttl = None

                                            self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping()
                                            self.accept_map_request_mapping.parent = self
                                            self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                            self.map_server = YList(self)
                                            self._segment_path = lambda: "etr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr, ['map_cache_ttl'], name, value)


                                        class MapServer(Entity):
                                            """
                                            Configures map server for ETR registration
                                            
                                            .. attribute:: ip_addr  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: key
                                            
                                            	Authentication key used with map server
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key>`
                                            
                                            .. attribute:: proxy_reply
                                            
                                            	Request Map\-Server to send Map\-Replies on behalf of site
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer, self).__init__()

                                                self.yang_name = "map-server"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['ip_addr']
                                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key))])
                                                self._leafs = OrderedDict([
                                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                                ])
                                                self.ip_addr = None
                                                self.proxy_reply = None

                                                self.key = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                            class Key(Entity):
                                                """
                                                Authentication key used with map server
                                                
                                                .. attribute:: key_pwd
                                                
                                                	
                                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd>`
                                                
                                                .. attribute:: key_0
                                                
                                                	
                                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0>`
                                                
                                                .. attribute:: key_6
                                                
                                                	
                                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6>`
                                                
                                                .. attribute:: key_7
                                                
                                                	
                                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "map-server"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7))])
                                                    self._leafs = OrderedDict()

                                                    self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd()
                                                    self.key_pwd.parent = self
                                                    self._children_name_map["key_pwd"] = "key-pwd"

                                                    self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0()
                                                    self.key_0.parent = self
                                                    self._children_name_map["key_0"] = "key-0"

                                                    self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6()
                                                    self.key_6.parent = self
                                                    self._children_name_map["key_6"] = "key-6"

                                                    self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7()
                                                    self.key_7.parent = self
                                                    self._children_name_map["key_7"] = "key-7"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key, [], name, value)


                                                class KeyPwd(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: unc_pwd
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                        self.yang_name = "key-pwd"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.unc_pwd = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-pwd"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key0(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_0
                                                    
                                                    	The UNENCRYPTED (cleartext) password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, self).__init__()

                                                        self.yang_name = "key-0"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_0 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-0"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key6(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_6
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, self).__init__()

                                                        self.yang_name = "key-6"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_6 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-6"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                                class Key7(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: ak_7
                                                    
                                                    	The ENCRYPTED password
                                                    	**type**\: str
                                                    
                                                    .. attribute:: hash_function
                                                    
                                                    	authentication type
                                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction>`
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Associates ITR/ETR with prefix list
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-lisp'
                                                    _revision = '2018-04-17'

                                                    def __init__(self):
                                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, self).__init__()

                                                        self.yang_name = "key-7"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7.HashFunction')])),
                                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                        ])
                                                        self.ak_7 = None
                                                        self.hash_function = None
                                                        self.prefix_list = None
                                                        self._segment_path = lambda: "key-7"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                    class HashFunction(Enum):
                                                        """
                                                        HashFunction (Enum Class)

                                                        authentication type

                                                        .. data:: sha1 = 0

                                                        .. data:: sha2 = 1

                                                        """

                                                        sha1 = Enum.YLeaf(0, "sha1")

                                                        sha2 = Enum.YLeaf(1, "sha2")



                                        class AcceptMapRequestMapping(Entity):
                                            """
                                            
                                            
                                            .. attribute:: accept_mappping
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: verify
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, self).__init__()

                                                self.yang_name = "accept-map-request-mapping"
                                                self.yang_parent_name = "etr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                    ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                                ])
                                                self.accept_mappping = None
                                                self.verify = None
                                                self._segment_path = lambda: "accept-map-request-mapping"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                    class MapCacheLimit(Entity):
                                        """
                                        Configures maximum size of map\-cache
                                        
                                        .. attribute:: max_map_cache_entries
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..100000
                                        
                                        .. attribute:: reserve_list
                                        
                                        	EID\-prefixes guaranteed to be stored in map\-cache
                                        	**type**\: str
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCacheLimit, self).__init__()

                                            self.yang_name = "map-cache-limit"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                                ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.max_map_cache_entries = None
                                            self.reserve_list = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "map-cache-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                    class SiteRegistration(Entity):
                                        """
                                        Site registrations configuration for a given instance\-id
                                        
                                        .. attribute:: limit
                                        
                                        	Maximum number of site registrations
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Warning threshold to issue system logging
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SiteRegistration, self).__init__()

                                            self.yang_name = "site-registration"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.limit = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "site-registration"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                    class SolicitMapRequest(Entity):
                                        """
                                        Configure Solicit\-Map\-Request handling
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore SMR bit in incoming Map\-Requests
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: max_per_entry
                                        
                                        	Maximum number of SMRs for addresses under a map\-cache entry
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: suppression_time
                                        
                                        	How long to suppress repeated SMRs for the same address
                                        	**type**\: int
                                        
                                        	**range:** 1..600
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SolicitMapRequest, self).__init__()

                                            self.yang_name = "solicit-map-request"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                                ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                            ])
                                            self.ignore = None
                                            self.max_per_entry = None
                                            self.suppression_time = None
                                            self._segment_path = lambda: "solicit-map-request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: eid_cont
                                        
                                        	EID\-record for RLOC static mapping
                                        	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "default"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont))])
                                            self._leafs = OrderedDict()

                                            self.eid_cont = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache, [], name, value)


                                        class EidCont(Entity):
                                            """
                                            EID\-record for RLOC static mapping
                                            
                                            .. attribute:: eid_prefix  (key)
                                            
                                            	xxxx.xxxx.xxxx 48 bit mac address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                            
                                            .. attribute:: etr_interface_ip
                                            
                                            	
                                            	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont, self).__init__()

                                                self.yang_name = "eid-cont"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['eid_prefix']
                                                self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp))])
                                                self._leafs = OrderedDict([
                                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ])
                                                self.eid_prefix = None

                                                self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp()
                                                self.etr_interface_ip.parent = self
                                                self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                                self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont, ['eid_prefix'], name, value)


                                            class EtrInterfaceIp(Entity):
                                                """
                                                
                                                
                                                .. attribute:: etr_interface_ip_address
                                                
                                                	IP address of loopback or other ETR interface
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                    self.yang_name = "etr-interface-ip"
                                                    self.yang_parent_name = "eid-cont"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ])
                                                    self.etr_interface_ip_address = None
                                                    self.priority = None
                                                    self.weight = None
                                                    self._segment_path = lambda: "etr-interface-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Default_.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN configuration
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.EidTable, ['vlan'], name, value)


                                class BroadcastUnderlay(Entity):
                                    """
                                    Multicast group to use for underlay
                                    
                                    .. attribute:: ipv4_multicast
                                    
                                    	IPv4 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_multicast
                                    
                                    	IPv6 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.BroadcastUnderlay, self).__init__()

                                        self.yang_name = "broadcast-underlay"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                            ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                        ])
                                        self.ipv4_multicast = None
                                        self.ipv6_multicast = None
                                        self._segment_path = lambda: "broadcast-underlay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                class Flood(Entity):
                                    """
                                    Control flooding or local intercept of broadcast frames
                                    
                                    .. attribute:: arp_nd
                                    
                                    	IPv4 ARP / IPv6 ND
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Frames with unknown destination MAC
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Flood, self).__init__()

                                        self.yang_name = "flood"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                            ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                        ])
                                        self.arp_nd = None
                                        self.unknown_unicast = None
                                        self._segment_path = lambda: "flood"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: mac
                                    
                                    	L2 EID records
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Mac>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.mac = None
                                        self._children_name_map["mac"] = "mac"

                                        self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Mac(Entity):
                                        """
                                        L2 EID records
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.locator_set = None
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Mac, ['locator_set'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "ethernet"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont))])
                                        self._leafs = OrderedDict()

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont, ['eid_prefix'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Default.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                    class Decapsulation(Entity):
                        """
                        Decapsulation behavior (e.g. filters)
                        
                        .. attribute:: filter
                        
                        	Filters traffic
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation, self).__init__()

                            self.yang_name = "decapsulation"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "decapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation, [], name, value)


                        class Filter(Entity):
                            """
                            Filters traffic
                            
                            .. attribute:: rloc
                            
                            	Filter based on Routing Locator (RLOC) in packet header
                            	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "decapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc))])
                                self._leafs = OrderedDict()

                                self.rloc = Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc()
                                self.rloc.parent = self
                                self._children_name_map["rloc"] = "rloc"
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter, [], name, value)


                            class Rloc(Entity):
                                """
                                Filter based on Routing Locator (RLOC) in packet header
                                
                                .. attribute:: source
                                
                                	Filters traffic based on RLOC source address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc, self).__init__()

                                    self.yang_name = "rloc"
                                    self.yang_parent_name = "filter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "rloc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc, [], name, value)


                                class Source(Entity):
                                    """
                                    Filters traffic based on RLOC source address
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator\-set Name
                                    	**type**\: str
                                    
                                    .. attribute:: member
                                    
                                    	Members learned from map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "rloc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                        ])
                                        self.locator_set = None
                                        self.member = None
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                    class DynamicEid(Entity):
                        """
                        Configure a dynamic EID
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: database_mapping
                        
                        	Configures EID\-prefix and locator\-set for dynamic\-EID
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping>`
                        
                        .. attribute:: eid_notify
                        
                        	Configure options for sending/receiving EID\-notify
                        	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify>`
                        
                        .. attribute:: map_notify_group
                        
                        	Multicast group which to send map\-notifies to
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                            ])
                            self.name = None
                            self.map_notify_group = None

                            self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.eid_notify = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify()
                            self.eid_notify.parent = self
                            self._children_name_map["eid_notify"] = "eid-notify"

                            self.map_server = YList(self)
                            self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid, ['name', 'map_notify_group'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Configures EID\-prefix and locator\-set for dynamic\-EID
                            
                            .. attribute:: ipv4_prefix
                            
                            	IPv4 EID\-prefix for dynamic\-EID
                            	**type**\: list of  		 :py:class:`Ipv4Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4-prefix", ("ipv4_prefix", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix))])
                                self._leafs = OrderedDict()

                                self.ipv4_prefix = YList(self)
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping, [], name, value)


                            class Ipv4Prefix(Entity):
                                """
                                IPv4 EID\-prefix for dynamic\-EID
                                
                                .. attribute:: eid_prefix  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                .. attribute:: locator_set
                                
                                	Use locators defined by locator\-set
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix, self).__init__()

                                    self.yang_name = "ipv4-prefix"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['eid_prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.eid_prefix = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "ipv4-prefix" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.DatabaseMapping.Ipv4Prefix, ['eid_prefix', 'locator_set'], name, value)


                        class EidNotify(Entity):
                            """
                            Configure options for sending/receiving EID\-notify
                            
                            .. attribute:: authentication_key
                            
                            	Authentication key used for validating received EID\-notify
                            	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey>`
                            
                            .. attribute:: gateway_key
                            
                            	
                            	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify, self).__init__()

                                self.yang_name = "eid-notify"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey))])
                                self._leafs = OrderedDict()

                                self.authentication_key = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey()
                                self.authentication_key.parent = self
                                self._children_name_map["authentication_key"] = "authentication-key"

                                self.gateway_key = YList(self)
                                self._segment_path = lambda: "eid-notify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify, [], name, value)


                            class AuthenticationKey(Entity):
                                """
                                Authentication key used for validating received EID\-notify
                                
                                .. attribute:: unc_pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: key_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: key_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: key_7
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                    self.yang_name = "authentication-key"
                                    self.yang_parent_name = "eid-notify"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                        ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                        ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                        ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                    ])
                                    self.unc_pwd = None
                                    self.key_0 = None
                                    self.key_6 = None
                                    self.key_7 = None
                                    self._segment_path = lambda: "authentication-key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                            class GatewayKey(Entity):
                                """
                                
                                
                                .. attribute:: gateway_ip  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                    self.yang_name = "gateway-key"
                                    self.yang_parent_name = "eid-notify"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['gateway_ip']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key))])
                                    self._leafs = OrderedDict([
                                        ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                    ])
                                    self.gateway_ip = None

                                    self.key = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey, ['gateway_ip'], name, value)


                                class Key(Entity):
                                    """
                                    
                                    
                                    .. attribute:: key_pwd
                                    
                                    	
                                    	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd>`
                                    
                                    .. attribute:: key_0
                                    
                                    	
                                    	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0>`
                                    
                                    .. attribute:: key_6
                                    
                                    	
                                    	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "gateway-key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6))])
                                        self._leafs = OrderedDict()

                                        self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd()
                                        self.key_pwd.parent = self
                                        self._children_name_map["key_pwd"] = "key-pwd"

                                        self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0()
                                        self.key_0.parent = self
                                        self._children_name_map["key_0"] = "key-0"

                                        self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6()
                                        self.key_6.parent = self
                                        self._children_name_map["key_6"] = "key-6"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key, [], name, value)


                                    class KeyPwd(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unc_pwd
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, self).__init__()

                                            self.yang_name = "key-pwd"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd.HashFunction')])),
                                            ])
                                            self.unc_pwd = None
                                            self.hash_function = None
                                            self._segment_path = lambda: "key-pwd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.KeyPwd, ['unc_pwd', 'hash_function'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key0(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_0
                                        
                                        	The UNENCRYPTED (cleartext) password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0, self).__init__()

                                            self.yang_name = "key-0"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0.HashFunction')])),
                                            ])
                                            self.ak_0 = None
                                            self.hash_function = None
                                            self._segment_path = lambda: "key-0"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key0, ['ak_0', 'hash_function'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                                    class Key6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ak_6
                                        
                                        	The ENCRYPTED password
                                        	**type**\: str
                                        
                                        .. attribute:: hash_function
                                        
                                        	authentication type
                                        	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6, self).__init__()

                                            self.yang_name = "key-6"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6.HashFunction')])),
                                            ])
                                            self.ak_6 = None
                                            self.hash_function = None
                                            self._segment_path = lambda: "key-6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.EidNotify.GatewayKey.Key.Key6, ['ak_6', 'hash_function'], name, value)

                                        class HashFunction(Enum):
                                            """
                                            HashFunction (Enum Class)

                                            authentication type

                                            .. data:: sha1 = 0

                                            .. data:: sha2 = 1

                                            """

                                            sha1 = Enum.YLeaf(0, "sha1")

                                            sha2 = Enum.YLeaf(1, "sha2")



                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip_addr  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_addr']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip_addr = None
                                self.proxy_reply = None

                                self.key = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_pwd
                                
                                	
                                	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd>`
                                
                                .. attribute:: key_0
                                
                                	
                                	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0>`
                                
                                .. attribute:: key_6
                                
                                	
                                	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6>`
                                
                                .. attribute:: key_7
                                
                                	
                                	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7))])
                                    self._leafs = OrderedDict()

                                    self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd()
                                    self.key_pwd.parent = self
                                    self._children_name_map["key_pwd"] = "key-pwd"

                                    self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0()
                                    self.key_0.parent = self
                                    self._children_name_map["key_0"] = "key-0"

                                    self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6()
                                    self.key_6.parent = self
                                    self._children_name_map["key_6"] = "key-6"

                                    self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7()
                                    self.key_7.parent = self
                                    self._children_name_map["key_7"] = "key-7"
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key, [], name, value)


                                class KeyPwd(Entity):
                                    """
                                    
                                    
                                    .. attribute:: unc_pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd, self).__init__()

                                        self.yang_name = "key-pwd"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.unc_pwd = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-pwd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key0(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0, self).__init__()

                                        self.yang_name = "key-0"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_0 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-0"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key6(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6, self).__init__()

                                        self.yang_name = "key-6"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_6 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                                class Key7(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ak_7
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: hash_function
                                    
                                    	authentication type
                                    	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7.HashFunction>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7, self).__init__()

                                        self.yang_name = "key-7"
                                        self.yang_parent_name = "key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                            ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7.HashFunction')])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ak_7 = None
                                        self.hash_function = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "key-7"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.DynamicEid.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                    class HashFunction(Enum):
                                        """
                                        HashFunction (Enum Class)

                                        authentication type

                                        .. data:: sha1 = 0

                                        .. data:: sha2 = 1

                                        """

                                        sha1 = Enum.YLeaf(0, "sha1")

                                        sha2 = Enum.YLeaf(1, "sha2")



                    class LocReachAlgorithm(Entity):
                        """
                        Configure locator reachability algorithm
                        
                        .. attribute:: lsb_reports
                        
                        	Configure data packet LSB report handling
                        	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports>`
                        
                        .. attribute:: rloc_probing
                        
                        	Probe high priority RLOCs with Map\-Requests as last resort
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.InstanceContainer.InstanceList.LocReachAlgorithm, self).__init__()

                            self.yang_name = "loc-reach-algorithm"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.LispList.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports))])
                            self._leafs = OrderedDict([
                                ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                            ])
                            self.rloc_probing = None

                            self.lsb_reports = Native.Router.LispList.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports()
                            self.lsb_reports.parent = self
                            self._children_name_map["lsb_reports"] = "lsb-reports"
                            self._segment_path = lambda: "loc-reach-algorithm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.LocReachAlgorithm, ['rloc_probing'], name, value)


                        class LsbReports(Entity):
                            """
                            Configure data packet LSB report handling
                            
                            .. attribute:: do_not_transmit
                            
                            	Force the setting of the encapsulation header L bit to zero
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore data packet LSB reports
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports, self).__init__()

                                self.yang_name = "lsb-reports"
                                self.yang_parent_name = "loc-reach-algorithm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.do_not_transmit = None
                                self.ignore = None
                                self._segment_path = lambda: "lsb-reports"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                    class MapServer(Entity):
                        """
                        Map\-Server commands
                        
                        .. attribute:: rloc
                        
                        	EID instance RLOC membership
                        	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc>`
                        
                        .. attribute:: site_registration
                        
                        	Map\-server site registration options
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.MapServer.SiteRegistration>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.InstanceContainer.InstanceList.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.MapServer.SiteRegistration))])
                            self._leafs = OrderedDict()

                            self.rloc = Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc()
                            self.rloc.parent = self
                            self._children_name_map["rloc"] = "rloc"

                            self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.MapServer.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"
                            self._segment_path = lambda: "map-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.MapServer, [], name, value)


                        class Rloc(Entity):
                            """
                            EID instance RLOC membership
                            
                            .. attribute:: members
                            
                            	EID instance RLOC membership
                            	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc, self).__init__()

                                self.yang_name = "rloc"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("members", ("members", Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members))])
                                self._leafs = OrderedDict()

                                self.members = Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members()
                                self.members.parent = self
                                self._children_name_map["members"] = "members"
                                self._segment_path = lambda: "rloc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc, [], name, value)


                            class Members(Entity):
                                """
                                EID instance RLOC membership
                                
                                .. attribute:: distribute
                                
                                	EID instance RLOC membership distribution
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: modify_discovered
                                
                                	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members, self).__init__()

                                    self.yang_name = "members"
                                    self.yang_parent_name = "rloc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered))])
                                    self._leafs = OrderedDict([
                                        ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                    ])
                                    self.distribute = None

                                    self.modify_discovered = Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered()
                                    self.modify_discovered.parent = self
                                    self._children_name_map["modify_discovered"] = "modify-discovered"
                                    self._segment_path = lambda: "members"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members, ['distribute'], name, value)


                                class ModifyDiscovered(Entity):
                                    """
                                    Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                    
                                    .. attribute:: operator
                                    
                                    	
                                    	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set from which to get member RLOC addresses
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                        self.yang_name = "modify-discovered"
                                        self.yang_parent_name = "members"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.operator = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "modify-discovered"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                    class Operator(Enum):
                                        """
                                        Operator (Enum Class)

                                        .. data:: add = 0

                                        .. data:: override = 1

                                        """

                                        add = Enum.YLeaf(0, "add")

                                        override = Enum.YLeaf(1, "override")



                        class SiteRegistration(Entity):
                            """
                            Map\-server site registration options
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations as a result of accept\-more\-specifics
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.MapServer.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                    class OtherXtrProbe(Entity):
                        """
                        Configure parameters for probing of other xTRs in our site
                        
                        .. attribute:: period
                        
                        	Period between probes in seconds
                        	**type**\: int
                        
                        	**range:** 5..900
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.InstanceContainer.InstanceList.OtherXtrProbe, self).__init__()

                            self.yang_name = "other-xtr-probe"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ])
                            self.period = None
                            self._segment_path = lambda: "other-xtr-probe"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.OtherXtrProbe, ['period'], name, value)


                    class RemoteRlocProbe(Entity):
                        """
                        Configure parameters for probing of remote RLOCs
                        
                        .. attribute:: on_membership_change
                        
                        	Trigger probing upon membership changes for remote RLOC
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: on_route_change
                        
                        	Trigger probing upon routing changes for remote RLOC
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.InstanceContainer.InstanceList.RemoteRlocProbe, self).__init__()

                            self.yang_name = "remote-rloc-probe"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                            ])
                            self.on_membership_change = None
                            self.on_route_change = None
                            self._segment_path = lambda: "remote-rloc-probe"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                    class Service(Entity):
                        """
                        Configure lisp service type
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv6
                        
                        	
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ethernet
                        
                        	
                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service, self).__init__()

                            self.yang_name = "service"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4)), ("ipv6", ("ipv6", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6)), ("ethernet", ("ethernet", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = None
                            self._children_name_map["ipv6"] = "ipv6"

                            self.ethernet = None
                            self._children_name_map["ethernet"] = "ethernet"
                            self._segment_path = lambda: "service"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service, [], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: default
                            
                            	
                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default>`
                            
                            .. attribute:: eid_table
                            
                            	Bind an eid\-table
                            	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.EidTable>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit>`
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest>`
                            
                            .. attribute:: alt
                            
                            	LISP Alternative Topology, LISP\-ALT
                            	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Alt>`
                            
                            .. attribute:: alt_vrf
                            
                            	Activate LISP\-ALT functionality in VRF
                            	**type**\: str
                            
                            	**status**\: deprecated
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Distance>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent>`
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr>`
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteExport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.UsePetr>`
                            
                            .. attribute:: import_
                            
                            	Redistribute LISP states internally
                            	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import>`
                            
                            .. attribute:: route_import
                            
                            	Import RIB routes by a routing protocol into LISP
                            	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: database_mapping
                            
                            	Configures Locator addresses for an ETR
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "service"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default)), ("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.EidTable)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Alt)), ("distance", ("distance", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.UsePetr)), ("import", ("import_", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import)), ("route-import", ("route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ])
                                self.alt_vrf = None
                                self.proxy_etr = None
                                self.sgt = None
                                self.map_request_source = None

                                self.default = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default()
                                self.default.parent = self
                                self._children_name_map["default"] = "default"

                                self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.EidTable()
                                self.eid_table.parent = self
                                self._children_name_map["eid_table"] = "eid-table"

                                self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.alt = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Alt()
                                self.alt.parent = self
                                self._children_name_map["alt"] = "alt"

                                self.distance = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_persistent = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.proxy_itr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr()
                                self.proxy_itr.parent = self
                                self._children_name_map["proxy_itr"] = "proxy-itr"

                                self.route_export = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.import_ = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import()
                                self.import_.parent = self
                                self._children_name_map["import_"] = "import"

                                self.route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport()
                                self.route_import.parent = self
                                self._children_name_map["route_import"] = "route-import"

                                self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                            class Default(Entity):
                                """
                                
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default, self).__init__()

                                    self.yang_name = "default"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.EidTable)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt)), ("distance", ("distance", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr)), ("import", ("import_", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import)), ("route-import", ("route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping))])
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "default"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.rip = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class EidTable(Entity):
                                """
                                Bind an eid\-table
                                
                                .. attribute:: vrf_name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: default
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: vrf
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.EidTable, self).__init__()

                                    self.yang_name = "eid-table"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.vrf_name = None
                                    self.default = None
                                    self.vrf = None
                                    self._segment_path = lambda: "eid-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class Alt(Entity):
                                """
                                LISP Alternative Topology, LISP\-ALT
                                
                                .. attribute:: summary_route
                                
                                	Summary route to install into the ALT table
                                	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Alt, self).__init__()

                                    self.yang_name = "alt"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute))])
                                    self._leafs = OrderedDict()

                                    self.summary_route = YList(self)
                                    self._segment_path = lambda: "alt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Alt, [], name, value)


                                class SummaryRoute(Entity):
                                    """
                                    Summary route to install into the ALT table
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: route_tag
                                    
                                    	ALT RIB route tag for EID prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute, self).__init__()

                                        self.yang_name = "summary-route"
                                        self.yang_parent_name = "alt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                        ])
                                        self.eid_prefix = None
                                        self.route_tag = None
                                        self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: away
                                
                                	Administrative distance for RIB route installation
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.away = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: eid_interface
                                
                                	Configures static EID\-to\-RLOC mappings for an ITR
                                	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface>`
                                
                                .. attribute:: away_eids
                                
                                	Map cache configuration for the away table
                                	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids>`
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids))])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None

                                    self.away_eids = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids()
                                    self.away_eids.parent = self
                                    self._children_name_map["away_eids"] = "away-eids"

                                    self.eid_interface = YList(self)
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache, ['site_registration'], name, value)


                                class EidInterface(Entity):
                                    """
                                    Configures static EID\-to\-RLOC mappings for an ITR
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: etr_interface_ip
                                    
                                    	
                                    	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop packets that match this map\-cache entry
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: map_request
                                    
                                    	Send Map\-Request for LISP destination EID
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: native_forward
                                    
                                    	Natively forward packets that match this map\-cache entry
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface, self).__init__()

                                        self.yang_name = "eid-interface"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                            ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.drop = None
                                        self.map_request = None
                                        self.native_forward = None

                                        self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp()
                                        self.etr_interface_ip.parent = self
                                        self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                        self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                    class EtrInterfaceIp(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr_interface_ip_address
                                        
                                        	IP address of loopback or other ETR interface
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                            self.yang_name = "etr-interface-ip"
                                            self.yang_parent_name = "eid-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.etr_interface_ip_address = None
                                            self.priority = None
                                            self.weight = None
                                            self._segment_path = lambda: "etr-interface-ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                class AwayEids(Entity):
                                    """
                                    Map cache configuration for the away table
                                    
                                    .. attribute:: send_map_request
                                    
                                    	Export away table entries into the map cache with action set to send\-map\-request
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids, self).__init__()

                                        self.yang_name = "away-eids"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                        ])
                                        self.send_map_request = None
                                        self._segment_path = lambda: "away-eids"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCache.AwayEids, ['send_map_request'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.MapCachePersistent, ['interval'], name, value)


                            class ProxyItr(Entity):
                                """
                                Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                
                                .. attribute:: ipv4_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr, self).__init__()

                                    self.yang_name = "proxy-itr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                        ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                    ])
                                    self.ipv4_addr = None
                                    self.ipv6_addr = None
                                    self._segment_path = lambda: "proxy-itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	
                                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority))])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ])
                                    self.locator_address = None

                                    self.priority = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority()
                                    self.priority.parent = self
                                    self._children_name_map["priority"] = "priority"
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.UsePetr, ['locator_address'], name, value)


                                class Priority(Entity):
                                    """
                                    
                                    
                                    .. attribute:: priority_value
                                    
                                    	Configures which Locators from a set are preferred
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: weight
                                    
                                    	Traffic load\-spreading among Locators
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority, self).__init__()

                                        self.yang_name = "priority"
                                        self.yang_parent_name = "use-petr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                        ])
                                        self.priority_value = None
                                        self.weight = None
                                        self._segment_path = lambda: "priority"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                            class Import(Entity):
                                """
                                Redistribute LISP states internally
                                
                                .. attribute:: database
                                
                                	Redistribute LISP internal states as database mapping
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import.Database>`
                                
                                .. attribute:: prefix_list_container
                                
                                	Redistribute LISP internal states into LISP prefix\-list entries
                                	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import, self).__init__()

                                    self.yang_name = "import"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.prefix_list_container = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer()
                                    self.prefix_list_container.parent = self
                                    self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                    self._segment_path = lambda: "import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import, [], name, value)


                                class Database(Entity):
                                    """
                                    Redistribute LISP internal states as database mapping
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.site_registration = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import.Database, ['site_registration', 'locator_set'], name, value)


                                class PrefixListContainer(Entity):
                                    """
                                    Redistribute LISP internal states into LISP prefix\-list entries
                                    
                                    .. attribute:: prefix_list
                                    
                                    	The name of the lisp prefix list
                                    	**type**\: str
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer, self).__init__()

                                        self.yang_name = "prefix-list-container"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.prefix_list = None
                                        self.site_registration = None
                                        self._segment_path = lambda: "prefix-list-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                            class RouteImport(Entity):
                                """
                                Import RIB routes by a routing protocol into LISP
                                
                                .. attribute:: database
                                
                                	Use RIB routes to define local EID database entries
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database>`
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache>`
                                
                                .. attribute:: prefix_list_proto
                                
                                	
                                	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport, self).__init__()

                                    self.yang_name = "route-import"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.prefix_list_proto = YList(self)
                                    self._segment_path = lambda: "route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport, [], name, value)


                                class Database(Entity):
                                    """
                                    Use RIB routes to define local EID database entries
                                    
                                    .. attribute:: application
                                    
                                    	Application Protocol
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected>`
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix>`
                                    
                                    .. attribute:: nd
                                    
                                    	Neighbor Discovery
                                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip))])
                                        self._leafs = OrderedDict()

                                        self.application = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application()
                                        self.application.parent = self
                                        self._children_name_map["application"] = "application"

                                        self.connected = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected()
                                        self.connected.parent = self
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis()
                                        self.isis.parent = self
                                        self._children_name_map["isis"] = "isis"

                                        self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.nd = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd()
                                        self.nd.parent = self
                                        self._children_name_map["nd"] = "nd"

                                        self.static = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static()
                                        self.static.parent = self
                                        self._children_name_map["static"] = "static"

                                        self.rip = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip()
                                        self.rip.parent = self
                                        self._children_name_map["rip"] = "rip"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application Protocol
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: process_id
                                        
                                        	Process name
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                            ])
                                            self.process_id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis, ['process_id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Nd(Entity):
                                        """
                                        Neighbor Discovery
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd, self).__init__()

                                            self.yang_name = "nd"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "nd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "nd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: application
                                    
                                    	Application Protocol
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                    
                                    .. attribute:: nd
                                    
                                    	Neighbour Discovery
                                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip))])
                                        self._leafs = OrderedDict()

                                        self.application = None
                                        self._children_name_map["application"] = "application"

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis()
                                        self.isis.parent = self
                                        self._children_name_map["isis"] = "isis"

                                        self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.nd = None
                                        self._children_name_map["nd"] = "nd"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.rip = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip()
                                        self.rip.parent = self
                                        self._children_name_map["rip"] = "rip"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application Protocol
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id
                                        
                                        	Process name
                                        	**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Nd(Entity):
                                        """
                                        Neighbour Discovery
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd, self).__init__()

                                            self.yang_name = "nd"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "nd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "nd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                class PrefixListProto(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix_list  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: protocol  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.Protocol>`
                                    
                                    .. attribute:: bgp_id
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId>`
                                    
                                    .. attribute:: eigrp_or_ospf_id
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                    
                                    .. attribute:: isis_id
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto, self).__init__()

                                        self.yang_name = "prefix-list-proto"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix_list','protocol']
                                        self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                        self._leafs = OrderedDict([
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.Protocol')])),
                                            ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.prefix_list = None
                                        self.protocol = None
                                        self.isis_id = None
                                        self.number = None
                                        self.threshold = None
                                        self.warning_only = None
                                        self.route_map = None

                                        self.bgp_id = YList(self)
                                        self.eigrp_or_ospf_id = YList(self)
                                        self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                    class Protocol(Enum):
                                        """
                                        Protocol (Enum Class)

                                        .. data:: application = 0

                                        .. data:: bgp = 1

                                        .. data:: connected = 2

                                        .. data:: eigrp = 3

                                        .. data:: isis = 4

                                        .. data:: maximum_prefix = 5

                                        .. data:: nd = 6

                                        .. data:: ospf = 7

                                        .. data:: static = 8

                                        .. data:: rip = 9

                                        """

                                        application = Enum.YLeaf(0, "application")

                                        bgp = Enum.YLeaf(1, "bgp")

                                        connected = Enum.YLeaf(2, "connected")

                                        eigrp = Enum.YLeaf(3, "eigrp")

                                        isis = Enum.YLeaf(4, "isis")

                                        maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                        nd = Enum.YLeaf(6, "nd")

                                        ospf = Enum.YLeaf(7, "ospf")

                                        static = Enum.YLeaf(8, "static")

                                        rip = Enum.YLeaf(9, "rip")



                                    class BgpId(Entity):
                                        """
                                        
                                        
                                        .. attribute:: bgp_id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId, self).__init__()

                                            self.yang_name = "bgp-id"
                                            self.yang_parent_name = "prefix-list-proto"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['bgp_id']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.bgp_id = None
                                            self.route_map = None
                                            self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                    class EigrpOrOspfId(Entity):
                                        """
                                        
                                        
                                        .. attribute:: int16_id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                            self.yang_name = "eigrp-or-ospf-id"
                                            self.yang_parent_name = "prefix-list-proto"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['int16_id']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.int16_id = None
                                            self.route_map = None
                                            self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures Locator addresses for an ETR
                                
                                .. attribute:: eid_cont
                                
                                	
                                	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont>`
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"

                                    self.eid_cont = YList(self)
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping, [], name, value)


                                class EidCont(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    .. attribute:: locator_set_container
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer>`
                                    
                                    .. attribute:: ipv4_addrees
                                    
                                    	IPv4 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees>`
                                    
                                    .. attribute:: ipv6_addrees
                                    
                                    	IPv6 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees>`
                                    
                                    .. attribute:: ipv4_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface>`
                                    
                                    .. attribute:: ipv6_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface>`
                                    
                                    .. attribute:: auto_discover_rlocs
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont, self).__init__()

                                        self.yang_name = "eid-cont"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.auto_discover_rlocs = None

                                        self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer()
                                        self.locator_set_container.parent = self
                                        self._children_name_map["locator_set_container"] = "locator-set-container"

                                        self.ipv4_addrees = YList(self)
                                        self.ipv6_addrees = YList(self)
                                        self.ipv4_interface = YList(self)
                                        self.ipv6_interface = YList(self)
                                        self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                    class LocatorSetContainer(Entity):
                                        """
                                        Use locators defined by locator\-set
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        .. attribute:: proxy
                                        
                                        	Enable configuration of static proxy database mapping
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                            self.yang_name = "locator-set-container"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.proxy = None
                                            self._segment_path = lambda: "locator-set-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                    class Ipv4Addrees(Entity):
                                        """
                                        IPv4 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                            self.yang_name = "ipv4-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv4-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Ipv6Addrees(Entity):
                                        """
                                        IPv6 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                            self.yang_name = "ipv6-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv6-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv4Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                            self.yang_name = "IPv4-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv4-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv6Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                            self.yang_name = "IPv6-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv6-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Ipv6(Entity):
                            """
                            
                            
                            .. attribute:: default
                            
                            	
                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default>`
                            
                            .. attribute:: eid_table
                            
                            	Bind an eid\-table
                            	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.EidTable>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit>`
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest>`
                            
                            .. attribute:: alt
                            
                            	LISP Alternative Topology, LISP\-ALT
                            	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Alt>`
                            
                            .. attribute:: alt_vrf
                            
                            	Activate LISP\-ALT functionality in VRF
                            	**type**\: str
                            
                            	**status**\: deprecated
                            
                            .. attribute:: distance
                            
                            	Administrative distance for RIB route installation
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Distance>`
                            
                            .. attribute:: map_cache
                            
                            	Address family specific map cache configuration
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache>`
                            
                            .. attribute:: map_cache_persistent
                            
                            	Dump map\-cache onto flash, making it persistent across reboots
                            	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent>`
                            
                            .. attribute:: proxy_etr
                            
                            	Configures a LISP Proxy Engress Tunnel Router (PETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: proxy_itr
                            
                            	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                            	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr>`
                            
                            .. attribute:: route_export
                            
                            	Export routes into RIB from LISP
                            	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteExport>`
                            
                            .. attribute:: sgt
                            
                            	Enable security group tag propagation in LISP encapsulated traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: use_petr
                            
                            	Encapsulate to Proxy ETR when matching forward\-native entry
                            	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.UsePetr>`
                            
                            .. attribute:: import_
                            
                            	Redistribute LISP states internally
                            	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import>`
                            
                            .. attribute:: route_import
                            
                            	Import RIB routes by a routing protocol into LISP
                            	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: database_mapping
                            
                            	Configures Locator addresses for an ETR
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "service"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default)), ("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.EidTable)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Alt)), ("distance", ("distance", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.UsePetr)), ("import", ("import_", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import)), ("route-import", ("route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                    ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                    ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ])
                                self.alt_vrf = None
                                self.proxy_etr = None
                                self.sgt = None
                                self.map_request_source = None

                                self.default = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default()
                                self.default.parent = self
                                self._children_name_map["default"] = "default"

                                self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.EidTable()
                                self.eid_table.parent = self
                                self._children_name_map["eid_table"] = "eid-table"

                                self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.alt = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Alt()
                                self.alt.parent = self
                                self._children_name_map["alt"] = "alt"

                                self.distance = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"

                                self.map_cache_persistent = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent()
                                self.map_cache_persistent.parent = self
                                self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                self.proxy_itr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr()
                                self.proxy_itr.parent = self
                                self._children_name_map["proxy_itr"] = "proxy-itr"

                                self.route_export = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteExport()
                                self.route_export.parent = self
                                self._children_name_map["route_export"] = "route-export"

                                self.import_ = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import()
                                self.import_.parent = self
                                self._children_name_map["import_"] = "import"

                                self.route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport()
                                self.route_import.parent = self
                                self._children_name_map["route_import"] = "route-import"

                                self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.use_petr = YList(self)
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                            class Default(Entity):
                                """
                                
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.EidTable>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.SolicitMapRequest>`
                                
                                .. attribute:: alt
                                
                                	LISP Alternative Topology, LISP\-ALT
                                	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt>`
                                
                                .. attribute:: alt_vrf
                                
                                	Activate LISP\-ALT functionality in VRF
                                	**type**\: str
                                
                                	**status**\: deprecated
                                
                                .. attribute:: distance
                                
                                	Administrative distance for RIB route installation
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Distance>`
                                
                                .. attribute:: map_cache
                                
                                	Address family specific map cache configuration
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache>`
                                
                                .. attribute:: map_cache_persistent
                                
                                	Dump map\-cache onto flash, making it persistent across reboots
                                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCachePersistent>`
                                
                                .. attribute:: proxy_etr
                                
                                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: proxy_itr
                                
                                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                	**type**\:  :py:class:`ProxyItr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.ProxyItr>`
                                
                                .. attribute:: route_export
                                
                                	Export routes into RIB from LISP
                                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteExport>`
                                
                                .. attribute:: sgt
                                
                                	Enable security group tag propagation in LISP encapsulated traffic
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: use_petr
                                
                                	Encapsulate to Proxy ETR when matching forward\-native entry
                                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr>`
                                
                                .. attribute:: import_
                                
                                	Redistribute LISP states internally
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import>`
                                
                                .. attribute:: route_import
                                
                                	Import RIB routes by a routing protocol into LISP
                                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default, self).__init__()

                                    self.yang_name = "default"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.EidTable)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.SolicitMapRequest)), ("alt", ("alt", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt)), ("distance", ("distance", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Distance)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCachePersistent)), ("proxy-itr", ("proxy_itr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.ProxyItr)), ("route-export", ("route_export", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteExport)), ("use-petr", ("use_petr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr)), ("import", ("import_", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import)), ("route-import", ("route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping))])
                                    self._leafs = OrderedDict([
                                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                    ])
                                    self.alt_vrf = None
                                    self.proxy_etr = None
                                    self.sgt = None
                                    self.map_request_source = None

                                    self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.alt = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt()
                                    self.alt.parent = self
                                    self._children_name_map["alt"] = "alt"

                                    self.distance = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.map_cache_persistent = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCachePersistent()
                                    self.map_cache_persistent.parent = self
                                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                                    self.proxy_itr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.ProxyItr()
                                    self.proxy_itr.parent = self
                                    self._children_name_map["proxy_itr"] = "proxy-itr"

                                    self.route_export = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteExport()
                                    self.route_export.parent = self
                                    self._children_name_map["route_export"] = "route-export"

                                    self.import_ = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport()
                                    self.route_import.parent = self
                                    self._children_name_map["route_import"] = "route-import"

                                    self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.use_petr = YList(self)
                                    self._segment_path = lambda: "default"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default, ['alt_vrf', 'proxy_etr', 'sgt', 'map_request_source'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vrf_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vrf
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                        ])
                                        self.vrf_name = None
                                        self.default = None
                                        self.vrf = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class Alt(Entity):
                                    """
                                    LISP Alternative Topology, LISP\-ALT
                                    
                                    .. attribute:: summary_route
                                    
                                    	Summary route to install into the ALT table
                                    	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt.SummaryRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt, self).__init__()

                                        self.yang_name = "alt"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt.SummaryRoute))])
                                        self._leafs = OrderedDict()

                                        self.summary_route = YList(self)
                                        self._segment_path = lambda: "alt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt, [], name, value)


                                    class SummaryRoute(Entity):
                                        """
                                        Summary route to install into the ALT table
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_tag
                                        
                                        	ALT RIB route tag for EID prefix
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt.SummaryRoute, self).__init__()

                                            self.yang_name = "summary-route"
                                            self.yang_parent_name = "alt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                            ])
                                            self.eid_prefix = None
                                            self.route_tag = None
                                            self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                                class Distance(Entity):
                                    """
                                    Administrative distance for RIB route installation
                                    
                                    .. attribute:: alt
                                    
                                    	LISP routes installed in the ALT table
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: away
                                    
                                    	Administrative distance for RIB route installation
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: dyn_eid
                                    
                                    	LISP installed routes of type dynamic\-EID
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: site_registrations
                                    
                                    	LISP installed routes of type site\-registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                            ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                        ])
                                        self.alt = None
                                        self.away = None
                                        self.dyn_eid = None
                                        self.site_registrations = None
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                                class MapCache(Entity):
                                    """
                                    Address family specific map cache configuration
                                    
                                    .. attribute:: eid_interface
                                    
                                    	Configures static EID\-to\-RLOC mappings for an ITR
                                    	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Map cache configuration for the away table
                                    	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.AwayEids>`
                                    
                                    .. attribute:: site_registration
                                    
                                    	Install map cache to map request for site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.AwayEids))])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.site_registration = None

                                        self.away_eids = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.AwayEids()
                                        self.away_eids.parent = self
                                        self._children_name_map["away_eids"] = "away-eids"

                                        self.eid_interface = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache, ['site_registration'], name, value)


                                    class EidInterface(Entity):
                                        """
                                        Configures static EID\-to\-RLOC mappings for an ITR
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface.EtrInterfaceIp>`
                                        
                                        .. attribute:: drop
                                        
                                        	Drop packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: map_request
                                        
                                        	Send Map\-Request for LISP destination EID
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: native_forward
                                        
                                        	Natively forward packets that match this map\-cache entry
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface, self).__init__()

                                            self.yang_name = "eid-interface"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.drop = None
                                            self.map_request = None
                                            self.native_forward = None

                                            self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                    class AwayEids(Entity):
                                        """
                                        Map cache configuration for the away table
                                        
                                        .. attribute:: send_map_request
                                        
                                        	Export away table entries into the map cache with action set to send\-map\-request
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.AwayEids, self).__init__()

                                            self.yang_name = "away-eids"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                            ])
                                            self.send_map_request = None
                                            self._segment_path = lambda: "away-eids"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCache.AwayEids, ['send_map_request'], name, value)


                                class MapCachePersistent(Entity):
                                    """
                                    Dump map\-cache onto flash, making it persistent across reboots
                                    
                                    .. attribute:: interval
                                    
                                    	Interval in minutes of how often the map\-cache is saved
                                    	**type**\: int
                                    
                                    	**range:** 1..1440
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCachePersistent, self).__init__()

                                        self.yang_name = "map-cache-persistent"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                        ])
                                        self.interval = None
                                        self._segment_path = lambda: "map-cache-persistent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.MapCachePersistent, ['interval'], name, value)


                                class ProxyItr(Entity):
                                    """
                                    Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                    
                                    .. attribute:: ipv4_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_addr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.ProxyItr, self).__init__()

                                        self.yang_name = "proxy-itr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                            ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                        ])
                                        self.ipv4_addr = None
                                        self.ipv6_addr = None
                                        self._segment_path = lambda: "proxy-itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                                class RouteExport(Entity):
                                    """
                                    Export routes into RIB from LISP
                                    
                                    .. attribute:: site_registrations
                                    
                                    	Export LISP site registrations to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: away_eids
                                    
                                    	Export LISP away EIDs to RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteExport, self).__init__()

                                        self.yang_name = "route-export"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                        ])
                                        self.site_registrations = None
                                        self.away_eids = None
                                        self._segment_path = lambda: "route-export"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteExport, ['site_registrations', 'away_eids'], name, value)


                                class UsePetr(Entity):
                                    """
                                    Encapsulate to Proxy ETR when matching forward\-native entry
                                    
                                    .. attribute:: locator_address  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: priority
                                    
                                    	
                                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr.Priority>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr, self).__init__()

                                        self.yang_name = "use-petr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['locator_address']
                                        self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr.Priority))])
                                        self._leafs = OrderedDict([
                                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                        ])
                                        self.locator_address = None

                                        self.priority = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr.Priority()
                                        self.priority.parent = self
                                        self._children_name_map["priority"] = "priority"
                                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr, ['locator_address'], name, value)


                                    class Priority(Entity):
                                        """
                                        
                                        
                                        .. attribute:: priority_value
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr.Priority, self).__init__()

                                            self.yang_name = "priority"
                                            self.yang_parent_name = "use-petr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.priority_value = None
                                            self.weight = None
                                            self._segment_path = lambda: "priority"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                                class Import(Entity):
                                    """
                                    Redistribute LISP states internally
                                    
                                    .. attribute:: database
                                    
                                    	Redistribute LISP internal states as database mapping
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.Database>`
                                    
                                    .. attribute:: prefix_list_container
                                    
                                    	Redistribute LISP internal states into LISP prefix\-list entries
                                    	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.PrefixListContainer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.PrefixListContainer))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.prefix_list_container = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.PrefixListContainer()
                                        self.prefix_list_container.parent = self
                                        self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import, [], name, value)


                                    class Database(Entity):
                                        """
                                        Redistribute LISP internal states as database mapping
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.site_registration = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.Database, ['site_registration', 'locator_set'], name, value)


                                    class PrefixListContainer(Entity):
                                        """
                                        Redistribute LISP internal states into LISP prefix\-list entries
                                        
                                        .. attribute:: prefix_list
                                        
                                        	The name of the lisp prefix list
                                        	**type**\: str
                                        
                                        .. attribute:: site_registration
                                        
                                        	Import states from site registrations
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.PrefixListContainer, self).__init__()

                                            self.yang_name = "prefix-list-container"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ])
                                            self.prefix_list = None
                                            self.site_registration = None
                                            self._segment_path = lambda: "prefix-list-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                                class RouteImport(Entity):
                                    """
                                    Import RIB routes by a routing protocol into LISP
                                    
                                    .. attribute:: database
                                    
                                    	Use RIB routes to define local EID database entries
                                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database>`
                                    
                                    .. attribute:: map_cache
                                    
                                    	Use RIB routes to define EID address space in map\-cache
                                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache>`
                                    
                                    .. attribute:: prefix_list_proto
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport, self).__init__()

                                        self.yang_name = "route-import"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto))])
                                        self._leafs = OrderedDict()

                                        self.database = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database()
                                        self.database.parent = self
                                        self._children_name_map["database"] = "database"

                                        self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache()
                                        self.map_cache.parent = self
                                        self._children_name_map["map_cache"] = "map-cache"

                                        self.prefix_list_proto = YList(self)
                                        self._segment_path = lambda: "route-import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport, [], name, value)


                                    class Database(Entity):
                                        """
                                        Use RIB routes to define local EID database entries
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbor Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd>`
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database, self).__init__()

                                            self.yang_name = "database"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"

                                            self.connected = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd()
                                            self.nd.parent = self
                                            self._children_name_map["nd"] = "nd"

                                            self.static = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: process_id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                                ])
                                                self.process_id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis, ['process_id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbor Discovery
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static.LispIpRouteImport))])
                                                self._leafs = OrderedDict()

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static, [], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_ip_route_import
                                            
                                            	
                                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip.LispIpRouteImport>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip.LispIpRouteImport))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip.LispIpRouteImport()
                                                self.lisp_ip_route_import.parent = self
                                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip, ['id'], name, value)


                                            class LispIpRouteImport(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                .. attribute:: locator_set
                                                
                                                	Locator set to use with created database mapping entries
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                    self.yang_name = "lisp-ip-route-import"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self.locator_set = None
                                                    self._segment_path = lambda: "lisp-ip-route-import"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MapCache(Entity):
                                        """
                                        Use RIB routes to define EID address space in map\-cache
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes to pick up from the RIB
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.MaximumPrefix>`
                                        
                                        .. attribute:: nd
                                        
                                        	Neighbour Discovery
                                        	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf>`
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache, self).__init__()

                                            self.yang_name = "map-cache"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"

                                            self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.nd = None
                                            self._children_name_map["nd"] = "nd"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.bgp = YList(self)
                                            self.eigrp = YList(self)
                                            self.ospf = YList(self)
                                            self.rip = YList(self)
                                            self._segment_path = lambda: "map-cache"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                        class Bgp(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: id
                                            
                                            	Process name
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes to pick up from the RIB
                                            
                                            .. attribute:: number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: threshold1
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: warning_only1
                                            
                                            	Only give a warning message and do not limit entries
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.warning_only = None
                                                self.threshold = None
                                                self.threshold1 = None
                                                self.warning_only1 = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                        class Nd(Entity):
                                            """
                                            Neighbour Discovery
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd, self).__init__()

                                                self.yang_name = "nd"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "nd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "nd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static.MapCacheContainer))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static, [], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            .. attribute:: map_cache_container
                                            
                                            	
                                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip.MapCacheContainer>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "map-cache"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip.MapCacheContainer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ])
                                                self.id = None

                                                self.map_cache_container = None
                                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                                self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip, ['id'], name, value)


                                            class MapCacheContainer(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map for route selection filtering
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                    self.yang_name = "map-cache-container"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "map-cache-container"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                    class PrefixListProto(Entity):
                                        """
                                        
                                        
                                        .. attribute:: prefix_list  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: protocol  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.Protocol>`
                                        
                                        .. attribute:: bgp_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.BgpId>`
                                        
                                        .. attribute:: eigrp_or_ospf_id
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                        
                                        .. attribute:: isis_id
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto, self).__init__()

                                            self.yang_name = "prefix-list-proto"
                                            self.yang_parent_name = "route-import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['prefix_list','protocol']
                                            self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.Protocol')])),
                                                ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.prefix_list = None
                                            self.protocol = None
                                            self.isis_id = None
                                            self.number = None
                                            self.threshold = None
                                            self.warning_only = None
                                            self.route_map = None

                                            self.bgp_id = YList(self)
                                            self.eigrp_or_ospf_id = YList(self)
                                            self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                        class Protocol(Enum):
                                            """
                                            Protocol (Enum Class)

                                            .. data:: application = 0

                                            .. data:: bgp = 1

                                            .. data:: connected = 2

                                            .. data:: eigrp = 3

                                            .. data:: isis = 4

                                            .. data:: maximum_prefix = 5

                                            .. data:: nd = 6

                                            .. data:: ospf = 7

                                            .. data:: static = 8

                                            .. data:: rip = 9

                                            """

                                            application = Enum.YLeaf(0, "application")

                                            bgp = Enum.YLeaf(1, "bgp")

                                            connected = Enum.YLeaf(2, "connected")

                                            eigrp = Enum.YLeaf(3, "eigrp")

                                            isis = Enum.YLeaf(4, "isis")

                                            maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                            nd = Enum.YLeaf(6, "nd")

                                            ospf = Enum.YLeaf(7, "ospf")

                                            static = Enum.YLeaf(8, "static")

                                            rip = Enum.YLeaf(9, "rip")



                                        class BgpId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: bgp_id  (key)
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.BgpId, self).__init__()

                                                self.yang_name = "bgp-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['bgp_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.bgp_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                        class EigrpOrOspfId(Entity):
                                            """
                                            
                                            
                                            .. attribute:: int16_id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: route_map
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                                self.yang_name = "eigrp-or-ospf-id"
                                                self.yang_parent_name = "prefix-list-proto"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['int16_id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.int16_id = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        .. attribute:: auto_discover_rlocs
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                                ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                            ])
                                            self.eid_prefix = None
                                            self.auto_discover_rlocs = None

                                            self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class EidTable(Entity):
                                """
                                Bind an eid\-table
                                
                                .. attribute:: vrf_name
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: default
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: vrf
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.EidTable, self).__init__()

                                    self.yang_name = "eid-table"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.vrf_name = None
                                    self.default = None
                                    self.vrf = None
                                    self._segment_path = lambda: "eid-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.EidTable, ['vrf_name', 'default', 'vrf'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class Alt(Entity):
                                """
                                LISP Alternative Topology, LISP\-ALT
                                
                                .. attribute:: summary_route
                                
                                	Summary route to install into the ALT table
                                	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Alt, self).__init__()

                                    self.yang_name = "alt"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute))])
                                    self._leafs = OrderedDict()

                                    self.summary_route = YList(self)
                                    self._segment_path = lambda: "alt"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Alt, [], name, value)


                                class SummaryRoute(Entity):
                                    """
                                    Summary route to install into the ALT table
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: route_tag
                                    
                                    	ALT RIB route tag for EID prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute, self).__init__()

                                        self.yang_name = "summary-route"
                                        self.yang_parent_name = "alt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                        ])
                                        self.eid_prefix = None
                                        self.route_tag = None
                                        self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                            class Distance(Entity):
                                """
                                Administrative distance for RIB route installation
                                
                                .. attribute:: alt
                                
                                	LISP routes installed in the ALT table
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: away
                                
                                	Administrative distance for RIB route installation
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: dyn_eid
                                
                                	LISP installed routes of type dynamic\-EID
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: site_registrations
                                
                                	LISP installed routes of type site\-registrations
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                        ('away', (YLeaf(YType.uint8, 'away'), ['int'])),
                                        ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                        ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                    ])
                                    self.alt = None
                                    self.away = None
                                    self.dyn_eid = None
                                    self.site_registrations = None
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Distance, ['alt', 'away', 'dyn_eid', 'site_registrations'], name, value)


                            class MapCache(Entity):
                                """
                                Address family specific map cache configuration
                                
                                .. attribute:: eid_interface
                                
                                	Configures static EID\-to\-RLOC mappings for an ITR
                                	**type**\: list of  		 :py:class:`EidInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface>`
                                
                                .. attribute:: away_eids
                                
                                	Map cache configuration for the away table
                                	**type**\:  :py:class:`AwayEids <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids>`
                                
                                .. attribute:: site_registration
                                
                                	Install map cache to map request for site registrations
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-interface", ("eid_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface)), ("away-eids", ("away_eids", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids))])
                                    self._leafs = OrderedDict([
                                        ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                    ])
                                    self.site_registration = None

                                    self.away_eids = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids()
                                    self.away_eids.parent = self
                                    self._children_name_map["away_eids"] = "away-eids"

                                    self.eid_interface = YList(self)
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache, ['site_registration'], name, value)


                                class EidInterface(Entity):
                                    """
                                    Configures static EID\-to\-RLOC mappings for an ITR
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: etr_interface_ip
                                    
                                    	
                                    	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp>`
                                    
                                    .. attribute:: drop
                                    
                                    	Drop packets that match this map\-cache entry
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: map_request
                                    
                                    	Send Map\-Request for LISP destination EID
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: native_forward
                                    
                                    	Natively forward packets that match this map\-cache entry
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface, self).__init__()

                                        self.yang_name = "eid-interface"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                            ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                            ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.drop = None
                                        self.map_request = None
                                        self.native_forward = None

                                        self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp()
                                        self.etr_interface_ip.parent = self
                                        self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                        self._segment_path = lambda: "eid-interface" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                                    class EtrInterfaceIp(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr_interface_ip_address
                                        
                                        	IP address of loopback or other ETR interface
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, self).__init__()

                                            self.yang_name = "etr-interface-ip"
                                            self.yang_parent_name = "eid-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.etr_interface_ip_address = None
                                            self.priority = None
                                            self.weight = None
                                            self._segment_path = lambda: "etr-interface-ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.EidInterface.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                                class AwayEids(Entity):
                                    """
                                    Map cache configuration for the away table
                                    
                                    .. attribute:: send_map_request
                                    
                                    	Export away table entries into the map cache with action set to send\-map\-request
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids, self).__init__()

                                        self.yang_name = "away-eids"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('send_map_request', (YLeaf(YType.empty, 'send-map-request'), ['Empty'])),
                                        ])
                                        self.send_map_request = None
                                        self._segment_path = lambda: "away-eids"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCache.AwayEids, ['send_map_request'], name, value)


                            class MapCachePersistent(Entity):
                                """
                                Dump map\-cache onto flash, making it persistent across reboots
                                
                                .. attribute:: interval
                                
                                	Interval in minutes of how often the map\-cache is saved
                                	**type**\: int
                                
                                	**range:** 1..1440
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent, self).__init__()

                                    self.yang_name = "map-cache-persistent"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ])
                                    self.interval = None
                                    self._segment_path = lambda: "map-cache-persistent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.MapCachePersistent, ['interval'], name, value)


                            class ProxyItr(Entity):
                                """
                                Configures a LISP Proxy Ingress Tunnel Router (PITR)
                                
                                .. attribute:: ipv4_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_addr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr, self).__init__()

                                    self.yang_name = "proxy-itr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_addr', (YLeaf(YType.str, 'ipv4-addr'), ['str'])),
                                        ('ipv6_addr', (YLeaf(YType.str, 'ipv6-addr'), ['str'])),
                                    ])
                                    self.ipv4_addr = None
                                    self.ipv6_addr = None
                                    self._segment_path = lambda: "proxy-itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.ProxyItr, ['ipv4_addr', 'ipv6_addr'], name, value)


                            class RouteExport(Entity):
                                """
                                Export routes into RIB from LISP
                                
                                .. attribute:: site_registrations
                                
                                	Export LISP site registrations to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: away_eids
                                
                                	Export LISP away EIDs to RIB
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteExport, self).__init__()

                                    self.yang_name = "route-export"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                        ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                    ])
                                    self.site_registrations = None
                                    self.away_eids = None
                                    self._segment_path = lambda: "route-export"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                            class UsePetr(Entity):
                                """
                                Encapsulate to Proxy ETR when matching forward\-native entry
                                
                                .. attribute:: locator_address  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: priority
                                
                                	
                                	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.UsePetr, self).__init__()

                                    self.yang_name = "use-petr"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['locator_address']
                                    self._child_classes = OrderedDict([("priority", ("priority", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority))])
                                    self._leafs = OrderedDict([
                                        ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ])
                                    self.locator_address = None

                                    self.priority = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority()
                                    self.priority.parent = self
                                    self._children_name_map["priority"] = "priority"
                                    self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.UsePetr, ['locator_address'], name, value)


                                class Priority(Entity):
                                    """
                                    
                                    
                                    .. attribute:: priority_value
                                    
                                    	Configures which Locators from a set are preferred
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: weight
                                    
                                    	Traffic load\-spreading among Locators
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority, self).__init__()

                                        self.yang_name = "priority"
                                        self.yang_parent_name = "use-petr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority_value', (YLeaf(YType.uint8, 'priority-value'), ['int'])),
                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                        ])
                                        self.priority_value = None
                                        self.weight = None
                                        self._segment_path = lambda: "priority"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.UsePetr.Priority, ['priority_value', 'weight'], name, value)


                            class Import(Entity):
                                """
                                Redistribute LISP states internally
                                
                                .. attribute:: database
                                
                                	Redistribute LISP internal states as database mapping
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import.Database>`
                                
                                .. attribute:: prefix_list_container
                                
                                	Redistribute LISP internal states into LISP prefix\-list entries
                                	**type**\:  :py:class:`PrefixListContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import, self).__init__()

                                    self.yang_name = "import"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import.Database)), ("prefix-list-container", ("prefix_list_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.prefix_list_container = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer()
                                    self.prefix_list_container.parent = self
                                    self._children_name_map["prefix_list_container"] = "prefix-list-container"
                                    self._segment_path = lambda: "import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import, [], name, value)


                                class Database(Entity):
                                    """
                                    Redistribute LISP internal states as database mapping
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set to use with created database mapping entries
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.site_registration = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import.Database, ['site_registration', 'locator_set'], name, value)


                                class PrefixListContainer(Entity):
                                    """
                                    Redistribute LISP internal states into LISP prefix\-list entries
                                    
                                    .. attribute:: prefix_list
                                    
                                    	The name of the lisp prefix list
                                    	**type**\: str
                                    
                                    .. attribute:: site_registration
                                    
                                    	Import states from site registrations
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer, self).__init__()

                                        self.yang_name = "prefix-list-container"
                                        self.yang_parent_name = "import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                        ])
                                        self.prefix_list = None
                                        self.site_registration = None
                                        self._segment_path = lambda: "prefix-list-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.Import.PrefixListContainer, ['prefix_list', 'site_registration'], name, value)


                            class RouteImport(Entity):
                                """
                                Import RIB routes by a routing protocol into LISP
                                
                                .. attribute:: database
                                
                                	Use RIB routes to define local EID database entries
                                	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database>`
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache>`
                                
                                .. attribute:: prefix_list_proto
                                
                                	
                                	**type**\: list of  		 :py:class:`PrefixListProto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport, self).__init__()

                                    self.yang_name = "route-import"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache)), ("prefix-list-proto", ("prefix_list_proto", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto))])
                                    self._leafs = OrderedDict()

                                    self.database = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database()
                                    self.database.parent = self
                                    self._children_name_map["database"] = "database"

                                    self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"

                                    self.prefix_list_proto = YList(self)
                                    self._segment_path = lambda: "route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport, [], name, value)


                                class Database(Entity):
                                    """
                                    Use RIB routes to define local EID database entries
                                    
                                    .. attribute:: application
                                    
                                    	Application Protocol
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected>`
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix>`
                                    
                                    .. attribute:: nd
                                    
                                    	Neighbor Discovery
                                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd>`
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database, self).__init__()

                                        self.yang_name = "database"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip))])
                                        self._leafs = OrderedDict()

                                        self.application = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application()
                                        self.application.parent = self
                                        self._children_name_map["application"] = "application"

                                        self.connected = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected()
                                        self.connected.parent = self
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis()
                                        self.isis.parent = self
                                        self._children_name_map["isis"] = "isis"

                                        self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.nd = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd()
                                        self.nd.parent = self
                                        self._children_name_map["nd"] = "nd"

                                        self.static = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static()
                                        self.static.parent = self
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application Protocol
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Application.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: process_id
                                        
                                        	Process name
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                            ])
                                            self.process_id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis, ['process_id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Nd(Entity):
                                        """
                                        Neighbor Discovery
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd, self).__init__()

                                            self.yang_name = "nd"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "nd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "nd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Nd.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                            self._leafs = OrderedDict()

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static, [], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this process
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_ip_route_import
                                        
                                        	
                                        	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.lisp_ip_route_import = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                            self.lisp_ip_route_import.parent = self
                                            self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip, ['id'], name, value)


                                        class LispIpRouteImport(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            .. attribute:: locator_set
                                            
                                            	Locator set to use with created database mapping entries
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                                self.yang_name = "lisp-ip-route-import"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self.locator_set = None
                                                self._segment_path = lambda: "lisp-ip-route-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: application
                                    
                                    	Application Protocol
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes to pick up from the RIB
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                    
                                    .. attribute:: nd
                                    
                                    	Neighbour Discovery
                                    	**type**\:  :py:class:`Nd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application)), ("bgp", ("bgp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("nd", ("nd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd)), ("ospf", ("ospf", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf)), ("static", ("static", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static)), ("rip", ("rip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip))])
                                        self._leafs = OrderedDict()

                                        self.application = None
                                        self._children_name_map["application"] = "application"

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis()
                                        self.isis.parent = self
                                        self._children_name_map["isis"] = "isis"

                                        self.maximum_prefix = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.nd = None
                                        self._children_name_map["nd"] = "nd"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application Protocol
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Application.MapCacheContainer, ['route_map'], name, value)


                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: id
                                        
                                        	Process name
                                        	**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes to pick up from the RIB
                                        
                                        .. attribute:: number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: threshold1
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: warning_only1
                                        
                                        	Only give a warning message and do not limit entries
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                                ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.warning_only = None
                                            self.threshold = None
                                            self.threshold1 = None
                                            self.warning_only1 = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                    class Nd(Entity):
                                        """
                                        Neighbour Discovery
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd, self).__init__()

                                            self.yang_name = "nd"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "nd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "nd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Nd.MapCacheContainer, ['route_map'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this process
                                        	**type**\: str
                                        
                                        .. attribute:: map_cache_container
                                        
                                        	
                                        	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.map_cache_container = None
                                            self._children_name_map["map_cache_container"] = "map-cache-container"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip, ['id'], name, value)


                                        class MapCacheContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for route selection filtering
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                                self.yang_name = "map-cache-container"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "map-cache-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                class PrefixListProto(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefix_list  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: protocol  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.Protocol>`
                                    
                                    .. attribute:: bgp_id
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`BgpId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId>`
                                    
                                    .. attribute:: eigrp_or_ospf_id
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`EigrpOrOspfId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId>`
                                    
                                    .. attribute:: isis_id
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto, self).__init__()

                                        self.yang_name = "prefix-list-proto"
                                        self.yang_parent_name = "route-import"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix_list','protocol']
                                        self._child_classes = OrderedDict([("bgp-id", ("bgp_id", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId)), ("eigrp-or-ospf-id", ("eigrp_or_ospf_id", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId))])
                                        self._leafs = OrderedDict([
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.Protocol')])),
                                            ('isis_id', (YLeaf(YType.str, 'isis-id'), ['str'])),
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.prefix_list = None
                                        self.protocol = None
                                        self.isis_id = None
                                        self.number = None
                                        self.threshold = None
                                        self.warning_only = None
                                        self.route_map = None

                                        self.bgp_id = YList(self)
                                        self.eigrp_or_ospf_id = YList(self)
                                        self._segment_path = lambda: "prefix-list-proto" + "[prefix-list='" + str(self.prefix_list) + "']" + "[protocol='" + str(self.protocol) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto, ['prefix_list', 'protocol', 'isis_id', 'number', 'threshold', 'warning_only', 'route_map'], name, value)

                                    class Protocol(Enum):
                                        """
                                        Protocol (Enum Class)

                                        .. data:: application = 0

                                        .. data:: bgp = 1

                                        .. data:: connected = 2

                                        .. data:: eigrp = 3

                                        .. data:: isis = 4

                                        .. data:: maximum_prefix = 5

                                        .. data:: nd = 6

                                        .. data:: ospf = 7

                                        .. data:: static = 8

                                        .. data:: rip = 9

                                        """

                                        application = Enum.YLeaf(0, "application")

                                        bgp = Enum.YLeaf(1, "bgp")

                                        connected = Enum.YLeaf(2, "connected")

                                        eigrp = Enum.YLeaf(3, "eigrp")

                                        isis = Enum.YLeaf(4, "isis")

                                        maximum_prefix = Enum.YLeaf(5, "maximum-prefix")

                                        nd = Enum.YLeaf(6, "nd")

                                        ospf = Enum.YLeaf(7, "ospf")

                                        static = Enum.YLeaf(8, "static")

                                        rip = Enum.YLeaf(9, "rip")



                                    class BgpId(Entity):
                                        """
                                        
                                        
                                        .. attribute:: bgp_id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId, self).__init__()

                                            self.yang_name = "bgp-id"
                                            self.yang_parent_name = "prefix-list-proto"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['bgp_id']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bgp_id', (YLeaf(YType.str, 'bgp-id'), ['int','str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.bgp_id = None
                                            self.route_map = None
                                            self._segment_path = lambda: "bgp-id" + "[bgp-id='" + str(self.bgp_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.BgpId, ['bgp_id', 'route_map'], name, value)


                                    class EigrpOrOspfId(Entity):
                                        """
                                        
                                        
                                        .. attribute:: int16_id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, self).__init__()

                                            self.yang_name = "eigrp-or-ospf-id"
                                            self.yang_parent_name = "prefix-list-proto"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['int16_id']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('int16_id', (YLeaf(YType.uint16, 'int16-id'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.int16_id = None
                                            self.route_map = None
                                            self._segment_path = lambda: "eigrp-or-ospf-id" + "[int16-id='" + str(self.int16_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.RouteImport.PrefixListProto.EigrpOrOspfId, ['int16_id', 'route_map'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures Locator addresses for an ETR
                                
                                .. attribute:: eid_cont
                                
                                	
                                	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont>`
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"

                                    self.eid_cont = YList(self)
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping, [], name, value)


                                class EidCont(Entity):
                                    """
                                    
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: locator_set_container
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer>`
                                    
                                    .. attribute:: ipv4_addrees
                                    
                                    	IPv4 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees>`
                                    
                                    .. attribute:: ipv6_addrees
                                    
                                    	IPv6 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees>`
                                    
                                    .. attribute:: ipv4_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface>`
                                    
                                    .. attribute:: ipv6_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface>`
                                    
                                    .. attribute:: auto_discover_rlocs
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont, self).__init__()

                                        self.yang_name = "eid-cont"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ('auto_discover_rlocs', (YLeaf(YType.empty, 'auto-discover-rlocs'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.auto_discover_rlocs = None

                                        self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer()
                                        self.locator_set_container.parent = self
                                        self._children_name_map["locator_set_container"] = "locator-set-container"

                                        self.ipv4_addrees = YList(self)
                                        self.ipv6_addrees = YList(self)
                                        self.ipv4_interface = YList(self)
                                        self.ipv6_interface = YList(self)
                                        self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont, ['eid_prefix', 'auto_discover_rlocs'], name, value)


                                    class LocatorSetContainer(Entity):
                                        """
                                        Use locators defined by locator\-set
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        .. attribute:: proxy
                                        
                                        	Enable configuration of static proxy database mapping
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                            self.yang_name = "locator-set-container"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.proxy = None
                                            self._segment_path = lambda: "locator-set-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                    class Ipv4Addrees(Entity):
                                        """
                                        IPv4 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                            self.yang_name = "ipv4-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv4-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Ipv6Addrees(Entity):
                                        """
                                        IPv6 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                            self.yang_name = "ipv6-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv6-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv4Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                            self.yang_name = "IPv4-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv4-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv6Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                            self.yang_name = "IPv6-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv6-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Ethernet(Entity):
                            """
                            
                            
                            .. attribute:: default
                            
                            	
                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default>`
                            
                            .. attribute:: eid_table
                            
                            	Bind an eid\-table
                            	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.EidTable>`
                            
                            .. attribute:: broadcast_underlay
                            
                            	Multicast group to use for underlay
                            	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay>`
                            
                            .. attribute:: flood
                            
                            	Control flooding or local intercept of broadcast frames
                            	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Flood>`
                            
                            .. attribute:: database_mapping
                            
                            	Configures Locator addresses for an ETR
                            	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping>`
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Itr>`
                            
                            .. attribute:: itr_enable
                            
                            	
                            	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable>`
                            
                            .. attribute:: etr_enable
                            
                            	
                            	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable>`
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr>`
                            
                            .. attribute:: map_cache_limit
                            
                            	Configures maximum size of map\-cache
                            	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit>`
                            
                            .. attribute:: site_registration
                            
                            	Site registrations configuration for a given instance\-id
                            	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration>`
                            
                            .. attribute:: solicit_map_request
                            
                            	Configure Solicit\-Map\-Request handling
                            	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest>`
                            
                            .. attribute:: map_request_source
                            
                            	Configures inner header source address in Map\-Request message
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_cache
                            
                            	Use RIB routes to define EID address space in map\-cache
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet, self).__init__()

                                self.yang_name = "ethernet"
                                self.yang_parent_name = "service"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default)), ("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay)), ("flood", ("flood", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Flood)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                ])
                                self.map_request_source = None

                                self.default = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default()
                                self.default.parent = self
                                self._children_name_map["default"] = "default"

                                self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.EidTable()
                                self.eid_table.parent = self
                                self._children_name_map["eid_table"] = "eid-table"

                                self.broadcast_underlay = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay()
                                self.broadcast_underlay.parent = self
                                self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                self.flood = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Flood()
                                self.flood.parent = self
                                self._children_name_map["flood"] = "flood"

                                self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping()
                                self.database_mapping.parent = self
                                self._children_name_map["database_mapping"] = "database-mapping"

                                self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Itr()
                                self.itr.parent = self
                                self._children_name_map["itr"] = "itr"

                                self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable()
                                self.itr_enable.parent = self
                                self._children_name_map["itr_enable"] = "itr-enable"

                                self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable()
                                self.etr_enable.parent = self
                                self._children_name_map["etr_enable"] = "etr-enable"

                                self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr()
                                self.etr.parent = self
                                self._children_name_map["etr"] = "etr"

                                self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit()
                                self.map_cache_limit.parent = self
                                self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration()
                                self.site_registration.parent = self
                                self._children_name_map["site_registration"] = "site-registration"

                                self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest()
                                self.solicit_map_request.parent = self
                                self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"
                                self._segment_path = lambda: "ethernet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet, ['map_request_source'], name, value)


                            class Default(Entity):
                                """
                                
                                
                                .. attribute:: eid_table
                                
                                	Bind an eid\-table
                                	**type**\:  :py:class:`EidTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.EidTable>`
                                
                                .. attribute:: broadcast_underlay
                                
                                	Multicast group to use for underlay
                                	**type**\:  :py:class:`BroadcastUnderlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.BroadcastUnderlay>`
                                
                                .. attribute:: flood
                                
                                	Control flooding or local intercept of broadcast frames
                                	**type**\:  :py:class:`Flood <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Flood>`
                                
                                .. attribute:: database_mapping
                                
                                	Configures Locator addresses for an ETR
                                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping>`
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr>`
                                
                                .. attribute:: itr_enable
                                
                                	
                                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.ItrEnable>`
                                
                                .. attribute:: etr_enable
                                
                                	
                                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.EtrEnable>`
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr>`
                                
                                .. attribute:: map_cache_limit
                                
                                	Configures maximum size of map\-cache
                                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCacheLimit>`
                                
                                .. attribute:: site_registration
                                
                                	Site registrations configuration for a given instance\-id
                                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.SiteRegistration>`
                                
                                .. attribute:: solicit_map_request
                                
                                	Configure Solicit\-Map\-Request handling
                                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.SolicitMapRequest>`
                                
                                .. attribute:: map_request_source
                                
                                	Configures inner header source address in Map\-Request message
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: map_cache
                                
                                	Use RIB routes to define EID address space in map\-cache
                                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default, self).__init__()

                                    self.yang_name = "default"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-table", ("eid_table", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.EidTable)), ("broadcast-underlay", ("broadcast_underlay", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.BroadcastUnderlay)), ("flood", ("flood", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Flood)), ("database-mapping", ("database_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping)), ("itr", ("itr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.ItrEnable)), ("etr-enable", ("etr_enable", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.EtrEnable)), ("etr", ("etr", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCacheLimit)), ("site-registration", ("site_registration", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.SolicitMapRequest)), ("map-cache", ("map_cache", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache))])
                                    self._leafs = OrderedDict([
                                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str','str'])),
                                    ])
                                    self.map_request_source = None

                                    self.eid_table = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.EidTable()
                                    self.eid_table.parent = self
                                    self._children_name_map["eid_table"] = "eid-table"

                                    self.broadcast_underlay = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.BroadcastUnderlay()
                                    self.broadcast_underlay.parent = self
                                    self._children_name_map["broadcast_underlay"] = "broadcast-underlay"

                                    self.flood = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Flood()
                                    self.flood.parent = self
                                    self._children_name_map["flood"] = "flood"

                                    self.database_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping()
                                    self.database_mapping.parent = self
                                    self._children_name_map["database_mapping"] = "database-mapping"

                                    self.itr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr()
                                    self.itr.parent = self
                                    self._children_name_map["itr"] = "itr"

                                    self.itr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.ItrEnable()
                                    self.itr_enable.parent = self
                                    self._children_name_map["itr_enable"] = "itr-enable"

                                    self.etr_enable = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.EtrEnable()
                                    self.etr_enable.parent = self
                                    self._children_name_map["etr_enable"] = "etr-enable"

                                    self.etr = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr()
                                    self.etr.parent = self
                                    self._children_name_map["etr"] = "etr"

                                    self.map_cache_limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCacheLimit()
                                    self.map_cache_limit.parent = self
                                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                                    self.site_registration = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.SiteRegistration()
                                    self.site_registration.parent = self
                                    self._children_name_map["site_registration"] = "site-registration"

                                    self.solicit_map_request = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.SolicitMapRequest()
                                    self.solicit_map_request.parent = self
                                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                                    self.map_cache = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache()
                                    self.map_cache.parent = self
                                    self._children_name_map["map_cache"] = "map-cache"
                                    self._segment_path = lambda: "default"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default, ['map_request_source'], name, value)


                                class EidTable(Entity):
                                    """
                                    Bind an eid\-table
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN configuration
                                    	**type**\: int
                                    
                                    	**range:** 1..4094
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.EidTable, self).__init__()

                                        self.yang_name = "eid-table"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                        ])
                                        self.vlan = None
                                        self._segment_path = lambda: "eid-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.EidTable, ['vlan'], name, value)


                                class BroadcastUnderlay(Entity):
                                    """
                                    Multicast group to use for underlay
                                    
                                    .. attribute:: ipv4_multicast
                                    
                                    	IPv4 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_multicast
                                    
                                    	IPv6 multicast group address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.BroadcastUnderlay, self).__init__()

                                        self.yang_name = "broadcast-underlay"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                            ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                        ])
                                        self.ipv4_multicast = None
                                        self.ipv6_multicast = None
                                        self._segment_path = lambda: "broadcast-underlay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                                class Flood(Entity):
                                    """
                                    Control flooding or local intercept of broadcast frames
                                    
                                    .. attribute:: arp_nd
                                    
                                    	IPv4 ARP / IPv6 ND
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Frames with unknown destination MAC
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Flood, self).__init__()

                                        self.yang_name = "flood"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                            ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                        ])
                                        self.arp_nd = None
                                        self.unknown_unicast = None
                                        self._segment_path = lambda: "flood"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                                class DatabaseMapping(Entity):
                                    """
                                    Configures Locator addresses for an ETR
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont>`
                                    
                                    .. attribute:: mac
                                    
                                    	L2 EID records
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Mac>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: limit
                                    
                                    	Configures the maximum size of local EID prefixes database
                                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Limit>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping, self).__init__()

                                        self.yang_name = "database-mapping"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Limit))])
                                        self._leafs = OrderedDict()

                                        self.mac = None
                                        self._children_name_map["mac"] = "mac"

                                        self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Limit()
                                        self.limit.parent = self
                                        self._children_name_map["limit"] = "limit"

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "database-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: locator_set_container
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.LocatorSetContainer>`
                                        
                                        .. attribute:: ipv4_addrees
                                        
                                        	IPv4 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees>`
                                        
                                        .. attribute:: ipv6_addrees
                                        
                                        	IPv6 Address of loopback or other ETR interface
                                        	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees>`
                                        
                                        .. attribute:: ipv4_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface>`
                                        
                                        .. attribute:: ipv6_interface
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.LocatorSetContainer()
                                            self.locator_set_container.parent = self
                                            self._children_name_map["locator_set_container"] = "locator-set-container"

                                            self.ipv4_addrees = YList(self)
                                            self.ipv6_addrees = YList(self)
                                            self.ipv4_interface = YList(self)
                                            self.ipv6_interface = YList(self)
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                        class LocatorSetContainer(Entity):
                                            """
                                            Use locators defined by locator\-set
                                            
                                            .. attribute:: locator_set
                                            
                                            	Use locators defined by locator\-set
                                            	**type**\: str
                                            
                                            .. attribute:: proxy
                                            
                                            	Enable configuration of static proxy database mapping
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                                self.yang_name = "locator-set-container"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                    ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                                ])
                                                self.locator_set = None
                                                self.proxy = None
                                                self._segment_path = lambda: "locator-set-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                        class Ipv4Addrees(Entity):
                                            """
                                            IPv4 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                                self.yang_name = "ipv4-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv4-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class Ipv6Addrees(Entity):
                                            """
                                            IPv6 Address of loopback or other ETR interface
                                            
                                            .. attribute:: address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                                self.yang_name = "ipv6-addrees"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['address']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "ipv6-addrees"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv4Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                                self.yang_name = "IPv4-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv4-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                        class IPv6Interface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	Use IPv4 address of interface as locator
                                            	**type**\: str
                                            
                                            .. attribute:: database_mapping_option
                                            
                                            	
                                            	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                                self.yang_name = "IPv6-interface"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.name = None

                                                self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                                self.database_mapping_option.parent = self
                                                self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                                self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                            class DatabaseMappingOption(Entity):
                                                """
                                                
                                                
                                                .. attribute:: priority
                                                
                                                	Configures which Locators from a set are preferred
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: weight
                                                
                                                	Traffic load\-spreading among Locators
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: down
                                                
                                                	Configure this database mapping down
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                    self.yang_name = "database-mapping-option"
                                                    self.yang_parent_name = "IPv6-interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                    ])
                                                    self.priority = None
                                                    self.weight = None
                                                    self.down = None
                                                    self._segment_path = lambda: "database-mapping-option"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Mac(Entity):
                                        """
                                        L2 EID records
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.locator_set = None
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Mac, ['locator_set'], name, value)


                                    class Limit(Entity):
                                        """
                                        Configures the maximum size of local EID prefixes database
                                        
                                        .. attribute:: dynamic
                                        
                                        	Configures the maximum size of dynamic local EID prefixes database
                                        	**type**\: int
                                        
                                        	**range:** 1..5000
                                        
                                        .. attribute:: warning_threshold
                                        
                                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Limit, self).__init__()

                                            self.yang_name = "limit"
                                            self.yang_parent_name = "database-mapping"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                            ])
                                            self.dynamic = None
                                            self.warning_threshold = None
                                            self._segment_path = lambda: "limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                                class Itr(Entity):
                                    """
                                    Configures a LISP Ingress Tunnel Router (ITR)
                                    
                                    .. attribute:: map_resolver
                                    
                                    	Configures map\-resolver address for sending Map\-Requests
                                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr.MapResolver>`
                                    
                                    .. attribute:: nmr_ttl
                                    
                                    	verride negative map\-reply TTL for site EID
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr, self).__init__()

                                        self.yang_name = "itr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr.MapResolver))])
                                        self._leafs = OrderedDict([
                                            ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                        ])
                                        self.nmr_ttl = None

                                        self.map_resolver = YList(self)
                                        self._segment_path = lambda: "itr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr, ['nmr_ttl'], name, value)


                                    class MapResolver(Entity):
                                        """
                                        Configures map\-resolver address for sending Map\-Requests
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Associates ITR/ETR with prefix list
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr.MapResolver, self).__init__()

                                            self.yang_name = "map-resolver"
                                            self.yang_parent_name = "itr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ])
                                            self.ip_addr = None
                                            self.prefix_list = None
                                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                                class ItrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: itr
                                    
                                    	Configures a LISP Ingress Tunnel Router (ITR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.ItrEnable, self).__init__()

                                        self.yang_name = "itr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                        ])
                                        self.itr = None
                                        self._segment_path = lambda: "itr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.ItrEnable, ['itr'], name, value)


                                class EtrEnable(Entity):
                                    """
                                    
                                    
                                    .. attribute:: etr
                                    
                                    	Configures a LISP Egress Tunnel Router (ETR)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.EtrEnable, self).__init__()

                                        self.yang_name = "etr-enable"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                        ])
                                        self.etr = None
                                        self._segment_path = lambda: "etr-enable"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.EtrEnable, ['etr'], name, value)


                                class Etr(Entity):
                                    """
                                    Configures a LISP Egress Tunnel Router (ETR)
                                    
                                    .. attribute:: map_server
                                    
                                    	Configures map server for ETR registration
                                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer>`
                                    
                                    .. attribute:: map_cache_ttl
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 60..10080
                                    
                                    .. attribute:: accept_map_request_mapping
                                    
                                    	
                                    	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr, self).__init__()

                                        self.yang_name = "etr"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping))])
                                        self._leafs = OrderedDict([
                                            ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                        ])
                                        self.map_cache_ttl = None

                                        self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping()
                                        self.accept_map_request_mapping.parent = self
                                        self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                        self.map_server = YList(self)
                                        self._segment_path = lambda: "etr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr, ['map_cache_ttl'], name, value)


                                    class MapServer(Entity):
                                        """
                                        Configures map server for ETR registration
                                        
                                        .. attribute:: ip_addr  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key used with map server
                                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key>`
                                        
                                        .. attribute:: proxy_reply
                                        
                                        	Request Map\-Server to send Map\-Replies on behalf of site
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer, self).__init__()

                                            self.yang_name = "map-server"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ip_addr']
                                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key))])
                                            self._leafs = OrderedDict([
                                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                            ])
                                            self.ip_addr = None
                                            self.proxy_reply = None

                                            self.key = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                        class Key(Entity):
                                            """
                                            Authentication key used with map server
                                            
                                            .. attribute:: key_pwd
                                            
                                            	
                                            	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd>`
                                            
                                            .. attribute:: key_0
                                            
                                            	
                                            	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0>`
                                            
                                            .. attribute:: key_6
                                            
                                            	
                                            	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6>`
                                            
                                            .. attribute:: key_7
                                            
                                            	
                                            	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "map-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7))])
                                                self._leafs = OrderedDict()

                                                self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd()
                                                self.key_pwd.parent = self
                                                self._children_name_map["key_pwd"] = "key-pwd"

                                                self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0()
                                                self.key_0.parent = self
                                                self._children_name_map["key_0"] = "key-0"

                                                self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6()
                                                self.key_6.parent = self
                                                self._children_name_map["key_6"] = "key-6"

                                                self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7()
                                                self.key_7.parent = self
                                                self._children_name_map["key_7"] = "key-7"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key, [], name, value)


                                            class KeyPwd(Entity):
                                                """
                                                
                                                
                                                .. attribute:: unc_pwd
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                    self.yang_name = "key-pwd"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.unc_pwd = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-pwd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key0(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_0
                                                
                                                	The UNENCRYPTED (cleartext) password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0, self).__init__()

                                                    self.yang_name = "key-0"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_0 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-0"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key6(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_6
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6, self).__init__()

                                                    self.yang_name = "key-6"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_6 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                            class Key7(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ak_7
                                                
                                                	The ENCRYPTED password
                                                	**type**\: str
                                                
                                                .. attribute:: hash_function
                                                
                                                	authentication type
                                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7.HashFunction>`
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Associates ITR/ETR with prefix list
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-lisp'
                                                _revision = '2018-04-17'

                                                def __init__(self):
                                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7, self).__init__()

                                                    self.yang_name = "key-7"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7.HashFunction')])),
                                                        ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                    ])
                                                    self.ak_7 = None
                                                    self.hash_function = None
                                                    self.prefix_list = None
                                                    self._segment_path = lambda: "key-7"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                                class HashFunction(Enum):
                                                    """
                                                    HashFunction (Enum Class)

                                                    authentication type

                                                    .. data:: sha1 = 0

                                                    .. data:: sha2 = 1

                                                    """

                                                    sha1 = Enum.YLeaf(0, "sha1")

                                                    sha2 = Enum.YLeaf(1, "sha2")



                                    class AcceptMapRequestMapping(Entity):
                                        """
                                        
                                        
                                        .. attribute:: accept_mappping
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: verify
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping, self).__init__()

                                            self.yang_name = "accept-map-request-mapping"
                                            self.yang_parent_name = "etr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                                ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                            ])
                                            self.accept_mappping = None
                                            self.verify = None
                                            self._segment_path = lambda: "accept-map-request-mapping"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                                class MapCacheLimit(Entity):
                                    """
                                    Configures maximum size of map\-cache
                                    
                                    .. attribute:: max_map_cache_entries
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..100000
                                    
                                    .. attribute:: reserve_list
                                    
                                    	EID\-prefixes guaranteed to be stored in map\-cache
                                    	**type**\: str
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 0..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCacheLimit, self).__init__()

                                        self.yang_name = "map-cache-limit"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.max_map_cache_entries = None
                                        self.reserve_list = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "map-cache-limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                                class SiteRegistration(Entity):
                                    """
                                    Site registrations configuration for a given instance\-id
                                    
                                    .. attribute:: limit
                                    
                                    	Maximum number of site registrations
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Warning threshold to issue system logging
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.SiteRegistration, self).__init__()

                                        self.yang_name = "site-registration"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.limit = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "site-registration"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                                class SolicitMapRequest(Entity):
                                    """
                                    Configure Solicit\-Map\-Request handling
                                    
                                    .. attribute:: ignore
                                    
                                    	Ignore SMR bit in incoming Map\-Requests
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: max_per_entry
                                    
                                    	Maximum number of SMRs for addresses under a map\-cache entry
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: suppression_time
                                    
                                    	How long to suppress repeated SMRs for the same address
                                    	**type**\: int
                                    
                                    	**range:** 1..600
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.SolicitMapRequest, self).__init__()

                                        self.yang_name = "solicit-map-request"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                        ])
                                        self.ignore = None
                                        self.max_per_entry = None
                                        self.suppression_time = None
                                        self._segment_path = lambda: "solicit-map-request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                                class MapCache(Entity):
                                    """
                                    Use RIB routes to define EID address space in map\-cache
                                    
                                    .. attribute:: eid_cont
                                    
                                    	EID\-record for RLOC static mapping
                                    	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache, self).__init__()

                                        self.yang_name = "map-cache"
                                        self.yang_parent_name = "default"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont))])
                                        self._leafs = OrderedDict()

                                        self.eid_cont = YList(self)
                                        self._segment_path = lambda: "map-cache"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache, [], name, value)


                                    class EidCont(Entity):
                                        """
                                        EID\-record for RLOC static mapping
                                        
                                        .. attribute:: eid_prefix  (key)
                                        
                                        	xxxx.xxxx.xxxx 48 bit mac address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                        
                                        .. attribute:: etr_interface_ip
                                        
                                        	
                                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont.EtrInterfaceIp>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont, self).__init__()

                                            self.yang_name = "eid-cont"
                                            self.yang_parent_name = "map-cache"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['eid_prefix']
                                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont.EtrInterfaceIp))])
                                            self._leafs = OrderedDict([
                                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                            ])
                                            self.eid_prefix = None

                                            self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont.EtrInterfaceIp()
                                            self.etr_interface_ip.parent = self
                                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                            self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont, ['eid_prefix'], name, value)


                                        class EtrInterfaceIp(Entity):
                                            """
                                            
                                            
                                            .. attribute:: etr_interface_ip_address
                                            
                                            	IP address of loopback or other ETR interface
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                                self.yang_name = "etr-interface-ip"
                                                self.yang_parent_name = "eid-cont"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.etr_interface_ip_address = None
                                                self.priority = None
                                                self.weight = None
                                                self._segment_path = lambda: "etr-interface-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Default.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


                            class EidTable(Entity):
                                """
                                Bind an eid\-table
                                
                                .. attribute:: vlan
                                
                                	VLAN configuration
                                	**type**\: int
                                
                                	**range:** 1..4094
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.EidTable, self).__init__()

                                    self.yang_name = "eid-table"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                                    ])
                                    self.vlan = None
                                    self._segment_path = lambda: "eid-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.EidTable, ['vlan'], name, value)


                            class BroadcastUnderlay(Entity):
                                """
                                Multicast group to use for underlay
                                
                                .. attribute:: ipv4_multicast
                                
                                	IPv4 multicast group address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_multicast
                                
                                	IPv6 multicast group address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay, self).__init__()

                                    self.yang_name = "broadcast-underlay"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_multicast', (YLeaf(YType.str, 'ipv4-multicast'), ['str'])),
                                        ('ipv6_multicast', (YLeaf(YType.str, 'ipv6-multicast'), ['str'])),
                                    ])
                                    self.ipv4_multicast = None
                                    self.ipv6_multicast = None
                                    self._segment_path = lambda: "broadcast-underlay"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.BroadcastUnderlay, ['ipv4_multicast', 'ipv6_multicast'], name, value)


                            class Flood(Entity):
                                """
                                Control flooding or local intercept of broadcast frames
                                
                                .. attribute:: arp_nd
                                
                                	IPv4 ARP / IPv6 ND
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Frames with unknown destination MAC
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Flood, self).__init__()

                                    self.yang_name = "flood"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('arp_nd', (YLeaf(YType.empty, 'arp-nd'), ['Empty'])),
                                        ('unknown_unicast', (YLeaf(YType.empty, 'unknown-unicast'), ['Empty'])),
                                    ])
                                    self.arp_nd = None
                                    self.unknown_unicast = None
                                    self._segment_path = lambda: "flood"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Flood, ['arp_nd', 'unknown_unicast'], name, value)


                            class DatabaseMapping(Entity):
                                """
                                Configures Locator addresses for an ETR
                                
                                .. attribute:: eid_cont
                                
                                	EID\-record for RLOC static mapping
                                	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont>`
                                
                                .. attribute:: mac
                                
                                	L2 EID records
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: limit
                                
                                	Configures the maximum size of local EID prefixes database
                                	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping, self).__init__()

                                    self.yang_name = "database-mapping"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont)), ("mac", ("mac", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac)), ("limit", ("limit", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit))])
                                    self._leafs = OrderedDict()

                                    self.mac = None
                                    self._children_name_map["mac"] = "mac"

                                    self.limit = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit()
                                    self.limit.parent = self
                                    self._children_name_map["limit"] = "limit"

                                    self.eid_cont = YList(self)
                                    self._segment_path = lambda: "database-mapping"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping, [], name, value)


                                class EidCont(Entity):
                                    """
                                    EID\-record for RLOC static mapping
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	xxxx.xxxx.xxxx 48 bit mac address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                    
                                    .. attribute:: locator_set_container
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\:  :py:class:`LocatorSetContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer>`
                                    
                                    .. attribute:: ipv4_addrees
                                    
                                    	IPv4 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv4Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees>`
                                    
                                    .. attribute:: ipv6_addrees
                                    
                                    	IPv6 Address of loopback or other ETR interface
                                    	**type**\: list of  		 :py:class:`Ipv6Addrees <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees>`
                                    
                                    .. attribute:: ipv4_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv4Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface>`
                                    
                                    .. attribute:: ipv6_interface
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IPv6Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont, self).__init__()

                                        self.yang_name = "eid-cont"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("locator-set-container", ("locator_set_container", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer)), ("ipv4-addrees", ("ipv4_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees)), ("ipv6-addrees", ("ipv6_addrees", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees)), ("IPv4-interface", ("ipv4_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface)), ("IPv6-interface", ("ipv6_interface", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                        ])
                                        self.eid_prefix = None

                                        self.locator_set_container = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer()
                                        self.locator_set_container.parent = self
                                        self._children_name_map["locator_set_container"] = "locator-set-container"

                                        self.ipv4_addrees = YList(self)
                                        self.ipv6_addrees = YList(self)
                                        self.ipv4_interface = YList(self)
                                        self.ipv6_interface = YList(self)
                                        self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont, ['eid_prefix'], name, value)


                                    class LocatorSetContainer(Entity):
                                        """
                                        Use locators defined by locator\-set
                                        
                                        .. attribute:: locator_set
                                        
                                        	Use locators defined by locator\-set
                                        	**type**\: str
                                        
                                        .. attribute:: proxy
                                        
                                        	Enable configuration of static proxy database mapping
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, self).__init__()

                                            self.yang_name = "locator-set-container"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                                ('proxy', (YLeaf(YType.empty, 'proxy'), ['Empty'])),
                                            ])
                                            self.locator_set = None
                                            self.proxy = None
                                            self._segment_path = lambda: "locator-set-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.LocatorSetContainer, ['locator_set', 'proxy'], name, value)


                                    class Ipv4Addrees(Entity):
                                        """
                                        IPv4 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, self).__init__()

                                            self.yang_name = "ipv4-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv4-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv4-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv4Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class Ipv6Addrees(Entity):
                                        """
                                        IPv6 Address of loopback or other ETR interface
                                        
                                        .. attribute:: address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, self).__init__()

                                            self.yang_name = "ipv6-addrees"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['address']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ])
                                            self.address = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "ipv6-addrees" + "[address='" + str(self.address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees, ['address'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "ipv6-addrees"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.Ipv6Addrees.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv4Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, self).__init__()

                                            self.yang_name = "IPv4-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv4-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv4-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv4Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                    class IPv6Interface(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	Use IPv4 address of interface as locator
                                        	**type**\: str
                                        
                                        .. attribute:: database_mapping_option
                                        
                                        	
                                        	**type**\:  :py:class:`DatabaseMappingOption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, self).__init__()

                                            self.yang_name = "IPv6-interface"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("database-mapping-option", ("database_mapping_option", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.database_mapping_option = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption()
                                            self.database_mapping_option.parent = self
                                            self._children_name_map["database_mapping_option"] = "database-mapping-option"
                                            self._segment_path = lambda: "IPv6-interface" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface, ['name'], name, value)


                                        class DatabaseMappingOption(Entity):
                                            """
                                            
                                            
                                            .. attribute:: priority
                                            
                                            	Configures which Locators from a set are preferred
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: weight
                                            
                                            	Traffic load\-spreading among Locators
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: down
                                            
                                            	Configure this database mapping down
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, self).__init__()

                                                self.yang_name = "database-mapping-option"
                                                self.yang_parent_name = "IPv6-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self.weight = None
                                                self.down = None
                                                self._segment_path = lambda: "database-mapping-option"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.EidCont.IPv6Interface.DatabaseMappingOption, ['priority', 'weight', 'down'], name, value)


                                class Mac(Entity):
                                    """
                                    L2 EID records
                                    
                                    .. attribute:: locator_set
                                    
                                    	Use locators defined by locator\-set
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.locator_set = None
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Mac, ['locator_set'], name, value)


                                class Limit(Entity):
                                    """
                                    Configures the maximum size of local EID prefixes database
                                    
                                    .. attribute:: dynamic
                                    
                                    	Configures the maximum size of dynamic local EID prefixes database
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: warning_threshold
                                    
                                    	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit, self).__init__()

                                        self.yang_name = "limit"
                                        self.yang_parent_name = "database-mapping"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                        ])
                                        self.dynamic = None
                                        self.warning_threshold = None
                                        self._segment_path = lambda: "limit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                            class Itr(Entity):
                                """
                                Configures a LISP Ingress Tunnel Router (ITR)
                                
                                .. attribute:: map_resolver
                                
                                	Configures map\-resolver address for sending Map\-Requests
                                	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver>`
                                
                                .. attribute:: nmr_ttl
                                
                                	verride negative map\-reply TTL for site EID
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Itr, self).__init__()

                                    self.yang_name = "itr"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver))])
                                    self._leafs = OrderedDict([
                                        ('nmr_ttl', (YLeaf(YType.uint16, 'nmr-ttl'), ['int'])),
                                    ])
                                    self.nmr_ttl = None

                                    self.map_resolver = YList(self)
                                    self._segment_path = lambda: "itr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Itr, ['nmr_ttl'], name, value)


                                class MapResolver(Entity):
                                    """
                                    Configures map\-resolver address for sending Map\-Requests
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Associates ITR/ETR with prefix list
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver, self).__init__()

                                        self.yang_name = "map-resolver"
                                        self.yang_parent_name = "itr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                        ])
                                        self.ip_addr = None
                                        self.prefix_list = None
                                        self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Itr.MapResolver, ['ip_addr', 'prefix_list'], name, value)


                            class ItrEnable(Entity):
                                """
                                
                                
                                .. attribute:: itr
                                
                                	Configures a LISP Ingress Tunnel Router (ITR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable, self).__init__()

                                    self.yang_name = "itr-enable"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                    ])
                                    self.itr = None
                                    self._segment_path = lambda: "itr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.ItrEnable, ['itr'], name, value)


                            class EtrEnable(Entity):
                                """
                                
                                
                                .. attribute:: etr
                                
                                	Configures a LISP Egress Tunnel Router (ETR)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable, self).__init__()

                                    self.yang_name = "etr-enable"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                    ])
                                    self.etr = None
                                    self._segment_path = lambda: "etr-enable"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.EtrEnable, ['etr'], name, value)


                            class Etr(Entity):
                                """
                                Configures a LISP Egress Tunnel Router (ETR)
                                
                                .. attribute:: map_server
                                
                                	Configures map server for ETR registration
                                	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer>`
                                
                                .. attribute:: map_cache_ttl
                                
                                	
                                	**type**\: int
                                
                                	**range:** 60..10080
                                
                                .. attribute:: accept_map_request_mapping
                                
                                	
                                	**type**\:  :py:class:`AcceptMapRequestMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr, self).__init__()

                                    self.yang_name = "etr"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer)), ("accept-map-request-mapping", ("accept_map_request_mapping", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping))])
                                    self._leafs = OrderedDict([
                                        ('map_cache_ttl', (YLeaf(YType.uint16, 'map-cache-ttl'), ['int'])),
                                    ])
                                    self.map_cache_ttl = None

                                    self.accept_map_request_mapping = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping()
                                    self.accept_map_request_mapping.parent = self
                                    self._children_name_map["accept_map_request_mapping"] = "accept-map-request-mapping"

                                    self.map_server = YList(self)
                                    self._segment_path = lambda: "etr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr, ['map_cache_ttl'], name, value)


                                class MapServer(Entity):
                                    """
                                    Configures map server for ETR registration
                                    
                                    .. attribute:: ip_addr  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key used with map server
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key>`
                                    
                                    .. attribute:: proxy_reply
                                    
                                    	Request Map\-Server to send Map\-Replies on behalf of site
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer, self).__init__()

                                        self.yang_name = "map-server"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_addr']
                                        self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key))])
                                        self._leafs = OrderedDict([
                                            ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                            ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                        ])
                                        self.ip_addr = None
                                        self.proxy_reply = None

                                        self.key = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                    class Key(Entity):
                                        """
                                        Authentication key used with map server
                                        
                                        .. attribute:: key_pwd
                                        
                                        	
                                        	**type**\:  :py:class:`KeyPwd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd>`
                                        
                                        .. attribute:: key_0
                                        
                                        	
                                        	**type**\:  :py:class:`Key0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0>`
                                        
                                        .. attribute:: key_6
                                        
                                        	
                                        	**type**\:  :py:class:`Key6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6>`
                                        
                                        .. attribute:: key_7
                                        
                                        	
                                        	**type**\:  :py:class:`Key7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "map-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("key-pwd", ("key_pwd", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd)), ("key-0", ("key_0", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0)), ("key-6", ("key_6", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6)), ("key-7", ("key_7", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7))])
                                            self._leafs = OrderedDict()

                                            self.key_pwd = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd()
                                            self.key_pwd.parent = self
                                            self._children_name_map["key_pwd"] = "key-pwd"

                                            self.key_0 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0()
                                            self.key_0.parent = self
                                            self._children_name_map["key_0"] = "key-0"

                                            self.key_6 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6()
                                            self.key_6.parent = self
                                            self._children_name_map["key_6"] = "key-6"

                                            self.key_7 = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7()
                                            self.key_7.parent = self
                                            self._children_name_map["key_7"] = "key-7"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key, [], name, value)


                                        class KeyPwd(Entity):
                                            """
                                            
                                            
                                            .. attribute:: unc_pwd
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd, self).__init__()

                                                self.yang_name = "key-pwd"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.unc_pwd = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-pwd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.KeyPwd, ['unc_pwd', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key0(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_0
                                            
                                            	The UNENCRYPTED (cleartext) password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0, self).__init__()

                                                self.yang_name = "key-0"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_0 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-0"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key0, ['ak_0', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key6(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_6
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6, self).__init__()

                                                self.yang_name = "key-6"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_6 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-6"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key6, ['ak_6', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                        class Key7(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ak_7
                                            
                                            	The ENCRYPTED password
                                            	**type**\: str
                                            
                                            .. attribute:: hash_function
                                            
                                            	authentication type
                                            	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Associates ITR/ETR with prefix list
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-lisp'
                                            _revision = '2018-04-17'

                                            def __init__(self):
                                                super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7, self).__init__()

                                                self.yang_name = "key-7"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ak_7', (YLeaf(YType.str, 'ak-7'), ['str'])),
                                                    ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7.HashFunction')])),
                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                ])
                                                self.ak_7 = None
                                                self.hash_function = None
                                                self.prefix_list = None
                                                self._segment_path = lambda: "key-7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.MapServer.Key.Key7, ['ak_7', 'hash_function', 'prefix_list'], name, value)

                                            class HashFunction(Enum):
                                                """
                                                HashFunction (Enum Class)

                                                authentication type

                                                .. data:: sha1 = 0

                                                .. data:: sha2 = 1

                                                """

                                                sha1 = Enum.YLeaf(0, "sha1")

                                                sha2 = Enum.YLeaf(1, "sha2")



                                class AcceptMapRequestMapping(Entity):
                                    """
                                    
                                    
                                    .. attribute:: accept_mappping
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: verify
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping, self).__init__()

                                        self.yang_name = "accept-map-request-mapping"
                                        self.yang_parent_name = "etr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('accept_mappping', (YLeaf(YType.empty, 'accept-mappping'), ['Empty'])),
                                            ('verify', (YLeaf(YType.empty, 'verify'), ['Empty'])),
                                        ])
                                        self.accept_mappping = None
                                        self.verify = None
                                        self._segment_path = lambda: "accept-map-request-mapping"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.Etr.AcceptMapRequestMapping, ['accept_mappping', 'verify'], name, value)


                            class MapCacheLimit(Entity):
                                """
                                Configures maximum size of map\-cache
                                
                                .. attribute:: max_map_cache_entries
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..100000
                                
                                .. attribute:: reserve_list
                                
                                	EID\-prefixes guaranteed to be stored in map\-cache
                                	**type**\: str
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit, self).__init__()

                                    self.yang_name = "map-cache-limit"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                        ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.max_map_cache_entries = None
                                    self.reserve_list = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "map-cache-limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                            class SiteRegistration(Entity):
                                """
                                Site registrations configuration for a given instance\-id
                                
                                .. attribute:: limit
                                
                                	Maximum number of site registrations
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Warning threshold to issue system logging
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration, self).__init__()

                                    self.yang_name = "site-registration"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.limit = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "site-registration"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                            class SolicitMapRequest(Entity):
                                """
                                Configure Solicit\-Map\-Request handling
                                
                                .. attribute:: ignore
                                
                                	Ignore SMR bit in incoming Map\-Requests
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: max_per_entry
                                
                                	Maximum number of SMRs for addresses under a map\-cache entry
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: suppression_time
                                
                                	How long to suppress repeated SMRs for the same address
                                	**type**\: int
                                
                                	**range:** 1..600
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest, self).__init__()

                                    self.yang_name = "solicit-map-request"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                        ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                        ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                    ])
                                    self.ignore = None
                                    self.max_per_entry = None
                                    self.suppression_time = None
                                    self._segment_path = lambda: "solicit-map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                            class MapCache(Entity):
                                """
                                Use RIB routes to define EID address space in map\-cache
                                
                                .. attribute:: eid_cont
                                
                                	EID\-record for RLOC static mapping
                                	**type**\: list of  		 :py:class:`EidCont <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "ethernet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eid-cont", ("eid_cont", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont))])
                                    self._leafs = OrderedDict()

                                    self.eid_cont = YList(self)
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache, [], name, value)


                                class EidCont(Entity):
                                    """
                                    EID\-record for RLOC static mapping
                                    
                                    .. attribute:: eid_prefix  (key)
                                    
                                    	xxxx.xxxx.xxxx 48 bit mac address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+\\.[0\-9a\-fA\-F]+
                                    
                                    .. attribute:: etr_interface_ip
                                    
                                    	
                                    	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont, self).__init__()

                                        self.yang_name = "eid-cont"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['eid_prefix']
                                        self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp))])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                        ])
                                        self.eid_prefix = None

                                        self.etr_interface_ip = Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp()
                                        self.etr_interface_ip.parent = self
                                        self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                                        self._segment_path = lambda: "eid-cont" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont, ['eid_prefix'], name, value)


                                    class EtrInterfaceIp(Entity):
                                        """
                                        
                                        
                                        .. attribute:: etr_interface_ip_address
                                        
                                        	IP address of loopback or other ETR interface
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Configures which Locators from a set are preferred
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: weight
                                        
                                        	Traffic load\-spreading among Locators
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, self).__init__()

                                            self.yang_name = "etr-interface-ip"
                                            self.yang_parent_name = "eid-cont"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ])
                                            self.etr_interface_ip_address = None
                                            self.priority = None
                                            self.weight = None
                                            self._segment_path = lambda: "etr-interface-ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.InstanceContainer.InstanceList.Service.Ethernet.MapCache.EidCont.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


            class Alt(Entity):
                """
                LISP Alternative Topology, LISP\-ALT
                
                .. attribute:: summary_route
                
                	Summary route to install into the ALT table
                	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Alt.SummaryRoute>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Alt, self).__init__()

                    self.yang_name = "alt"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.Alt.SummaryRoute))])
                    self._leafs = OrderedDict()

                    self.summary_route = YList(self)
                    self._segment_path = lambda: "alt"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Alt, [], name, value)


                class SummaryRoute(Entity):
                    """
                    Summary route to install into the ALT table
                    
                    .. attribute:: eid_prefix  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                    
                    .. attribute:: route_tag
                    
                    	ALT RIB route tag for EID prefix
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Alt.SummaryRoute, self).__init__()

                        self.yang_name = "summary-route"
                        self.yang_parent_name = "alt"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['eid_prefix']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                            ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                        ])
                        self.eid_prefix = None
                        self.route_tag = None
                        self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


            class ControlPacket(Entity):
                """
                Configure control packet tx option
                
                .. attribute:: mtu
                
                	Configure control packet MTU
                	**type**\: int
                
                	**range:** 304..10000
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.ControlPacket, self).__init__()

                    self.yang_name = "control-packet"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                    ])
                    self.mtu = None
                    self._segment_path = lambda: "control-packet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.ControlPacket, ['mtu'], name, value)


            class Ddt(Entity):
                """
                Delegated Database Tree (DDT) mapping system
                
                .. attribute:: authoritative
                
                	DDT authoritative prefix
                	**type**\:  :py:class:`Authoritative <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ddt.Authoritative>`
                
                .. attribute:: cache_limit
                
                	DDT resolver cache entry limit
                	**type**\: int
                
                	**range:** 1..100000
                
                .. attribute:: root
                
                	DDT root node
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Ddt, self).__init__()

                    self.yang_name = "ddt"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("authoritative", ("authoritative", Native.Router.LispList.Ddt.Authoritative))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('cache_limit', (YLeaf(YType.uint32, 'cache-limit'), ['int'])),
                        ('root', (YLeaf(YType.str, 'root'), ['str','str'])),
                    ])
                    self.cache_limit = None
                    self.root = None

                    self.authoritative = Native.Router.LispList.Ddt.Authoritative()
                    self.authoritative.parent = self
                    self._children_name_map["authoritative"] = "authoritative"
                    self._segment_path = lambda: "ddt"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Ddt, ['cache_limit', 'root'], name, value)


                class Authoritative(Entity):
                    """
                    DDT authoritative prefix
                    
                    .. attribute:: instance_id_eid_prefix_list
                    
                    	
                    	**type**\: list of  		 :py:class:`InstanceIdEidPrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ddt.Authoritative.InstanceIdEidPrefixList>`
                    
                    .. attribute:: instance_id_list
                    
                    	
                    	**type**\: list of  		 :py:class:`InstanceIdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ddt.Authoritative.InstanceIdList>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ddt.Authoritative, self).__init__()

                        self.yang_name = "authoritative"
                        self.yang_parent_name = "ddt"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("instance-id-eid-prefix-list", ("instance_id_eid_prefix_list", Native.Router.LispList.Ddt.Authoritative.InstanceIdEidPrefixList)), ("instance-id-list", ("instance_id_list", Native.Router.LispList.Ddt.Authoritative.InstanceIdList))])
                        self._leafs = OrderedDict()

                        self.instance_id_eid_prefix_list = YList(self)
                        self.instance_id_list = YList(self)
                        self._segment_path = lambda: "authoritative"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ddt.Authoritative, [], name, value)


                    class InstanceIdEidPrefixList(Entity):
                        """
                        
                        
                        .. attribute:: instance_id  (key)
                        
                        	EID instance\-ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: eid_prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: delegate
                        
                        	DDT delegation to a child DDT node or map\-server
                        	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate>`
                        
                        .. attribute:: map_server_peer
                        
                        	Peer map\-servers that are authoritative for the same EID prefixes
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ddt.Authoritative.InstanceIdEidPrefixList, self).__init__()

                            self.yang_name = "instance-id-eid-prefix-list"
                            self.yang_parent_name = "authoritative"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance_id','eid_prefix']
                            self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.LispList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate))])
                            self._leafs = OrderedDict([
                                ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                            ])
                            self.instance_id = None
                            self.eid_prefix = None
                            self.map_server_peer = None

                            self.delegate = Native.Router.LispList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate()
                            self.delegate.parent = self
                            self._children_name_map["delegate"] = "delegate"
                            self._segment_path = lambda: "instance-id-eid-prefix-list" + "[instance-id='" + str(self.instance_id) + "']" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ddt.Authoritative.InstanceIdEidPrefixList, ['instance_id', 'eid_prefix', 'map_server_peer'], name, value)


                        class Delegate(Entity):
                            """
                            DDT delegation to a child DDT node or map\-server
                            
                            .. attribute:: eid_prefix
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: instance_id
                            
                            	EID instance\-ID
                            	**type**\: str
                            
                            .. attribute:: to
                            
                            	DDT delegation to a child DDT node or map\-server
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ip_address
                            
                            	IPv4/6 Child or map\-server node locator address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_server
                            
                            	Delegation points to a map\-server
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, self).__init__()

                                self.yang_name = "delegate"
                                self.yang_parent_name = "instance-id-eid-prefix-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                    ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                    ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                ])
                                self.eid_prefix = None
                                self.instance_id = None
                                self.to = None
                                self.ip_address = None
                                self.map_server = None
                                self._segment_path = lambda: "delegate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                    class InstanceIdList(Entity):
                        """
                        
                        
                        .. attribute:: instance_id  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: delegate
                        
                        	DDT delegation to a child DDT node or map\-server
                        	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ddt.Authoritative.InstanceIdList.Delegate>`
                        
                        .. attribute:: map_server_peer
                        
                        	Peer map\-servers that are authoritative for the same EID prefixes
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ddt.Authoritative.InstanceIdList, self).__init__()

                            self.yang_name = "instance-id-list"
                            self.yang_parent_name = "authoritative"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance_id']
                            self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.LispList.Ddt.Authoritative.InstanceIdList.Delegate))])
                            self._leafs = OrderedDict([
                                ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                            ])
                            self.instance_id = None
                            self.map_server_peer = None

                            self.delegate = Native.Router.LispList.Ddt.Authoritative.InstanceIdList.Delegate()
                            self.delegate.parent = self
                            self._children_name_map["delegate"] = "delegate"
                            self._segment_path = lambda: "instance-id-list" + "[instance-id='" + str(self.instance_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ddt.Authoritative.InstanceIdList, ['instance_id', 'map_server_peer'], name, value)


                        class Delegate(Entity):
                            """
                            DDT delegation to a child DDT node or map\-server
                            
                            .. attribute:: eid_prefix
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: instance_id
                            
                            	EID instance\-ID
                            	**type**\: str
                            
                            .. attribute:: to
                            
                            	DDT delegation to a child DDT node or map\-server
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ip_address
                            
                            	IPv4/6 Child or map\-server node locator address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: map_server
                            
                            	Delegation points to a map\-server
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ddt.Authoritative.InstanceIdList.Delegate, self).__init__()

                                self.yang_name = "delegate"
                                self.yang_parent_name = "instance-id-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                    ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                    ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                ])
                                self.eid_prefix = None
                                self.instance_id = None
                                self.to = None
                                self.ip_address = None
                                self.map_server = None
                                self._segment_path = lambda: "delegate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ddt.Authoritative.InstanceIdList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


            class Decapsulation(Entity):
                """
                Decapsulation behavior (e.g. filters)
                
                .. attribute:: filter
                
                	Filters traffic
                	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Decapsulation.Filter>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Decapsulation, self).__init__()

                    self.yang_name = "decapsulation"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("filter", ("filter", Native.Router.LispList.Decapsulation.Filter))])
                    self._leafs = OrderedDict()

                    self.filter = Native.Router.LispList.Decapsulation.Filter()
                    self.filter.parent = self
                    self._children_name_map["filter"] = "filter"
                    self._segment_path = lambda: "decapsulation"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Decapsulation, [], name, value)


                class Filter(Entity):
                    """
                    Filters traffic
                    
                    .. attribute:: rloc
                    
                    	Filter based on Routing Locator (RLOC) in packet header
                    	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Decapsulation.Filter.Rloc>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Decapsulation.Filter, self).__init__()

                        self.yang_name = "filter"
                        self.yang_parent_name = "decapsulation"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.Decapsulation.Filter.Rloc))])
                        self._leafs = OrderedDict()

                        self.rloc = Native.Router.LispList.Decapsulation.Filter.Rloc()
                        self.rloc.parent = self
                        self._children_name_map["rloc"] = "rloc"
                        self._segment_path = lambda: "filter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Decapsulation.Filter, [], name, value)


                    class Rloc(Entity):
                        """
                        Filter based on Routing Locator (RLOC) in packet header
                        
                        .. attribute:: source
                        
                        	Filters traffic based on RLOC source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Decapsulation.Filter.Rloc.Source>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Decapsulation.Filter.Rloc, self).__init__()

                            self.yang_name = "rloc"
                            self.yang_parent_name = "filter"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Decapsulation.Filter.Rloc.Source))])
                            self._leafs = OrderedDict()

                            self.source = Native.Router.LispList.Decapsulation.Filter.Rloc.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._segment_path = lambda: "rloc"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Decapsulation.Filter.Rloc, [], name, value)


                        class Source(Entity):
                            """
                            Filters traffic based on RLOC source address
                            
                            .. attribute:: locator_set
                            
                            	Locator\-set Name
                            	**type**\: str
                            
                            .. attribute:: member
                            
                            	Members learned from map\-server
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Decapsulation.Filter.Rloc.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "rloc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                ])
                                self.locator_set = None
                                self.member = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


            class Etr(Entity):
                """
                Configures a LISP Egress Tunnel Router (ETR)
                
                .. attribute:: map_server
                
                	Configures map server for ETR registration
                	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Etr.MapServer>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Etr, self).__init__()

                    self.yang_name = "etr"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Etr.MapServer))])
                    self._leafs = OrderedDict()

                    self.map_server = Native.Router.LispList.Etr.MapServer()
                    self.map_server.parent = self
                    self._children_name_map["map_server"] = "map-server"
                    self._segment_path = lambda: "etr"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Etr, [], name, value)


                class MapServer(Entity):
                    """
                    Configures map server for ETR registration
                    
                    .. attribute:: source_address
                    
                    	Configures map server source address
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Etr.MapServer, self).__init__()

                        self.yang_name = "map-server"
                        self.yang_parent_name = "etr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                        ])
                        self.source_address = None
                        self._segment_path = lambda: "map-server"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Etr.MapServer, ['source_address'], name, value)


            class Ipv4(Entity):
                """
                IPv4 address family
                
                .. attribute:: alt_vrf
                
                	Activate LISP\-ALT functionality in VRF
                	**type**\: str
                
                	**status**\: deprecated
                
                .. attribute:: database_mapping
                
                	Address family specific local EID prefixes database configuration
                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.DatabaseMapping>`
                
                .. attribute:: distance
                
                	Administrative distance for RIB route installation
                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.Distance>`
                
                .. attribute:: itr
                
                	Configures a LISP Ingress Tunnel Router (ITR)
                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.Itr>`
                
                .. attribute:: itr_enable
                
                	
                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.ItrEnable>`
                
                .. attribute:: etr
                
                	Configures a LISP Egress Tunnel Router (ETR)
                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.Etr>`
                
                .. attribute:: etr_enable
                
                	
                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.EtrEnable>`
                
                .. attribute:: locator
                
                	Locator related configuration
                	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.Locator>`
                
                .. attribute:: map_cache
                
                	Address family specific map cache configuration
                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.MapCache>`
                
                .. attribute:: map_cache_limit
                
                	Configures maximum size of map\-cache
                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.MapCacheLimit>`
                
                .. attribute:: map_cache_persistent
                
                	Dump map\-cache onto flash, making it persistent across reboots
                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.MapCachePersistent>`
                
                .. attribute:: map_request_source
                
                	Configures inner header source address in Map\-Request message
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: map_resolver
                
                	Configures a LISP Map Resolver (MR)
                	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.MapResolver>`
                
                	**presence node**\: True
                
                .. attribute:: map_server
                
                	Configures a LISP Map Server (MS)
                	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.MapServer>`
                
                	**presence node**\: True
                
                .. attribute:: path_mtu_discovery
                
                	Path MTU discovery
                	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.PathMtuDiscovery>`
                
                	**presence node**\: True
                
                .. attribute:: proxy_etr
                
                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_itr
                
                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                	**type**\: union of the below types:
                
                		**type**\: list of str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: list of str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: route_export
                
                	Export routes into RIB from LISP
                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteExport>`
                
                .. attribute:: route_import
                
                	Import RIB routes by a routing protocol into LISP
                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport>`
                
                .. attribute:: sgt
                
                	Enable security group tag propagation in LISP encapsulated traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: site_registration
                
                	Site registrations configuration for a given instance\-id
                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.SiteRegistration>`
                
                .. attribute:: solicit_map_request
                
                	Configure Solicit\-Map\-Request handling
                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.SolicitMapRequest>`
                
                .. attribute:: source_locator
                
                	Source Locator configuration
                	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.SourceLocator>`
                
                .. attribute:: use_petr
                
                	Encapsulate to Proxy ETR when matching forward\-native entry
                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.UsePetr>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Ipv4, self).__init__()

                    self.yang_name = "ipv4"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Ipv4.DatabaseMapping)), ("distance", ("distance", Native.Router.LispList.Ipv4.Distance)), ("itr", ("itr", Native.Router.LispList.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Ipv4.ItrEnable)), ("etr", ("etr", Native.Router.LispList.Ipv4.Etr)), ("etr-enable", ("etr_enable", Native.Router.LispList.Ipv4.EtrEnable)), ("locator", ("locator", Native.Router.LispList.Ipv4.Locator)), ("map-cache", ("map_cache", Native.Router.LispList.Ipv4.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Ipv4.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Ipv4.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.LispList.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Ipv4.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.LispList.Ipv4.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.LispList.Ipv4.RouteExport)), ("route-import", ("route_import", Native.Router.LispList.Ipv4.RouteImport)), ("site-registration", ("site_registration", Native.Router.LispList.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Ipv4.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.LispList.Ipv4.SourceLocator)), ("use-petr", ("use_petr", Native.Router.LispList.Ipv4.UsePetr))])
                    self._leafs = OrderedDict([
                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                        ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                    ])
                    self.alt_vrf = None
                    self.map_request_source = None
                    self.proxy_etr = None
                    self.proxy_itr = []
                    self.sgt = None

                    self.database_mapping = Native.Router.LispList.Ipv4.DatabaseMapping()
                    self.database_mapping.parent = self
                    self._children_name_map["database_mapping"] = "database-mapping"

                    self.distance = Native.Router.LispList.Ipv4.Distance()
                    self.distance.parent = self
                    self._children_name_map["distance"] = "distance"

                    self.itr = Native.Router.LispList.Ipv4.Itr()
                    self.itr.parent = self
                    self._children_name_map["itr"] = "itr"

                    self.itr_enable = Native.Router.LispList.Ipv4.ItrEnable()
                    self.itr_enable.parent = self
                    self._children_name_map["itr_enable"] = "itr-enable"

                    self.etr = Native.Router.LispList.Ipv4.Etr()
                    self.etr.parent = self
                    self._children_name_map["etr"] = "etr"

                    self.etr_enable = Native.Router.LispList.Ipv4.EtrEnable()
                    self.etr_enable.parent = self
                    self._children_name_map["etr_enable"] = "etr-enable"

                    self.locator = Native.Router.LispList.Ipv4.Locator()
                    self.locator.parent = self
                    self._children_name_map["locator"] = "locator"

                    self.map_cache = Native.Router.LispList.Ipv4.MapCache()
                    self.map_cache.parent = self
                    self._children_name_map["map_cache"] = "map-cache"

                    self.map_cache_limit = Native.Router.LispList.Ipv4.MapCacheLimit()
                    self.map_cache_limit.parent = self
                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                    self.map_cache_persistent = Native.Router.LispList.Ipv4.MapCachePersistent()
                    self.map_cache_persistent.parent = self
                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                    self.map_resolver = None
                    self._children_name_map["map_resolver"] = "map-resolver"

                    self.map_server = None
                    self._children_name_map["map_server"] = "map-server"

                    self.path_mtu_discovery = None
                    self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                    self.route_export = Native.Router.LispList.Ipv4.RouteExport()
                    self.route_export.parent = self
                    self._children_name_map["route_export"] = "route-export"

                    self.route_import = Native.Router.LispList.Ipv4.RouteImport()
                    self.route_import.parent = self
                    self._children_name_map["route_import"] = "route-import"

                    self.site_registration = Native.Router.LispList.Ipv4.SiteRegistration()
                    self.site_registration.parent = self
                    self._children_name_map["site_registration"] = "site-registration"

                    self.solicit_map_request = Native.Router.LispList.Ipv4.SolicitMapRequest()
                    self.solicit_map_request.parent = self
                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                    self.source_locator = Native.Router.LispList.Ipv4.SourceLocator()
                    self.source_locator.parent = self
                    self._children_name_map["source_locator"] = "source-locator"

                    self.use_petr = YList(self)
                    self._segment_path = lambda: "ipv4"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Ipv4, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                class DatabaseMapping(Entity):
                    """
                    Address family specific local EID prefixes database configuration
                    
                    .. attribute:: limit
                    
                    	Configures the maximum size of local EID prefixes database
                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.DatabaseMapping.Limit>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.DatabaseMapping, self).__init__()

                        self.yang_name = "database-mapping"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Ipv4.DatabaseMapping.Limit))])
                        self._leafs = OrderedDict()

                        self.limit = Native.Router.LispList.Ipv4.DatabaseMapping.Limit()
                        self.limit.parent = self
                        self._children_name_map["limit"] = "limit"
                        self._segment_path = lambda: "database-mapping"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.DatabaseMapping, [], name, value)


                    class Limit(Entity):
                        """
                        Configures the maximum size of local EID prefixes database
                        
                        .. attribute:: dynamic
                        
                        	Configures the maximum size of dynamic local EID prefixes database
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.DatabaseMapping.Limit, self).__init__()

                            self.yang_name = "limit"
                            self.yang_parent_name = "database-mapping"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.dynamic = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                class Distance(Entity):
                    """
                    Administrative distance for RIB route installation
                    
                    .. attribute:: alt
                    
                    	LISP routes installed in the ALT table
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: dyn_eid
                    
                    	LISP installed routes of type dynamic\-EID
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: site_registrations
                    
                    	LISP installed routes of type site\-registrations
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.Distance, self).__init__()

                        self.yang_name = "distance"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                        ])
                        self.alt = None
                        self.dyn_eid = None
                        self.site_registrations = None
                        self._segment_path = lambda: "distance"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                class Itr(Entity):
                    """
                    Configures a LISP Ingress Tunnel Router (ITR)
                    
                    .. attribute:: map_resolver
                    
                    	Configures map\-resolver address for sending Map\-Requests
                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.Itr.MapResolver>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.Itr, self).__init__()

                        self.yang_name = "itr"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Ipv4.Itr.MapResolver))])
                        self._leafs = OrderedDict()

                        self.map_resolver = YList(self)
                        self._segment_path = lambda: "itr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.Itr, [], name, value)


                    class MapResolver(Entity):
                        """
                        Configures map\-resolver address for sending Map\-Requests
                        
                        .. attribute:: ip_addr  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.Itr.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "itr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_addr']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                            ])
                            self.ip_addr = None
                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.Itr.MapResolver, ['ip_addr'], name, value)


                class ItrEnable(Entity):
                    """
                    
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.ItrEnable, self).__init__()

                        self.yang_name = "itr-enable"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                        ])
                        self.itr = None
                        self._segment_path = lambda: "itr-enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.ItrEnable, ['itr'], name, value)


                class Etr(Entity):
                    """
                    Configures a LISP Egress Tunnel Router (ETR)
                    
                    .. attribute:: map_server
                    
                    	Configures map server for ETR registration
                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.Etr.MapServer>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.Etr, self).__init__()

                        self.yang_name = "etr"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Ipv4.Etr.MapServer))])
                        self._leafs = OrderedDict()

                        self.map_server = YList(self)
                        self._segment_path = lambda: "etr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.Etr, [], name, value)


                    class MapServer(Entity):
                        """
                        Configures map server for ETR registration
                        
                        .. attribute:: ip_addr  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: key
                        
                        	Authentication key used with map server
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.Etr.MapServer.Key>`
                        
                        .. attribute:: proxy_reply
                        
                        	Request Map\-Server to send Map\-Replies on behalf of site
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.Etr.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "etr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_addr']
                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Ipv4.Etr.MapServer.Key))])
                            self._leafs = OrderedDict([
                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                            ])
                            self.ip_addr = None
                            self.proxy_reply = None

                            self.key = Native.Router.LispList.Ipv4.Etr.MapServer.Key()
                            self.key.parent = self
                            self._children_name_map["key"] = "key"
                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                        class Key(Entity):
                            """
                            Authentication key used with map server
                            
                            .. attribute:: key_0
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            .. attribute:: key_6
                            
                            	The ENCRYPTED password
                            	**type**\: str
                            
                            .. attribute:: key_7
                            
                            	The HIDDEN password
                            	**type**\: str
                            
                            .. attribute:: pwd
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.Etr.MapServer.Key, self).__init__()

                                self.yang_name = "key"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                    ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                    ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                    ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                ])
                                self.key_0 = None
                                self.key_6 = None
                                self.key_7 = None
                                self.pwd = None
                                self._segment_path = lambda: "key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                class EtrEnable(Entity):
                    """
                    
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.EtrEnable, self).__init__()

                        self.yang_name = "etr-enable"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                        ])
                        self.etr = None
                        self._segment_path = lambda: "etr-enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.EtrEnable, ['etr'], name, value)


                class Locator(Entity):
                    """
                    Locator related configuration
                    
                    .. attribute:: reachability
                    
                    	Configuration realted to locator reachability
                    	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.Locator.Reachability>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.Locator, self).__init__()

                        self.yang_name = "locator"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.LispList.Ipv4.Locator.Reachability))])
                        self._leafs = OrderedDict()

                        self.reachability = Native.Router.LispList.Ipv4.Locator.Reachability()
                        self.reachability.parent = self
                        self._children_name_map["reachability"] = "reachability"
                        self._segment_path = lambda: "locator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.Locator, [], name, value)


                    class Reachability(Entity):
                        """
                        Configuration realted to locator reachability
                        
                        .. attribute:: exclude_default
                        
                        	If a remote RLOC is reached via the default route, treat it as unreachable
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.Locator.Reachability, self).__init__()

                            self.yang_name = "reachability"
                            self.yang_parent_name = "locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                            ])
                            self.exclude_default = None
                            self._segment_path = lambda: "reachability"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.Locator.Reachability, ['exclude_default'], name, value)


                class MapCache(Entity):
                    """
                    Address family specific map cache configuration
                    
                    .. attribute:: site_registration
                    
                    	Install map cache to map request for site registrations
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.MapCache, self).__init__()

                        self.yang_name = "map-cache"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                        ])
                        self.site_registration = None
                        self._segment_path = lambda: "map-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.MapCache, ['site_registration'], name, value)


                class MapCacheLimit(Entity):
                    """
                    Configures maximum size of map\-cache
                    
                    .. attribute:: max_map_cache_entries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..100000
                    
                    .. attribute:: reserve_list
                    
                    	EID\-prefixes guaranteed to be stored in map\-cache
                    	**type**\: str
                    
                    .. attribute:: warning_threshold
                    
                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.MapCacheLimit, self).__init__()

                        self.yang_name = "map-cache-limit"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                        ])
                        self.max_map_cache_entries = None
                        self.reserve_list = None
                        self.warning_threshold = None
                        self._segment_path = lambda: "map-cache-limit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                class MapCachePersistent(Entity):
                    """
                    Dump map\-cache onto flash, making it persistent across reboots
                    
                    .. attribute:: interval
                    
                    	Interval in minutes of how often the map\-cache is saved
                    	**type**\: int
                    
                    	**range:** 1..1440
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.MapCachePersistent, self).__init__()

                        self.yang_name = "map-cache-persistent"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                        ])
                        self.interval = None
                        self._segment_path = lambda: "map-cache-persistent"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.MapCachePersistent, ['interval'], name, value)


                class MapResolver(Entity):
                    """
                    Configures a LISP Map Resolver (MR)
                    
                    .. attribute:: map_request
                    
                    	Map\-Request processing options
                    	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.MapResolver.MapRequest>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.MapResolver, self).__init__()

                        self.yang_name = "map-resolver"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Ipv4.MapResolver.MapRequest))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.map_request = Native.Router.LispList.Ipv4.MapResolver.MapRequest()
                        self.map_request.parent = self
                        self._children_name_map["map_request"] = "map-request"
                        self._segment_path = lambda: "map-resolver"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.MapResolver, [], name, value)


                    class MapRequest(Entity):
                        """
                        Map\-Request processing options
                        
                        .. attribute:: validate
                        
                        	Validation options
                        	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.MapResolver.MapRequest.Validate>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.MapResolver.MapRequest, self).__init__()

                            self.yang_name = "map-request"
                            self.yang_parent_name = "map-resolver"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Ipv4.MapResolver.MapRequest.Validate))])
                            self._leafs = OrderedDict()

                            self.validate = Native.Router.LispList.Ipv4.MapResolver.MapRequest.Validate()
                            self.validate.parent = self
                            self._children_name_map["validate"] = "validate"
                            self._segment_path = lambda: "map-request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.MapResolver.MapRequest, [], name, value)


                        class Validate(Entity):
                            """
                            Validation options
                            
                            .. attribute:: source
                            
                            	Influence which source RLOCs map requests are accepted from
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.MapResolver.MapRequest.Validate.Source>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                self.yang_name = "validate"
                                self.yang_parent_name = "map-request"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                self._leafs = OrderedDict()

                                self.source = Native.Router.LispList.Ipv4.MapResolver.MapRequest.Validate.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "validate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                            class Source(Entity):
                                """
                                Influence which source RLOCs map requests are accepted from
                                
                                .. attribute:: list
                                
                                	Define allowed prefixes using an ip[v6] prefix list
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: registered
                                
                                	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ipv4
                                
                                	IPv4 prefixes
                                	**type**\: str
                                
                                .. attribute:: ipv6
                                
                                	IPv6 prefixes
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "validate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                        ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.list = None
                                    self.registered = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                class MapServer(Entity):
                    """
                    Configures a LISP Map Server (MS)
                    
                    .. attribute:: map_register
                    
                    	Map\-Register processing options
                    	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.MapServer.MapRegister>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.MapServer, self).__init__()

                        self.yang_name = "map-server"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Ipv4.MapServer.MapRegister))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.map_register = Native.Router.LispList.Ipv4.MapServer.MapRegister()
                        self.map_register.parent = self
                        self._children_name_map["map_register"] = "map-register"
                        self._segment_path = lambda: "map-server"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.MapServer, [], name, value)


                    class MapRegister(Entity):
                        """
                        Map\-Register processing options
                        
                        .. attribute:: validate
                        
                        	Validation options
                        	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.MapServer.MapRegister.Validate>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.MapServer.MapRegister, self).__init__()

                            self.yang_name = "map-register"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Ipv4.MapServer.MapRegister.Validate))])
                            self._leafs = OrderedDict()

                            self.validate = Native.Router.LispList.Ipv4.MapServer.MapRegister.Validate()
                            self.validate.parent = self
                            self._children_name_map["validate"] = "validate"
                            self._segment_path = lambda: "map-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.MapServer.MapRegister, [], name, value)


                        class Validate(Entity):
                            """
                            Validation options
                            
                            .. attribute:: source
                            
                            	RLOC Source IP address
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.MapServer.MapRegister.Validate.Source>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                self.yang_name = "validate"
                                self.yang_parent_name = "map-register"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Ipv4.MapServer.MapRegister.Validate.Source))])
                                self._leafs = OrderedDict()

                                self.source = Native.Router.LispList.Ipv4.MapServer.MapRegister.Validate.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "validate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                            class Source(Entity):
                                """
                                RLOC Source IP address
                                
                                .. attribute:: allowed_locator
                                
                                	Against sites' allowed\-locators policy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "validate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                    ])
                                    self.allowed_locator = None
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                class PathMtuDiscovery(Entity):
                    """
                    Path MTU discovery
                    
                    .. attribute:: max
                    
                    	Upper bound on the path MTU accepted
                    	**type**\: int
                    
                    	**range:** 68..65535
                    
                    .. attribute:: min
                    
                    	Lower bound on the path MTU accepted
                    	**type**\: int
                    
                    	**range:** 68..65535
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.PathMtuDiscovery, self).__init__()

                        self.yang_name = "path-mtu-discovery"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                            ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                        ])
                        self.max = None
                        self.min = None
                        self._segment_path = lambda: "path-mtu-discovery"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.PathMtuDiscovery, ['max', 'min'], name, value)


                class RouteExport(Entity):
                    """
                    Export routes into RIB from LISP
                    
                    .. attribute:: site_registrations
                    
                    	Export LISP site registrations to RIB
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: away_eids
                    
                    	Export LISP away EIDs to RIB
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.RouteExport, self).__init__()

                        self.yang_name = "route-export"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                        ])
                        self.site_registrations = None
                        self.away_eids = None
                        self._segment_path = lambda: "route-export"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                class RouteImport(Entity):
                    """
                    Import RIB routes by a routing protocol into LISP
                    
                    .. attribute:: database
                    
                    	Use RIB routes to define local EID database entries
                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database>`
                    
                    .. attribute:: map_cache
                    
                    	Use RIB routes to define EID address space in map\-cache
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.RouteImport, self).__init__()

                        self.yang_name = "route-import"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Ipv4.RouteImport.MapCache))])
                        self._leafs = OrderedDict()

                        self.database = Native.Router.LispList.Ipv4.RouteImport.Database()
                        self.database.parent = self
                        self._children_name_map["database"] = "database"

                        self.map_cache = Native.Router.LispList.Ipv4.RouteImport.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"
                        self._segment_path = lambda: "route-import"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport, [], name, value)


                    class Database(Entity):
                        """
                        Use RIB routes to define local EID database entries
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Connected>`
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Isis>`
                        
                        .. attribute:: maximum_prefix
                        
                        	Maximum number of prefixes to pick up from the RIB
                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.MaximumPrefix>`
                        
                        .. attribute:: ospf
                        
                        	Open Shortest Path First (OSPF)
                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Ospf>`
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Rip>`
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Static>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.RouteImport.Database, self).__init__()

                            self.yang_name = "database"
                            self.yang_parent_name = "route-import"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Ipv4.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Ipv4.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Ipv4.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Ipv4.RouteImport.Database.Rip)), ("static", ("static", Native.Router.LispList.Ipv4.RouteImport.Database.Static))])
                            self._leafs = OrderedDict()

                            self.connected = Native.Router.LispList.Ipv4.RouteImport.Database.Connected()
                            self.connected.parent = self
                            self._children_name_map["connected"] = "connected"

                            self.maximum_prefix = Native.Router.LispList.Ipv4.RouteImport.Database.MaximumPrefix()
                            self.maximum_prefix.parent = self
                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                            self.rip = Native.Router.LispList.Ipv4.RouteImport.Database.Rip()
                            self.rip.parent = self
                            self._children_name_map["rip"] = "rip"

                            self.static = Native.Router.LispList.Ipv4.RouteImport.Database.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"

                            self.bgp = YList(self)
                            self.eigrp = YList(self)
                            self.isis = YList(self)
                            self.ospf = YList(self)
                            self.ospfv3 = YList(self)
                            self._segment_path = lambda: "database"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database, [], name, value)


                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.Database.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "connected"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Connected, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "connected"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.Database.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Isis, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class MaximumPrefix(Entity):
                            """
                            Maximum number of prefixes to pick up from the RIB
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: warning_only
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: warning_only1
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                self.yang_name = "maximum-prefix"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                ])
                                self.number = None
                                self.warning_only = None
                                self.threshold = None
                                self.threshold1 = None
                                self.warning_only1 = None
                                self._segment_path = lambda: "maximum-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                        class Ospf(Entity):
                            """
                            Open Shortest Path First (OSPF)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                self.yang_name = "ospf"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "ospf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.Database.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Ospfv3, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.Database.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "rip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Rip, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "rip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.Database.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Static, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                    class MapCache(Entity):
                        """
                        Use RIB routes to define EID address space in map\-cache
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Connected>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Isis>`
                        
                        .. attribute:: maximum_prefix
                        
                        	Maximum number of prefixes to pick up from the RIB
                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                        
                        .. attribute:: ospf
                        
                        	Open Shortest Path First (OSPF)
                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospf>`
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Rip>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Static>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.RouteImport.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "route-import"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Ipv4.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.LispList.Ipv4.RouteImport.MapCache.Static))])
                            self._leafs = OrderedDict()

                            self.connected = None
                            self._children_name_map["connected"] = "connected"

                            self.maximum_prefix = Native.Router.LispList.Ipv4.RouteImport.MapCache.MaximumPrefix()
                            self.maximum_prefix.parent = self
                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                            self.rip = None
                            self._children_name_map["rip"] = "rip"

                            self.static = None
                            self._children_name_map["static"] = "static"

                            self.bgp = YList(self)
                            self.eigrp = YList(self)
                            self.isis = YList(self)
                            self.ospf = YList(self)
                            self.ospfv3 = YList(self)
                            self._segment_path = lambda: "map-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache, [], name, value)


                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "connected"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "connected"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                        class MaximumPrefix(Entity):
                            """
                            Maximum number of prefixes to pick up from the RIB
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: warning_only
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: warning_only1
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                self.yang_name = "maximum-prefix"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                ])
                                self.number = None
                                self.warning_only = None
                                self.threshold = None
                                self.threshold1 = None
                                self.warning_only1 = None
                                self._segment_path = lambda: "maximum-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                        class Ospf(Entity):
                            """
                            Open Shortest Path First (OSPF)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                self.yang_name = "ospf"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "ospf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "rip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "rip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Static, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                class SiteRegistration(Entity):
                    """
                    Site registrations configuration for a given instance\-id
                    
                    .. attribute:: limit
                    
                    	Maximum number of site registrations for a given instance\-id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: warning_threshold
                    
                    	Warning threshold to issue system logging
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.SiteRegistration, self).__init__()

                        self.yang_name = "site-registration"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                        ])
                        self.limit = None
                        self.warning_threshold = None
                        self._segment_path = lambda: "site-registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                class SolicitMapRequest(Entity):
                    """
                    Configure Solicit\-Map\-Request handling
                    
                    .. attribute:: ignore
                    
                    	Ignore SMR bit in incoming Map\-Requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: max_per_entry
                    
                    	Maximum number of SMRs for addresses under a map\-cache entry
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    .. attribute:: suppression_time
                    
                    	How long to suppress repeated SMRs for the same address
                    	**type**\: int
                    
                    	**range:** 1..600
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.SolicitMapRequest, self).__init__()

                        self.yang_name = "solicit-map-request"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                        ])
                        self.ignore = None
                        self.max_per_entry = None
                        self.suppression_time = None
                        self._segment_path = lambda: "solicit-map-request"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                class SourceLocator(Entity):
                    """
                    Source Locator configuration
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.SourceLocator.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.SourceLocator.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.SourceLocator.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv4.SourceLocator.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.SourceLocator, self).__init__()

                        self.yang_name = "source-locator"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.LispList.Ipv4.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.LispList.Ipv4.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.LispList.Ipv4.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.LispList.Ipv4.SourceLocator.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Router.LispList.Ipv4.SourceLocator.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Router.LispList.Ipv4.SourceLocator.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Router.LispList.Ipv4.SourceLocator.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Router.LispList.Ipv4.SourceLocator.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "source-locator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.SourceLocator.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.SourceLocator.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.SourceLocator.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv4.SourceLocator.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv4.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                class UsePetr(Entity):
                    """
                    Encapsulate to Proxy ETR when matching forward\-native entry
                    
                    .. attribute:: locator_address  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: priority
                    
                    	Configures which Locators from a set are preferred
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: weight
                    
                    	Traffic load\-spreading among Locators
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv4.UsePetr, self).__init__()

                        self.yang_name = "use-petr"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['locator_address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                        ])
                        self.locator_address = None
                        self.priority = None
                        self.weight = None
                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv4.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


            class Ipv6(Entity):
                """
                IPv6 address family
                
                .. attribute:: alt_vrf
                
                	Activate LISP\-ALT functionality in VRF
                	**type**\: str
                
                	**status**\: deprecated
                
                .. attribute:: database_mapping
                
                	Address family specific local EID prefixes database configuration
                	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.DatabaseMapping>`
                
                .. attribute:: distance
                
                	Administrative distance for RIB route installation
                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.Distance>`
                
                .. attribute:: itr
                
                	Configures a LISP Ingress Tunnel Router (ITR)
                	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.Itr>`
                
                .. attribute:: itr_enable
                
                	
                	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.ItrEnable>`
                
                .. attribute:: etr
                
                	Configures a LISP Egress Tunnel Router (ETR)
                	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.Etr>`
                
                .. attribute:: etr_enable
                
                	
                	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.EtrEnable>`
                
                .. attribute:: locator
                
                	Locator related configuration
                	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.Locator>`
                
                .. attribute:: map_cache
                
                	Address family specific map cache configuration
                	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.MapCache>`
                
                .. attribute:: map_cache_limit
                
                	Configures maximum size of map\-cache
                	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.MapCacheLimit>`
                
                .. attribute:: map_cache_persistent
                
                	Dump map\-cache onto flash, making it persistent across reboots
                	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.MapCachePersistent>`
                
                .. attribute:: map_request_source
                
                	Configures inner header source address in Map\-Request message
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: map_resolver
                
                	Configures a LISP Map Resolver (MR)
                	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.MapResolver>`
                
                	**presence node**\: True
                
                .. attribute:: map_server
                
                	Configures a LISP Map Server (MS)
                	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.MapServer>`
                
                	**presence node**\: True
                
                .. attribute:: path_mtu_discovery
                
                	Path MTU discovery
                	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.PathMtuDiscovery>`
                
                	**presence node**\: True
                
                .. attribute:: proxy_etr
                
                	Configures a LISP Proxy Engress Tunnel Router (PETR)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: proxy_itr
                
                	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                	**type**\: union of the below types:
                
                		**type**\: list of str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: list of str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: route_export
                
                	Export routes into RIB from LISP
                	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteExport>`
                
                .. attribute:: route_import
                
                	Import RIB routes by a routing protocol into LISP
                	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport>`
                
                .. attribute:: sgt
                
                	Enable security group tag propagation in LISP encapsulated traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: site_registration
                
                	Site registrations configuration for a given instance\-id
                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.SiteRegistration>`
                
                .. attribute:: solicit_map_request
                
                	Configure Solicit\-Map\-Request handling
                	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.SolicitMapRequest>`
                
                .. attribute:: source_locator
                
                	Source Locator configuration
                	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.SourceLocator>`
                
                .. attribute:: use_petr
                
                	Encapsulate to Proxy ETR when matching forward\-native entry
                	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.UsePetr>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.Ipv6.DatabaseMapping)), ("distance", ("distance", Native.Router.LispList.Ipv6.Distance)), ("itr", ("itr", Native.Router.LispList.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.Ipv6.ItrEnable)), ("etr", ("etr", Native.Router.LispList.Ipv6.Etr)), ("etr-enable", ("etr_enable", Native.Router.LispList.Ipv6.EtrEnable)), ("locator", ("locator", Native.Router.LispList.Ipv6.Locator)), ("map-cache", ("map_cache", Native.Router.LispList.Ipv6.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.Ipv6.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.Ipv6.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.LispList.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.Ipv6.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.LispList.Ipv6.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.LispList.Ipv6.RouteExport)), ("route-import", ("route_import", Native.Router.LispList.Ipv6.RouteImport)), ("site-registration", ("site_registration", Native.Router.LispList.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.Ipv6.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.LispList.Ipv6.SourceLocator)), ("use-petr", ("use_petr", Native.Router.LispList.Ipv6.UsePetr))])
                    self._leafs = OrderedDict([
                        ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                        ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                        ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                        ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                        ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                    ])
                    self.alt_vrf = None
                    self.map_request_source = None
                    self.proxy_etr = None
                    self.proxy_itr = []
                    self.sgt = None

                    self.database_mapping = Native.Router.LispList.Ipv6.DatabaseMapping()
                    self.database_mapping.parent = self
                    self._children_name_map["database_mapping"] = "database-mapping"

                    self.distance = Native.Router.LispList.Ipv6.Distance()
                    self.distance.parent = self
                    self._children_name_map["distance"] = "distance"

                    self.itr = Native.Router.LispList.Ipv6.Itr()
                    self.itr.parent = self
                    self._children_name_map["itr"] = "itr"

                    self.itr_enable = Native.Router.LispList.Ipv6.ItrEnable()
                    self.itr_enable.parent = self
                    self._children_name_map["itr_enable"] = "itr-enable"

                    self.etr = Native.Router.LispList.Ipv6.Etr()
                    self.etr.parent = self
                    self._children_name_map["etr"] = "etr"

                    self.etr_enable = Native.Router.LispList.Ipv6.EtrEnable()
                    self.etr_enable.parent = self
                    self._children_name_map["etr_enable"] = "etr-enable"

                    self.locator = Native.Router.LispList.Ipv6.Locator()
                    self.locator.parent = self
                    self._children_name_map["locator"] = "locator"

                    self.map_cache = Native.Router.LispList.Ipv6.MapCache()
                    self.map_cache.parent = self
                    self._children_name_map["map_cache"] = "map-cache"

                    self.map_cache_limit = Native.Router.LispList.Ipv6.MapCacheLimit()
                    self.map_cache_limit.parent = self
                    self._children_name_map["map_cache_limit"] = "map-cache-limit"

                    self.map_cache_persistent = Native.Router.LispList.Ipv6.MapCachePersistent()
                    self.map_cache_persistent.parent = self
                    self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                    self.map_resolver = None
                    self._children_name_map["map_resolver"] = "map-resolver"

                    self.map_server = None
                    self._children_name_map["map_server"] = "map-server"

                    self.path_mtu_discovery = None
                    self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                    self.route_export = Native.Router.LispList.Ipv6.RouteExport()
                    self.route_export.parent = self
                    self._children_name_map["route_export"] = "route-export"

                    self.route_import = Native.Router.LispList.Ipv6.RouteImport()
                    self.route_import.parent = self
                    self._children_name_map["route_import"] = "route-import"

                    self.site_registration = Native.Router.LispList.Ipv6.SiteRegistration()
                    self.site_registration.parent = self
                    self._children_name_map["site_registration"] = "site-registration"

                    self.solicit_map_request = Native.Router.LispList.Ipv6.SolicitMapRequest()
                    self.solicit_map_request.parent = self
                    self._children_name_map["solicit_map_request"] = "solicit-map-request"

                    self.source_locator = Native.Router.LispList.Ipv6.SourceLocator()
                    self.source_locator.parent = self
                    self._children_name_map["source_locator"] = "source-locator"

                    self.use_petr = YList(self)
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Ipv6, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                class DatabaseMapping(Entity):
                    """
                    Address family specific local EID prefixes database configuration
                    
                    .. attribute:: limit
                    
                    	Configures the maximum size of local EID prefixes database
                    	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.DatabaseMapping.Limit>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.DatabaseMapping, self).__init__()

                        self.yang_name = "database-mapping"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.Ipv6.DatabaseMapping.Limit))])
                        self._leafs = OrderedDict()

                        self.limit = Native.Router.LispList.Ipv6.DatabaseMapping.Limit()
                        self.limit.parent = self
                        self._children_name_map["limit"] = "limit"
                        self._segment_path = lambda: "database-mapping"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.DatabaseMapping, [], name, value)


                    class Limit(Entity):
                        """
                        Configures the maximum size of local EID prefixes database
                        
                        .. attribute:: dynamic
                        
                        	Configures the maximum size of dynamic local EID prefixes database
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: warning_threshold
                        
                        	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.DatabaseMapping.Limit, self).__init__()

                            self.yang_name = "limit"
                            self.yang_parent_name = "database-mapping"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                            ])
                            self.dynamic = None
                            self.warning_threshold = None
                            self._segment_path = lambda: "limit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                class Distance(Entity):
                    """
                    Administrative distance for RIB route installation
                    
                    .. attribute:: alt
                    
                    	LISP routes installed in the ALT table
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: dyn_eid
                    
                    	LISP installed routes of type dynamic\-EID
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: site_registrations
                    
                    	LISP installed routes of type site\-registrations
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.Distance, self).__init__()

                        self.yang_name = "distance"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                            ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                            ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                        ])
                        self.alt = None
                        self.dyn_eid = None
                        self.site_registrations = None
                        self._segment_path = lambda: "distance"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                class Itr(Entity):
                    """
                    Configures a LISP Ingress Tunnel Router (ITR)
                    
                    .. attribute:: map_resolver
                    
                    	Configures map\-resolver address for sending Map\-Requests
                    	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.Itr.MapResolver>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.Itr, self).__init__()

                        self.yang_name = "itr"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.Ipv6.Itr.MapResolver))])
                        self._leafs = OrderedDict()

                        self.map_resolver = YList(self)
                        self._segment_path = lambda: "itr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.Itr, [], name, value)


                    class MapResolver(Entity):
                        """
                        Configures map\-resolver address for sending Map\-Requests
                        
                        .. attribute:: ip_addr  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.Itr.MapResolver, self).__init__()

                            self.yang_name = "map-resolver"
                            self.yang_parent_name = "itr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_addr']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                            ])
                            self.ip_addr = None
                            self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.Itr.MapResolver, ['ip_addr'], name, value)


                class ItrEnable(Entity):
                    """
                    
                    
                    .. attribute:: itr
                    
                    	Configures a LISP Ingress Tunnel Router (ITR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.ItrEnable, self).__init__()

                        self.yang_name = "itr-enable"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                        ])
                        self.itr = None
                        self._segment_path = lambda: "itr-enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.ItrEnable, ['itr'], name, value)


                class Etr(Entity):
                    """
                    Configures a LISP Egress Tunnel Router (ETR)
                    
                    .. attribute:: map_server
                    
                    	Configures map server for ETR registration
                    	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.Etr.MapServer>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.Etr, self).__init__()

                        self.yang_name = "etr"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.Ipv6.Etr.MapServer))])
                        self._leafs = OrderedDict()

                        self.map_server = YList(self)
                        self._segment_path = lambda: "etr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.Etr, [], name, value)


                    class MapServer(Entity):
                        """
                        Configures map server for ETR registration
                        
                        .. attribute:: ip_addr  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: key
                        
                        	Authentication key used with map server
                        	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.Etr.MapServer.Key>`
                        
                        .. attribute:: proxy_reply
                        
                        	Request Map\-Server to send Map\-Replies on behalf of site
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.Etr.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "etr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_addr']
                            self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.Ipv6.Etr.MapServer.Key))])
                            self._leafs = OrderedDict([
                                ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                            ])
                            self.ip_addr = None
                            self.proxy_reply = None

                            self.key = Native.Router.LispList.Ipv6.Etr.MapServer.Key()
                            self.key.parent = self
                            self._children_name_map["key"] = "key"
                            self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                        class Key(Entity):
                            """
                            Authentication key used with map server
                            
                            .. attribute:: key_0
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            .. attribute:: key_6
                            
                            	The ENCRYPTED password
                            	**type**\: str
                            
                            .. attribute:: key_7
                            
                            	The HIDDEN password
                            	**type**\: str
                            
                            .. attribute:: pwd
                            
                            	The UNENCRYPTED (cleartext) password
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.Etr.MapServer.Key, self).__init__()

                                self.yang_name = "key"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                    ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                    ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                    ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                ])
                                self.key_0 = None
                                self.key_6 = None
                                self.key_7 = None
                                self.pwd = None
                                self._segment_path = lambda: "key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                class EtrEnable(Entity):
                    """
                    
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.EtrEnable, self).__init__()

                        self.yang_name = "etr-enable"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                        ])
                        self.etr = None
                        self._segment_path = lambda: "etr-enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.EtrEnable, ['etr'], name, value)


                class Locator(Entity):
                    """
                    Locator related configuration
                    
                    .. attribute:: reachability
                    
                    	Configuration realted to locator reachability
                    	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.Locator.Reachability>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.Locator, self).__init__()

                        self.yang_name = "locator"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.LispList.Ipv6.Locator.Reachability))])
                        self._leafs = OrderedDict()

                        self.reachability = Native.Router.LispList.Ipv6.Locator.Reachability()
                        self.reachability.parent = self
                        self._children_name_map["reachability"] = "reachability"
                        self._segment_path = lambda: "locator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.Locator, [], name, value)


                    class Reachability(Entity):
                        """
                        Configuration realted to locator reachability
                        
                        .. attribute:: exclude_default
                        
                        	If a remote RLOC is reached via the default route, treat it as unreachable
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.Locator.Reachability, self).__init__()

                            self.yang_name = "reachability"
                            self.yang_parent_name = "locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                            ])
                            self.exclude_default = None
                            self._segment_path = lambda: "reachability"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.Locator.Reachability, ['exclude_default'], name, value)


                class MapCache(Entity):
                    """
                    Address family specific map cache configuration
                    
                    .. attribute:: site_registration
                    
                    	Install map cache to map request for site registrations
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.MapCache, self).__init__()

                        self.yang_name = "map-cache"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                        ])
                        self.site_registration = None
                        self._segment_path = lambda: "map-cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.MapCache, ['site_registration'], name, value)


                class MapCacheLimit(Entity):
                    """
                    Configures maximum size of map\-cache
                    
                    .. attribute:: max_map_cache_entries
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..100000
                    
                    .. attribute:: reserve_list
                    
                    	EID\-prefixes guaranteed to be stored in map\-cache
                    	**type**\: str
                    
                    .. attribute:: warning_threshold
                    
                    	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.MapCacheLimit, self).__init__()

                        self.yang_name = "map-cache-limit"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                            ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                        ])
                        self.max_map_cache_entries = None
                        self.reserve_list = None
                        self.warning_threshold = None
                        self._segment_path = lambda: "map-cache-limit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                class MapCachePersistent(Entity):
                    """
                    Dump map\-cache onto flash, making it persistent across reboots
                    
                    .. attribute:: interval
                    
                    	Interval in minutes of how often the map\-cache is saved
                    	**type**\: int
                    
                    	**range:** 1..1440
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.MapCachePersistent, self).__init__()

                        self.yang_name = "map-cache-persistent"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                        ])
                        self.interval = None
                        self._segment_path = lambda: "map-cache-persistent"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.MapCachePersistent, ['interval'], name, value)


                class MapResolver(Entity):
                    """
                    Configures a LISP Map Resolver (MR)
                    
                    .. attribute:: map_request
                    
                    	Map\-Request processing options
                    	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.MapResolver.MapRequest>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.MapResolver, self).__init__()

                        self.yang_name = "map-resolver"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.Ipv6.MapResolver.MapRequest))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.map_request = Native.Router.LispList.Ipv6.MapResolver.MapRequest()
                        self.map_request.parent = self
                        self._children_name_map["map_request"] = "map-request"
                        self._segment_path = lambda: "map-resolver"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.MapResolver, [], name, value)


                    class MapRequest(Entity):
                        """
                        Map\-Request processing options
                        
                        .. attribute:: validate
                        
                        	Validation options
                        	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.MapResolver.MapRequest.Validate>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.MapResolver.MapRequest, self).__init__()

                            self.yang_name = "map-request"
                            self.yang_parent_name = "map-resolver"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Ipv6.MapResolver.MapRequest.Validate))])
                            self._leafs = OrderedDict()

                            self.validate = Native.Router.LispList.Ipv6.MapResolver.MapRequest.Validate()
                            self.validate.parent = self
                            self._children_name_map["validate"] = "validate"
                            self._segment_path = lambda: "map-request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.MapResolver.MapRequest, [], name, value)


                        class Validate(Entity):
                            """
                            Validation options
                            
                            .. attribute:: source
                            
                            	Influence which source RLOCs map requests are accepted from
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.MapResolver.MapRequest.Validate.Source>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                self.yang_name = "validate"
                                self.yang_parent_name = "map-request"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                self._leafs = OrderedDict()

                                self.source = Native.Router.LispList.Ipv6.MapResolver.MapRequest.Validate.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "validate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                            class Source(Entity):
                                """
                                Influence which source RLOCs map requests are accepted from
                                
                                .. attribute:: list
                                
                                	Define allowed prefixes using an ip[v6] prefix list
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: registered
                                
                                	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ipv4
                                
                                	IPv4 prefixes
                                	**type**\: str
                                
                                .. attribute:: ipv6
                                
                                	IPv6 prefixes
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "validate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                        ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.list = None
                                    self.registered = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                class MapServer(Entity):
                    """
                    Configures a LISP Map Server (MS)
                    
                    .. attribute:: map_register
                    
                    	Map\-Register processing options
                    	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.MapServer.MapRegister>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.MapServer, self).__init__()

                        self.yang_name = "map-server"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.Ipv6.MapServer.MapRegister))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.map_register = Native.Router.LispList.Ipv6.MapServer.MapRegister()
                        self.map_register.parent = self
                        self._children_name_map["map_register"] = "map-register"
                        self._segment_path = lambda: "map-server"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.MapServer, [], name, value)


                    class MapRegister(Entity):
                        """
                        Map\-Register processing options
                        
                        .. attribute:: validate
                        
                        	Validation options
                        	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.MapServer.MapRegister.Validate>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.MapServer.MapRegister, self).__init__()

                            self.yang_name = "map-register"
                            self.yang_parent_name = "map-server"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.Ipv6.MapServer.MapRegister.Validate))])
                            self._leafs = OrderedDict()

                            self.validate = Native.Router.LispList.Ipv6.MapServer.MapRegister.Validate()
                            self.validate.parent = self
                            self._children_name_map["validate"] = "validate"
                            self._segment_path = lambda: "map-register"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.MapServer.MapRegister, [], name, value)


                        class Validate(Entity):
                            """
                            Validation options
                            
                            .. attribute:: source
                            
                            	RLOC Source IP address
                            	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.MapServer.MapRegister.Validate.Source>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                self.yang_name = "validate"
                                self.yang_parent_name = "map-register"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.Ipv6.MapServer.MapRegister.Validate.Source))])
                                self._leafs = OrderedDict()

                                self.source = Native.Router.LispList.Ipv6.MapServer.MapRegister.Validate.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                                self._segment_path = lambda: "validate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                            class Source(Entity):
                                """
                                RLOC Source IP address
                                
                                .. attribute:: allowed_locator
                                
                                	Against sites' allowed\-locators policy
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                    self.yang_name = "source"
                                    self.yang_parent_name = "validate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                    ])
                                    self.allowed_locator = None
                                    self._segment_path = lambda: "source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                class PathMtuDiscovery(Entity):
                    """
                    Path MTU discovery
                    
                    .. attribute:: max
                    
                    	Upper bound on the path MTU accepted
                    	**type**\: int
                    
                    	**range:** 68..65535
                    
                    .. attribute:: min
                    
                    	Lower bound on the path MTU accepted
                    	**type**\: int
                    
                    	**range:** 68..65535
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.PathMtuDiscovery, self).__init__()

                        self.yang_name = "path-mtu-discovery"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                            ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                        ])
                        self.max = None
                        self.min = None
                        self._segment_path = lambda: "path-mtu-discovery"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.PathMtuDiscovery, ['max', 'min'], name, value)


                class RouteExport(Entity):
                    """
                    Export routes into RIB from LISP
                    
                    .. attribute:: site_registrations
                    
                    	Export LISP site registrations to RIB
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: away_eids
                    
                    	Export LISP away EIDs to RIB
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.RouteExport, self).__init__()

                        self.yang_name = "route-export"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                            ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                        ])
                        self.site_registrations = None
                        self.away_eids = None
                        self._segment_path = lambda: "route-export"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                class RouteImport(Entity):
                    """
                    Import RIB routes by a routing protocol into LISP
                    
                    .. attribute:: database
                    
                    	Use RIB routes to define local EID database entries
                    	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database>`
                    
                    .. attribute:: map_cache
                    
                    	Use RIB routes to define EID address space in map\-cache
                    	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.RouteImport, self).__init__()

                        self.yang_name = "route-import"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.Ipv6.RouteImport.MapCache))])
                        self._leafs = OrderedDict()

                        self.database = Native.Router.LispList.Ipv6.RouteImport.Database()
                        self.database.parent = self
                        self._children_name_map["database"] = "database"

                        self.map_cache = Native.Router.LispList.Ipv6.RouteImport.MapCache()
                        self.map_cache.parent = self
                        self._children_name_map["map_cache"] = "map-cache"
                        self._segment_path = lambda: "route-import"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport, [], name, value)


                    class Database(Entity):
                        """
                        Use RIB routes to define local EID database entries
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Connected>`
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Isis>`
                        
                        .. attribute:: maximum_prefix
                        
                        	Maximum number of prefixes to pick up from the RIB
                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.MaximumPrefix>`
                        
                        .. attribute:: ospf
                        
                        	Open Shortest Path First (OSPF)
                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Ospf>`
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Rip>`
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Static>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.RouteImport.Database, self).__init__()

                            self.yang_name = "database"
                            self.yang_parent_name = "route-import"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Ipv6.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Ipv6.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Ipv6.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Ipv6.RouteImport.Database.Rip)), ("static", ("static", Native.Router.LispList.Ipv6.RouteImport.Database.Static))])
                            self._leafs = OrderedDict()

                            self.connected = Native.Router.LispList.Ipv6.RouteImport.Database.Connected()
                            self.connected.parent = self
                            self._children_name_map["connected"] = "connected"

                            self.maximum_prefix = Native.Router.LispList.Ipv6.RouteImport.Database.MaximumPrefix()
                            self.maximum_prefix.parent = self
                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                            self.rip = Native.Router.LispList.Ipv6.RouteImport.Database.Rip()
                            self.rip.parent = self
                            self._children_name_map["rip"] = "rip"

                            self.static = Native.Router.LispList.Ipv6.RouteImport.Database.Static()
                            self.static.parent = self
                            self._children_name_map["static"] = "static"

                            self.bgp = YList(self)
                            self.eigrp = YList(self)
                            self.isis = YList(self)
                            self.ospf = YList(self)
                            self.ospfv3 = YList(self)
                            self._segment_path = lambda: "database"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database, [], name, value)


                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.Database.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "connected"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Connected, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "connected"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.Database.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Isis, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class MaximumPrefix(Entity):
                            """
                            Maximum number of prefixes to pick up from the RIB
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: warning_only
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: warning_only1
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                self.yang_name = "maximum-prefix"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                ])
                                self.number = None
                                self.warning_only = None
                                self.threshold = None
                                self.threshold1 = None
                                self.warning_only1 = None
                                self._segment_path = lambda: "maximum-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                        class Ospf(Entity):
                            """
                            Open Shortest Path First (OSPF)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                self.yang_name = "ospf"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "ospf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.Database.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Ospfv3, ['id'], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.Database.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "rip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Rip, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "rip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: lisp_ip_route_import
                            
                            	
                            	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.Database.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                self._leafs = OrderedDict()

                                self.lisp_ip_route_import = Native.Router.LispList.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                self.lisp_ip_route_import.parent = self
                                self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Static, [], name, value)


                            class LispIpRouteImport(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                .. attribute:: locator_set
                                
                                	Locator set to use with created database mapping entries
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                    self.yang_name = "lisp-ip-route-import"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self.locator_set = None
                                    self._segment_path = lambda: "lisp-ip-route-import"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                    class MapCache(Entity):
                        """
                        Use RIB routes to define EID address space in map\-cache
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Connected>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                        	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Eigrp>`
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Isis>`
                        
                        .. attribute:: maximum_prefix
                        
                        	Maximum number of prefixes to pick up from the RIB
                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                        
                        .. attribute:: ospf
                        
                        	Open Shortest Path First (OSPF)
                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospf>`
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3
                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospfv3>`
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Rip>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Static>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.RouteImport.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "route-import"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.LispList.Ipv6.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.LispList.Ipv6.RouteImport.MapCache.Static))])
                            self._leafs = OrderedDict()

                            self.connected = None
                            self._children_name_map["connected"] = "connected"

                            self.maximum_prefix = Native.Router.LispList.Ipv6.RouteImport.MapCache.MaximumPrefix()
                            self.maximum_prefix.parent = self
                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                            self.rip = None
                            self._children_name_map["rip"] = "rip"

                            self.static = None
                            self._children_name_map["static"] = "static"

                            self.bgp = YList(self)
                            self.eigrp = YList(self)
                            self.isis = YList(self)
                            self.ospf = YList(self)
                            self.ospfv3 = YList(self)
                            self._segment_path = lambda: "map-cache"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache, [], name, value)


                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "connected"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "connected"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                        class Eigrp(Entity):
                            """
                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "isis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                        class MaximumPrefix(Entity):
                            """
                            Maximum number of prefixes to pick up from the RIB
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: warning_only
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: threshold
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: threshold1
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: warning_only1
                            
                            	Only give a warning message and do not limit entries
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                self.yang_name = "maximum-prefix"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                    ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                    ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                ])
                                self.number = None
                                self.warning_only = None
                                self.threshold = None
                                self.threshold1 = None
                                self.warning_only1 = None
                                self._segment_path = lambda: "maximum-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                        class Ospf(Entity):
                            """
                            Open Shortest Path First (OSPF)
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                self.yang_name = "ospf"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "ospf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                        class Ospfv3(Entity):
                            """
                            OSPFv3
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "rip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Rip, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "rip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: map_cache_container
                            
                            	
                            	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_cache_container = None
                                self._children_name_map["map_cache_container"] = "map-cache-container"
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Static, [], name, value)


                            class MapCacheContainer(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map for route selection filtering
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                    self.yang_name = "map-cache-container"
                                    self.yang_parent_name = "static"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "map-cache-container"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                class SiteRegistration(Entity):
                    """
                    Site registrations configuration for a given instance\-id
                    
                    .. attribute:: limit
                    
                    	Maximum number of site registrations for a given instance\-id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: warning_threshold
                    
                    	Warning threshold to issue system logging
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.SiteRegistration, self).__init__()

                        self.yang_name = "site-registration"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                        ])
                        self.limit = None
                        self.warning_threshold = None
                        self._segment_path = lambda: "site-registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                class SolicitMapRequest(Entity):
                    """
                    Configure Solicit\-Map\-Request handling
                    
                    .. attribute:: ignore
                    
                    	Ignore SMR bit in incoming Map\-Requests
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: max_per_entry
                    
                    	Maximum number of SMRs for addresses under a map\-cache entry
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    .. attribute:: suppression_time
                    
                    	How long to suppress repeated SMRs for the same address
                    	**type**\: int
                    
                    	**range:** 1..600
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.SolicitMapRequest, self).__init__()

                        self.yang_name = "solicit-map-request"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                            ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                        ])
                        self.ignore = None
                        self.max_per_entry = None
                        self.suppression_time = None
                        self._segment_path = lambda: "solicit-map-request"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                class SourceLocator(Entity):
                    """
                    Source Locator configuration
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.SourceLocator.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.SourceLocator.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.SourceLocator.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Ipv6.SourceLocator.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.SourceLocator, self).__init__()

                        self.yang_name = "source-locator"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.LispList.Ipv6.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.LispList.Ipv6.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.LispList.Ipv6.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.LispList.Ipv6.SourceLocator.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Router.LispList.Ipv6.SourceLocator.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Router.LispList.Ipv6.SourceLocator.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Router.LispList.Ipv6.SourceLocator.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Router.LispList.Ipv6.SourceLocator.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "source-locator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.SourceLocator.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.SourceLocator.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.SourceLocator.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Ipv6.SourceLocator.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "source-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Ipv6.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                class UsePetr(Entity):
                    """
                    Encapsulate to Proxy ETR when matching forward\-native entry
                    
                    .. attribute:: locator_address  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: priority
                    
                    	Configures which Locators from a set are preferred
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: weight
                    
                    	Traffic load\-spreading among Locators
                    	**type**\: int
                    
                    	**range:** 0..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Ipv6.UsePetr, self).__init__()

                        self.yang_name = "use-petr"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['locator_address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                        ])
                        self.locator_address = None
                        self.priority = None
                        self.weight = None
                        self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Ipv6.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


            class LocReachAlgorithm(Entity):
                """
                Configure locator reachability algorithm
                
                .. attribute:: lsb_reports
                
                	Configure data packet LSB report handling
                	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.LocReachAlgorithm.LsbReports>`
                
                .. attribute:: rloc_probing
                
                	Probe high priority RLOCs with Map\-Requests as last resort
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.LocReachAlgorithm, self).__init__()

                    self.yang_name = "loc-reach-algorithm"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.LispList.LocReachAlgorithm.LsbReports))])
                    self._leafs = OrderedDict([
                        ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                    ])
                    self.rloc_probing = None

                    self.lsb_reports = Native.Router.LispList.LocReachAlgorithm.LsbReports()
                    self.lsb_reports.parent = self
                    self._children_name_map["lsb_reports"] = "lsb-reports"
                    self._segment_path = lambda: "loc-reach-algorithm"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.LocReachAlgorithm, ['rloc_probing'], name, value)


                class LsbReports(Entity):
                    """
                    Configure data packet LSB report handling
                    
                    .. attribute:: do_not_transmit
                    
                    	Force the setting of the encapsulation header L bit to zero
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ignore
                    
                    	Ignore data packet LSB reports
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.LocReachAlgorithm.LsbReports, self).__init__()

                        self.yang_name = "lsb-reports"
                        self.yang_parent_name = "loc-reach-algorithm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                            ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                        ])
                        self.do_not_transmit = None
                        self.ignore = None
                        self._segment_path = lambda: "lsb-reports"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


            class LocatorDown(Entity):
                """
                Manually set locator status to down
                
                .. attribute:: address
                
                	IPv4/6 Locator address to be set down
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ipv4_interface
                
                	Use IPv4 address of interface as locator
                	**type**\: str
                
                .. attribute:: ipv6_interface
                
                	Use IPv6 address of interface as locator
                	**type**\: str
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.LocatorDown, self).__init__()

                    self.yang_name = "locator-down"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                        ('ipv4_interface', (YLeaf(YType.str, 'IPv4-interface'), ['str'])),
                        ('ipv6_interface', (YLeaf(YType.str, 'IPv6-interface'), ['str'])),
                    ])
                    self.address = None
                    self.ipv4_interface = None
                    self.ipv6_interface = None
                    self._segment_path = lambda: "locator-down"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.LocatorDown, ['address', 'ipv4_interface', 'ipv6_interface'], name, value)


            class LocatorTable(Entity):
                """
                Specify the RLOC table
                
                .. attribute:: vrf_name
                
                	
                	**type**\: str
                
                .. attribute:: default
                
                	Default VRF
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vrf
                
                	VRF name
                	**type**\: str
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.LocatorTable, self).__init__()

                    self.yang_name = "locator-table"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ])
                    self.vrf_name = None
                    self.default = None
                    self.vrf = None
                    self._segment_path = lambda: "locator-table"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.LocatorTable, ['vrf_name', 'default', 'vrf'], name, value)


            class MapRequest(Entity):
                """
                Configure map\-request handling
                
                .. attribute:: itr_rlocs
                
                	Configure to use the specified RLOC set as ITR RLOC in map\-request
                	**type**\: str
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.MapRequest, self).__init__()

                    self.yang_name = "map-request"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('itr_rlocs', (YLeaf(YType.str, 'itr-rlocs'), ['str'])),
                    ])
                    self.itr_rlocs = None
                    self._segment_path = lambda: "map-request"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.MapRequest, ['itr_rlocs'], name, value)


            class MapServer(Entity):
                """
                Map\-Server commands
                
                .. attribute:: rloc
                
                	EID instance RLOC membership
                	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.MapServer.Rloc>`
                
                .. attribute:: site_registration
                
                	Map\-server site registration options
                	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.MapServer.SiteRegistration>`
                
                .. attribute:: nmr
                
                	Map\-server negative map\-reply optio
                	**type**\:  :py:class:`Nmr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.MapServer.Nmr>`
                
                .. attribute:: session
                
                	Map\-server session
                	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.MapServer.Session>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.MapServer, self).__init__()

                    self.yang_name = "map-server"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.LispList.MapServer.SiteRegistration)), ("nmr", ("nmr", Native.Router.LispList.MapServer.Nmr)), ("session", ("session", Native.Router.LispList.MapServer.Session))])
                    self._leafs = OrderedDict()

                    self.rloc = Native.Router.LispList.MapServer.Rloc()
                    self.rloc.parent = self
                    self._children_name_map["rloc"] = "rloc"

                    self.site_registration = Native.Router.LispList.MapServer.SiteRegistration()
                    self.site_registration.parent = self
                    self._children_name_map["site_registration"] = "site-registration"

                    self.nmr = Native.Router.LispList.MapServer.Nmr()
                    self.nmr.parent = self
                    self._children_name_map["nmr"] = "nmr"

                    self.session = Native.Router.LispList.MapServer.Session()
                    self.session.parent = self
                    self._children_name_map["session"] = "session"
                    self._segment_path = lambda: "map-server"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.MapServer, [], name, value)


                class Rloc(Entity):
                    """
                    EID instance RLOC membership
                    
                    .. attribute:: members
                    
                    	EID instance RLOC membership
                    	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.MapServer.Rloc.Members>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.MapServer.Rloc, self).__init__()

                        self.yang_name = "rloc"
                        self.yang_parent_name = "map-server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("members", ("members", Native.Router.LispList.MapServer.Rloc.Members))])
                        self._leafs = OrderedDict()

                        self.members = Native.Router.LispList.MapServer.Rloc.Members()
                        self.members.parent = self
                        self._children_name_map["members"] = "members"
                        self._segment_path = lambda: "rloc"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.MapServer.Rloc, [], name, value)


                    class Members(Entity):
                        """
                        EID instance RLOC membership
                        
                        .. attribute:: distribute
                        
                        	EID instance RLOC membership distribution
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: modify_discovered
                        
                        	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                        	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.MapServer.Rloc.Members.ModifyDiscovered>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.MapServer.Rloc.Members, self).__init__()

                            self.yang_name = "members"
                            self.yang_parent_name = "rloc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.LispList.MapServer.Rloc.Members.ModifyDiscovered))])
                            self._leafs = OrderedDict([
                                ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                            ])
                            self.distribute = None

                            self.modify_discovered = Native.Router.LispList.MapServer.Rloc.Members.ModifyDiscovered()
                            self.modify_discovered.parent = self
                            self._children_name_map["modify_discovered"] = "modify-discovered"
                            self._segment_path = lambda: "members"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.MapServer.Rloc.Members, ['distribute'], name, value)


                        class ModifyDiscovered(Entity):
                            """
                            Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                            
                            .. attribute:: operator
                            
                            	
                            	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                            
                            .. attribute:: locator_set
                            
                            	Locator set from which to get member RLOC addresses
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                self.yang_name = "modify-discovered"
                                self.yang_parent_name = "members"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                ])
                                self.operator = None
                                self.locator_set = None
                                self._segment_path = lambda: "modify-discovered"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                            class Operator(Enum):
                                """
                                Operator (Enum Class)

                                .. data:: add = 0

                                .. data:: override = 1

                                """

                                add = Enum.YLeaf(0, "add")

                                override = Enum.YLeaf(1, "override")



                class SiteRegistration(Entity):
                    """
                    Map\-server site registration options
                    
                    .. attribute:: limit
                    
                    	Maximum number of site registrations as a result of accept\-more\-specifics
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: warning_threshold
                    
                    	Warning threshold to issue system logging
                    	**type**\: int
                    
                    	**range:** 1..100
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.MapServer.SiteRegistration, self).__init__()

                        self.yang_name = "site-registration"
                        self.yang_parent_name = "map-server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                            ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                        ])
                        self.limit = None
                        self.warning_threshold = None
                        self._segment_path = lambda: "site-registration"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                class Nmr(Entity):
                    """
                    Map\-server negative map\-reply optio
                    
                    .. attribute:: non_site_ttl
                    
                    	Negative map\-reply TTL for non\-site EID
                    	**type**\: int
                    
                    	**range:** 1..1440
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.MapServer.Nmr, self).__init__()

                        self.yang_name = "nmr"
                        self.yang_parent_name = "map-server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('non_site_ttl', (YLeaf(YType.uint16, 'non-site-ttl'), ['int'])),
                        ])
                        self.non_site_ttl = None
                        self._segment_path = lambda: "nmr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.MapServer.Nmr, ['non_site_ttl'], name, value)


                class Session(Entity):
                    """
                    Map\-server session
                    
                    .. attribute:: passive_open
                    
                    	Open passive TCP sockets to listen for incoming connections
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.MapServer.Session, self).__init__()

                        self.yang_name = "session"
                        self.yang_parent_name = "map-server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('passive_open', (YLeaf(YType.str, 'passive-open'), ['str'])),
                        ])
                        self.passive_open = None
                        self._segment_path = lambda: "session"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.MapServer.Session, ['passive_open'], name, value)


            class OtherXtrProbe(Entity):
                """
                Configure parameters for probing of other xTRs in our site
                
                .. attribute:: period
                
                	Period between probes in seconds
                	**type**\: int
                
                	**range:** 5..900
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.OtherXtrProbe, self).__init__()

                    self.yang_name = "other-xtr-probe"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                    ])
                    self.period = None
                    self._segment_path = lambda: "other-xtr-probe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.OtherXtrProbe, ['period'], name, value)


            class RemoteRlocProbe(Entity):
                """
                Configure parameters for probing of remote RLOCs
                
                .. attribute:: on_membership_change
                
                	Trigger probing upon membership changes for remote RLOC
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: on_route_change
                
                	Trigger probing upon routing changes for remote RLOC
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.RemoteRlocProbe, self).__init__()

                    self.yang_name = "remote-rloc-probe"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                        ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                    ])
                    self.on_membership_change = None
                    self.on_route_change = None
                    self._segment_path = lambda: "remote-rloc-probe"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


            class EidTable(Entity):
                """
                Configure an EID instance for a VRF
                
                .. attribute:: instance_list
                
                	
                	**type**\: list of  		 :py:class:`InstanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.EidTable, self).__init__()

                    self.yang_name = "eid-table"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("instance-list", ("instance_list", Native.Router.LispList.EidTable.InstanceList))])
                    self._leafs = OrderedDict()

                    self.instance_list = YList(self)
                    self._segment_path = lambda: "eid-table"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.EidTable, [], name, value)


                class InstanceList(Entity):
                    """
                    
                    
                    .. attribute:: instance_id  (key)
                    
                    	EID instance\-ID
                    	**type**\: int
                    
                    	**range:** 0..16777214
                    
                    .. attribute:: vrf_name
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	Default VRF
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: database_mapping
                    
                    	Configures Locator addresses for an ETR
                    	**type**\: list of  		 :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.DatabaseMapping>`
                    
                    .. attribute:: dynamic_eid
                    
                    	Configure a dynamic EID
                    	**type**\: list of  		 :py:class:`DynamicEid <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.DynamicEid>`
                    
                    .. attribute:: alt
                    
                    	LISP Alternative Topology, LISP\-ALT
                    	**type**\:  :py:class:`Alt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Alt>`
                    
                    .. attribute:: control_packet
                    
                    	Configure control packet tx option
                    	**type**\:  :py:class:`ControlPacket <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.ControlPacket>`
                    
                    .. attribute:: ddt
                    
                    	Delegated Database Tree (DDT) mapping system
                    	**type**\:  :py:class:`Ddt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ddt>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: decapsulation
                    
                    	Decapsulation behavior (e.g. filters)
                    	**type**\:  :py:class:`Decapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Decapsulation>`
                    
                    .. attribute:: disable_ttl_propagate
                    
                    	Disable ttl propagation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: etr
                    
                    	Configures a LISP Egress Tunnel Router (ETR)
                    	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Etr>`
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address family
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address family
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6>`
                    
                    .. attribute:: loc_reach_algorithm
                    
                    	Configure locator reachability algorithm
                    	**type**\:  :py:class:`LocReachAlgorithm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.LocReachAlgorithm>`
                    
                    .. attribute:: locator_down
                    
                    	Manually set locator status to down
                    	**type**\:  :py:class:`LocatorDown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.LocatorDown>`
                    
                    .. attribute:: locator_table
                    
                    	Specify the RLOC table
                    	**type**\:  :py:class:`LocatorTable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.LocatorTable>`
                    
                    .. attribute:: map_request
                    
                    	Configure map\-request handling
                    	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.MapRequest>`
                    
                    .. attribute:: map_server
                    
                    	Map\-Server commands
                    	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.MapServer>`
                    
                    .. attribute:: other_xtr_probe
                    
                    	Configure parameters for probing of other xTRs in our site
                    	**type**\:  :py:class:`OtherXtrProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.OtherXtrProbe>`
                    
                    .. attribute:: remote_rloc_probe
                    
                    	Configure parameters for probing of remote RLOCs
                    	**type**\:  :py:class:`RemoteRlocProbe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.RemoteRlocProbe>`
                    
                    .. attribute:: map_cache
                    
                    	Configures static EID\-to\-RLOC mappings for an ITR
                    	**type**\: list of  		 :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.MapCache>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.EidTable.InstanceList, self).__init__()

                        self.yang_name = "instance-list"
                        self.yang_parent_name = "eid-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['instance_id']
                        self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.EidTable.InstanceList.DatabaseMapping)), ("dynamic-eid", ("dynamic_eid", Native.Router.LispList.EidTable.InstanceList.DynamicEid)), ("alt", ("alt", Native.Router.LispList.EidTable.InstanceList.Alt)), ("control-packet", ("control_packet", Native.Router.LispList.EidTable.InstanceList.ControlPacket)), ("ddt", ("ddt", Native.Router.LispList.EidTable.InstanceList.Ddt)), ("decapsulation", ("decapsulation", Native.Router.LispList.EidTable.InstanceList.Decapsulation)), ("etr", ("etr", Native.Router.LispList.EidTable.InstanceList.Etr)), ("ipv4", ("ipv4", Native.Router.LispList.EidTable.InstanceList.Ipv4)), ("ipv6", ("ipv6", Native.Router.LispList.EidTable.InstanceList.Ipv6)), ("loc-reach-algorithm", ("loc_reach_algorithm", Native.Router.LispList.EidTable.InstanceList.LocReachAlgorithm)), ("locator-down", ("locator_down", Native.Router.LispList.EidTable.InstanceList.LocatorDown)), ("locator-table", ("locator_table", Native.Router.LispList.EidTable.InstanceList.LocatorTable)), ("map-request", ("map_request", Native.Router.LispList.EidTable.InstanceList.MapRequest)), ("map-server", ("map_server", Native.Router.LispList.EidTable.InstanceList.MapServer)), ("other-xtr-probe", ("other_xtr_probe", Native.Router.LispList.EidTable.InstanceList.OtherXtrProbe)), ("remote-rloc-probe", ("remote_rloc_probe", Native.Router.LispList.EidTable.InstanceList.RemoteRlocProbe)), ("map-cache", ("map_cache", Native.Router.LispList.EidTable.InstanceList.MapCache))])
                        self._leafs = OrderedDict([
                            ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ('disable_ttl_propagate', (YLeaf(YType.empty, 'disable-ttl-propagate'), ['Empty'])),
                        ])
                        self.instance_id = None
                        self.vrf_name = None
                        self.default = None
                        self.vrf = None
                        self.disable_ttl_propagate = None

                        self.alt = Native.Router.LispList.EidTable.InstanceList.Alt()
                        self.alt.parent = self
                        self._children_name_map["alt"] = "alt"

                        self.control_packet = Native.Router.LispList.EidTable.InstanceList.ControlPacket()
                        self.control_packet.parent = self
                        self._children_name_map["control_packet"] = "control-packet"

                        self.ddt = None
                        self._children_name_map["ddt"] = "ddt"

                        self.decapsulation = Native.Router.LispList.EidTable.InstanceList.Decapsulation()
                        self.decapsulation.parent = self
                        self._children_name_map["decapsulation"] = "decapsulation"

                        self.etr = Native.Router.LispList.EidTable.InstanceList.Etr()
                        self.etr.parent = self
                        self._children_name_map["etr"] = "etr"

                        self.ipv4 = Native.Router.LispList.EidTable.InstanceList.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv6 = Native.Router.LispList.EidTable.InstanceList.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"

                        self.loc_reach_algorithm = Native.Router.LispList.EidTable.InstanceList.LocReachAlgorithm()
                        self.loc_reach_algorithm.parent = self
                        self._children_name_map["loc_reach_algorithm"] = "loc-reach-algorithm"

                        self.locator_down = Native.Router.LispList.EidTable.InstanceList.LocatorDown()
                        self.locator_down.parent = self
                        self._children_name_map["locator_down"] = "locator-down"

                        self.locator_table = Native.Router.LispList.EidTable.InstanceList.LocatorTable()
                        self.locator_table.parent = self
                        self._children_name_map["locator_table"] = "locator-table"

                        self.map_request = Native.Router.LispList.EidTable.InstanceList.MapRequest()
                        self.map_request.parent = self
                        self._children_name_map["map_request"] = "map-request"

                        self.map_server = Native.Router.LispList.EidTable.InstanceList.MapServer()
                        self.map_server.parent = self
                        self._children_name_map["map_server"] = "map-server"

                        self.other_xtr_probe = Native.Router.LispList.EidTable.InstanceList.OtherXtrProbe()
                        self.other_xtr_probe.parent = self
                        self._children_name_map["other_xtr_probe"] = "other-xtr-probe"

                        self.remote_rloc_probe = Native.Router.LispList.EidTable.InstanceList.RemoteRlocProbe()
                        self.remote_rloc_probe.parent = self
                        self._children_name_map["remote_rloc_probe"] = "remote-rloc-probe"

                        self.database_mapping = YList(self)
                        self.dynamic_eid = YList(self)
                        self.map_cache = YList(self)
                        self._segment_path = lambda: "instance-list" + "[instance-id='" + str(self.instance_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList, ['instance_id', 'vrf_name', 'default', 'vrf', 'disable_ttl_propagate'], name, value)


                    class DatabaseMapping(Entity):
                        """
                        Configures Locator addresses for an ETR
                        
                        .. attribute:: eid_prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: locator_set
                        
                        	Use locators defined by locator\-set
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.DatabaseMapping, self).__init__()

                            self.yang_name = "database-mapping"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['eid_prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                            ])
                            self.eid_prefix = None
                            self.locator_set = None
                            self._segment_path = lambda: "database-mapping" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.DatabaseMapping, ['eid_prefix', 'locator_set'], name, value)


                    class DynamicEid(Entity):
                        """
                        Configure a dynamic EID
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: database_mapping
                        
                        	Configures EID\-prefix and locator\-set for dynamic\-EID
                        	**type**\: list of  		 :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.DynamicEid.DatabaseMapping>`
                        
                        .. attribute:: eid_notify
                        
                        	Configure options for sending/receiving EID\-notify
                        	**type**\:  :py:class:`EidNotify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify>`
                        
                        .. attribute:: map_notify_group
                        
                        	Multicast group which to send map\-notifies to
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.DynamicEid.MapServer>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.DynamicEid, self).__init__()

                            self.yang_name = "dynamic-eid"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.EidTable.InstanceList.DynamicEid.DatabaseMapping)), ("eid-notify", ("eid_notify", Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify)), ("map-server", ("map_server", Native.Router.LispList.EidTable.InstanceList.DynamicEid.MapServer))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('map_notify_group', (YLeaf(YType.str, 'map-notify-group'), ['str','str'])),
                            ])
                            self.name = None
                            self.map_notify_group = None

                            self.eid_notify = Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify()
                            self.eid_notify.parent = self
                            self._children_name_map["eid_notify"] = "eid-notify"

                            self.database_mapping = YList(self)
                            self.map_server = YList(self)
                            self._segment_path = lambda: "dynamic-eid" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.DynamicEid, ['name', 'map_notify_group'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Configures EID\-prefix and locator\-set for dynamic\-EID
                            
                            .. attribute:: eid_prefix  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            .. attribute:: locator_set
                            
                            	Use locators defined by locator\-set
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.DynamicEid.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['eid_prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str'])),
                                    ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                ])
                                self.eid_prefix = None
                                self.locator_set = None
                                self._segment_path = lambda: "database-mapping" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.DynamicEid.DatabaseMapping, ['eid_prefix', 'locator_set'], name, value)


                        class EidNotify(Entity):
                            """
                            Configure options for sending/receiving EID\-notify
                            
                            .. attribute:: authentication_key
                            
                            	Authentication key used for validating received EID\-notify
                            	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey>`
                            
                            .. attribute:: gateway_key
                            
                            	
                            	**type**\: list of  		 :py:class:`GatewayKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify, self).__init__()

                                self.yang_name = "eid-notify"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey)), ("gateway-key", ("gateway_key", Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey))])
                                self._leafs = OrderedDict()

                                self.authentication_key = Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey()
                                self.authentication_key.parent = self
                                self._children_name_map["authentication_key"] = "authentication-key"

                                self.gateway_key = YList(self)
                                self._segment_path = lambda: "eid-notify"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify, [], name, value)


                            class AuthenticationKey(Entity):
                                """
                                Authentication key used for validating received EID\-notify
                                
                                .. attribute:: ak_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: ak_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: unc_pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey, self).__init__()

                                    self.yang_name = "authentication-key"
                                    self.yang_parent_name = "eid-notify"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                    ])
                                    self.ak_0 = None
                                    self.ak_6 = None
                                    self.unc_pwd = None
                                    self._segment_path = lambda: "authentication-key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify.AuthenticationKey, ['ak_0', 'ak_6', 'unc_pwd'], name, value)


                            class GatewayKey(Entity):
                                """
                                
                                
                                .. attribute:: gateway_ip  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ak_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: ak_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: unc_pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: hash_function
                                
                                	EID\-notify authentication type
                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey.HashFunction>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey, self).__init__()

                                    self.yang_name = "gateway-key"
                                    self.yang_parent_name = "eid-notify"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['gateway_ip']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('gateway_ip', (YLeaf(YType.str, 'gateway-ip'), ['str','str'])),
                                        ('ak_0', (YLeaf(YType.str, 'ak-0'), ['str'])),
                                        ('ak_6', (YLeaf(YType.str, 'ak-6'), ['str'])),
                                        ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey.HashFunction')])),
                                    ])
                                    self.gateway_ip = None
                                    self.ak_0 = None
                                    self.ak_6 = None
                                    self.unc_pwd = None
                                    self.hash_function = None
                                    self._segment_path = lambda: "gateway-key" + "[gateway-ip='" + str(self.gateway_ip) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.DynamicEid.EidNotify.GatewayKey, ['gateway_ip', 'ak_0', 'ak_6', 'unc_pwd', 'hash_function'], name, value)

                                class HashFunction(Enum):
                                    """
                                    HashFunction (Enum Class)

                                    EID\-notify authentication type

                                    .. data:: sha1 = 0

                                    .. data:: sha2 = 1

                                    """

                                    sha1 = Enum.YLeaf(0, "sha1")

                                    sha2 = Enum.YLeaf(1, "sha2")



                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: key
                            
                            	Authentication key used with map server
                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.DynamicEid.MapServer.Key>`
                            
                            .. attribute:: proxy_reply
                            
                            	Request Map\-Server to send Map\-Replies on behalf of site
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.DynamicEid.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "dynamic-eid"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip']
                                self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.EidTable.InstanceList.DynamicEid.MapServer.Key))])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                                    ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                ])
                                self.ip = None
                                self.proxy_reply = None

                                self.key = Native.Router.LispList.EidTable.InstanceList.DynamicEid.MapServer.Key()
                                self.key.parent = self
                                self._children_name_map["key"] = "key"
                                self._segment_path = lambda: "map-server" + "[ip='" + str(self.ip) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.DynamicEid.MapServer, ['ip', 'proxy_reply'], name, value)


                            class Key(Entity):
                                """
                                Authentication key used with map server
                                
                                .. attribute:: key_0
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: key_6
                                
                                	The ENCRYPTED password
                                	**type**\: str
                                
                                .. attribute:: key_7
                                
                                	The HIDDEN password
                                	**type**\: str
                                
                                .. attribute:: pwd
                                
                                	The UNENCRYPTED (cleartext) password
                                	**type**\: str
                                
                                .. attribute:: hash_function
                                
                                	Map\-Register authentication type
                                	**type**\:  :py:class:`HashFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.DynamicEid.MapServer.Key.HashFunction>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.DynamicEid.MapServer.Key, self).__init__()

                                    self.yang_name = "key"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                        ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                        ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                        ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                        ('hash_function', (YLeaf(YType.enumeration, 'hash-function'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.EidTable.InstanceList.DynamicEid.MapServer.Key.HashFunction')])),
                                    ])
                                    self.key_0 = None
                                    self.key_6 = None
                                    self.key_7 = None
                                    self.pwd = None
                                    self.hash_function = None
                                    self._segment_path = lambda: "key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.DynamicEid.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd', 'hash_function'], name, value)

                                class HashFunction(Enum):
                                    """
                                    HashFunction (Enum Class)

                                    Map\-Register authentication type

                                    .. data:: sha1 = 0

                                    .. data:: sha2 = 1

                                    """

                                    sha1 = Enum.YLeaf(0, "sha1")

                                    sha2 = Enum.YLeaf(1, "sha2")



                    class Alt(Entity):
                        """
                        LISP Alternative Topology, LISP\-ALT
                        
                        .. attribute:: summary_route
                        
                        	Summary route to install into the ALT table
                        	**type**\: list of  		 :py:class:`SummaryRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Alt.SummaryRoute>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.Alt, self).__init__()

                            self.yang_name = "alt"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("summary-route", ("summary_route", Native.Router.LispList.EidTable.InstanceList.Alt.SummaryRoute))])
                            self._leafs = OrderedDict()

                            self.summary_route = YList(self)
                            self._segment_path = lambda: "alt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Alt, [], name, value)


                        class SummaryRoute(Entity):
                            """
                            Summary route to install into the ALT table
                            
                            .. attribute:: eid_prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: route_tag
                            
                            	ALT RIB route tag for EID prefix
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Alt.SummaryRoute, self).__init__()

                                self.yang_name = "summary-route"
                                self.yang_parent_name = "alt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['eid_prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.eid_prefix = None
                                self.route_tag = None
                                self._segment_path = lambda: "summary-route" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Alt.SummaryRoute, ['eid_prefix', 'route_tag'], name, value)


                    class ControlPacket(Entity):
                        """
                        Configure control packet tx option
                        
                        .. attribute:: mtu
                        
                        	Configure control packet MTU
                        	**type**\: int
                        
                        	**range:** 304..10000
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.ControlPacket, self).__init__()

                            self.yang_name = "control-packet"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ])
                            self.mtu = None
                            self._segment_path = lambda: "control-packet"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.ControlPacket, ['mtu'], name, value)


                    class Ddt(Entity):
                        """
                        Delegated Database Tree (DDT) mapping system
                        
                        .. attribute:: authoritative
                        
                        	DDT authoritative prefix
                        	**type**\:  :py:class:`Authoritative <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative>`
                        
                        .. attribute:: cache_limit
                        
                        	DDT resolver cache entry limit
                        	**type**\: int
                        
                        	**range:** 1..100000
                        
                        .. attribute:: root
                        
                        	DDT root node
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.Ddt, self).__init__()

                            self.yang_name = "ddt"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authoritative", ("authoritative", Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cache_limit', (YLeaf(YType.uint32, 'cache-limit'), ['int'])),
                                ('root', (YLeaf(YType.str, 'root'), ['str','str'])),
                            ])
                            self.cache_limit = None
                            self.root = None

                            self.authoritative = Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative()
                            self.authoritative.parent = self
                            self._children_name_map["authoritative"] = "authoritative"
                            self._segment_path = lambda: "ddt"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ddt, ['cache_limit', 'root'], name, value)


                        class Authoritative(Entity):
                            """
                            DDT authoritative prefix
                            
                            .. attribute:: instance_id_eid_prefix_list
                            
                            	
                            	**type**\: list of  		 :py:class:`InstanceIdEidPrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList>`
                            
                            .. attribute:: instance_id_list
                            
                            	
                            	**type**\: list of  		 :py:class:`InstanceIdList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative, self).__init__()

                                self.yang_name = "authoritative"
                                self.yang_parent_name = "ddt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("instance-id-eid-prefix-list", ("instance_id_eid_prefix_list", Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList)), ("instance-id-list", ("instance_id_list", Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList))])
                                self._leafs = OrderedDict()

                                self.instance_id_eid_prefix_list = YList(self)
                                self.instance_id_list = YList(self)
                                self._segment_path = lambda: "authoritative"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative, [], name, value)


                            class InstanceIdEidPrefixList(Entity):
                                """
                                
                                
                                .. attribute:: instance_id  (key)
                                
                                	EID instance\-ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: eid_prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: delegate
                                
                                	DDT delegation to a child DDT node or map\-server
                                	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate>`
                                
                                .. attribute:: map_server_peer
                                
                                	Peer map\-servers that are authoritative for the same EID prefixes
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList, self).__init__()

                                    self.yang_name = "instance-id-eid-prefix-list"
                                    self.yang_parent_name = "authoritative"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['instance_id','eid_prefix']
                                    self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate))])
                                    self._leafs = OrderedDict([
                                        ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                        ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                        ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                    ])
                                    self.instance_id = None
                                    self.eid_prefix = None
                                    self.map_server_peer = None

                                    self.delegate = Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate()
                                    self.delegate.parent = self
                                    self._children_name_map["delegate"] = "delegate"
                                    self._segment_path = lambda: "instance-id-eid-prefix-list" + "[instance-id='" + str(self.instance_id) + "']" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList, ['instance_id', 'eid_prefix', 'map_server_peer'], name, value)


                                class Delegate(Entity):
                                    """
                                    DDT delegation to a child DDT node or map\-server
                                    
                                    .. attribute:: eid_prefix
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: instance_id
                                    
                                    	EID instance\-ID
                                    	**type**\: str
                                    
                                    .. attribute:: to
                                    
                                    	DDT delegation to a child DDT node or map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ip_address
                                    
                                    	IPv4/6 Child or map\-server node locator address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: map_server
                                    
                                    	Delegation points to a map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, self).__init__()

                                        self.yang_name = "delegate"
                                        self.yang_parent_name = "instance-id-eid-prefix-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                            ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                            ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.instance_id = None
                                        self.to = None
                                        self.ip_address = None
                                        self.map_server = None
                                        self._segment_path = lambda: "delegate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdEidPrefixList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                            class InstanceIdList(Entity):
                                """
                                
                                
                                .. attribute:: instance_id  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: delegate
                                
                                	DDT delegation to a child DDT node or map\-server
                                	**type**\:  :py:class:`Delegate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate>`
                                
                                .. attribute:: map_server_peer
                                
                                	Peer map\-servers that are authoritative for the same EID prefixes
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList, self).__init__()

                                    self.yang_name = "instance-id-list"
                                    self.yang_parent_name = "authoritative"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['instance_id']
                                    self._child_classes = OrderedDict([("delegate", ("delegate", Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate))])
                                    self._leafs = OrderedDict([
                                        ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                        ('map_server_peer', (YLeaf(YType.str, 'map-server-peer'), ['str','str'])),
                                    ])
                                    self.instance_id = None
                                    self.map_server_peer = None

                                    self.delegate = Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate()
                                    self.delegate.parent = self
                                    self._children_name_map["delegate"] = "delegate"
                                    self._segment_path = lambda: "instance-id-list" + "[instance-id='" + str(self.instance_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList, ['instance_id', 'map_server_peer'], name, value)


                                class Delegate(Entity):
                                    """
                                    DDT delegation to a child DDT node or map\-server
                                    
                                    .. attribute:: eid_prefix
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: instance_id
                                    
                                    	EID instance\-ID
                                    	**type**\: str
                                    
                                    .. attribute:: to
                                    
                                    	DDT delegation to a child DDT node or map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ip_address
                                    
                                    	IPv4/6 Child or map\-server node locator address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: map_server
                                    
                                    	Delegation points to a map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate, self).__init__()

                                        self.yang_name = "delegate"
                                        self.yang_parent_name = "instance-id-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                            ('instance_id', (YLeaf(YType.str, 'instance-id'), ['str'])),
                                            ('to', (YLeaf(YType.empty, 'to'), ['Empty'])),
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                            ('map_server', (YLeaf(YType.empty, 'map-server'), ['Empty'])),
                                        ])
                                        self.eid_prefix = None
                                        self.instance_id = None
                                        self.to = None
                                        self.ip_address = None
                                        self.map_server = None
                                        self._segment_path = lambda: "delegate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ddt.Authoritative.InstanceIdList.Delegate, ['eid_prefix', 'instance_id', 'to', 'ip_address', 'map_server'], name, value)


                    class Decapsulation(Entity):
                        """
                        Decapsulation behavior (e.g. filters)
                        
                        .. attribute:: filter
                        
                        	Filters traffic
                        	**type**\:  :py:class:`Filter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.Decapsulation, self).__init__()

                            self.yang_name = "decapsulation"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("filter", ("filter", Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter))])
                            self._leafs = OrderedDict()

                            self.filter = Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter()
                            self.filter.parent = self
                            self._children_name_map["filter"] = "filter"
                            self._segment_path = lambda: "decapsulation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Decapsulation, [], name, value)


                        class Filter(Entity):
                            """
                            Filters traffic
                            
                            .. attribute:: rloc
                            
                            	Filter based on Routing Locator (RLOC) in packet header
                            	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter.Rloc>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter, self).__init__()

                                self.yang_name = "filter"
                                self.yang_parent_name = "decapsulation"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter.Rloc))])
                                self._leafs = OrderedDict()

                                self.rloc = Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter.Rloc()
                                self.rloc.parent = self
                                self._children_name_map["rloc"] = "rloc"
                                self._segment_path = lambda: "filter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter, [], name, value)


                            class Rloc(Entity):
                                """
                                Filter based on Routing Locator (RLOC) in packet header
                                
                                .. attribute:: source
                                
                                	Filters traffic based on RLOC source address
                                	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter.Rloc, self).__init__()

                                    self.yang_name = "rloc"
                                    self.yang_parent_name = "filter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source))])
                                    self._leafs = OrderedDict()

                                    self.source = Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                    self._segment_path = lambda: "rloc"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter.Rloc, [], name, value)


                                class Source(Entity):
                                    """
                                    Filters traffic based on RLOC source address
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator\-set Name
                                    	**type**\: str
                                    
                                    .. attribute:: member
                                    
                                    	Members learned from map\-server
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source, self).__init__()

                                        self.yang_name = "source"
                                        self.yang_parent_name = "rloc"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ('member', (YLeaf(YType.empty, 'member'), ['Empty'])),
                                        ])
                                        self.locator_set = None
                                        self.member = None
                                        self._segment_path = lambda: "source"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Decapsulation.Filter.Rloc.Source, ['locator_set', 'member'], name, value)


                    class Etr(Entity):
                        """
                        Configures a LISP Egress Tunnel Router (ETR)
                        
                        .. attribute:: map_server
                        
                        	Configures map server for ETR registration
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Etr.MapServer>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.Etr, self).__init__()

                            self.yang_name = "etr"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.EidTable.InstanceList.Etr.MapServer))])
                            self._leafs = OrderedDict()

                            self.map_server = Native.Router.LispList.EidTable.InstanceList.Etr.MapServer()
                            self.map_server.parent = self
                            self._children_name_map["map_server"] = "map-server"
                            self._segment_path = lambda: "etr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Etr, [], name, value)


                        class MapServer(Entity):
                            """
                            Configures map server for ETR registration
                            
                            .. attribute:: source_address
                            
                            	Configures map server source address
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Etr.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "etr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                ])
                                self.source_address = None
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Etr.MapServer, ['source_address'], name, value)


                    class Ipv4(Entity):
                        """
                        IPv4 address family
                        
                        .. attribute:: alt_vrf
                        
                        	Activate LISP\-ALT functionality in VRF
                        	**type**\: str
                        
                        	**status**\: deprecated
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.DatabaseMapping>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.Distance>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.ItrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.EtrEnable>`
                        
                        .. attribute:: locator
                        
                        	Locator related configuration
                        	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.Locator>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCache>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCacheLimit>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCachePersistent>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: path_mtu_discovery
                        
                        	Path MTU discovery
                        	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.PathMtuDiscovery>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\: union of the below types:
                        
                        		**type**\: list of str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: list of str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteExport>`
                        
                        .. attribute:: route_import
                        
                        	Import RIB routes by a routing protocol into LISP
                        	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.SolicitMapRequest>`
                        
                        .. attribute:: source_locator
                        
                        	Source Locator configuration
                        	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.UsePetr>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.EidTable.InstanceList.Ipv4.DatabaseMapping)), ("distance", ("distance", Native.Router.LispList.EidTable.InstanceList.Ipv4.Distance)), ("itr", ("itr", Native.Router.LispList.EidTable.InstanceList.Ipv4.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.EidTable.InstanceList.Ipv4.ItrEnable)), ("etr", ("etr", Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr)), ("etr-enable", ("etr_enable", Native.Router.LispList.EidTable.InstanceList.Ipv4.EtrEnable)), ("locator", ("locator", Native.Router.LispList.EidTable.InstanceList.Ipv4.Locator)), ("map-cache", ("map_cache", Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.LispList.EidTable.InstanceList.Ipv4.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteExport)), ("route-import", ("route_import", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport)), ("site-registration", ("site_registration", Native.Router.LispList.EidTable.InstanceList.Ipv4.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.EidTable.InstanceList.Ipv4.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator)), ("use-petr", ("use_petr", Native.Router.LispList.EidTable.InstanceList.Ipv4.UsePetr))])
                            self._leafs = OrderedDict([
                                ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                            ])
                            self.alt_vrf = None
                            self.map_request_source = None
                            self.proxy_etr = None
                            self.proxy_itr = []
                            self.sgt = None

                            self.database_mapping = Native.Router.LispList.EidTable.InstanceList.Ipv4.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.distance = Native.Router.LispList.EidTable.InstanceList.Ipv4.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.itr = Native.Router.LispList.EidTable.InstanceList.Ipv4.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.LispList.EidTable.InstanceList.Ipv4.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr = Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.etr_enable = Native.Router.LispList.EidTable.InstanceList.Ipv4.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.locator = Native.Router.LispList.EidTable.InstanceList.Ipv4.Locator()
                            self.locator.parent = self
                            self._children_name_map["locator"] = "locator"

                            self.map_cache = Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_limit = Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_cache_persistent = Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.path_mtu_discovery = None
                            self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                            self.route_export = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.route_import = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport()
                            self.route_import.parent = self
                            self._children_name_map["route_import"] = "route-import"

                            self.site_registration = Native.Router.LispList.EidTable.InstanceList.Ipv4.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.LispList.EidTable.InstanceList.Ipv4.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.source_locator = Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator()
                            self.source_locator.parent = self
                            self._children_name_map["source_locator"] = "source-locator"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.LispList.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.Itr.MapResolver>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.EidTable.InstanceList.Ipv4.Itr.MapResolver))])
                                self._leafs = OrderedDict()

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.Itr, [], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ])
                                    self.ip_addr = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.Itr.MapResolver, ['ip_addr'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.ItrEnable, ['itr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr.MapServer))])
                                self._leafs = OrderedDict()

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr, [], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: key_7
                                    
                                    	The HIDDEN password
                                    	**type**\: str
                                    
                                    .. attribute:: pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                            ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                        ])
                                        self.key_0 = None
                                        self.key_6 = None
                                        self.key_7 = None
                                        self.pwd = None
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.EtrEnable, ['etr'], name, value)


                        class Locator(Entity):
                            """
                            Locator related configuration
                            
                            .. attribute:: reachability
                            
                            	Configuration realted to locator reachability
                            	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.Locator.Reachability>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.Locator, self).__init__()

                                self.yang_name = "locator"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.LispList.EidTable.InstanceList.Ipv4.Locator.Reachability))])
                                self._leafs = OrderedDict()

                                self.reachability = Native.Router.LispList.EidTable.InstanceList.Ipv4.Locator.Reachability()
                                self.reachability.parent = self
                                self._children_name_map["reachability"] = "reachability"
                                self._segment_path = lambda: "locator"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.Locator, [], name, value)


                            class Reachability(Entity):
                                """
                                Configuration realted to locator reachability
                                
                                .. attribute:: exclude_default
                                
                                	If a remote RLOC is reached via the default route, treat it as unreachable
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.Locator.Reachability, self).__init__()

                                    self.yang_name = "reachability"
                                    self.yang_parent_name = "locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                    ])
                                    self.exclude_default = None
                                    self._segment_path = lambda: "reachability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.Locator.Reachability, ['exclude_default'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None
                                self._segment_path = lambda: "map-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCache, ['site_registration'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapCachePersistent, ['interval'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 prefixes
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 prefixes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                                ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.list = None
                                            self.registered = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class PathMtuDiscovery(Entity):
                            """
                            Path MTU discovery
                            
                            .. attribute:: max
                            
                            	Upper bound on the path MTU accepted
                            	**type**\: int
                            
                            	**range:** 68..65535
                            
                            .. attribute:: min
                            
                            	Lower bound on the path MTU accepted
                            	**type**\: int
                            
                            	**range:** 68..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.PathMtuDiscovery, self).__init__()

                                self.yang_name = "path-mtu-discovery"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                    ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                ])
                                self.max = None
                                self.min = None
                                self._segment_path = lambda: "path-mtu-discovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.PathMtuDiscovery, ['max', 'min'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class RouteImport(Entity):
                            """
                            Import RIB routes by a routing protocol into LISP
                            
                            .. attribute:: database
                            
                            	Use RIB routes to define local EID database entries
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database>`
                            
                            .. attribute:: map_cache
                            
                            	Use RIB routes to define EID address space in map\-cache
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport, self).__init__()

                                self.yang_name = "route-import"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"

                                self.map_cache = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"
                                self._segment_path = lambda: "route-import"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport, [], name, value)


                            class Database(Entity):
                                """
                                Use RIB routes to define local EID database entries
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected>`
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes to pick up from the RIB
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix>`
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip>`
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Static>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "route-import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip)), ("static", ("static", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Static))])
                                    self._leafs = OrderedDict()

                                    self.connected = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected()
                                    self.connected.parent = self
                                    self._children_name_map["connected"] = "connected"

                                    self.maximum_prefix = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.rip = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip()
                                    self.rip.parent = self
                                    self._children_name_map["rip"] = "rip"

                                    self.static = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Static()
                                    self.static.parent = self
                                    self._children_name_map["static"] = "static"

                                    self.bgp = YList(self)
                                    self.eigrp = YList(self)
                                    self.isis = YList(self)
                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "database"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database, [], name, value)


                                class Bgp(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "connected"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes to pick up from the RIB
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold1
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only1
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.warning_only = None
                                        self.threshold = None
                                        self.threshold1 = None
                                        self.warning_only1 = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "rip"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Static, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class MapCache(Entity):
                                """
                                Use RIB routes to define EID address space in map\-cache
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes to pick up from the RIB
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix>`
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "route-import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static))])
                                    self._leafs = OrderedDict()

                                    self.connected = None
                                    self._children_name_map["connected"] = "connected"

                                    self.maximum_prefix = Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.rip = None
                                    self._children_name_map["rip"] = "rip"

                                    self.static = None
                                    self._children_name_map["static"] = "static"

                                    self.bgp = YList(self)
                                    self.eigrp = YList(self)
                                    self.isis = YList(self)
                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache, [], name, value)


                                class Bgp(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "connected"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes to pick up from the RIB
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold1
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only1
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.warning_only = None
                                        self.threshold = None
                                        self.threshold1 = None
                                        self.warning_only1 = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "rip"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations for a given instance\-id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class SourceLocator(Entity):
                            """
                            Source Locator configuration
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator, self).__init__()

                                self.yang_name = "source-locator"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "source-locator"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	Configures which Locators from a set are preferred
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: weight
                            
                            	Traffic load\-spreading among Locators
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv4.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                ])
                                self.locator_address = None
                                self.priority = None
                                self.weight = None
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv4.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                    class Ipv6(Entity):
                        """
                        IPv6 address family
                        
                        .. attribute:: alt_vrf
                        
                        	Activate LISP\-ALT functionality in VRF
                        	**type**\: str
                        
                        	**status**\: deprecated
                        
                        .. attribute:: database_mapping
                        
                        	Address family specific local EID prefixes database configuration
                        	**type**\:  :py:class:`DatabaseMapping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.DatabaseMapping>`
                        
                        .. attribute:: distance
                        
                        	Administrative distance for RIB route installation
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.Distance>`
                        
                        .. attribute:: itr
                        
                        	Configures a LISP Ingress Tunnel Router (ITR)
                        	**type**\:  :py:class:`Itr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.Itr>`
                        
                        .. attribute:: itr_enable
                        
                        	
                        	**type**\:  :py:class:`ItrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.ItrEnable>`
                        
                        .. attribute:: etr
                        
                        	Configures a LISP Egress Tunnel Router (ETR)
                        	**type**\:  :py:class:`Etr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr>`
                        
                        .. attribute:: etr_enable
                        
                        	
                        	**type**\:  :py:class:`EtrEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.EtrEnable>`
                        
                        .. attribute:: locator
                        
                        	Locator related configuration
                        	**type**\:  :py:class:`Locator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.Locator>`
                        
                        .. attribute:: map_cache
                        
                        	Address family specific map cache configuration
                        	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCache>`
                        
                        .. attribute:: map_cache_limit
                        
                        	Configures maximum size of map\-cache
                        	**type**\:  :py:class:`MapCacheLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCacheLimit>`
                        
                        .. attribute:: map_cache_persistent
                        
                        	Dump map\-cache onto flash, making it persistent across reboots
                        	**type**\:  :py:class:`MapCachePersistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCachePersistent>`
                        
                        .. attribute:: map_request_source
                        
                        	Configures inner header source address in Map\-Request message
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: map_resolver
                        
                        	Configures a LISP Map Resolver (MR)
                        	**type**\:  :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: map_server
                        
                        	Configures a LISP Map Server (MS)
                        	**type**\:  :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: path_mtu_discovery
                        
                        	Path MTU discovery
                        	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.PathMtuDiscovery>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: proxy_etr
                        
                        	Configures a LISP Proxy Engress Tunnel Router (PETR)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: proxy_itr
                        
                        	Configures a LISP Proxy Ingress Tunnel Router (PITR)
                        	**type**\: union of the below types:
                        
                        		**type**\: list of str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: list of str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: route_export
                        
                        	Export routes into RIB from LISP
                        	**type**\:  :py:class:`RouteExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteExport>`
                        
                        .. attribute:: route_import
                        
                        	Import RIB routes by a routing protocol into LISP
                        	**type**\:  :py:class:`RouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport>`
                        
                        .. attribute:: sgt
                        
                        	Enable security group tag propagation in LISP encapsulated traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: site_registration
                        
                        	Site registrations configuration for a given instance\-id
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.SiteRegistration>`
                        
                        .. attribute:: solicit_map_request
                        
                        	Configure Solicit\-Map\-Request handling
                        	**type**\:  :py:class:`SolicitMapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.SolicitMapRequest>`
                        
                        .. attribute:: source_locator
                        
                        	Source Locator configuration
                        	**type**\:  :py:class:`SourceLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator>`
                        
                        .. attribute:: use_petr
                        
                        	Encapsulate to Proxy ETR when matching forward\-native entry
                        	**type**\: list of  		 :py:class:`UsePetr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.UsePetr>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database-mapping", ("database_mapping", Native.Router.LispList.EidTable.InstanceList.Ipv6.DatabaseMapping)), ("distance", ("distance", Native.Router.LispList.EidTable.InstanceList.Ipv6.Distance)), ("itr", ("itr", Native.Router.LispList.EidTable.InstanceList.Ipv6.Itr)), ("itr-enable", ("itr_enable", Native.Router.LispList.EidTable.InstanceList.Ipv6.ItrEnable)), ("etr", ("etr", Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr)), ("etr-enable", ("etr_enable", Native.Router.LispList.EidTable.InstanceList.Ipv6.EtrEnable)), ("locator", ("locator", Native.Router.LispList.EidTable.InstanceList.Ipv6.Locator)), ("map-cache", ("map_cache", Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCache)), ("map-cache-limit", ("map_cache_limit", Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCacheLimit)), ("map-cache-persistent", ("map_cache_persistent", Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCachePersistent)), ("map-resolver", ("map_resolver", Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver)), ("map-server", ("map_server", Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer)), ("path-mtu-discovery", ("path_mtu_discovery", Native.Router.LispList.EidTable.InstanceList.Ipv6.PathMtuDiscovery)), ("route-export", ("route_export", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteExport)), ("route-import", ("route_import", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport)), ("site-registration", ("site_registration", Native.Router.LispList.EidTable.InstanceList.Ipv6.SiteRegistration)), ("solicit-map-request", ("solicit_map_request", Native.Router.LispList.EidTable.InstanceList.Ipv6.SolicitMapRequest)), ("source-locator", ("source_locator", Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator)), ("use-petr", ("use_petr", Native.Router.LispList.EidTable.InstanceList.Ipv6.UsePetr))])
                            self._leafs = OrderedDict([
                                ('alt_vrf', (YLeaf(YType.str, 'alt-vrf'), ['str'])),
                                ('map_request_source', (YLeaf(YType.str, 'map-request-source'), ['str'])),
                                ('proxy_etr', (YLeaf(YType.empty, 'proxy-etr'), ['Empty'])),
                                ('proxy_itr', (YLeafList(YType.str, 'proxy-itr'), ['str','str'])),
                                ('sgt', (YLeaf(YType.empty, 'sgt'), ['Empty'])),
                            ])
                            self.alt_vrf = None
                            self.map_request_source = None
                            self.proxy_etr = None
                            self.proxy_itr = []
                            self.sgt = None

                            self.database_mapping = Native.Router.LispList.EidTable.InstanceList.Ipv6.DatabaseMapping()
                            self.database_mapping.parent = self
                            self._children_name_map["database_mapping"] = "database-mapping"

                            self.distance = Native.Router.LispList.EidTable.InstanceList.Ipv6.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.itr = Native.Router.LispList.EidTable.InstanceList.Ipv6.Itr()
                            self.itr.parent = self
                            self._children_name_map["itr"] = "itr"

                            self.itr_enable = Native.Router.LispList.EidTable.InstanceList.Ipv6.ItrEnable()
                            self.itr_enable.parent = self
                            self._children_name_map["itr_enable"] = "itr-enable"

                            self.etr = Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr()
                            self.etr.parent = self
                            self._children_name_map["etr"] = "etr"

                            self.etr_enable = Native.Router.LispList.EidTable.InstanceList.Ipv6.EtrEnable()
                            self.etr_enable.parent = self
                            self._children_name_map["etr_enable"] = "etr-enable"

                            self.locator = Native.Router.LispList.EidTable.InstanceList.Ipv6.Locator()
                            self.locator.parent = self
                            self._children_name_map["locator"] = "locator"

                            self.map_cache = Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCache()
                            self.map_cache.parent = self
                            self._children_name_map["map_cache"] = "map-cache"

                            self.map_cache_limit = Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCacheLimit()
                            self.map_cache_limit.parent = self
                            self._children_name_map["map_cache_limit"] = "map-cache-limit"

                            self.map_cache_persistent = Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCachePersistent()
                            self.map_cache_persistent.parent = self
                            self._children_name_map["map_cache_persistent"] = "map-cache-persistent"

                            self.map_resolver = None
                            self._children_name_map["map_resolver"] = "map-resolver"

                            self.map_server = None
                            self._children_name_map["map_server"] = "map-server"

                            self.path_mtu_discovery = None
                            self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"

                            self.route_export = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteExport()
                            self.route_export.parent = self
                            self._children_name_map["route_export"] = "route-export"

                            self.route_import = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport()
                            self.route_import.parent = self
                            self._children_name_map["route_import"] = "route-import"

                            self.site_registration = Native.Router.LispList.EidTable.InstanceList.Ipv6.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.solicit_map_request = Native.Router.LispList.EidTable.InstanceList.Ipv6.SolicitMapRequest()
                            self.solicit_map_request.parent = self
                            self._children_name_map["solicit_map_request"] = "solicit-map-request"

                            self.source_locator = Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator()
                            self.source_locator.parent = self
                            self._children_name_map["source_locator"] = "source-locator"

                            self.use_petr = YList(self)
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6, ['alt_vrf', 'map_request_source', 'proxy_etr', 'proxy_itr', 'sgt'], name, value)


                        class DatabaseMapping(Entity):
                            """
                            Address family specific local EID prefixes database configuration
                            
                            .. attribute:: limit
                            
                            	Configures the maximum size of local EID prefixes database
                            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.DatabaseMapping, self).__init__()

                                self.yang_name = "database-mapping"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("limit", ("limit", Native.Router.LispList.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit))])
                                self._leafs = OrderedDict()

                                self.limit = Native.Router.LispList.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit()
                                self.limit.parent = self
                                self._children_name_map["limit"] = "limit"
                                self._segment_path = lambda: "database-mapping"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.DatabaseMapping, [], name, value)


                            class Limit(Entity):
                                """
                                Configures the maximum size of local EID prefixes database
                                
                                .. attribute:: dynamic
                                
                                	Configures the maximum size of dynamic local EID prefixes database
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: warning_threshold
                                
                                	Send warning message to syslog when the database\-mapping dynamic sizereaches this percentage of the limit
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit, self).__init__()

                                    self.yang_name = "limit"
                                    self.yang_parent_name = "database-mapping"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dynamic', (YLeaf(YType.uint32, 'dynamic'), ['int'])),
                                        ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                    ])
                                    self.dynamic = None
                                    self.warning_threshold = None
                                    self._segment_path = lambda: "limit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.DatabaseMapping.Limit, ['dynamic', 'warning_threshold'], name, value)


                        class Distance(Entity):
                            """
                            Administrative distance for RIB route installation
                            
                            .. attribute:: alt
                            
                            	LISP routes installed in the ALT table
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dyn_eid
                            
                            	LISP installed routes of type dynamic\-EID
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: site_registrations
                            
                            	LISP installed routes of type site\-registrations
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('alt', (YLeaf(YType.uint8, 'alt'), ['int'])),
                                    ('dyn_eid', (YLeaf(YType.uint8, 'dyn-eid'), ['int'])),
                                    ('site_registrations', (YLeaf(YType.uint8, 'site-registrations'), ['int'])),
                                ])
                                self.alt = None
                                self.dyn_eid = None
                                self.site_registrations = None
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.Distance, ['alt', 'dyn_eid', 'site_registrations'], name, value)


                        class Itr(Entity):
                            """
                            Configures a LISP Ingress Tunnel Router (ITR)
                            
                            .. attribute:: map_resolver
                            
                            	Configures map\-resolver address for sending Map\-Requests
                            	**type**\: list of  		 :py:class:`MapResolver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.Itr.MapResolver>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.Itr, self).__init__()

                                self.yang_name = "itr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-resolver", ("map_resolver", Native.Router.LispList.EidTable.InstanceList.Ipv6.Itr.MapResolver))])
                                self._leafs = OrderedDict()

                                self.map_resolver = YList(self)
                                self._segment_path = lambda: "itr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.Itr, [], name, value)


                            class MapResolver(Entity):
                                """
                                Configures map\-resolver address for sending Map\-Requests
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.Itr.MapResolver, self).__init__()

                                    self.yang_name = "map-resolver"
                                    self.yang_parent_name = "itr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                    ])
                                    self.ip_addr = None
                                    self._segment_path = lambda: "map-resolver" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.Itr.MapResolver, ['ip_addr'], name, value)


                        class ItrEnable(Entity):
                            """
                            
                            
                            .. attribute:: itr
                            
                            	Configures a LISP Ingress Tunnel Router (ITR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.ItrEnable, self).__init__()

                                self.yang_name = "itr-enable"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('itr', (YLeaf(YType.empty, 'itr'), ['Empty'])),
                                ])
                                self.itr = None
                                self._segment_path = lambda: "itr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.ItrEnable, ['itr'], name, value)


                        class Etr(Entity):
                            """
                            Configures a LISP Egress Tunnel Router (ETR)
                            
                            .. attribute:: map_server
                            
                            	Configures map server for ETR registration
                            	**type**\: list of  		 :py:class:`MapServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr.MapServer>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr, self).__init__()

                                self.yang_name = "etr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-server", ("map_server", Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr.MapServer))])
                                self._leafs = OrderedDict()

                                self.map_server = YList(self)
                                self._segment_path = lambda: "etr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr, [], name, value)


                            class MapServer(Entity):
                                """
                                Configures map server for ETR registration
                                
                                .. attribute:: ip_addr  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: key
                                
                                	Authentication key used with map server
                                	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr.MapServer.Key>`
                                
                                .. attribute:: proxy_reply
                                
                                	Request Map\-Server to send Map\-Replies on behalf of site
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr.MapServer, self).__init__()

                                    self.yang_name = "map-server"
                                    self.yang_parent_name = "etr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_addr']
                                    self._child_classes = OrderedDict([("key", ("key", Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr.MapServer.Key))])
                                    self._leafs = OrderedDict([
                                        ('ip_addr', (YLeaf(YType.str, 'ip-addr'), ['str','str'])),
                                        ('proxy_reply', (YLeaf(YType.empty, 'proxy-reply'), ['Empty'])),
                                    ])
                                    self.ip_addr = None
                                    self.proxy_reply = None

                                    self.key = Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr.MapServer.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._segment_path = lambda: "map-server" + "[ip-addr='" + str(self.ip_addr) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr.MapServer, ['ip_addr', 'proxy_reply'], name, value)


                                class Key(Entity):
                                    """
                                    Authentication key used with map server
                                    
                                    .. attribute:: key_0
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    .. attribute:: key_6
                                    
                                    	The ENCRYPTED password
                                    	**type**\: str
                                    
                                    .. attribute:: key_7
                                    
                                    	The HIDDEN password
                                    	**type**\: str
                                    
                                    .. attribute:: pwd
                                    
                                    	The UNENCRYPTED (cleartext) password
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr.MapServer.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "map-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                                            ('pwd', (YLeaf(YType.str, 'pwd'), ['str'])),
                                        ])
                                        self.key_0 = None
                                        self.key_6 = None
                                        self.key_7 = None
                                        self.pwd = None
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.Etr.MapServer.Key, ['key_0', 'key_6', 'key_7', 'pwd'], name, value)


                        class EtrEnable(Entity):
                            """
                            
                            
                            .. attribute:: etr
                            
                            	Configures a LISP Egress Tunnel Router (ETR)
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.EtrEnable, self).__init__()

                                self.yang_name = "etr-enable"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr', (YLeaf(YType.empty, 'etr'), ['Empty'])),
                                ])
                                self.etr = None
                                self._segment_path = lambda: "etr-enable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.EtrEnable, ['etr'], name, value)


                        class Locator(Entity):
                            """
                            Locator related configuration
                            
                            .. attribute:: reachability
                            
                            	Configuration realted to locator reachability
                            	**type**\:  :py:class:`Reachability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.Locator.Reachability>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.Locator, self).__init__()

                                self.yang_name = "locator"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("reachability", ("reachability", Native.Router.LispList.EidTable.InstanceList.Ipv6.Locator.Reachability))])
                                self._leafs = OrderedDict()

                                self.reachability = Native.Router.LispList.EidTable.InstanceList.Ipv6.Locator.Reachability()
                                self.reachability.parent = self
                                self._children_name_map["reachability"] = "reachability"
                                self._segment_path = lambda: "locator"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.Locator, [], name, value)


                            class Reachability(Entity):
                                """
                                Configuration realted to locator reachability
                                
                                .. attribute:: exclude_default
                                
                                	If a remote RLOC is reached via the default route, treat it as unreachable
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.Locator.Reachability, self).__init__()

                                    self.yang_name = "reachability"
                                    self.yang_parent_name = "locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('exclude_default', (YLeaf(YType.empty, 'exclude-default'), ['Empty'])),
                                    ])
                                    self.exclude_default = None
                                    self._segment_path = lambda: "reachability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.Locator.Reachability, ['exclude_default'], name, value)


                        class MapCache(Entity):
                            """
                            Address family specific map cache configuration
                            
                            .. attribute:: site_registration
                            
                            	Install map cache to map request for site registrations
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCache, self).__init__()

                                self.yang_name = "map-cache"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registration', (YLeaf(YType.empty, 'site-registration'), ['Empty'])),
                                ])
                                self.site_registration = None
                                self._segment_path = lambda: "map-cache"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCache, ['site_registration'], name, value)


                        class MapCacheLimit(Entity):
                            """
                            Configures maximum size of map\-cache
                            
                            .. attribute:: max_map_cache_entries
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..100000
                            
                            .. attribute:: reserve_list
                            
                            	EID\-prefixes guaranteed to be stored in map\-cache
                            	**type**\: str
                            
                            .. attribute:: warning_threshold
                            
                            	Send warning message to syslog when the map\-cache size reaches this percentage of the limit
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCacheLimit, self).__init__()

                                self.yang_name = "map-cache-limit"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_map_cache_entries', (YLeaf(YType.uint32, 'max-map-cache-entries'), ['int'])),
                                    ('reserve_list', (YLeaf(YType.str, 'reserve-list'), ['str'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.max_map_cache_entries = None
                                self.reserve_list = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "map-cache-limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCacheLimit, ['max_map_cache_entries', 'reserve_list', 'warning_threshold'], name, value)


                        class MapCachePersistent(Entity):
                            """
                            Dump map\-cache onto flash, making it persistent across reboots
                            
                            .. attribute:: interval
                            
                            	Interval in minutes of how often the map\-cache is saved
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCachePersistent, self).__init__()

                                self.yang_name = "map-cache-persistent"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                ])
                                self.interval = None
                                self._segment_path = lambda: "map-cache-persistent"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapCachePersistent, ['interval'], name, value)


                        class MapResolver(Entity):
                            """
                            Configures a LISP Map Resolver (MR)
                            
                            .. attribute:: map_request
                            
                            	Map\-Request processing options
                            	**type**\:  :py:class:`MapRequest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver, self).__init__()

                                self.yang_name = "map-resolver"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-request", ("map_request", Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_request = Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest()
                                self.map_request.parent = self
                                self._children_name_map["map_request"] = "map-request"
                                self._segment_path = lambda: "map-resolver"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver, [], name, value)


                            class MapRequest(Entity):
                                """
                                Map\-Request processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest, self).__init__()

                                    self.yang_name = "map-request"
                                    self.yang_parent_name = "map-resolver"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	Influence which source RLOCs map requests are accepted from
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        Influence which source RLOCs map requests are accepted from
                                        
                                        .. attribute:: list
                                        
                                        	Define allowed prefixes using an ip[v6] prefix list
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: registered
                                        
                                        	...from RLOCs that register EID\-prefixes in the same IID on a co\-located MapServer
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 prefixes
                                        	**type**\: str
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 prefixes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('list', (YLeaf(YType.empty, 'list'), ['Empty'])),
                                                ('registered', (YLeaf(YType.empty, 'registered'), ['Empty'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.list = None
                                            self.registered = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapResolver.MapRequest.Validate.Source, ['list', 'registered', 'ipv4', 'ipv6'], name, value)


                        class MapServer(Entity):
                            """
                            Configures a LISP Map Server (MS)
                            
                            .. attribute:: map_register
                            
                            	Map\-Register processing options
                            	**type**\:  :py:class:`MapRegister <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer, self).__init__()

                                self.yang_name = "map-server"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("map-register", ("map_register", Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.map_register = Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister()
                                self.map_register.parent = self
                                self._children_name_map["map_register"] = "map-register"
                                self._segment_path = lambda: "map-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer, [], name, value)


                            class MapRegister(Entity):
                                """
                                Map\-Register processing options
                                
                                .. attribute:: validate
                                
                                	Validation options
                                	**type**\:  :py:class:`Validate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister, self).__init__()

                                    self.yang_name = "map-register"
                                    self.yang_parent_name = "map-server"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("validate", ("validate", Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate))])
                                    self._leafs = OrderedDict()

                                    self.validate = Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate()
                                    self.validate.parent = self
                                    self._children_name_map["validate"] = "validate"
                                    self._segment_path = lambda: "map-register"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister, [], name, value)


                                class Validate(Entity):
                                    """
                                    Validation options
                                    
                                    .. attribute:: source
                                    
                                    	RLOC Source IP address
                                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate, self).__init__()

                                        self.yang_name = "validate"
                                        self.yang_parent_name = "map-register"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("source", ("source", Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source))])
                                        self._leafs = OrderedDict()

                                        self.source = Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source()
                                        self.source.parent = self
                                        self._children_name_map["source"] = "source"
                                        self._segment_path = lambda: "validate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate, [], name, value)


                                    class Source(Entity):
                                        """
                                        RLOC Source IP address
                                        
                                        .. attribute:: allowed_locator
                                        
                                        	Against sites' allowed\-locators policy
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source, self).__init__()

                                            self.yang_name = "source"
                                            self.yang_parent_name = "validate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allowed_locator', (YLeaf(YType.empty, 'allowed-locator'), ['Empty'])),
                                            ])
                                            self.allowed_locator = None
                                            self._segment_path = lambda: "source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.MapServer.MapRegister.Validate.Source, ['allowed_locator'], name, value)


                        class PathMtuDiscovery(Entity):
                            """
                            Path MTU discovery
                            
                            .. attribute:: max
                            
                            	Upper bound on the path MTU accepted
                            	**type**\: int
                            
                            	**range:** 68..65535
                            
                            .. attribute:: min
                            
                            	Lower bound on the path MTU accepted
                            	**type**\: int
                            
                            	**range:** 68..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.PathMtuDiscovery, self).__init__()

                                self.yang_name = "path-mtu-discovery"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                    ('min', (YLeaf(YType.uint16, 'min'), ['int'])),
                                ])
                                self.max = None
                                self.min = None
                                self._segment_path = lambda: "path-mtu-discovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.PathMtuDiscovery, ['max', 'min'], name, value)


                        class RouteExport(Entity):
                            """
                            Export routes into RIB from LISP
                            
                            .. attribute:: site_registrations
                            
                            	Export LISP site registrations to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: away_eids
                            
                            	Export LISP away EIDs to RIB
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteExport, self).__init__()

                                self.yang_name = "route-export"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('site_registrations', (YLeaf(YType.empty, 'site-registrations'), ['Empty'])),
                                    ('away_eids', (YLeaf(YType.empty, 'away-eids'), ['Empty'])),
                                ])
                                self.site_registrations = None
                                self.away_eids = None
                                self._segment_path = lambda: "route-export"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteExport, ['site_registrations', 'away_eids'], name, value)


                        class RouteImport(Entity):
                            """
                            Import RIB routes by a routing protocol into LISP
                            
                            .. attribute:: database
                            
                            	Use RIB routes to define local EID database entries
                            	**type**\:  :py:class:`Database <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database>`
                            
                            .. attribute:: map_cache
                            
                            	Use RIB routes to define EID address space in map\-cache
                            	**type**\:  :py:class:`MapCache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport, self).__init__()

                                self.yang_name = "route-import"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database", ("database", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database)), ("map-cache", ("map_cache", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache))])
                                self._leafs = OrderedDict()

                                self.database = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"

                                self.map_cache = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache()
                                self.map_cache.parent = self
                                self._children_name_map["map_cache"] = "map-cache"
                                self._segment_path = lambda: "route-import"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport, [], name, value)


                            class Database(Entity):
                                """
                                Use RIB routes to define local EID database entries
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected>`
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes to pick up from the RIB
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix>`
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip>`
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Static>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database, self).__init__()

                                    self.yang_name = "database"
                                    self.yang_parent_name = "route-import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp)), ("connected", ("connected", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp)), ("isis", ("isis", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3)), ("rip", ("rip", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip)), ("static", ("static", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Static))])
                                    self._leafs = OrderedDict()

                                    self.connected = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected()
                                    self.connected.parent = self
                                    self._children_name_map["connected"] = "connected"

                                    self.maximum_prefix = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.rip = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip()
                                    self.rip.parent = self
                                    self._children_name_map["rip"] = "rip"

                                    self.static = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Static()
                                    self.static.parent = self
                                    self._children_name_map["static"] = "static"

                                    self.bgp = YList(self)
                                    self.eigrp = YList(self)
                                    self.isis = YList(self)
                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "database"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database, [], name, value)


                                class Bgp(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Bgp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "connected"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Connected.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Eigrp.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Isis.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes to pick up from the RIB
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold1
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only1
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.warning_only = None
                                        self.threshold = None
                                        self.threshold1 = None
                                        self.warning_only1 = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospf.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3, ['id'], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Ospfv3.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "rip"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Rip.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: lisp_ip_route_import
                                    
                                    	
                                    	**type**\:  :py:class:`LispIpRouteImport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lisp-ip-route-import", ("lisp_ip_route_import", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport))])
                                        self._leafs = OrderedDict()

                                        self.lisp_ip_route_import = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport()
                                        self.lisp_ip_route_import.parent = self
                                        self._children_name_map["lisp_ip_route_import"] = "lisp-ip-route-import"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Static, [], name, value)


                                    class LispIpRouteImport(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        .. attribute:: locator_set
                                        
                                        	Locator set to use with created database mapping entries
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport, self).__init__()

                                            self.yang_name = "lisp-ip-route-import"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self.locator_set = None
                                            self._segment_path = lambda: "lisp-ip-route-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.Database.Static.LispIpRouteImport, ['route_map', 'locator_set'], name, value)


                            class MapCache(Entity):
                                """
                                Use RIB routes to define EID address space in map\-cache
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\: list of  		 :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes to pick up from the RIB
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix>`
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache, self).__init__()

                                    self.yang_name = "map-cache"
                                    self.yang_parent_name = "route-import"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp)), ("connected", ("connected", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected)), ("eigrp", ("eigrp", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp)), ("isis", ("isis", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis)), ("maximum-prefix", ("maximum_prefix", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix)), ("ospf", ("ospf", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf)), ("ospfv3", ("ospfv3", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3)), ("rip", ("rip", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip)), ("static", ("static", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static))])
                                    self._leafs = OrderedDict()

                                    self.connected = None
                                    self._children_name_map["connected"] = "connected"

                                    self.maximum_prefix = Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.rip = None
                                    self._children_name_map["rip"] = "rip"

                                    self.static = None
                                    self._children_name_map["static"] = "static"

                                    self.bgp = YList(self)
                                    self.eigrp = YList(self)
                                    self.isis = YList(self)
                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "map-cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache, [], name, value)


                                class Bgp(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "bgp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Bgp.MapCacheContainer, ['route_map'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "connected"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Connected.MapCacheContainer, ['route_map'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "eigrp" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Eigrp.MapCacheContainer, ['route_map'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "isis" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Isis.MapCacheContainer, ['route_map'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes to pick up from the RIB
                                    
                                    .. attribute:: number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: threshold1
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only1
                                    
                                    	Only give a warning message and do not limit entries
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.int32, 'number'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('threshold1', (YLeaf(YType.uint8, 'threshold1'), ['int'])),
                                            ('warning_only1', (YLeaf(YType.empty, 'warning-only1'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.warning_only = None
                                        self.threshold = None
                                        self.threshold1 = None
                                        self.warning_only1 = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.MaximumPrefix, ['number', 'warning_only', 'threshold', 'threshold1', 'warning_only1'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospf.MapCacheContainer, ['route_map'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3, ['id'], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Ospfv3.MapCacheContainer, ['route_map'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "rip"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Rip.MapCacheContainer, ['route_map'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: map_cache_container
                                    
                                    	
                                    	**type**\:  :py:class:`MapCacheContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "map-cache"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("map-cache-container", ("map_cache_container", Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.map_cache_container = None
                                        self._children_name_map["map_cache_container"] = "map-cache-container"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static, [], name, value)


                                    class MapCacheContainer(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map for route selection filtering
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-lisp'
                                        _revision = '2018-04-17'

                                        def __init__(self):
                                            super(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, self).__init__()

                                            self.yang_name = "map-cache-container"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "map-cache-container"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.RouteImport.MapCache.Static.MapCacheContainer, ['route_map'], name, value)


                        class SiteRegistration(Entity):
                            """
                            Site registrations configuration for a given instance\-id
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations for a given instance\-id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class SolicitMapRequest(Entity):
                            """
                            Configure Solicit\-Map\-Request handling
                            
                            .. attribute:: ignore
                            
                            	Ignore SMR bit in incoming Map\-Requests
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: max_per_entry
                            
                            	Maximum number of SMRs for addresses under a map\-cache entry
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: suppression_time
                            
                            	How long to suppress repeated SMRs for the same address
                            	**type**\: int
                            
                            	**range:** 1..600
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.SolicitMapRequest, self).__init__()

                                self.yang_name = "solicit-map-request"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                    ('max_per_entry', (YLeaf(YType.uint8, 'max-per-entry'), ['int'])),
                                    ('suppression_time', (YLeaf(YType.uint16, 'suppression-time'), ['int'])),
                                ])
                                self.ignore = None
                                self.max_per_entry = None
                                self.suppression_time = None
                                self._segment_path = lambda: "solicit-map-request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.SolicitMapRequest, ['ignore', 'max_per_entry', 'suppression_time'], name, value)


                        class SourceLocator(Entity):
                            """
                            Source Locator configuration
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator, self).__init__()

                                self.yang_name = "source-locator"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "source-locator"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "source-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.SourceLocator.PortChannelSubinterface, [u'port_channel'], name, value)


                        class UsePetr(Entity):
                            """
                            Encapsulate to Proxy ETR when matching forward\-native entry
                            
                            .. attribute:: locator_address  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	Configures which Locators from a set are preferred
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: weight
                            
                            	Traffic load\-spreading among Locators
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.Ipv6.UsePetr, self).__init__()

                                self.yang_name = "use-petr"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['locator_address']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('locator_address', (YLeaf(YType.str, 'locator-address'), ['str','str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                ])
                                self.locator_address = None
                                self.priority = None
                                self.weight = None
                                self._segment_path = lambda: "use-petr" + "[locator-address='" + str(self.locator_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.Ipv6.UsePetr, ['locator_address', 'priority', 'weight'], name, value)


                    class LocReachAlgorithm(Entity):
                        """
                        Configure locator reachability algorithm
                        
                        .. attribute:: lsb_reports
                        
                        	Configure data packet LSB report handling
                        	**type**\:  :py:class:`LsbReports <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.LocReachAlgorithm.LsbReports>`
                        
                        .. attribute:: rloc_probing
                        
                        	Probe high priority RLOCs with Map\-Requests as last resort
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.LocReachAlgorithm, self).__init__()

                            self.yang_name = "loc-reach-algorithm"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lsb-reports", ("lsb_reports", Native.Router.LispList.EidTable.InstanceList.LocReachAlgorithm.LsbReports))])
                            self._leafs = OrderedDict([
                                ('rloc_probing', (YLeaf(YType.empty, 'rloc-probing'), ['Empty'])),
                            ])
                            self.rloc_probing = None

                            self.lsb_reports = Native.Router.LispList.EidTable.InstanceList.LocReachAlgorithm.LsbReports()
                            self.lsb_reports.parent = self
                            self._children_name_map["lsb_reports"] = "lsb-reports"
                            self._segment_path = lambda: "loc-reach-algorithm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.LocReachAlgorithm, ['rloc_probing'], name, value)


                        class LsbReports(Entity):
                            """
                            Configure data packet LSB report handling
                            
                            .. attribute:: do_not_transmit
                            
                            	Force the setting of the encapsulation header L bit to zero
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ignore
                            
                            	Ignore data packet LSB reports
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.LocReachAlgorithm.LsbReports, self).__init__()

                                self.yang_name = "lsb-reports"
                                self.yang_parent_name = "loc-reach-algorithm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('do_not_transmit', (YLeaf(YType.empty, 'do-not-transmit'), ['Empty'])),
                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                ])
                                self.do_not_transmit = None
                                self.ignore = None
                                self._segment_path = lambda: "lsb-reports"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.LocReachAlgorithm.LsbReports, ['do_not_transmit', 'ignore'], name, value)


                    class LocatorDown(Entity):
                        """
                        Manually set locator status to down
                        
                        .. attribute:: address
                        
                        	IPv4/6 Locator address to be set down
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv4_interface
                        
                        	Use IPv4 address of interface as locator
                        	**type**\: str
                        
                        .. attribute:: ipv6_interface
                        
                        	Use IPv6 address of interface as locator
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.LocatorDown, self).__init__()

                            self.yang_name = "locator-down"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                ('ipv4_interface', (YLeaf(YType.str, 'IPv4-interface'), ['str'])),
                                ('ipv6_interface', (YLeaf(YType.str, 'IPv6-interface'), ['str'])),
                            ])
                            self.address = None
                            self.ipv4_interface = None
                            self.ipv6_interface = None
                            self._segment_path = lambda: "locator-down"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.LocatorDown, ['address', 'ipv4_interface', 'ipv6_interface'], name, value)


                    class LocatorTable(Entity):
                        """
                        Specify the RLOC table
                        
                        .. attribute:: vrf_name
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: default
                        
                        	Default VRF
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vrf
                        
                        	VRF name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.LocatorTable, self).__init__()

                            self.yang_name = "locator-table"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.vrf_name = None
                            self.default = None
                            self.vrf = None
                            self._segment_path = lambda: "locator-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.LocatorTable, ['vrf_name', 'default', 'vrf'], name, value)


                    class MapRequest(Entity):
                        """
                        Configure map\-request handling
                        
                        .. attribute:: itr_rlocs
                        
                        	Configure to use the specified RLOC set as ITR RLOC in map\-request
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.MapRequest, self).__init__()

                            self.yang_name = "map-request"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('itr_rlocs', (YLeaf(YType.str, 'itr-rlocs'), ['str'])),
                            ])
                            self.itr_rlocs = None
                            self._segment_path = lambda: "map-request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.MapRequest, ['itr_rlocs'], name, value)


                    class MapServer(Entity):
                        """
                        Map\-Server commands
                        
                        .. attribute:: rloc
                        
                        	EID instance RLOC membership
                        	**type**\:  :py:class:`Rloc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc>`
                        
                        .. attribute:: site_registration
                        
                        	Map\-server site registration options
                        	**type**\:  :py:class:`SiteRegistration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.MapServer.SiteRegistration>`
                        
                        .. attribute:: nmr
                        
                        	Map\-server negative map\-reply optio
                        	**type**\:  :py:class:`Nmr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.MapServer.Nmr>`
                        
                        .. attribute:: session
                        
                        	Map\-server session
                        	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.MapServer.Session>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.MapServer, self).__init__()

                            self.yang_name = "map-server"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rloc", ("rloc", Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc)), ("site-registration", ("site_registration", Native.Router.LispList.EidTable.InstanceList.MapServer.SiteRegistration)), ("nmr", ("nmr", Native.Router.LispList.EidTable.InstanceList.MapServer.Nmr)), ("session", ("session", Native.Router.LispList.EidTable.InstanceList.MapServer.Session))])
                            self._leafs = OrderedDict()

                            self.rloc = Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc()
                            self.rloc.parent = self
                            self._children_name_map["rloc"] = "rloc"

                            self.site_registration = Native.Router.LispList.EidTable.InstanceList.MapServer.SiteRegistration()
                            self.site_registration.parent = self
                            self._children_name_map["site_registration"] = "site-registration"

                            self.nmr = Native.Router.LispList.EidTable.InstanceList.MapServer.Nmr()
                            self.nmr.parent = self
                            self._children_name_map["nmr"] = "nmr"

                            self.session = Native.Router.LispList.EidTable.InstanceList.MapServer.Session()
                            self.session.parent = self
                            self._children_name_map["session"] = "session"
                            self._segment_path = lambda: "map-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.MapServer, [], name, value)


                        class Rloc(Entity):
                            """
                            EID instance RLOC membership
                            
                            .. attribute:: members
                            
                            	EID instance RLOC membership
                            	**type**\:  :py:class:`Members <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc, self).__init__()

                                self.yang_name = "rloc"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("members", ("members", Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members))])
                                self._leafs = OrderedDict()

                                self.members = Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members()
                                self.members.parent = self
                                self._children_name_map["members"] = "members"
                                self._segment_path = lambda: "rloc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc, [], name, value)


                            class Members(Entity):
                                """
                                EID instance RLOC membership
                                
                                .. attribute:: distribute
                                
                                	EID instance RLOC membership distribution
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: modify_discovered
                                
                                	Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                	**type**\:  :py:class:`ModifyDiscovered <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered>`
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members, self).__init__()

                                    self.yang_name = "members"
                                    self.yang_parent_name = "rloc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("modify-discovered", ("modify_discovered", Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered))])
                                    self._leafs = OrderedDict([
                                        ('distribute', (YLeaf(YType.empty, 'distribute'), ['Empty'])),
                                    ])
                                    self.distribute = None

                                    self.modify_discovered = Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered()
                                    self.modify_discovered.parent = self
                                    self._children_name_map["modify_discovered"] = "modify-discovered"
                                    self._segment_path = lambda: "members"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members, ['distribute'], name, value)


                                class ModifyDiscovered(Entity):
                                    """
                                    Modify the EID instance membership that is automaticallydiscovered from ETR registrations
                                    
                                    .. attribute:: operator
                                    
                                    	
                                    	**type**\:  :py:class:`Operator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator>`
                                    
                                    .. attribute:: locator_set
                                    
                                    	Locator set from which to get member RLOC addresses
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-lisp'
                                    _revision = '2018-04-17'

                                    def __init__(self):
                                        super(Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, self).__init__()

                                        self.yang_name = "modify-discovered"
                                        self.yang_parent_name = "members"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('operator', (YLeaf(YType.enumeration, 'operator'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered.Operator')])),
                                            ('locator_set', (YLeaf(YType.str, 'locator-set'), ['str'])),
                                        ])
                                        self.operator = None
                                        self.locator_set = None
                                        self._segment_path = lambda: "modify-discovered"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.MapServer.Rloc.Members.ModifyDiscovered, ['operator', 'locator_set'], name, value)

                                    class Operator(Enum):
                                        """
                                        Operator (Enum Class)

                                        .. data:: add = 0

                                        .. data:: override = 1

                                        """

                                        add = Enum.YLeaf(0, "add")

                                        override = Enum.YLeaf(1, "override")



                        class SiteRegistration(Entity):
                            """
                            Map\-server site registration options
                            
                            .. attribute:: limit
                            
                            	Maximum number of site registrations as a result of accept\-more\-specifics
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: warning_threshold
                            
                            	Warning threshold to issue system logging
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.MapServer.SiteRegistration, self).__init__()

                                self.yang_name = "site-registration"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('limit', (YLeaf(YType.uint32, 'limit'), ['int'])),
                                    ('warning_threshold', (YLeaf(YType.uint8, 'warning-threshold'), ['int'])),
                                ])
                                self.limit = None
                                self.warning_threshold = None
                                self._segment_path = lambda: "site-registration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.MapServer.SiteRegistration, ['limit', 'warning_threshold'], name, value)


                        class Nmr(Entity):
                            """
                            Map\-server negative map\-reply optio
                            
                            .. attribute:: non_site_ttl
                            
                            	Negative map\-reply TTL for non\-site EID
                            	**type**\: int
                            
                            	**range:** 1..1440
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.MapServer.Nmr, self).__init__()

                                self.yang_name = "nmr"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('non_site_ttl', (YLeaf(YType.uint16, 'non-site-ttl'), ['int'])),
                                ])
                                self.non_site_ttl = None
                                self._segment_path = lambda: "nmr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.MapServer.Nmr, ['non_site_ttl'], name, value)


                        class Session(Entity):
                            """
                            Map\-server session
                            
                            .. attribute:: passive_open
                            
                            	Open passive TCP sockets to listen for incoming connections
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.MapServer.Session, self).__init__()

                                self.yang_name = "session"
                                self.yang_parent_name = "map-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('passive_open', (YLeaf(YType.str, 'passive-open'), ['str'])),
                                ])
                                self.passive_open = None
                                self._segment_path = lambda: "session"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.MapServer.Session, ['passive_open'], name, value)


                    class OtherXtrProbe(Entity):
                        """
                        Configure parameters for probing of other xTRs in our site
                        
                        .. attribute:: period
                        
                        	Period between probes in seconds
                        	**type**\: int
                        
                        	**range:** 5..900
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.OtherXtrProbe, self).__init__()

                            self.yang_name = "other-xtr-probe"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                            ])
                            self.period = None
                            self._segment_path = lambda: "other-xtr-probe"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.OtherXtrProbe, ['period'], name, value)


                    class RemoteRlocProbe(Entity):
                        """
                        Configure parameters for probing of remote RLOCs
                        
                        .. attribute:: on_membership_change
                        
                        	Trigger probing upon membership changes for remote RLOC
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: on_route_change
                        
                        	Trigger probing upon routing changes for remote RLOC
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.RemoteRlocProbe, self).__init__()

                            self.yang_name = "remote-rloc-probe"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('on_membership_change', (YLeaf(YType.empty, 'on-membership-change'), ['Empty'])),
                                ('on_route_change', (YLeaf(YType.empty, 'on-route-change'), ['Empty'])),
                            ])
                            self.on_membership_change = None
                            self.on_route_change = None
                            self._segment_path = lambda: "remote-rloc-probe"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.RemoteRlocProbe, ['on_membership_change', 'on_route_change'], name, value)


                    class MapCache(Entity):
                        """
                        Configures static EID\-to\-RLOC mappings for an ITR
                        
                        .. attribute:: eid_prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: etr_interface_ip
                        
                        	
                        	**type**\:  :py:class:`EtrInterfaceIp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.EidTable.InstanceList.MapCache.EtrInterfaceIp>`
                        
                        .. attribute:: drop
                        
                        	Drop packets that match this map\-cache entry
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: map_request
                        
                        	Send Map\-Request for LISP destination EID
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: native_forward
                        
                        	Natively forward packets that match this map\-cache entry
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.EidTable.InstanceList.MapCache, self).__init__()

                            self.yang_name = "map-cache"
                            self.yang_parent_name = "instance-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['eid_prefix']
                            self._child_classes = OrderedDict([("etr-interface-ip", ("etr_interface_ip", Native.Router.LispList.EidTable.InstanceList.MapCache.EtrInterfaceIp))])
                            self._leafs = OrderedDict([
                                ('eid_prefix', (YLeaf(YType.str, 'eid-prefix'), ['str','str'])),
                                ('drop', (YLeaf(YType.empty, 'drop'), ['Empty'])),
                                ('map_request', (YLeaf(YType.empty, 'map-request'), ['Empty'])),
                                ('native_forward', (YLeaf(YType.empty, 'native-forward'), ['Empty'])),
                            ])
                            self.eid_prefix = None
                            self.drop = None
                            self.map_request = None
                            self.native_forward = None

                            self.etr_interface_ip = Native.Router.LispList.EidTable.InstanceList.MapCache.EtrInterfaceIp()
                            self.etr_interface_ip.parent = self
                            self._children_name_map["etr_interface_ip"] = "etr-interface-ip"
                            self._segment_path = lambda: "map-cache" + "[eid-prefix='" + str(self.eid_prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.MapCache, ['eid_prefix', 'drop', 'map_request', 'native_forward'], name, value)


                        class EtrInterfaceIp(Entity):
                            """
                            
                            
                            .. attribute:: etr_interface_ip_address
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: priority
                            
                            	Configures which Locators from a set are preferred
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: weight
                            
                            	Traffic load\-spreading among Locators
                            	**type**\: int
                            
                            	**range:** 0..100
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.EidTable.InstanceList.MapCache.EtrInterfaceIp, self).__init__()

                                self.yang_name = "etr-interface-ip"
                                self.yang_parent_name = "map-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('etr_interface_ip_address', (YLeaf(YType.str, 'etr-interface-ip-address'), ['str','str'])),
                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                ])
                                self.etr_interface_ip_address = None
                                self.priority = None
                                self.weight = None
                                self._segment_path = lambda: "etr-interface-ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.EidTable.InstanceList.MapCache.EtrInterfaceIp, ['etr_interface_ip_address', 'priority', 'weight'], name, value)


            class Security(Entity):
                """
                Enable default LISP security and authentication in reply is optional
                
                .. attribute:: strong
                
                	Enable default LISP security and authentication in reply is required
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Security, self).__init__()

                    self.yang_name = "security"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('strong', (YLeaf(YType.empty, 'strong'), ['Empty'])),
                    ])
                    self.strong = None
                    self._segment_path = lambda: "security"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Security, ['strong'], name, value)


            class Site(Entity):
                """
                Configure a LISP site on a map server (MS)
                
                .. attribute:: sname  (key)
                
                	The site name
                	**type**\: str
                
                .. attribute:: default
                
                	
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default>`
                
                .. attribute:: authentication_key
                
                	Authentication key used by LISP site
                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.AuthenticationKey>`
                
                .. attribute:: description
                
                	Site description
                	**type**\: str
                
                .. attribute:: allowed_locator
                
                	Locator from LISP site
                	**type**\:  :py:class:`AllowedLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.AllowedLocator>`
                
                .. attribute:: eid_prefix
                
                	Site EID address prefix
                	**type**\:  :py:class:`EidPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.EidPrefix>`
                
                .. attribute:: eid_record
                
                	Site EID address prefix
                	**type**\:  :py:class:`EidRecord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.EidRecord>`
                
                .. attribute:: site_id
                
                	Configure a site\-id for this site
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Site, self).__init__()

                    self.yang_name = "site"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['sname']
                    self._child_classes = OrderedDict([("default", ("default", Native.Router.LispList.Site.Default)), ("authentication-key", ("authentication_key", Native.Router.LispList.Site.AuthenticationKey)), ("allowed-locator", ("allowed_locator", Native.Router.LispList.Site.AllowedLocator)), ("eid-prefix", ("eid_prefix", Native.Router.LispList.Site.EidPrefix)), ("eid-record", ("eid_record", Native.Router.LispList.Site.EidRecord))])
                    self._leafs = OrderedDict([
                        ('sname', (YLeaf(YType.str, 'sname'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                    ])
                    self.sname = None
                    self.description = None
                    self.site_id = None

                    self.default = Native.Router.LispList.Site.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.authentication_key = Native.Router.LispList.Site.AuthenticationKey()
                    self.authentication_key.parent = self
                    self._children_name_map["authentication_key"] = "authentication-key"

                    self.allowed_locator = Native.Router.LispList.Site.AllowedLocator()
                    self.allowed_locator.parent = self
                    self._children_name_map["allowed_locator"] = "allowed-locator"

                    self.eid_prefix = Native.Router.LispList.Site.EidPrefix()
                    self.eid_prefix.parent = self
                    self._children_name_map["eid_prefix"] = "eid-prefix"

                    self.eid_record = Native.Router.LispList.Site.EidRecord()
                    self.eid_record.parent = self
                    self._children_name_map["eid_record"] = "eid-record"
                    self._segment_path = lambda: "site" + "[sname='" + str(self.sname) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Site, ['sname', 'description', 'site_id'], name, value)


                class Default(Entity):
                    """
                    
                    
                    .. attribute:: authentication_key
                    
                    	Authentication key used by LISP site
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default.AuthenticationKey>`
                    
                    .. attribute:: description
                    
                    	Site description
                    	**type**\: str
                    
                    .. attribute:: allowed_locator
                    
                    	Locator from LISP site
                    	**type**\:  :py:class:`AllowedLocator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default.AllowedLocator>`
                    
                    .. attribute:: eid_prefix
                    
                    	Site EID address prefix
                    	**type**\:  :py:class:`EidPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default.EidPrefix>`
                    
                    .. attribute:: eid_record
                    
                    	Site EID address prefix
                    	**type**\:  :py:class:`EidRecord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default.EidRecord>`
                    
                    .. attribute:: site_id
                    
                    	Configure a site\-id for this site
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Site.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.LispList.Site.Default.AuthenticationKey)), ("allowed-locator", ("allowed_locator", Native.Router.LispList.Site.Default.AllowedLocator)), ("eid-prefix", ("eid_prefix", Native.Router.LispList.Site.Default.EidPrefix)), ("eid-record", ("eid_record", Native.Router.LispList.Site.Default.EidRecord))])
                        self._leafs = OrderedDict([
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('site_id', (YLeaf(YType.uint32, 'site-id'), ['int'])),
                        ])
                        self.description = None
                        self.site_id = None

                        self.authentication_key = Native.Router.LispList.Site.Default.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.allowed_locator = Native.Router.LispList.Site.Default.AllowedLocator()
                        self.allowed_locator.parent = self
                        self._children_name_map["allowed_locator"] = "allowed-locator"

                        self.eid_prefix = Native.Router.LispList.Site.Default.EidPrefix()
                        self.eid_prefix.parent = self
                        self._children_name_map["eid_prefix"] = "eid-prefix"

                        self.eid_record = Native.Router.LispList.Site.Default.EidRecord()
                        self.eid_record.parent = self
                        self._children_name_map["eid_record"] = "eid-record"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Site.Default, ['description', 'site_id'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Authentication key used by LISP site
                        
                        .. attribute:: unc_pwd
                        
                        	The UNENCRYPTED (cleartext) password
                        	**type**\: str
                        
                        .. attribute:: key_0
                        
                        	The UNENCRYPTED (cleartext) password
                        	**type**\: str
                        
                        .. attribute:: key_6
                        
                        	The ENCRYPTED password
                        	**type**\: str
                        
                        .. attribute:: key_7
                        
                        	The ENCRYPTED password
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Site.Default.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                                ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                                ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                                ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                            ])
                            self.unc_pwd = None
                            self.key_0 = None
                            self.key_6 = None
                            self.key_7 = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Site.Default.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                    class AllowedLocator(Entity):
                        """
                        Locator from LISP site
                        
                        .. attribute:: ls_ipv4
                        
                        	IPv4 locator allowed in registered locator\-set
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ls_ipv6
                        
                        	IPv6 locator allowed in registered locator\-set
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: list
                        
                        	Prefixes allowed in registerd locator\-set
                        	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default.AllowedLocator.List>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Site.Default.AllowedLocator, self).__init__()

                            self.yang_name = "allowed-locator"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Site.Default.AllowedLocator.List))])
                            self._leafs = OrderedDict([
                                ('ls_ipv4', (YLeaf(YType.str, 'ls-ipv4'), ['str'])),
                                ('ls_ipv6', (YLeaf(YType.str, 'ls-ipv6'), ['str'])),
                            ])
                            self.ls_ipv4 = None
                            self.ls_ipv6 = None

                            self.list = Native.Router.LispList.Site.Default.AllowedLocator.List()
                            self.list.parent = self
                            self._children_name_map["list"] = "list"
                            self._segment_path = lambda: "allowed-locator"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Site.Default.AllowedLocator, ['ls_ipv4', 'ls_ipv6'], name, value)


                        class List(Entity):
                            """
                            Prefixes allowed in registerd locator\-set
                            
                            .. attribute:: ipv4
                            
                            	IPv4 prefix\-list name
                            	**type**\: str
                            
                            .. attribute:: ipv6
                            
                            	IPv6 prefix\-list name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Site.Default.AllowedLocator.List, self).__init__()

                                self.yang_name = "list"
                                self.yang_parent_name = "allowed-locator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "list"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Site.Default.AllowedLocator.List, ['ipv4', 'ipv6'], name, value)


                    class EidPrefix(Entity):
                        """
                        Site EID address prefix
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default.EidPrefix.Prefixes>`
                        
                        .. attribute:: instance_id
                        
                        	EID instance\-ID
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default.EidPrefix.InstanceId>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Site.Default.EidPrefix, self).__init__()

                            self.yang_name = "eid-prefix"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Site.Default.EidPrefix.Prefixes)), ("instance-id", ("instance_id", Native.Router.LispList.Site.Default.EidPrefix.InstanceId))])
                            self._leafs = OrderedDict([
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self.instance_id = YList(self)
                            self._segment_path = lambda: "eid-prefix"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Site.Default.EidPrefix, ['any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Site.Default.EidPrefix.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "eid-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Site.Default.EidPrefix.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                        class InstanceId(Entity):
                            """
                            EID instance\-ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default.EidPrefix.InstanceId.Prefixes>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Site.Default.EidPrefix.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "eid-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Site.Default.EidPrefix.InstanceId.Prefixes))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.id = None
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Site.Default.EidPrefix.InstanceId, ['id', 'any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Site.Default.EidPrefix.InstanceId.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "instance-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Site.Default.EidPrefix.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                    class EidRecord(Entity):
                        """
                        Site EID address prefix
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default.EidRecord.Prefixes>`
                        
                        .. attribute:: instance_id
                        
                        	EID instance\-ID
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default.EidRecord.InstanceId>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Site.Default.EidRecord, self).__init__()

                            self.yang_name = "eid-record"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Site.Default.EidRecord.Prefixes)), ("instance-id", ("instance_id", Native.Router.LispList.Site.Default.EidRecord.InstanceId))])
                            self._leafs = OrderedDict([
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self.instance_id = YList(self)
                            self._segment_path = lambda: "eid-record"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Site.Default.EidRecord, ['any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Site.Default.EidRecord.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "eid-record"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Site.Default.EidRecord.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                        class InstanceId(Entity):
                            """
                            EID instance\-ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..16777214
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.Default.EidRecord.InstanceId.Prefixes>`
                            
                            .. attribute:: any_mac
                            
                            	Accept registrations for any L2 EID records
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Site.Default.EidRecord.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "eid-record"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Site.Default.EidRecord.InstanceId.Prefixes))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                                ])
                                self.id = None
                                self.any_mac = None

                                self.prefixes = YList(self)
                                self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Site.Default.EidRecord.InstanceId, ['id', 'any_mac'], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: prefix  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: accept_more_specifics
                                
                                	Accept registrations for more specific EID prefixes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_tag
                                
                                	RIB route tag
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-lisp'
                                _revision = '2018-04-17'

                                def __init__(self):
                                    super(Native.Router.LispList.Site.Default.EidRecord.InstanceId.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "instance-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                        ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.accept_more_specifics = None
                                    self.route_tag = None
                                    self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.LispList.Site.Default.EidRecord.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                class AuthenticationKey(Entity):
                    """
                    Authentication key used by LISP site
                    
                    .. attribute:: unc_pwd
                    
                    	The UNENCRYPTED (cleartext) password
                    	**type**\: str
                    
                    .. attribute:: key_0
                    
                    	The UNENCRYPTED (cleartext) password
                    	**type**\: str
                    
                    .. attribute:: key_6
                    
                    	The ENCRYPTED password
                    	**type**\: str
                    
                    .. attribute:: key_7
                    
                    	The ENCRYPTED password
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Site.AuthenticationKey, self).__init__()

                        self.yang_name = "authentication-key"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unc_pwd', (YLeaf(YType.str, 'unc-pwd'), ['str'])),
                            ('key_0', (YLeaf(YType.str, 'key-0'), ['str'])),
                            ('key_6', (YLeaf(YType.str, 'key-6'), ['str'])),
                            ('key_7', (YLeaf(YType.str, 'key-7'), ['str'])),
                        ])
                        self.unc_pwd = None
                        self.key_0 = None
                        self.key_6 = None
                        self.key_7 = None
                        self._segment_path = lambda: "authentication-key"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Site.AuthenticationKey, ['unc_pwd', 'key_0', 'key_6', 'key_7'], name, value)


                class AllowedLocator(Entity):
                    """
                    Locator from LISP site
                    
                    .. attribute:: ls_ipv4
                    
                    	IPv4 locator allowed in registered locator\-set
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ls_ipv6
                    
                    	IPv6 locator allowed in registered locator\-set
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: list
                    
                    	Prefixes allowed in registerd locator\-set
                    	**type**\:  :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.AllowedLocator.List>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Site.AllowedLocator, self).__init__()

                        self.yang_name = "allowed-locator"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("list", ("list", Native.Router.LispList.Site.AllowedLocator.List))])
                        self._leafs = OrderedDict([
                            ('ls_ipv4', (YLeaf(YType.str, 'ls-ipv4'), ['str'])),
                            ('ls_ipv6', (YLeaf(YType.str, 'ls-ipv6'), ['str'])),
                        ])
                        self.ls_ipv4 = None
                        self.ls_ipv6 = None

                        self.list = Native.Router.LispList.Site.AllowedLocator.List()
                        self.list.parent = self
                        self._children_name_map["list"] = "list"
                        self._segment_path = lambda: "allowed-locator"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Site.AllowedLocator, ['ls_ipv4', 'ls_ipv6'], name, value)


                    class List(Entity):
                        """
                        Prefixes allowed in registerd locator\-set
                        
                        .. attribute:: ipv4
                        
                        	IPv4 prefix\-list name
                        	**type**\: str
                        
                        .. attribute:: ipv6
                        
                        	IPv6 prefix\-list name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Site.AllowedLocator.List, self).__init__()

                            self.yang_name = "list"
                            self.yang_parent_name = "allowed-locator"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                            ])
                            self.ipv4 = None
                            self.ipv6 = None
                            self._segment_path = lambda: "list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Site.AllowedLocator.List, ['ipv4', 'ipv6'], name, value)


                class EidPrefix(Entity):
                    """
                    Site EID address prefix
                    
                    .. attribute:: prefixes
                    
                    	
                    	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.EidPrefix.Prefixes>`
                    
                    .. attribute:: instance_id
                    
                    	EID instance\-ID
                    	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.EidPrefix.InstanceId>`
                    
                    .. attribute:: any_mac
                    
                    	Accept registrations for any L2 EID records
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Site.EidPrefix, self).__init__()

                        self.yang_name = "eid-prefix"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Site.EidPrefix.Prefixes)), ("instance-id", ("instance_id", Native.Router.LispList.Site.EidPrefix.InstanceId))])
                        self._leafs = OrderedDict([
                            ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                        ])
                        self.any_mac = None

                        self.prefixes = YList(self)
                        self.instance_id = YList(self)
                        self._segment_path = lambda: "eid-prefix"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Site.EidPrefix, ['any_mac'], name, value)


                    class Prefixes(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: accept_more_specifics
                        
                        	Accept registrations for more specific EID prefixes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_tag
                        
                        	RIB route tag
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Site.EidPrefix.Prefixes, self).__init__()

                            self.yang_name = "prefixes"
                            self.yang_parent_name = "eid-prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                            ])
                            self.prefix = None
                            self.accept_more_specifics = None
                            self.route_tag = None
                            self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Site.EidPrefix.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                    class InstanceId(Entity):
                        """
                        EID instance\-ID
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.EidPrefix.InstanceId.Prefixes>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Site.EidPrefix.InstanceId, self).__init__()

                            self.yang_name = "instance-id"
                            self.yang_parent_name = "eid-prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Site.EidPrefix.InstanceId.Prefixes))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.id = None
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Site.EidPrefix.InstanceId, ['id', 'any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Site.EidPrefix.InstanceId.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "instance-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Site.EidPrefix.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                class EidRecord(Entity):
                    """
                    Site EID address prefix
                    
                    .. attribute:: prefixes
                    
                    	
                    	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.EidRecord.Prefixes>`
                    
                    .. attribute:: instance_id
                    
                    	EID instance\-ID
                    	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.EidRecord.InstanceId>`
                    
                    .. attribute:: any_mac
                    
                    	Accept registrations for any L2 EID records
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Site.EidRecord, self).__init__()

                        self.yang_name = "eid-record"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Site.EidRecord.Prefixes)), ("instance-id", ("instance_id", Native.Router.LispList.Site.EidRecord.InstanceId))])
                        self._leafs = OrderedDict([
                            ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                        ])
                        self.any_mac = None

                        self.prefixes = YList(self)
                        self.instance_id = YList(self)
                        self._segment_path = lambda: "eid-record"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Site.EidRecord, ['any_mac'], name, value)


                    class Prefixes(Entity):
                        """
                        
                        
                        .. attribute:: prefix  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: accept_more_specifics
                        
                        	Accept registrations for more specific EID prefixes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: route_tag
                        
                        	RIB route tag
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Site.EidRecord.Prefixes, self).__init__()

                            self.yang_name = "prefixes"
                            self.yang_parent_name = "eid-record"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                            ])
                            self.prefix = None
                            self.accept_more_specifics = None
                            self.route_tag = None
                            self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Site.EidRecord.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


                    class InstanceId(Entity):
                        """
                        EID instance\-ID
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Site.EidRecord.InstanceId.Prefixes>`
                        
                        .. attribute:: any_mac
                        
                        	Accept registrations for any L2 EID records
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-lisp'
                        _revision = '2018-04-17'

                        def __init__(self):
                            super(Native.Router.LispList.Site.EidRecord.InstanceId, self).__init__()

                            self.yang_name = "instance-id"
                            self.yang_parent_name = "eid-record"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.Router.LispList.Site.EidRecord.InstanceId.Prefixes))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ('any_mac', (YLeaf(YType.empty, 'any-mac'), ['Empty'])),
                            ])
                            self.id = None
                            self.any_mac = None

                            self.prefixes = YList(self)
                            self._segment_path = lambda: "instance-id" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.LispList.Site.EidRecord.InstanceId, ['id', 'any_mac'], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: accept_more_specifics
                            
                            	Accept registrations for more specific EID prefixes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_tag
                            
                            	RIB route tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ios-lisp'
                            _revision = '2018-04-17'

                            def __init__(self):
                                super(Native.Router.LispList.Site.EidRecord.InstanceId.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "instance-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('accept_more_specifics', (YLeaf(YType.empty, 'accept-more-specifics'), ['Empty'])),
                                    ('route_tag', (YLeaf(YType.uint32, 'route-tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.accept_more_specifics = None
                                self.route_tag = None
                                self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.LispList.Site.EidRecord.InstanceId.Prefixes, ['prefix', 'accept_more_specifics', 'route_tag'], name, value)


            class Syslog(Entity):
                """
                Configure syslog option
                
                .. attribute:: session
                
                	Enable session syslog
                	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.LispList.Syslog.Session>`
                
                .. attribute:: verbose
                
                	Enable verbose syslog
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-lisp'
                _revision = '2018-04-17'

                def __init__(self):
                    super(Native.Router.LispList.Syslog, self).__init__()

                    self.yang_name = "syslog"
                    self.yang_parent_name = "lisp-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("session", ("session", Native.Router.LispList.Syslog.Session))])
                    self._leafs = OrderedDict([
                        ('verbose', (YLeaf(YType.empty, 'verbose'), ['Empty'])),
                    ])
                    self.verbose = None

                    self.session = Native.Router.LispList.Syslog.Session()
                    self.session.parent = self
                    self._children_name_map["session"] = "session"
                    self._segment_path = lambda: "syslog"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.LispList.Syslog, ['verbose'], name, value)


                class Session(Entity):
                    """
                    Enable session syslog
                    
                    .. attribute:: changes
                    
                    	Enable session change syslog
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-lisp'
                    _revision = '2018-04-17'

                    def __init__(self):
                        super(Native.Router.LispList.Syslog.Session, self).__init__()

                        self.yang_name = "session"
                        self.yang_parent_name = "syslog"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('changes', (YLeaf(YType.empty, 'changes'), ['Empty'])),
                        ])
                        self.changes = None
                        self._segment_path = lambda: "session"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.LispList.Syslog.Session, ['changes'], name, value)


        class Ospfv3(Entity):
            """
            OSPFv3
            
            .. attribute:: id  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: area
            
            	OSPF area parameters
            	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area>`
            
            .. attribute:: auto_cost
            
            	Calculate OSPF interface cost according to bandwidth
            	**type**\:  :py:class:`AutoCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AutoCost>`
            
            	**presence node**\: True
            
            .. attribute:: event_log
            
            	OSPF Event Logging
            	**type**\:  :py:class:`EventLog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.EventLog>`
            
            	**presence node**\: True
            
            .. attribute:: bfd
            
            	BFD configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Bfd>`
            
            .. attribute:: interface_id
            
            	Source of the interface ID
            	**type**\:  :py:class:`InterfaceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.InterfaceId>`
            
            .. attribute:: log_adjacency_changes
            
            	Log changes in adjacency state
            	**type**\:  :py:class:`LogAdjacencyChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.LogAdjacencyChanges>`
            
            	**presence node**\: True
            
            .. attribute:: max_lsa
            
            	maximum number of LSAs OSPF process will receive
            	**type**\:  :py:class:`MaxLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.MaxLsa>`
            
            .. attribute:: max_metric
            
            	Set maximum metric
            	**type**\:  :py:class:`MaxMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.MaxMetric>`
            
            .. attribute:: passive_interface
            
            	Suppress routing updates on an interface
            	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.PassiveInterface>`
            
            .. attribute:: disable
            
            	
            	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Disable>`
            
            .. attribute:: queue_depth
            
            	OSPF Hello/Router process queue depth
            	**type**\:  :py:class:`QueueDepth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.QueueDepth>`
            
            .. attribute:: timers
            
            	Adjust routing timers
            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Timers>`
            
            .. attribute:: router_id
            
            	Override configured router identifier (peers will reset)
            	**type**\: str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: nsr
            
            	Enable non\-stop routing
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: traffic_share
            
            	How to compute traffic share over alternate paths
            	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.TrafficShare>`
            
            .. attribute:: ttl_security
            
            	TTL security check
            	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.TtlSecurity>`
            
            .. attribute:: authentication
            
            	Authentication parameters
            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Authentication>`
            
            .. attribute:: graceful_restart
            
            	Graceful\-restart options
            	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.GracefulRestart>`
            
            	**presence node**\: True
            
            .. attribute:: manet
            
            	Specify MANET OSPF parameters
            	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Manet>`
            
            .. attribute:: address_family
            
            	Enter Address Family command mode
            	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily>`
            
            

            """

            _prefix = 'ios-ospfv3'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Router.Ospfv3, self).__init__()

                self.yang_name = "ospfv3"
                self.yang_parent_name = "router"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("area", ("area", Native.Router.Ospfv3.Area)), ("auto-cost", ("auto_cost", Native.Router.Ospfv3.AutoCost)), ("event-log", ("event_log", Native.Router.Ospfv3.EventLog)), ("bfd", ("bfd", Native.Router.Ospfv3.Bfd)), ("interface-id", ("interface_id", Native.Router.Ospfv3.InterfaceId)), ("log-adjacency-changes", ("log_adjacency_changes", Native.Router.Ospfv3.LogAdjacencyChanges)), ("max-lsa", ("max_lsa", Native.Router.Ospfv3.MaxLsa)), ("max-metric", ("max_metric", Native.Router.Ospfv3.MaxMetric)), ("passive-interface", ("passive_interface", Native.Router.Ospfv3.PassiveInterface)), ("disable", ("disable", Native.Router.Ospfv3.Disable)), ("queue-depth", ("queue_depth", Native.Router.Ospfv3.QueueDepth)), ("timers", ("timers", Native.Router.Ospfv3.Timers)), ("traffic-share", ("traffic_share", Native.Router.Ospfv3.TrafficShare)), ("ttl-security", ("ttl_security", Native.Router.Ospfv3.TtlSecurity)), ("authentication", ("authentication", Native.Router.Ospfv3.Authentication)), ("graceful-restart", ("graceful_restart", Native.Router.Ospfv3.GracefulRestart)), ("manet", ("manet", Native.Router.Ospfv3.Manet)), ("address-family", ("address_family", Native.Router.Ospfv3.AddressFamily))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                    ('nsr', (YLeaf(YType.empty, 'nsr'), ['Empty'])),
                ])
                self.id = None
                self.router_id = None
                self.nsr = None

                self.auto_cost = None
                self._children_name_map["auto_cost"] = "auto-cost"

                self.event_log = None
                self._children_name_map["event_log"] = "event-log"

                self.bfd = Native.Router.Ospfv3.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.interface_id = Native.Router.Ospfv3.InterfaceId()
                self.interface_id.parent = self
                self._children_name_map["interface_id"] = "interface-id"

                self.log_adjacency_changes = None
                self._children_name_map["log_adjacency_changes"] = "log-adjacency-changes"

                self.max_lsa = Native.Router.Ospfv3.MaxLsa()
                self.max_lsa.parent = self
                self._children_name_map["max_lsa"] = "max-lsa"

                self.max_metric = Native.Router.Ospfv3.MaxMetric()
                self.max_metric.parent = self
                self._children_name_map["max_metric"] = "max-metric"

                self.passive_interface = Native.Router.Ospfv3.PassiveInterface()
                self.passive_interface.parent = self
                self._children_name_map["passive_interface"] = "passive-interface"

                self.disable = Native.Router.Ospfv3.Disable()
                self.disable.parent = self
                self._children_name_map["disable"] = "disable"

                self.queue_depth = Native.Router.Ospfv3.QueueDepth()
                self.queue_depth.parent = self
                self._children_name_map["queue_depth"] = "queue-depth"

                self.timers = Native.Router.Ospfv3.Timers()
                self.timers.parent = self
                self._children_name_map["timers"] = "timers"

                self.traffic_share = Native.Router.Ospfv3.TrafficShare()
                self.traffic_share.parent = self
                self._children_name_map["traffic_share"] = "traffic-share"

                self.ttl_security = Native.Router.Ospfv3.TtlSecurity()
                self.ttl_security.parent = self
                self._children_name_map["ttl_security"] = "ttl-security"

                self.authentication = Native.Router.Ospfv3.Authentication()
                self.authentication.parent = self
                self._children_name_map["authentication"] = "authentication"

                self.graceful_restart = None
                self._children_name_map["graceful_restart"] = "graceful-restart"

                self.manet = Native.Router.Ospfv3.Manet()
                self.manet.parent = self
                self._children_name_map["manet"] = "manet"

                self.address_family = Native.Router.Ospfv3.AddressFamily()
                self.address_family.parent = self
                self._children_name_map["address_family"] = "address-family"

                self.area = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-ospfv3:ospfv3" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Router.Ospfv3, [u'id', 'router_id', 'nsr'], name, value)


            class Area(Entity):
                """
                OSPF area parameters
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..4294967295
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: authentication
                
                	Enable authentication
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Authentication>`
                
                	**presence node**\: True
                
                .. attribute:: capability
                
                	Enable area specific capability
                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Capability>`
                
                .. attribute:: default_cost
                
                	Set the summary default\-cost of a NSSA/stub area
                	**type**\: int
                
                	**range:** 0..16777215
                
                .. attribute:: filter_list
                
                	Filter networks between OSPF areas
                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.FilterList>`
                
                .. attribute:: nssa
                
                	Specify a NSSA area
                	**type**\:  :py:class:`Nssa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Nssa>`
                
                	**presence node**\: True
                
                .. attribute:: ipv4_range
                
                	
                	**type**\:  :py:class:`Ipv4Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Ipv4Range>`
                
                .. attribute:: ipv6_range
                
                	
                	**type**\:  :py:class:`Ipv6Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Ipv6Range>`
                
                .. attribute:: sham_link
                
                	Define a sham link and its parameters
                	**type**\: list of  		 :py:class:`ShamLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.ShamLink>`
                
                .. attribute:: stub
                
                	Specify a stub area
                	**type**\:  :py:class:`Stub <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Stub>`
                
                	**presence node**\: True
                
                .. attribute:: virtual_link
                
                	Define a virtual link and its parameters
                	**type**\: list of  		 :py:class:`VirtualLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink>`
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.Area, self).__init__()

                    self.yang_name = "area"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospfv3.Area.Authentication)), ("capability", ("capability", Native.Router.Ospfv3.Area.Capability)), ("filter-list", ("filter_list", Native.Router.Ospfv3.Area.FilterList)), ("nssa", ("nssa", Native.Router.Ospfv3.Area.Nssa)), ("ipv4-range", ("ipv4_range", Native.Router.Ospfv3.Area.Ipv4Range)), ("ipv6-range", ("ipv6_range", Native.Router.Ospfv3.Area.Ipv6Range)), ("sham-link", ("sham_link", Native.Router.Ospfv3.Area.ShamLink)), ("stub", ("stub", Native.Router.Ospfv3.Area.Stub)), ("virtual-link", ("virtual_link", Native.Router.Ospfv3.Area.VirtualLink))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                        ('default_cost', (YLeaf(YType.uint32, 'default-cost'), ['int'])),
                    ])
                    self.id = None
                    self.default_cost = None

                    self.authentication = None
                    self._children_name_map["authentication"] = "authentication"

                    self.capability = Native.Router.Ospfv3.Area.Capability()
                    self.capability.parent = self
                    self._children_name_map["capability"] = "capability"

                    self.nssa = None
                    self._children_name_map["nssa"] = "nssa"

                    self.ipv4_range = Native.Router.Ospfv3.Area.Ipv4Range()
                    self.ipv4_range.parent = self
                    self._children_name_map["ipv4_range"] = "ipv4-range"

                    self.ipv6_range = Native.Router.Ospfv3.Area.Ipv6Range()
                    self.ipv6_range.parent = self
                    self._children_name_map["ipv6_range"] = "ipv6-range"

                    self.stub = None
                    self._children_name_map["stub"] = "stub"

                    self.filter_list = YList(self)
                    self.sham_link = YList(self)
                    self.virtual_link = YList(self)
                    self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.Area, ['id', 'default_cost'], name, value)


                class Authentication(Entity):
                    """
                    Enable authentication
                    
                    .. attribute:: message_digest
                    
                    	Use message\-digest authentication
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Area.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                        ])
                        self.message_digest = None
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Area.Authentication, ['message_digest'], name, value)


                class Capability(Entity):
                    """
                    Enable area specific capability
                    
                    .. attribute:: default_exclusion
                    
                    	Enable exclusion of links from base topology
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Area.Capability, self).__init__()

                        self.yang_name = "capability"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default_exclusion', (YLeaf(YType.empty, 'default-exclusion'), ['Empty'])),
                        ])
                        self.default_exclusion = None
                        self._segment_path = lambda: "capability"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Area.Capability, ['default_exclusion'], name, value)


                class FilterList(Entity):
                    """
                    Filter networks between OSPF areas
                    
                    .. attribute:: in_out  (key)
                    
                    	
                    	**type**\:  :py:class:`InOut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.FilterList.InOut>`
                    
                    .. attribute:: prefix
                    
                    	Filter prefixes between OSPF areas
                    	**type**\: str
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Area.FilterList, self).__init__()

                        self.yang_name = "filter-list"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['in_out']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.Area.FilterList.InOut')])),
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                        ])
                        self.in_out = None
                        self.prefix = None
                        self._segment_path = lambda: "filter-list" + "[in-out='" + str(self.in_out) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Area.FilterList, ['in_out', 'prefix'], name, value)

                    class InOut(Enum):
                        """
                        InOut (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



                class Nssa(Entity):
                    """
                    Specify a NSSA area
                    
                    .. attribute:: default_information_originate
                    
                    	Originate Type 7 default into NSSA area
                    	**type**\:  :py:class:`DefaultInformationOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: no_ext_capability
                    
                    	Do not send domain specific capabilities into NSSA
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: no_redistribution
                    
                    	No redistribution into this NSSA area
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: no_summary
                    
                    	Do not send summary LSA into NSSA
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nssa_only
                    
                    	Limit default advertisement to this NSSA area
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: translate
                    
                    	Translate LSA
                    	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Nssa.Translate>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Area.Nssa, self).__init__()

                        self.yang_name = "nssa"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("default-information-originate", ("default_information_originate", Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate)), ("translate", ("translate", Native.Router.Ospfv3.Area.Nssa.Translate))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                            ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                            ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                        ])
                        self.no_ext_capability = None
                        self.no_redistribution = None
                        self.no_summary = None
                        self.nssa_only = None

                        self.default_information_originate = None
                        self._children_name_map["default_information_originate"] = "default-information-originate"

                        self.translate = Native.Router.Ospfv3.Area.Nssa.Translate()
                        self.translate.parent = self
                        self._children_name_map["translate"] = "translate"
                        self._segment_path = lambda: "nssa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Area.Nssa, ['no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                    class DefaultInformationOriginate(Entity):
                        """
                        Originate Type 7 default into NSSA area
                        
                        .. attribute:: metric
                        
                        	OSPF default metric
                        	**type**\: int
                        
                        	**range:** 0..16777214
                        
                        .. attribute:: metric_type
                        
                        	OSPF metric type for default routes
                        	**type**\: int
                        
                        	**range:** 1..2
                        
                        .. attribute:: no_ext_capability
                        
                        	Do not send domain specific capabilities into NSSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: no_redistribution
                        
                        	No redistribution into this NSSA area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: no_summary
                        
                        	Do not send summary LSA into NSSA
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: nssa_only
                        
                        	Limit default advertisement to this NSSA area
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: translate
                        
                        	Translate LSA
                        	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate.Translate>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate, self).__init__()

                            self.yang_name = "default-information-originate"
                            self.yang_parent_name = "nssa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("translate", ("translate", Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate.Translate))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.int32, 'metric'), ['int'])),
                                ('metric_type', (YLeaf(YType.uint32, 'metric-type'), ['int'])),
                                ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                                ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                            ])
                            self.metric = None
                            self.metric_type = None
                            self.no_ext_capability = None
                            self.no_redistribution = None
                            self.no_summary = None
                            self.nssa_only = None

                            self.translate = Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate.Translate()
                            self.translate.parent = self
                            self._children_name_map["translate"] = "translate"
                            self._segment_path = lambda: "default-information-originate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate, ['metric', 'metric_type', 'no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                        class Translate(Entity):
                            """
                            Translate LSA
                            
                            .. attribute:: type7
                            
                            	From Type 7 to Type 5
                            	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate.Translate.Type7>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate.Translate, self).__init__()

                                self.yang_name = "translate"
                                self.yang_parent_name = "default-information-originate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate.Translate.Type7))])
                                self._leafs = OrderedDict()

                                self.type7 = Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate.Translate.Type7()
                                self.type7.parent = self
                                self._children_name_map["type7"] = "type7"
                                self._segment_path = lambda: "translate"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate.Translate, [], name, value)


                            class Type7(Entity):
                                """
                                From Type 7 to Type 5
                                
                                .. attribute:: always
                                
                                	Always translate LSAs on this ABR
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: suppress_fa
                                
                                	Suppress forwarding address in translated LSAs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate.Translate.Type7, self).__init__()

                                    self.yang_name = "type7"
                                    self.yang_parent_name = "translate"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                        ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                    ])
                                    self.always = None
                                    self.suppress_fa = None
                                    self._segment_path = lambda: "type7"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.Area.Nssa.DefaultInformationOriginate.Translate.Type7, ['always', 'suppress_fa'], name, value)


                    class Translate(Entity):
                        """
                        Translate LSA
                        
                        .. attribute:: type7
                        
                        	From Type 7 to Type 5
                        	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Nssa.Translate.Type7>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.Nssa.Translate, self).__init__()

                            self.yang_name = "translate"
                            self.yang_parent_name = "nssa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospfv3.Area.Nssa.Translate.Type7))])
                            self._leafs = OrderedDict()

                            self.type7 = Native.Router.Ospfv3.Area.Nssa.Translate.Type7()
                            self.type7.parent = self
                            self._children_name_map["type7"] = "type7"
                            self._segment_path = lambda: "translate"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.Nssa.Translate, [], name, value)


                        class Type7(Entity):
                            """
                            From Type 7 to Type 5
                            
                            .. attribute:: always
                            
                            	Always translate LSAs on this ABR
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: suppress_fa
                            
                            	Suppress forwarding address in translated LSAs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.Area.Nssa.Translate.Type7, self).__init__()

                                self.yang_name = "type7"
                                self.yang_parent_name = "translate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                    ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                ])
                                self.always = None
                                self.suppress_fa = None
                                self._segment_path = lambda: "type7"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.Area.Nssa.Translate.Type7, ['always', 'suppress_fa'], name, value)


                class Ipv4Range(Entity):
                    """
                    
                    
                    .. attribute:: range
                    
                    	Summarize routes matching address/mask (border routers only)
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Ipv4Range.Range>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Area.Ipv4Range, self).__init__()

                        self.yang_name = "ipv4-range"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospfv3.Area.Ipv4Range.Range))])
                        self._leafs = OrderedDict()

                        self.range = YList(self)
                        self._segment_path = lambda: "ipv4-range"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Area.Ipv4Range, [], name, value)


                    class Range(Entity):
                        """
                        Summarize routes matching address/mask (border routers only)
                        
                        .. attribute:: ip  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: advertise
                        
                        	Advertise this range (default)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: not_advertise
                        
                        	DoNotAdvertise this range
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cost
                        
                        	User specified metric for this range
                        	**type**\: int
                        
                        	**range:** 0..16777215
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.Ipv4Range.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ipv4-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip','mask']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.ip = None
                            self.mask = None
                            self.advertise = None
                            self.not_advertise = None
                            self.cost = None
                            self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.Ipv4Range.Range, ['ip', 'mask', 'advertise', 'not_advertise', 'cost'], name, value)


                class Ipv6Range(Entity):
                    """
                    
                    
                    .. attribute:: range
                    
                    	Summarize routes matching address/mask (border routers only)
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.Ipv6Range.Range>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Area.Ipv6Range, self).__init__()

                        self.yang_name = "ipv6-range"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospfv3.Area.Ipv6Range.Range))])
                        self._leafs = OrderedDict()

                        self.range = YList(self)
                        self._segment_path = lambda: "ipv6-range"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Area.Ipv6Range, [], name, value)


                    class Range(Entity):
                        """
                        Summarize routes matching address/mask (border routers only)
                        
                        .. attribute:: ip  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: advertise
                        
                        	Advertise this range (default)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: not_advertise
                        
                        	DoNotAdvertise this range
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: cost
                        
                        	User specified metric for this range
                        	**type**\: int
                        
                        	**range:** 0..16777215
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.Ipv6Range.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ipv6-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                            ])
                            self.ip = None
                            self.advertise = None
                            self.not_advertise = None
                            self.cost = None
                            self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.Ipv6Range.Range, ['ip', 'advertise', 'not_advertise', 'cost'], name, value)


                class ShamLink(Entity):
                    """
                    Define a sham link and its parameters
                    
                    .. attribute:: source  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: dest  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cost
                    
                    	Associate a cost with the sham\-link
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.ShamLink.TtlSecurity>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Area.ShamLink, self).__init__()

                        self.yang_name = "sham-link"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['source','dest']
                        self._child_classes = OrderedDict([("ttl-security", ("ttl_security", Native.Router.Ospfv3.Area.ShamLink.TtlSecurity))])
                        self._leafs = OrderedDict([
                            ('source', (YLeaf(YType.str, 'source'), ['str','str'])),
                            ('dest', (YLeaf(YType.str, 'dest'), ['str','str'])),
                            ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                        ])
                        self.source = None
                        self.dest = None
                        self.cost = None

                        self.ttl_security = Native.Router.Ospfv3.Area.ShamLink.TtlSecurity()
                        self.ttl_security.parent = self
                        self._children_name_map["ttl_security"] = "ttl-security"
                        self._segment_path = lambda: "sham-link" + "[source='" + str(self.source) + "']" + "[dest='" + str(self.dest) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Area.ShamLink, ['source', 'dest', 'cost'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.ShamLink.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "sham-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.ShamLink.TtlSecurity, ['hops'], name, value)


                class Stub(Entity):
                    """
                    Specify a stub area
                    
                    .. attribute:: no_ext_capability
                    
                    	Do not send domain specific capabilities into stub area
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: no_summary
                    
                    	Do not send summary LSA into stub area
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Area.Stub, self).__init__()

                        self.yang_name = "stub"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                            ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                        ])
                        self.no_ext_capability = None
                        self.no_summary = None
                        self._segment_path = lambda: "stub"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Area.Stub, ['no_ext_capability', 'no_summary'], name, value)


                class VirtualLink(Entity):
                    """
                    Define a virtual link and its parameters
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: authentication
                    
                    	Set authentication type
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication>`
                    
                    .. attribute:: hello_interval
                    
                    	Hello packet interval
                    	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.HelloInterval>`
                    
                    .. attribute:: dead_interval
                    
                    	Dead router detection time
                    	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.DeadInterval>`
                    
                    .. attribute:: retransmit_interval
                    
                    	LSA retransmit interval
                    	**type**\:  :py:class:`RetransmitInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.RetransmitInterval>`
                    
                    .. attribute:: transmit_delay
                    
                    	LSA transmission delay
                    	**type**\:  :py:class:`TransmitDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.TransmitDelay>`
                    
                    .. attribute:: topology
                    
                    	Disable virtual link on topology
                    	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Topology>`
                    
                    .. attribute:: ttl_security
                    
                    	TTL security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.TtlSecurity>`
                    
                    .. attribute:: authentication_key
                    
                    	Set authentication key
                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.AuthenticationKey>`
                    
                    .. attribute:: message_digest_key
                    
                    	Set message digest key
                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.MessageDigestKey>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Area.VirtualLink, self).__init__()

                        self.yang_name = "virtual-link"
                        self.yang_parent_name = "area"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospfv3.Area.VirtualLink.Authentication)), ("hello-interval", ("hello_interval", Native.Router.Ospfv3.Area.VirtualLink.HelloInterval)), ("dead-interval", ("dead_interval", Native.Router.Ospfv3.Area.VirtualLink.DeadInterval)), ("retransmit-interval", ("retransmit_interval", Native.Router.Ospfv3.Area.VirtualLink.RetransmitInterval)), ("transmit-delay", ("transmit_delay", Native.Router.Ospfv3.Area.VirtualLink.TransmitDelay)), ("topology", ("topology", Native.Router.Ospfv3.Area.VirtualLink.Topology)), ("ttl-security", ("ttl_security", Native.Router.Ospfv3.Area.VirtualLink.TtlSecurity)), ("authentication-key", ("authentication_key", Native.Router.Ospfv3.Area.VirtualLink.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.Area.VirtualLink.MessageDigestKey))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                        ])
                        self.id = None

                        self.authentication = Native.Router.Ospfv3.Area.VirtualLink.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.hello_interval = Native.Router.Ospfv3.Area.VirtualLink.HelloInterval()
                        self.hello_interval.parent = self
                        self._children_name_map["hello_interval"] = "hello-interval"

                        self.dead_interval = Native.Router.Ospfv3.Area.VirtualLink.DeadInterval()
                        self.dead_interval.parent = self
                        self._children_name_map["dead_interval"] = "dead-interval"

                        self.retransmit_interval = Native.Router.Ospfv3.Area.VirtualLink.RetransmitInterval()
                        self.retransmit_interval.parent = self
                        self._children_name_map["retransmit_interval"] = "retransmit-interval"

                        self.transmit_delay = Native.Router.Ospfv3.Area.VirtualLink.TransmitDelay()
                        self.transmit_delay.parent = self
                        self._children_name_map["transmit_delay"] = "transmit-delay"

                        self.topology = Native.Router.Ospfv3.Area.VirtualLink.Topology()
                        self.topology.parent = self
                        self._children_name_map["topology"] = "topology"

                        self.ttl_security = Native.Router.Ospfv3.Area.VirtualLink.TtlSecurity()
                        self.ttl_security.parent = self
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.authentication_key = Native.Router.Ospfv3.Area.VirtualLink.AuthenticationKey()
                        self.authentication_key.parent = self
                        self._children_name_map["authentication_key"] = "authentication-key"

                        self.message_digest_key = YList(self)
                        self._segment_path = lambda: "virtual-link" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink, ['id'], name, value)


                    class Authentication(Entity):
                        """
                        Set authentication type
                        
                        .. attribute:: authentication_key
                        
                        	Set authentication key
                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication.AuthenticationKey>`
                        
                        .. attribute:: message_digest_key
                        
                        	Set message digest key
                        	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigestKey>`
                        
                        .. attribute:: key_chain
                        
                        	Use a key\-chain for cryptographic authentication keys
                        	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain>`
                        
                        .. attribute:: message_digest
                        
                        	Message\-digest authentication
                        	**type**\:  :py:class:`MessageDigest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest>`
                        
                        .. attribute:: null
                        
                        	No authentication
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.VirtualLink.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.Area.VirtualLink.Authentication.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigestKey)), ("key-chain", ("key_chain", Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain)), ("message-digest", ("message_digest", Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest))])
                            self._leafs = OrderedDict([
                                ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                            ])
                            self.null = None

                            self.authentication_key = Native.Router.Ospfv3.Area.VirtualLink.Authentication.AuthenticationKey()
                            self.authentication_key.parent = self
                            self._children_name_map["authentication_key"] = "authentication-key"

                            self.key_chain = Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain()
                            self.key_chain.parent = self
                            self._children_name_map["key_chain"] = "key-chain"

                            self.message_digest = Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest()
                            self.message_digest.parent = self
                            self._children_name_map["message_digest"] = "message-digest"

                            self.message_digest_key = YList(self)
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication, ['null'], name, value)


                        class AuthenticationKey(Entity):
                            """
                            Set authentication key
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.Area.VirtualLink.Authentication.AuthenticationKey, self).__init__()

                                self.yang_name = "authentication-key"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "authentication-key"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                        class MessageDigestKey(Entity):
                            """
                            Set message digest key
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: md5
                            
                            	Use MD5 algorithm
                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigestKey.Md5>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigestKey, self).__init__()

                                self.yang_name = "message-digest-key"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigestKey.Md5))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                ])
                                self.id = None

                                self.md5 = Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigestKey.Md5()
                                self.md5.parent = self
                                self._children_name_map["md5"] = "md5"
                                self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigestKey, ['id'], name, value)


                            class Md5(Entity):
                                """
                                Use MD5 algorithm
                                
                                .. attribute:: auth_type
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: auth_key
                                
                                	
                                	**type**\: str
                                
                                	**length:** 1..16
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigestKey.Md5, self).__init__()

                                    self.yang_name = "md5"
                                    self.yang_parent_name = "message-digest-key"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                    ])
                                    self.auth_type = None
                                    self.auth_key = None
                                    self._segment_path = lambda: "md5"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                        class KeyChain(Entity):
                            """
                            Use a key\-chain for cryptographic authentication keys
                            
                            .. attribute:: name
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: authentication_key
                            
                            	Set authentication key
                            	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey>`
                            
                            .. attribute:: message_digest_key
                            
                            	Set message digest key
                            	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain, self).__init__()

                                self.yang_name = "key-chain"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.authentication_key = Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey()
                                self.authentication_key.parent = self
                                self._children_name_map["authentication_key"] = "authentication-key"

                                self.message_digest_key = YList(self)
                                self._segment_path = lambda: "key-chain"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain, ['name'], name, value)


                            class AuthenticationKey(Entity):
                                """
                                Set authentication key
                                
                                .. attribute:: auth_type
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: auth_key
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, self).__init__()

                                    self.yang_name = "authentication-key"
                                    self.yang_parent_name = "key-chain"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                    ])
                                    self.auth_type = None
                                    self.auth_key = None
                                    self._segment_path = lambda: "authentication-key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                            class MessageDigestKey(Entity):
                                """
                                Set message digest key
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: md5
                                
                                	Use MD5 algorithm
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, self).__init__()

                                    self.yang_name = "message-digest-key"
                                    self.yang_parent_name = "key-chain"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.md5 = Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, ['id'], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 algorithm
                                    
                                    .. attribute:: auth_type
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: auth_key
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**length:** 1..16
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "message-digest-key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                            ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                        ])
                                        self.auth_type = None
                                        self.auth_key = None
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                        class MessageDigest(Entity):
                            """
                            Message\-digest authentication
                            
                            .. attribute:: authentication_key
                            
                            	Set authentication key
                            	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey>`
                            
                            .. attribute:: message_digest_key
                            
                            	Set message digest key
                            	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest, self).__init__()

                                self.yang_name = "message-digest"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey))])
                                self._leafs = OrderedDict()

                                self.authentication_key = Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey()
                                self.authentication_key.parent = self
                                self._children_name_map["authentication_key"] = "authentication-key"

                                self.message_digest_key = YList(self)
                                self._segment_path = lambda: "message-digest"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest, [], name, value)


                            class AuthenticationKey(Entity):
                                """
                                Set authentication key
                                
                                .. attribute:: auth_type
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: auth_key
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, self).__init__()

                                    self.yang_name = "authentication-key"
                                    self.yang_parent_name = "message-digest"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                    ])
                                    self.auth_type = None
                                    self.auth_key = None
                                    self._segment_path = lambda: "authentication-key"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                            class MessageDigestKey(Entity):
                                """
                                Set message digest key
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: md5
                                
                                	Use MD5 algorithm
                                	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, self).__init__()

                                    self.yang_name = "message-digest-key"
                                    self.yang_parent_name = "message-digest"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                    ])
                                    self.id = None

                                    self.md5 = Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5()
                                    self.md5.parent = self
                                    self._children_name_map["md5"] = "md5"
                                    self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, ['id'], name, value)


                                class Md5(Entity):
                                    """
                                    Use MD5 algorithm
                                    
                                    .. attribute:: auth_type
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: auth_key
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**length:** 1..16
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, self).__init__()

                                        self.yang_name = "md5"
                                        self.yang_parent_name = "message-digest-key"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                            ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                        ])
                                        self.auth_type = None
                                        self.auth_key = None
                                        self._segment_path = lambda: "md5"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                    class HelloInterval(Entity):
                        """
                        Hello packet interval
                        
                        .. attribute:: hello_interval_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8192
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.VirtualLink.HelloInterval, self).__init__()

                            self.yang_name = "hello-interval"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('hello_interval_value', (YLeaf(YType.int32, 'hello-interval-value'), ['int'])),
                            ])
                            self.hello_interval_value = None
                            self._segment_path = lambda: "hello-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.HelloInterval, ['hello_interval_value'], name, value)


                    class DeadInterval(Entity):
                        """
                        Dead router detection time
                        
                        .. attribute:: dead_interval_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8192
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.VirtualLink.DeadInterval, self).__init__()

                            self.yang_name = "dead-interval"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dead_interval_value', (YLeaf(YType.uint16, 'dead-interval-value'), ['int'])),
                            ])
                            self.dead_interval_value = None
                            self._segment_path = lambda: "dead-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.DeadInterval, ['dead_interval_value'], name, value)


                    class RetransmitInterval(Entity):
                        """
                        LSA retransmit interval
                        
                        .. attribute:: retransmit_interval_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8192
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.VirtualLink.RetransmitInterval, self).__init__()

                            self.yang_name = "retransmit-interval"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('retransmit_interval_value', (YLeaf(YType.uint16, 'retransmit-interval-value'), ['int'])),
                            ])
                            self.retransmit_interval_value = None
                            self._segment_path = lambda: "retransmit-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.RetransmitInterval, ['retransmit_interval_value'], name, value)


                    class TransmitDelay(Entity):
                        """
                        LSA transmission delay
                        
                        .. attribute:: transmit_delay_value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..8192
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.VirtualLink.TransmitDelay, self).__init__()

                            self.yang_name = "transmit-delay"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('transmit_delay_value', (YLeaf(YType.uint16, 'transmit-delay-value'), ['int'])),
                            ])
                            self.transmit_delay_value = None
                            self._segment_path = lambda: "transmit-delay"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.TransmitDelay, ['transmit_delay_value'], name, value)


                    class Topology(Entity):
                        """
                        Disable virtual link on topology
                        
                        .. attribute:: disable
                        
                        	Disable virtual link
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.VirtualLink.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "topology"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.Topology, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        TTL security check
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.VirtualLink.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.TtlSecurity, ['hops'], name, value)


                    class AuthenticationKey(Entity):
                        """
                        Set authentication key
                        
                        .. attribute:: auth_type
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: auth_key
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.VirtualLink.AuthenticationKey, self).__init__()

                            self.yang_name = "authentication-key"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                            ])
                            self.auth_type = None
                            self.auth_key = None
                            self._segment_path = lambda: "authentication-key"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                    class MessageDigestKey(Entity):
                        """
                        Set message digest key
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: md5
                        
                        	Use MD5 algorithm
                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Area.VirtualLink.MessageDigestKey.Md5>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Area.VirtualLink.MessageDigestKey, self).__init__()

                            self.yang_name = "message-digest-key"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.Area.VirtualLink.MessageDigestKey.Md5))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.md5 = Native.Router.Ospfv3.Area.VirtualLink.MessageDigestKey.Md5()
                            self.md5.parent = self
                            self._children_name_map["md5"] = "md5"
                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.MessageDigestKey, ['id'], name, value)


                        class Md5(Entity):
                            """
                            Use MD5 algorithm
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..16
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.Area.VirtualLink.MessageDigestKey.Md5, self).__init__()

                                self.yang_name = "md5"
                                self.yang_parent_name = "message-digest-key"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "md5"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.Area.VirtualLink.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


            class AutoCost(Entity):
                """
                Calculate OSPF interface cost according to bandwidth
                
                .. attribute:: reference_bandwidth
                
                	Use reference bandwidth method to assign OSPF cost
                	**type**\: int
                
                	**range:** 1..4294967
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.AutoCost, self).__init__()

                    self.yang_name = "auto-cost"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('reference_bandwidth', (YLeaf(YType.uint32, 'reference-bandwidth'), ['int'])),
                    ])
                    self.reference_bandwidth = None
                    self._segment_path = lambda: "auto-cost"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.AutoCost, ['reference_bandwidth'], name, value)


            class EventLog(Entity):
                """
                OSPF Event Logging
                
                .. attribute:: one_shot
                
                	Disable Logging When Log Buffer Becomes Full
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pause
                
                	Pause Event Logging
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: size
                
                	Maximum Number of Events Stored in the Event Log
                	**type**\: int
                
                	**range:** 1..65534
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.EventLog, self).__init__()

                    self.yang_name = "event-log"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('one_shot', (YLeaf(YType.empty, 'one-shot'), ['Empty'])),
                        ('pause', (YLeaf(YType.empty, 'pause'), ['Empty'])),
                        ('size', (YLeaf(YType.uint32, 'size'), ['int'])),
                    ])
                    self.one_shot = None
                    self.pause = None
                    self.size = None
                    self._segment_path = lambda: "event-log"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.EventLog, ['one_shot', 'pause', 'size'], name, value)


            class Bfd(Entity):
                """
                BFD configuration commands
                
                .. attribute:: all_interfaces
                
                	Enable BFD on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                    ])
                    self.all_interfaces = None
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.Bfd, ['all_interfaces'], name, value)


            class InterfaceId(Entity):
                """
                Source of the interface ID
                
                .. attribute:: snmp_if_index
                
                	SNMP MIB ifIndex
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.InterfaceId, self).__init__()

                    self.yang_name = "interface-id"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('snmp_if_index', (YLeaf(YType.empty, 'snmp-if-index'), ['Empty'])),
                    ])
                    self.snmp_if_index = None
                    self._segment_path = lambda: "interface-id"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.InterfaceId, ['snmp_if_index'], name, value)


            class LogAdjacencyChanges(Entity):
                """
                Log changes in adjacency state
                
                .. attribute:: detail
                
                	Log all state changes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.LogAdjacencyChanges, self).__init__()

                    self.yang_name = "log-adjacency-changes"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('detail', (YLeaf(YType.empty, 'detail'), ['Empty'])),
                    ])
                    self.detail = None
                    self._segment_path = lambda: "log-adjacency-changes"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.LogAdjacencyChanges, ['detail'], name, value)


            class MaxLsa(Entity):
                """
                maximum number of LSAs OSPF process will receive
                
                .. attribute:: number
                
                	
                	**type**\: int
                
                	**range:** 1..4294967294
                
                .. attribute:: threshold_value
                
                	
                	**type**\: int
                
                	**range:** 1..100
                
                .. attribute:: ignore_count
                
                	maximum number of times adjacencies can be suppressed
                	**type**\: int
                
                	**range:** 1..65534
                
                .. attribute:: ignore_time
                
                	time during which all adjacencies are suppressed
                	**type**\: int
                
                	**range:** 1..17895
                
                .. attribute:: reset_time
                
                	time after which ignore\-count is reset to zero
                	**type**\: int
                
                	**range:** 2..35791
                
                .. attribute:: warning_only
                
                	Only give warning message when limit is exceeded
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.MaxLsa, self).__init__()

                    self.yang_name = "max-lsa"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                        ('threshold_value', (YLeaf(YType.uint32, 'threshold-value'), ['int'])),
                        ('ignore_count', (YLeaf(YType.uint32, 'ignore-count'), ['int'])),
                        ('ignore_time', (YLeaf(YType.uint32, 'ignore-time'), ['int'])),
                        ('reset_time', (YLeaf(YType.uint32, 'reset-time'), ['int'])),
                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                    ])
                    self.number = None
                    self.threshold_value = None
                    self.ignore_count = None
                    self.ignore_time = None
                    self.reset_time = None
                    self.warning_only = None
                    self._segment_path = lambda: "max-lsa"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.MaxLsa, ['number', 'threshold_value', 'ignore_count', 'ignore_time', 'reset_time', 'warning_only'], name, value)


            class MaxMetric(Entity):
                """
                Set maximum metric
                
                .. attribute:: router_lsa
                
                	Maximum metric in self\-originated router\-LSAs
                	**type**\:  :py:class:`RouterLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.MaxMetric.RouterLsa>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.MaxMetric, self).__init__()

                    self.yang_name = "max-metric"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("router-lsa", ("router_lsa", Native.Router.Ospfv3.MaxMetric.RouterLsa))])
                    self._leafs = OrderedDict()

                    self.router_lsa = None
                    self._children_name_map["router_lsa"] = "router-lsa"
                    self._segment_path = lambda: "max-metric"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.MaxMetric, [], name, value)


                class RouterLsa(Entity):
                    """
                    Maximum metric in self\-originated router\-LSAs
                    
                    .. attribute:: external_lsa
                    
                    	Override external\-lsa metric with max\-metric value
                    	**type**\:  :py:class:`ExternalLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.MaxMetric.RouterLsa.ExternalLsa>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: include_stub
                    
                    	Set maximum metric for stub links in router\-LSAs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: on_startup
                    
                    	Set maximum metric temporarily after reboot
                    	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.MaxMetric.RouterLsa.OnStartup>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: summary_lsa
                    
                    	Override summary\-lsa metric with max\-metric value
                    	**type**\:  :py:class:`SummaryLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.MaxMetric.RouterLsa.SummaryLsa>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.MaxMetric.RouterLsa, self).__init__()

                        self.yang_name = "router-lsa"
                        self.yang_parent_name = "max-metric"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("external-lsa", ("external_lsa", Native.Router.Ospfv3.MaxMetric.RouterLsa.ExternalLsa)), ("on-startup", ("on_startup", Native.Router.Ospfv3.MaxMetric.RouterLsa.OnStartup)), ("summary-lsa", ("summary_lsa", Native.Router.Ospfv3.MaxMetric.RouterLsa.SummaryLsa))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('include_stub', (YLeaf(YType.empty, 'include-stub'), ['Empty'])),
                        ])
                        self.include_stub = None

                        self.external_lsa = None
                        self._children_name_map["external_lsa"] = "external-lsa"

                        self.on_startup = None
                        self._children_name_map["on_startup"] = "on-startup"

                        self.summary_lsa = None
                        self._children_name_map["summary_lsa"] = "summary-lsa"
                        self._segment_path = lambda: "router-lsa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.MaxMetric.RouterLsa, ['include_stub'], name, value)


                    class ExternalLsa(Entity):
                        """
                        Override external\-lsa metric with max\-metric value
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777215
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.MaxMetric.RouterLsa.ExternalLsa, self).__init__()

                            self.yang_name = "external-lsa"
                            self.yang_parent_name = "router-lsa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.metric = None
                            self._segment_path = lambda: "external-lsa"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.MaxMetric.RouterLsa.ExternalLsa, ['metric'], name, value)


                    class OnStartup(Entity):
                        """
                        Set maximum metric temporarily after reboot
                        
                        .. attribute:: time
                        
                        	
                        	**type**\: int
                        
                        	**range:** 5..86400
                        
                        .. attribute:: wait_for_bgp
                        
                        	Let BGP decide when to originate router\-LSA with normal metric
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.MaxMetric.RouterLsa.OnStartup, self).__init__()

                            self.yang_name = "on-startup"
                            self.yang_parent_name = "router-lsa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                ('wait_for_bgp', (YLeaf(YType.empty, 'wait-for-bgp'), ['Empty'])),
                            ])
                            self.time = None
                            self.wait_for_bgp = None
                            self._segment_path = lambda: "on-startup"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.MaxMetric.RouterLsa.OnStartup, ['time', 'wait_for_bgp'], name, value)


                    class SummaryLsa(Entity):
                        """
                        Override summary\-lsa metric with max\-metric value
                        
                        .. attribute:: metric
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..16777215
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.MaxMetric.RouterLsa.SummaryLsa, self).__init__()

                            self.yang_name = "summary-lsa"
                            self.yang_parent_name = "router-lsa"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ])
                            self.metric = None
                            self._segment_path = lambda: "summary-lsa"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.MaxMetric.RouterLsa.SummaryLsa, ['metric'], name, value)


            class PassiveInterface(Entity):
                """
                Suppress routing updates on an interface
                
                .. attribute:: default
                
                	Suppress routing updates on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.PassiveInterface, self).__init__()

                    self.yang_name = "passive-interface"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                    ])
                    self.default = None
                    self.interface = None
                    self._segment_path = lambda: "passive-interface"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.PassiveInterface, [u'default', u'interface'], name, value)


            class Disable(Entity):
                """
                
                
                .. attribute:: passive_interface
                
                	
                	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Disable.PassiveInterface>`
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.Disable, self).__init__()

                    self.yang_name = "disable"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.Ospfv3.Disable.PassiveInterface))])
                    self._leafs = OrderedDict()

                    self.passive_interface = YList(self)
                    self._segment_path = lambda: "disable"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.Disable, [], name, value)


                class PassiveInterface(Entity):
                    """
                    
                    
                    .. attribute:: interface  (key)
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Disable.PassiveInterface, self).__init__()

                        self.yang_name = "passive-interface"
                        self.yang_parent_name = "disable"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ])
                        self.interface = None
                        self._segment_path = lambda: "passive-interface" + "[interface='" + str(self.interface) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Disable.PassiveInterface, [u'interface'], name, value)


            class QueueDepth(Entity):
                """
                OSPF Hello/Router process queue depth
                
                .. attribute:: hello
                
                	OSPF Hello process queue depth
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.QueueDepth.Hello>`
                
                .. attribute:: update
                
                	OSPF Router process queue depth
                	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.QueueDepth.Update>`
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.QueueDepth, self).__init__()

                    self.yang_name = "queue-depth"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("hello", ("hello", Native.Router.Ospfv3.QueueDepth.Hello)), ("update", ("update", Native.Router.Ospfv3.QueueDepth.Update))])
                    self._leafs = OrderedDict()

                    self.hello = Native.Router.Ospfv3.QueueDepth.Hello()
                    self.hello.parent = self
                    self._children_name_map["hello"] = "hello"

                    self.update = Native.Router.Ospfv3.QueueDepth.Update()
                    self.update.parent = self
                    self._children_name_map["update"] = "update"
                    self._segment_path = lambda: "queue-depth"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.QueueDepth, [], name, value)


                class Hello(Entity):
                    """
                    OSPF Hello process queue depth
                    
                    .. attribute:: options
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..2147483647
                    
                    		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.QueueDepth.Hello, self).__init__()

                        self.yang_name = "hello"
                        self.yang_parent_name = "queue-depth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                        ])
                        self.options = None
                        self._segment_path = lambda: "hello"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.QueueDepth.Hello, ['options'], name, value)

                    class Options(Enum):
                        """
                        Options (Enum Class)

                        .. data:: unlimited = 0

                        """

                        unlimited = Enum.YLeaf(0, "unlimited")



                class Update(Entity):
                    """
                    OSPF Router process queue depth
                    
                    .. attribute:: options
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..2147483647
                    
                    		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.QueueDepth.Update, self).__init__()

                        self.yang_name = "update"
                        self.yang_parent_name = "queue-depth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                        ])
                        self.options = None
                        self._segment_path = lambda: "update"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.QueueDepth.Update, ['options'], name, value)

                    class Options(Enum):
                        """
                        Options (Enum Class)

                        .. data:: unlimited = 0

                        """

                        unlimited = Enum.YLeaf(0, "unlimited")



            class Timers(Entity):
                """
                Adjust routing timers
                
                .. attribute:: lsa
                
                	OSPF LSA timers
                	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Timers.Lsa>`
                
                .. attribute:: pacing
                
                	OSPF pacing timers
                	**type**\:  :py:class:`Pacing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Timers.Pacing>`
                
                .. attribute:: throttle
                
                	OSPF throttle timers
                	**type**\:  :py:class:`Throttle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Timers.Throttle>`
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.Timers, self).__init__()

                    self.yang_name = "timers"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospfv3.Timers.Lsa)), ("pacing", ("pacing", Native.Router.Ospfv3.Timers.Pacing)), ("throttle", ("throttle", Native.Router.Ospfv3.Timers.Throttle))])
                    self._leafs = OrderedDict()

                    self.lsa = Native.Router.Ospfv3.Timers.Lsa()
                    self.lsa.parent = self
                    self._children_name_map["lsa"] = "lsa"

                    self.pacing = Native.Router.Ospfv3.Timers.Pacing()
                    self.pacing.parent = self
                    self._children_name_map["pacing"] = "pacing"

                    self.throttle = Native.Router.Ospfv3.Timers.Throttle()
                    self.throttle.parent = self
                    self._children_name_map["throttle"] = "throttle"
                    self._segment_path = lambda: "timers"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.Timers, [], name, value)


                class Lsa(Entity):
                    """
                    OSPF LSA timers
                    
                    .. attribute:: arrival
                    
                    	OSPF LSA arrival timer
                    	**type**\: int
                    
                    	**range:** 0..600000
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Timers.Lsa, self).__init__()

                        self.yang_name = "lsa"
                        self.yang_parent_name = "timers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('arrival', (YLeaf(YType.uint32, 'arrival'), ['int'])),
                        ])
                        self.arrival = None
                        self._segment_path = lambda: "lsa"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Timers.Lsa, ['arrival'], name, value)


                class Pacing(Entity):
                    """
                    OSPF pacing timers
                    
                    .. attribute:: flood
                    
                    	OSPF flood pacing timer
                    	**type**\: int
                    
                    	**range:** 5..100
                    
                    .. attribute:: lsa_group
                    
                    	OSPF LSA group pacing timer
                    	**type**\: int
                    
                    	**range:** 10..1800
                    
                    .. attribute:: retransmission
                    
                    	OSPF retransmission pacing timer
                    	**type**\: int
                    
                    	**range:** 5..200
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Timers.Pacing, self).__init__()

                        self.yang_name = "pacing"
                        self.yang_parent_name = "timers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('flood', (YLeaf(YType.uint32, 'flood'), ['int'])),
                            ('lsa_group', (YLeaf(YType.uint32, 'lsa-group'), ['int'])),
                            ('retransmission', (YLeaf(YType.uint32, 'retransmission'), ['int'])),
                        ])
                        self.flood = None
                        self.lsa_group = None
                        self.retransmission = None
                        self._segment_path = lambda: "pacing"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Timers.Pacing, ['flood', 'lsa_group', 'retransmission'], name, value)


                class Throttle(Entity):
                    """
                    OSPF throttle timers
                    
                    .. attribute:: lsa
                    
                    	OSPF LSA throttle timers
                    	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Timers.Throttle.Lsa>`
                    
                    .. attribute:: spf
                    
                    	OSPF SPF throttle timers
                    	**type**\:  :py:class:`Spf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Timers.Throttle.Spf>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Timers.Throttle, self).__init__()

                        self.yang_name = "throttle"
                        self.yang_parent_name = "timers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospfv3.Timers.Throttle.Lsa)), ("spf", ("spf", Native.Router.Ospfv3.Timers.Throttle.Spf))])
                        self._leafs = OrderedDict()

                        self.lsa = Native.Router.Ospfv3.Timers.Throttle.Lsa()
                        self.lsa.parent = self
                        self._children_name_map["lsa"] = "lsa"

                        self.spf = Native.Router.Ospfv3.Timers.Throttle.Spf()
                        self.spf.parent = self
                        self._children_name_map["spf"] = "spf"
                        self._segment_path = lambda: "throttle"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Timers.Throttle, [], name, value)


                    class Lsa(Entity):
                        """
                        OSPF LSA throttle timers
                        
                        .. attribute:: all
                        
                        	For all type of OSPF LSAs
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Timers.Throttle.Lsa.All>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Timers.Throttle.Lsa, self).__init__()

                            self.yang_name = "lsa"
                            self.yang_parent_name = "throttle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Ospfv3.Timers.Throttle.Lsa.All))])
                            self._leafs = OrderedDict()

                            self.all = Native.Router.Ospfv3.Timers.Throttle.Lsa.All()
                            self.all.parent = self
                            self._children_name_map["all"] = "all"
                            self._segment_path = lambda: "lsa"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Timers.Throttle.Lsa, [], name, value)


                        class All(Entity):
                            """
                            For all type of OSPF LSAs
                            
                            .. attribute:: delay
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..600000
                            
                            .. attribute:: min_delay
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..600000
                            
                            .. attribute:: max_delay
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..600000
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.Timers.Throttle.Lsa.All, self).__init__()

                                self.yang_name = "all"
                                self.yang_parent_name = "lsa"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                    ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                    ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                ])
                                self.delay = None
                                self.min_delay = None
                                self.max_delay = None
                                self._segment_path = lambda: "all"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.Timers.Throttle.Lsa.All, ['delay', 'min_delay', 'max_delay'], name, value)


                    class Spf(Entity):
                        """
                        OSPF SPF throttle timers
                        
                        .. attribute:: delay
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..600000
                        
                        .. attribute:: min_delay
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..600000
                        
                        .. attribute:: max_delay
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..600000
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Timers.Throttle.Spf, self).__init__()

                            self.yang_name = "spf"
                            self.yang_parent_name = "throttle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                            ])
                            self.delay = None
                            self.min_delay = None
                            self.max_delay = None
                            self._segment_path = lambda: "spf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Timers.Throttle.Spf, ['delay', 'min_delay', 'max_delay'], name, value)


            class TrafficShare(Entity):
                """
                How to compute traffic share over alternate paths
                
                .. attribute:: min
                
                	All traffic shared among min metric paths
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: across_interfaces
                
                	Use different interfaces for equal\-cost paths
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.TrafficShare, self).__init__()

                    self.yang_name = "traffic-share"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                        ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                    ])
                    self.min = None
                    self.across_interfaces = None
                    self._segment_path = lambda: "traffic-share"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.TrafficShare, ['min', 'across_interfaces'], name, value)


            class TtlSecurity(Entity):
                """
                TTL security check
                
                .. attribute:: all_interfaces
                
                	Enable TTL Security on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hops
                
                	IP hops
                	**type**\: int
                
                	**range:** 1..254
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.TtlSecurity, self).__init__()

                    self.yang_name = "ttl-security"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                        ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                    ])
                    self.all_interfaces = None
                    self.hops = None
                    self._segment_path = lambda: "ttl-security"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.TtlSecurity, ['all_interfaces', 'hops'], name, value)


            class Authentication(Entity):
                """
                Authentication parameters
                
                .. attribute:: mode
                
                	Authentication operation mode
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Authentication.Mode>`
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.Authentication, self).__init__()

                    self.yang_name = "authentication"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.Authentication.Mode')])),
                    ])
                    self.mode = None
                    self._segment_path = lambda: "authentication"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.Authentication, [u'mode'], name, value)

                class Mode(Enum):
                    """
                    Mode (Enum Class)

                    Authentication operation mode

                    .. data:: deployment = 0

                    .. data:: strict = 1

                    """

                    deployment = Enum.YLeaf(0, "deployment")

                    strict = Enum.YLeaf(1, "strict")



            class GracefulRestart(Entity):
                """
                Graceful\-restart options
                
                .. attribute:: helper
                
                	helper support
                	**type**\:  :py:class:`Helper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.GracefulRestart.Helper>`
                
                	**presence node**\: True
                
                .. attribute:: restart_interval
                
                	Graceful restart interval
                	**type**\: int
                
                	**range:** 0..65535
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.GracefulRestart, self).__init__()

                    self.yang_name = "graceful-restart"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("helper", ("helper", Native.Router.Ospfv3.GracefulRestart.Helper))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('restart_interval', (YLeaf(YType.uint16, 'restart-interval'), ['int'])),
                    ])
                    self.restart_interval = None

                    self.helper = None
                    self._children_name_map["helper"] = "helper"
                    self._segment_path = lambda: "graceful-restart"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.GracefulRestart, [u'restart_interval'], name, value)


                class Helper(Entity):
                    """
                    helper support
                    
                    .. attribute:: disable
                    
                    	disable helper support
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: strict_lsa_checking
                    
                    	enable helper strict LSA checking
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.GracefulRestart.Helper, self).__init__()

                        self.yang_name = "helper"
                        self.yang_parent_name = "graceful-restart"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('strict_lsa_checking', (YLeaf(YType.empty, 'strict-lsa-checking'), ['Empty'])),
                        ])
                        self.disable = None
                        self.strict_lsa_checking = None
                        self._segment_path = lambda: "helper"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.GracefulRestart.Helper, [u'disable', u'strict_lsa_checking'], name, value)


            class Manet(Entity):
                """
                Specify MANET OSPF parameters
                
                .. attribute:: cache
                
                	Specify MANET cache sizes
                	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Manet.Cache>`
                
                .. attribute:: hello
                
                	Unicast Hellos rather than multicast
                	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Manet.Hello>`
                
                .. attribute:: peering
                
                	MANET OSPF Smart Peering
                	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Manet.Peering>`
                
                .. attribute:: willingness
                
                	Specify Relay willingness value
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.Manet, self).__init__()

                    self.yang_name = "manet"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cache", ("cache", Native.Router.Ospfv3.Manet.Cache)), ("peering", ("peering", Native.Router.Ospfv3.Manet.Peering))])
                    self._leafs = OrderedDict([
                        ('hello', (YLeaf(YType.enumeration, 'hello'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.Manet.Hello')])),
                        ('willingness', (YLeaf(YType.uint8, 'willingness'), ['int'])),
                    ])
                    self.hello = None
                    self.willingness = None

                    self.cache = Native.Router.Ospfv3.Manet.Cache()
                    self.cache.parent = self
                    self._children_name_map["cache"] = "cache"

                    self.peering = Native.Router.Ospfv3.Manet.Peering()
                    self.peering.parent = self
                    self._children_name_map["peering"] = "peering"
                    self._segment_path = lambda: "manet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.Manet, [u'hello', u'willingness'], name, value)

                class Hello(Enum):
                    """
                    Hello (Enum Class)

                    Unicast Hellos rather than multicast

                    .. data:: unicast = 0

                    """

                    unicast = Enum.YLeaf(0, "unicast")



                class Cache(Entity):
                    """
                    Specify MANET cache sizes
                    
                    .. attribute:: acknowledgement
                    
                    	Specify MANET acknowledgement cache size
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update
                    
                    	Specify MANET LSA cache size
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Manet.Cache, self).__init__()

                        self.yang_name = "cache"
                        self.yang_parent_name = "manet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acknowledgement', (YLeaf(YType.uint64, 'acknowledgement'), ['int'])),
                            ('update', (YLeaf(YType.uint64, 'update'), ['int'])),
                        ])
                        self.acknowledgement = None
                        self.update = None
                        self._segment_path = lambda: "cache"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Manet.Cache, [u'acknowledgement', u'update'], name, value)


                class Peering(Entity):
                    """
                    MANET OSPF Smart Peering
                    
                    .. attribute:: selective
                    
                    	Enable selective peering
                    	**type**\:  :py:class:`Selective <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.Manet.Peering.Selective>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.Manet.Peering, self).__init__()

                        self.yang_name = "peering"
                        self.yang_parent_name = "manet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("selective", ("selective", Native.Router.Ospfv3.Manet.Peering.Selective))])
                        self._leafs = OrderedDict()

                        self.selective = Native.Router.Ospfv3.Manet.Peering.Selective()
                        self.selective.parent = self
                        self._children_name_map["selective"] = "selective"
                        self._segment_path = lambda: "peering"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.Manet.Peering, [], name, value)


                    class Selective(Entity):
                        """
                        Enable selective peering
                        
                        .. attribute:: disable
                        
                        	Disable selective peering
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: per_interface
                        
                        	Select peers per interface rather than per node
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: redundancy
                        
                        	Redundant paths
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.Manet.Peering.Selective, self).__init__()

                            self.yang_name = "selective"
                            self.yang_parent_name = "peering"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ('per_interface', (YLeaf(YType.empty, 'per-interface'), ['Empty'])),
                                ('redundancy', (YLeaf(YType.uint8, 'redundancy'), ['int'])),
                            ])
                            self.disable = None
                            self.per_interface = None
                            self.redundancy = None
                            self._segment_path = lambda: "selective"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.Manet.Peering.Selective, [u'disable', u'per_interface', u'redundancy'], name, value)


            class AddressFamily(Entity):
                """
                Enter Address Family command mode
                
                .. attribute:: ipv4
                
                	IPv4 Address family
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4>`
                
                .. attribute:: ipv6
                
                	IPv6 Address family
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6>`
                
                

                """

                _prefix = 'ios-ospfv3'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Ospfv3.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "ospfv3"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Ospfv3.AddressFamily.Ipv4)), ("ipv6", ("ipv6", Native.Router.Ospfv3.AddressFamily.Ipv6))])
                    self._leafs = OrderedDict()

                    self.ipv4 = Native.Router.Ospfv3.AddressFamily.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = Native.Router.Ospfv3.AddressFamily.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._segment_path = lambda: "address-family"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily, [], name, value)


                class Ipv4(Entity):
                    """
                    IPv4 Address family
                    
                    .. attribute:: unicast
                    
                    	Address Family Modifier
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: vrf
                    
                    	Specify parameters for a VPN Routing/Forwarding instance
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.AddressFamily.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("unicast", ("unicast", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast)), ("vrf", ("vrf", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf))])
                        self._leafs = OrderedDict()

                        self.unicast = None
                        self._children_name_map["unicast"] = "unicast"

                        self.vrf = YList(self)
                        self._segment_path = lambda: "ipv4"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4, [], name, value)


                    class Unicast(Entity):
                        """
                        Address Family Modifier
                        
                        .. attribute:: area
                        
                        	OSPF area parameters
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area>`
                        
                        .. attribute:: auto_cost
                        
                        	Calculate OSPF interface cost according to bandwidth
                        	**type**\:  :py:class:`AutoCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.AutoCost>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: event_log
                        
                        	OSPF Event Logging
                        	**type**\:  :py:class:`EventLog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.EventLog>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: bfd
                        
                        	BFD configuration commands
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Bfd>`
                        
                        .. attribute:: interface_id
                        
                        	Source of the interface ID
                        	**type**\:  :py:class:`InterfaceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.InterfaceId>`
                        
                        .. attribute:: log_adjacency_changes
                        
                        	Log changes in adjacency state
                        	**type**\:  :py:class:`LogAdjacencyChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.LogAdjacencyChanges>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: max_lsa
                        
                        	maximum number of LSAs OSPF process will receive
                        	**type**\:  :py:class:`MaxLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxLsa>`
                        
                        .. attribute:: max_metric
                        
                        	Set maximum metric
                        	**type**\:  :py:class:`MaxMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric>`
                        
                        .. attribute:: passive_interface
                        
                        	Suppress routing updates on an interface
                        	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.PassiveInterface>`
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Disable>`
                        
                        .. attribute:: queue_depth
                        
                        	OSPF Hello/Router process queue depth
                        	**type**\:  :py:class:`QueueDepth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth>`
                        
                        .. attribute:: timers
                        
                        	Adjust routing timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers>`
                        
                        .. attribute:: router_id
                        
                        	Override configured router identifier (peers will reset)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nsr
                        
                        	Enable non\-stop routing
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: traffic_share
                        
                        	How to compute traffic share over alternate paths
                        	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.TrafficShare>`
                        
                        .. attribute:: ttl_security
                        
                        	TTL security check
                        	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.TtlSecurity>`
                        
                        .. attribute:: capability
                        
                        	Enable specific OSPF feature
                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Capability>`
                        
                        .. attribute:: compatible
                        
                        	OSPF compatibility list
                        	**type**\:  :py:class:`Compatible <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Compatible>`
                        
                        .. attribute:: default_information
                        
                        	Control distribution of default information
                        	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DefaultInformation>`
                        
                        .. attribute:: default_metric
                        
                        	Set metric of redistributed routes
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: discard_route
                        
                        	Enable or disable discard\-route installation
                        	**type**\:  :py:class:`DiscardRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DiscardRoute>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: distance
                        
                        	Define an administrative distance
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance>`
                        
                        .. attribute:: maximum_paths
                        
                        	Forward packets over multiple paths
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: redistribute
                        
                        	Redistribute information from another routing protocol
                        	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute>`
                        
                        .. attribute:: authentication
                        
                        	Authentication parameters
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Authentication>`
                        
                        .. attribute:: graceful_restart
                        
                        	Graceful\-restart options
                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.GracefulRestart>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF parameters
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet>`
                        
                        .. attribute:: summary_prefix
                        
                        	
                        	**type**\: list of  		 :py:class:`SummaryPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.SummaryPrefix>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area)), ("auto-cost", ("auto_cost", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.AutoCost)), ("event-log", ("event_log", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.EventLog)), ("bfd", ("bfd", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Bfd)), ("interface-id", ("interface_id", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.InterfaceId)), ("log-adjacency-changes", ("log_adjacency_changes", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.LogAdjacencyChanges)), ("max-lsa", ("max_lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxLsa)), ("max-metric", ("max_metric", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric)), ("passive-interface", ("passive_interface", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.PassiveInterface)), ("disable", ("disable", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Disable)), ("queue-depth", ("queue_depth", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth)), ("timers", ("timers", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers)), ("traffic-share", ("traffic_share", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.TrafficShare)), ("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.TtlSecurity)), ("capability", ("capability", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Capability)), ("compatible", ("compatible", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Compatible)), ("default-information", ("default_information", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DefaultInformation)), ("discard-route", ("discard_route", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DiscardRoute)), ("distance", ("distance", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance)), ("redistribute", ("redistribute", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute)), ("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Authentication)), ("graceful-restart", ("graceful_restart", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.GracefulRestart)), ("manet", ("manet", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet)), ("summary-prefix", ("summary_prefix", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.SummaryPrefix))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('nsr', (YLeaf(YType.empty, 'nsr'), ['Empty'])),
                                ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                            ])
                            self.router_id = None
                            self.nsr = None
                            self.default_metric = None
                            self.maximum_paths = None

                            self.auto_cost = None
                            self._children_name_map["auto_cost"] = "auto-cost"

                            self.event_log = None
                            self._children_name_map["event_log"] = "event-log"

                            self.bfd = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Bfd()
                            self.bfd.parent = self
                            self._children_name_map["bfd"] = "bfd"

                            self.interface_id = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.InterfaceId()
                            self.interface_id.parent = self
                            self._children_name_map["interface_id"] = "interface-id"

                            self.log_adjacency_changes = None
                            self._children_name_map["log_adjacency_changes"] = "log-adjacency-changes"

                            self.max_lsa = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxLsa()
                            self.max_lsa.parent = self
                            self._children_name_map["max_lsa"] = "max-lsa"

                            self.max_metric = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric()
                            self.max_metric.parent = self
                            self._children_name_map["max_metric"] = "max-metric"

                            self.passive_interface = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.PassiveInterface()
                            self.passive_interface.parent = self
                            self._children_name_map["passive_interface"] = "passive-interface"

                            self.disable = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Disable()
                            self.disable.parent = self
                            self._children_name_map["disable"] = "disable"

                            self.queue_depth = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth()
                            self.queue_depth.parent = self
                            self._children_name_map["queue_depth"] = "queue-depth"

                            self.timers = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"

                            self.traffic_share = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.TrafficShare()
                            self.traffic_share.parent = self
                            self._children_name_map["traffic_share"] = "traffic-share"

                            self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.TtlSecurity()
                            self.ttl_security.parent = self
                            self._children_name_map["ttl_security"] = "ttl-security"

                            self.capability = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Capability()
                            self.capability.parent = self
                            self._children_name_map["capability"] = "capability"

                            self.compatible = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Compatible()
                            self.compatible.parent = self
                            self._children_name_map["compatible"] = "compatible"

                            self.default_information = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DefaultInformation()
                            self.default_information.parent = self
                            self._children_name_map["default_information"] = "default-information"

                            self.discard_route = None
                            self._children_name_map["discard_route"] = "discard-route"

                            self.distance = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.redistribute = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute()
                            self.redistribute.parent = self
                            self._children_name_map["redistribute"] = "redistribute"

                            self.authentication = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.graceful_restart = None
                            self._children_name_map["graceful_restart"] = "graceful-restart"

                            self.manet = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.area = YList(self)
                            self.summary_prefix = YList(self)
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast, ['router_id', 'nsr', 'default_metric', 'maximum_paths'], name, value)


                        class Area(Entity):
                            """
                            OSPF area parameters
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: authentication
                            
                            	Enable authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Authentication>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: capability
                            
                            	Enable area specific capability
                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Capability>`
                            
                            .. attribute:: default_cost
                            
                            	Set the summary default\-cost of a NSSA/stub area
                            	**type**\: int
                            
                            	**range:** 0..16777215
                            
                            .. attribute:: filter_list
                            
                            	Filter networks between OSPF areas
                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.FilterList>`
                            
                            .. attribute:: nssa
                            
                            	Specify a NSSA area
                            	**type**\:  :py:class:`Nssa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ipv4_range
                            
                            	
                            	**type**\:  :py:class:`Ipv4Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv4Range>`
                            
                            .. attribute:: ipv6_range
                            
                            	
                            	**type**\:  :py:class:`Ipv6Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv6Range>`
                            
                            .. attribute:: sham_link
                            
                            	Define a sham link and its parameters
                            	**type**\: list of  		 :py:class:`ShamLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.ShamLink>`
                            
                            .. attribute:: stub
                            
                            	Specify a stub area
                            	**type**\:  :py:class:`Stub <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Stub>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: virtual_link
                            
                            	Define a virtual link and its parameters
                            	**type**\: list of  		 :py:class:`VirtualLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Authentication)), ("capability", ("capability", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Capability)), ("filter-list", ("filter_list", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.FilterList)), ("nssa", ("nssa", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa)), ("ipv4-range", ("ipv4_range", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv4Range)), ("ipv6-range", ("ipv6_range", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv6Range)), ("sham-link", ("sham_link", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.ShamLink)), ("stub", ("stub", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Stub)), ("virtual-link", ("virtual_link", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('default_cost', (YLeaf(YType.uint32, 'default-cost'), ['int'])),
                                ])
                                self.id = None
                                self.default_cost = None

                                self.authentication = None
                                self._children_name_map["authentication"] = "authentication"

                                self.capability = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Capability()
                                self.capability.parent = self
                                self._children_name_map["capability"] = "capability"

                                self.nssa = None
                                self._children_name_map["nssa"] = "nssa"

                                self.ipv4_range = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv4Range()
                                self.ipv4_range.parent = self
                                self._children_name_map["ipv4_range"] = "ipv4-range"

                                self.ipv6_range = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv6Range()
                                self.ipv6_range.parent = self
                                self._children_name_map["ipv6_range"] = "ipv6-range"

                                self.stub = None
                                self._children_name_map["stub"] = "stub"

                                self.filter_list = YList(self)
                                self.sham_link = YList(self)
                                self.virtual_link = YList(self)
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area, ['id', 'default_cost'], name, value)


                            class Authentication(Entity):
                                """
                                Enable authentication
                                
                                .. attribute:: message_digest
                                
                                	Use message\-digest authentication
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                    ])
                                    self.message_digest = None
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Authentication, ['message_digest'], name, value)


                            class Capability(Entity):
                                """
                                Enable area specific capability
                                
                                .. attribute:: default_exclusion
                                
                                	Enable exclusion of links from base topology
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Capability, self).__init__()

                                    self.yang_name = "capability"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('default_exclusion', (YLeaf(YType.empty, 'default-exclusion'), ['Empty'])),
                                    ])
                                    self.default_exclusion = None
                                    self._segment_path = lambda: "capability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Capability, ['default_exclusion'], name, value)


                            class FilterList(Entity):
                                """
                                Filter networks between OSPF areas
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`InOut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.FilterList.InOut>`
                                
                                .. attribute:: prefix
                                
                                	Filter prefixes between OSPF areas
                                	**type**\: str
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.FilterList, self).__init__()

                                    self.yang_name = "filter-list"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['in_out']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.FilterList.InOut')])),
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ])
                                    self.in_out = None
                                    self.prefix = None
                                    self._segment_path = lambda: "filter-list" + "[in-out='" + str(self.in_out) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.FilterList, ['in_out', 'prefix'], name, value)

                                class InOut(Enum):
                                    """
                                    InOut (Enum Class)

                                    .. data:: in_ = 0

                                    .. data:: out = 1

                                    """

                                    in_ = Enum.YLeaf(0, "in")

                                    out = Enum.YLeaf(1, "out")



                            class Nssa(Entity):
                                """
                                Specify a NSSA area
                                
                                .. attribute:: default_information_originate
                                
                                	Originate Type 7 default into NSSA area
                                	**type**\:  :py:class:`DefaultInformationOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_ext_capability
                                
                                	Do not send domain specific capabilities into NSSA
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_redistribution
                                
                                	No redistribution into this NSSA area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into NSSA
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit default advertisement to this NSSA area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: translate
                                
                                	Translate LSA
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.Translate>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa, self).__init__()

                                    self.yang_name = "nssa"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default-information-originate", ("default_information_originate", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate)), ("translate", ("translate", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.Translate))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                        ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                                        ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.no_ext_capability = None
                                    self.no_redistribution = None
                                    self.no_summary = None
                                    self.nssa_only = None

                                    self.default_information_originate = None
                                    self._children_name_map["default_information_originate"] = "default-information-originate"

                                    self.translate = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "nssa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa, ['no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                                class DefaultInformationOriginate(Entity):
                                    """
                                    Originate Type 7 default into NSSA area
                                    
                                    .. attribute:: metric
                                    
                                    	OSPF default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..16777214
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF metric type for default routes
                                    	**type**\: int
                                    
                                    	**range:** 1..2
                                    
                                    .. attribute:: no_ext_capability
                                    
                                    	Do not send domain specific capabilities into NSSA
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_redistribution
                                    
                                    	No redistribution into this NSSA area
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_summary
                                    
                                    	Do not send summary LSA into NSSA
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit default advertisement to this NSSA area
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: translate
                                    
                                    	Translate LSA
                                    	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate.Translate>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate, self).__init__()

                                        self.yang_name = "default-information-originate"
                                        self.yang_parent_name = "nssa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("translate", ("translate", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate.Translate))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.int32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.uint32, 'metric-type'), ['int'])),
                                            ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                            ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                                            ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.no_ext_capability = None
                                        self.no_redistribution = None
                                        self.no_summary = None
                                        self.nssa_only = None

                                        self.translate = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate.Translate()
                                        self.translate.parent = self
                                        self._children_name_map["translate"] = "translate"
                                        self._segment_path = lambda: "default-information-originate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate, ['metric', 'metric_type', 'no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                                    class Translate(Entity):
                                        """
                                        Translate LSA
                                        
                                        .. attribute:: type7
                                        
                                        	From Type 7 to Type 5
                                        	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate.Translate.Type7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate.Translate, self).__init__()

                                            self.yang_name = "translate"
                                            self.yang_parent_name = "default-information-originate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate.Translate.Type7))])
                                            self._leafs = OrderedDict()

                                            self.type7 = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate.Translate.Type7()
                                            self.type7.parent = self
                                            self._children_name_map["type7"] = "type7"
                                            self._segment_path = lambda: "translate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate.Translate, [], name, value)


                                        class Type7(Entity):
                                            """
                                            From Type 7 to Type 5
                                            
                                            .. attribute:: always
                                            
                                            	Always translate LSAs on this ABR
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: suppress_fa
                                            
                                            	Suppress forwarding address in translated LSAs
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate.Translate.Type7, self).__init__()

                                                self.yang_name = "type7"
                                                self.yang_parent_name = "translate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                                    ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                                ])
                                                self.always = None
                                                self.suppress_fa = None
                                                self._segment_path = lambda: "type7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.DefaultInformationOriginate.Translate.Type7, ['always', 'suppress_fa'], name, value)


                                class Translate(Entity):
                                    """
                                    Translate LSA
                                    
                                    .. attribute:: type7
                                    
                                    	From Type 7 to Type 5
                                    	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.Translate.Type7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "nssa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.Translate.Type7))])
                                        self._leafs = OrderedDict()

                                        self.type7 = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.Translate.Type7()
                                        self.type7.parent = self
                                        self._children_name_map["type7"] = "type7"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.Translate, [], name, value)


                                    class Type7(Entity):
                                        """
                                        From Type 7 to Type 5
                                        
                                        .. attribute:: always
                                        
                                        	Always translate LSAs on this ABR
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_fa
                                        
                                        	Suppress forwarding address in translated LSAs
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.Translate.Type7, self).__init__()

                                            self.yang_name = "type7"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                                ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                            ])
                                            self.always = None
                                            self.suppress_fa = None
                                            self._segment_path = lambda: "type7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Nssa.Translate.Type7, ['always', 'suppress_fa'], name, value)


                            class Ipv4Range(Entity):
                                """
                                
                                
                                .. attribute:: range
                                
                                	Summarize routes matching address/mask (border routers only)
                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv4Range.Range>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv4Range, self).__init__()

                                    self.yang_name = "ipv4-range"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv4Range.Range))])
                                    self._leafs = OrderedDict()

                                    self.range = YList(self)
                                    self._segment_path = lambda: "ipv4-range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv4Range, [], name, value)


                                class Range(Entity):
                                    """
                                    Summarize routes matching address/mask (border routers only)
                                    
                                    .. attribute:: ip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mask  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise this range (default)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: not_advertise
                                    
                                    	DoNotAdvertise this range
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: cost
                                    
                                    	User specified metric for this range
                                    	**type**\: int
                                    
                                    	**range:** 0..16777215
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv4Range.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "ipv4-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip','mask']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                            ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                            ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                        ])
                                        self.ip = None
                                        self.mask = None
                                        self.advertise = None
                                        self.not_advertise = None
                                        self.cost = None
                                        self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv4Range.Range, ['ip', 'mask', 'advertise', 'not_advertise', 'cost'], name, value)


                            class Ipv6Range(Entity):
                                """
                                
                                
                                .. attribute:: range
                                
                                	Summarize routes matching address/mask (border routers only)
                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv6Range.Range>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv6Range, self).__init__()

                                    self.yang_name = "ipv6-range"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv6Range.Range))])
                                    self._leafs = OrderedDict()

                                    self.range = YList(self)
                                    self._segment_path = lambda: "ipv6-range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv6Range, [], name, value)


                                class Range(Entity):
                                    """
                                    Summarize routes matching address/mask (border routers only)
                                    
                                    .. attribute:: ip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise this range (default)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: not_advertise
                                    
                                    	DoNotAdvertise this range
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: cost
                                    
                                    	User specified metric for this range
                                    	**type**\: int
                                    
                                    	**range:** 0..16777215
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv6Range.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "ipv6-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                            ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                            ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                        ])
                                        self.ip = None
                                        self.advertise = None
                                        self.not_advertise = None
                                        self.cost = None
                                        self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Ipv6Range.Range, ['ip', 'advertise', 'not_advertise', 'cost'], name, value)


                            class ShamLink(Entity):
                                """
                                Define a sham link and its parameters
                                
                                .. attribute:: source  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: dest  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: cost
                                
                                	Associate a cost with the sham\-link
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ttl_security
                                
                                	TTL security check
                                	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.ShamLink.TtlSecurity>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.ShamLink, self).__init__()

                                    self.yang_name = "sham-link"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['source','dest']
                                    self._child_classes = OrderedDict([("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.ShamLink.TtlSecurity))])
                                    self._leafs = OrderedDict([
                                        ('source', (YLeaf(YType.str, 'source'), ['str','str'])),
                                        ('dest', (YLeaf(YType.str, 'dest'), ['str','str'])),
                                        ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ])
                                    self.source = None
                                    self.dest = None
                                    self.cost = None

                                    self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.ShamLink.TtlSecurity()
                                    self.ttl_security.parent = self
                                    self._children_name_map["ttl_security"] = "ttl-security"
                                    self._segment_path = lambda: "sham-link" + "[source='" + str(self.source) + "']" + "[dest='" + str(self.dest) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.ShamLink, ['source', 'dest', 'cost'], name, value)


                                class TtlSecurity(Entity):
                                    """
                                    TTL security check
                                    
                                    .. attribute:: hops
                                    
                                    	IP hops
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.ShamLink.TtlSecurity, self).__init__()

                                        self.yang_name = "ttl-security"
                                        self.yang_parent_name = "sham-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                        ])
                                        self.hops = None
                                        self._segment_path = lambda: "ttl-security"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.ShamLink.TtlSecurity, ['hops'], name, value)


                            class Stub(Entity):
                                """
                                Specify a stub area
                                
                                .. attribute:: no_ext_capability
                                
                                	Do not send domain specific capabilities into stub area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into stub area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Stub, self).__init__()

                                    self.yang_name = "stub"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                        ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                    ])
                                    self.no_ext_capability = None
                                    self.no_summary = None
                                    self._segment_path = lambda: "stub"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.Stub, ['no_ext_capability', 'no_summary'], name, value)


                            class VirtualLink(Entity):
                                """
                                Define a virtual link and its parameters
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Set authentication type
                                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication>`
                                
                                .. attribute:: hello_interval
                                
                                	Hello packet interval
                                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.HelloInterval>`
                                
                                .. attribute:: dead_interval
                                
                                	Dead router detection time
                                	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.DeadInterval>`
                                
                                .. attribute:: retransmit_interval
                                
                                	LSA retransmit interval
                                	**type**\:  :py:class:`RetransmitInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.RetransmitInterval>`
                                
                                .. attribute:: transmit_delay
                                
                                	LSA transmission delay
                                	**type**\:  :py:class:`TransmitDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.TransmitDelay>`
                                
                                .. attribute:: topology
                                
                                	Disable virtual link on topology
                                	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Topology>`
                                
                                .. attribute:: ttl_security
                                
                                	TTL security check
                                	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.TtlSecurity>`
                                
                                .. attribute:: authentication_key
                                
                                	Set authentication key
                                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.AuthenticationKey>`
                                
                                .. attribute:: message_digest_key
                                
                                	Set message digest key
                                	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.MessageDigestKey>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink, self).__init__()

                                    self.yang_name = "virtual-link"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication)), ("hello-interval", ("hello_interval", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.HelloInterval)), ("dead-interval", ("dead_interval", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.DeadInterval)), ("retransmit-interval", ("retransmit_interval", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.RetransmitInterval)), ("transmit-delay", ("transmit_delay", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.TransmitDelay)), ("topology", ("topology", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Topology)), ("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.TtlSecurity)), ("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.MessageDigestKey))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                    ])
                                    self.id = None

                                    self.authentication = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"

                                    self.hello_interval = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.HelloInterval()
                                    self.hello_interval.parent = self
                                    self._children_name_map["hello_interval"] = "hello-interval"

                                    self.dead_interval = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.DeadInterval()
                                    self.dead_interval.parent = self
                                    self._children_name_map["dead_interval"] = "dead-interval"

                                    self.retransmit_interval = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.RetransmitInterval()
                                    self.retransmit_interval.parent = self
                                    self._children_name_map["retransmit_interval"] = "retransmit-interval"

                                    self.transmit_delay = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.TransmitDelay()
                                    self.transmit_delay.parent = self
                                    self._children_name_map["transmit_delay"] = "transmit-delay"

                                    self.topology = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Topology()
                                    self.topology.parent = self
                                    self._children_name_map["topology"] = "topology"

                                    self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.TtlSecurity()
                                    self.ttl_security.parent = self
                                    self._children_name_map["ttl_security"] = "ttl-security"

                                    self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.AuthenticationKey()
                                    self.authentication_key.parent = self
                                    self._children_name_map["authentication_key"] = "authentication-key"

                                    self.message_digest_key = YList(self)
                                    self._segment_path = lambda: "virtual-link" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink, ['id'], name, value)


                                class Authentication(Entity):
                                    """
                                    Set authentication type
                                    
                                    .. attribute:: authentication_key
                                    
                                    	Set authentication key
                                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.AuthenticationKey>`
                                    
                                    .. attribute:: message_digest_key
                                    
                                    	Set message digest key
                                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigestKey>`
                                    
                                    .. attribute:: key_chain
                                    
                                    	Use a key\-chain for cryptographic authentication keys
                                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain>`
                                    
                                    .. attribute:: message_digest
                                    
                                    	Message\-digest authentication
                                    	**type**\:  :py:class:`MessageDigest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest>`
                                    
                                    .. attribute:: null
                                    
                                    	No authentication
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigestKey)), ("key-chain", ("key_chain", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain)), ("message-digest", ("message_digest", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest))])
                                        self._leafs = OrderedDict([
                                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                        ])
                                        self.null = None

                                        self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.AuthenticationKey()
                                        self.authentication_key.parent = self
                                        self._children_name_map["authentication_key"] = "authentication-key"

                                        self.key_chain = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain()
                                        self.key_chain.parent = self
                                        self._children_name_map["key_chain"] = "key-chain"

                                        self.message_digest = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest()
                                        self.message_digest.parent = self
                                        self._children_name_map["message_digest"] = "message-digest"

                                        self.message_digest_key = YList(self)
                                        self._segment_path = lambda: "authentication"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication, ['null'], name, value)


                                    class AuthenticationKey(Entity):
                                        """
                                        Set authentication key
                                        
                                        .. attribute:: auth_type
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: auth_key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.AuthenticationKey, self).__init__()

                                            self.yang_name = "authentication-key"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                            ])
                                            self.auth_type = None
                                            self.auth_key = None
                                            self._segment_path = lambda: "authentication-key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                    class MessageDigestKey(Entity):
                                        """
                                        Set message digest key
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: md5
                                        
                                        	Use MD5 algorithm
                                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigestKey.Md5>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigestKey, self).__init__()

                                            self.yang_name = "message-digest-key"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigestKey.Md5))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigestKey.Md5()
                                            self.md5.parent = self
                                            self._children_name_map["md5"] = "md5"
                                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigestKey, ['id'], name, value)


                                        class Md5(Entity):
                                            """
                                            Use MD5 algorithm
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**length:** 1..16
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigestKey.Md5, self).__init__()

                                                self.yang_name = "md5"
                                                self.yang_parent_name = "message-digest-key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "md5"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                    class KeyChain(Entity):
                                        """
                                        Use a key\-chain for cryptographic authentication keys
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: authentication_key
                                        
                                        	Set authentication key
                                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey>`
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Set message digest key
                                        	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain, self).__init__()

                                            self.yang_name = "key-chain"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey()
                                            self.authentication_key.parent = self
                                            self._children_name_map["authentication_key"] = "authentication-key"

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "key-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain, ['name'], name, value)


                                        class AuthenticationKey(Entity):
                                            """
                                            Set authentication key
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, self).__init__()

                                                self.yang_name = "authentication-key"
                                                self.yang_parent_name = "key-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "authentication-key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Set message digest key
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: md5
                                            
                                            	Use MD5 algorithm
                                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "key-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5()
                                                self.md5.parent = self
                                                self._children_name_map["md5"] = "md5"
                                                self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, ['id'], name, value)


                                            class Md5(Entity):
                                                """
                                                Use MD5 algorithm
                                                
                                                .. attribute:: auth_type
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                .. attribute:: auth_key
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**length:** 1..16
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, self).__init__()

                                                    self.yang_name = "md5"
                                                    self.yang_parent_name = "message-digest-key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                    ])
                                                    self.auth_type = None
                                                    self.auth_key = None
                                                    self._segment_path = lambda: "md5"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                    class MessageDigest(Entity):
                                        """
                                        Message\-digest authentication
                                        
                                        .. attribute:: authentication_key
                                        
                                        	Set authentication key
                                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey>`
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Set message digest key
                                        	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest, self).__init__()

                                            self.yang_name = "message-digest"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey))])
                                            self._leafs = OrderedDict()

                                            self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey()
                                            self.authentication_key.parent = self
                                            self._children_name_map["authentication_key"] = "authentication-key"

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest, [], name, value)


                                        class AuthenticationKey(Entity):
                                            """
                                            Set authentication key
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, self).__init__()

                                                self.yang_name = "authentication-key"
                                                self.yang_parent_name = "message-digest"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "authentication-key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Set message digest key
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: md5
                                            
                                            	Use MD5 algorithm
                                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5()
                                                self.md5.parent = self
                                                self._children_name_map["md5"] = "md5"
                                                self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, ['id'], name, value)


                                            class Md5(Entity):
                                                """
                                                Use MD5 algorithm
                                                
                                                .. attribute:: auth_type
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                .. attribute:: auth_key
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**length:** 1..16
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, self).__init__()

                                                    self.yang_name = "md5"
                                                    self.yang_parent_name = "message-digest-key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                    ])
                                                    self.auth_type = None
                                                    self.auth_key = None
                                                    self._segment_path = lambda: "md5"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                class HelloInterval(Entity):
                                    """
                                    Hello packet interval
                                    
                                    .. attribute:: hello_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.HelloInterval, self).__init__()

                                        self.yang_name = "hello-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hello_interval_value', (YLeaf(YType.int32, 'hello-interval-value'), ['int'])),
                                        ])
                                        self.hello_interval_value = None
                                        self._segment_path = lambda: "hello-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.HelloInterval, ['hello_interval_value'], name, value)


                                class DeadInterval(Entity):
                                    """
                                    Dead router detection time
                                    
                                    .. attribute:: dead_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.DeadInterval, self).__init__()

                                        self.yang_name = "dead-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dead_interval_value', (YLeaf(YType.uint16, 'dead-interval-value'), ['int'])),
                                        ])
                                        self.dead_interval_value = None
                                        self._segment_path = lambda: "dead-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.DeadInterval, ['dead_interval_value'], name, value)


                                class RetransmitInterval(Entity):
                                    """
                                    LSA retransmit interval
                                    
                                    .. attribute:: retransmit_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.RetransmitInterval, self).__init__()

                                        self.yang_name = "retransmit-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('retransmit_interval_value', (YLeaf(YType.uint16, 'retransmit-interval-value'), ['int'])),
                                        ])
                                        self.retransmit_interval_value = None
                                        self._segment_path = lambda: "retransmit-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.RetransmitInterval, ['retransmit_interval_value'], name, value)


                                class TransmitDelay(Entity):
                                    """
                                    LSA transmission delay
                                    
                                    .. attribute:: transmit_delay_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.TransmitDelay, self).__init__()

                                        self.yang_name = "transmit-delay"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('transmit_delay_value', (YLeaf(YType.uint16, 'transmit-delay-value'), ['int'])),
                                        ])
                                        self.transmit_delay_value = None
                                        self._segment_path = lambda: "transmit-delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.TransmitDelay, ['transmit_delay_value'], name, value)


                                class Topology(Entity):
                                    """
                                    Disable virtual link on topology
                                    
                                    .. attribute:: disable
                                    
                                    	Disable virtual link
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Topology, self).__init__()

                                        self.yang_name = "topology"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ])
                                        self.disable = None
                                        self._segment_path = lambda: "topology"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.Topology, ['disable'], name, value)


                                class TtlSecurity(Entity):
                                    """
                                    TTL security check
                                    
                                    .. attribute:: hops
                                    
                                    	IP hops
                                    	**type**\: int
                                    
                                    	**range:** 1..254
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.TtlSecurity, self).__init__()

                                        self.yang_name = "ttl-security"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                        ])
                                        self.hops = None
                                        self._segment_path = lambda: "ttl-security"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.TtlSecurity, ['hops'], name, value)


                                class AuthenticationKey(Entity):
                                    """
                                    Set authentication key
                                    
                                    .. attribute:: auth_type
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: auth_key
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.AuthenticationKey, self).__init__()

                                        self.yang_name = "authentication-key"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                            ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                        ])
                                        self.auth_type = None
                                        self.auth_key = None
                                        self._segment_path = lambda: "authentication-key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                class MessageDigestKey(Entity):
                                    """
                                    Set message digest key
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: md5
                                    
                                    	Use MD5 algorithm
                                    	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.MessageDigestKey.Md5>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.MessageDigestKey, self).__init__()

                                        self.yang_name = "message-digest-key"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.MessageDigestKey.Md5))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.MessageDigestKey.Md5()
                                        self.md5.parent = self
                                        self._children_name_map["md5"] = "md5"
                                        self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.MessageDigestKey, ['id'], name, value)


                                    class Md5(Entity):
                                        """
                                        Use MD5 algorithm
                                        
                                        .. attribute:: auth_type
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: auth_key
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**length:** 1..16
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.MessageDigestKey.Md5, self).__init__()

                                            self.yang_name = "md5"
                                            self.yang_parent_name = "message-digest-key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                            ])
                                            self.auth_type = None
                                            self.auth_key = None
                                            self._segment_path = lambda: "md5"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Area.VirtualLink.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                        class AutoCost(Entity):
                            """
                            Calculate OSPF interface cost according to bandwidth
                            
                            .. attribute:: reference_bandwidth
                            
                            	Use reference bandwidth method to assign OSPF cost
                            	**type**\: int
                            
                            	**range:** 1..4294967
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.AutoCost, self).__init__()

                                self.yang_name = "auto-cost"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('reference_bandwidth', (YLeaf(YType.uint32, 'reference-bandwidth'), ['int'])),
                                ])
                                self.reference_bandwidth = None
                                self._segment_path = lambda: "auto-cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.AutoCost, ['reference_bandwidth'], name, value)


                        class EventLog(Entity):
                            """
                            OSPF Event Logging
                            
                            .. attribute:: one_shot
                            
                            	Disable Logging When Log Buffer Becomes Full
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: pause
                            
                            	Pause Event Logging
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: size
                            
                            	Maximum Number of Events Stored in the Event Log
                            	**type**\: int
                            
                            	**range:** 1..65534
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.EventLog, self).__init__()

                                self.yang_name = "event-log"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('one_shot', (YLeaf(YType.empty, 'one-shot'), ['Empty'])),
                                    ('pause', (YLeaf(YType.empty, 'pause'), ['Empty'])),
                                    ('size', (YLeaf(YType.uint32, 'size'), ['int'])),
                                ])
                                self.one_shot = None
                                self.pause = None
                                self.size = None
                                self._segment_path = lambda: "event-log"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.EventLog, ['one_shot', 'pause', 'size'], name, value)


                        class Bfd(Entity):
                            """
                            BFD configuration commands
                            
                            .. attribute:: all_interfaces
                            
                            	Enable BFD on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                                ])
                                self.all_interfaces = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Bfd, ['all_interfaces'], name, value)


                        class InterfaceId(Entity):
                            """
                            Source of the interface ID
                            
                            .. attribute:: snmp_if_index
                            
                            	SNMP MIB ifIndex
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.InterfaceId, self).__init__()

                                self.yang_name = "interface-id"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('snmp_if_index', (YLeaf(YType.empty, 'snmp-if-index'), ['Empty'])),
                                ])
                                self.snmp_if_index = None
                                self._segment_path = lambda: "interface-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.InterfaceId, ['snmp_if_index'], name, value)


                        class LogAdjacencyChanges(Entity):
                            """
                            Log changes in adjacency state
                            
                            .. attribute:: detail
                            
                            	Log all state changes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.LogAdjacencyChanges, self).__init__()

                                self.yang_name = "log-adjacency-changes"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('detail', (YLeaf(YType.empty, 'detail'), ['Empty'])),
                                ])
                                self.detail = None
                                self._segment_path = lambda: "log-adjacency-changes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.LogAdjacencyChanges, ['detail'], name, value)


                        class MaxLsa(Entity):
                            """
                            maximum number of LSAs OSPF process will receive
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967294
                            
                            .. attribute:: threshold_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: ignore_count
                            
                            	maximum number of times adjacencies can be suppressed
                            	**type**\: int
                            
                            	**range:** 1..65534
                            
                            .. attribute:: ignore_time
                            
                            	time during which all adjacencies are suppressed
                            	**type**\: int
                            
                            	**range:** 1..17895
                            
                            .. attribute:: reset_time
                            
                            	time after which ignore\-count is reset to zero
                            	**type**\: int
                            
                            	**range:** 2..35791
                            
                            .. attribute:: warning_only
                            
                            	Only give warning message when limit is exceeded
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxLsa, self).__init__()

                                self.yang_name = "max-lsa"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                    ('threshold_value', (YLeaf(YType.uint32, 'threshold-value'), ['int'])),
                                    ('ignore_count', (YLeaf(YType.uint32, 'ignore-count'), ['int'])),
                                    ('ignore_time', (YLeaf(YType.uint32, 'ignore-time'), ['int'])),
                                    ('reset_time', (YLeaf(YType.uint32, 'reset-time'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                ])
                                self.number = None
                                self.threshold_value = None
                                self.ignore_count = None
                                self.ignore_time = None
                                self.reset_time = None
                                self.warning_only = None
                                self._segment_path = lambda: "max-lsa"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxLsa, ['number', 'threshold_value', 'ignore_count', 'ignore_time', 'reset_time', 'warning_only'], name, value)


                        class MaxMetric(Entity):
                            """
                            Set maximum metric
                            
                            .. attribute:: router_lsa
                            
                            	Maximum metric in self\-originated router\-LSAs
                            	**type**\:  :py:class:`RouterLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric, self).__init__()

                                self.yang_name = "max-metric"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("router-lsa", ("router_lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa))])
                                self._leafs = OrderedDict()

                                self.router_lsa = None
                                self._children_name_map["router_lsa"] = "router-lsa"
                                self._segment_path = lambda: "max-metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric, [], name, value)


                            class RouterLsa(Entity):
                                """
                                Maximum metric in self\-originated router\-LSAs
                                
                                .. attribute:: external_lsa
                                
                                	Override external\-lsa metric with max\-metric value
                                	**type**\:  :py:class:`ExternalLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.ExternalLsa>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: include_stub
                                
                                	Set maximum metric for stub links in router\-LSAs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: on_startup
                                
                                	Set maximum metric temporarily after reboot
                                	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.OnStartup>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: summary_lsa
                                
                                	Override summary\-lsa metric with max\-metric value
                                	**type**\:  :py:class:`SummaryLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.SummaryLsa>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa, self).__init__()

                                    self.yang_name = "router-lsa"
                                    self.yang_parent_name = "max-metric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("external-lsa", ("external_lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.ExternalLsa)), ("on-startup", ("on_startup", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.OnStartup)), ("summary-lsa", ("summary_lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.SummaryLsa))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('include_stub', (YLeaf(YType.empty, 'include-stub'), ['Empty'])),
                                    ])
                                    self.include_stub = None

                                    self.external_lsa = None
                                    self._children_name_map["external_lsa"] = "external-lsa"

                                    self.on_startup = None
                                    self._children_name_map["on_startup"] = "on-startup"

                                    self.summary_lsa = None
                                    self._children_name_map["summary_lsa"] = "summary-lsa"
                                    self._segment_path = lambda: "router-lsa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa, ['include_stub'], name, value)


                                class ExternalLsa(Entity):
                                    """
                                    Override external\-lsa metric with max\-metric value
                                    
                                    .. attribute:: metric
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..16777215
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.ExternalLsa, self).__init__()

                                        self.yang_name = "external-lsa"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.metric = None
                                        self._segment_path = lambda: "external-lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.ExternalLsa, ['metric'], name, value)


                                class OnStartup(Entity):
                                    """
                                    Set maximum metric temporarily after reboot
                                    
                                    .. attribute:: time
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 5..86400
                                    
                                    .. attribute:: wait_for_bgp
                                    
                                    	Let BGP decide when to originate router\-LSA with normal metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.OnStartup, self).__init__()

                                        self.yang_name = "on-startup"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                            ('wait_for_bgp', (YLeaf(YType.empty, 'wait-for-bgp'), ['Empty'])),
                                        ])
                                        self.time = None
                                        self.wait_for_bgp = None
                                        self._segment_path = lambda: "on-startup"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.OnStartup, ['time', 'wait_for_bgp'], name, value)


                                class SummaryLsa(Entity):
                                    """
                                    Override summary\-lsa metric with max\-metric value
                                    
                                    .. attribute:: metric
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..16777215
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.SummaryLsa, self).__init__()

                                        self.yang_name = "summary-lsa"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.metric = None
                                        self._segment_path = lambda: "summary-lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.MaxMetric.RouterLsa.SummaryLsa, ['metric'], name, value)


                        class PassiveInterface(Entity):
                            """
                            Suppress routing updates on an interface
                            
                            .. attribute:: default
                            
                            	Suppress routing updates on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: interface
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.PassiveInterface, self).__init__()

                                self.yang_name = "passive-interface"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ])
                                self.default = None
                                self.interface = None
                                self._segment_path = lambda: "passive-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.PassiveInterface, [u'default', u'interface'], name, value)


                        class Disable(Entity):
                            """
                            
                            
                            .. attribute:: passive_interface
                            
                            	
                            	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Disable.PassiveInterface>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Disable, self).__init__()

                                self.yang_name = "disable"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Disable.PassiveInterface))])
                                self._leafs = OrderedDict()

                                self.passive_interface = YList(self)
                                self._segment_path = lambda: "disable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Disable, [], name, value)


                            class PassiveInterface(Entity):
                                """
                                
                                
                                .. attribute:: interface  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Disable.PassiveInterface, self).__init__()

                                    self.yang_name = "passive-interface"
                                    self.yang_parent_name = "disable"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ])
                                    self.interface = None
                                    self._segment_path = lambda: "passive-interface" + "[interface='" + str(self.interface) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Disable.PassiveInterface, [u'interface'], name, value)


                        class QueueDepth(Entity):
                            """
                            OSPF Hello/Router process queue depth
                            
                            .. attribute:: hello
                            
                            	OSPF Hello process queue depth
                            	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth.Hello>`
                            
                            .. attribute:: update
                            
                            	OSPF Router process queue depth
                            	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth.Update>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth, self).__init__()

                                self.yang_name = "queue-depth"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hello", ("hello", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth.Hello)), ("update", ("update", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth.Update))])
                                self._leafs = OrderedDict()

                                self.hello = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth.Hello()
                                self.hello.parent = self
                                self._children_name_map["hello"] = "hello"

                                self.update = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth.Update()
                                self.update.parent = self
                                self._children_name_map["update"] = "update"
                                self._segment_path = lambda: "queue-depth"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth, [], name, value)


                            class Hello(Entity):
                                """
                                OSPF Hello process queue depth
                                
                                .. attribute:: options
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..2147483647
                                
                                		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth.Hello, self).__init__()

                                    self.yang_name = "hello"
                                    self.yang_parent_name = "queue-depth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                                    ])
                                    self.options = None
                                    self._segment_path = lambda: "hello"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth.Hello, ['options'], name, value)

                                class Options(Enum):
                                    """
                                    Options (Enum Class)

                                    .. data:: unlimited = 0

                                    """

                                    unlimited = Enum.YLeaf(0, "unlimited")



                            class Update(Entity):
                                """
                                OSPF Router process queue depth
                                
                                .. attribute:: options
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..2147483647
                                
                                		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth.Update, self).__init__()

                                    self.yang_name = "update"
                                    self.yang_parent_name = "queue-depth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                                    ])
                                    self.options = None
                                    self._segment_path = lambda: "update"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.QueueDepth.Update, ['options'], name, value)

                                class Options(Enum):
                                    """
                                    Options (Enum Class)

                                    .. data:: unlimited = 0

                                    """

                                    unlimited = Enum.YLeaf(0, "unlimited")



                        class Timers(Entity):
                            """
                            Adjust routing timers
                            
                            .. attribute:: lsa
                            
                            	OSPF LSA timers
                            	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Lsa>`
                            
                            .. attribute:: pacing
                            
                            	OSPF pacing timers
                            	**type**\:  :py:class:`Pacing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Pacing>`
                            
                            .. attribute:: throttle
                            
                            	OSPF throttle timers
                            	**type**\:  :py:class:`Throttle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Lsa)), ("pacing", ("pacing", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Pacing)), ("throttle", ("throttle", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle))])
                                self._leafs = OrderedDict()

                                self.lsa = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Lsa()
                                self.lsa.parent = self
                                self._children_name_map["lsa"] = "lsa"

                                self.pacing = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Pacing()
                                self.pacing.parent = self
                                self._children_name_map["pacing"] = "pacing"

                                self.throttle = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle()
                                self.throttle.parent = self
                                self._children_name_map["throttle"] = "throttle"
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers, [], name, value)


                            class Lsa(Entity):
                                """
                                OSPF LSA timers
                                
                                .. attribute:: arrival
                                
                                	OSPF LSA arrival timer
                                	**type**\: int
                                
                                	**range:** 0..600000
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('arrival', (YLeaf(YType.uint32, 'arrival'), ['int'])),
                                    ])
                                    self.arrival = None
                                    self._segment_path = lambda: "lsa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Lsa, ['arrival'], name, value)


                            class Pacing(Entity):
                                """
                                OSPF pacing timers
                                
                                .. attribute:: flood
                                
                                	OSPF flood pacing timer
                                	**type**\: int
                                
                                	**range:** 5..100
                                
                                .. attribute:: lsa_group
                                
                                	OSPF LSA group pacing timer
                                	**type**\: int
                                
                                	**range:** 10..1800
                                
                                .. attribute:: retransmission
                                
                                	OSPF retransmission pacing timer
                                	**type**\: int
                                
                                	**range:** 5..200
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Pacing, self).__init__()

                                    self.yang_name = "pacing"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('flood', (YLeaf(YType.uint32, 'flood'), ['int'])),
                                        ('lsa_group', (YLeaf(YType.uint32, 'lsa-group'), ['int'])),
                                        ('retransmission', (YLeaf(YType.uint32, 'retransmission'), ['int'])),
                                    ])
                                    self.flood = None
                                    self.lsa_group = None
                                    self.retransmission = None
                                    self._segment_path = lambda: "pacing"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Pacing, ['flood', 'lsa_group', 'retransmission'], name, value)


                            class Throttle(Entity):
                                """
                                OSPF throttle timers
                                
                                .. attribute:: lsa
                                
                                	OSPF LSA throttle timers
                                	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Lsa>`
                                
                                .. attribute:: spf
                                
                                	OSPF SPF throttle timers
                                	**type**\:  :py:class:`Spf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Spf>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle, self).__init__()

                                    self.yang_name = "throttle"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Lsa)), ("spf", ("spf", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Spf))])
                                    self._leafs = OrderedDict()

                                    self.lsa = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Lsa()
                                    self.lsa.parent = self
                                    self._children_name_map["lsa"] = "lsa"

                                    self.spf = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Spf()
                                    self.spf.parent = self
                                    self._children_name_map["spf"] = "spf"
                                    self._segment_path = lambda: "throttle"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle, [], name, value)


                                class Lsa(Entity):
                                    """
                                    OSPF LSA throttle timers
                                    
                                    .. attribute:: all
                                    
                                    	For all type of OSPF LSAs
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Lsa.All>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "throttle"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Lsa.All))])
                                        self._leafs = OrderedDict()

                                        self.all = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Lsa.All()
                                        self.all.parent = self
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Lsa, [], name, value)


                                    class All(Entity):
                                        """
                                        For all type of OSPF LSAs
                                        
                                        .. attribute:: delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        .. attribute:: min_delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        .. attribute:: max_delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Lsa.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                                ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                            ])
                                            self.delay = None
                                            self.min_delay = None
                                            self.max_delay = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Lsa.All, ['delay', 'min_delay', 'max_delay'], name, value)


                                class Spf(Entity):
                                    """
                                    OSPF SPF throttle timers
                                    
                                    .. attribute:: delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    .. attribute:: min_delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    .. attribute:: max_delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Spf, self).__init__()

                                        self.yang_name = "spf"
                                        self.yang_parent_name = "throttle"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                            ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                            ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                        ])
                                        self.delay = None
                                        self.min_delay = None
                                        self.max_delay = None
                                        self._segment_path = lambda: "spf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Timers.Throttle.Spf, ['delay', 'min_delay', 'max_delay'], name, value)


                        class TrafficShare(Entity):
                            """
                            How to compute traffic share over alternate paths
                            
                            .. attribute:: min
                            
                            	All traffic shared among min metric paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: across_interfaces
                            
                            	Use different interfaces for equal\-cost paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.TrafficShare, self).__init__()

                                self.yang_name = "traffic-share"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                                ])
                                self.min = None
                                self.across_interfaces = None
                                self._segment_path = lambda: "traffic-share"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.TrafficShare, ['min', 'across_interfaces'], name, value)


                        class TtlSecurity(Entity):
                            """
                            TTL security check
                            
                            .. attribute:: all_interfaces
                            
                            	Enable TTL Security on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: hops
                            
                            	IP hops
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.TtlSecurity, self).__init__()

                                self.yang_name = "ttl-security"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                                    ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                ])
                                self.all_interfaces = None
                                self.hops = None
                                self._segment_path = lambda: "ttl-security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.TtlSecurity, ['all_interfaces', 'hops'], name, value)


                        class Capability(Entity):
                            """
                            Enable specific OSPF feature
                            
                            .. attribute:: capability_type
                            
                            	
                            	**type**\:  :py:class:`CapabilityType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Capability.CapabilityType>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('capability_type', (YLeaf(YType.enumeration, 'capability-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Capability.CapabilityType')])),
                                ])
                                self.capability_type = None
                                self._segment_path = lambda: "capability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Capability, ['capability_type'], name, value)

                            class CapabilityType(Enum):
                                """
                                CapabilityType (Enum Class)

                                .. data:: lls = 0

                                .. data:: opaque = 1

                                .. data:: transit = 2

                                .. data:: vrf_lite = 3

                                """

                                lls = Enum.YLeaf(0, "lls")

                                opaque = Enum.YLeaf(1, "opaque")

                                transit = Enum.YLeaf(2, "transit")

                                vrf_lite = Enum.YLeaf(3, "vrf-lite")



                        class Compatible(Entity):
                            """
                            OSPF compatibility list
                            
                            .. attribute:: rfc1583
                            
                            	Compatible with RFC 1583
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rfc1587
                            
                            	Compatible with RFC 1587
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rfc5243
                            
                            	Compatible with RFC 5243
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Compatible, self).__init__()

                                self.yang_name = "compatible"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rfc1583', (YLeaf(YType.empty, 'rfc1583'), ['Empty'])),
                                    ('rfc1587', (YLeaf(YType.empty, 'rfc1587'), ['Empty'])),
                                    ('rfc5243', (YLeaf(YType.empty, 'rfc5243'), ['Empty'])),
                                ])
                                self.rfc1583 = None
                                self.rfc1587 = None
                                self.rfc5243 = None
                                self._segment_path = lambda: "compatible"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Compatible, ['rfc1583', 'rfc1587', 'rfc5243'], name, value)


                        class DefaultInformation(Entity):
                            """
                            Control distribution of default information
                            
                            .. attribute:: originate
                            
                            	Distribute a default route
                            	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DefaultInformation.Originate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DefaultInformation, self).__init__()

                                self.yang_name = "default-information"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("originate", ("originate", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DefaultInformation.Originate))])
                                self._leafs = OrderedDict()

                                self.originate = None
                                self._children_name_map["originate"] = "originate"
                                self._segment_path = lambda: "default-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DefaultInformation, [], name, value)


                            class Originate(Entity):
                                """
                                Distribute a default route
                                
                                .. attribute:: always
                                
                                	Always advertise default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: metric
                                
                                	OSPF default metric
                                	**type**\: int
                                
                                	**range:** 0..16777214
                                
                                .. attribute:: metric_type
                                
                                	OSPF metric type for default routes
                                	**type**\: int
                                
                                	**range:** 1..2
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DefaultInformation.Originate, self).__init__()

                                    self.yang_name = "originate"
                                    self.yang_parent_name = "default-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.uint32, 'metric-type'), ['int'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.always = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "originate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DefaultInformation.Originate, ['always', 'metric', 'metric_type', 'route_map'], name, value)


                        class DiscardRoute(Entity):
                            """
                            Enable or disable discard\-route installation
                            
                            .. attribute:: external
                            
                            	Discard route for redistributed summarised routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: internal
                            
                            	Discard route for summarised internal routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: metric
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DiscardRoute, self).__init__()

                                self.yang_name = "discard-route"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ])
                                self.external = None
                                self.internal = None
                                self.metric = None
                                self._segment_path = lambda: "discard-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.DiscardRoute, ['external', 'internal', 'metric'], name, value)


                        class Distance(Entity):
                            """
                            Define an administrative distance
                            
                            .. attribute:: ospf_distance
                            
                            	
                            	**type**\:  :py:class:`OspfDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance.OspfDistance>`
                            
                            .. attribute:: ospf
                            
                            	OSPF routes Administrative distance
                            	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance.Ospf>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ospf-distance", ("ospf_distance", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance.OspfDistance)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance.Ospf))])
                                self._leafs = OrderedDict()

                                self.ospf_distance = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance.OspfDistance()
                                self.ospf_distance.parent = self
                                self._children_name_map["ospf_distance"] = "ospf-distance"

                                self.ospf = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance.Ospf()
                                self.ospf.parent = self
                                self._children_name_map["ospf"] = "ospf"
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance, [], name, value)


                            class OspfDistance(Entity):
                                """
                                
                                
                                .. attribute:: distance
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: ip
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: wildcard
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..99
                                
                                		**type**\: int
                                
                                			**range:** 1300..1999
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance.OspfDistance, self).__init__()

                                    self.yang_name = "ospf-distance"
                                    self.yang_parent_name = "distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                        ('wildcard', (YLeaf(YType.str, 'wildcard'), ['str'])),
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','int','str'])),
                                    ])
                                    self.distance = None
                                    self.ip = None
                                    self.wildcard = None
                                    self.acl_name = None
                                    self._segment_path = lambda: "ospf-distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance.OspfDistance, ['distance', 'ip', 'wildcard', 'acl_name'], name, value)


                            class Ospf(Entity):
                                """
                                OSPF routes Administrative distance
                                
                                .. attribute:: external
                                
                                	External routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: inter_area
                                
                                	Inter\-area routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: intra_area
                                
                                	Intra\-area routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('external', (YLeaf(YType.uint32, 'external'), ['int'])),
                                        ('inter_area', (YLeaf(YType.uint32, 'inter-area'), ['int'])),
                                        ('intra_area', (YLeaf(YType.uint32, 'intra-area'), ['int'])),
                                    ])
                                    self.external = None
                                    self.inter_area = None
                                    self.intra_area = None
                                    self._segment_path = lambda: "ospf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Distance.Ospf, ['external', 'inter_area', 'intra_area'], name, value)


                        class Redistribute(Entity):
                            """
                            Redistribute information from another routing protocol
                            
                            .. attribute:: application
                            
                            	Application
                            	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Application>`
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: iso_igrp
                            
                            	IGRP for OSI networks
                            	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: lisp
                            
                            	Locator ID Separation Protocol (LISP)
                            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp>`
                            
                            .. attribute:: mobile
                            
                            	Mobile routes
                            	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Mobile>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: odr
                            
                            	On Demand stub Routes
                            	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Odr>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Rip>`
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Static>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes redistributed to protocol
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.MaximumPrefix>`
                            
                            .. attribute:: vrf
                            
                            	Specify a source VRF
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute, self).__init__()

                                self.yang_name = "redistribute"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Static)), ("maximum-prefix", ("maximum_prefix", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.MaximumPrefix)), ("vrf", ("vrf", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf))])
                                self._leafs = OrderedDict()

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.isis = None
                                self._children_name_map["isis"] = "isis"

                                self.iso_igrp = None
                                self._children_name_map["iso_igrp"] = "iso-igrp"

                                self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp()
                                self.lisp.parent = self
                                self._children_name_map["lisp"] = "lisp"

                                self.mobile = None
                                self._children_name_map["mobile"] = "mobile"

                                self.odr = None
                                self._children_name_map["odr"] = "odr"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.maximum_prefix = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.vrf = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.application = YList(self)
                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self.rip = YList(self)
                                self._segment_path = lambda: "redistribute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute, [], name, value)


                            class Application(Entity):
                                """
                                Application
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Application.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Application, self).__init__()

                                    self.yang_name = "application"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Application.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Application.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Application, ['name'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Application.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Application.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "application"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Application.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                    ])
                                    self.as_number = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Bgp, ['as_number'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Connected, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                    ])
                                    self.as_number = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp, ['as_number'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: isis_level_routes
                                
                                	
                                	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisLevelRoutes>`
                                
                                .. attribute:: isis_area
                                
                                	
                                	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea>`
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisLevelRoutes')])),
                                    ])
                                    self.isis_level_routes = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"

                                    self.isis_area = YList(self)
                                    self._segment_path = lambda: "isis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis, ['isis_level_routes'], name, value)

                                class IsisLevelRoutes(Enum):
                                    """
                                    IsisLevelRoutes (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    .. data:: level_1_2 = 2

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")

                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class IsisArea(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: isis_level_routes
                                    
                                    	
                                    	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.IsisLevelRoutes>`
                                    
                                    .. attribute:: redist_options
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RedistOptions>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea, self).__init__()

                                        self.yang_name = "isis-area"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RedistOptions))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.IsisLevelRoutes')])),
                                        ])
                                        self.name = None
                                        self.isis_level_routes = None

                                        self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RedistOptions()
                                        self.redist_options.parent = self
                                        self._children_name_map["redist_options"] = "redist-options"
                                        self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                    class IsisLevelRoutes(Enum):
                                        """
                                        IsisLevelRoutes (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        .. data:: level_1_2 = 2

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")

                                        level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class RedistOptions(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RedistOptions.MetricType>`
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RedistOptions, self).__init__()

                                            self.yang_name = "redist-options"
                                            self.yang_parent_name = "isis-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RedistOptions.MetricType')])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.tag = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.nssa_only = None
                                            self._segment_path = lambda: "redist-options"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class IsoIgrp(Entity):
                                """
                                IGRP for OSI networks
                                
                                .. attribute:: area_tag_route_map_container
                                
                                	
                                	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.AreaTagRouteMapContainer>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: iso_igrp_container
                                
                                	
                                	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp, self).__init__()

                                    self.yang_name = "iso-igrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.AreaTagRouteMapContainer()
                                    self.area_tag_route_map_container.parent = self
                                    self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                    self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer()
                                    self.iso_igrp_container.parent = self
                                    self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                    self._segment_path = lambda: "iso-igrp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp, ['route_map'], name, value)


                                class AreaTagRouteMapContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: area_tag
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                        self.yang_name = "area-tag-route-map-container"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.area_tag = None
                                        self.route_map = None
                                        self._segment_path = lambda: "area-tag-route-map-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                class IsoIgrpContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer, self).__init__()

                                        self.yang_name = "iso-igrp-container"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self._segment_path = lambda: "iso-igrp-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Lisp(Entity):
                                """
                                Locator ID Separation Protocol (LISP)
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp, self).__init__()

                                    self.yang_name = "lisp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp.RedistOptions))])
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "lisp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "lisp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Mobile(Entity):
                                """
                                Mobile routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Mobile, self).__init__()

                                    self.yang_name = "mobile"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "mobile"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Mobile, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "mobile"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Odr(Entity):
                                """
                                On Demand stub Routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Odr, self).__init__()

                                    self.yang_name = "odr"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "odr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Odr, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "odr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match>`
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.MetricType>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.MetricType')])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.id = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.nssa_only = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.tag = None
                                    self.vrf = None

                                    self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.nssa_external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                            class Ospfv3_(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match>`
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.MetricType>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.MetricType')])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ])
                                    self.id = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.nssa_only = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.tag = None

                                    self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.Internal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.Internal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.External.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.External.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.NssaExternal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.nssa_external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: id  (key)
                                
                                	User selected string identifying this rip process
                                	**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Rip.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Rip.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Rip.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Rip, ['id'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Rip.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Rip.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Rip.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Static.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Static.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Static.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Static, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Static.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Static.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Static.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes redistributed to protocol
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: threshold_warning_only_container
                                
                                	
                                	**type**\:  :py:class:`ThresholdWarningOnlyContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("threshold-warning-only-container", ("threshold_warning_only_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                    ])
                                    self.number = None

                                    self.threshold_warning_only_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer()
                                    self.threshold_warning_only_container.parent = self
                                    self._children_name_map["threshold_warning_only_container"] = "threshold-warning-only-container"
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.MaximumPrefix, ['number'], name, value)


                                class ThresholdWarningOnlyContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer, self).__init__()

                                        self.yang_name = "threshold-warning-only-container"
                                        self.yang_parent_name = "maximum-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.threshold = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "threshold-warning-only-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer, ['threshold', 'warning_only'], name, value)


                            class Vrf(Entity):
                                """
                                Specify a source VRF
                                
                                .. attribute:: non_global_vrf
                                
                                	
                                	**type**\: list of  		 :py:class:`NonGlobalVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf>`
                                
                                .. attribute:: global_
                                
                                	global VRF
                                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("non-global-vrf", ("non_global_vrf", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf)), ("global", ("global_", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global))])
                                    self._leafs = OrderedDict()

                                    self.global_ = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"

                                    self.non_global_vrf = YList(self)
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf, [], name, value)


                                class NonGlobalVrf(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator ID Separation Protocol (LISP)
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf, self).__init__()

                                        self.yang_name = "non-global-vrf"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Static))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.iso_igrp = None
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp()
                                        self.lisp.parent = self
                                        self._children_name_map["lisp"] = "lisp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.application = YList(self)
                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "non-global-vrf" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf, ['name'], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Application, ['name'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_level_routes
                                        
                                        	
                                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisLevelRoutes>`
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea>`
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisLevelRoutes')])),
                                            ])
                                            self.isis_level_routes = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis, ['isis_level_routes'], name, value)

                                        class IsisLevelRoutes(Enum):
                                            """
                                            IsisLevelRoutes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: isis_level_routes
                                            
                                            	
                                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.IsisLevelRoutes>`
                                            
                                            .. attribute:: redist_options
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.IsisLevelRoutes')])),
                                                ])
                                                self.name = None
                                                self.isis_level_routes = None

                                                self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions()
                                                self.redist_options.parent = self
                                                self._children_name_map["redist_options"] = "redist-options"
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                            class IsisLevelRoutes(Enum):
                                                """
                                                IsisLevelRoutes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class RedistOptions(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions.MetricType>`
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions, self).__init__()

                                                    self.yang_name = "redist-options"
                                                    self.yang_parent_name = "isis-area"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions.MetricType')])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.tag = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.nssa_only = None
                                                    self._segment_path = lambda: "redist-options"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: area_tag_route_map_container
                                        
                                        	
                                        	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: iso_igrp_container
                                        
                                        	
                                        	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer()
                                            self.area_tag_route_map_container.parent = self
                                            self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                            self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer()
                                            self.iso_igrp_container.parent = self
                                            self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp, ['route_map'], name, value)


                                        class AreaTagRouteMapContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: area_tag
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                                self.yang_name = "area-tag-route-map-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.area_tag = None
                                                self.route_map = None
                                                self._segment_path = lambda: "area-tag-route-map-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                        class IsoIgrpContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer, self).__init__()

                                                self.yang_name = "iso-igrp-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self._segment_path = lambda: "iso-igrp-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Lisp(Entity):
                                        """
                                        Locator ID Separation Protocol (LISP)
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions))])
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "lisp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "mobile"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "odr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self.vrf = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Ospfv3_(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this rip process
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip, ['id'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Static, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                class Global(Entity):
                                    """
                                    global VRF
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator ID Separation Protocol (LISP)
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.iso_igrp = None
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp()
                                        self.lisp.parent = self
                                        self._children_name_map["lisp"] = "lisp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.application = YList(self)
                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "global"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Application.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Application.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Application.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Application, ['name'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Application.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Application.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Application.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Bgp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Connected, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Eigrp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_level_routes
                                        
                                        	
                                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisLevelRoutes>`
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea>`
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisLevelRoutes')])),
                                            ])
                                            self.isis_level_routes = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis, ['isis_level_routes'], name, value)

                                        class IsisLevelRoutes(Enum):
                                            """
                                            IsisLevelRoutes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: isis_level_routes
                                            
                                            	
                                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.IsisLevelRoutes>`
                                            
                                            .. attribute:: redist_options
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.IsisLevelRoutes')])),
                                                ])
                                                self.name = None
                                                self.isis_level_routes = None

                                                self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions()
                                                self.redist_options.parent = self
                                                self._children_name_map["redist_options"] = "redist-options"
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                            class IsisLevelRoutes(Enum):
                                                """
                                                IsisLevelRoutes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class RedistOptions(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions.MetricType>`
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions, self).__init__()

                                                    self.yang_name = "redist-options"
                                                    self.yang_parent_name = "isis-area"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions.MetricType')])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.tag = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.nssa_only = None
                                                    self._segment_path = lambda: "redist-options"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: area_tag_route_map_container
                                        
                                        	
                                        	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: iso_igrp_container
                                        
                                        	
                                        	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer()
                                            self.area_tag_route_map_container.parent = self
                                            self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                            self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer()
                                            self.iso_igrp_container.parent = self
                                            self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp, ['route_map'], name, value)


                                        class AreaTagRouteMapContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: area_tag
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                                self.yang_name = "area-tag-route-map-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.area_tag = None
                                                self.route_map = None
                                                self._segment_path = lambda: "area-tag-route-map-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                        class IsoIgrpContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer, self).__init__()

                                                self.yang_name = "iso-igrp-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self._segment_path = lambda: "iso-igrp-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Lisp(Entity):
                                        """
                                        Locator ID Separation Protocol (LISP)
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions))])
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "lisp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Mobile, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "mobile"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Odr, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "odr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self.vrf = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Ospfv3_(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this rip process
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Rip, ['id'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Static.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Static.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Static.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Static, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Static.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Static.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Static.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Redistribute.Vrf.Global.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                        class Authentication(Entity):
                            """
                            Authentication parameters
                            
                            .. attribute:: mode
                            
                            	Authentication operation mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Authentication.Mode>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Authentication.Mode')])),
                                ])
                                self.mode = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Authentication, [u'mode'], name, value)

                            class Mode(Enum):
                                """
                                Mode (Enum Class)

                                Authentication operation mode

                                .. data:: deployment = 0

                                .. data:: normal = 1

                                .. data:: strict = 2

                                """

                                deployment = Enum.YLeaf(0, "deployment")

                                normal = Enum.YLeaf(1, "normal")

                                strict = Enum.YLeaf(2, "strict")



                        class GracefulRestart(Entity):
                            """
                            Graceful\-restart options
                            
                            .. attribute:: disable
                            
                            	Graceful restart disable
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: helper
                            
                            	helper support
                            	**type**\:  :py:class:`Helper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.GracefulRestart.Helper>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: restart_interval
                            
                            	Graceful restart interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.GracefulRestart, self).__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("helper", ("helper", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.GracefulRestart.Helper))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('restart_interval', (YLeaf(YType.uint16, 'restart-interval'), ['int'])),
                                ])
                                self.disable = None
                                self.restart_interval = None

                                self.helper = None
                                self._children_name_map["helper"] = "helper"
                                self._segment_path = lambda: "graceful-restart"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.GracefulRestart, [u'disable', u'restart_interval'], name, value)


                            class Helper(Entity):
                                """
                                helper support
                                
                                .. attribute:: disable
                                
                                	disable helper support
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: strict_lsa_checking
                                
                                	enable helper strict LSA checking
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.GracefulRestart.Helper, self).__init__()

                                    self.yang_name = "helper"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ('strict_lsa_checking', (YLeaf(YType.empty, 'strict-lsa-checking'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self.strict_lsa_checking = None
                                    self._segment_path = lambda: "helper"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.GracefulRestart.Helper, [u'disable', u'strict_lsa_checking'], name, value)


                        class Manet(Entity):
                            """
                            Specify MANET OSPF parameters
                            
                            .. attribute:: cache
                            
                            	Specify MANET cache sizes
                            	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Cache>`
                            
                            .. attribute:: hello
                            
                            	Unicast Hellos rather than multicast
                            	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Hello>`
                            
                            .. attribute:: peering
                            
                            	MANET OSPF Smart Peering
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Peering>`
                            
                            .. attribute:: willingness
                            
                            	Specify Relay willingness value
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cache", ("cache", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Cache)), ("peering", ("peering", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Peering))])
                                self._leafs = OrderedDict([
                                    ('hello', (YLeaf(YType.enumeration, 'hello'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Hello')])),
                                    ('willingness', (YLeaf(YType.uint8, 'willingness'), ['int'])),
                                ])
                                self.hello = None
                                self.willingness = None

                                self.cache = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Cache()
                                self.cache.parent = self
                                self._children_name_map["cache"] = "cache"

                                self.peering = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet, [u'hello', u'willingness'], name, value)

                            class Hello(Enum):
                                """
                                Hello (Enum Class)

                                Unicast Hellos rather than multicast

                                .. data:: unicast = 0

                                .. data:: multicast = 1

                                """

                                unicast = Enum.YLeaf(0, "unicast")

                                multicast = Enum.YLeaf(1, "multicast")



                            class Cache(Entity):
                                """
                                Specify MANET cache sizes
                                
                                .. attribute:: acknowledgement
                                
                                	Specify MANET acknowledgement cache size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update
                                
                                	Specify MANET LSA cache size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Cache, self).__init__()

                                    self.yang_name = "cache"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acknowledgement', (YLeaf(YType.uint64, 'acknowledgement'), ['int'])),
                                        ('update', (YLeaf(YType.uint64, 'update'), ['int'])),
                                    ])
                                    self.acknowledgement = None
                                    self.update = None
                                    self._segment_path = lambda: "cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Cache, [u'acknowledgement', u'update'], name, value)


                            class Peering(Entity):
                                """
                                MANET OSPF Smart Peering
                                
                                .. attribute:: selective
                                
                                	Enable selective peering
                                	**type**\:  :py:class:`Selective <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Peering.Selective>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("selective", ("selective", Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Peering.Selective))])
                                    self._leafs = OrderedDict()

                                    self.selective = Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Peering.Selective()
                                    self.selective.parent = self
                                    self._children_name_map["selective"] = "selective"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Peering, [], name, value)


                                class Selective(Entity):
                                    """
                                    Enable selective peering
                                    
                                    .. attribute:: disable
                                    
                                    	Disable selective peering
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: per_interface
                                    
                                    	Select peers per interface rather than per node
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: redundancy
                                    
                                    	Redundant paths
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Peering.Selective, self).__init__()

                                        self.yang_name = "selective"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ('per_interface', (YLeaf(YType.empty, 'per-interface'), ['Empty'])),
                                            ('redundancy', (YLeaf(YType.uint8, 'redundancy'), ['int'])),
                                        ])
                                        self.disable = None
                                        self.per_interface = None
                                        self.redundancy = None
                                        self._segment_path = lambda: "selective"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.Manet.Peering.Selective, [u'disable', u'per_interface', u'redundancy'], name, value)


                        class SummaryPrefix(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            .. attribute:: nssa_only
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: tag
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: not_advertise
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.SummaryPrefix, self).__init__()

                                self.yang_name = "summary-prefix"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                ])
                                self.prefix = None
                                self.nssa_only = None
                                self.tag = None
                                self.not_advertise = None
                                self._segment_path = lambda: "summary-prefix" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Unicast.SummaryPrefix, [u'prefix', u'nssa_only', u'tag', u'not_advertise'], name, value)


                    class Vrf(Entity):
                        """
                        Specify parameters for a VPN Routing/Forwarding instance
                        
                        .. attribute:: vrf  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: area
                        
                        	OSPF area parameters
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area>`
                        
                        .. attribute:: auto_cost
                        
                        	Calculate OSPF interface cost according to bandwidth
                        	**type**\:  :py:class:`AutoCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.AutoCost>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: event_log
                        
                        	OSPF Event Logging
                        	**type**\:  :py:class:`EventLog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.EventLog>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: bfd
                        
                        	BFD configuration commands
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Bfd>`
                        
                        .. attribute:: interface_id
                        
                        	Source of the interface ID
                        	**type**\:  :py:class:`InterfaceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.InterfaceId>`
                        
                        .. attribute:: log_adjacency_changes
                        
                        	Log changes in adjacency state
                        	**type**\:  :py:class:`LogAdjacencyChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.LogAdjacencyChanges>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: max_lsa
                        
                        	maximum number of LSAs OSPF process will receive
                        	**type**\:  :py:class:`MaxLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxLsa>`
                        
                        .. attribute:: max_metric
                        
                        	Set maximum metric
                        	**type**\:  :py:class:`MaxMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric>`
                        
                        .. attribute:: passive_interface
                        
                        	Suppress routing updates on an interface
                        	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.PassiveInterface>`
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Disable>`
                        
                        .. attribute:: queue_depth
                        
                        	OSPF Hello/Router process queue depth
                        	**type**\:  :py:class:`QueueDepth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth>`
                        
                        .. attribute:: timers
                        
                        	Adjust routing timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers>`
                        
                        .. attribute:: router_id
                        
                        	Override configured router identifier (peers will reset)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nsr
                        
                        	Enable non\-stop routing
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: traffic_share
                        
                        	How to compute traffic share over alternate paths
                        	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.TrafficShare>`
                        
                        .. attribute:: ttl_security
                        
                        	TTL security check
                        	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.TtlSecurity>`
                        
                        .. attribute:: capability
                        
                        	Enable specific OSPF feature
                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Capability>`
                        
                        .. attribute:: compatible
                        
                        	OSPF compatibility list
                        	**type**\:  :py:class:`Compatible <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Compatible>`
                        
                        .. attribute:: default_information
                        
                        	Control distribution of default information
                        	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DefaultInformation>`
                        
                        .. attribute:: default_metric
                        
                        	Set metric of redistributed routes
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: discard_route
                        
                        	Enable or disable discard\-route installation
                        	**type**\:  :py:class:`DiscardRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DiscardRoute>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: distance
                        
                        	Define an administrative distance
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance>`
                        
                        .. attribute:: maximum_paths
                        
                        	Forward packets over multiple paths
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: redistribute
                        
                        	Redistribute information from another routing protocol
                        	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute>`
                        
                        .. attribute:: authentication
                        
                        	Authentication parameters
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Authentication>`
                        
                        .. attribute:: graceful_restart
                        
                        	Graceful\-restart options
                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.GracefulRestart>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF parameters
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet>`
                        
                        .. attribute:: summary_prefix
                        
                        	
                        	**type**\: list of  		 :py:class:`SummaryPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.SummaryPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['vrf']
                            self._child_classes = OrderedDict([("area", ("area", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area)), ("auto-cost", ("auto_cost", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.AutoCost)), ("event-log", ("event_log", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.EventLog)), ("bfd", ("bfd", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Bfd)), ("interface-id", ("interface_id", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.InterfaceId)), ("log-adjacency-changes", ("log_adjacency_changes", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.LogAdjacencyChanges)), ("max-lsa", ("max_lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxLsa)), ("max-metric", ("max_metric", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric)), ("passive-interface", ("passive_interface", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.PassiveInterface)), ("disable", ("disable", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Disable)), ("queue-depth", ("queue_depth", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth)), ("timers", ("timers", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers)), ("traffic-share", ("traffic_share", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.TrafficShare)), ("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.TtlSecurity)), ("capability", ("capability", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Capability)), ("compatible", ("compatible", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Compatible)), ("default-information", ("default_information", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DefaultInformation)), ("discard-route", ("discard_route", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DiscardRoute)), ("distance", ("distance", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance)), ("redistribute", ("redistribute", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute)), ("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Authentication)), ("graceful-restart", ("graceful_restart", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.GracefulRestart)), ("manet", ("manet", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet)), ("summary-prefix", ("summary_prefix", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.SummaryPrefix))])
                            self._leafs = OrderedDict([
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('nsr', (YLeaf(YType.empty, 'nsr'), ['Empty'])),
                                ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                            ])
                            self.vrf = None
                            self.unicast = None
                            self.router_id = None
                            self.nsr = None
                            self.default_metric = None
                            self.maximum_paths = None

                            self.auto_cost = None
                            self._children_name_map["auto_cost"] = "auto-cost"

                            self.event_log = None
                            self._children_name_map["event_log"] = "event-log"

                            self.bfd = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Bfd()
                            self.bfd.parent = self
                            self._children_name_map["bfd"] = "bfd"

                            self.interface_id = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.InterfaceId()
                            self.interface_id.parent = self
                            self._children_name_map["interface_id"] = "interface-id"

                            self.log_adjacency_changes = None
                            self._children_name_map["log_adjacency_changes"] = "log-adjacency-changes"

                            self.max_lsa = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxLsa()
                            self.max_lsa.parent = self
                            self._children_name_map["max_lsa"] = "max-lsa"

                            self.max_metric = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric()
                            self.max_metric.parent = self
                            self._children_name_map["max_metric"] = "max-metric"

                            self.passive_interface = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.PassiveInterface()
                            self.passive_interface.parent = self
                            self._children_name_map["passive_interface"] = "passive-interface"

                            self.disable = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Disable()
                            self.disable.parent = self
                            self._children_name_map["disable"] = "disable"

                            self.queue_depth = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth()
                            self.queue_depth.parent = self
                            self._children_name_map["queue_depth"] = "queue-depth"

                            self.timers = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"

                            self.traffic_share = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.TrafficShare()
                            self.traffic_share.parent = self
                            self._children_name_map["traffic_share"] = "traffic-share"

                            self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.TtlSecurity()
                            self.ttl_security.parent = self
                            self._children_name_map["ttl_security"] = "ttl-security"

                            self.capability = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Capability()
                            self.capability.parent = self
                            self._children_name_map["capability"] = "capability"

                            self.compatible = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Compatible()
                            self.compatible.parent = self
                            self._children_name_map["compatible"] = "compatible"

                            self.default_information = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DefaultInformation()
                            self.default_information.parent = self
                            self._children_name_map["default_information"] = "default-information"

                            self.discard_route = None
                            self._children_name_map["discard_route"] = "discard-route"

                            self.distance = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.redistribute = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute()
                            self.redistribute.parent = self
                            self._children_name_map["redistribute"] = "redistribute"

                            self.authentication = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.graceful_restart = None
                            self._children_name_map["graceful_restart"] = "graceful-restart"

                            self.manet = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.area = YList(self)
                            self.summary_prefix = YList(self)
                            self._segment_path = lambda: "vrf" + "[vrf='" + str(self.vrf) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf, [u'vrf', u'unicast', 'router_id', 'nsr', 'default_metric', 'maximum_paths'], name, value)


                        class Area(Entity):
                            """
                            OSPF area parameters
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: authentication
                            
                            	Enable authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Authentication>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: capability
                            
                            	Enable area specific capability
                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Capability>`
                            
                            .. attribute:: default_cost
                            
                            	Set the summary default\-cost of a NSSA/stub area
                            	**type**\: int
                            
                            	**range:** 0..16777215
                            
                            .. attribute:: filter_list
                            
                            	Filter networks between OSPF areas
                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.FilterList>`
                            
                            .. attribute:: nssa
                            
                            	Specify a NSSA area
                            	**type**\:  :py:class:`Nssa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ipv4_range
                            
                            	
                            	**type**\:  :py:class:`Ipv4Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv4Range>`
                            
                            .. attribute:: ipv6_range
                            
                            	
                            	**type**\:  :py:class:`Ipv6Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv6Range>`
                            
                            .. attribute:: sham_link
                            
                            	Define a sham link and its parameters
                            	**type**\: list of  		 :py:class:`ShamLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.ShamLink>`
                            
                            .. attribute:: stub
                            
                            	Specify a stub area
                            	**type**\:  :py:class:`Stub <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Stub>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: virtual_link
                            
                            	Define a virtual link and its parameters
                            	**type**\: list of  		 :py:class:`VirtualLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Authentication)), ("capability", ("capability", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Capability)), ("filter-list", ("filter_list", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.FilterList)), ("nssa", ("nssa", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa)), ("ipv4-range", ("ipv4_range", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv4Range)), ("ipv6-range", ("ipv6_range", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv6Range)), ("sham-link", ("sham_link", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.ShamLink)), ("stub", ("stub", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Stub)), ("virtual-link", ("virtual_link", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('default_cost', (YLeaf(YType.uint32, 'default-cost'), ['int'])),
                                ])
                                self.id = None
                                self.default_cost = None

                                self.authentication = None
                                self._children_name_map["authentication"] = "authentication"

                                self.capability = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Capability()
                                self.capability.parent = self
                                self._children_name_map["capability"] = "capability"

                                self.nssa = None
                                self._children_name_map["nssa"] = "nssa"

                                self.ipv4_range = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv4Range()
                                self.ipv4_range.parent = self
                                self._children_name_map["ipv4_range"] = "ipv4-range"

                                self.ipv6_range = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv6Range()
                                self.ipv6_range.parent = self
                                self._children_name_map["ipv6_range"] = "ipv6-range"

                                self.stub = None
                                self._children_name_map["stub"] = "stub"

                                self.filter_list = YList(self)
                                self.sham_link = YList(self)
                                self.virtual_link = YList(self)
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area, ['id', 'default_cost'], name, value)


                            class Authentication(Entity):
                                """
                                Enable authentication
                                
                                .. attribute:: message_digest
                                
                                	Use message\-digest authentication
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                    ])
                                    self.message_digest = None
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Authentication, ['message_digest'], name, value)


                            class Capability(Entity):
                                """
                                Enable area specific capability
                                
                                .. attribute:: default_exclusion
                                
                                	Enable exclusion of links from base topology
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Capability, self).__init__()

                                    self.yang_name = "capability"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('default_exclusion', (YLeaf(YType.empty, 'default-exclusion'), ['Empty'])),
                                    ])
                                    self.default_exclusion = None
                                    self._segment_path = lambda: "capability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Capability, ['default_exclusion'], name, value)


                            class FilterList(Entity):
                                """
                                Filter networks between OSPF areas
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`InOut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.FilterList.InOut>`
                                
                                .. attribute:: prefix
                                
                                	Filter prefixes between OSPF areas
                                	**type**\: str
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.FilterList, self).__init__()

                                    self.yang_name = "filter-list"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['in_out']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.FilterList.InOut')])),
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ])
                                    self.in_out = None
                                    self.prefix = None
                                    self._segment_path = lambda: "filter-list" + "[in-out='" + str(self.in_out) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.FilterList, ['in_out', 'prefix'], name, value)

                                class InOut(Enum):
                                    """
                                    InOut (Enum Class)

                                    .. data:: in_ = 0

                                    .. data:: out = 1

                                    """

                                    in_ = Enum.YLeaf(0, "in")

                                    out = Enum.YLeaf(1, "out")



                            class Nssa(Entity):
                                """
                                Specify a NSSA area
                                
                                .. attribute:: default_information_originate
                                
                                	Originate Type 7 default into NSSA area
                                	**type**\:  :py:class:`DefaultInformationOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_ext_capability
                                
                                	Do not send domain specific capabilities into NSSA
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_redistribution
                                
                                	No redistribution into this NSSA area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into NSSA
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit default advertisement to this NSSA area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: translate
                                
                                	Translate LSA
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.Translate>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa, self).__init__()

                                    self.yang_name = "nssa"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default-information-originate", ("default_information_originate", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate)), ("translate", ("translate", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.Translate))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                        ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                                        ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.no_ext_capability = None
                                    self.no_redistribution = None
                                    self.no_summary = None
                                    self.nssa_only = None

                                    self.default_information_originate = None
                                    self._children_name_map["default_information_originate"] = "default-information-originate"

                                    self.translate = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "nssa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa, ['no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                                class DefaultInformationOriginate(Entity):
                                    """
                                    Originate Type 7 default into NSSA area
                                    
                                    .. attribute:: metric
                                    
                                    	OSPF default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..16777214
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF metric type for default routes
                                    	**type**\: int
                                    
                                    	**range:** 1..2
                                    
                                    .. attribute:: no_ext_capability
                                    
                                    	Do not send domain specific capabilities into NSSA
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_redistribution
                                    
                                    	No redistribution into this NSSA area
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_summary
                                    
                                    	Do not send summary LSA into NSSA
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit default advertisement to this NSSA area
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: translate
                                    
                                    	Translate LSA
                                    	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate.Translate>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate, self).__init__()

                                        self.yang_name = "default-information-originate"
                                        self.yang_parent_name = "nssa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("translate", ("translate", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate.Translate))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.int32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.uint32, 'metric-type'), ['int'])),
                                            ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                            ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                                            ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.no_ext_capability = None
                                        self.no_redistribution = None
                                        self.no_summary = None
                                        self.nssa_only = None

                                        self.translate = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate.Translate()
                                        self.translate.parent = self
                                        self._children_name_map["translate"] = "translate"
                                        self._segment_path = lambda: "default-information-originate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate, ['metric', 'metric_type', 'no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                                    class Translate(Entity):
                                        """
                                        Translate LSA
                                        
                                        .. attribute:: type7
                                        
                                        	From Type 7 to Type 5
                                        	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate.Translate.Type7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate.Translate, self).__init__()

                                            self.yang_name = "translate"
                                            self.yang_parent_name = "default-information-originate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate.Translate.Type7))])
                                            self._leafs = OrderedDict()

                                            self.type7 = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate.Translate.Type7()
                                            self.type7.parent = self
                                            self._children_name_map["type7"] = "type7"
                                            self._segment_path = lambda: "translate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate.Translate, [], name, value)


                                        class Type7(Entity):
                                            """
                                            From Type 7 to Type 5
                                            
                                            .. attribute:: always
                                            
                                            	Always translate LSAs on this ABR
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: suppress_fa
                                            
                                            	Suppress forwarding address in translated LSAs
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate.Translate.Type7, self).__init__()

                                                self.yang_name = "type7"
                                                self.yang_parent_name = "translate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                                    ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                                ])
                                                self.always = None
                                                self.suppress_fa = None
                                                self._segment_path = lambda: "type7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.DefaultInformationOriginate.Translate.Type7, ['always', 'suppress_fa'], name, value)


                                class Translate(Entity):
                                    """
                                    Translate LSA
                                    
                                    .. attribute:: type7
                                    
                                    	From Type 7 to Type 5
                                    	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.Translate.Type7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "nssa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.Translate.Type7))])
                                        self._leafs = OrderedDict()

                                        self.type7 = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.Translate.Type7()
                                        self.type7.parent = self
                                        self._children_name_map["type7"] = "type7"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.Translate, [], name, value)


                                    class Type7(Entity):
                                        """
                                        From Type 7 to Type 5
                                        
                                        .. attribute:: always
                                        
                                        	Always translate LSAs on this ABR
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_fa
                                        
                                        	Suppress forwarding address in translated LSAs
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.Translate.Type7, self).__init__()

                                            self.yang_name = "type7"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                                ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                            ])
                                            self.always = None
                                            self.suppress_fa = None
                                            self._segment_path = lambda: "type7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Nssa.Translate.Type7, ['always', 'suppress_fa'], name, value)


                            class Ipv4Range(Entity):
                                """
                                
                                
                                .. attribute:: range
                                
                                	Summarize routes matching address/mask (border routers only)
                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv4Range.Range>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv4Range, self).__init__()

                                    self.yang_name = "ipv4-range"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv4Range.Range))])
                                    self._leafs = OrderedDict()

                                    self.range = YList(self)
                                    self._segment_path = lambda: "ipv4-range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv4Range, [], name, value)


                                class Range(Entity):
                                    """
                                    Summarize routes matching address/mask (border routers only)
                                    
                                    .. attribute:: ip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mask  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise this range (default)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: not_advertise
                                    
                                    	DoNotAdvertise this range
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: cost
                                    
                                    	User specified metric for this range
                                    	**type**\: int
                                    
                                    	**range:** 0..16777215
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv4Range.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "ipv4-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip','mask']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                            ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                            ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                        ])
                                        self.ip = None
                                        self.mask = None
                                        self.advertise = None
                                        self.not_advertise = None
                                        self.cost = None
                                        self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv4Range.Range, ['ip', 'mask', 'advertise', 'not_advertise', 'cost'], name, value)


                            class Ipv6Range(Entity):
                                """
                                
                                
                                .. attribute:: range
                                
                                	Summarize routes matching address/mask (border routers only)
                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv6Range.Range>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv6Range, self).__init__()

                                    self.yang_name = "ipv6-range"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv6Range.Range))])
                                    self._leafs = OrderedDict()

                                    self.range = YList(self)
                                    self._segment_path = lambda: "ipv6-range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv6Range, [], name, value)


                                class Range(Entity):
                                    """
                                    Summarize routes matching address/mask (border routers only)
                                    
                                    .. attribute:: ip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise this range (default)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: not_advertise
                                    
                                    	DoNotAdvertise this range
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: cost
                                    
                                    	User specified metric for this range
                                    	**type**\: int
                                    
                                    	**range:** 0..16777215
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv6Range.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "ipv6-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                            ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                            ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                        ])
                                        self.ip = None
                                        self.advertise = None
                                        self.not_advertise = None
                                        self.cost = None
                                        self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Ipv6Range.Range, ['ip', 'advertise', 'not_advertise', 'cost'], name, value)


                            class ShamLink(Entity):
                                """
                                Define a sham link and its parameters
                                
                                .. attribute:: source  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: dest  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: cost
                                
                                	Associate a cost with the sham\-link
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ttl_security
                                
                                	TTL security check
                                	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.ShamLink.TtlSecurity>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.ShamLink, self).__init__()

                                    self.yang_name = "sham-link"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['source','dest']
                                    self._child_classes = OrderedDict([("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.ShamLink.TtlSecurity))])
                                    self._leafs = OrderedDict([
                                        ('source', (YLeaf(YType.str, 'source'), ['str','str'])),
                                        ('dest', (YLeaf(YType.str, 'dest'), ['str','str'])),
                                        ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ])
                                    self.source = None
                                    self.dest = None
                                    self.cost = None

                                    self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.ShamLink.TtlSecurity()
                                    self.ttl_security.parent = self
                                    self._children_name_map["ttl_security"] = "ttl-security"
                                    self._segment_path = lambda: "sham-link" + "[source='" + str(self.source) + "']" + "[dest='" + str(self.dest) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.ShamLink, ['source', 'dest', 'cost'], name, value)


                                class TtlSecurity(Entity):
                                    """
                                    TTL security check
                                    
                                    .. attribute:: hops
                                    
                                    	IP hops
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.ShamLink.TtlSecurity, self).__init__()

                                        self.yang_name = "ttl-security"
                                        self.yang_parent_name = "sham-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                        ])
                                        self.hops = None
                                        self._segment_path = lambda: "ttl-security"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.ShamLink.TtlSecurity, ['hops'], name, value)


                            class Stub(Entity):
                                """
                                Specify a stub area
                                
                                .. attribute:: no_ext_capability
                                
                                	Do not send domain specific capabilities into stub area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into stub area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Stub, self).__init__()

                                    self.yang_name = "stub"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                        ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                    ])
                                    self.no_ext_capability = None
                                    self.no_summary = None
                                    self._segment_path = lambda: "stub"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.Stub, ['no_ext_capability', 'no_summary'], name, value)


                            class VirtualLink(Entity):
                                """
                                Define a virtual link and its parameters
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Set authentication type
                                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication>`
                                
                                .. attribute:: hello_interval
                                
                                	Hello packet interval
                                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.HelloInterval>`
                                
                                .. attribute:: dead_interval
                                
                                	Dead router detection time
                                	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.DeadInterval>`
                                
                                .. attribute:: retransmit_interval
                                
                                	LSA retransmit interval
                                	**type**\:  :py:class:`RetransmitInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.RetransmitInterval>`
                                
                                .. attribute:: transmit_delay
                                
                                	LSA transmission delay
                                	**type**\:  :py:class:`TransmitDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.TransmitDelay>`
                                
                                .. attribute:: topology
                                
                                	Disable virtual link on topology
                                	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Topology>`
                                
                                .. attribute:: ttl_security
                                
                                	TTL security check
                                	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.TtlSecurity>`
                                
                                .. attribute:: authentication_key
                                
                                	Set authentication key
                                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.AuthenticationKey>`
                                
                                .. attribute:: message_digest_key
                                
                                	Set message digest key
                                	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.MessageDigestKey>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink, self).__init__()

                                    self.yang_name = "virtual-link"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication)), ("hello-interval", ("hello_interval", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.HelloInterval)), ("dead-interval", ("dead_interval", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.DeadInterval)), ("retransmit-interval", ("retransmit_interval", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.RetransmitInterval)), ("transmit-delay", ("transmit_delay", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.TransmitDelay)), ("topology", ("topology", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Topology)), ("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.TtlSecurity)), ("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.MessageDigestKey))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                    ])
                                    self.id = None

                                    self.authentication = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"

                                    self.hello_interval = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.HelloInterval()
                                    self.hello_interval.parent = self
                                    self._children_name_map["hello_interval"] = "hello-interval"

                                    self.dead_interval = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.DeadInterval()
                                    self.dead_interval.parent = self
                                    self._children_name_map["dead_interval"] = "dead-interval"

                                    self.retransmit_interval = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.RetransmitInterval()
                                    self.retransmit_interval.parent = self
                                    self._children_name_map["retransmit_interval"] = "retransmit-interval"

                                    self.transmit_delay = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.TransmitDelay()
                                    self.transmit_delay.parent = self
                                    self._children_name_map["transmit_delay"] = "transmit-delay"

                                    self.topology = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Topology()
                                    self.topology.parent = self
                                    self._children_name_map["topology"] = "topology"

                                    self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.TtlSecurity()
                                    self.ttl_security.parent = self
                                    self._children_name_map["ttl_security"] = "ttl-security"

                                    self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.AuthenticationKey()
                                    self.authentication_key.parent = self
                                    self._children_name_map["authentication_key"] = "authentication-key"

                                    self.message_digest_key = YList(self)
                                    self._segment_path = lambda: "virtual-link" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink, ['id'], name, value)


                                class Authentication(Entity):
                                    """
                                    Set authentication type
                                    
                                    .. attribute:: authentication_key
                                    
                                    	Set authentication key
                                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.AuthenticationKey>`
                                    
                                    .. attribute:: message_digest_key
                                    
                                    	Set message digest key
                                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigestKey>`
                                    
                                    .. attribute:: key_chain
                                    
                                    	Use a key\-chain for cryptographic authentication keys
                                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain>`
                                    
                                    .. attribute:: message_digest
                                    
                                    	Message\-digest authentication
                                    	**type**\:  :py:class:`MessageDigest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest>`
                                    
                                    .. attribute:: null
                                    
                                    	No authentication
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigestKey)), ("key-chain", ("key_chain", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain)), ("message-digest", ("message_digest", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest))])
                                        self._leafs = OrderedDict([
                                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                        ])
                                        self.null = None

                                        self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.AuthenticationKey()
                                        self.authentication_key.parent = self
                                        self._children_name_map["authentication_key"] = "authentication-key"

                                        self.key_chain = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain()
                                        self.key_chain.parent = self
                                        self._children_name_map["key_chain"] = "key-chain"

                                        self.message_digest = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest()
                                        self.message_digest.parent = self
                                        self._children_name_map["message_digest"] = "message-digest"

                                        self.message_digest_key = YList(self)
                                        self._segment_path = lambda: "authentication"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication, ['null'], name, value)


                                    class AuthenticationKey(Entity):
                                        """
                                        Set authentication key
                                        
                                        .. attribute:: auth_type
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: auth_key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.AuthenticationKey, self).__init__()

                                            self.yang_name = "authentication-key"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                            ])
                                            self.auth_type = None
                                            self.auth_key = None
                                            self._segment_path = lambda: "authentication-key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                    class MessageDigestKey(Entity):
                                        """
                                        Set message digest key
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: md5
                                        
                                        	Use MD5 algorithm
                                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigestKey.Md5>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigestKey, self).__init__()

                                            self.yang_name = "message-digest-key"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigestKey.Md5))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigestKey.Md5()
                                            self.md5.parent = self
                                            self._children_name_map["md5"] = "md5"
                                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigestKey, ['id'], name, value)


                                        class Md5(Entity):
                                            """
                                            Use MD5 algorithm
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**length:** 1..16
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigestKey.Md5, self).__init__()

                                                self.yang_name = "md5"
                                                self.yang_parent_name = "message-digest-key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "md5"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                    class KeyChain(Entity):
                                        """
                                        Use a key\-chain for cryptographic authentication keys
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: authentication_key
                                        
                                        	Set authentication key
                                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey>`
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Set message digest key
                                        	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain, self).__init__()

                                            self.yang_name = "key-chain"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey()
                                            self.authentication_key.parent = self
                                            self._children_name_map["authentication_key"] = "authentication-key"

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "key-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain, ['name'], name, value)


                                        class AuthenticationKey(Entity):
                                            """
                                            Set authentication key
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, self).__init__()

                                                self.yang_name = "authentication-key"
                                                self.yang_parent_name = "key-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "authentication-key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Set message digest key
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: md5
                                            
                                            	Use MD5 algorithm
                                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "key-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5()
                                                self.md5.parent = self
                                                self._children_name_map["md5"] = "md5"
                                                self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, ['id'], name, value)


                                            class Md5(Entity):
                                                """
                                                Use MD5 algorithm
                                                
                                                .. attribute:: auth_type
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                .. attribute:: auth_key
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**length:** 1..16
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, self).__init__()

                                                    self.yang_name = "md5"
                                                    self.yang_parent_name = "message-digest-key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                    ])
                                                    self.auth_type = None
                                                    self.auth_key = None
                                                    self._segment_path = lambda: "md5"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                    class MessageDigest(Entity):
                                        """
                                        Message\-digest authentication
                                        
                                        .. attribute:: authentication_key
                                        
                                        	Set authentication key
                                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey>`
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Set message digest key
                                        	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest, self).__init__()

                                            self.yang_name = "message-digest"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey))])
                                            self._leafs = OrderedDict()

                                            self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey()
                                            self.authentication_key.parent = self
                                            self._children_name_map["authentication_key"] = "authentication-key"

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest, [], name, value)


                                        class AuthenticationKey(Entity):
                                            """
                                            Set authentication key
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, self).__init__()

                                                self.yang_name = "authentication-key"
                                                self.yang_parent_name = "message-digest"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "authentication-key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Set message digest key
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: md5
                                            
                                            	Use MD5 algorithm
                                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5()
                                                self.md5.parent = self
                                                self._children_name_map["md5"] = "md5"
                                                self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, ['id'], name, value)


                                            class Md5(Entity):
                                                """
                                                Use MD5 algorithm
                                                
                                                .. attribute:: auth_type
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                .. attribute:: auth_key
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**length:** 1..16
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, self).__init__()

                                                    self.yang_name = "md5"
                                                    self.yang_parent_name = "message-digest-key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                    ])
                                                    self.auth_type = None
                                                    self.auth_key = None
                                                    self._segment_path = lambda: "md5"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                class HelloInterval(Entity):
                                    """
                                    Hello packet interval
                                    
                                    .. attribute:: hello_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.HelloInterval, self).__init__()

                                        self.yang_name = "hello-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hello_interval_value', (YLeaf(YType.int32, 'hello-interval-value'), ['int'])),
                                        ])
                                        self.hello_interval_value = None
                                        self._segment_path = lambda: "hello-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.HelloInterval, ['hello_interval_value'], name, value)


                                class DeadInterval(Entity):
                                    """
                                    Dead router detection time
                                    
                                    .. attribute:: dead_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.DeadInterval, self).__init__()

                                        self.yang_name = "dead-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dead_interval_value', (YLeaf(YType.uint16, 'dead-interval-value'), ['int'])),
                                        ])
                                        self.dead_interval_value = None
                                        self._segment_path = lambda: "dead-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.DeadInterval, ['dead_interval_value'], name, value)


                                class RetransmitInterval(Entity):
                                    """
                                    LSA retransmit interval
                                    
                                    .. attribute:: retransmit_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.RetransmitInterval, self).__init__()

                                        self.yang_name = "retransmit-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('retransmit_interval_value', (YLeaf(YType.uint16, 'retransmit-interval-value'), ['int'])),
                                        ])
                                        self.retransmit_interval_value = None
                                        self._segment_path = lambda: "retransmit-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.RetransmitInterval, ['retransmit_interval_value'], name, value)


                                class TransmitDelay(Entity):
                                    """
                                    LSA transmission delay
                                    
                                    .. attribute:: transmit_delay_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.TransmitDelay, self).__init__()

                                        self.yang_name = "transmit-delay"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('transmit_delay_value', (YLeaf(YType.uint16, 'transmit-delay-value'), ['int'])),
                                        ])
                                        self.transmit_delay_value = None
                                        self._segment_path = lambda: "transmit-delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.TransmitDelay, ['transmit_delay_value'], name, value)


                                class Topology(Entity):
                                    """
                                    Disable virtual link on topology
                                    
                                    .. attribute:: disable
                                    
                                    	Disable virtual link
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Topology, self).__init__()

                                        self.yang_name = "topology"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ])
                                        self.disable = None
                                        self._segment_path = lambda: "topology"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.Topology, ['disable'], name, value)


                                class TtlSecurity(Entity):
                                    """
                                    TTL security check
                                    
                                    .. attribute:: hops
                                    
                                    	IP hops
                                    	**type**\: int
                                    
                                    	**range:** 1..254
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.TtlSecurity, self).__init__()

                                        self.yang_name = "ttl-security"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                        ])
                                        self.hops = None
                                        self._segment_path = lambda: "ttl-security"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.TtlSecurity, ['hops'], name, value)


                                class AuthenticationKey(Entity):
                                    """
                                    Set authentication key
                                    
                                    .. attribute:: auth_type
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: auth_key
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.AuthenticationKey, self).__init__()

                                        self.yang_name = "authentication-key"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                            ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                        ])
                                        self.auth_type = None
                                        self.auth_key = None
                                        self._segment_path = lambda: "authentication-key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                class MessageDigestKey(Entity):
                                    """
                                    Set message digest key
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: md5
                                    
                                    	Use MD5 algorithm
                                    	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.MessageDigestKey.Md5>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.MessageDigestKey, self).__init__()

                                        self.yang_name = "message-digest-key"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.MessageDigestKey.Md5))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.MessageDigestKey.Md5()
                                        self.md5.parent = self
                                        self._children_name_map["md5"] = "md5"
                                        self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.MessageDigestKey, ['id'], name, value)


                                    class Md5(Entity):
                                        """
                                        Use MD5 algorithm
                                        
                                        .. attribute:: auth_type
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: auth_key
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**length:** 1..16
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.MessageDigestKey.Md5, self).__init__()

                                            self.yang_name = "md5"
                                            self.yang_parent_name = "message-digest-key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                            ])
                                            self.auth_type = None
                                            self.auth_key = None
                                            self._segment_path = lambda: "md5"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Area.VirtualLink.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                        class AutoCost(Entity):
                            """
                            Calculate OSPF interface cost according to bandwidth
                            
                            .. attribute:: reference_bandwidth
                            
                            	Use reference bandwidth method to assign OSPF cost
                            	**type**\: int
                            
                            	**range:** 1..4294967
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.AutoCost, self).__init__()

                                self.yang_name = "auto-cost"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('reference_bandwidth', (YLeaf(YType.uint32, 'reference-bandwidth'), ['int'])),
                                ])
                                self.reference_bandwidth = None
                                self._segment_path = lambda: "auto-cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.AutoCost, ['reference_bandwidth'], name, value)


                        class EventLog(Entity):
                            """
                            OSPF Event Logging
                            
                            .. attribute:: one_shot
                            
                            	Disable Logging When Log Buffer Becomes Full
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: pause
                            
                            	Pause Event Logging
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: size
                            
                            	Maximum Number of Events Stored in the Event Log
                            	**type**\: int
                            
                            	**range:** 1..65534
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.EventLog, self).__init__()

                                self.yang_name = "event-log"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('one_shot', (YLeaf(YType.empty, 'one-shot'), ['Empty'])),
                                    ('pause', (YLeaf(YType.empty, 'pause'), ['Empty'])),
                                    ('size', (YLeaf(YType.uint32, 'size'), ['int'])),
                                ])
                                self.one_shot = None
                                self.pause = None
                                self.size = None
                                self._segment_path = lambda: "event-log"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.EventLog, ['one_shot', 'pause', 'size'], name, value)


                        class Bfd(Entity):
                            """
                            BFD configuration commands
                            
                            .. attribute:: all_interfaces
                            
                            	Enable BFD on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                                ])
                                self.all_interfaces = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Bfd, ['all_interfaces'], name, value)


                        class InterfaceId(Entity):
                            """
                            Source of the interface ID
                            
                            .. attribute:: snmp_if_index
                            
                            	SNMP MIB ifIndex
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.InterfaceId, self).__init__()

                                self.yang_name = "interface-id"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('snmp_if_index', (YLeaf(YType.empty, 'snmp-if-index'), ['Empty'])),
                                ])
                                self.snmp_if_index = None
                                self._segment_path = lambda: "interface-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.InterfaceId, ['snmp_if_index'], name, value)


                        class LogAdjacencyChanges(Entity):
                            """
                            Log changes in adjacency state
                            
                            .. attribute:: detail
                            
                            	Log all state changes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.LogAdjacencyChanges, self).__init__()

                                self.yang_name = "log-adjacency-changes"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('detail', (YLeaf(YType.empty, 'detail'), ['Empty'])),
                                ])
                                self.detail = None
                                self._segment_path = lambda: "log-adjacency-changes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.LogAdjacencyChanges, ['detail'], name, value)


                        class MaxLsa(Entity):
                            """
                            maximum number of LSAs OSPF process will receive
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967294
                            
                            .. attribute:: threshold_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: ignore_count
                            
                            	maximum number of times adjacencies can be suppressed
                            	**type**\: int
                            
                            	**range:** 1..65534
                            
                            .. attribute:: ignore_time
                            
                            	time during which all adjacencies are suppressed
                            	**type**\: int
                            
                            	**range:** 1..17895
                            
                            .. attribute:: reset_time
                            
                            	time after which ignore\-count is reset to zero
                            	**type**\: int
                            
                            	**range:** 2..35791
                            
                            .. attribute:: warning_only
                            
                            	Only give warning message when limit is exceeded
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxLsa, self).__init__()

                                self.yang_name = "max-lsa"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                    ('threshold_value', (YLeaf(YType.uint32, 'threshold-value'), ['int'])),
                                    ('ignore_count', (YLeaf(YType.uint32, 'ignore-count'), ['int'])),
                                    ('ignore_time', (YLeaf(YType.uint32, 'ignore-time'), ['int'])),
                                    ('reset_time', (YLeaf(YType.uint32, 'reset-time'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                ])
                                self.number = None
                                self.threshold_value = None
                                self.ignore_count = None
                                self.ignore_time = None
                                self.reset_time = None
                                self.warning_only = None
                                self._segment_path = lambda: "max-lsa"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxLsa, ['number', 'threshold_value', 'ignore_count', 'ignore_time', 'reset_time', 'warning_only'], name, value)


                        class MaxMetric(Entity):
                            """
                            Set maximum metric
                            
                            .. attribute:: router_lsa
                            
                            	Maximum metric in self\-originated router\-LSAs
                            	**type**\:  :py:class:`RouterLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric, self).__init__()

                                self.yang_name = "max-metric"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("router-lsa", ("router_lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa))])
                                self._leafs = OrderedDict()

                                self.router_lsa = None
                                self._children_name_map["router_lsa"] = "router-lsa"
                                self._segment_path = lambda: "max-metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric, [], name, value)


                            class RouterLsa(Entity):
                                """
                                Maximum metric in self\-originated router\-LSAs
                                
                                .. attribute:: external_lsa
                                
                                	Override external\-lsa metric with max\-metric value
                                	**type**\:  :py:class:`ExternalLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.ExternalLsa>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: include_stub
                                
                                	Set maximum metric for stub links in router\-LSAs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: on_startup
                                
                                	Set maximum metric temporarily after reboot
                                	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.OnStartup>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: summary_lsa
                                
                                	Override summary\-lsa metric with max\-metric value
                                	**type**\:  :py:class:`SummaryLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.SummaryLsa>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa, self).__init__()

                                    self.yang_name = "router-lsa"
                                    self.yang_parent_name = "max-metric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("external-lsa", ("external_lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.ExternalLsa)), ("on-startup", ("on_startup", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.OnStartup)), ("summary-lsa", ("summary_lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.SummaryLsa))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('include_stub', (YLeaf(YType.empty, 'include-stub'), ['Empty'])),
                                    ])
                                    self.include_stub = None

                                    self.external_lsa = None
                                    self._children_name_map["external_lsa"] = "external-lsa"

                                    self.on_startup = None
                                    self._children_name_map["on_startup"] = "on-startup"

                                    self.summary_lsa = None
                                    self._children_name_map["summary_lsa"] = "summary-lsa"
                                    self._segment_path = lambda: "router-lsa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa, ['include_stub'], name, value)


                                class ExternalLsa(Entity):
                                    """
                                    Override external\-lsa metric with max\-metric value
                                    
                                    .. attribute:: metric
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..16777215
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.ExternalLsa, self).__init__()

                                        self.yang_name = "external-lsa"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.metric = None
                                        self._segment_path = lambda: "external-lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.ExternalLsa, ['metric'], name, value)


                                class OnStartup(Entity):
                                    """
                                    Set maximum metric temporarily after reboot
                                    
                                    .. attribute:: time
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 5..86400
                                    
                                    .. attribute:: wait_for_bgp
                                    
                                    	Let BGP decide when to originate router\-LSA with normal metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.OnStartup, self).__init__()

                                        self.yang_name = "on-startup"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                            ('wait_for_bgp', (YLeaf(YType.empty, 'wait-for-bgp'), ['Empty'])),
                                        ])
                                        self.time = None
                                        self.wait_for_bgp = None
                                        self._segment_path = lambda: "on-startup"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.OnStartup, ['time', 'wait_for_bgp'], name, value)


                                class SummaryLsa(Entity):
                                    """
                                    Override summary\-lsa metric with max\-metric value
                                    
                                    .. attribute:: metric
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..16777215
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.SummaryLsa, self).__init__()

                                        self.yang_name = "summary-lsa"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.metric = None
                                        self._segment_path = lambda: "summary-lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.MaxMetric.RouterLsa.SummaryLsa, ['metric'], name, value)


                        class PassiveInterface(Entity):
                            """
                            Suppress routing updates on an interface
                            
                            .. attribute:: default
                            
                            	Suppress routing updates on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: interface
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.PassiveInterface, self).__init__()

                                self.yang_name = "passive-interface"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ])
                                self.default = None
                                self.interface = None
                                self._segment_path = lambda: "passive-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.PassiveInterface, [u'default', u'interface'], name, value)


                        class Disable(Entity):
                            """
                            
                            
                            .. attribute:: passive_interface
                            
                            	
                            	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Disable.PassiveInterface>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Disable, self).__init__()

                                self.yang_name = "disable"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Disable.PassiveInterface))])
                                self._leafs = OrderedDict()

                                self.passive_interface = YList(self)
                                self._segment_path = lambda: "disable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Disable, [], name, value)


                            class PassiveInterface(Entity):
                                """
                                
                                
                                .. attribute:: interface  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Disable.PassiveInterface, self).__init__()

                                    self.yang_name = "passive-interface"
                                    self.yang_parent_name = "disable"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ])
                                    self.interface = None
                                    self._segment_path = lambda: "passive-interface" + "[interface='" + str(self.interface) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Disable.PassiveInterface, [u'interface'], name, value)


                        class QueueDepth(Entity):
                            """
                            OSPF Hello/Router process queue depth
                            
                            .. attribute:: hello
                            
                            	OSPF Hello process queue depth
                            	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth.Hello>`
                            
                            .. attribute:: update
                            
                            	OSPF Router process queue depth
                            	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth.Update>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth, self).__init__()

                                self.yang_name = "queue-depth"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hello", ("hello", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth.Hello)), ("update", ("update", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth.Update))])
                                self._leafs = OrderedDict()

                                self.hello = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth.Hello()
                                self.hello.parent = self
                                self._children_name_map["hello"] = "hello"

                                self.update = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth.Update()
                                self.update.parent = self
                                self._children_name_map["update"] = "update"
                                self._segment_path = lambda: "queue-depth"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth, [], name, value)


                            class Hello(Entity):
                                """
                                OSPF Hello process queue depth
                                
                                .. attribute:: options
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..2147483647
                                
                                		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth.Hello, self).__init__()

                                    self.yang_name = "hello"
                                    self.yang_parent_name = "queue-depth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                                    ])
                                    self.options = None
                                    self._segment_path = lambda: "hello"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth.Hello, ['options'], name, value)

                                class Options(Enum):
                                    """
                                    Options (Enum Class)

                                    .. data:: unlimited = 0

                                    """

                                    unlimited = Enum.YLeaf(0, "unlimited")



                            class Update(Entity):
                                """
                                OSPF Router process queue depth
                                
                                .. attribute:: options
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..2147483647
                                
                                		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth.Update, self).__init__()

                                    self.yang_name = "update"
                                    self.yang_parent_name = "queue-depth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                                    ])
                                    self.options = None
                                    self._segment_path = lambda: "update"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.QueueDepth.Update, ['options'], name, value)

                                class Options(Enum):
                                    """
                                    Options (Enum Class)

                                    .. data:: unlimited = 0

                                    """

                                    unlimited = Enum.YLeaf(0, "unlimited")



                        class Timers(Entity):
                            """
                            Adjust routing timers
                            
                            .. attribute:: lsa
                            
                            	OSPF LSA timers
                            	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Lsa>`
                            
                            .. attribute:: pacing
                            
                            	OSPF pacing timers
                            	**type**\:  :py:class:`Pacing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Pacing>`
                            
                            .. attribute:: throttle
                            
                            	OSPF throttle timers
                            	**type**\:  :py:class:`Throttle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Lsa)), ("pacing", ("pacing", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Pacing)), ("throttle", ("throttle", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle))])
                                self._leafs = OrderedDict()

                                self.lsa = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Lsa()
                                self.lsa.parent = self
                                self._children_name_map["lsa"] = "lsa"

                                self.pacing = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Pacing()
                                self.pacing.parent = self
                                self._children_name_map["pacing"] = "pacing"

                                self.throttle = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle()
                                self.throttle.parent = self
                                self._children_name_map["throttle"] = "throttle"
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers, [], name, value)


                            class Lsa(Entity):
                                """
                                OSPF LSA timers
                                
                                .. attribute:: arrival
                                
                                	OSPF LSA arrival timer
                                	**type**\: int
                                
                                	**range:** 0..600000
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('arrival', (YLeaf(YType.uint32, 'arrival'), ['int'])),
                                    ])
                                    self.arrival = None
                                    self._segment_path = lambda: "lsa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Lsa, ['arrival'], name, value)


                            class Pacing(Entity):
                                """
                                OSPF pacing timers
                                
                                .. attribute:: flood
                                
                                	OSPF flood pacing timer
                                	**type**\: int
                                
                                	**range:** 5..100
                                
                                .. attribute:: lsa_group
                                
                                	OSPF LSA group pacing timer
                                	**type**\: int
                                
                                	**range:** 10..1800
                                
                                .. attribute:: retransmission
                                
                                	OSPF retransmission pacing timer
                                	**type**\: int
                                
                                	**range:** 5..200
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Pacing, self).__init__()

                                    self.yang_name = "pacing"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('flood', (YLeaf(YType.uint32, 'flood'), ['int'])),
                                        ('lsa_group', (YLeaf(YType.uint32, 'lsa-group'), ['int'])),
                                        ('retransmission', (YLeaf(YType.uint32, 'retransmission'), ['int'])),
                                    ])
                                    self.flood = None
                                    self.lsa_group = None
                                    self.retransmission = None
                                    self._segment_path = lambda: "pacing"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Pacing, ['flood', 'lsa_group', 'retransmission'], name, value)


                            class Throttle(Entity):
                                """
                                OSPF throttle timers
                                
                                .. attribute:: lsa
                                
                                	OSPF LSA throttle timers
                                	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Lsa>`
                                
                                .. attribute:: spf
                                
                                	OSPF SPF throttle timers
                                	**type**\:  :py:class:`Spf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Spf>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle, self).__init__()

                                    self.yang_name = "throttle"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Lsa)), ("spf", ("spf", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Spf))])
                                    self._leafs = OrderedDict()

                                    self.lsa = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Lsa()
                                    self.lsa.parent = self
                                    self._children_name_map["lsa"] = "lsa"

                                    self.spf = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Spf()
                                    self.spf.parent = self
                                    self._children_name_map["spf"] = "spf"
                                    self._segment_path = lambda: "throttle"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle, [], name, value)


                                class Lsa(Entity):
                                    """
                                    OSPF LSA throttle timers
                                    
                                    .. attribute:: all
                                    
                                    	For all type of OSPF LSAs
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Lsa.All>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "throttle"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Lsa.All))])
                                        self._leafs = OrderedDict()

                                        self.all = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Lsa.All()
                                        self.all.parent = self
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Lsa, [], name, value)


                                    class All(Entity):
                                        """
                                        For all type of OSPF LSAs
                                        
                                        .. attribute:: delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        .. attribute:: min_delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        .. attribute:: max_delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Lsa.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                                ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                            ])
                                            self.delay = None
                                            self.min_delay = None
                                            self.max_delay = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Lsa.All, ['delay', 'min_delay', 'max_delay'], name, value)


                                class Spf(Entity):
                                    """
                                    OSPF SPF throttle timers
                                    
                                    .. attribute:: delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    .. attribute:: min_delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    .. attribute:: max_delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Spf, self).__init__()

                                        self.yang_name = "spf"
                                        self.yang_parent_name = "throttle"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                            ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                            ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                        ])
                                        self.delay = None
                                        self.min_delay = None
                                        self.max_delay = None
                                        self._segment_path = lambda: "spf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Timers.Throttle.Spf, ['delay', 'min_delay', 'max_delay'], name, value)


                        class TrafficShare(Entity):
                            """
                            How to compute traffic share over alternate paths
                            
                            .. attribute:: min
                            
                            	All traffic shared among min metric paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: across_interfaces
                            
                            	Use different interfaces for equal\-cost paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.TrafficShare, self).__init__()

                                self.yang_name = "traffic-share"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                                ])
                                self.min = None
                                self.across_interfaces = None
                                self._segment_path = lambda: "traffic-share"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.TrafficShare, ['min', 'across_interfaces'], name, value)


                        class TtlSecurity(Entity):
                            """
                            TTL security check
                            
                            .. attribute:: all_interfaces
                            
                            	Enable TTL Security on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: hops
                            
                            	IP hops
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.TtlSecurity, self).__init__()

                                self.yang_name = "ttl-security"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                                    ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                ])
                                self.all_interfaces = None
                                self.hops = None
                                self._segment_path = lambda: "ttl-security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.TtlSecurity, ['all_interfaces', 'hops'], name, value)


                        class Capability(Entity):
                            """
                            Enable specific OSPF feature
                            
                            .. attribute:: capability_type
                            
                            	
                            	**type**\:  :py:class:`CapabilityType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Capability.CapabilityType>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('capability_type', (YLeaf(YType.enumeration, 'capability-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Capability.CapabilityType')])),
                                ])
                                self.capability_type = None
                                self._segment_path = lambda: "capability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Capability, ['capability_type'], name, value)

                            class CapabilityType(Enum):
                                """
                                CapabilityType (Enum Class)

                                .. data:: lls = 0

                                .. data:: opaque = 1

                                .. data:: transit = 2

                                .. data:: vrf_lite = 3

                                """

                                lls = Enum.YLeaf(0, "lls")

                                opaque = Enum.YLeaf(1, "opaque")

                                transit = Enum.YLeaf(2, "transit")

                                vrf_lite = Enum.YLeaf(3, "vrf-lite")



                        class Compatible(Entity):
                            """
                            OSPF compatibility list
                            
                            .. attribute:: rfc1583
                            
                            	Compatible with RFC 1583
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rfc1587
                            
                            	Compatible with RFC 1587
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rfc5243
                            
                            	Compatible with RFC 5243
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Compatible, self).__init__()

                                self.yang_name = "compatible"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rfc1583', (YLeaf(YType.empty, 'rfc1583'), ['Empty'])),
                                    ('rfc1587', (YLeaf(YType.empty, 'rfc1587'), ['Empty'])),
                                    ('rfc5243', (YLeaf(YType.empty, 'rfc5243'), ['Empty'])),
                                ])
                                self.rfc1583 = None
                                self.rfc1587 = None
                                self.rfc5243 = None
                                self._segment_path = lambda: "compatible"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Compatible, ['rfc1583', 'rfc1587', 'rfc5243'], name, value)


                        class DefaultInformation(Entity):
                            """
                            Control distribution of default information
                            
                            .. attribute:: originate
                            
                            	Distribute a default route
                            	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DefaultInformation.Originate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DefaultInformation, self).__init__()

                                self.yang_name = "default-information"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("originate", ("originate", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DefaultInformation.Originate))])
                                self._leafs = OrderedDict()

                                self.originate = None
                                self._children_name_map["originate"] = "originate"
                                self._segment_path = lambda: "default-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DefaultInformation, [], name, value)


                            class Originate(Entity):
                                """
                                Distribute a default route
                                
                                .. attribute:: always
                                
                                	Always advertise default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: metric
                                
                                	OSPF default metric
                                	**type**\: int
                                
                                	**range:** 0..16777214
                                
                                .. attribute:: metric_type
                                
                                	OSPF metric type for default routes
                                	**type**\: int
                                
                                	**range:** 1..2
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DefaultInformation.Originate, self).__init__()

                                    self.yang_name = "originate"
                                    self.yang_parent_name = "default-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.uint32, 'metric-type'), ['int'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.always = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "originate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DefaultInformation.Originate, ['always', 'metric', 'metric_type', 'route_map'], name, value)


                        class DiscardRoute(Entity):
                            """
                            Enable or disable discard\-route installation
                            
                            .. attribute:: external
                            
                            	Discard route for redistributed summarised routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: internal
                            
                            	Discard route for summarised internal routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: metric
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DiscardRoute, self).__init__()

                                self.yang_name = "discard-route"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ])
                                self.external = None
                                self.internal = None
                                self.metric = None
                                self._segment_path = lambda: "discard-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.DiscardRoute, ['external', 'internal', 'metric'], name, value)


                        class Distance(Entity):
                            """
                            Define an administrative distance
                            
                            .. attribute:: ospf_distance
                            
                            	
                            	**type**\:  :py:class:`OspfDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance.OspfDistance>`
                            
                            .. attribute:: ospf
                            
                            	OSPF routes Administrative distance
                            	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance.Ospf>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ospf-distance", ("ospf_distance", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance.OspfDistance)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance.Ospf))])
                                self._leafs = OrderedDict()

                                self.ospf_distance = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance.OspfDistance()
                                self.ospf_distance.parent = self
                                self._children_name_map["ospf_distance"] = "ospf-distance"

                                self.ospf = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance.Ospf()
                                self.ospf.parent = self
                                self._children_name_map["ospf"] = "ospf"
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance, [], name, value)


                            class OspfDistance(Entity):
                                """
                                
                                
                                .. attribute:: distance
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: ip
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: wildcard
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..99
                                
                                		**type**\: int
                                
                                			**range:** 1300..1999
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance.OspfDistance, self).__init__()

                                    self.yang_name = "ospf-distance"
                                    self.yang_parent_name = "distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                        ('wildcard', (YLeaf(YType.str, 'wildcard'), ['str'])),
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','int','str'])),
                                    ])
                                    self.distance = None
                                    self.ip = None
                                    self.wildcard = None
                                    self.acl_name = None
                                    self._segment_path = lambda: "ospf-distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance.OspfDistance, ['distance', 'ip', 'wildcard', 'acl_name'], name, value)


                            class Ospf(Entity):
                                """
                                OSPF routes Administrative distance
                                
                                .. attribute:: external
                                
                                	External routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: inter_area
                                
                                	Inter\-area routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: intra_area
                                
                                	Intra\-area routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('external', (YLeaf(YType.uint32, 'external'), ['int'])),
                                        ('inter_area', (YLeaf(YType.uint32, 'inter-area'), ['int'])),
                                        ('intra_area', (YLeaf(YType.uint32, 'intra-area'), ['int'])),
                                    ])
                                    self.external = None
                                    self.inter_area = None
                                    self.intra_area = None
                                    self._segment_path = lambda: "ospf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Distance.Ospf, ['external', 'inter_area', 'intra_area'], name, value)


                        class Redistribute(Entity):
                            """
                            Redistribute information from another routing protocol
                            
                            .. attribute:: application
                            
                            	Application
                            	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Application>`
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: iso_igrp
                            
                            	IGRP for OSI networks
                            	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: lisp
                            
                            	Locator ID Separation Protocol (LISP)
                            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp>`
                            
                            .. attribute:: mobile
                            
                            	Mobile routes
                            	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Mobile>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: odr
                            
                            	On Demand stub Routes
                            	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Odr>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Rip>`
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Static>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes redistributed to protocol
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.MaximumPrefix>`
                            
                            .. attribute:: vrf
                            
                            	Specify a source VRF
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute, self).__init__()

                                self.yang_name = "redistribute"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Static)), ("maximum-prefix", ("maximum_prefix", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.MaximumPrefix)), ("vrf", ("vrf", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_))])
                                self._leafs = OrderedDict()

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.isis = None
                                self._children_name_map["isis"] = "isis"

                                self.iso_igrp = None
                                self._children_name_map["iso_igrp"] = "iso-igrp"

                                self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp()
                                self.lisp.parent = self
                                self._children_name_map["lisp"] = "lisp"

                                self.mobile = None
                                self._children_name_map["mobile"] = "mobile"

                                self.odr = None
                                self._children_name_map["odr"] = "odr"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.maximum_prefix = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.vrf = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.application = YList(self)
                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self.rip = YList(self)
                                self._segment_path = lambda: "redistribute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute, [], name, value)


                            class Application(Entity):
                                """
                                Application
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Application.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Application, self).__init__()

                                    self.yang_name = "application"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Application.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Application.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Application, ['name'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Application.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Application.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "application"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Application.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                    ])
                                    self.as_number = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Bgp, ['as_number'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Connected, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                    ])
                                    self.as_number = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp, ['as_number'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: isis_level_routes
                                
                                	
                                	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisLevelRoutes>`
                                
                                .. attribute:: isis_area
                                
                                	
                                	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea>`
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisLevelRoutes')])),
                                    ])
                                    self.isis_level_routes = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"

                                    self.isis_area = YList(self)
                                    self._segment_path = lambda: "isis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis, ['isis_level_routes'], name, value)

                                class IsisLevelRoutes(Enum):
                                    """
                                    IsisLevelRoutes (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    .. data:: level_1_2 = 2

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")

                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class IsisArea(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: isis_level_routes
                                    
                                    	
                                    	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.IsisLevelRoutes>`
                                    
                                    .. attribute:: redist_options
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RedistOptions>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea, self).__init__()

                                        self.yang_name = "isis-area"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RedistOptions))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.IsisLevelRoutes')])),
                                        ])
                                        self.name = None
                                        self.isis_level_routes = None

                                        self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RedistOptions()
                                        self.redist_options.parent = self
                                        self._children_name_map["redist_options"] = "redist-options"
                                        self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                    class IsisLevelRoutes(Enum):
                                        """
                                        IsisLevelRoutes (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        .. data:: level_1_2 = 2

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")

                                        level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class RedistOptions(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RedistOptions.MetricType>`
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RedistOptions, self).__init__()

                                            self.yang_name = "redist-options"
                                            self.yang_parent_name = "isis-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RedistOptions.MetricType')])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.tag = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.nssa_only = None
                                            self._segment_path = lambda: "redist-options"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class IsoIgrp(Entity):
                                """
                                IGRP for OSI networks
                                
                                .. attribute:: area_tag_route_map_container
                                
                                	
                                	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.AreaTagRouteMapContainer>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: iso_igrp_container
                                
                                	
                                	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp, self).__init__()

                                    self.yang_name = "iso-igrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.AreaTagRouteMapContainer()
                                    self.area_tag_route_map_container.parent = self
                                    self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                    self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer()
                                    self.iso_igrp_container.parent = self
                                    self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                    self._segment_path = lambda: "iso-igrp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp, ['route_map'], name, value)


                                class AreaTagRouteMapContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: area_tag
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                        self.yang_name = "area-tag-route-map-container"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.area_tag = None
                                        self.route_map = None
                                        self._segment_path = lambda: "area-tag-route-map-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                class IsoIgrpContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer, self).__init__()

                                        self.yang_name = "iso-igrp-container"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self._segment_path = lambda: "iso-igrp-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Lisp(Entity):
                                """
                                Locator ID Separation Protocol (LISP)
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp, self).__init__()

                                    self.yang_name = "lisp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp.RedistOptions))])
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "lisp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "lisp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Mobile(Entity):
                                """
                                Mobile routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Mobile, self).__init__()

                                    self.yang_name = "mobile"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "mobile"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Mobile, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "mobile"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Odr(Entity):
                                """
                                On Demand stub Routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Odr, self).__init__()

                                    self.yang_name = "odr"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "odr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Odr, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "odr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match>`
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.MetricType>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.MetricType')])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.id = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.nssa_only = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.tag = None
                                    self.vrf = None

                                    self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.nssa_external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                            class Ospfv3_(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match>`
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.MetricType>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.MetricType')])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ])
                                    self.id = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.nssa_only = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.tag = None

                                    self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.Internal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.Internal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.External.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.External.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.NssaExternal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.nssa_external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: id  (key)
                                
                                	User selected string identifying this rip process
                                	**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Rip.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Rip.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Rip.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Rip, ['id'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Rip.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Rip.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Rip.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Static.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Static.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Static.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Static, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Static.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Static.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Static.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes redistributed to protocol
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: threshold_warning_only_container
                                
                                	
                                	**type**\:  :py:class:`ThresholdWarningOnlyContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("threshold-warning-only-container", ("threshold_warning_only_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                    ])
                                    self.number = None

                                    self.threshold_warning_only_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer()
                                    self.threshold_warning_only_container.parent = self
                                    self._children_name_map["threshold_warning_only_container"] = "threshold-warning-only-container"
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.MaximumPrefix, ['number'], name, value)


                                class ThresholdWarningOnlyContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer, self).__init__()

                                        self.yang_name = "threshold-warning-only-container"
                                        self.yang_parent_name = "maximum-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.threshold = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "threshold-warning-only-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer, ['threshold', 'warning_only'], name, value)


                            class Vrf_(Entity):
                                """
                                Specify a source VRF
                                
                                .. attribute:: non_global_vrf
                                
                                	
                                	**type**\: list of  		 :py:class:`NonGlobalVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf>`
                                
                                .. attribute:: global_
                                
                                	global VRF
                                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("non-global-vrf", ("non_global_vrf", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf)), ("global", ("global_", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global))])
                                    self._leafs = OrderedDict()

                                    self.global_ = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"

                                    self.non_global_vrf = YList(self)
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_, [], name, value)


                                class NonGlobalVrf(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator ID Separation Protocol (LISP)
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf, self).__init__()

                                        self.yang_name = "non-global-vrf"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.iso_igrp = None
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp()
                                        self.lisp.parent = self
                                        self._children_name_map["lisp"] = "lisp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.application = YList(self)
                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "non-global-vrf" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf, ['name'], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application, ['name'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_level_routes
                                        
                                        	
                                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisLevelRoutes>`
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea>`
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisLevelRoutes')])),
                                            ])
                                            self.isis_level_routes = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis, ['isis_level_routes'], name, value)

                                        class IsisLevelRoutes(Enum):
                                            """
                                            IsisLevelRoutes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: isis_level_routes
                                            
                                            	
                                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.IsisLevelRoutes>`
                                            
                                            .. attribute:: redist_options
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.IsisLevelRoutes')])),
                                                ])
                                                self.name = None
                                                self.isis_level_routes = None

                                                self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions()
                                                self.redist_options.parent = self
                                                self._children_name_map["redist_options"] = "redist-options"
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                            class IsisLevelRoutes(Enum):
                                                """
                                                IsisLevelRoutes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class RedistOptions(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions.MetricType>`
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions, self).__init__()

                                                    self.yang_name = "redist-options"
                                                    self.yang_parent_name = "isis-area"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions.MetricType')])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.tag = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.nssa_only = None
                                                    self._segment_path = lambda: "redist-options"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: area_tag_route_map_container
                                        
                                        	
                                        	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: iso_igrp_container
                                        
                                        	
                                        	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer()
                                            self.area_tag_route_map_container.parent = self
                                            self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                            self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer()
                                            self.iso_igrp_container.parent = self
                                            self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp, ['route_map'], name, value)


                                        class AreaTagRouteMapContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: area_tag
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                                self.yang_name = "area-tag-route-map-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.area_tag = None
                                                self.route_map = None
                                                self._segment_path = lambda: "area-tag-route-map-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                        class IsoIgrpContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer, self).__init__()

                                                self.yang_name = "iso-igrp-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self._segment_path = lambda: "iso-igrp-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Lisp(Entity):
                                        """
                                        Locator ID Separation Protocol (LISP)
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions))])
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "lisp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "mobile"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "odr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self.vrf = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Ospfv3_(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this rip process
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip, ['id'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                class Global(Entity):
                                    """
                                    global VRF
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator ID Separation Protocol (LISP)
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.iso_igrp = None
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp()
                                        self.lisp.parent = self
                                        self._children_name_map["lisp"] = "lisp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.application = YList(self)
                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "global"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Application, ['name'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Bgp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Connected, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Eigrp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_level_routes
                                        
                                        	
                                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisLevelRoutes>`
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea>`
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisLevelRoutes')])),
                                            ])
                                            self.isis_level_routes = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis, ['isis_level_routes'], name, value)

                                        class IsisLevelRoutes(Enum):
                                            """
                                            IsisLevelRoutes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: isis_level_routes
                                            
                                            	
                                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.IsisLevelRoutes>`
                                            
                                            .. attribute:: redist_options
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.IsisLevelRoutes')])),
                                                ])
                                                self.name = None
                                                self.isis_level_routes = None

                                                self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions()
                                                self.redist_options.parent = self
                                                self._children_name_map["redist_options"] = "redist-options"
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                            class IsisLevelRoutes(Enum):
                                                """
                                                IsisLevelRoutes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class RedistOptions(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions.MetricType>`
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions, self).__init__()

                                                    self.yang_name = "redist-options"
                                                    self.yang_parent_name = "isis-area"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions.MetricType')])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.tag = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.nssa_only = None
                                                    self._segment_path = lambda: "redist-options"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: area_tag_route_map_container
                                        
                                        	
                                        	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.AreaTagRouteMapContainer>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: iso_igrp_container
                                        
                                        	
                                        	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.AreaTagRouteMapContainer()
                                            self.area_tag_route_map_container.parent = self
                                            self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                            self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer()
                                            self.iso_igrp_container.parent = self
                                            self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp, ['route_map'], name, value)


                                        class AreaTagRouteMapContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: area_tag
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                                self.yang_name = "area-tag-route-map-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.area_tag = None
                                                self.route_map = None
                                                self._segment_path = lambda: "area-tag-route-map-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                        class IsoIgrpContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer, self).__init__()

                                                self.yang_name = "iso-igrp-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self._segment_path = lambda: "iso-igrp-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Lisp(Entity):
                                        """
                                        Locator ID Separation Protocol (LISP)
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions))])
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "lisp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Mobile, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "mobile"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Odr, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "odr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self.vrf = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Ospfv3_(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this rip process
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Rip, ['id'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Static, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                        class Authentication(Entity):
                            """
                            Authentication parameters
                            
                            .. attribute:: mode
                            
                            	Authentication operation mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Authentication.Mode>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Authentication.Mode')])),
                                ])
                                self.mode = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Authentication, [u'mode'], name, value)

                            class Mode(Enum):
                                """
                                Mode (Enum Class)

                                Authentication operation mode

                                .. data:: deployment = 0

                                .. data:: normal = 1

                                .. data:: strict = 2

                                """

                                deployment = Enum.YLeaf(0, "deployment")

                                normal = Enum.YLeaf(1, "normal")

                                strict = Enum.YLeaf(2, "strict")



                        class GracefulRestart(Entity):
                            """
                            Graceful\-restart options
                            
                            .. attribute:: disable
                            
                            	Graceful restart disable
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: helper
                            
                            	helper support
                            	**type**\:  :py:class:`Helper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.GracefulRestart.Helper>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: restart_interval
                            
                            	Graceful restart interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.GracefulRestart, self).__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("helper", ("helper", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.GracefulRestart.Helper))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('restart_interval', (YLeaf(YType.uint16, 'restart-interval'), ['int'])),
                                ])
                                self.disable = None
                                self.restart_interval = None

                                self.helper = None
                                self._children_name_map["helper"] = "helper"
                                self._segment_path = lambda: "graceful-restart"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.GracefulRestart, [u'disable', u'restart_interval'], name, value)


                            class Helper(Entity):
                                """
                                helper support
                                
                                .. attribute:: disable
                                
                                	disable helper support
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: strict_lsa_checking
                                
                                	enable helper strict LSA checking
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.GracefulRestart.Helper, self).__init__()

                                    self.yang_name = "helper"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ('strict_lsa_checking', (YLeaf(YType.empty, 'strict-lsa-checking'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self.strict_lsa_checking = None
                                    self._segment_path = lambda: "helper"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.GracefulRestart.Helper, [u'disable', u'strict_lsa_checking'], name, value)


                        class Manet(Entity):
                            """
                            Specify MANET OSPF parameters
                            
                            .. attribute:: cache
                            
                            	Specify MANET cache sizes
                            	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Cache>`
                            
                            .. attribute:: hello
                            
                            	Unicast Hellos rather than multicast
                            	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Hello>`
                            
                            .. attribute:: peering
                            
                            	MANET OSPF Smart Peering
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Peering>`
                            
                            .. attribute:: willingness
                            
                            	Specify Relay willingness value
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cache", ("cache", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Cache)), ("peering", ("peering", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Peering))])
                                self._leafs = OrderedDict([
                                    ('hello', (YLeaf(YType.enumeration, 'hello'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Hello')])),
                                    ('willingness', (YLeaf(YType.uint8, 'willingness'), ['int'])),
                                ])
                                self.hello = None
                                self.willingness = None

                                self.cache = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Cache()
                                self.cache.parent = self
                                self._children_name_map["cache"] = "cache"

                                self.peering = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet, [u'hello', u'willingness'], name, value)

                            class Hello(Enum):
                                """
                                Hello (Enum Class)

                                Unicast Hellos rather than multicast

                                .. data:: unicast = 0

                                .. data:: multicast = 1

                                """

                                unicast = Enum.YLeaf(0, "unicast")

                                multicast = Enum.YLeaf(1, "multicast")



                            class Cache(Entity):
                                """
                                Specify MANET cache sizes
                                
                                .. attribute:: acknowledgement
                                
                                	Specify MANET acknowledgement cache size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update
                                
                                	Specify MANET LSA cache size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Cache, self).__init__()

                                    self.yang_name = "cache"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acknowledgement', (YLeaf(YType.uint64, 'acknowledgement'), ['int'])),
                                        ('update', (YLeaf(YType.uint64, 'update'), ['int'])),
                                    ])
                                    self.acknowledgement = None
                                    self.update = None
                                    self._segment_path = lambda: "cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Cache, [u'acknowledgement', u'update'], name, value)


                            class Peering(Entity):
                                """
                                MANET OSPF Smart Peering
                                
                                .. attribute:: selective
                                
                                	Enable selective peering
                                	**type**\:  :py:class:`Selective <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Peering.Selective>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("selective", ("selective", Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Peering.Selective))])
                                    self._leafs = OrderedDict()

                                    self.selective = Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Peering.Selective()
                                    self.selective.parent = self
                                    self._children_name_map["selective"] = "selective"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Peering, [], name, value)


                                class Selective(Entity):
                                    """
                                    Enable selective peering
                                    
                                    .. attribute:: disable
                                    
                                    	Disable selective peering
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: per_interface
                                    
                                    	Select peers per interface rather than per node
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: redundancy
                                    
                                    	Redundant paths
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Peering.Selective, self).__init__()

                                        self.yang_name = "selective"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ('per_interface', (YLeaf(YType.empty, 'per-interface'), ['Empty'])),
                                            ('redundancy', (YLeaf(YType.uint8, 'redundancy'), ['int'])),
                                        ])
                                        self.disable = None
                                        self.per_interface = None
                                        self.redundancy = None
                                        self._segment_path = lambda: "selective"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.Manet.Peering.Selective, [u'disable', u'per_interface', u'redundancy'], name, value)


                        class SummaryPrefix(Entity):
                            """
                            
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            .. attribute:: nssa_only
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: tag
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: not_advertise
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.SummaryPrefix, self).__init__()

                                self.yang_name = "summary-prefix"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                ])
                                self.prefix = None
                                self.nssa_only = None
                                self.tag = None
                                self.not_advertise = None
                                self._segment_path = lambda: "summary-prefix" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv4.Vrf.SummaryPrefix, [u'prefix', u'nssa_only', u'tag', u'not_advertise'], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 Address family
                    
                    .. attribute:: unicast
                    
                    	
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: vrf
                    
                    	Specify parameters for a VPN Routing/Forwarding instance
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-ospfv3'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Ospfv3.AddressFamily.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("unicast", ("unicast", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast)), ("vrf", ("vrf", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf))])
                        self._leafs = OrderedDict()

                        self.unicast = None
                        self._children_name_map["unicast"] = "unicast"

                        self.vrf = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6, [], name, value)


                    class Unicast(Entity):
                        """
                        
                        
                        .. attribute:: area
                        
                        	OSPF area parameters
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area>`
                        
                        .. attribute:: auto_cost
                        
                        	Calculate OSPF interface cost according to bandwidth
                        	**type**\:  :py:class:`AutoCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.AutoCost>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: event_log
                        
                        	OSPF Event Logging
                        	**type**\:  :py:class:`EventLog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.EventLog>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: bfd
                        
                        	BFD configuration commands
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Bfd>`
                        
                        .. attribute:: interface_id
                        
                        	Source of the interface ID
                        	**type**\:  :py:class:`InterfaceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.InterfaceId>`
                        
                        .. attribute:: log_adjacency_changes
                        
                        	Log changes in adjacency state
                        	**type**\:  :py:class:`LogAdjacencyChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.LogAdjacencyChanges>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: max_lsa
                        
                        	maximum number of LSAs OSPF process will receive
                        	**type**\:  :py:class:`MaxLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxLsa>`
                        
                        .. attribute:: max_metric
                        
                        	Set maximum metric
                        	**type**\:  :py:class:`MaxMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric>`
                        
                        .. attribute:: passive_interface
                        
                        	Suppress routing updates on an interface
                        	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.PassiveInterface>`
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Disable>`
                        
                        .. attribute:: queue_depth
                        
                        	OSPF Hello/Router process queue depth
                        	**type**\:  :py:class:`QueueDepth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth>`
                        
                        .. attribute:: timers
                        
                        	Adjust routing timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers>`
                        
                        .. attribute:: router_id
                        
                        	Override configured router identifier (peers will reset)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nsr
                        
                        	Enable non\-stop routing
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: traffic_share
                        
                        	How to compute traffic share over alternate paths
                        	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.TrafficShare>`
                        
                        .. attribute:: ttl_security
                        
                        	TTL security check
                        	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.TtlSecurity>`
                        
                        .. attribute:: capability
                        
                        	Enable specific OSPF feature
                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Capability>`
                        
                        .. attribute:: compatible
                        
                        	OSPF compatibility list
                        	**type**\:  :py:class:`Compatible <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Compatible>`
                        
                        .. attribute:: default_information
                        
                        	Control distribution of default information
                        	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DefaultInformation>`
                        
                        .. attribute:: default_metric
                        
                        	Set metric of redistributed routes
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: discard_route
                        
                        	Enable or disable discard\-route installation
                        	**type**\:  :py:class:`DiscardRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DiscardRoute>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: distance
                        
                        	Define an administrative distance
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance>`
                        
                        .. attribute:: maximum_paths
                        
                        	Forward packets over multiple paths
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: redistribute
                        
                        	Redistribute information from another routing protocol
                        	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute>`
                        
                        .. attribute:: authentication
                        
                        	Authentication parameters
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Authentication>`
                        
                        .. attribute:: graceful_restart
                        
                        	Graceful\-restart options
                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.GracefulRestart>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF parameters
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet>`
                        
                        .. attribute:: summary_prefix
                        
                        	Configure IPv6 summary prefix
                        	**type**\: list of  		 :py:class:`SummaryPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.SummaryPrefix>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area)), ("auto-cost", ("auto_cost", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.AutoCost)), ("event-log", ("event_log", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.EventLog)), ("bfd", ("bfd", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Bfd)), ("interface-id", ("interface_id", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.InterfaceId)), ("log-adjacency-changes", ("log_adjacency_changes", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.LogAdjacencyChanges)), ("max-lsa", ("max_lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxLsa)), ("max-metric", ("max_metric", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric)), ("passive-interface", ("passive_interface", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.PassiveInterface)), ("disable", ("disable", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Disable)), ("queue-depth", ("queue_depth", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth)), ("timers", ("timers", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers)), ("traffic-share", ("traffic_share", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.TrafficShare)), ("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.TtlSecurity)), ("capability", ("capability", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Capability)), ("compatible", ("compatible", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Compatible)), ("default-information", ("default_information", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DefaultInformation)), ("discard-route", ("discard_route", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DiscardRoute)), ("distance", ("distance", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance)), ("redistribute", ("redistribute", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute)), ("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Authentication)), ("graceful-restart", ("graceful_restart", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.GracefulRestart)), ("manet", ("manet", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet)), ("summary-prefix", ("summary_prefix", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.SummaryPrefix))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('nsr', (YLeaf(YType.empty, 'nsr'), ['Empty'])),
                                ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                            ])
                            self.router_id = None
                            self.nsr = None
                            self.default_metric = None
                            self.maximum_paths = None

                            self.auto_cost = None
                            self._children_name_map["auto_cost"] = "auto-cost"

                            self.event_log = None
                            self._children_name_map["event_log"] = "event-log"

                            self.bfd = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Bfd()
                            self.bfd.parent = self
                            self._children_name_map["bfd"] = "bfd"

                            self.interface_id = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.InterfaceId()
                            self.interface_id.parent = self
                            self._children_name_map["interface_id"] = "interface-id"

                            self.log_adjacency_changes = None
                            self._children_name_map["log_adjacency_changes"] = "log-adjacency-changes"

                            self.max_lsa = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxLsa()
                            self.max_lsa.parent = self
                            self._children_name_map["max_lsa"] = "max-lsa"

                            self.max_metric = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric()
                            self.max_metric.parent = self
                            self._children_name_map["max_metric"] = "max-metric"

                            self.passive_interface = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.PassiveInterface()
                            self.passive_interface.parent = self
                            self._children_name_map["passive_interface"] = "passive-interface"

                            self.disable = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Disable()
                            self.disable.parent = self
                            self._children_name_map["disable"] = "disable"

                            self.queue_depth = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth()
                            self.queue_depth.parent = self
                            self._children_name_map["queue_depth"] = "queue-depth"

                            self.timers = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"

                            self.traffic_share = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.TrafficShare()
                            self.traffic_share.parent = self
                            self._children_name_map["traffic_share"] = "traffic-share"

                            self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.TtlSecurity()
                            self.ttl_security.parent = self
                            self._children_name_map["ttl_security"] = "ttl-security"

                            self.capability = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Capability()
                            self.capability.parent = self
                            self._children_name_map["capability"] = "capability"

                            self.compatible = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Compatible()
                            self.compatible.parent = self
                            self._children_name_map["compatible"] = "compatible"

                            self.default_information = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DefaultInformation()
                            self.default_information.parent = self
                            self._children_name_map["default_information"] = "default-information"

                            self.discard_route = None
                            self._children_name_map["discard_route"] = "discard-route"

                            self.distance = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.redistribute = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute()
                            self.redistribute.parent = self
                            self._children_name_map["redistribute"] = "redistribute"

                            self.authentication = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.graceful_restart = None
                            self._children_name_map["graceful_restart"] = "graceful-restart"

                            self.manet = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.area = YList(self)
                            self.summary_prefix = YList(self)
                            self._segment_path = lambda: "unicast"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast, ['router_id', 'nsr', 'default_metric', 'maximum_paths'], name, value)


                        class Area(Entity):
                            """
                            OSPF area parameters
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: authentication
                            
                            	Enable authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Authentication>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: capability
                            
                            	Enable area specific capability
                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Capability>`
                            
                            .. attribute:: default_cost
                            
                            	Set the summary default\-cost of a NSSA/stub area
                            	**type**\: int
                            
                            	**range:** 0..16777215
                            
                            .. attribute:: filter_list
                            
                            	Filter networks between OSPF areas
                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.FilterList>`
                            
                            .. attribute:: nssa
                            
                            	Specify a NSSA area
                            	**type**\:  :py:class:`Nssa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ipv4_range
                            
                            	
                            	**type**\:  :py:class:`Ipv4Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv4Range>`
                            
                            .. attribute:: ipv6_range
                            
                            	
                            	**type**\:  :py:class:`Ipv6Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv6Range>`
                            
                            .. attribute:: sham_link
                            
                            	Define a sham link and its parameters
                            	**type**\: list of  		 :py:class:`ShamLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.ShamLink>`
                            
                            .. attribute:: stub
                            
                            	Specify a stub area
                            	**type**\:  :py:class:`Stub <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Stub>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: virtual_link
                            
                            	Define a virtual link and its parameters
                            	**type**\: list of  		 :py:class:`VirtualLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Authentication)), ("capability", ("capability", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Capability)), ("filter-list", ("filter_list", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.FilterList)), ("nssa", ("nssa", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa)), ("ipv4-range", ("ipv4_range", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv4Range)), ("ipv6-range", ("ipv6_range", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv6Range)), ("sham-link", ("sham_link", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.ShamLink)), ("stub", ("stub", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Stub)), ("virtual-link", ("virtual_link", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('default_cost', (YLeaf(YType.uint32, 'default-cost'), ['int'])),
                                ])
                                self.id = None
                                self.default_cost = None

                                self.authentication = None
                                self._children_name_map["authentication"] = "authentication"

                                self.capability = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Capability()
                                self.capability.parent = self
                                self._children_name_map["capability"] = "capability"

                                self.nssa = None
                                self._children_name_map["nssa"] = "nssa"

                                self.ipv4_range = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv4Range()
                                self.ipv4_range.parent = self
                                self._children_name_map["ipv4_range"] = "ipv4-range"

                                self.ipv6_range = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv6Range()
                                self.ipv6_range.parent = self
                                self._children_name_map["ipv6_range"] = "ipv6-range"

                                self.stub = None
                                self._children_name_map["stub"] = "stub"

                                self.filter_list = YList(self)
                                self.sham_link = YList(self)
                                self.virtual_link = YList(self)
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area, ['id', 'default_cost'], name, value)


                            class Authentication(Entity):
                                """
                                Enable authentication
                                
                                .. attribute:: message_digest
                                
                                	Use message\-digest authentication
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                    ])
                                    self.message_digest = None
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Authentication, ['message_digest'], name, value)


                            class Capability(Entity):
                                """
                                Enable area specific capability
                                
                                .. attribute:: default_exclusion
                                
                                	Enable exclusion of links from base topology
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Capability, self).__init__()

                                    self.yang_name = "capability"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('default_exclusion', (YLeaf(YType.empty, 'default-exclusion'), ['Empty'])),
                                    ])
                                    self.default_exclusion = None
                                    self._segment_path = lambda: "capability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Capability, ['default_exclusion'], name, value)


                            class FilterList(Entity):
                                """
                                Filter networks between OSPF areas
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`InOut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.FilterList.InOut>`
                                
                                .. attribute:: prefix
                                
                                	Filter prefixes between OSPF areas
                                	**type**\: str
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.FilterList, self).__init__()

                                    self.yang_name = "filter-list"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['in_out']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.FilterList.InOut')])),
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ])
                                    self.in_out = None
                                    self.prefix = None
                                    self._segment_path = lambda: "filter-list" + "[in-out='" + str(self.in_out) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.FilterList, ['in_out', 'prefix'], name, value)

                                class InOut(Enum):
                                    """
                                    InOut (Enum Class)

                                    .. data:: in_ = 0

                                    .. data:: out = 1

                                    """

                                    in_ = Enum.YLeaf(0, "in")

                                    out = Enum.YLeaf(1, "out")



                            class Nssa(Entity):
                                """
                                Specify a NSSA area
                                
                                .. attribute:: default_information_originate
                                
                                	Originate Type 7 default into NSSA area
                                	**type**\:  :py:class:`DefaultInformationOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_ext_capability
                                
                                	Do not send domain specific capabilities into NSSA
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_redistribution
                                
                                	No redistribution into this NSSA area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into NSSA
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit default advertisement to this NSSA area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: translate
                                
                                	Translate LSA
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.Translate>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa, self).__init__()

                                    self.yang_name = "nssa"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default-information-originate", ("default_information_originate", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate)), ("translate", ("translate", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.Translate))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                        ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                                        ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.no_ext_capability = None
                                    self.no_redistribution = None
                                    self.no_summary = None
                                    self.nssa_only = None

                                    self.default_information_originate = None
                                    self._children_name_map["default_information_originate"] = "default-information-originate"

                                    self.translate = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "nssa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa, ['no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                                class DefaultInformationOriginate(Entity):
                                    """
                                    Originate Type 7 default into NSSA area
                                    
                                    .. attribute:: metric
                                    
                                    	OSPF default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..16777214
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF metric type for default routes
                                    	**type**\: int
                                    
                                    	**range:** 1..2
                                    
                                    .. attribute:: no_ext_capability
                                    
                                    	Do not send domain specific capabilities into NSSA
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_redistribution
                                    
                                    	No redistribution into this NSSA area
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_summary
                                    
                                    	Do not send summary LSA into NSSA
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit default advertisement to this NSSA area
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: translate
                                    
                                    	Translate LSA
                                    	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate.Translate>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate, self).__init__()

                                        self.yang_name = "default-information-originate"
                                        self.yang_parent_name = "nssa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("translate", ("translate", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate.Translate))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.int32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.uint32, 'metric-type'), ['int'])),
                                            ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                            ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                                            ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.no_ext_capability = None
                                        self.no_redistribution = None
                                        self.no_summary = None
                                        self.nssa_only = None

                                        self.translate = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate.Translate()
                                        self.translate.parent = self
                                        self._children_name_map["translate"] = "translate"
                                        self._segment_path = lambda: "default-information-originate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate, ['metric', 'metric_type', 'no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                                    class Translate(Entity):
                                        """
                                        Translate LSA
                                        
                                        .. attribute:: type7
                                        
                                        	From Type 7 to Type 5
                                        	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate.Translate.Type7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate.Translate, self).__init__()

                                            self.yang_name = "translate"
                                            self.yang_parent_name = "default-information-originate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate.Translate.Type7))])
                                            self._leafs = OrderedDict()

                                            self.type7 = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate.Translate.Type7()
                                            self.type7.parent = self
                                            self._children_name_map["type7"] = "type7"
                                            self._segment_path = lambda: "translate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate.Translate, [], name, value)


                                        class Type7(Entity):
                                            """
                                            From Type 7 to Type 5
                                            
                                            .. attribute:: always
                                            
                                            	Always translate LSAs on this ABR
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: suppress_fa
                                            
                                            	Suppress forwarding address in translated LSAs
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate.Translate.Type7, self).__init__()

                                                self.yang_name = "type7"
                                                self.yang_parent_name = "translate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                                    ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                                ])
                                                self.always = None
                                                self.suppress_fa = None
                                                self._segment_path = lambda: "type7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.DefaultInformationOriginate.Translate.Type7, ['always', 'suppress_fa'], name, value)


                                class Translate(Entity):
                                    """
                                    Translate LSA
                                    
                                    .. attribute:: type7
                                    
                                    	From Type 7 to Type 5
                                    	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.Translate.Type7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "nssa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.Translate.Type7))])
                                        self._leafs = OrderedDict()

                                        self.type7 = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.Translate.Type7()
                                        self.type7.parent = self
                                        self._children_name_map["type7"] = "type7"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.Translate, [], name, value)


                                    class Type7(Entity):
                                        """
                                        From Type 7 to Type 5
                                        
                                        .. attribute:: always
                                        
                                        	Always translate LSAs on this ABR
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_fa
                                        
                                        	Suppress forwarding address in translated LSAs
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.Translate.Type7, self).__init__()

                                            self.yang_name = "type7"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                                ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                            ])
                                            self.always = None
                                            self.suppress_fa = None
                                            self._segment_path = lambda: "type7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Nssa.Translate.Type7, ['always', 'suppress_fa'], name, value)


                            class Ipv4Range(Entity):
                                """
                                
                                
                                .. attribute:: range
                                
                                	Summarize routes matching address/mask (border routers only)
                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv4Range.Range>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv4Range, self).__init__()

                                    self.yang_name = "ipv4-range"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv4Range.Range))])
                                    self._leafs = OrderedDict()

                                    self.range = YList(self)
                                    self._segment_path = lambda: "ipv4-range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv4Range, [], name, value)


                                class Range(Entity):
                                    """
                                    Summarize routes matching address/mask (border routers only)
                                    
                                    .. attribute:: ip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mask  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise this range (default)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: not_advertise
                                    
                                    	DoNotAdvertise this range
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: cost
                                    
                                    	User specified metric for this range
                                    	**type**\: int
                                    
                                    	**range:** 0..16777215
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv4Range.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "ipv4-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip','mask']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                            ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                            ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                        ])
                                        self.ip = None
                                        self.mask = None
                                        self.advertise = None
                                        self.not_advertise = None
                                        self.cost = None
                                        self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv4Range.Range, ['ip', 'mask', 'advertise', 'not_advertise', 'cost'], name, value)


                            class Ipv6Range(Entity):
                                """
                                
                                
                                .. attribute:: range
                                
                                	Summarize routes matching address/mask (border routers only)
                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv6Range.Range>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv6Range, self).__init__()

                                    self.yang_name = "ipv6-range"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv6Range.Range))])
                                    self._leafs = OrderedDict()

                                    self.range = YList(self)
                                    self._segment_path = lambda: "ipv6-range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv6Range, [], name, value)


                                class Range(Entity):
                                    """
                                    Summarize routes matching address/mask (border routers only)
                                    
                                    .. attribute:: ip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise this range (default)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: not_advertise
                                    
                                    	DoNotAdvertise this range
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: cost
                                    
                                    	User specified metric for this range
                                    	**type**\: int
                                    
                                    	**range:** 0..16777215
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv6Range.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "ipv6-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                            ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                            ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                        ])
                                        self.ip = None
                                        self.advertise = None
                                        self.not_advertise = None
                                        self.cost = None
                                        self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Ipv6Range.Range, ['ip', 'advertise', 'not_advertise', 'cost'], name, value)


                            class ShamLink(Entity):
                                """
                                Define a sham link and its parameters
                                
                                .. attribute:: source  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: dest  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: cost
                                
                                	Associate a cost with the sham\-link
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ttl_security
                                
                                	TTL security check
                                	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.ShamLink.TtlSecurity>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.ShamLink, self).__init__()

                                    self.yang_name = "sham-link"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['source','dest']
                                    self._child_classes = OrderedDict([("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.ShamLink.TtlSecurity))])
                                    self._leafs = OrderedDict([
                                        ('source', (YLeaf(YType.str, 'source'), ['str','str'])),
                                        ('dest', (YLeaf(YType.str, 'dest'), ['str','str'])),
                                        ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ])
                                    self.source = None
                                    self.dest = None
                                    self.cost = None

                                    self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.ShamLink.TtlSecurity()
                                    self.ttl_security.parent = self
                                    self._children_name_map["ttl_security"] = "ttl-security"
                                    self._segment_path = lambda: "sham-link" + "[source='" + str(self.source) + "']" + "[dest='" + str(self.dest) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.ShamLink, ['source', 'dest', 'cost'], name, value)


                                class TtlSecurity(Entity):
                                    """
                                    TTL security check
                                    
                                    .. attribute:: hops
                                    
                                    	IP hops
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.ShamLink.TtlSecurity, self).__init__()

                                        self.yang_name = "ttl-security"
                                        self.yang_parent_name = "sham-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                        ])
                                        self.hops = None
                                        self._segment_path = lambda: "ttl-security"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.ShamLink.TtlSecurity, ['hops'], name, value)


                            class Stub(Entity):
                                """
                                Specify a stub area
                                
                                .. attribute:: no_ext_capability
                                
                                	Do not send domain specific capabilities into stub area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into stub area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Stub, self).__init__()

                                    self.yang_name = "stub"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                        ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                    ])
                                    self.no_ext_capability = None
                                    self.no_summary = None
                                    self._segment_path = lambda: "stub"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.Stub, ['no_ext_capability', 'no_summary'], name, value)


                            class VirtualLink(Entity):
                                """
                                Define a virtual link and its parameters
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Set authentication type
                                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication>`
                                
                                .. attribute:: hello_interval
                                
                                	Hello packet interval
                                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.HelloInterval>`
                                
                                .. attribute:: dead_interval
                                
                                	Dead router detection time
                                	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.DeadInterval>`
                                
                                .. attribute:: retransmit_interval
                                
                                	LSA retransmit interval
                                	**type**\:  :py:class:`RetransmitInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.RetransmitInterval>`
                                
                                .. attribute:: transmit_delay
                                
                                	LSA transmission delay
                                	**type**\:  :py:class:`TransmitDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.TransmitDelay>`
                                
                                .. attribute:: topology
                                
                                	Disable virtual link on topology
                                	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Topology>`
                                
                                .. attribute:: ttl_security
                                
                                	TTL security check
                                	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.TtlSecurity>`
                                
                                .. attribute:: authentication_key
                                
                                	Set authentication key
                                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.AuthenticationKey>`
                                
                                .. attribute:: message_digest_key
                                
                                	Set message digest key
                                	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.MessageDigestKey>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink, self).__init__()

                                    self.yang_name = "virtual-link"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication)), ("hello-interval", ("hello_interval", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.HelloInterval)), ("dead-interval", ("dead_interval", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.DeadInterval)), ("retransmit-interval", ("retransmit_interval", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.RetransmitInterval)), ("transmit-delay", ("transmit_delay", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.TransmitDelay)), ("topology", ("topology", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Topology)), ("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.TtlSecurity)), ("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.MessageDigestKey))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                    ])
                                    self.id = None

                                    self.authentication = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"

                                    self.hello_interval = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.HelloInterval()
                                    self.hello_interval.parent = self
                                    self._children_name_map["hello_interval"] = "hello-interval"

                                    self.dead_interval = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.DeadInterval()
                                    self.dead_interval.parent = self
                                    self._children_name_map["dead_interval"] = "dead-interval"

                                    self.retransmit_interval = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.RetransmitInterval()
                                    self.retransmit_interval.parent = self
                                    self._children_name_map["retransmit_interval"] = "retransmit-interval"

                                    self.transmit_delay = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.TransmitDelay()
                                    self.transmit_delay.parent = self
                                    self._children_name_map["transmit_delay"] = "transmit-delay"

                                    self.topology = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Topology()
                                    self.topology.parent = self
                                    self._children_name_map["topology"] = "topology"

                                    self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.TtlSecurity()
                                    self.ttl_security.parent = self
                                    self._children_name_map["ttl_security"] = "ttl-security"

                                    self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.AuthenticationKey()
                                    self.authentication_key.parent = self
                                    self._children_name_map["authentication_key"] = "authentication-key"

                                    self.message_digest_key = YList(self)
                                    self._segment_path = lambda: "virtual-link" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink, ['id'], name, value)


                                class Authentication(Entity):
                                    """
                                    Set authentication type
                                    
                                    .. attribute:: authentication_key
                                    
                                    	Set authentication key
                                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.AuthenticationKey>`
                                    
                                    .. attribute:: message_digest_key
                                    
                                    	Set message digest key
                                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigestKey>`
                                    
                                    .. attribute:: key_chain
                                    
                                    	Use a key\-chain for cryptographic authentication keys
                                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain>`
                                    
                                    .. attribute:: message_digest
                                    
                                    	Message\-digest authentication
                                    	**type**\:  :py:class:`MessageDigest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest>`
                                    
                                    .. attribute:: null
                                    
                                    	No authentication
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigestKey)), ("key-chain", ("key_chain", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain)), ("message-digest", ("message_digest", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest))])
                                        self._leafs = OrderedDict([
                                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                        ])
                                        self.null = None

                                        self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.AuthenticationKey()
                                        self.authentication_key.parent = self
                                        self._children_name_map["authentication_key"] = "authentication-key"

                                        self.key_chain = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain()
                                        self.key_chain.parent = self
                                        self._children_name_map["key_chain"] = "key-chain"

                                        self.message_digest = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest()
                                        self.message_digest.parent = self
                                        self._children_name_map["message_digest"] = "message-digest"

                                        self.message_digest_key = YList(self)
                                        self._segment_path = lambda: "authentication"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication, ['null'], name, value)


                                    class AuthenticationKey(Entity):
                                        """
                                        Set authentication key
                                        
                                        .. attribute:: auth_type
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: auth_key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.AuthenticationKey, self).__init__()

                                            self.yang_name = "authentication-key"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                            ])
                                            self.auth_type = None
                                            self.auth_key = None
                                            self._segment_path = lambda: "authentication-key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                    class MessageDigestKey(Entity):
                                        """
                                        Set message digest key
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: md5
                                        
                                        	Use MD5 algorithm
                                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigestKey.Md5>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigestKey, self).__init__()

                                            self.yang_name = "message-digest-key"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigestKey.Md5))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigestKey.Md5()
                                            self.md5.parent = self
                                            self._children_name_map["md5"] = "md5"
                                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigestKey, ['id'], name, value)


                                        class Md5(Entity):
                                            """
                                            Use MD5 algorithm
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**length:** 1..16
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigestKey.Md5, self).__init__()

                                                self.yang_name = "md5"
                                                self.yang_parent_name = "message-digest-key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "md5"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                    class KeyChain(Entity):
                                        """
                                        Use a key\-chain for cryptographic authentication keys
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: authentication_key
                                        
                                        	Set authentication key
                                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey>`
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Set message digest key
                                        	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain, self).__init__()

                                            self.yang_name = "key-chain"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey()
                                            self.authentication_key.parent = self
                                            self._children_name_map["authentication_key"] = "authentication-key"

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "key-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain, ['name'], name, value)


                                        class AuthenticationKey(Entity):
                                            """
                                            Set authentication key
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, self).__init__()

                                                self.yang_name = "authentication-key"
                                                self.yang_parent_name = "key-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "authentication-key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Set message digest key
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: md5
                                            
                                            	Use MD5 algorithm
                                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "key-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5()
                                                self.md5.parent = self
                                                self._children_name_map["md5"] = "md5"
                                                self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, ['id'], name, value)


                                            class Md5(Entity):
                                                """
                                                Use MD5 algorithm
                                                
                                                .. attribute:: auth_type
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                .. attribute:: auth_key
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**length:** 1..16
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, self).__init__()

                                                    self.yang_name = "md5"
                                                    self.yang_parent_name = "message-digest-key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                    ])
                                                    self.auth_type = None
                                                    self.auth_key = None
                                                    self._segment_path = lambda: "md5"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                    class MessageDigest(Entity):
                                        """
                                        Message\-digest authentication
                                        
                                        .. attribute:: authentication_key
                                        
                                        	Set authentication key
                                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey>`
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Set message digest key
                                        	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest, self).__init__()

                                            self.yang_name = "message-digest"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey))])
                                            self._leafs = OrderedDict()

                                            self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey()
                                            self.authentication_key.parent = self
                                            self._children_name_map["authentication_key"] = "authentication-key"

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest, [], name, value)


                                        class AuthenticationKey(Entity):
                                            """
                                            Set authentication key
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, self).__init__()

                                                self.yang_name = "authentication-key"
                                                self.yang_parent_name = "message-digest"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "authentication-key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Set message digest key
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: md5
                                            
                                            	Use MD5 algorithm
                                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5()
                                                self.md5.parent = self
                                                self._children_name_map["md5"] = "md5"
                                                self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, ['id'], name, value)


                                            class Md5(Entity):
                                                """
                                                Use MD5 algorithm
                                                
                                                .. attribute:: auth_type
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                .. attribute:: auth_key
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**length:** 1..16
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, self).__init__()

                                                    self.yang_name = "md5"
                                                    self.yang_parent_name = "message-digest-key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                    ])
                                                    self.auth_type = None
                                                    self.auth_key = None
                                                    self._segment_path = lambda: "md5"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                class HelloInterval(Entity):
                                    """
                                    Hello packet interval
                                    
                                    .. attribute:: hello_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.HelloInterval, self).__init__()

                                        self.yang_name = "hello-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hello_interval_value', (YLeaf(YType.int32, 'hello-interval-value'), ['int'])),
                                        ])
                                        self.hello_interval_value = None
                                        self._segment_path = lambda: "hello-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.HelloInterval, ['hello_interval_value'], name, value)


                                class DeadInterval(Entity):
                                    """
                                    Dead router detection time
                                    
                                    .. attribute:: dead_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.DeadInterval, self).__init__()

                                        self.yang_name = "dead-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dead_interval_value', (YLeaf(YType.uint16, 'dead-interval-value'), ['int'])),
                                        ])
                                        self.dead_interval_value = None
                                        self._segment_path = lambda: "dead-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.DeadInterval, ['dead_interval_value'], name, value)


                                class RetransmitInterval(Entity):
                                    """
                                    LSA retransmit interval
                                    
                                    .. attribute:: retransmit_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.RetransmitInterval, self).__init__()

                                        self.yang_name = "retransmit-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('retransmit_interval_value', (YLeaf(YType.uint16, 'retransmit-interval-value'), ['int'])),
                                        ])
                                        self.retransmit_interval_value = None
                                        self._segment_path = lambda: "retransmit-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.RetransmitInterval, ['retransmit_interval_value'], name, value)


                                class TransmitDelay(Entity):
                                    """
                                    LSA transmission delay
                                    
                                    .. attribute:: transmit_delay_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.TransmitDelay, self).__init__()

                                        self.yang_name = "transmit-delay"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('transmit_delay_value', (YLeaf(YType.uint16, 'transmit-delay-value'), ['int'])),
                                        ])
                                        self.transmit_delay_value = None
                                        self._segment_path = lambda: "transmit-delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.TransmitDelay, ['transmit_delay_value'], name, value)


                                class Topology(Entity):
                                    """
                                    Disable virtual link on topology
                                    
                                    .. attribute:: disable
                                    
                                    	Disable virtual link
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Topology, self).__init__()

                                        self.yang_name = "topology"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ])
                                        self.disable = None
                                        self._segment_path = lambda: "topology"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.Topology, ['disable'], name, value)


                                class TtlSecurity(Entity):
                                    """
                                    TTL security check
                                    
                                    .. attribute:: hops
                                    
                                    	IP hops
                                    	**type**\: int
                                    
                                    	**range:** 1..254
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.TtlSecurity, self).__init__()

                                        self.yang_name = "ttl-security"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                        ])
                                        self.hops = None
                                        self._segment_path = lambda: "ttl-security"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.TtlSecurity, ['hops'], name, value)


                                class AuthenticationKey(Entity):
                                    """
                                    Set authentication key
                                    
                                    .. attribute:: auth_type
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: auth_key
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.AuthenticationKey, self).__init__()

                                        self.yang_name = "authentication-key"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                            ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                        ])
                                        self.auth_type = None
                                        self.auth_key = None
                                        self._segment_path = lambda: "authentication-key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                class MessageDigestKey(Entity):
                                    """
                                    Set message digest key
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: md5
                                    
                                    	Use MD5 algorithm
                                    	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.MessageDigestKey.Md5>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.MessageDigestKey, self).__init__()

                                        self.yang_name = "message-digest-key"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.MessageDigestKey.Md5))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.MessageDigestKey.Md5()
                                        self.md5.parent = self
                                        self._children_name_map["md5"] = "md5"
                                        self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.MessageDigestKey, ['id'], name, value)


                                    class Md5(Entity):
                                        """
                                        Use MD5 algorithm
                                        
                                        .. attribute:: auth_type
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: auth_key
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**length:** 1..16
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.MessageDigestKey.Md5, self).__init__()

                                            self.yang_name = "md5"
                                            self.yang_parent_name = "message-digest-key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                            ])
                                            self.auth_type = None
                                            self.auth_key = None
                                            self._segment_path = lambda: "md5"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Area.VirtualLink.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                        class AutoCost(Entity):
                            """
                            Calculate OSPF interface cost according to bandwidth
                            
                            .. attribute:: reference_bandwidth
                            
                            	Use reference bandwidth method to assign OSPF cost
                            	**type**\: int
                            
                            	**range:** 1..4294967
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.AutoCost, self).__init__()

                                self.yang_name = "auto-cost"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('reference_bandwidth', (YLeaf(YType.uint32, 'reference-bandwidth'), ['int'])),
                                ])
                                self.reference_bandwidth = None
                                self._segment_path = lambda: "auto-cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.AutoCost, ['reference_bandwidth'], name, value)


                        class EventLog(Entity):
                            """
                            OSPF Event Logging
                            
                            .. attribute:: one_shot
                            
                            	Disable Logging When Log Buffer Becomes Full
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: pause
                            
                            	Pause Event Logging
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: size
                            
                            	Maximum Number of Events Stored in the Event Log
                            	**type**\: int
                            
                            	**range:** 1..65534
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.EventLog, self).__init__()

                                self.yang_name = "event-log"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('one_shot', (YLeaf(YType.empty, 'one-shot'), ['Empty'])),
                                    ('pause', (YLeaf(YType.empty, 'pause'), ['Empty'])),
                                    ('size', (YLeaf(YType.uint32, 'size'), ['int'])),
                                ])
                                self.one_shot = None
                                self.pause = None
                                self.size = None
                                self._segment_path = lambda: "event-log"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.EventLog, ['one_shot', 'pause', 'size'], name, value)


                        class Bfd(Entity):
                            """
                            BFD configuration commands
                            
                            .. attribute:: all_interfaces
                            
                            	Enable BFD on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                                ])
                                self.all_interfaces = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Bfd, ['all_interfaces'], name, value)


                        class InterfaceId(Entity):
                            """
                            Source of the interface ID
                            
                            .. attribute:: snmp_if_index
                            
                            	SNMP MIB ifIndex
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.InterfaceId, self).__init__()

                                self.yang_name = "interface-id"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('snmp_if_index', (YLeaf(YType.empty, 'snmp-if-index'), ['Empty'])),
                                ])
                                self.snmp_if_index = None
                                self._segment_path = lambda: "interface-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.InterfaceId, ['snmp_if_index'], name, value)


                        class LogAdjacencyChanges(Entity):
                            """
                            Log changes in adjacency state
                            
                            .. attribute:: detail
                            
                            	Log all state changes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.LogAdjacencyChanges, self).__init__()

                                self.yang_name = "log-adjacency-changes"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('detail', (YLeaf(YType.empty, 'detail'), ['Empty'])),
                                ])
                                self.detail = None
                                self._segment_path = lambda: "log-adjacency-changes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.LogAdjacencyChanges, ['detail'], name, value)


                        class MaxLsa(Entity):
                            """
                            maximum number of LSAs OSPF process will receive
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967294
                            
                            .. attribute:: threshold_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: ignore_count
                            
                            	maximum number of times adjacencies can be suppressed
                            	**type**\: int
                            
                            	**range:** 1..65534
                            
                            .. attribute:: ignore_time
                            
                            	time during which all adjacencies are suppressed
                            	**type**\: int
                            
                            	**range:** 1..17895
                            
                            .. attribute:: reset_time
                            
                            	time after which ignore\-count is reset to zero
                            	**type**\: int
                            
                            	**range:** 2..35791
                            
                            .. attribute:: warning_only
                            
                            	Only give warning message when limit is exceeded
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxLsa, self).__init__()

                                self.yang_name = "max-lsa"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                    ('threshold_value', (YLeaf(YType.uint32, 'threshold-value'), ['int'])),
                                    ('ignore_count', (YLeaf(YType.uint32, 'ignore-count'), ['int'])),
                                    ('ignore_time', (YLeaf(YType.uint32, 'ignore-time'), ['int'])),
                                    ('reset_time', (YLeaf(YType.uint32, 'reset-time'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                ])
                                self.number = None
                                self.threshold_value = None
                                self.ignore_count = None
                                self.ignore_time = None
                                self.reset_time = None
                                self.warning_only = None
                                self._segment_path = lambda: "max-lsa"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxLsa, ['number', 'threshold_value', 'ignore_count', 'ignore_time', 'reset_time', 'warning_only'], name, value)


                        class MaxMetric(Entity):
                            """
                            Set maximum metric
                            
                            .. attribute:: router_lsa
                            
                            	Maximum metric in self\-originated router\-LSAs
                            	**type**\:  :py:class:`RouterLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric, self).__init__()

                                self.yang_name = "max-metric"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("router-lsa", ("router_lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa))])
                                self._leafs = OrderedDict()

                                self.router_lsa = None
                                self._children_name_map["router_lsa"] = "router-lsa"
                                self._segment_path = lambda: "max-metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric, [], name, value)


                            class RouterLsa(Entity):
                                """
                                Maximum metric in self\-originated router\-LSAs
                                
                                .. attribute:: external_lsa
                                
                                	Override external\-lsa metric with max\-metric value
                                	**type**\:  :py:class:`ExternalLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.ExternalLsa>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: include_stub
                                
                                	Set maximum metric for stub links in router\-LSAs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: on_startup
                                
                                	Set maximum metric temporarily after reboot
                                	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.OnStartup>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: summary_lsa
                                
                                	Override summary\-lsa metric with max\-metric value
                                	**type**\:  :py:class:`SummaryLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.SummaryLsa>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa, self).__init__()

                                    self.yang_name = "router-lsa"
                                    self.yang_parent_name = "max-metric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("external-lsa", ("external_lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.ExternalLsa)), ("on-startup", ("on_startup", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.OnStartup)), ("summary-lsa", ("summary_lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.SummaryLsa))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('include_stub', (YLeaf(YType.empty, 'include-stub'), ['Empty'])),
                                    ])
                                    self.include_stub = None

                                    self.external_lsa = None
                                    self._children_name_map["external_lsa"] = "external-lsa"

                                    self.on_startup = None
                                    self._children_name_map["on_startup"] = "on-startup"

                                    self.summary_lsa = None
                                    self._children_name_map["summary_lsa"] = "summary-lsa"
                                    self._segment_path = lambda: "router-lsa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa, ['include_stub'], name, value)


                                class ExternalLsa(Entity):
                                    """
                                    Override external\-lsa metric with max\-metric value
                                    
                                    .. attribute:: metric
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..16777215
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.ExternalLsa, self).__init__()

                                        self.yang_name = "external-lsa"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.metric = None
                                        self._segment_path = lambda: "external-lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.ExternalLsa, ['metric'], name, value)


                                class OnStartup(Entity):
                                    """
                                    Set maximum metric temporarily after reboot
                                    
                                    .. attribute:: time
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 5..86400
                                    
                                    .. attribute:: wait_for_bgp
                                    
                                    	Let BGP decide when to originate router\-LSA with normal metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.OnStartup, self).__init__()

                                        self.yang_name = "on-startup"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                            ('wait_for_bgp', (YLeaf(YType.empty, 'wait-for-bgp'), ['Empty'])),
                                        ])
                                        self.time = None
                                        self.wait_for_bgp = None
                                        self._segment_path = lambda: "on-startup"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.OnStartup, ['time', 'wait_for_bgp'], name, value)


                                class SummaryLsa(Entity):
                                    """
                                    Override summary\-lsa metric with max\-metric value
                                    
                                    .. attribute:: metric
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..16777215
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.SummaryLsa, self).__init__()

                                        self.yang_name = "summary-lsa"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.metric = None
                                        self._segment_path = lambda: "summary-lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.MaxMetric.RouterLsa.SummaryLsa, ['metric'], name, value)


                        class PassiveInterface(Entity):
                            """
                            Suppress routing updates on an interface
                            
                            .. attribute:: default
                            
                            	Suppress routing updates on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: interface
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.PassiveInterface, self).__init__()

                                self.yang_name = "passive-interface"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ])
                                self.default = None
                                self.interface = None
                                self._segment_path = lambda: "passive-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.PassiveInterface, [u'default', u'interface'], name, value)


                        class Disable(Entity):
                            """
                            
                            
                            .. attribute:: passive_interface
                            
                            	
                            	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Disable.PassiveInterface>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Disable, self).__init__()

                                self.yang_name = "disable"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Disable.PassiveInterface))])
                                self._leafs = OrderedDict()

                                self.passive_interface = YList(self)
                                self._segment_path = lambda: "disable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Disable, [], name, value)


                            class PassiveInterface(Entity):
                                """
                                
                                
                                .. attribute:: interface  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Disable.PassiveInterface, self).__init__()

                                    self.yang_name = "passive-interface"
                                    self.yang_parent_name = "disable"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ])
                                    self.interface = None
                                    self._segment_path = lambda: "passive-interface" + "[interface='" + str(self.interface) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Disable.PassiveInterface, [u'interface'], name, value)


                        class QueueDepth(Entity):
                            """
                            OSPF Hello/Router process queue depth
                            
                            .. attribute:: hello
                            
                            	OSPF Hello process queue depth
                            	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth.Hello>`
                            
                            .. attribute:: update
                            
                            	OSPF Router process queue depth
                            	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth.Update>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth, self).__init__()

                                self.yang_name = "queue-depth"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hello", ("hello", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth.Hello)), ("update", ("update", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth.Update))])
                                self._leafs = OrderedDict()

                                self.hello = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth.Hello()
                                self.hello.parent = self
                                self._children_name_map["hello"] = "hello"

                                self.update = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth.Update()
                                self.update.parent = self
                                self._children_name_map["update"] = "update"
                                self._segment_path = lambda: "queue-depth"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth, [], name, value)


                            class Hello(Entity):
                                """
                                OSPF Hello process queue depth
                                
                                .. attribute:: options
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..2147483647
                                
                                		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth.Hello, self).__init__()

                                    self.yang_name = "hello"
                                    self.yang_parent_name = "queue-depth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                                    ])
                                    self.options = None
                                    self._segment_path = lambda: "hello"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth.Hello, ['options'], name, value)

                                class Options(Enum):
                                    """
                                    Options (Enum Class)

                                    .. data:: unlimited = 0

                                    """

                                    unlimited = Enum.YLeaf(0, "unlimited")



                            class Update(Entity):
                                """
                                OSPF Router process queue depth
                                
                                .. attribute:: options
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..2147483647
                                
                                		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth.Update, self).__init__()

                                    self.yang_name = "update"
                                    self.yang_parent_name = "queue-depth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                                    ])
                                    self.options = None
                                    self._segment_path = lambda: "update"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.QueueDepth.Update, ['options'], name, value)

                                class Options(Enum):
                                    """
                                    Options (Enum Class)

                                    .. data:: unlimited = 0

                                    """

                                    unlimited = Enum.YLeaf(0, "unlimited")



                        class Timers(Entity):
                            """
                            Adjust routing timers
                            
                            .. attribute:: lsa
                            
                            	OSPF LSA timers
                            	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Lsa>`
                            
                            .. attribute:: pacing
                            
                            	OSPF pacing timers
                            	**type**\:  :py:class:`Pacing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Pacing>`
                            
                            .. attribute:: throttle
                            
                            	OSPF throttle timers
                            	**type**\:  :py:class:`Throttle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Lsa)), ("pacing", ("pacing", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Pacing)), ("throttle", ("throttle", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle))])
                                self._leafs = OrderedDict()

                                self.lsa = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Lsa()
                                self.lsa.parent = self
                                self._children_name_map["lsa"] = "lsa"

                                self.pacing = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Pacing()
                                self.pacing.parent = self
                                self._children_name_map["pacing"] = "pacing"

                                self.throttle = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle()
                                self.throttle.parent = self
                                self._children_name_map["throttle"] = "throttle"
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers, [], name, value)


                            class Lsa(Entity):
                                """
                                OSPF LSA timers
                                
                                .. attribute:: arrival
                                
                                	OSPF LSA arrival timer
                                	**type**\: int
                                
                                	**range:** 0..600000
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('arrival', (YLeaf(YType.uint32, 'arrival'), ['int'])),
                                    ])
                                    self.arrival = None
                                    self._segment_path = lambda: "lsa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Lsa, ['arrival'], name, value)


                            class Pacing(Entity):
                                """
                                OSPF pacing timers
                                
                                .. attribute:: flood
                                
                                	OSPF flood pacing timer
                                	**type**\: int
                                
                                	**range:** 5..100
                                
                                .. attribute:: lsa_group
                                
                                	OSPF LSA group pacing timer
                                	**type**\: int
                                
                                	**range:** 10..1800
                                
                                .. attribute:: retransmission
                                
                                	OSPF retransmission pacing timer
                                	**type**\: int
                                
                                	**range:** 5..200
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Pacing, self).__init__()

                                    self.yang_name = "pacing"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('flood', (YLeaf(YType.uint32, 'flood'), ['int'])),
                                        ('lsa_group', (YLeaf(YType.uint32, 'lsa-group'), ['int'])),
                                        ('retransmission', (YLeaf(YType.uint32, 'retransmission'), ['int'])),
                                    ])
                                    self.flood = None
                                    self.lsa_group = None
                                    self.retransmission = None
                                    self._segment_path = lambda: "pacing"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Pacing, ['flood', 'lsa_group', 'retransmission'], name, value)


                            class Throttle(Entity):
                                """
                                OSPF throttle timers
                                
                                .. attribute:: lsa
                                
                                	OSPF LSA throttle timers
                                	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Lsa>`
                                
                                .. attribute:: spf
                                
                                	OSPF SPF throttle timers
                                	**type**\:  :py:class:`Spf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Spf>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle, self).__init__()

                                    self.yang_name = "throttle"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Lsa)), ("spf", ("spf", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Spf))])
                                    self._leafs = OrderedDict()

                                    self.lsa = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Lsa()
                                    self.lsa.parent = self
                                    self._children_name_map["lsa"] = "lsa"

                                    self.spf = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Spf()
                                    self.spf.parent = self
                                    self._children_name_map["spf"] = "spf"
                                    self._segment_path = lambda: "throttle"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle, [], name, value)


                                class Lsa(Entity):
                                    """
                                    OSPF LSA throttle timers
                                    
                                    .. attribute:: all
                                    
                                    	For all type of OSPF LSAs
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Lsa.All>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "throttle"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Lsa.All))])
                                        self._leafs = OrderedDict()

                                        self.all = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Lsa.All()
                                        self.all.parent = self
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Lsa, [], name, value)


                                    class All(Entity):
                                        """
                                        For all type of OSPF LSAs
                                        
                                        .. attribute:: delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        .. attribute:: min_delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        .. attribute:: max_delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Lsa.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                                ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                            ])
                                            self.delay = None
                                            self.min_delay = None
                                            self.max_delay = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Lsa.All, ['delay', 'min_delay', 'max_delay'], name, value)


                                class Spf(Entity):
                                    """
                                    OSPF SPF throttle timers
                                    
                                    .. attribute:: delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    .. attribute:: min_delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    .. attribute:: max_delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Spf, self).__init__()

                                        self.yang_name = "spf"
                                        self.yang_parent_name = "throttle"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                            ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                            ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                        ])
                                        self.delay = None
                                        self.min_delay = None
                                        self.max_delay = None
                                        self._segment_path = lambda: "spf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Timers.Throttle.Spf, ['delay', 'min_delay', 'max_delay'], name, value)


                        class TrafficShare(Entity):
                            """
                            How to compute traffic share over alternate paths
                            
                            .. attribute:: min
                            
                            	All traffic shared among min metric paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: across_interfaces
                            
                            	Use different interfaces for equal\-cost paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.TrafficShare, self).__init__()

                                self.yang_name = "traffic-share"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                                ])
                                self.min = None
                                self.across_interfaces = None
                                self._segment_path = lambda: "traffic-share"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.TrafficShare, ['min', 'across_interfaces'], name, value)


                        class TtlSecurity(Entity):
                            """
                            TTL security check
                            
                            .. attribute:: all_interfaces
                            
                            	Enable TTL Security on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: hops
                            
                            	IP hops
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.TtlSecurity, self).__init__()

                                self.yang_name = "ttl-security"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                                    ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                ])
                                self.all_interfaces = None
                                self.hops = None
                                self._segment_path = lambda: "ttl-security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.TtlSecurity, ['all_interfaces', 'hops'], name, value)


                        class Capability(Entity):
                            """
                            Enable specific OSPF feature
                            
                            .. attribute:: capability_type
                            
                            	
                            	**type**\:  :py:class:`CapabilityType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Capability.CapabilityType>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('capability_type', (YLeaf(YType.enumeration, 'capability-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Capability.CapabilityType')])),
                                ])
                                self.capability_type = None
                                self._segment_path = lambda: "capability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Capability, ['capability_type'], name, value)

                            class CapabilityType(Enum):
                                """
                                CapabilityType (Enum Class)

                                .. data:: lls = 0

                                .. data:: opaque = 1

                                .. data:: transit = 2

                                .. data:: vrf_lite = 3

                                """

                                lls = Enum.YLeaf(0, "lls")

                                opaque = Enum.YLeaf(1, "opaque")

                                transit = Enum.YLeaf(2, "transit")

                                vrf_lite = Enum.YLeaf(3, "vrf-lite")



                        class Compatible(Entity):
                            """
                            OSPF compatibility list
                            
                            .. attribute:: rfc1583
                            
                            	Compatible with RFC 1583
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rfc1587
                            
                            	Compatible with RFC 1587
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rfc5243
                            
                            	Compatible with RFC 5243
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Compatible, self).__init__()

                                self.yang_name = "compatible"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rfc1583', (YLeaf(YType.empty, 'rfc1583'), ['Empty'])),
                                    ('rfc1587', (YLeaf(YType.empty, 'rfc1587'), ['Empty'])),
                                    ('rfc5243', (YLeaf(YType.empty, 'rfc5243'), ['Empty'])),
                                ])
                                self.rfc1583 = None
                                self.rfc1587 = None
                                self.rfc5243 = None
                                self._segment_path = lambda: "compatible"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Compatible, ['rfc1583', 'rfc1587', 'rfc5243'], name, value)


                        class DefaultInformation(Entity):
                            """
                            Control distribution of default information
                            
                            .. attribute:: originate
                            
                            	Distribute a default route
                            	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DefaultInformation.Originate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DefaultInformation, self).__init__()

                                self.yang_name = "default-information"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("originate", ("originate", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DefaultInformation.Originate))])
                                self._leafs = OrderedDict()

                                self.originate = None
                                self._children_name_map["originate"] = "originate"
                                self._segment_path = lambda: "default-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DefaultInformation, [], name, value)


                            class Originate(Entity):
                                """
                                Distribute a default route
                                
                                .. attribute:: always
                                
                                	Always advertise default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: metric
                                
                                	OSPF default metric
                                	**type**\: int
                                
                                	**range:** 0..16777214
                                
                                .. attribute:: metric_type
                                
                                	OSPF metric type for default routes
                                	**type**\: int
                                
                                	**range:** 1..2
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DefaultInformation.Originate, self).__init__()

                                    self.yang_name = "originate"
                                    self.yang_parent_name = "default-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.uint32, 'metric-type'), ['int'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.always = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "originate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DefaultInformation.Originate, ['always', 'metric', 'metric_type', 'route_map'], name, value)


                        class DiscardRoute(Entity):
                            """
                            Enable or disable discard\-route installation
                            
                            .. attribute:: external
                            
                            	Discard route for redistributed summarised routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: internal
                            
                            	Discard route for summarised internal routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: metric
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DiscardRoute, self).__init__()

                                self.yang_name = "discard-route"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ])
                                self.external = None
                                self.internal = None
                                self.metric = None
                                self._segment_path = lambda: "discard-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.DiscardRoute, ['external', 'internal', 'metric'], name, value)


                        class Distance(Entity):
                            """
                            Define an administrative distance
                            
                            .. attribute:: ospf_distance
                            
                            	
                            	**type**\:  :py:class:`OspfDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance.OspfDistance>`
                            
                            .. attribute:: ospf
                            
                            	OSPF routes Administrative distance
                            	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance.Ospf>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ospf-distance", ("ospf_distance", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance.OspfDistance)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance.Ospf))])
                                self._leafs = OrderedDict()

                                self.ospf_distance = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance.OspfDistance()
                                self.ospf_distance.parent = self
                                self._children_name_map["ospf_distance"] = "ospf-distance"

                                self.ospf = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance.Ospf()
                                self.ospf.parent = self
                                self._children_name_map["ospf"] = "ospf"
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance, [], name, value)


                            class OspfDistance(Entity):
                                """
                                
                                
                                .. attribute:: distance
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: ip
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: wildcard
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..99
                                
                                		**type**\: int
                                
                                			**range:** 1300..1999
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance.OspfDistance, self).__init__()

                                    self.yang_name = "ospf-distance"
                                    self.yang_parent_name = "distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                        ('wildcard', (YLeaf(YType.str, 'wildcard'), ['str'])),
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','int','str'])),
                                    ])
                                    self.distance = None
                                    self.ip = None
                                    self.wildcard = None
                                    self.acl_name = None
                                    self._segment_path = lambda: "ospf-distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance.OspfDistance, ['distance', 'ip', 'wildcard', 'acl_name'], name, value)


                            class Ospf(Entity):
                                """
                                OSPF routes Administrative distance
                                
                                .. attribute:: external
                                
                                	External routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: inter_area
                                
                                	Inter\-area routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: intra_area
                                
                                	Intra\-area routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('external', (YLeaf(YType.uint32, 'external'), ['int'])),
                                        ('inter_area', (YLeaf(YType.uint32, 'inter-area'), ['int'])),
                                        ('intra_area', (YLeaf(YType.uint32, 'intra-area'), ['int'])),
                                    ])
                                    self.external = None
                                    self.inter_area = None
                                    self.intra_area = None
                                    self._segment_path = lambda: "ospf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Distance.Ospf, ['external', 'inter_area', 'intra_area'], name, value)


                        class Redistribute(Entity):
                            """
                            Redistribute information from another routing protocol
                            
                            .. attribute:: application
                            
                            	Application
                            	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Application>`
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: iso_igrp
                            
                            	IGRP for OSI networks
                            	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: lisp
                            
                            	Locator ID Separation Protocol (LISP)
                            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp>`
                            
                            .. attribute:: mobile
                            
                            	Mobile routes
                            	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Mobile>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: odr
                            
                            	On Demand stub Routes
                            	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Odr>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Rip>`
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Static>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes redistributed to protocol
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.MaximumPrefix>`
                            
                            .. attribute:: vrf
                            
                            	Specify a source VRF
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute, self).__init__()

                                self.yang_name = "redistribute"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Static)), ("maximum-prefix", ("maximum_prefix", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.MaximumPrefix)), ("vrf", ("vrf", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf))])
                                self._leafs = OrderedDict()

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.isis = None
                                self._children_name_map["isis"] = "isis"

                                self.iso_igrp = None
                                self._children_name_map["iso_igrp"] = "iso-igrp"

                                self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp()
                                self.lisp.parent = self
                                self._children_name_map["lisp"] = "lisp"

                                self.mobile = None
                                self._children_name_map["mobile"] = "mobile"

                                self.odr = None
                                self._children_name_map["odr"] = "odr"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.maximum_prefix = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.vrf = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.application = YList(self)
                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self.rip = YList(self)
                                self._segment_path = lambda: "redistribute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute, [], name, value)


                            class Application(Entity):
                                """
                                Application
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Application.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Application, self).__init__()

                                    self.yang_name = "application"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Application.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Application.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Application, ['name'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Application.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Application.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "application"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Application.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Bgp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Bgp.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                    ])
                                    self.as_number = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Bgp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Bgp, ['as_number'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Bgp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Bgp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Bgp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Connected.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Connected.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Connected.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Connected, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Connected.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Connected.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Connected.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Eigrp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Eigrp.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                    ])
                                    self.as_number = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Eigrp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Eigrp, ['as_number'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Eigrp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Eigrp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Eigrp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: isis_level_routes
                                
                                	
                                	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisLevelRoutes>`
                                
                                .. attribute:: isis_area
                                
                                	
                                	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea>`
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisLevelRoutes')])),
                                    ])
                                    self.isis_level_routes = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"

                                    self.isis_area = YList(self)
                                    self._segment_path = lambda: "isis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis, ['isis_level_routes'], name, value)

                                class IsisLevelRoutes(Enum):
                                    """
                                    IsisLevelRoutes (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    .. data:: level_1_2 = 2

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")

                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class IsisArea(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: isis_level_routes
                                    
                                    	
                                    	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea.IsisLevelRoutes>`
                                    
                                    .. attribute:: redist_options
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea.RedistOptions>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea, self).__init__()

                                        self.yang_name = "isis-area"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea.RedistOptions))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea.IsisLevelRoutes')])),
                                        ])
                                        self.name = None
                                        self.isis_level_routes = None

                                        self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea.RedistOptions()
                                        self.redist_options.parent = self
                                        self._children_name_map["redist_options"] = "redist-options"
                                        self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                    class IsisLevelRoutes(Enum):
                                        """
                                        IsisLevelRoutes (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        .. data:: level_1_2 = 2

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")

                                        level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class RedistOptions(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea.RedistOptions.MetricType>`
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea.RedistOptions, self).__init__()

                                            self.yang_name = "redist-options"
                                            self.yang_parent_name = "isis-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea.RedistOptions.MetricType')])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.tag = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.nssa_only = None
                                            self._segment_path = lambda: "redist-options"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class IsoIgrp(Entity):
                                """
                                IGRP for OSI networks
                                
                                .. attribute:: area_tag_route_map_container
                                
                                	
                                	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.AreaTagRouteMapContainer>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: iso_igrp_container
                                
                                	
                                	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp, self).__init__()

                                    self.yang_name = "iso-igrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.AreaTagRouteMapContainer()
                                    self.area_tag_route_map_container.parent = self
                                    self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                    self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer()
                                    self.iso_igrp_container.parent = self
                                    self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                    self._segment_path = lambda: "iso-igrp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp, ['route_map'], name, value)


                                class AreaTagRouteMapContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: area_tag
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                        self.yang_name = "area-tag-route-map-container"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.area_tag = None
                                        self.route_map = None
                                        self._segment_path = lambda: "area-tag-route-map-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                class IsoIgrpContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer, self).__init__()

                                        self.yang_name = "iso-igrp-container"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self._segment_path = lambda: "iso-igrp-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Lisp(Entity):
                                """
                                Locator ID Separation Protocol (LISP)
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp, self).__init__()

                                    self.yang_name = "lisp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp.RedistOptions))])
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "lisp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "lisp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Mobile(Entity):
                                """
                                Mobile routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Mobile.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Mobile, self).__init__()

                                    self.yang_name = "mobile"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Mobile.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Mobile.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "mobile"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Mobile, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Mobile.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Mobile.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "mobile"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Mobile.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Odr(Entity):
                                """
                                On Demand stub Routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Odr.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Odr, self).__init__()

                                    self.yang_name = "odr"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Odr.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Odr.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "odr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Odr, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Odr.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Odr.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "odr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Odr.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match>`
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.MetricType>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.MetricType')])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.id = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.nssa_only = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.tag = None
                                    self.vrf = None

                                    self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.Internal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.Internal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.External.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.External.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.NssaExternal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.NssaExternal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.nssa_external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                            class Ospfv3_(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match>`
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.MetricType>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.MetricType')])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ])
                                    self.id = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.nssa_only = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.tag = None

                                    self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.Internal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.Internal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.External.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.External.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.NssaExternal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.nssa_external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: id  (key)
                                
                                	User selected string identifying this rip process
                                	**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Rip.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Rip.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Rip.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Rip, ['id'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Rip.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Rip.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Rip.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Static.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Static.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Static.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Static, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Static.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Static.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Static.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes redistributed to protocol
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: threshold_warning_only_container
                                
                                	
                                	**type**\:  :py:class:`ThresholdWarningOnlyContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("threshold-warning-only-container", ("threshold_warning_only_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                    ])
                                    self.number = None

                                    self.threshold_warning_only_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer()
                                    self.threshold_warning_only_container.parent = self
                                    self._children_name_map["threshold_warning_only_container"] = "threshold-warning-only-container"
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.MaximumPrefix, ['number'], name, value)


                                class ThresholdWarningOnlyContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer, self).__init__()

                                        self.yang_name = "threshold-warning-only-container"
                                        self.yang_parent_name = "maximum-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.threshold = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "threshold-warning-only-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer, ['threshold', 'warning_only'], name, value)


                            class Vrf(Entity):
                                """
                                Specify a source VRF
                                
                                .. attribute:: non_global_vrf
                                
                                	
                                	**type**\: list of  		 :py:class:`NonGlobalVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf>`
                                
                                .. attribute:: global_
                                
                                	global VRF
                                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("non-global-vrf", ("non_global_vrf", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf)), ("global", ("global_", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global))])
                                    self._leafs = OrderedDict()

                                    self.global_ = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"

                                    self.non_global_vrf = YList(self)
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf, [], name, value)


                                class NonGlobalVrf(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator ID Separation Protocol (LISP)
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf, self).__init__()

                                        self.yang_name = "non-global-vrf"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Static))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.iso_igrp = None
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp()
                                        self.lisp.parent = self
                                        self._children_name_map["lisp"] = "lisp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.application = YList(self)
                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "non-global-vrf" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf, ['name'], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Application, ['name'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_level_routes
                                        
                                        	
                                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisLevelRoutes>`
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea>`
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisLevelRoutes')])),
                                            ])
                                            self.isis_level_routes = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis, ['isis_level_routes'], name, value)

                                        class IsisLevelRoutes(Enum):
                                            """
                                            IsisLevelRoutes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: isis_level_routes
                                            
                                            	
                                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.IsisLevelRoutes>`
                                            
                                            .. attribute:: redist_options
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.IsisLevelRoutes')])),
                                                ])
                                                self.name = None
                                                self.isis_level_routes = None

                                                self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions()
                                                self.redist_options.parent = self
                                                self._children_name_map["redist_options"] = "redist-options"
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                            class IsisLevelRoutes(Enum):
                                                """
                                                IsisLevelRoutes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class RedistOptions(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions.MetricType>`
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions, self).__init__()

                                                    self.yang_name = "redist-options"
                                                    self.yang_parent_name = "isis-area"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions.MetricType')])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.tag = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.nssa_only = None
                                                    self._segment_path = lambda: "redist-options"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: area_tag_route_map_container
                                        
                                        	
                                        	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: iso_igrp_container
                                        
                                        	
                                        	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer()
                                            self.area_tag_route_map_container.parent = self
                                            self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                            self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer()
                                            self.iso_igrp_container.parent = self
                                            self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp, ['route_map'], name, value)


                                        class AreaTagRouteMapContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: area_tag
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                                self.yang_name = "area-tag-route-map-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.area_tag = None
                                                self.route_map = None
                                                self._segment_path = lambda: "area-tag-route-map-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                        class IsoIgrpContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer, self).__init__()

                                                self.yang_name = "iso-igrp-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self._segment_path = lambda: "iso-igrp-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Lisp(Entity):
                                        """
                                        Locator ID Separation Protocol (LISP)
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions))])
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "lisp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "mobile"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "odr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self.vrf = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Ospfv3_(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this rip process
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip, ['id'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Static, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.NonGlobalVrf.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                class Global(Entity):
                                    """
                                    global VRF
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator ID Separation Protocol (LISP)
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.iso_igrp = None
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp()
                                        self.lisp.parent = self
                                        self._children_name_map["lisp"] = "lisp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.application = YList(self)
                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "global"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Application.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Application.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Application.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Application, ['name'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Application.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Application.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Application.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Bgp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Connected, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Eigrp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_level_routes
                                        
                                        	
                                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisLevelRoutes>`
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea>`
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisLevelRoutes')])),
                                            ])
                                            self.isis_level_routes = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis, ['isis_level_routes'], name, value)

                                        class IsisLevelRoutes(Enum):
                                            """
                                            IsisLevelRoutes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: isis_level_routes
                                            
                                            	
                                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.IsisLevelRoutes>`
                                            
                                            .. attribute:: redist_options
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.IsisLevelRoutes')])),
                                                ])
                                                self.name = None
                                                self.isis_level_routes = None

                                                self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions()
                                                self.redist_options.parent = self
                                                self._children_name_map["redist_options"] = "redist-options"
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                            class IsisLevelRoutes(Enum):
                                                """
                                                IsisLevelRoutes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class RedistOptions(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions.MetricType>`
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions, self).__init__()

                                                    self.yang_name = "redist-options"
                                                    self.yang_parent_name = "isis-area"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions.MetricType')])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.tag = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.nssa_only = None
                                                    self._segment_path = lambda: "redist-options"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: area_tag_route_map_container
                                        
                                        	
                                        	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: iso_igrp_container
                                        
                                        	
                                        	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer()
                                            self.area_tag_route_map_container.parent = self
                                            self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                            self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer()
                                            self.iso_igrp_container.parent = self
                                            self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp, ['route_map'], name, value)


                                        class AreaTagRouteMapContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: area_tag
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                                self.yang_name = "area-tag-route-map-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.area_tag = None
                                                self.route_map = None
                                                self._segment_path = lambda: "area-tag-route-map-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                        class IsoIgrpContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer, self).__init__()

                                                self.yang_name = "iso-igrp-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self._segment_path = lambda: "iso-igrp-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Lisp(Entity):
                                        """
                                        Locator ID Separation Protocol (LISP)
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions))])
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "lisp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Mobile, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "mobile"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Odr, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "odr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self.vrf = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Ospfv3_(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this rip process
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Rip, ['id'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Static.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Static.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Static.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Static, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Static.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Static.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Static.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Redistribute.Vrf.Global.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                        class Authentication(Entity):
                            """
                            Authentication parameters
                            
                            .. attribute:: mode
                            
                            	Authentication operation mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Authentication.Mode>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Authentication.Mode')])),
                                ])
                                self.mode = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Authentication, [u'mode'], name, value)

                            class Mode(Enum):
                                """
                                Mode (Enum Class)

                                Authentication operation mode

                                .. data:: deployment = 0

                                .. data:: normal = 1

                                .. data:: strict = 2

                                """

                                deployment = Enum.YLeaf(0, "deployment")

                                normal = Enum.YLeaf(1, "normal")

                                strict = Enum.YLeaf(2, "strict")



                        class GracefulRestart(Entity):
                            """
                            Graceful\-restart options
                            
                            .. attribute:: disable
                            
                            	Graceful restart disable
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: helper
                            
                            	helper support
                            	**type**\:  :py:class:`Helper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.GracefulRestart.Helper>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: restart_interval
                            
                            	Graceful restart interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.GracefulRestart, self).__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("helper", ("helper", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.GracefulRestart.Helper))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('restart_interval', (YLeaf(YType.uint16, 'restart-interval'), ['int'])),
                                ])
                                self.disable = None
                                self.restart_interval = None

                                self.helper = None
                                self._children_name_map["helper"] = "helper"
                                self._segment_path = lambda: "graceful-restart"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.GracefulRestart, [u'disable', u'restart_interval'], name, value)


                            class Helper(Entity):
                                """
                                helper support
                                
                                .. attribute:: disable
                                
                                	disable helper support
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: strict_lsa_checking
                                
                                	enable helper strict LSA checking
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.GracefulRestart.Helper, self).__init__()

                                    self.yang_name = "helper"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ('strict_lsa_checking', (YLeaf(YType.empty, 'strict-lsa-checking'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self.strict_lsa_checking = None
                                    self._segment_path = lambda: "helper"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.GracefulRestart.Helper, [u'disable', u'strict_lsa_checking'], name, value)


                        class Manet(Entity):
                            """
                            Specify MANET OSPF parameters
                            
                            .. attribute:: cache
                            
                            	Specify MANET cache sizes
                            	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Cache>`
                            
                            .. attribute:: hello
                            
                            	Unicast Hellos rather than multicast
                            	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Hello>`
                            
                            .. attribute:: peering
                            
                            	MANET OSPF Smart Peering
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Peering>`
                            
                            .. attribute:: willingness
                            
                            	Specify Relay willingness value
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cache", ("cache", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Cache)), ("peering", ("peering", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Peering))])
                                self._leafs = OrderedDict([
                                    ('hello', (YLeaf(YType.enumeration, 'hello'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Hello')])),
                                    ('willingness', (YLeaf(YType.uint8, 'willingness'), ['int'])),
                                ])
                                self.hello = None
                                self.willingness = None

                                self.cache = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Cache()
                                self.cache.parent = self
                                self._children_name_map["cache"] = "cache"

                                self.peering = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet, [u'hello', u'willingness'], name, value)

                            class Hello(Enum):
                                """
                                Hello (Enum Class)

                                Unicast Hellos rather than multicast

                                .. data:: unicast = 0

                                .. data:: multicast = 1

                                """

                                unicast = Enum.YLeaf(0, "unicast")

                                multicast = Enum.YLeaf(1, "multicast")



                            class Cache(Entity):
                                """
                                Specify MANET cache sizes
                                
                                .. attribute:: acknowledgement
                                
                                	Specify MANET acknowledgement cache size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update
                                
                                	Specify MANET LSA cache size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Cache, self).__init__()

                                    self.yang_name = "cache"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acknowledgement', (YLeaf(YType.uint64, 'acknowledgement'), ['int'])),
                                        ('update', (YLeaf(YType.uint64, 'update'), ['int'])),
                                    ])
                                    self.acknowledgement = None
                                    self.update = None
                                    self._segment_path = lambda: "cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Cache, [u'acknowledgement', u'update'], name, value)


                            class Peering(Entity):
                                """
                                MANET OSPF Smart Peering
                                
                                .. attribute:: selective
                                
                                	Enable selective peering
                                	**type**\:  :py:class:`Selective <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Peering.Selective>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("selective", ("selective", Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Peering.Selective))])
                                    self._leafs = OrderedDict()

                                    self.selective = Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Peering.Selective()
                                    self.selective.parent = self
                                    self._children_name_map["selective"] = "selective"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Peering, [], name, value)


                                class Selective(Entity):
                                    """
                                    Enable selective peering
                                    
                                    .. attribute:: disable
                                    
                                    	Disable selective peering
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: per_interface
                                    
                                    	Select peers per interface rather than per node
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: redundancy
                                    
                                    	Redundant paths
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Peering.Selective, self).__init__()

                                        self.yang_name = "selective"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ('per_interface', (YLeaf(YType.empty, 'per-interface'), ['Empty'])),
                                            ('redundancy', (YLeaf(YType.uint8, 'redundancy'), ['int'])),
                                        ])
                                        self.disable = None
                                        self.per_interface = None
                                        self.redundancy = None
                                        self._segment_path = lambda: "selective"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.Manet.Peering.Selective, [u'disable', u'per_interface', u'redundancy'], name, value)


                        class SummaryPrefix(Entity):
                            """
                            Configure IPv6 summary prefix
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: nssa_only
                            
                            	Limit summary to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: tag
                            
                            	Set tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: not_advertise
                            
                            	Do not advertise when translating OSPF type\-7 LSA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.SummaryPrefix, self).__init__()

                                self.yang_name = "summary-prefix"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                ])
                                self.prefix = None
                                self.nssa_only = None
                                self.tag = None
                                self.not_advertise = None
                                self._segment_path = lambda: "summary-prefix" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Unicast.SummaryPrefix, [u'prefix', u'nssa_only', u'tag', u'not_advertise'], name, value)


                    class Vrf(Entity):
                        """
                        Specify parameters for a VPN Routing/Forwarding instance
                        
                        .. attribute:: vrf  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: unicast
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: area
                        
                        	OSPF area parameters
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area>`
                        
                        .. attribute:: auto_cost
                        
                        	Calculate OSPF interface cost according to bandwidth
                        	**type**\:  :py:class:`AutoCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.AutoCost>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: event_log
                        
                        	OSPF Event Logging
                        	**type**\:  :py:class:`EventLog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.EventLog>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: bfd
                        
                        	BFD configuration commands
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Bfd>`
                        
                        .. attribute:: interface_id
                        
                        	Source of the interface ID
                        	**type**\:  :py:class:`InterfaceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.InterfaceId>`
                        
                        .. attribute:: log_adjacency_changes
                        
                        	Log changes in adjacency state
                        	**type**\:  :py:class:`LogAdjacencyChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.LogAdjacencyChanges>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: max_lsa
                        
                        	maximum number of LSAs OSPF process will receive
                        	**type**\:  :py:class:`MaxLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxLsa>`
                        
                        .. attribute:: max_metric
                        
                        	Set maximum metric
                        	**type**\:  :py:class:`MaxMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric>`
                        
                        .. attribute:: passive_interface
                        
                        	Suppress routing updates on an interface
                        	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.PassiveInterface>`
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Disable>`
                        
                        .. attribute:: queue_depth
                        
                        	OSPF Hello/Router process queue depth
                        	**type**\:  :py:class:`QueueDepth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth>`
                        
                        .. attribute:: timers
                        
                        	Adjust routing timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers>`
                        
                        .. attribute:: router_id
                        
                        	Override configured router identifier (peers will reset)
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nsr
                        
                        	Enable non\-stop routing
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: traffic_share
                        
                        	How to compute traffic share over alternate paths
                        	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.TrafficShare>`
                        
                        .. attribute:: ttl_security
                        
                        	TTL security check
                        	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.TtlSecurity>`
                        
                        .. attribute:: capability
                        
                        	Enable specific OSPF feature
                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Capability>`
                        
                        .. attribute:: compatible
                        
                        	OSPF compatibility list
                        	**type**\:  :py:class:`Compatible <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Compatible>`
                        
                        .. attribute:: default_information
                        
                        	Control distribution of default information
                        	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DefaultInformation>`
                        
                        .. attribute:: default_metric
                        
                        	Set metric of redistributed routes
                        	**type**\: int
                        
                        	**range:** 1..16777214
                        
                        .. attribute:: discard_route
                        
                        	Enable or disable discard\-route installation
                        	**type**\:  :py:class:`DiscardRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DiscardRoute>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: distance
                        
                        	Define an administrative distance
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance>`
                        
                        .. attribute:: maximum_paths
                        
                        	Forward packets over multiple paths
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: redistribute
                        
                        	Redistribute information from another routing protocol
                        	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute>`
                        
                        .. attribute:: authentication
                        
                        	Authentication parameters
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Authentication>`
                        
                        .. attribute:: graceful_restart
                        
                        	Graceful\-restart options
                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.GracefulRestart>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: manet
                        
                        	Specify MANET OSPF parameters
                        	**type**\:  :py:class:`Manet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet>`
                        
                        .. attribute:: summary_prefix
                        
                        	Configure IPv6 summary prefix
                        	**type**\: list of  		 :py:class:`SummaryPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.SummaryPrefix>`
                        
                        

                        """

                        _prefix = 'ios-ospfv3'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['vrf']
                            self._child_classes = OrderedDict([("area", ("area", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area)), ("auto-cost", ("auto_cost", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.AutoCost)), ("event-log", ("event_log", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.EventLog)), ("bfd", ("bfd", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Bfd)), ("interface-id", ("interface_id", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.InterfaceId)), ("log-adjacency-changes", ("log_adjacency_changes", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.LogAdjacencyChanges)), ("max-lsa", ("max_lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxLsa)), ("max-metric", ("max_metric", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric)), ("passive-interface", ("passive_interface", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.PassiveInterface)), ("disable", ("disable", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Disable)), ("queue-depth", ("queue_depth", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth)), ("timers", ("timers", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers)), ("traffic-share", ("traffic_share", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.TrafficShare)), ("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.TtlSecurity)), ("capability", ("capability", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Capability)), ("compatible", ("compatible", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Compatible)), ("default-information", ("default_information", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DefaultInformation)), ("discard-route", ("discard_route", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DiscardRoute)), ("distance", ("distance", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance)), ("redistribute", ("redistribute", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute)), ("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Authentication)), ("graceful-restart", ("graceful_restart", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.GracefulRestart)), ("manet", ("manet", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet)), ("summary-prefix", ("summary_prefix", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.SummaryPrefix))])
                            self._leafs = OrderedDict([
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('nsr', (YLeaf(YType.empty, 'nsr'), ['Empty'])),
                                ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                            ])
                            self.vrf = None
                            self.unicast = None
                            self.router_id = None
                            self.nsr = None
                            self.default_metric = None
                            self.maximum_paths = None

                            self.auto_cost = None
                            self._children_name_map["auto_cost"] = "auto-cost"

                            self.event_log = None
                            self._children_name_map["event_log"] = "event-log"

                            self.bfd = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Bfd()
                            self.bfd.parent = self
                            self._children_name_map["bfd"] = "bfd"

                            self.interface_id = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.InterfaceId()
                            self.interface_id.parent = self
                            self._children_name_map["interface_id"] = "interface-id"

                            self.log_adjacency_changes = None
                            self._children_name_map["log_adjacency_changes"] = "log-adjacency-changes"

                            self.max_lsa = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxLsa()
                            self.max_lsa.parent = self
                            self._children_name_map["max_lsa"] = "max-lsa"

                            self.max_metric = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric()
                            self.max_metric.parent = self
                            self._children_name_map["max_metric"] = "max-metric"

                            self.passive_interface = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.PassiveInterface()
                            self.passive_interface.parent = self
                            self._children_name_map["passive_interface"] = "passive-interface"

                            self.disable = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Disable()
                            self.disable.parent = self
                            self._children_name_map["disable"] = "disable"

                            self.queue_depth = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth()
                            self.queue_depth.parent = self
                            self._children_name_map["queue_depth"] = "queue-depth"

                            self.timers = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"

                            self.traffic_share = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.TrafficShare()
                            self.traffic_share.parent = self
                            self._children_name_map["traffic_share"] = "traffic-share"

                            self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.TtlSecurity()
                            self.ttl_security.parent = self
                            self._children_name_map["ttl_security"] = "ttl-security"

                            self.capability = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Capability()
                            self.capability.parent = self
                            self._children_name_map["capability"] = "capability"

                            self.compatible = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Compatible()
                            self.compatible.parent = self
                            self._children_name_map["compatible"] = "compatible"

                            self.default_information = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DefaultInformation()
                            self.default_information.parent = self
                            self._children_name_map["default_information"] = "default-information"

                            self.discard_route = None
                            self._children_name_map["discard_route"] = "discard-route"

                            self.distance = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.redistribute = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute()
                            self.redistribute.parent = self
                            self._children_name_map["redistribute"] = "redistribute"

                            self.authentication = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.graceful_restart = None
                            self._children_name_map["graceful_restart"] = "graceful-restart"

                            self.manet = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet()
                            self.manet.parent = self
                            self._children_name_map["manet"] = "manet"

                            self.area = YList(self)
                            self.summary_prefix = YList(self)
                            self._segment_path = lambda: "vrf" + "[vrf='" + str(self.vrf) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf, [u'vrf', u'unicast', 'router_id', 'nsr', 'default_metric', 'maximum_paths'], name, value)


                        class Area(Entity):
                            """
                            OSPF area parameters
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: authentication
                            
                            	Enable authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Authentication>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: capability
                            
                            	Enable area specific capability
                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Capability>`
                            
                            .. attribute:: default_cost
                            
                            	Set the summary default\-cost of a NSSA/stub area
                            	**type**\: int
                            
                            	**range:** 0..16777215
                            
                            .. attribute:: filter_list
                            
                            	Filter networks between OSPF areas
                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.FilterList>`
                            
                            .. attribute:: nssa
                            
                            	Specify a NSSA area
                            	**type**\:  :py:class:`Nssa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ipv4_range
                            
                            	
                            	**type**\:  :py:class:`Ipv4Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv4Range>`
                            
                            .. attribute:: ipv6_range
                            
                            	
                            	**type**\:  :py:class:`Ipv6Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv6Range>`
                            
                            .. attribute:: sham_link
                            
                            	Define a sham link and its parameters
                            	**type**\: list of  		 :py:class:`ShamLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.ShamLink>`
                            
                            .. attribute:: stub
                            
                            	Specify a stub area
                            	**type**\:  :py:class:`Stub <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Stub>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: virtual_link
                            
                            	Define a virtual link and its parameters
                            	**type**\: list of  		 :py:class:`VirtualLink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Authentication)), ("capability", ("capability", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Capability)), ("filter-list", ("filter_list", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.FilterList)), ("nssa", ("nssa", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa)), ("ipv4-range", ("ipv4_range", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv4Range)), ("ipv6-range", ("ipv6_range", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv6Range)), ("sham-link", ("sham_link", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.ShamLink)), ("stub", ("stub", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Stub)), ("virtual-link", ("virtual_link", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                                    ('default_cost', (YLeaf(YType.uint32, 'default-cost'), ['int'])),
                                ])
                                self.id = None
                                self.default_cost = None

                                self.authentication = None
                                self._children_name_map["authentication"] = "authentication"

                                self.capability = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Capability()
                                self.capability.parent = self
                                self._children_name_map["capability"] = "capability"

                                self.nssa = None
                                self._children_name_map["nssa"] = "nssa"

                                self.ipv4_range = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv4Range()
                                self.ipv4_range.parent = self
                                self._children_name_map["ipv4_range"] = "ipv4-range"

                                self.ipv6_range = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv6Range()
                                self.ipv6_range.parent = self
                                self._children_name_map["ipv6_range"] = "ipv6-range"

                                self.stub = None
                                self._children_name_map["stub"] = "stub"

                                self.filter_list = YList(self)
                                self.sham_link = YList(self)
                                self.virtual_link = YList(self)
                                self._segment_path = lambda: "area" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area, ['id', 'default_cost'], name, value)


                            class Authentication(Entity):
                                """
                                Enable authentication
                                
                                .. attribute:: message_digest
                                
                                	Use message\-digest authentication
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('message_digest', (YLeaf(YType.empty, 'message-digest'), ['Empty'])),
                                    ])
                                    self.message_digest = None
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Authentication, ['message_digest'], name, value)


                            class Capability(Entity):
                                """
                                Enable area specific capability
                                
                                .. attribute:: default_exclusion
                                
                                	Enable exclusion of links from base topology
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Capability, self).__init__()

                                    self.yang_name = "capability"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('default_exclusion', (YLeaf(YType.empty, 'default-exclusion'), ['Empty'])),
                                    ])
                                    self.default_exclusion = None
                                    self._segment_path = lambda: "capability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Capability, ['default_exclusion'], name, value)


                            class FilterList(Entity):
                                """
                                Filter networks between OSPF areas
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`InOut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.FilterList.InOut>`
                                
                                .. attribute:: prefix
                                
                                	Filter prefixes between OSPF areas
                                	**type**\: str
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.FilterList, self).__init__()

                                    self.yang_name = "filter-list"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['in_out']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.FilterList.InOut')])),
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ])
                                    self.in_out = None
                                    self.prefix = None
                                    self._segment_path = lambda: "filter-list" + "[in-out='" + str(self.in_out) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.FilterList, ['in_out', 'prefix'], name, value)

                                class InOut(Enum):
                                    """
                                    InOut (Enum Class)

                                    .. data:: in_ = 0

                                    .. data:: out = 1

                                    """

                                    in_ = Enum.YLeaf(0, "in")

                                    out = Enum.YLeaf(1, "out")



                            class Nssa(Entity):
                                """
                                Specify a NSSA area
                                
                                .. attribute:: default_information_originate
                                
                                	Originate Type 7 default into NSSA area
                                	**type**\:  :py:class:`DefaultInformationOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: no_ext_capability
                                
                                	Do not send domain specific capabilities into NSSA
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_redistribution
                                
                                	No redistribution into this NSSA area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into NSSA
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit default advertisement to this NSSA area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: translate
                                
                                	Translate LSA
                                	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.Translate>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa, self).__init__()

                                    self.yang_name = "nssa"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default-information-originate", ("default_information_originate", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate)), ("translate", ("translate", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.Translate))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                        ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                                        ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ])
                                    self.no_ext_capability = None
                                    self.no_redistribution = None
                                    self.no_summary = None
                                    self.nssa_only = None

                                    self.default_information_originate = None
                                    self._children_name_map["default_information_originate"] = "default-information-originate"

                                    self.translate = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.Translate()
                                    self.translate.parent = self
                                    self._children_name_map["translate"] = "translate"
                                    self._segment_path = lambda: "nssa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa, ['no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                                class DefaultInformationOriginate(Entity):
                                    """
                                    Originate Type 7 default into NSSA area
                                    
                                    .. attribute:: metric
                                    
                                    	OSPF default metric
                                    	**type**\: int
                                    
                                    	**range:** 0..16777214
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF metric type for default routes
                                    	**type**\: int
                                    
                                    	**range:** 1..2
                                    
                                    .. attribute:: no_ext_capability
                                    
                                    	Do not send domain specific capabilities into NSSA
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_redistribution
                                    
                                    	No redistribution into this NSSA area
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_summary
                                    
                                    	Do not send summary LSA into NSSA
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit default advertisement to this NSSA area
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: translate
                                    
                                    	Translate LSA
                                    	**type**\:  :py:class:`Translate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate.Translate>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate, self).__init__()

                                        self.yang_name = "default-information-originate"
                                        self.yang_parent_name = "nssa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("translate", ("translate", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate.Translate))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.int32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.uint32, 'metric-type'), ['int'])),
                                            ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                            ('no_redistribution', (YLeaf(YType.empty, 'no-redistribution'), ['Empty'])),
                                            ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.no_ext_capability = None
                                        self.no_redistribution = None
                                        self.no_summary = None
                                        self.nssa_only = None

                                        self.translate = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate.Translate()
                                        self.translate.parent = self
                                        self._children_name_map["translate"] = "translate"
                                        self._segment_path = lambda: "default-information-originate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate, ['metric', 'metric_type', 'no_ext_capability', 'no_redistribution', 'no_summary', 'nssa_only'], name, value)


                                    class Translate(Entity):
                                        """
                                        Translate LSA
                                        
                                        .. attribute:: type7
                                        
                                        	From Type 7 to Type 5
                                        	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate.Translate.Type7>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate.Translate, self).__init__()

                                            self.yang_name = "translate"
                                            self.yang_parent_name = "default-information-originate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate.Translate.Type7))])
                                            self._leafs = OrderedDict()

                                            self.type7 = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate.Translate.Type7()
                                            self.type7.parent = self
                                            self._children_name_map["type7"] = "type7"
                                            self._segment_path = lambda: "translate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate.Translate, [], name, value)


                                        class Type7(Entity):
                                            """
                                            From Type 7 to Type 5
                                            
                                            .. attribute:: always
                                            
                                            	Always translate LSAs on this ABR
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: suppress_fa
                                            
                                            	Suppress forwarding address in translated LSAs
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate.Translate.Type7, self).__init__()

                                                self.yang_name = "type7"
                                                self.yang_parent_name = "translate"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                                    ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                                ])
                                                self.always = None
                                                self.suppress_fa = None
                                                self._segment_path = lambda: "type7"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.DefaultInformationOriginate.Translate.Type7, ['always', 'suppress_fa'], name, value)


                                class Translate(Entity):
                                    """
                                    Translate LSA
                                    
                                    .. attribute:: type7
                                    
                                    	From Type 7 to Type 5
                                    	**type**\:  :py:class:`Type7 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.Translate.Type7>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.Translate, self).__init__()

                                        self.yang_name = "translate"
                                        self.yang_parent_name = "nssa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("type7", ("type7", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.Translate.Type7))])
                                        self._leafs = OrderedDict()

                                        self.type7 = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.Translate.Type7()
                                        self.type7.parent = self
                                        self._children_name_map["type7"] = "type7"
                                        self._segment_path = lambda: "translate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.Translate, [], name, value)


                                    class Type7(Entity):
                                        """
                                        From Type 7 to Type 5
                                        
                                        .. attribute:: always
                                        
                                        	Always translate LSAs on this ABR
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_fa
                                        
                                        	Suppress forwarding address in translated LSAs
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.Translate.Type7, self).__init__()

                                            self.yang_name = "type7"
                                            self.yang_parent_name = "translate"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                                ('suppress_fa', (YLeaf(YType.empty, 'suppress-fa'), ['Empty'])),
                                            ])
                                            self.always = None
                                            self.suppress_fa = None
                                            self._segment_path = lambda: "type7"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Nssa.Translate.Type7, ['always', 'suppress_fa'], name, value)


                            class Ipv4Range(Entity):
                                """
                                
                                
                                .. attribute:: range
                                
                                	Summarize routes matching address/mask (border routers only)
                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv4Range.Range>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv4Range, self).__init__()

                                    self.yang_name = "ipv4-range"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv4Range.Range))])
                                    self._leafs = OrderedDict()

                                    self.range = YList(self)
                                    self._segment_path = lambda: "ipv4-range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv4Range, [], name, value)


                                class Range(Entity):
                                    """
                                    Summarize routes matching address/mask (border routers only)
                                    
                                    .. attribute:: ip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mask  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise this range (default)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: not_advertise
                                    
                                    	DoNotAdvertise this range
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: cost
                                    
                                    	User specified metric for this range
                                    	**type**\: int
                                    
                                    	**range:** 0..16777215
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv4Range.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "ipv4-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip','mask']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                            ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                            ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                        ])
                                        self.ip = None
                                        self.mask = None
                                        self.advertise = None
                                        self.not_advertise = None
                                        self.cost = None
                                        self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv4Range.Range, ['ip', 'mask', 'advertise', 'not_advertise', 'cost'], name, value)


                            class Ipv6Range(Entity):
                                """
                                
                                
                                .. attribute:: range
                                
                                	Summarize routes matching address/mask (border routers only)
                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv6Range.Range>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv6Range, self).__init__()

                                    self.yang_name = "ipv6-range"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv6Range.Range))])
                                    self._leafs = OrderedDict()

                                    self.range = YList(self)
                                    self._segment_path = lambda: "ipv6-range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv6Range, [], name, value)


                                class Range(Entity):
                                    """
                                    Summarize routes matching address/mask (border routers only)
                                    
                                    .. attribute:: ip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise this range (default)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: not_advertise
                                    
                                    	DoNotAdvertise this range
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: cost
                                    
                                    	User specified metric for this range
                                    	**type**\: int
                                    
                                    	**range:** 0..16777215
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv6Range.Range, self).__init__()

                                        self.yang_name = "range"
                                        self.yang_parent_name = "ipv6-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                            ('advertise', (YLeaf(YType.empty, 'advertise'), ['Empty'])),
                                            ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                            ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                        ])
                                        self.ip = None
                                        self.advertise = None
                                        self.not_advertise = None
                                        self.cost = None
                                        self._segment_path = lambda: "range" + "[ip='" + str(self.ip) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Ipv6Range.Range, ['ip', 'advertise', 'not_advertise', 'cost'], name, value)


                            class ShamLink(Entity):
                                """
                                Define a sham link and its parameters
                                
                                .. attribute:: source  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: dest  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: cost
                                
                                	Associate a cost with the sham\-link
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ttl_security
                                
                                	TTL security check
                                	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.ShamLink.TtlSecurity>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.ShamLink, self).__init__()

                                    self.yang_name = "sham-link"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['source','dest']
                                    self._child_classes = OrderedDict([("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.ShamLink.TtlSecurity))])
                                    self._leafs = OrderedDict([
                                        ('source', (YLeaf(YType.str, 'source'), ['str','str'])),
                                        ('dest', (YLeaf(YType.str, 'dest'), ['str','str'])),
                                        ('cost', (YLeaf(YType.uint16, 'cost'), ['int'])),
                                    ])
                                    self.source = None
                                    self.dest = None
                                    self.cost = None

                                    self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.ShamLink.TtlSecurity()
                                    self.ttl_security.parent = self
                                    self._children_name_map["ttl_security"] = "ttl-security"
                                    self._segment_path = lambda: "sham-link" + "[source='" + str(self.source) + "']" + "[dest='" + str(self.dest) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.ShamLink, ['source', 'dest', 'cost'], name, value)


                                class TtlSecurity(Entity):
                                    """
                                    TTL security check
                                    
                                    .. attribute:: hops
                                    
                                    	IP hops
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.ShamLink.TtlSecurity, self).__init__()

                                        self.yang_name = "ttl-security"
                                        self.yang_parent_name = "sham-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                        ])
                                        self.hops = None
                                        self._segment_path = lambda: "ttl-security"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.ShamLink.TtlSecurity, ['hops'], name, value)


                            class Stub(Entity):
                                """
                                Specify a stub area
                                
                                .. attribute:: no_ext_capability
                                
                                	Do not send domain specific capabilities into stub area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into stub area
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Stub, self).__init__()

                                    self.yang_name = "stub"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('no_ext_capability', (YLeaf(YType.empty, 'no-ext-capability'), ['Empty'])),
                                        ('no_summary', (YLeaf(YType.empty, 'no-summary'), ['Empty'])),
                                    ])
                                    self.no_ext_capability = None
                                    self.no_summary = None
                                    self._segment_path = lambda: "stub"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.Stub, ['no_ext_capability', 'no_summary'], name, value)


                            class VirtualLink(Entity):
                                """
                                Define a virtual link and its parameters
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Set authentication type
                                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication>`
                                
                                .. attribute:: hello_interval
                                
                                	Hello packet interval
                                	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.HelloInterval>`
                                
                                .. attribute:: dead_interval
                                
                                	Dead router detection time
                                	**type**\:  :py:class:`DeadInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.DeadInterval>`
                                
                                .. attribute:: retransmit_interval
                                
                                	LSA retransmit interval
                                	**type**\:  :py:class:`RetransmitInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.RetransmitInterval>`
                                
                                .. attribute:: transmit_delay
                                
                                	LSA transmission delay
                                	**type**\:  :py:class:`TransmitDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.TransmitDelay>`
                                
                                .. attribute:: topology
                                
                                	Disable virtual link on topology
                                	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Topology>`
                                
                                .. attribute:: ttl_security
                                
                                	TTL security check
                                	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.TtlSecurity>`
                                
                                .. attribute:: authentication_key
                                
                                	Set authentication key
                                	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.AuthenticationKey>`
                                
                                .. attribute:: message_digest_key
                                
                                	Set message digest key
                                	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.MessageDigestKey>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink, self).__init__()

                                    self.yang_name = "virtual-link"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("authentication", ("authentication", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication)), ("hello-interval", ("hello_interval", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.HelloInterval)), ("dead-interval", ("dead_interval", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.DeadInterval)), ("retransmit-interval", ("retransmit_interval", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.RetransmitInterval)), ("transmit-delay", ("transmit_delay", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.TransmitDelay)), ("topology", ("topology", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Topology)), ("ttl-security", ("ttl_security", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.TtlSecurity)), ("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.MessageDigestKey))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                    ])
                                    self.id = None

                                    self.authentication = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"

                                    self.hello_interval = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.HelloInterval()
                                    self.hello_interval.parent = self
                                    self._children_name_map["hello_interval"] = "hello-interval"

                                    self.dead_interval = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.DeadInterval()
                                    self.dead_interval.parent = self
                                    self._children_name_map["dead_interval"] = "dead-interval"

                                    self.retransmit_interval = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.RetransmitInterval()
                                    self.retransmit_interval.parent = self
                                    self._children_name_map["retransmit_interval"] = "retransmit-interval"

                                    self.transmit_delay = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.TransmitDelay()
                                    self.transmit_delay.parent = self
                                    self._children_name_map["transmit_delay"] = "transmit-delay"

                                    self.topology = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Topology()
                                    self.topology.parent = self
                                    self._children_name_map["topology"] = "topology"

                                    self.ttl_security = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.TtlSecurity()
                                    self.ttl_security.parent = self
                                    self._children_name_map["ttl_security"] = "ttl-security"

                                    self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.AuthenticationKey()
                                    self.authentication_key.parent = self
                                    self._children_name_map["authentication_key"] = "authentication-key"

                                    self.message_digest_key = YList(self)
                                    self._segment_path = lambda: "virtual-link" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink, ['id'], name, value)


                                class Authentication(Entity):
                                    """
                                    Set authentication type
                                    
                                    .. attribute:: authentication_key
                                    
                                    	Set authentication key
                                    	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.AuthenticationKey>`
                                    
                                    .. attribute:: message_digest_key
                                    
                                    	Set message digest key
                                    	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigestKey>`
                                    
                                    .. attribute:: key_chain
                                    
                                    	Use a key\-chain for cryptographic authentication keys
                                    	**type**\:  :py:class:`KeyChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain>`
                                    
                                    .. attribute:: message_digest
                                    
                                    	Message\-digest authentication
                                    	**type**\:  :py:class:`MessageDigest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest>`
                                    
                                    .. attribute:: null
                                    
                                    	No authentication
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigestKey)), ("key-chain", ("key_chain", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain)), ("message-digest", ("message_digest", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest))])
                                        self._leafs = OrderedDict([
                                            ('null', (YLeaf(YType.empty, 'null'), ['Empty'])),
                                        ])
                                        self.null = None

                                        self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.AuthenticationKey()
                                        self.authentication_key.parent = self
                                        self._children_name_map["authentication_key"] = "authentication-key"

                                        self.key_chain = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain()
                                        self.key_chain.parent = self
                                        self._children_name_map["key_chain"] = "key-chain"

                                        self.message_digest = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest()
                                        self.message_digest.parent = self
                                        self._children_name_map["message_digest"] = "message-digest"

                                        self.message_digest_key = YList(self)
                                        self._segment_path = lambda: "authentication"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication, ['null'], name, value)


                                    class AuthenticationKey(Entity):
                                        """
                                        Set authentication key
                                        
                                        .. attribute:: auth_type
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: auth_key
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.AuthenticationKey, self).__init__()

                                            self.yang_name = "authentication-key"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                            ])
                                            self.auth_type = None
                                            self.auth_key = None
                                            self._segment_path = lambda: "authentication-key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                    class MessageDigestKey(Entity):
                                        """
                                        Set message digest key
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: md5
                                        
                                        	Use MD5 algorithm
                                        	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigestKey.Md5>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigestKey, self).__init__()

                                            self.yang_name = "message-digest-key"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigestKey.Md5))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigestKey.Md5()
                                            self.md5.parent = self
                                            self._children_name_map["md5"] = "md5"
                                            self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigestKey, ['id'], name, value)


                                        class Md5(Entity):
                                            """
                                            Use MD5 algorithm
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**length:** 1..16
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigestKey.Md5, self).__init__()

                                                self.yang_name = "md5"
                                                self.yang_parent_name = "message-digest-key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "md5"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                    class KeyChain(Entity):
                                        """
                                        Use a key\-chain for cryptographic authentication keys
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: authentication_key
                                        
                                        	Set authentication key
                                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey>`
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Set message digest key
                                        	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain, self).__init__()

                                            self.yang_name = "key-chain"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey()
                                            self.authentication_key.parent = self
                                            self._children_name_map["authentication_key"] = "authentication-key"

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "key-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain, ['name'], name, value)


                                        class AuthenticationKey(Entity):
                                            """
                                            Set authentication key
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, self).__init__()

                                                self.yang_name = "authentication-key"
                                                self.yang_parent_name = "key-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "authentication-key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Set message digest key
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: md5
                                            
                                            	Use MD5 algorithm
                                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "key-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5()
                                                self.md5.parent = self
                                                self._children_name_map["md5"] = "md5"
                                                self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey, ['id'], name, value)


                                            class Md5(Entity):
                                                """
                                                Use MD5 algorithm
                                                
                                                .. attribute:: auth_type
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                .. attribute:: auth_key
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**length:** 1..16
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, self).__init__()

                                                    self.yang_name = "md5"
                                                    self.yang_parent_name = "message-digest-key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                    ])
                                                    self.auth_type = None
                                                    self.auth_key = None
                                                    self._segment_path = lambda: "md5"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.KeyChain.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                    class MessageDigest(Entity):
                                        """
                                        Message\-digest authentication
                                        
                                        .. attribute:: authentication_key
                                        
                                        	Set authentication key
                                        	**type**\:  :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey>`
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Set message digest key
                                        	**type**\: list of  		 :py:class:`MessageDigestKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest, self).__init__()

                                            self.yang_name = "message-digest"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("authentication-key", ("authentication_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey)), ("message-digest-key", ("message_digest_key", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey))])
                                            self._leafs = OrderedDict()

                                            self.authentication_key = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey()
                                            self.authentication_key.parent = self
                                            self._children_name_map["authentication_key"] = "authentication-key"

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest, [], name, value)


                                        class AuthenticationKey(Entity):
                                            """
                                            Set authentication key
                                            
                                            .. attribute:: auth_type
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: auth_key
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, self).__init__()

                                                self.yang_name = "authentication-key"
                                                self.yang_parent_name = "message-digest"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                ])
                                                self.auth_type = None
                                                self.auth_key = None
                                                self._segment_path = lambda: "authentication-key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Set message digest key
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: md5
                                            
                                            	Use MD5 algorithm
                                            	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5()
                                                self.md5.parent = self
                                                self._children_name_map["md5"] = "md5"
                                                self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey, ['id'], name, value)


                                            class Md5(Entity):
                                                """
                                                Use MD5 algorithm
                                                
                                                .. attribute:: auth_type
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..7
                                                
                                                .. attribute:: auth_key
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**length:** 1..16
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, self).__init__()

                                                    self.yang_name = "md5"
                                                    self.yang_parent_name = "message-digest-key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                        ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                                    ])
                                                    self.auth_type = None
                                                    self.auth_key = None
                                                    self._segment_path = lambda: "md5"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Authentication.MessageDigest.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                                class HelloInterval(Entity):
                                    """
                                    Hello packet interval
                                    
                                    .. attribute:: hello_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.HelloInterval, self).__init__()

                                        self.yang_name = "hello-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hello_interval_value', (YLeaf(YType.int32, 'hello-interval-value'), ['int'])),
                                        ])
                                        self.hello_interval_value = None
                                        self._segment_path = lambda: "hello-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.HelloInterval, ['hello_interval_value'], name, value)


                                class DeadInterval(Entity):
                                    """
                                    Dead router detection time
                                    
                                    .. attribute:: dead_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.DeadInterval, self).__init__()

                                        self.yang_name = "dead-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dead_interval_value', (YLeaf(YType.uint16, 'dead-interval-value'), ['int'])),
                                        ])
                                        self.dead_interval_value = None
                                        self._segment_path = lambda: "dead-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.DeadInterval, ['dead_interval_value'], name, value)


                                class RetransmitInterval(Entity):
                                    """
                                    LSA retransmit interval
                                    
                                    .. attribute:: retransmit_interval_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.RetransmitInterval, self).__init__()

                                        self.yang_name = "retransmit-interval"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('retransmit_interval_value', (YLeaf(YType.uint16, 'retransmit-interval-value'), ['int'])),
                                        ])
                                        self.retransmit_interval_value = None
                                        self._segment_path = lambda: "retransmit-interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.RetransmitInterval, ['retransmit_interval_value'], name, value)


                                class TransmitDelay(Entity):
                                    """
                                    LSA transmission delay
                                    
                                    .. attribute:: transmit_delay_value
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..8192
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.TransmitDelay, self).__init__()

                                        self.yang_name = "transmit-delay"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('transmit_delay_value', (YLeaf(YType.uint16, 'transmit-delay-value'), ['int'])),
                                        ])
                                        self.transmit_delay_value = None
                                        self._segment_path = lambda: "transmit-delay"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.TransmitDelay, ['transmit_delay_value'], name, value)


                                class Topology(Entity):
                                    """
                                    Disable virtual link on topology
                                    
                                    .. attribute:: disable
                                    
                                    	Disable virtual link
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Topology, self).__init__()

                                        self.yang_name = "topology"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ])
                                        self.disable = None
                                        self._segment_path = lambda: "topology"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.Topology, ['disable'], name, value)


                                class TtlSecurity(Entity):
                                    """
                                    TTL security check
                                    
                                    .. attribute:: hops
                                    
                                    	IP hops
                                    	**type**\: int
                                    
                                    	**range:** 1..254
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.TtlSecurity, self).__init__()

                                        self.yang_name = "ttl-security"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                        ])
                                        self.hops = None
                                        self._segment_path = lambda: "ttl-security"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.TtlSecurity, ['hops'], name, value)


                                class AuthenticationKey(Entity):
                                    """
                                    Set authentication key
                                    
                                    .. attribute:: auth_type
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..7
                                    
                                    .. attribute:: auth_key
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.AuthenticationKey, self).__init__()

                                        self.yang_name = "authentication-key"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                            ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                        ])
                                        self.auth_type = None
                                        self.auth_key = None
                                        self._segment_path = lambda: "authentication-key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.AuthenticationKey, ['auth_type', 'auth_key'], name, value)


                                class MessageDigestKey(Entity):
                                    """
                                    Set message digest key
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: md5
                                    
                                    	Use MD5 algorithm
                                    	**type**\:  :py:class:`Md5 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.MessageDigestKey.Md5>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.MessageDigestKey, self).__init__()

                                        self.yang_name = "message-digest-key"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("md5", ("md5", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.MessageDigestKey.Md5))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint8, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.md5 = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.MessageDigestKey.Md5()
                                        self.md5.parent = self
                                        self._children_name_map["md5"] = "md5"
                                        self._segment_path = lambda: "message-digest-key" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.MessageDigestKey, ['id'], name, value)


                                    class Md5(Entity):
                                        """
                                        Use MD5 algorithm
                                        
                                        .. attribute:: auth_type
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: auth_key
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**length:** 1..16
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.MessageDigestKey.Md5, self).__init__()

                                            self.yang_name = "md5"
                                            self.yang_parent_name = "message-digest-key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                                ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                            ])
                                            self.auth_type = None
                                            self.auth_key = None
                                            self._segment_path = lambda: "md5"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Area.VirtualLink.MessageDigestKey.Md5, ['auth_type', 'auth_key'], name, value)


                        class AutoCost(Entity):
                            """
                            Calculate OSPF interface cost according to bandwidth
                            
                            .. attribute:: reference_bandwidth
                            
                            	Use reference bandwidth method to assign OSPF cost
                            	**type**\: int
                            
                            	**range:** 1..4294967
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.AutoCost, self).__init__()

                                self.yang_name = "auto-cost"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('reference_bandwidth', (YLeaf(YType.uint32, 'reference-bandwidth'), ['int'])),
                                ])
                                self.reference_bandwidth = None
                                self._segment_path = lambda: "auto-cost"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.AutoCost, ['reference_bandwidth'], name, value)


                        class EventLog(Entity):
                            """
                            OSPF Event Logging
                            
                            .. attribute:: one_shot
                            
                            	Disable Logging When Log Buffer Becomes Full
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: pause
                            
                            	Pause Event Logging
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: size
                            
                            	Maximum Number of Events Stored in the Event Log
                            	**type**\: int
                            
                            	**range:** 1..65534
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.EventLog, self).__init__()

                                self.yang_name = "event-log"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('one_shot', (YLeaf(YType.empty, 'one-shot'), ['Empty'])),
                                    ('pause', (YLeaf(YType.empty, 'pause'), ['Empty'])),
                                    ('size', (YLeaf(YType.uint32, 'size'), ['int'])),
                                ])
                                self.one_shot = None
                                self.pause = None
                                self.size = None
                                self._segment_path = lambda: "event-log"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.EventLog, ['one_shot', 'pause', 'size'], name, value)


                        class Bfd(Entity):
                            """
                            BFD configuration commands
                            
                            .. attribute:: all_interfaces
                            
                            	Enable BFD on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                                ])
                                self.all_interfaces = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Bfd, ['all_interfaces'], name, value)


                        class InterfaceId(Entity):
                            """
                            Source of the interface ID
                            
                            .. attribute:: snmp_if_index
                            
                            	SNMP MIB ifIndex
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.InterfaceId, self).__init__()

                                self.yang_name = "interface-id"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('snmp_if_index', (YLeaf(YType.empty, 'snmp-if-index'), ['Empty'])),
                                ])
                                self.snmp_if_index = None
                                self._segment_path = lambda: "interface-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.InterfaceId, ['snmp_if_index'], name, value)


                        class LogAdjacencyChanges(Entity):
                            """
                            Log changes in adjacency state
                            
                            .. attribute:: detail
                            
                            	Log all state changes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.LogAdjacencyChanges, self).__init__()

                                self.yang_name = "log-adjacency-changes"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('detail', (YLeaf(YType.empty, 'detail'), ['Empty'])),
                                ])
                                self.detail = None
                                self._segment_path = lambda: "log-adjacency-changes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.LogAdjacencyChanges, ['detail'], name, value)


                        class MaxLsa(Entity):
                            """
                            maximum number of LSAs OSPF process will receive
                            
                            .. attribute:: number
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..4294967294
                            
                            .. attribute:: threshold_value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..100
                            
                            .. attribute:: ignore_count
                            
                            	maximum number of times adjacencies can be suppressed
                            	**type**\: int
                            
                            	**range:** 1..65534
                            
                            .. attribute:: ignore_time
                            
                            	time during which all adjacencies are suppressed
                            	**type**\: int
                            
                            	**range:** 1..17895
                            
                            .. attribute:: reset_time
                            
                            	time after which ignore\-count is reset to zero
                            	**type**\: int
                            
                            	**range:** 2..35791
                            
                            .. attribute:: warning_only
                            
                            	Only give warning message when limit is exceeded
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxLsa, self).__init__()

                                self.yang_name = "max-lsa"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                    ('threshold_value', (YLeaf(YType.uint32, 'threshold-value'), ['int'])),
                                    ('ignore_count', (YLeaf(YType.uint32, 'ignore-count'), ['int'])),
                                    ('ignore_time', (YLeaf(YType.uint32, 'ignore-time'), ['int'])),
                                    ('reset_time', (YLeaf(YType.uint32, 'reset-time'), ['int'])),
                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                ])
                                self.number = None
                                self.threshold_value = None
                                self.ignore_count = None
                                self.ignore_time = None
                                self.reset_time = None
                                self.warning_only = None
                                self._segment_path = lambda: "max-lsa"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxLsa, ['number', 'threshold_value', 'ignore_count', 'ignore_time', 'reset_time', 'warning_only'], name, value)


                        class MaxMetric(Entity):
                            """
                            Set maximum metric
                            
                            .. attribute:: router_lsa
                            
                            	Maximum metric in self\-originated router\-LSAs
                            	**type**\:  :py:class:`RouterLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric, self).__init__()

                                self.yang_name = "max-metric"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("router-lsa", ("router_lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa))])
                                self._leafs = OrderedDict()

                                self.router_lsa = None
                                self._children_name_map["router_lsa"] = "router-lsa"
                                self._segment_path = lambda: "max-metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric, [], name, value)


                            class RouterLsa(Entity):
                                """
                                Maximum metric in self\-originated router\-LSAs
                                
                                .. attribute:: external_lsa
                                
                                	Override external\-lsa metric with max\-metric value
                                	**type**\:  :py:class:`ExternalLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.ExternalLsa>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: include_stub
                                
                                	Set maximum metric for stub links in router\-LSAs
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: on_startup
                                
                                	Set maximum metric temporarily after reboot
                                	**type**\:  :py:class:`OnStartup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.OnStartup>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: summary_lsa
                                
                                	Override summary\-lsa metric with max\-metric value
                                	**type**\:  :py:class:`SummaryLsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.SummaryLsa>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa, self).__init__()

                                    self.yang_name = "router-lsa"
                                    self.yang_parent_name = "max-metric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("external-lsa", ("external_lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.ExternalLsa)), ("on-startup", ("on_startup", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.OnStartup)), ("summary-lsa", ("summary_lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.SummaryLsa))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('include_stub', (YLeaf(YType.empty, 'include-stub'), ['Empty'])),
                                    ])
                                    self.include_stub = None

                                    self.external_lsa = None
                                    self._children_name_map["external_lsa"] = "external-lsa"

                                    self.on_startup = None
                                    self._children_name_map["on_startup"] = "on-startup"

                                    self.summary_lsa = None
                                    self._children_name_map["summary_lsa"] = "summary-lsa"
                                    self._segment_path = lambda: "router-lsa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa, ['include_stub'], name, value)


                                class ExternalLsa(Entity):
                                    """
                                    Override external\-lsa metric with max\-metric value
                                    
                                    .. attribute:: metric
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..16777215
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.ExternalLsa, self).__init__()

                                        self.yang_name = "external-lsa"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.metric = None
                                        self._segment_path = lambda: "external-lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.ExternalLsa, ['metric'], name, value)


                                class OnStartup(Entity):
                                    """
                                    Set maximum metric temporarily after reboot
                                    
                                    .. attribute:: time
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 5..86400
                                    
                                    .. attribute:: wait_for_bgp
                                    
                                    	Let BGP decide when to originate router\-LSA with normal metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.OnStartup, self).__init__()

                                        self.yang_name = "on-startup"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                            ('wait_for_bgp', (YLeaf(YType.empty, 'wait-for-bgp'), ['Empty'])),
                                        ])
                                        self.time = None
                                        self.wait_for_bgp = None
                                        self._segment_path = lambda: "on-startup"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.OnStartup, ['time', 'wait_for_bgp'], name, value)


                                class SummaryLsa(Entity):
                                    """
                                    Override summary\-lsa metric with max\-metric value
                                    
                                    .. attribute:: metric
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..16777215
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.SummaryLsa, self).__init__()

                                        self.yang_name = "summary-lsa"
                                        self.yang_parent_name = "router-lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.metric = None
                                        self._segment_path = lambda: "summary-lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.MaxMetric.RouterLsa.SummaryLsa, ['metric'], name, value)


                        class PassiveInterface(Entity):
                            """
                            Suppress routing updates on an interface
                            
                            .. attribute:: default
                            
                            	Suppress routing updates on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: interface
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.PassiveInterface, self).__init__()

                                self.yang_name = "passive-interface"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ])
                                self.default = None
                                self.interface = None
                                self._segment_path = lambda: "passive-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.PassiveInterface, [u'default', u'interface'], name, value)


                        class Disable(Entity):
                            """
                            
                            
                            .. attribute:: passive_interface
                            
                            	
                            	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Disable.PassiveInterface>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Disable, self).__init__()

                                self.yang_name = "disable"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Disable.PassiveInterface))])
                                self._leafs = OrderedDict()

                                self.passive_interface = YList(self)
                                self._segment_path = lambda: "disable"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Disable, [], name, value)


                            class PassiveInterface(Entity):
                                """
                                
                                
                                .. attribute:: interface  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Disable.PassiveInterface, self).__init__()

                                    self.yang_name = "passive-interface"
                                    self.yang_parent_name = "disable"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ])
                                    self.interface = None
                                    self._segment_path = lambda: "passive-interface" + "[interface='" + str(self.interface) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Disable.PassiveInterface, [u'interface'], name, value)


                        class QueueDepth(Entity):
                            """
                            OSPF Hello/Router process queue depth
                            
                            .. attribute:: hello
                            
                            	OSPF Hello process queue depth
                            	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Hello>`
                            
                            .. attribute:: update
                            
                            	OSPF Router process queue depth
                            	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth, self).__init__()

                                self.yang_name = "queue-depth"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hello", ("hello", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Hello)), ("update", ("update", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update))])
                                self._leafs = OrderedDict()

                                self.hello = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Hello()
                                self.hello.parent = self
                                self._children_name_map["hello"] = "hello"

                                self.update = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update()
                                self.update.parent = self
                                self._children_name_map["update"] = "update"
                                self._segment_path = lambda: "queue-depth"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth, [], name, value)


                            class Hello(Entity):
                                """
                                OSPF Hello process queue depth
                                
                                .. attribute:: options
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..2147483647
                                
                                		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Hello, self).__init__()

                                    self.yang_name = "hello"
                                    self.yang_parent_name = "queue-depth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                                    ])
                                    self.options = None
                                    self._segment_path = lambda: "hello"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Hello, ['options'], name, value)

                                class Options(Enum):
                                    """
                                    Options (Enum Class)

                                    .. data:: unlimited = 0

                                    """

                                    unlimited = Enum.YLeaf(0, "unlimited")



                            class Update(Entity):
                                """
                                OSPF Router process queue depth
                                
                                .. attribute:: options
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..2147483647
                                
                                		**type**\:  :py:class:`Options <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update, self).__init__()

                                    self.yang_name = "update"
                                    self.yang_parent_name = "queue-depth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('options', (YLeaf(YType.str, 'options'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update.Options')])),
                                    ])
                                    self.options = None
                                    self._segment_path = lambda: "update"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.QueueDepth.Update, ['options'], name, value)

                                class Options(Enum):
                                    """
                                    Options (Enum Class)

                                    .. data:: unlimited = 0

                                    """

                                    unlimited = Enum.YLeaf(0, "unlimited")



                        class Timers(Entity):
                            """
                            Adjust routing timers
                            
                            .. attribute:: lsa
                            
                            	OSPF LSA timers
                            	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Lsa>`
                            
                            .. attribute:: pacing
                            
                            	OSPF pacing timers
                            	**type**\:  :py:class:`Pacing <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Pacing>`
                            
                            .. attribute:: throttle
                            
                            	OSPF throttle timers
                            	**type**\:  :py:class:`Throttle <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Lsa)), ("pacing", ("pacing", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Pacing)), ("throttle", ("throttle", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle))])
                                self._leafs = OrderedDict()

                                self.lsa = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Lsa()
                                self.lsa.parent = self
                                self._children_name_map["lsa"] = "lsa"

                                self.pacing = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Pacing()
                                self.pacing.parent = self
                                self._children_name_map["pacing"] = "pacing"

                                self.throttle = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle()
                                self.throttle.parent = self
                                self._children_name_map["throttle"] = "throttle"
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers, [], name, value)


                            class Lsa(Entity):
                                """
                                OSPF LSA timers
                                
                                .. attribute:: arrival
                                
                                	OSPF LSA arrival timer
                                	**type**\: int
                                
                                	**range:** 0..600000
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('arrival', (YLeaf(YType.uint32, 'arrival'), ['int'])),
                                    ])
                                    self.arrival = None
                                    self._segment_path = lambda: "lsa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Lsa, ['arrival'], name, value)


                            class Pacing(Entity):
                                """
                                OSPF pacing timers
                                
                                .. attribute:: flood
                                
                                	OSPF flood pacing timer
                                	**type**\: int
                                
                                	**range:** 5..100
                                
                                .. attribute:: lsa_group
                                
                                	OSPF LSA group pacing timer
                                	**type**\: int
                                
                                	**range:** 10..1800
                                
                                .. attribute:: retransmission
                                
                                	OSPF retransmission pacing timer
                                	**type**\: int
                                
                                	**range:** 5..200
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Pacing, self).__init__()

                                    self.yang_name = "pacing"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('flood', (YLeaf(YType.uint32, 'flood'), ['int'])),
                                        ('lsa_group', (YLeaf(YType.uint32, 'lsa-group'), ['int'])),
                                        ('retransmission', (YLeaf(YType.uint32, 'retransmission'), ['int'])),
                                    ])
                                    self.flood = None
                                    self.lsa_group = None
                                    self.retransmission = None
                                    self._segment_path = lambda: "pacing"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Pacing, ['flood', 'lsa_group', 'retransmission'], name, value)


                            class Throttle(Entity):
                                """
                                OSPF throttle timers
                                
                                .. attribute:: lsa
                                
                                	OSPF LSA throttle timers
                                	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Lsa>`
                                
                                .. attribute:: spf
                                
                                	OSPF SPF throttle timers
                                	**type**\:  :py:class:`Spf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Spf>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle, self).__init__()

                                    self.yang_name = "throttle"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsa", ("lsa", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Lsa)), ("spf", ("spf", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Spf))])
                                    self._leafs = OrderedDict()

                                    self.lsa = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Lsa()
                                    self.lsa.parent = self
                                    self._children_name_map["lsa"] = "lsa"

                                    self.spf = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Spf()
                                    self.spf.parent = self
                                    self._children_name_map["spf"] = "spf"
                                    self._segment_path = lambda: "throttle"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle, [], name, value)


                                class Lsa(Entity):
                                    """
                                    OSPF LSA throttle timers
                                    
                                    .. attribute:: all
                                    
                                    	For all type of OSPF LSAs
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Lsa.All>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "throttle"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Lsa.All))])
                                        self._leafs = OrderedDict()

                                        self.all = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Lsa.All()
                                        self.all.parent = self
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Lsa, [], name, value)


                                    class All(Entity):
                                        """
                                        For all type of OSPF LSAs
                                        
                                        .. attribute:: delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        .. attribute:: min_delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        .. attribute:: max_delay
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..600000
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Lsa.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                                ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                            ])
                                            self.delay = None
                                            self.min_delay = None
                                            self.max_delay = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Lsa.All, ['delay', 'min_delay', 'max_delay'], name, value)


                                class Spf(Entity):
                                    """
                                    OSPF SPF throttle timers
                                    
                                    .. attribute:: delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    .. attribute:: min_delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    .. attribute:: max_delay
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..600000
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Spf, self).__init__()

                                        self.yang_name = "spf"
                                        self.yang_parent_name = "throttle"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                            ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                            ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                        ])
                                        self.delay = None
                                        self.min_delay = None
                                        self.max_delay = None
                                        self._segment_path = lambda: "spf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Timers.Throttle.Spf, ['delay', 'min_delay', 'max_delay'], name, value)


                        class TrafficShare(Entity):
                            """
                            How to compute traffic share over alternate paths
                            
                            .. attribute:: min
                            
                            	All traffic shared among min metric paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: across_interfaces
                            
                            	Use different interfaces for equal\-cost paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.TrafficShare, self).__init__()

                                self.yang_name = "traffic-share"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('min', (YLeaf(YType.empty, 'min'), ['Empty'])),
                                    ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                                ])
                                self.min = None
                                self.across_interfaces = None
                                self._segment_path = lambda: "traffic-share"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.TrafficShare, ['min', 'across_interfaces'], name, value)


                        class TtlSecurity(Entity):
                            """
                            TTL security check
                            
                            .. attribute:: all_interfaces
                            
                            	Enable TTL Security on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: hops
                            
                            	IP hops
                            	**type**\: int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.TtlSecurity, self).__init__()

                                self.yang_name = "ttl-security"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                                    ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                ])
                                self.all_interfaces = None
                                self.hops = None
                                self._segment_path = lambda: "ttl-security"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.TtlSecurity, ['all_interfaces', 'hops'], name, value)


                        class Capability(Entity):
                            """
                            Enable specific OSPF feature
                            
                            .. attribute:: capability_type
                            
                            	
                            	**type**\:  :py:class:`CapabilityType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Capability.CapabilityType>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('capability_type', (YLeaf(YType.enumeration, 'capability-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Capability.CapabilityType')])),
                                ])
                                self.capability_type = None
                                self._segment_path = lambda: "capability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Capability, ['capability_type'], name, value)

                            class CapabilityType(Enum):
                                """
                                CapabilityType (Enum Class)

                                .. data:: lls = 0

                                .. data:: opaque = 1

                                .. data:: transit = 2

                                .. data:: vrf_lite = 3

                                """

                                lls = Enum.YLeaf(0, "lls")

                                opaque = Enum.YLeaf(1, "opaque")

                                transit = Enum.YLeaf(2, "transit")

                                vrf_lite = Enum.YLeaf(3, "vrf-lite")



                        class Compatible(Entity):
                            """
                            OSPF compatibility list
                            
                            .. attribute:: rfc1583
                            
                            	Compatible with RFC 1583
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rfc1587
                            
                            	Compatible with RFC 1587
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: rfc5243
                            
                            	Compatible with RFC 5243
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Compatible, self).__init__()

                                self.yang_name = "compatible"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rfc1583', (YLeaf(YType.empty, 'rfc1583'), ['Empty'])),
                                    ('rfc1587', (YLeaf(YType.empty, 'rfc1587'), ['Empty'])),
                                    ('rfc5243', (YLeaf(YType.empty, 'rfc5243'), ['Empty'])),
                                ])
                                self.rfc1583 = None
                                self.rfc1587 = None
                                self.rfc5243 = None
                                self._segment_path = lambda: "compatible"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Compatible, ['rfc1583', 'rfc1587', 'rfc5243'], name, value)


                        class DefaultInformation(Entity):
                            """
                            Control distribution of default information
                            
                            .. attribute:: originate
                            
                            	Distribute a default route
                            	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DefaultInformation.Originate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DefaultInformation, self).__init__()

                                self.yang_name = "default-information"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("originate", ("originate", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DefaultInformation.Originate))])
                                self._leafs = OrderedDict()

                                self.originate = None
                                self._children_name_map["originate"] = "originate"
                                self._segment_path = lambda: "default-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DefaultInformation, [], name, value)


                            class Originate(Entity):
                                """
                                Distribute a default route
                                
                                .. attribute:: always
                                
                                	Always advertise default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: metric
                                
                                	OSPF default metric
                                	**type**\: int
                                
                                	**range:** 0..16777214
                                
                                .. attribute:: metric_type
                                
                                	OSPF metric type for default routes
                                	**type**\: int
                                
                                	**range:** 1..2
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DefaultInformation.Originate, self).__init__()

                                    self.yang_name = "originate"
                                    self.yang_parent_name = "default-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.uint32, 'metric-type'), ['int'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.always = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.route_map = None
                                    self._segment_path = lambda: "originate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DefaultInformation.Originate, ['always', 'metric', 'metric_type', 'route_map'], name, value)


                        class DiscardRoute(Entity):
                            """
                            Enable or disable discard\-route installation
                            
                            .. attribute:: external
                            
                            	Discard route for redistributed summarised routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: internal
                            
                            	Discard route for summarised internal routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: metric
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DiscardRoute, self).__init__()

                                self.yang_name = "discard-route"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('external', (YLeaf(YType.empty, 'external'), ['Empty'])),
                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ])
                                self.external = None
                                self.internal = None
                                self.metric = None
                                self._segment_path = lambda: "discard-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.DiscardRoute, ['external', 'internal', 'metric'], name, value)


                        class Distance(Entity):
                            """
                            Define an administrative distance
                            
                            .. attribute:: ospf_distance
                            
                            	
                            	**type**\:  :py:class:`OspfDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance.OspfDistance>`
                            
                            .. attribute:: ospf
                            
                            	OSPF routes Administrative distance
                            	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance.Ospf>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ospf-distance", ("ospf_distance", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance.OspfDistance)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance.Ospf))])
                                self._leafs = OrderedDict()

                                self.ospf_distance = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance.OspfDistance()
                                self.ospf_distance.parent = self
                                self._children_name_map["ospf_distance"] = "ospf-distance"

                                self.ospf = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance.Ospf()
                                self.ospf.parent = self
                                self._children_name_map["ospf"] = "ospf"
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance, [], name, value)


                            class OspfDistance(Entity):
                                """
                                
                                
                                .. attribute:: distance
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: ip
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: wildcard
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: acl_name
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..99
                                
                                		**type**\: int
                                
                                			**range:** 1300..1999
                                
                                		**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance.OspfDistance, self).__init__()

                                    self.yang_name = "ospf-distance"
                                    self.yang_parent_name = "distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                        ('wildcard', (YLeaf(YType.str, 'wildcard'), ['str'])),
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['int','int','str'])),
                                    ])
                                    self.distance = None
                                    self.ip = None
                                    self.wildcard = None
                                    self.acl_name = None
                                    self._segment_path = lambda: "ospf-distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance.OspfDistance, ['distance', 'ip', 'wildcard', 'acl_name'], name, value)


                            class Ospf(Entity):
                                """
                                OSPF routes Administrative distance
                                
                                .. attribute:: external
                                
                                	External routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: inter_area
                                
                                	Inter\-area routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: intra_area
                                
                                	Intra\-area routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('external', (YLeaf(YType.uint32, 'external'), ['int'])),
                                        ('inter_area', (YLeaf(YType.uint32, 'inter-area'), ['int'])),
                                        ('intra_area', (YLeaf(YType.uint32, 'intra-area'), ['int'])),
                                    ])
                                    self.external = None
                                    self.inter_area = None
                                    self.intra_area = None
                                    self._segment_path = lambda: "ospf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Distance.Ospf, ['external', 'inter_area', 'intra_area'], name, value)


                        class Redistribute(Entity):
                            """
                            Redistribute information from another routing protocol
                            
                            .. attribute:: application
                            
                            	Application
                            	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Application>`
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Bgp>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: iso_igrp
                            
                            	IGRP for OSI networks
                            	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: lisp
                            
                            	Locator ID Separation Protocol (LISP)
                            	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp>`
                            
                            .. attribute:: mobile
                            
                            	Mobile routes
                            	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Mobile>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: odr
                            
                            	On Demand stub Routes
                            	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Odr>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf>`
                            
                            .. attribute:: ospfv3
                            
                            	OSPFv3
                            	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_>`
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Rip>`
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Static>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes redistributed to protocol
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.MaximumPrefix>`
                            
                            .. attribute:: vrf
                            
                            	Specify a source VRF
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute, self).__init__()

                                self.yang_name = "redistribute"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Static)), ("maximum-prefix", ("maximum_prefix", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.MaximumPrefix)), ("vrf", ("vrf", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_))])
                                self._leafs = OrderedDict()

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.isis = None
                                self._children_name_map["isis"] = "isis"

                                self.iso_igrp = None
                                self._children_name_map["iso_igrp"] = "iso-igrp"

                                self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp()
                                self.lisp.parent = self
                                self._children_name_map["lisp"] = "lisp"

                                self.mobile = None
                                self._children_name_map["mobile"] = "mobile"

                                self.odr = None
                                self._children_name_map["odr"] = "odr"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.maximum_prefix = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.vrf = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.application = YList(self)
                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.ospf = YList(self)
                                self.ospfv3 = YList(self)
                                self.rip = YList(self)
                                self._segment_path = lambda: "redistribute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute, [], name, value)


                            class Application(Entity):
                                """
                                Application
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Application.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Application, self).__init__()

                                    self.yang_name = "application"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Application.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Application.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Application, ['name'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Application.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Application.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "application"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Application.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Bgp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Bgp.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                    ])
                                    self.as_number = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Bgp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Bgp, ['as_number'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Bgp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Bgp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Bgp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Connected.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Connected.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Connected.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Connected, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Connected.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Connected.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Connected.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Eigrp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Eigrp.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                    ])
                                    self.as_number = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Eigrp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Eigrp, ['as_number'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Eigrp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Eigrp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Eigrp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: isis_level_routes
                                
                                	
                                	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisLevelRoutes>`
                                
                                .. attribute:: isis_area
                                
                                	
                                	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea>`
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisLevelRoutes')])),
                                    ])
                                    self.isis_level_routes = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"

                                    self.isis_area = YList(self)
                                    self._segment_path = lambda: "isis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis, ['isis_level_routes'], name, value)

                                class IsisLevelRoutes(Enum):
                                    """
                                    IsisLevelRoutes (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    .. data:: level_1_2 = 2

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")

                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class IsisArea(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: isis_level_routes
                                    
                                    	
                                    	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea.IsisLevelRoutes>`
                                    
                                    .. attribute:: redist_options
                                    
                                    	
                                    	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea.RedistOptions>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea, self).__init__()

                                        self.yang_name = "isis-area"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea.RedistOptions))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea.IsisLevelRoutes')])),
                                        ])
                                        self.name = None
                                        self.isis_level_routes = None

                                        self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea.RedistOptions()
                                        self.redist_options.parent = self
                                        self._children_name_map["redist_options"] = "redist-options"
                                        self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                    class IsisLevelRoutes(Enum):
                                        """
                                        IsisLevelRoutes (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        .. data:: level_1_2 = 2

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")

                                        level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class RedistOptions(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea.RedistOptions.MetricType>`
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea.RedistOptions, self).__init__()

                                            self.yang_name = "redist-options"
                                            self.yang_parent_name = "isis-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea.RedistOptions.MetricType')])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.tag = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.nssa_only = None
                                            self._segment_path = lambda: "redist-options"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class IsoIgrp(Entity):
                                """
                                IGRP for OSI networks
                                
                                .. attribute:: area_tag_route_map_container
                                
                                	
                                	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.AreaTagRouteMapContainer>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: iso_igrp_container
                                
                                	
                                	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp, self).__init__()

                                    self.yang_name = "iso-igrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.AreaTagRouteMapContainer()
                                    self.area_tag_route_map_container.parent = self
                                    self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                    self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer()
                                    self.iso_igrp_container.parent = self
                                    self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                    self._segment_path = lambda: "iso-igrp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp, ['route_map'], name, value)


                                class AreaTagRouteMapContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: area_tag
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                        self.yang_name = "area-tag-route-map-container"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.area_tag = None
                                        self.route_map = None
                                        self._segment_path = lambda: "area-tag-route-map-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                class IsoIgrpContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer, self).__init__()

                                        self.yang_name = "iso-igrp-container"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self._segment_path = lambda: "iso-igrp-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Lisp(Entity):
                                """
                                Locator ID Separation Protocol (LISP)
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp, self).__init__()

                                    self.yang_name = "lisp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp.RedistOptions))])
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "lisp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "lisp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Mobile(Entity):
                                """
                                Mobile routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Mobile.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Mobile, self).__init__()

                                    self.yang_name = "mobile"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Mobile.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Mobile.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "mobile"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Mobile, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Mobile.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Mobile.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "mobile"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Mobile.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Odr(Entity):
                                """
                                On Demand stub Routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Odr.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Odr, self).__init__()

                                    self.yang_name = "odr"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Odr.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Odr.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "odr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Odr, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Odr.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Odr.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "odr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Odr.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match>`
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.MetricType>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.MetricType')])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.id = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.nssa_only = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.tag = None
                                    self.vrf = None

                                    self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"
                                    self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.Internal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.Internal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.External.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.External.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.NssaExternal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.NssaExternal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.nssa_external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                            class Ospfv3_(Entity):
                                """
                                OSPFv3
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match>`
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_type
                                
                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.MetricType>`
                                
                                .. attribute:: nssa_only
                                
                                	Limit redistributed routes to NSSA areas
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: subnets
                                
                                	Consider subnets for redistribution into OSPF
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_, self).__init__()

                                    self.yang_name = "ospfv3"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.MetricType')])),
                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ])
                                    self.id = None
                                    self.metric = None
                                    self.metric_type = None
                                    self.nssa_only = None
                                    self.subnets = None
                                    self.route_map = None
                                    self.tag = None

                                    self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"
                                    self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                class MetricType(Enum):
                                    """
                                    MetricType (Enum Class)

                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospfv3"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.Internal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.Internal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.External.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.External.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.NssaExternal.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.nssa_external_routes = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                            class Rip(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: id  (key)
                                
                                	User selected string identifying this rip process
                                	**type**\: str
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Rip.RedistOptions>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Rip, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Rip.RedistOptions))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Rip.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Rip, ['id'], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Rip.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Rip.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Rip.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: redist_options
                                
                                	
                                	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Static.RedistOptions>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Static.RedistOptions))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Static.RedistOptions()
                                    self.redist_options.parent = self
                                    self._children_name_map["redist_options"] = "redist-options"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Static, [], name, value)


                                class RedistOptions(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: metric_type
                                    
                                    	OSPF/IS\-IS exterior metric type for redistributed routes
                                    	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Static.RedistOptions.MetricType>`
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subnets
                                    
                                    	Consider subnets for redistribution into OSPF
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: nssa_only
                                    
                                    	Limit redistributed routes to NSSA areas
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Static.RedistOptions, self).__init__()

                                        self.yang_name = "redist-options"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Static.RedistOptions.MetricType')])),
                                            ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                        ])
                                        self.metric = None
                                        self.metric_type = None
                                        self.tag = None
                                        self.subnets = None
                                        self.route_map = None
                                        self.nssa_only = None
                                        self._segment_path = lambda: "redist-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                    class MetricType(Enum):
                                        """
                                        MetricType (Enum Class)

                                        OSPF/IS\-IS exterior metric type for redistributed routes

                                        .. data:: Y_1 = 0

                                        .. data:: Y_2 = 1

                                        """

                                        Y_1 = Enum.YLeaf(0, "1")

                                        Y_2 = Enum.YLeaf(1, "2")



                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes redistributed to protocol
                                
                                .. attribute:: number
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: threshold_warning_only_container
                                
                                	
                                	**type**\:  :py:class:`ThresholdWarningOnlyContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("threshold-warning-only-container", ("threshold_warning_only_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                    ])
                                    self.number = None

                                    self.threshold_warning_only_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer()
                                    self.threshold_warning_only_container.parent = self
                                    self._children_name_map["threshold_warning_only_container"] = "threshold-warning-only-container"
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.MaximumPrefix, ['number'], name, value)


                                class ThresholdWarningOnlyContainer(Entity):
                                    """
                                    
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer, self).__init__()

                                        self.yang_name = "threshold-warning-only-container"
                                        self.yang_parent_name = "maximum-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.threshold = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "threshold-warning-only-container"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.MaximumPrefix.ThresholdWarningOnlyContainer, ['threshold', 'warning_only'], name, value)


                            class Vrf_(Entity):
                                """
                                Specify a source VRF
                                
                                .. attribute:: non_global_vrf
                                
                                	
                                	**type**\: list of  		 :py:class:`NonGlobalVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf>`
                                
                                .. attribute:: global_
                                
                                	global VRF
                                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("non-global-vrf", ("non_global_vrf", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf)), ("global", ("global_", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global))])
                                    self._leafs = OrderedDict()

                                    self.global_ = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"

                                    self.non_global_vrf = YList(self)
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_, [], name, value)


                                class NonGlobalVrf(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator ID Separation Protocol (LISP)
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf, self).__init__()

                                        self.yang_name = "non-global-vrf"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.iso_igrp = None
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp()
                                        self.lisp.parent = self
                                        self._children_name_map["lisp"] = "lisp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.application = YList(self)
                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "non-global-vrf" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf, ['name'], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application, ['name'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_level_routes
                                        
                                        	
                                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisLevelRoutes>`
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea>`
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisLevelRoutes')])),
                                            ])
                                            self.isis_level_routes = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis, ['isis_level_routes'], name, value)

                                        class IsisLevelRoutes(Enum):
                                            """
                                            IsisLevelRoutes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: isis_level_routes
                                            
                                            	
                                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.IsisLevelRoutes>`
                                            
                                            .. attribute:: redist_options
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.IsisLevelRoutes')])),
                                                ])
                                                self.name = None
                                                self.isis_level_routes = None

                                                self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions()
                                                self.redist_options.parent = self
                                                self._children_name_map["redist_options"] = "redist-options"
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                            class IsisLevelRoutes(Enum):
                                                """
                                                IsisLevelRoutes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class RedistOptions(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions.MetricType>`
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions, self).__init__()

                                                    self.yang_name = "redist-options"
                                                    self.yang_parent_name = "isis-area"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions.MetricType')])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.tag = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.nssa_only = None
                                                    self._segment_path = lambda: "redist-options"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: area_tag_route_map_container
                                        
                                        	
                                        	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: iso_igrp_container
                                        
                                        	
                                        	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer()
                                            self.area_tag_route_map_container.parent = self
                                            self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                            self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer()
                                            self.iso_igrp_container.parent = self
                                            self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp, ['route_map'], name, value)


                                        class AreaTagRouteMapContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: area_tag
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                                self.yang_name = "area-tag-route-map-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.area_tag = None
                                                self.route_map = None
                                                self._segment_path = lambda: "area-tag-route-map-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                        class IsoIgrpContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer, self).__init__()

                                                self.yang_name = "iso-igrp-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self._segment_path = lambda: "iso-igrp-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Lisp(Entity):
                                        """
                                        Locator ID Separation Protocol (LISP)
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions))])
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "lisp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "mobile"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "odr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self.vrf = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Ospfv3_(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this rip process
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip, ['id'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "non-global-vrf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.NonGlobalVrf.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                class Global(Entity):
                                    """
                                    global VRF
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\: list of  		 :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Application>`
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Bgp>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator ID Separation Protocol (LISP)
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\: list of  		 :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Rip>`
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "vrf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Application)), ("bgp", ("bgp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Bgp)), ("connected", ("connected", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Connected)), ("eigrp", ("eigrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Eigrp)), ("isis", ("isis", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp)), ("lisp", ("lisp", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp)), ("mobile", ("mobile", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Mobile)), ("odr", ("odr", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Odr)), ("ospf", ("ospf", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_)), ("rip", ("rip", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Rip)), ("static", ("static", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Static))])
                                        self._leafs = OrderedDict()

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.iso_igrp = None
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.lisp = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp()
                                        self.lisp.parent = self
                                        self._children_name_map["lisp"] = "lisp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.application = YList(self)
                                        self.bgp = YList(self)
                                        self.eigrp = YList(self)
                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self.rip = YList(self)
                                        self._segment_path = lambda: "global"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "application" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Application, ['name'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Application.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Bgp(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Bgp, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Bgp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Bgp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Connected, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "connected"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Connected.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_number  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['as_number']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                            ])
                                            self.as_number = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Eigrp, ['as_number'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "eigrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Eigrp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_level_routes
                                        
                                        	
                                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisLevelRoutes>`
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea>`
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea)), ("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisLevelRoutes')])),
                                            ])
                                            self.isis_level_routes = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis, ['isis_level_routes'], name, value)

                                        class IsisLevelRoutes(Enum):
                                            """
                                            IsisLevelRoutes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: isis_level_routes
                                            
                                            	
                                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.IsisLevelRoutes>`
                                            
                                            .. attribute:: redist_options
                                            
                                            	
                                            	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.IsisLevelRoutes')])),
                                                ])
                                                self.name = None
                                                self.isis_level_routes = None

                                                self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions()
                                                self.redist_options.parent = self
                                                self._children_name_map["redist_options"] = "redist-options"
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea, ['name', 'isis_level_routes'], name, value)

                                            class IsisLevelRoutes(Enum):
                                                """
                                                IsisLevelRoutes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class RedistOptions(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions.MetricType>`
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions, self).__init__()

                                                    self.yang_name = "redist-options"
                                                    self.yang_parent_name = "isis-area"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions.MetricType')])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.tag = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.nssa_only = None
                                                    self._segment_path = lambda: "redist-options"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.IsisArea.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Isis.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: area_tag_route_map_container
                                        
                                        	
                                        	**type**\:  :py:class:`AreaTagRouteMapContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.AreaTagRouteMapContainer>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: iso_igrp_container
                                        
                                        	
                                        	**type**\:  :py:class:`IsoIgrpContainer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("area-tag-route-map-container", ("area_tag_route_map_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.AreaTagRouteMapContainer)), ("iso-igrp-container", ("iso_igrp_container", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.area_tag_route_map_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.AreaTagRouteMapContainer()
                                            self.area_tag_route_map_container.parent = self
                                            self._children_name_map["area_tag_route_map_container"] = "area-tag-route-map-container"

                                            self.iso_igrp_container = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer()
                                            self.iso_igrp_container.parent = self
                                            self._children_name_map["iso_igrp_container"] = "iso-igrp-container"
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp, ['route_map'], name, value)


                                        class AreaTagRouteMapContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: area_tag
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.AreaTagRouteMapContainer, self).__init__()

                                                self.yang_name = "area-tag-route-map-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('area_tag', (YLeaf(YType.str, 'area-tag'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.area_tag = None
                                                self.route_map = None
                                                self._segment_path = lambda: "area-tag-route-map-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.AreaTagRouteMapContainer, ['area_tag', 'route_map'], name, value)


                                        class IsoIgrpContainer(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer, self).__init__()

                                                self.yang_name = "iso-igrp-container"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self._segment_path = lambda: "iso-igrp-container"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.IsoIgrp.IsoIgrpContainer, ['metric', 'metric_type', 'tag', 'subnets'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Lisp(Entity):
                                        """
                                        Locator ID Separation Protocol (LISP)
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions))])
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "lisp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Lisp.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Mobile, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "mobile"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Mobile.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Odr, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "odr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Odr.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None
                                            self.vrf = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag', 'vrf'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospf.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Ospfv3_(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	Redistribution of OSPF routes
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric_type
                                        
                                        	OSPF/IS\-IS exterior metric type for redistributed routes
                                        	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.MetricType>`
                                        
                                        .. attribute:: nssa_only
                                        
                                        	Limit redistributed routes to NSSA areas
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: subnets
                                        
                                        	Consider subnets for redistribution into OSPF
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: tag
                                        
                                        	Set tag for routes redistributed into OSPF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.MetricType')])),
                                                ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.metric_type = None
                                            self.nssa_only = None
                                            self.subnets = None
                                            self.route_map = None
                                            self.tag = None

                                            self.match = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_, ['id', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                        class MetricType(Enum):
                                            """
                                            MetricType (Enum Class)

                                            OSPF/IS\-IS exterior metric type for redistributed routes

                                            .. data:: Y_1 = 0

                                            .. data:: Y_2 = 1

                                            """

                                            Y_1 = Enum.YLeaf(0, "1")

                                            Y_2 = Enum.YLeaf(1, "2")



                                        class Match(Entity):
                                            """
                                            Redistribution of OSPF routes
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal)), ("external", ("external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal))])
                                                self._leafs = OrderedDict()

                                                self.internal = None
                                                self._children_name_map["internal"] = "internal"

                                                self.external = None
                                                self._children_name_map["external"] = "external"

                                                self.nssa_external = None
                                                self._children_name_map["nssa_external"] = "nssa-external"
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match, [], name, value)


                                            class Internal(Entity):
                                                """
                                                Redistribute OSPF internal routes
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal, self).__init__()

                                                    self.yang_name = "internal"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.Internal, ['metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class External(Entity):
                                                """
                                                Redistribute OSPF external routes
                                                
                                                .. attribute:: external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External, self).__init__()

                                                    self.yang_name = "external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.External, ['external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                            class NssaExternal(Entity):
                                                """
                                                Redistribute OSPF NSSA external routes
                                                
                                                .. attribute:: nssa_external_routes
                                                
                                                	
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric_type
                                                
                                                	OSPF/IS\-IS exterior metric type for redistributed routes
                                                	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal.MetricType>`
                                                
                                                .. attribute:: nssa_only
                                                
                                                	Limit redistributed routes to NSSA areas
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: subnets
                                                
                                                	Consider subnets for redistribution into OSPF
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: tag
                                                
                                                	Set tag for routes redistributed into OSPF
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-ospfv3'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal, self).__init__()

                                                    self.yang_name = "nssa-external"
                                                    self.yang_parent_name = "match"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_ospf', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal.MetricType')])),
                                                        ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                        ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ])
                                                    self.nssa_external_routes = None
                                                    self.metric = None
                                                    self.metric_type = None
                                                    self.nssa_only = None
                                                    self.subnets = None
                                                    self.route_map = None
                                                    self.tag = None
                                                    self._segment_path = lambda: "nssa-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Ospfv3_.Match.NssaExternal, ['nssa_external_routes', 'metric', 'metric_type', 'nssa_only', 'subnets', 'route_map', 'tag'], name, value)

                                                class MetricType(Enum):
                                                    """
                                                    MetricType (Enum Class)

                                                    OSPF/IS\-IS exterior metric type for redistributed routes

                                                    .. data:: Y_1 = 0

                                                    .. data:: Y_2 = 1

                                                    """

                                                    Y_1 = Enum.YLeaf(0, "1")

                                                    Y_2 = Enum.YLeaf(1, "2")



                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	User selected string identifying this rip process
                                        	**type**\: str
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions>`
                                        
                                        

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ])
                                            self.id = None

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "rip" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Rip, ['id'], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "rip"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Rip.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: redist_options
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-ospfv3'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("redist-options", ("redist_options", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.redist_options = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions()
                                            self.redist_options.parent = self
                                            self._children_name_map["redist_options"] = "redist-options"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Static, [], name, value)


                                        class RedistOptions(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric_type
                                            
                                            	OSPF/IS\-IS exterior metric type for redistributed routes
                                            	**type**\:  :py:class:`MetricType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions.MetricType>`
                                            
                                            .. attribute:: tag
                                            
                                            	Set tag for routes redistributed into OSPF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subnets
                                            
                                            	Consider subnets for redistribution into OSPF
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: nssa_only
                                            
                                            	Limit redistributed routes to NSSA areas
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-ospfv3'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions, self).__init__()

                                                self.yang_name = "redist-options"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions.MetricType')])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('subnets', (YLeaf(YType.empty, 'subnets'), ['Empty'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                                ])
                                                self.metric = None
                                                self.metric_type = None
                                                self.tag = None
                                                self.subnets = None
                                                self.route_map = None
                                                self.nssa_only = None
                                                self._segment_path = lambda: "redist-options"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Redistribute.Vrf_.Global.Static.RedistOptions, ['metric', 'metric_type', 'tag', 'subnets', 'route_map', 'nssa_only'], name, value)

                                            class MetricType(Enum):
                                                """
                                                MetricType (Enum Class)

                                                OSPF/IS\-IS exterior metric type for redistributed routes

                                                .. data:: Y_1 = 0

                                                .. data:: Y_2 = 1

                                                """

                                                Y_1 = Enum.YLeaf(0, "1")

                                                Y_2 = Enum.YLeaf(1, "2")



                        class Authentication(Entity):
                            """
                            Authentication parameters
                            
                            .. attribute:: mode
                            
                            	Authentication operation mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Authentication.Mode>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Authentication.Mode')])),
                                ])
                                self.mode = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Authentication, [u'mode'], name, value)

                            class Mode(Enum):
                                """
                                Mode (Enum Class)

                                Authentication operation mode

                                .. data:: deployment = 0

                                .. data:: normal = 1

                                .. data:: strict = 2

                                """

                                deployment = Enum.YLeaf(0, "deployment")

                                normal = Enum.YLeaf(1, "normal")

                                strict = Enum.YLeaf(2, "strict")



                        class GracefulRestart(Entity):
                            """
                            Graceful\-restart options
                            
                            .. attribute:: disable
                            
                            	Graceful restart disable
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: helper
                            
                            	helper support
                            	**type**\:  :py:class:`Helper <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.GracefulRestart.Helper>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: restart_interval
                            
                            	Graceful restart interval
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.GracefulRestart, self).__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("helper", ("helper", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.GracefulRestart.Helper))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                    ('restart_interval', (YLeaf(YType.uint16, 'restart-interval'), ['int'])),
                                ])
                                self.disable = None
                                self.restart_interval = None

                                self.helper = None
                                self._children_name_map["helper"] = "helper"
                                self._segment_path = lambda: "graceful-restart"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.GracefulRestart, [u'disable', u'restart_interval'], name, value)


                            class Helper(Entity):
                                """
                                helper support
                                
                                .. attribute:: disable
                                
                                	disable helper support
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: strict_lsa_checking
                                
                                	enable helper strict LSA checking
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.GracefulRestart.Helper, self).__init__()

                                    self.yang_name = "helper"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ('strict_lsa_checking', (YLeaf(YType.empty, 'strict-lsa-checking'), ['Empty'])),
                                    ])
                                    self.disable = None
                                    self.strict_lsa_checking = None
                                    self._segment_path = lambda: "helper"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.GracefulRestart.Helper, [u'disable', u'strict_lsa_checking'], name, value)


                        class Manet(Entity):
                            """
                            Specify MANET OSPF parameters
                            
                            .. attribute:: cache
                            
                            	Specify MANET cache sizes
                            	**type**\:  :py:class:`Cache <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Cache>`
                            
                            .. attribute:: hello
                            
                            	Unicast Hellos rather than multicast
                            	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Hello>`
                            
                            .. attribute:: peering
                            
                            	MANET OSPF Smart Peering
                            	**type**\:  :py:class:`Peering <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Peering>`
                            
                            .. attribute:: willingness
                            
                            	Specify Relay willingness value
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet, self).__init__()

                                self.yang_name = "manet"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cache", ("cache", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Cache)), ("peering", ("peering", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Peering))])
                                self._leafs = OrderedDict([
                                    ('hello', (YLeaf(YType.enumeration, 'hello'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Hello')])),
                                    ('willingness', (YLeaf(YType.uint8, 'willingness'), ['int'])),
                                ])
                                self.hello = None
                                self.willingness = None

                                self.cache = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Cache()
                                self.cache.parent = self
                                self._children_name_map["cache"] = "cache"

                                self.peering = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Peering()
                                self.peering.parent = self
                                self._children_name_map["peering"] = "peering"
                                self._segment_path = lambda: "manet"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet, [u'hello', u'willingness'], name, value)

                            class Hello(Enum):
                                """
                                Hello (Enum Class)

                                Unicast Hellos rather than multicast

                                .. data:: unicast = 0

                                .. data:: multicast = 1

                                """

                                unicast = Enum.YLeaf(0, "unicast")

                                multicast = Enum.YLeaf(1, "multicast")



                            class Cache(Entity):
                                """
                                Specify MANET cache sizes
                                
                                .. attribute:: acknowledgement
                                
                                	Specify MANET acknowledgement cache size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update
                                
                                	Specify MANET LSA cache size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Cache, self).__init__()

                                    self.yang_name = "cache"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('acknowledgement', (YLeaf(YType.uint64, 'acknowledgement'), ['int'])),
                                        ('update', (YLeaf(YType.uint64, 'update'), ['int'])),
                                    ])
                                    self.acknowledgement = None
                                    self.update = None
                                    self._segment_path = lambda: "cache"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Cache, [u'acknowledgement', u'update'], name, value)


                            class Peering(Entity):
                                """
                                MANET OSPF Smart Peering
                                
                                .. attribute:: selective
                                
                                	Enable selective peering
                                	**type**\:  :py:class:`Selective <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Peering.Selective>`
                                
                                

                                """

                                _prefix = 'ios-ospfv3'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Peering, self).__init__()

                                    self.yang_name = "peering"
                                    self.yang_parent_name = "manet"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("selective", ("selective", Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Peering.Selective))])
                                    self._leafs = OrderedDict()

                                    self.selective = Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Peering.Selective()
                                    self.selective.parent = self
                                    self._children_name_map["selective"] = "selective"
                                    self._segment_path = lambda: "peering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Peering, [], name, value)


                                class Selective(Entity):
                                    """
                                    Enable selective peering
                                    
                                    .. attribute:: disable
                                    
                                    	Disable selective peering
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: per_interface
                                    
                                    	Select peers per interface rather than per node
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: redundancy
                                    
                                    	Redundant paths
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ios-ospfv3'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Peering.Selective, self).__init__()

                                        self.yang_name = "selective"
                                        self.yang_parent_name = "peering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ('per_interface', (YLeaf(YType.empty, 'per-interface'), ['Empty'])),
                                            ('redundancy', (YLeaf(YType.uint8, 'redundancy'), ['int'])),
                                        ])
                                        self.disable = None
                                        self.per_interface = None
                                        self.redundancy = None
                                        self._segment_path = lambda: "selective"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.Manet.Peering.Selective, [u'disable', u'per_interface', u'redundancy'], name, value)


                        class SummaryPrefix(Entity):
                            """
                            Configure IPv6 summary prefix
                            
                            .. attribute:: prefix  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: nssa_only
                            
                            	Limit summary to NSSA areas
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: tag
                            
                            	Set tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: not_advertise
                            
                            	Do not advertise when translating OSPF type\-7 LSA
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-ospfv3'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.SummaryPrefix, self).__init__()

                                self.yang_name = "summary-prefix"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['prefix']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('nssa_only', (YLeaf(YType.empty, 'nssa-only'), ['Empty'])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                    ('not_advertise', (YLeaf(YType.empty, 'not-advertise'), ['Empty'])),
                                ])
                                self.prefix = None
                                self.nssa_only = None
                                self.tag = None
                                self.not_advertise = None
                                self._segment_path = lambda: "summary-prefix" + "[prefix='" + str(self.prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Ospfv3.AddressFamily.Ipv6.Vrf.SummaryPrefix, [u'prefix', u'nssa_only', u'tag', u'not_advertise'], name, value)


        class Bgp(Entity):
            """
            Border Gateway Protocol (BGP)
            
            .. attribute:: id  (key)
            
            	
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 1..4294967295
            
            		**type**\: str
            
            .. attribute:: bgp
            
            	
            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_>`
            
            .. attribute:: peer_group
            
            	
            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup>`
            
            .. attribute:: neighbor
            
            	Specify a neighbor router
            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor>`
            
            .. attribute:: address_family
            
            	Enter Address Family command mode
            	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily>`
            
            .. attribute:: template
            
            	Enter template command mode
            	**type**\:  :py:class:`Template <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template>`
            
            .. attribute:: timers
            
            	Adjust routing timers
            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Timers>`
            
            .. attribute:: scope
            
            	
            	**type**\:  :py:class:`Scope <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope>`
            
            

            """

            _prefix = 'ios-bgp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Router.Bgp, self).__init__()

                self.yang_name = "bgp"
                self.yang_parent_name = "router"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Bgp_)), ("peer-group", ("peer_group", Native.Router.Bgp.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Neighbor)), ("address-family", ("address_family", Native.Router.Bgp.AddressFamily)), ("template", ("template", Native.Router.Bgp.Template)), ("timers", ("timers", Native.Router.Bgp.Timers)), ("scope", ("scope", Native.Router.Bgp.Scope))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                ])
                self.id = None

                self.bgp = Native.Router.Bgp.Bgp_()
                self.bgp.parent = self
                self._children_name_map["bgp"] = "bgp"

                self.peer_group = Native.Router.Bgp.PeerGroup()
                self.peer_group.parent = self
                self._children_name_map["peer_group"] = "peer-group"

                self.address_family = Native.Router.Bgp.AddressFamily()
                self.address_family.parent = self
                self._children_name_map["address_family"] = "address-family"

                self.template = Native.Router.Bgp.Template()
                self.template.parent = self
                self._children_name_map["template"] = "template"

                self.timers = Native.Router.Bgp.Timers()
                self.timers.parent = self
                self._children_name_map["timers"] = "timers"

                self.scope = Native.Router.Bgp.Scope()
                self.scope.parent = self
                self._children_name_map["scope"] = "scope"

                self.neighbor = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-bgp:bgp" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Router.Bgp, ['id'], name, value)


            class Bgp_(Entity):
                """
                
                
                .. attribute:: aigp_rib_metric
                
                	Install RIB metric as NH metric + metric on AIGP attribute
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: always_compare_med
                
                	Allow comparing MED from different neighbors
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: asnotation
                
                	Change the default AS plain notation
                	**type**\:  :py:class:`Asnotation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Asnotation>`
                
                .. attribute:: bestpath
                
                	Change the default bestpath selection
                	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Bestpath>`
                
                .. attribute:: client_to_client
                
                	Configure client to client route reflection
                	**type**\:  :py:class:`ClientToClient <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.ClientToClient>`
                
                .. attribute:: cluster_id
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: confederation
                
                	AS confederation parameters
                	**type**\:  :py:class:`Confederation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Confederation>`
                
                .. attribute:: consistency_checker
                
                	Consistency\-checker
                	**type**\:  :py:class:`ConsistencyChecker <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.ConsistencyChecker>`
                
                .. attribute:: default
                
                	Configure BGP defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Default>`
                
                .. attribute:: deterministic_med
                
                	Pick the best\-MED path among paths advertised from the neighboring AS
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dynamic_med_interval
                
                	Set the interval to re\-compute dynamic MED from IGP metric
                	**type**\:  :py:class:`DynamicMedInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.DynamicMedInterval>`
                
                .. attribute:: enforce_first_as
                
                	Enforce the first AS for EBGP routes(default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: enhanced_error
                
                	Enabled BGP Enhanced error handling
                	**type**\: bool
                
                .. attribute:: fast_external_fallover
                
                	Immediately reset session if a link to a directly connected external peer goes down
                	**type**\: bool
                
                .. attribute:: graceful_restart
                
                	Graceful restart capability parameters
                	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.GracefulRestart>`
                
                	**presence node**\: True
                
                .. attribute:: ha_mode
                
                	Select BGP High Availability mode
                	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.HaMode>`
                
                .. attribute:: listen
                
                	Neighbor subnet range listener
                	**type**\:  :py:class:`Listen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Listen>`
                
                .. attribute:: log_neighbor_changes
                
                	Log neighbor up/down and reset reason
                	**type**\: bool
                
                	**default value**\: true
                
                .. attribute:: maxas_limit
                
                	Allow AS\-PATH attribute from any neighbor imposing a limit on number of ASes
                	**type**\: int
                
                	**range:** 1..2000
                
                .. attribute:: maxcommunity_limit
                
                	Number of communities in the COMMUNITY attribute
                	**type**\: int
                
                	**range:** 1..1018
                
                .. attribute:: maxextcommunity_limit
                
                	Allow EXTENDED COMMUNITY attribute from any neighbor imposing a limit on number of extended communities
                	**type**\:  :py:class:`MaxextcommunityLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.MaxextcommunityLimit>`
                
                .. attribute:: nopeerup_delay
                
                	Set how long BGP will wait for the first peer to come up before beginning the update delay or graceful restart timers (in seconds)
                	**type**\:  :py:class:`NopeerupDelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.NopeerupDelay>`
                
                .. attribute:: refresh
                
                	refresh
                	**type**\:  :py:class:`Refresh <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Refresh>`
                
                .. attribute:: regexp
                
                	Select regular expression engine
                	**type**\:  :py:class:`Regexp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Regexp>`
                
                .. attribute:: route_map_cache
                
                	Enable route\-map caching
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: router_id
                
                	Override configured router identifier (peers will reset)
                	**type**\:  :py:class:`RouterId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.RouterId>`
                
                .. attribute:: sso
                
                	Stateful Switchover
                	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Sso>`
                
                .. attribute:: transport
                
                	Transport options
                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Transport>`
                
                .. attribute:: update_delay
                
                	Set the max initial delay for sending update
                	**type**\: int
                
                	**range:** 1..3600
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Bgp.Bgp_, self).__init__()

                    self.yang_name = "bgp"
                    self.yang_parent_name = "bgp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("asnotation", ("asnotation", Native.Router.Bgp.Bgp_.Asnotation)), ("bestpath", ("bestpath", Native.Router.Bgp.Bgp_.Bestpath)), ("client-to-client", ("client_to_client", Native.Router.Bgp.Bgp_.ClientToClient)), ("confederation", ("confederation", Native.Router.Bgp.Bgp_.Confederation)), ("consistency-checker", ("consistency_checker", Native.Router.Bgp.Bgp_.ConsistencyChecker)), ("default", ("default", Native.Router.Bgp.Bgp_.Default)), ("dynamic-med-interval", ("dynamic_med_interval", Native.Router.Bgp.Bgp_.DynamicMedInterval)), ("graceful-restart", ("graceful_restart", Native.Router.Bgp.Bgp_.GracefulRestart)), ("ha-mode", ("ha_mode", Native.Router.Bgp.Bgp_.HaMode)), ("listen", ("listen", Native.Router.Bgp.Bgp_.Listen)), ("maxextcommunity-limit", ("maxextcommunity_limit", Native.Router.Bgp.Bgp_.MaxextcommunityLimit)), ("nopeerup-delay", ("nopeerup_delay", Native.Router.Bgp.Bgp_.NopeerupDelay)), ("refresh", ("refresh", Native.Router.Bgp.Bgp_.Refresh)), ("regexp", ("regexp", Native.Router.Bgp.Bgp_.Regexp)), ("router-id", ("router_id", Native.Router.Bgp.Bgp_.RouterId)), ("sso", ("sso", Native.Router.Bgp.Bgp_.Sso)), ("transport", ("transport", Native.Router.Bgp.Bgp_.Transport))])
                    self._leafs = OrderedDict([
                        ('aigp_rib_metric', (YLeaf(YType.empty, 'aigp-rib-metric'), ['Empty'])),
                        ('always_compare_med', (YLeaf(YType.empty, 'always-compare-med'), ['Empty'])),
                        ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                        ('deterministic_med', (YLeaf(YType.empty, 'deterministic-med'), ['Empty'])),
                        ('enforce_first_as', (YLeaf(YType.empty, 'enforce-first-as'), ['Empty'])),
                        ('enhanced_error', (YLeaf(YType.boolean, 'enhanced-error'), ['bool'])),
                        ('fast_external_fallover', (YLeaf(YType.boolean, 'fast-external-fallover'), ['bool'])),
                        ('log_neighbor_changes', (YLeaf(YType.boolean, 'log-neighbor-changes'), ['bool'])),
                        ('maxas_limit', (YLeaf(YType.uint16, 'maxas-limit'), ['int'])),
                        ('maxcommunity_limit', (YLeaf(YType.uint16, 'maxcommunity-limit'), ['int'])),
                        ('route_map_cache', (YLeaf(YType.empty, 'route-map-cache'), ['Empty'])),
                        ('update_delay', (YLeaf(YType.uint16, 'update-delay'), ['int'])),
                    ])
                    self.aigp_rib_metric = None
                    self.always_compare_med = None
                    self.cluster_id = None
                    self.deterministic_med = None
                    self.enforce_first_as = None
                    self.enhanced_error = None
                    self.fast_external_fallover = None
                    self.log_neighbor_changes = None
                    self.maxas_limit = None
                    self.maxcommunity_limit = None
                    self.route_map_cache = None
                    self.update_delay = None

                    self.asnotation = Native.Router.Bgp.Bgp_.Asnotation()
                    self.asnotation.parent = self
                    self._children_name_map["asnotation"] = "asnotation"

                    self.bestpath = Native.Router.Bgp.Bgp_.Bestpath()
                    self.bestpath.parent = self
                    self._children_name_map["bestpath"] = "bestpath"

                    self.client_to_client = Native.Router.Bgp.Bgp_.ClientToClient()
                    self.client_to_client.parent = self
                    self._children_name_map["client_to_client"] = "client-to-client"

                    self.confederation = Native.Router.Bgp.Bgp_.Confederation()
                    self.confederation.parent = self
                    self._children_name_map["confederation"] = "confederation"

                    self.consistency_checker = Native.Router.Bgp.Bgp_.ConsistencyChecker()
                    self.consistency_checker.parent = self
                    self._children_name_map["consistency_checker"] = "consistency-checker"

                    self.default = Native.Router.Bgp.Bgp_.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.dynamic_med_interval = Native.Router.Bgp.Bgp_.DynamicMedInterval()
                    self.dynamic_med_interval.parent = self
                    self._children_name_map["dynamic_med_interval"] = "dynamic-med-interval"

                    self.graceful_restart = None
                    self._children_name_map["graceful_restart"] = "graceful-restart"

                    self.ha_mode = Native.Router.Bgp.Bgp_.HaMode()
                    self.ha_mode.parent = self
                    self._children_name_map["ha_mode"] = "ha-mode"

                    self.listen = Native.Router.Bgp.Bgp_.Listen()
                    self.listen.parent = self
                    self._children_name_map["listen"] = "listen"

                    self.maxextcommunity_limit = Native.Router.Bgp.Bgp_.MaxextcommunityLimit()
                    self.maxextcommunity_limit.parent = self
                    self._children_name_map["maxextcommunity_limit"] = "maxextcommunity-limit"

                    self.nopeerup_delay = Native.Router.Bgp.Bgp_.NopeerupDelay()
                    self.nopeerup_delay.parent = self
                    self._children_name_map["nopeerup_delay"] = "nopeerup-delay"

                    self.refresh = Native.Router.Bgp.Bgp_.Refresh()
                    self.refresh.parent = self
                    self._children_name_map["refresh"] = "refresh"

                    self.regexp = Native.Router.Bgp.Bgp_.Regexp()
                    self.regexp.parent = self
                    self._children_name_map["regexp"] = "regexp"

                    self.router_id = Native.Router.Bgp.Bgp_.RouterId()
                    self.router_id.parent = self
                    self._children_name_map["router_id"] = "router-id"

                    self.sso = Native.Router.Bgp.Bgp_.Sso()
                    self.sso.parent = self
                    self._children_name_map["sso"] = "sso"

                    self.transport = Native.Router.Bgp.Bgp_.Transport()
                    self.transport.parent = self
                    self._children_name_map["transport"] = "transport"
                    self._segment_path = lambda: "bgp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Bgp.Bgp_, ['aigp_rib_metric', 'always_compare_med', 'cluster_id', 'deterministic_med', 'enforce_first_as', 'enhanced_error', 'fast_external_fallover', 'log_neighbor_changes', 'maxas_limit', 'maxcommunity_limit', 'route_map_cache', 'update_delay'], name, value)


                class Asnotation(Entity):
                    """
                    Change the default AS plain notation
                    
                    .. attribute:: dot
                    
                    	AS dot notation
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.Asnotation, self).__init__()

                        self.yang_name = "asnotation"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dot', (YLeaf(YType.empty, 'dot'), ['Empty'])),
                        ])
                        self.dot = None
                        self._segment_path = lambda: "asnotation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.Asnotation, ['dot'], name, value)


                class Bestpath(Entity):
                    """
                    Change the default bestpath selection
                    
                    .. attribute:: as_path
                    
                    	
                    	**type**\:  :py:class:`AsPath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Bestpath.AsPath>`
                    
                    .. attribute:: compare_routerid
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cost_community
                    
                    	cost community
                    	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Bestpath.CostCommunity>`
                    
                    .. attribute:: igp_metric
                    
                    	igp metric
                    	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Bestpath.IgpMetric>`
                    
                    .. attribute:: med
                    
                    	MED attribute
                    	**type**\:  :py:class:`Med <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Bestpath.Med>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.Bestpath, self).__init__()

                        self.yang_name = "bestpath"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.Bgp_.Bestpath.CostCommunity)), ("igp-metric", ("igp_metric", Native.Router.Bgp.Bgp_.Bestpath.IgpMetric)), ("med", ("med", Native.Router.Bgp.Bgp_.Bestpath.Med))])
                        self._leafs = OrderedDict([
                            ('as_path', (YLeaf(YType.enumeration, 'as-path'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Bgp_.Bestpath.AsPath')])),
                            ('compare_routerid', (YLeaf(YType.empty, 'compare-routerid'), ['Empty'])),
                        ])
                        self.as_path = None
                        self.compare_routerid = None

                        self.cost_community = Native.Router.Bgp.Bgp_.Bestpath.CostCommunity()
                        self.cost_community.parent = self
                        self._children_name_map["cost_community"] = "cost-community"

                        self.igp_metric = Native.Router.Bgp.Bgp_.Bestpath.IgpMetric()
                        self.igp_metric.parent = self
                        self._children_name_map["igp_metric"] = "igp-metric"

                        self.med = Native.Router.Bgp.Bgp_.Bestpath.Med()
                        self.med.parent = self
                        self._children_name_map["med"] = "med"
                        self._segment_path = lambda: "bestpath"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.Bestpath, ['as_path', 'compare_routerid'], name, value)

                    class AsPath(Enum):
                        """
                        AsPath (Enum Class)

                        .. data:: ignore = 0

                        """

                        ignore = Enum.YLeaf(0, "ignore")



                    class CostCommunity(Entity):
                        """
                        cost community
                        
                        .. attribute:: ignore
                        
                        	Ignore cost communities in bestpath selection
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Bgp_.Bestpath.CostCommunity, self).__init__()

                            self.yang_name = "cost-community"
                            self.yang_parent_name = "bestpath"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "cost-community"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Bgp_.Bestpath.CostCommunity, ['ignore'], name, value)


                    class IgpMetric(Entity):
                        """
                        igp metric
                        
                        .. attribute:: ignore
                        
                        	Ignore igp metric in bestpath selection
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Bgp_.Bestpath.IgpMetric, self).__init__()

                            self.yang_name = "igp-metric"
                            self.yang_parent_name = "bestpath"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                            ])
                            self.ignore = None
                            self._segment_path = lambda: "igp-metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                    class Med(Entity):
                        """
                        MED attribute
                        
                        .. attribute:: confed
                        
                        	Compare MED among confederation paths
                        	**type**\:  :py:class:`Confed <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Bestpath.Med.Confed>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: missing_as_worst
                        
                        	Treat missing MED as the least preferred one
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Bgp_.Bestpath.Med, self).__init__()

                            self.yang_name = "med"
                            self.yang_parent_name = "bestpath"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("confed", ("confed", Native.Router.Bgp.Bgp_.Bestpath.Med.Confed))])
                            self._leafs = OrderedDict([
                                ('missing_as_worst', (YLeaf(YType.empty, 'missing-as-worst'), ['Empty'])),
                            ])
                            self.missing_as_worst = None

                            self.confed = None
                            self._children_name_map["confed"] = "confed"
                            self._segment_path = lambda: "med"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Bgp_.Bestpath.Med, ['missing_as_worst'], name, value)


                        class Confed(Entity):
                            """
                            Compare MED among confederation paths
                            
                            .. attribute:: missing_as_worst
                            
                            	Treat missing MED as the least preferred one
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Bgp_.Bestpath.Med.Confed, self).__init__()

                                self.yang_name = "confed"
                                self.yang_parent_name = "med"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('missing_as_worst', (YLeaf(YType.empty, 'missing-as-worst'), ['Empty'])),
                                ])
                                self.missing_as_worst = None
                                self._segment_path = lambda: "confed"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Bgp_.Bestpath.Med.Confed, ['missing_as_worst'], name, value)


                class ClientToClient(Entity):
                    """
                    Configure client to client route reflection
                    
                    .. attribute:: reflection
                    
                    	reflection of routes allowed
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.ClientToClient, self).__init__()

                        self.yang_name = "client-to-client"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('reflection', (YLeaf(YType.boolean, 'reflection'), ['bool'])),
                        ])
                        self.reflection = None
                        self._segment_path = lambda: "client-to-client"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.ClientToClient, ['reflection'], name, value)


                class Confederation(Entity):
                    """
                    AS confederation parameters
                    
                    .. attribute:: identifier
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: peers
                    
                    	Peer ASs in BGP confederation
                    	**type**\:  :py:class:`Peers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Confederation.Peers>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.Confederation, self).__init__()

                        self.yang_name = "confederation"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peers", ("peers", Native.Router.Bgp.Bgp_.Confederation.Peers))])
                        self._leafs = OrderedDict([
                            ('identifier', (YLeaf(YType.uint32, 'identifier'), ['int'])),
                        ])
                        self.identifier = None

                        self.peers = Native.Router.Bgp.Bgp_.Confederation.Peers()
                        self.peers.parent = self
                        self._children_name_map["peers"] = "peers"
                        self._segment_path = lambda: "confederation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.Confederation, ['identifier'], name, value)


                    class Peers(Entity):
                        """
                        Peer ASs in BGP confederation
                        
                        .. attribute:: peers_as
                        
                        	
                        	**type**\: list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Bgp_.Confederation.Peers, self).__init__()

                            self.yang_name = "peers"
                            self.yang_parent_name = "confederation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('peers_as', (YLeafList(YType.uint32, 'peers-as'), ['int'])),
                            ])
                            self.peers_as = []
                            self._segment_path = lambda: "peers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Bgp_.Confederation.Peers, ['peers_as'], name, value)


                class ConsistencyChecker(Entity):
                    """
                    Consistency\-checker
                    
                    .. attribute:: auto_repair
                    
                    	Auto\-Repair
                    	**type**\:  :py:class:`AutoRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.ConsistencyChecker.AutoRepair>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: error_message
                    
                    	Log Error\-Msg
                    	**type**\:  :py:class:`ErrorMessage <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.ConsistencyChecker.ErrorMessage>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.ConsistencyChecker, self).__init__()

                        self.yang_name = "consistency-checker"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto-repair", ("auto_repair", Native.Router.Bgp.Bgp_.ConsistencyChecker.AutoRepair)), ("error-message", ("error_message", Native.Router.Bgp.Bgp_.ConsistencyChecker.ErrorMessage))])
                        self._leafs = OrderedDict()

                        self.auto_repair = None
                        self._children_name_map["auto_repair"] = "auto-repair"

                        self.error_message = None
                        self._children_name_map["error_message"] = "error-message"
                        self._segment_path = lambda: "consistency-checker"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.ConsistencyChecker, [], name, value)


                    class AutoRepair(Entity):
                        """
                        Auto\-Repair
                        
                        .. attribute:: interval
                        
                        	Interval (minutes)
                        	**type**\: int
                        
                        	**range:** 5..1440
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Bgp_.ConsistencyChecker.AutoRepair, self).__init__()

                            self.yang_name = "auto-repair"
                            self.yang_parent_name = "consistency-checker"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "auto-repair"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Bgp_.ConsistencyChecker.AutoRepair, ['interval'], name, value)


                    class ErrorMessage(Entity):
                        """
                        Log Error\-Msg
                        
                        .. attribute:: interval
                        
                        	Interval (minutes)
                        	**type**\: int
                        
                        	**range:** 5..1440
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Bgp_.ConsistencyChecker.ErrorMessage, self).__init__()

                            self.yang_name = "error-message"
                            self.yang_parent_name = "consistency-checker"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "error-message"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Bgp_.ConsistencyChecker.ErrorMessage, ['interval'], name, value)


                class Default(Entity):
                    """
                    Configure BGP defaults
                    
                    .. attribute:: ipv4_unicast
                    
                    	Activate ipv4\-unicast for a peer by default
                    	**type**\: bool
                    
                    .. attribute:: ipv6_nexthop
                    
                    	Default IPv6 nexthop format
                    	**type**\: bool
                    
                    .. attribute:: local_preference
                    
                    	local preference (higher=more preferred)
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    	**default value**\: 100
                    
                    .. attribute:: route_target
                    
                    	Control behavior based on Route\-Target attributes
                    	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Default.RouteTarget>`
                    
                    	**default value**\: filter
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ipv4_unicast', (YLeaf(YType.boolean, 'ipv4-unicast'), ['bool'])),
                            ('ipv6_nexthop', (YLeaf(YType.boolean, 'ipv6-nexthop'), ['bool'])),
                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                            ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Bgp_.Default.RouteTarget')])),
                        ])
                        self.ipv4_unicast = None
                        self.ipv6_nexthop = None
                        self.local_preference = None
                        self.route_target = None
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.Default, ['ipv4_unicast', 'ipv6_nexthop', 'local_preference', 'route_target'], name, value)

                    class RouteTarget(Enum):
                        """
                        RouteTarget (Enum Class)

                        Control behavior based on Route\-Target attributes

                        .. data:: filter = 0

                        """

                        filter = Enum.YLeaf(0, "filter")



                class DynamicMedInterval(Entity):
                    """
                    Set the interval to re\-compute dynamic MED from IGP metric
                    
                    .. attribute:: interval
                    
                    	Interval value (seconds)
                    	**type**\: int
                    
                    	**range:** 60..4294967295
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.DynamicMedInterval, self).__init__()

                        self.yang_name = "dynamic-med-interval"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                        ])
                        self.interval = None
                        self._segment_path = lambda: "dynamic-med-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.DynamicMedInterval, ['interval'], name, value)


                class GracefulRestart(Entity):
                    """
                    Graceful restart capability parameters
                    
                    .. attribute:: extended
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: restart_time
                    
                    	Set the max time needed to restart and come back up
                    	**type**\: int
                    
                    	**range:** 1..3600
                    
                    .. attribute:: stalepath_time
                    
                    	Set the max time to hold onto restarting peer's stale paths
                    	**type**\: int
                    
                    	**range:** 1..3600
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.GracefulRestart, self).__init__()

                        self.yang_name = "graceful-restart"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('extended', (YLeaf(YType.empty, 'extended'), ['Empty'])),
                            ('restart_time', (YLeaf(YType.uint16, 'restart-time'), ['int'])),
                            ('stalepath_time', (YLeaf(YType.uint16, 'stalepath-time'), ['int'])),
                        ])
                        self.extended = None
                        self.restart_time = None
                        self.stalepath_time = None
                        self._segment_path = lambda: "graceful-restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.GracefulRestart, ['extended', 'restart_time', 'stalepath_time'], name, value)


                class HaMode(Entity):
                    """
                    Select BGP High Availability mode
                    
                    .. attribute:: sso
                    
                    	BGP High Availability NSR sso mode
                    	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.HaMode.Sso>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.HaMode, self).__init__()

                        self.yang_name = "ha-mode"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sso", ("sso", Native.Router.Bgp.Bgp_.HaMode.Sso))])
                        self._leafs = OrderedDict()

                        self.sso = None
                        self._children_name_map["sso"] = "sso"
                        self._segment_path = lambda: "ha-mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.HaMode, [], name, value)


                    class Sso(Entity):
                        """
                        BGP High Availability NSR sso mode
                        
                        .. attribute:: prefer
                        
                        	Prefer BGP High Availability NSR sso mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Bgp_.HaMode.Sso, self).__init__()

                            self.yang_name = "sso"
                            self.yang_parent_name = "ha-mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                            ])
                            self.prefer = None
                            self._segment_path = lambda: "sso"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Bgp_.HaMode.Sso, ['prefer'], name, value)


                class Listen(Entity):
                    """
                    Neighbor subnet range listener
                    
                    .. attribute:: limit
                    
                    	Set the max limit for the dynamic subnet range neighbors
                    	**type**\: int
                    
                    	**range:** 1..10000
                    
                    .. attribute:: range
                    
                    	Subnet network range
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Listen.Range>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.Listen, self).__init__()

                        self.yang_name = "listen"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Bgp_.Listen.Range))])
                        self._leafs = OrderedDict([
                            ('limit', (YLeaf(YType.uint16, 'limit'), ['int'])),
                        ])
                        self.limit = None

                        self.range = YList(self)
                        self._segment_path = lambda: "listen"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.Listen, ['limit'], name, value)


                    class Range(Entity):
                        """
                        Subnet network range
                        
                        .. attribute:: network_range  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: peer_group  (key)
                        
                        	Member of the peer\-group
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Bgp_.Listen.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "listen"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['network_range','peer_group']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('network_range', (YLeaf(YType.str, 'network-range'), ['str','str'])),
                                ('peer_group', (YLeaf(YType.str, 'peer-group'), ['str'])),
                            ])
                            self.network_range = None
                            self.peer_group = None
                            self._segment_path = lambda: "range" + "[network-range='" + str(self.network_range) + "']" + "[peer-group='" + str(self.peer_group) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Bgp_.Listen.Range, ['network_range', 'peer_group'], name, value)


                class MaxextcommunityLimit(Entity):
                    """
                    Allow EXTENDED COMMUNITY attribute from any neighbor imposing a
                    limit on number of extended communities
                    
                    .. attribute:: number
                    
                    	Number of extended communities in the EXTENDED COMMUNITY attribute
                    	**type**\: int
                    
                    	**range:** 1..509
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.MaxextcommunityLimit, self).__init__()

                        self.yang_name = "maxextcommunity-limit"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ])
                        self.number = None
                        self._segment_path = lambda: "maxextcommunity-limit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.MaxextcommunityLimit, ['number'], name, value)


                class NopeerupDelay(Entity):
                    """
                    Set how long BGP will wait for the first peer to come up before beginning the update delay or graceful restart timers (in seconds)
                    
                    .. attribute:: cold_boot
                    
                    	Delay in seconds
                    	**type**\: int
                    
                    	**range:** 1..3600
                    
                    .. attribute:: nsf_switchover
                    
                    	Delay in seconds
                    	**type**\: int
                    
                    	**range:** 1..3600
                    
                    .. attribute:: post_boot
                    
                    	Delay in seconds
                    	**type**\: int
                    
                    	**range:** 1..3600
                    
                    .. attribute:: user_initiated
                    
                    	Delay in seconds
                    	**type**\: int
                    
                    	**range:** 1..3600
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.NopeerupDelay, self).__init__()

                        self.yang_name = "nopeerup-delay"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('cold_boot', (YLeaf(YType.uint16, 'cold-boot'), ['int'])),
                            ('nsf_switchover', (YLeaf(YType.uint16, 'nsf-switchover'), ['int'])),
                            ('post_boot', (YLeaf(YType.uint16, 'post-boot'), ['int'])),
                            ('user_initiated', (YLeaf(YType.uint16, 'user-initiated'), ['int'])),
                        ])
                        self.cold_boot = None
                        self.nsf_switchover = None
                        self.post_boot = None
                        self.user_initiated = None
                        self._segment_path = lambda: "nopeerup-delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.NopeerupDelay, ['cold_boot', 'nsf_switchover', 'post_boot', 'user_initiated'], name, value)


                class Refresh(Entity):
                    """
                    refresh
                    
                    .. attribute:: max_eor_time
                    
                    	Configure refresh max\-eor time
                    	**type**\:  :py:class:`MaxEorTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Refresh.MaxEorTime>`
                    
                    .. attribute:: stalepath_time
                    
                    	Configure refresh stale\-path time
                    	**type**\:  :py:class:`StalepathTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Refresh.StalepathTime>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.Refresh, self).__init__()

                        self.yang_name = "refresh"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("max-eor-time", ("max_eor_time", Native.Router.Bgp.Bgp_.Refresh.MaxEorTime)), ("stalepath-time", ("stalepath_time", Native.Router.Bgp.Bgp_.Refresh.StalepathTime))])
                        self._leafs = OrderedDict()

                        self.max_eor_time = Native.Router.Bgp.Bgp_.Refresh.MaxEorTime()
                        self.max_eor_time.parent = self
                        self._children_name_map["max_eor_time"] = "max-eor-time"

                        self.stalepath_time = Native.Router.Bgp.Bgp_.Refresh.StalepathTime()
                        self.stalepath_time.parent = self
                        self._children_name_map["stalepath_time"] = "stalepath-time"
                        self._segment_path = lambda: "refresh"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.Refresh, [], name, value)


                    class MaxEorTime(Entity):
                        """
                        Configure refresh max\-eor time
                        
                        .. attribute:: refresh_disable
                        
                        	
                        	**type**\:  :py:class:`RefreshDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Refresh.MaxEorTime.RefreshDisable>`
                        
                        .. attribute:: timer_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 600..3600
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Bgp_.Refresh.MaxEorTime, self).__init__()

                            self.yang_name = "max-eor-time"
                            self.yang_parent_name = "refresh"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('refresh_disable', (YLeaf(YType.enumeration, 'refresh-disable'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Bgp_.Refresh.MaxEorTime.RefreshDisable')])),
                                ('timer_interval', (YLeaf(YType.uint16, 'timer-interval'), ['int'])),
                            ])
                            self.refresh_disable = None
                            self.timer_interval = None
                            self._segment_path = lambda: "max-eor-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Bgp_.Refresh.MaxEorTime, ['refresh_disable', 'timer_interval'], name, value)

                        class RefreshDisable(Enum):
                            """
                            RefreshDisable (Enum Class)

                            .. data:: Y_0 = 0

                            """

                            Y_0 = Enum.YLeaf(0, "0")



                    class StalepathTime(Entity):
                        """
                        Configure refresh stale\-path time
                        
                        .. attribute:: refresh_disable
                        
                        	
                        	**type**\:  :py:class:`RefreshDisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.Refresh.StalepathTime.RefreshDisable>`
                        
                        .. attribute:: timer_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 600..3600
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Bgp_.Refresh.StalepathTime, self).__init__()

                            self.yang_name = "stalepath-time"
                            self.yang_parent_name = "refresh"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('refresh_disable', (YLeaf(YType.enumeration, 'refresh-disable'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Bgp_.Refresh.StalepathTime.RefreshDisable')])),
                                ('timer_interval', (YLeaf(YType.uint16, 'timer-interval'), ['int'])),
                            ])
                            self.refresh_disable = None
                            self.timer_interval = None
                            self._segment_path = lambda: "stalepath-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Bgp_.Refresh.StalepathTime, ['refresh_disable', 'timer_interval'], name, value)

                        class RefreshDisable(Enum):
                            """
                            RefreshDisable (Enum Class)

                            .. data:: Y_0 = 0

                            """

                            Y_0 = Enum.YLeaf(0, "0")



                class Regexp(Entity):
                    """
                    Select regular expression engine
                    
                    .. attribute:: deterministic
                    
                    	Enable bounded\-execution\-time regular expression engine
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.Regexp, self).__init__()

                        self.yang_name = "regexp"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('deterministic', (YLeaf(YType.boolean, 'deterministic'), ['bool'])),
                        ])
                        self.deterministic = None
                        self._segment_path = lambda: "regexp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.Regexp, ['deterministic'], name, value)


                class RouterId(Entity):
                    """
                    Override configured router identifier (peers will reset)
                    
                    .. attribute:: ip_id
                    
                    	Manually configured router identifier
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface
                    
                    	Use IPv4 address on interface
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.RouterId.Interface>`
                    
                    .. attribute:: vrf
                    
                    	vrf\-specific router id configuration
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.RouterId.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.RouterId, self).__init__()

                        self.yang_name = "router-id"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Native.Router.Bgp.Bgp_.RouterId.Interface))])
                        self._leafs = OrderedDict([
                            ('ip_id', (YLeaf(YType.str, 'ip-id'), ['str'])),
                            ('vrf', (YLeaf(YType.enumeration, 'vrf'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Bgp_.RouterId.Vrf')])),
                        ])
                        self.ip_id = None
                        self.vrf = None

                        self.interface = Native.Router.Bgp.Bgp_.RouterId.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._segment_path = lambda: "router-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.RouterId, ['ip_id', 'vrf'], name, value)

                    class Vrf(Enum):
                        """
                        Vrf (Enum Class)

                        vrf\-specific router id configuration

                        .. data:: auto_assign = 0

                        """

                        auto_assign = Enum.YLeaf(0, "auto-assign")



                    class Interface(Entity):
                        """
                        Use IPv4 address on interface
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.RouterId.Interface.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.RouterId.Interface.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.RouterId.Interface.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Bgp_.RouterId.Interface.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Bgp_.RouterId.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "router-id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.Bgp_.RouterId.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.Bgp_.RouterId.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.Bgp_.RouterId.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.Bgp_.RouterId.Interface.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Router.Bgp.Bgp_.RouterId.Interface.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Router.Bgp.Bgp_.RouterId.Interface.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Router.Bgp.Bgp_.RouterId.Interface.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Router.Bgp.Bgp_.RouterId.Interface.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Bgp_.RouterId.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Bgp_.RouterId.Interface.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Bgp_.RouterId.Interface.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Bgp_.RouterId.Interface.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Bgp_.RouterId.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Bgp_.RouterId.Interface.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Bgp_.RouterId.Interface.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Bgp_.RouterId.Interface.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Bgp_.RouterId.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                class Sso(Entity):
                    """
                    Stateful Switchover
                    
                    .. attribute:: route_refresh_enable
                    
                    	Enable SSO only for Route\-Refresh capable peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.Sso, self).__init__()

                        self.yang_name = "sso"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_refresh_enable', (YLeaf(YType.empty, 'route-refresh-enable'), ['Empty'])),
                        ])
                        self.route_refresh_enable = None
                        self._segment_path = lambda: "sso"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.Sso, ['route_refresh_enable'], name, value)


                class Transport(Entity):
                    """
                    Transport options
                    
                    .. attribute:: path_mtu_discovery
                    
                    	Use transport path MTU discovery
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Bgp_.Transport, self).__init__()

                        self.yang_name = "transport"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('path_mtu_discovery', (YLeaf(YType.boolean, 'path-mtu-discovery'), ['bool'])),
                        ])
                        self.path_mtu_discovery = None
                        self._segment_path = lambda: "transport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Bgp_.Transport, ['path_mtu_discovery'], name, value)


            class PeerGroup(Entity):
                """
                
                
                .. attribute:: neighbor
                
                	Specify a neighbor router
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Bgp.PeerGroup, self).__init__()

                    self.yang_name = "peer-group"
                    self.yang_parent_name = "bgp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.PeerGroup.Neighbor))])
                    self._leafs = OrderedDict()

                    self.neighbor = YList(self)
                    self._segment_path = lambda: "peer-group"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Bgp.PeerGroup, [], name, value)


                class Neighbor(Entity):
                    """
                    Specify a neighbor router
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: peer_group
                    
                    	Member of the peer\-group
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: cluster_id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: description
                    
                    	Neighbor specific description
                    	**type**\: str
                    
                    .. attribute:: disable_connected_check
                    
                    	one\-hop away EBGP peer using loopback address
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ebgp_multihop
                    
                    	Allow EBGP neighbors not on directly connected networks
                    	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.EbgpMultihop>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fall_over
                    
                    	session fall on peer route lost
                    	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.FallOver>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ha_mode
                    
                    	high availability mode
                    	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.HaMode>`
                    
                    .. attribute:: inherit
                    
                    	Inherit a template
                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.Inherit>`
                    
                    .. attribute:: local_as
                    
                    	Specify a local\-as number
                    	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.LocalAs>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: log_neighbor_changes
                    
                    	Log neighbor up/down and reset reason
                    	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.LogNeighborChanges>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: password
                    
                    	Set a password
                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.Password>`
                    
                    .. attribute:: path_attribute
                    
                    	BGP optional attribute filtering
                    	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute>`
                    
                    .. attribute:: remote_as
                    
                    	Specify a BGP peer\-group remote\-as
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: str
                    
                    .. attribute:: shutdown
                    
                    	Administratively shut down this neighbor
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: timers
                    
                    	BGP per neighbor timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.Timers>`
                    
                    .. attribute:: transport
                    
                    	Transport options
                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.Transport>`
                    
                    .. attribute:: ttl_security
                    
                    	BGP ttl security check
                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.TtlSecurity>`
                    
                    .. attribute:: update_source
                    
                    	Source of routing updates
                    	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource>`
                    
                    .. attribute:: version
                    
                    	Set the BGP version to match a neighbor
                    	**type**\: int
                    
                    	**range:** 4..None
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.PeerGroup.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "peer-group"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.PeerGroup.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.PeerGroup.Neighbor.FallOver)), ("ha-mode", ("ha_mode", Native.Router.Bgp.PeerGroup.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.PeerGroup.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.PeerGroup.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.PeerGroup.Neighbor.LogNeighborChanges)), ("password", ("password", Native.Router.Bgp.PeerGroup.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute)), ("timers", ("timers", Native.Router.Bgp.PeerGroup.Neighbor.Timers)), ("transport", ("transport", Native.Router.Bgp.PeerGroup.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.PeerGroup.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('peer_group', (YLeaf(YType.empty, 'peer-group'), ['Empty'])),
                            ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                            ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                            ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                        ])
                        self.id = None
                        self.peer_group = None
                        self.cluster_id = None
                        self.description = None
                        self.disable_connected_check = None
                        self.remote_as = None
                        self.shutdown = None
                        self.version = None

                        self.ebgp_multihop = None
                        self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                        self.fall_over = None
                        self._children_name_map["fall_over"] = "fall-over"

                        self.ha_mode = Native.Router.Bgp.PeerGroup.Neighbor.HaMode()
                        self.ha_mode.parent = self
                        self._children_name_map["ha_mode"] = "ha-mode"

                        self.inherit = Native.Router.Bgp.PeerGroup.Neighbor.Inherit()
                        self.inherit.parent = self
                        self._children_name_map["inherit"] = "inherit"

                        self.local_as = None
                        self._children_name_map["local_as"] = "local-as"

                        self.log_neighbor_changes = None
                        self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                        self.password = Native.Router.Bgp.PeerGroup.Neighbor.Password()
                        self.password.parent = self
                        self._children_name_map["password"] = "password"

                        self.path_attribute = Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute()
                        self.path_attribute.parent = self
                        self._children_name_map["path_attribute"] = "path-attribute"

                        self.timers = Native.Router.Bgp.PeerGroup.Neighbor.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.transport = Native.Router.Bgp.PeerGroup.Neighbor.Transport()
                        self.transport.parent = self
                        self._children_name_map["transport"] = "transport"

                        self.ttl_security = Native.Router.Bgp.PeerGroup.Neighbor.TtlSecurity()
                        self.ttl_security.parent = self
                        self._children_name_map["ttl_security"] = "ttl-security"

                        self.update_source = Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource()
                        self.update_source.parent = self
                        self._children_name_map["update_source"] = "update-source"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor, ['id', 'peer_group', 'cluster_id', 'description', 'disable_connected_check', 'remote_as', 'shutdown', 'version'], name, value)


                    class EbgpMultihop(Entity):
                        """
                        Allow EBGP neighbors not on directly connected networks
                        
                        .. attribute:: max_hop
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.EbgpMultihop, self).__init__()

                            self.yang_name = "ebgp-multihop"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                            ])
                            self.max_hop = None
                            self._segment_path = lambda: "ebgp-multihop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                    class FallOver(Entity):
                        """
                        session fall on peer route lost
                        
                        .. attribute:: bfd
                        
                        	Use BFD to detect failure
                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.FallOver.Bfd>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: route_map_name
                        
                        	
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.FallOver, self).__init__()

                            self.yang_name = "fall-over"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.PeerGroup.Neighbor.FallOver.Bfd))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                            ])
                            self.route_map_name = None

                            self.bfd = None
                            self._children_name_map["bfd"] = "bfd"
                            self._segment_path = lambda: "fall-over"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.FallOver, ['route_map_name'], name, value)


                        class Bfd(Entity):
                            """
                            Use BFD to detect failure
                            
                            .. attribute:: multi_hop
                            
                            	Force BFD multi\-hop to detect failure
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: single_hop
                            
                            	Force BFD single\-hop to detect failure
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: check_control_plane_failure
                            
                            	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: strict_mode
                            
                            	Enable BFD strict\-mode
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.PeerGroup.Neighbor.FallOver.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "fall-over"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                    ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                    ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                    ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                ])
                                self.multi_hop = None
                                self.single_hop = None
                                self.check_control_plane_failure = None
                                self.strict_mode = None
                                self._segment_path = lambda: "bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                    class HaMode(Entity):
                        """
                        high availability mode
                        
                        .. attribute:: graceful_restart
                        
                        	graceful\-restart for this peer
                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.HaMode.GracefulRestart>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: sso
                        
                        	stateful\-switchover support for this peer
                        	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.HaMode.Sso>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.HaMode, self).__init__()

                            self.yang_name = "ha-mode"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.PeerGroup.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.PeerGroup.Neighbor.HaMode.Sso))])
                            self._leafs = OrderedDict()

                            self.graceful_restart = None
                            self._children_name_map["graceful_restart"] = "graceful-restart"

                            self.sso = None
                            self._children_name_map["sso"] = "sso"
                            self._segment_path = lambda: "ha-mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.HaMode, [], name, value)


                        class GracefulRestart(Entity):
                            """
                            graceful\-restart for this peer
                            
                            .. attribute:: disable
                            
                            	disable graceful\-restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.PeerGroup.Neighbor.HaMode.GracefulRestart, self).__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "ha-mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "graceful-restart"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                        class Sso(Entity):
                            """
                            stateful\-switchover support for this peer
                            
                            .. attribute:: disable
                            
                            	disable stateful\-switchover
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.PeerGroup.Neighbor.HaMode.Sso, self).__init__()

                                self.yang_name = "sso"
                                self.yang_parent_name = "ha-mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "sso"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.HaMode.Sso, ['disable'], name, value)


                    class Inherit(Entity):
                        """
                        Inherit a template
                        
                        .. attribute:: peer_policy
                        
                        	Inherit a peer\-policy template
                        	**type**\: str
                        
                        .. attribute:: peer_session
                        
                        	Inherit a peer\-session template
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.Inherit, self).__init__()

                            self.yang_name = "inherit"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                            ])
                            self.peer_policy = None
                            self.peer_session = None
                            self._segment_path = lambda: "inherit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                    class LocalAs(Entity):
                        """
                        Specify a local\-as number
                        
                        .. attribute:: as_no
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4294967295
                        
                        		**type**\: str
                        
                        .. attribute:: no_prepend
                        
                        	Do not prepend local\-as to updates from ebgp peers
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: replace_as
                        
                        	Replace real AS with local AS in the EBGP updates
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: dual_as
                        
                        	Accept either real AS or local AS from the ebgp peer
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.LocalAs, self).__init__()

                            self.yang_name = "local-as"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                            ])
                            self.as_no = None
                            self.no_prepend = None
                            self.replace_as = None
                            self.dual_as = None
                            self._segment_path = lambda: "local-as"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                    class LogNeighborChanges(Entity):
                        """
                        Log neighbor up/down and reset reason
                        
                        .. attribute:: disable
                        
                        	disable
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.LogNeighborChanges, self).__init__()

                            self.yang_name = "log-neighbor-changes"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "log-neighbor-changes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.LogNeighborChanges, ['disable'], name, value)


                    class Password(Entity):
                        """
                        Set a password
                        
                        .. attribute:: enctype
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..7
                        
                        .. attribute:: text
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.Password, self).__init__()

                            self.yang_name = "password"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                            ])
                            self.enctype = None
                            self.text = None
                            self._segment_path = lambda: "password"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.Password, ['enctype', 'text'], name, value)


                    class PathAttribute(Entity):
                        """
                        BGP optional attribute filtering
                        
                        .. attribute:: discard
                        
                        	Discard matching path\-attribute for this neighbor
                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard>`
                        
                        .. attribute:: treat_as_withdraw
                        
                        	Treat\-as\-withdraw matching path\-attribute for this neighbor
                        	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute, self).__init__()

                            self.yang_name = "path-attribute"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw))])
                            self._leafs = OrderedDict()

                            self.discard = Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard()
                            self.discard.parent = self
                            self._children_name_map["discard"] = "discard"

                            self.treat_as_withdraw = Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw()
                            self.treat_as_withdraw.parent = self
                            self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                            self._segment_path = lambda: "path-attribute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute, [], name, value)


                        class Discard(Entity):
                            """
                            Discard matching path\-attribute for this neighbor
                            
                            .. attribute:: attibute_type
                            
                            	
                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType>`
                            
                            .. attribute:: range
                            
                            	
                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard.Range>`
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard, self).__init__()

                                self.yang_name = "discard"
                                self.yang_parent_name = "path-attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard.Range))])
                                self._leafs = OrderedDict()

                                self.attibute_type = Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType()
                                self.attibute_type.parent = self
                                self._children_name_map["attibute_type"] = "attibute_type"

                                self.range = Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard.Range()
                                self.range.parent = self
                                self._children_name_map["range"] = "range"
                                self._segment_path = lambda: "discard"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard, [], name, value)


                            class AttibuteType(Entity):
                                """
                                
                                
                                .. attribute:: type
                                
                                	path attribute type
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: in_
                                
                                	Perform inbound path\-attribute filtering
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                    self.yang_name = "attibute_type"
                                    self.yang_parent_name = "discard"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ])
                                    self.type = None
                                    self.in_ = None
                                    self._segment_path = lambda: "attibute_type"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                            class Range(Entity):
                                """
                                
                                
                                .. attribute:: start_value
                                
                                	path attribute range start value
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: end_value
                                
                                	path attribute range end value
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: in_
                                
                                	Perform inbound path\-attribute filtering
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "discard"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ])
                                    self.start_value = None
                                    self.end_value = None
                                    self.in_ = None
                                    self._segment_path = lambda: "range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                        class TreatAsWithdraw(Entity):
                            """
                            Treat\-as\-withdraw matching path\-attribute for this neighbor
                            
                            .. attribute:: attibute_type
                            
                            	
                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                            
                            .. attribute:: range
                            
                            	
                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                self.yang_name = "treat-as-withdraw"
                                self.yang_parent_name = "path-attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                self._leafs = OrderedDict()

                                self.attibute_type = Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                self.attibute_type.parent = self
                                self._children_name_map["attibute_type"] = "attibute_type"

                                self.range = Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                self.range.parent = self
                                self._children_name_map["range"] = "range"
                                self._segment_path = lambda: "treat-as-withdraw"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                            class AttibuteType(Entity):
                                """
                                
                                
                                .. attribute:: type
                                
                                	path attribute type
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: in_
                                
                                	Perform inbound path\-attribute filtering
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                    self.yang_name = "attibute_type"
                                    self.yang_parent_name = "treat-as-withdraw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ])
                                    self.type = None
                                    self.in_ = None
                                    self._segment_path = lambda: "attibute_type"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                            class Range(Entity):
                                """
                                
                                
                                .. attribute:: start_value
                                
                                	path attribute range start value
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: end_value
                                
                                	path attribute range end value
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: in_
                                
                                	Perform inbound path\-attribute filtering
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                    self.yang_name = "range"
                                    self.yang_parent_name = "treat-as-withdraw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ])
                                    self.start_value = None
                                    self.end_value = None
                                    self.in_ = None
                                    self._segment_path = lambda: "range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                    class Timers(Entity):
                        """
                        BGP per neighbor timers
                        
                        .. attribute:: keepalive_interval
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: holdtime
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: minimum_neighbor_hold
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                            ])
                            self.keepalive_interval = None
                            self.holdtime = None
                            self.minimum_neighbor_hold = None
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                    class Transport(Entity):
                        """
                        Transport options
                        
                        .. attribute:: connection_mode
                        
                        	Specify passive or active connection
                        	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.Transport.ConnectionMode>`
                        
                        .. attribute:: multi_session
                        
                        	Use multi\-session for transport
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: path_mtu_discovery
                        
                        	Use transport path MTU discovery
                        	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.Transport.PathMtuDiscovery>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.Transport, self).__init__()

                            self.yang_name = "transport"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.PeerGroup.Neighbor.Transport.PathMtuDiscovery))])
                            self._leafs = OrderedDict([
                                ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.PeerGroup.Neighbor.Transport.ConnectionMode')])),
                                ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                            ])
                            self.connection_mode = None
                            self.multi_session = None

                            self.path_mtu_discovery = None
                            self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                            self._segment_path = lambda: "transport"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                        class ConnectionMode(Enum):
                            """
                            ConnectionMode (Enum Class)

                            Specify passive or active connection

                            .. data:: active = 0

                            .. data:: passive = 1

                            """

                            active = Enum.YLeaf(0, "active")

                            passive = Enum.YLeaf(1, "passive")



                        class PathMtuDiscovery(Entity):
                            """
                            Use transport path MTU discovery
                            
                            .. attribute:: disable
                            
                            	disable
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.PeerGroup.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                self.yang_name = "path-mtu-discovery"
                                self.yang_parent_name = "transport"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "path-mtu-discovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                    class TtlSecurity(Entity):
                        """
                        BGP ttl security check
                        
                        .. attribute:: hops
                        
                        	IP hops
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.TtlSecurity, self).__init__()

                            self.yang_name = "ttl-security"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                            ])
                            self.hops = None
                            self._segment_path = lambda: "ttl-security"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.TtlSecurity, ['hops'], name, value)


                    class UpdateSource(Entity):
                        """
                        Source of routing updates
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource, self).__init__()

                            self.yang_name = "update-source"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "update-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "update-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "update-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "update-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "update-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


            class Neighbor(Entity):
                """
                Specify a neighbor router
                
                .. attribute:: id  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: remote_as
                
                	Specify a BGP neighbor
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\: str
                
                	**mandatory**\: True
                
                .. attribute:: cluster_id
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..4294967295
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: description
                
                	Neighbor specific description
                	**type**\: str
                
                .. attribute:: disable_connected_check
                
                	one\-hop away EBGP peer using loopback address
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ebgp_multihop
                
                	Allow EBGP neighbors not on directly connected networks
                	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.EbgpMultihop>`
                
                	**presence node**\: True
                
                .. attribute:: fall_over
                
                	session fall on peer route lost
                	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.FallOver>`
                
                	**presence node**\: True
                
                .. attribute:: ha_mode
                
                	high availability mode
                	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.HaMode>`
                
                .. attribute:: inherit
                
                	Inherit a template
                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.Inherit>`
                
                .. attribute:: local_as
                
                	Specify a local\-as number
                	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.LocalAs>`
                
                	**presence node**\: True
                
                .. attribute:: log_neighbor_changes
                
                	Log neighbor up/down and reset reason
                	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.LogNeighborChanges>`
                
                	**presence node**\: True
                
                .. attribute:: password
                
                	Set a password
                	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.Password>`
                
                .. attribute:: path_attribute
                
                	BGP optional attribute filtering
                	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.PathAttribute>`
                
                .. attribute:: shutdown
                
                	Administratively shut down this neighbor
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: timers
                
                	BGP per neighbor timers
                	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.Timers>`
                
                .. attribute:: transport
                
                	Transport options
                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.Transport>`
                
                .. attribute:: ttl_security
                
                	BGP ttl security check
                	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.TtlSecurity>`
                
                .. attribute:: update_source
                
                	Source of routing updates
                	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.UpdateSource>`
                
                .. attribute:: version
                
                	Set the BGP version to match a neighbor
                	**type**\: int
                
                	**range:** 4..None
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Bgp.Neighbor, self).__init__()

                    self.yang_name = "neighbor"
                    self.yang_parent_name = "bgp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.Neighbor.FallOver)), ("ha-mode", ("ha_mode", Native.Router.Bgp.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.Neighbor.LogNeighborChanges)), ("password", ("password", Native.Router.Bgp.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.Neighbor.PathAttribute)), ("timers", ("timers", Native.Router.Bgp.Neighbor.Timers)), ("transport", ("transport", Native.Router.Bgp.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.Neighbor.UpdateSource))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                        ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                        ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                        ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                        ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                    ])
                    self.id = None
                    self.remote_as = None
                    self.cluster_id = None
                    self.description = None
                    self.disable_connected_check = None
                    self.shutdown = None
                    self.version = None

                    self.ebgp_multihop = None
                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                    self.fall_over = None
                    self._children_name_map["fall_over"] = "fall-over"

                    self.ha_mode = Native.Router.Bgp.Neighbor.HaMode()
                    self.ha_mode.parent = self
                    self._children_name_map["ha_mode"] = "ha-mode"

                    self.inherit = Native.Router.Bgp.Neighbor.Inherit()
                    self.inherit.parent = self
                    self._children_name_map["inherit"] = "inherit"

                    self.local_as = None
                    self._children_name_map["local_as"] = "local-as"

                    self.log_neighbor_changes = None
                    self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                    self.password = Native.Router.Bgp.Neighbor.Password()
                    self.password.parent = self
                    self._children_name_map["password"] = "password"

                    self.path_attribute = Native.Router.Bgp.Neighbor.PathAttribute()
                    self.path_attribute.parent = self
                    self._children_name_map["path_attribute"] = "path-attribute"

                    self.timers = Native.Router.Bgp.Neighbor.Timers()
                    self.timers.parent = self
                    self._children_name_map["timers"] = "timers"

                    self.transport = Native.Router.Bgp.Neighbor.Transport()
                    self.transport.parent = self
                    self._children_name_map["transport"] = "transport"

                    self.ttl_security = Native.Router.Bgp.Neighbor.TtlSecurity()
                    self.ttl_security.parent = self
                    self._children_name_map["ttl_security"] = "ttl-security"

                    self.update_source = Native.Router.Bgp.Neighbor.UpdateSource()
                    self.update_source.parent = self
                    self._children_name_map["update_source"] = "update-source"
                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Bgp.Neighbor, ['id', 'remote_as', 'cluster_id', 'description', 'disable_connected_check', 'shutdown', 'version'], name, value)


                class EbgpMultihop(Entity):
                    """
                    Allow EBGP neighbors not on directly connected networks
                    
                    .. attribute:: max_hop
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.EbgpMultihop, self).__init__()

                        self.yang_name = "ebgp-multihop"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                        ])
                        self.max_hop = None
                        self._segment_path = lambda: "ebgp-multihop"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                class FallOver(Entity):
                    """
                    session fall on peer route lost
                    
                    .. attribute:: bfd
                    
                    	Use BFD to detect failure
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.FallOver.Bfd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: route_map_name
                    
                    	
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.FallOver, self).__init__()

                        self.yang_name = "fall-over"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.Neighbor.FallOver.Bfd))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                        ])
                        self.route_map_name = None

                        self.bfd = None
                        self._children_name_map["bfd"] = "bfd"
                        self._segment_path = lambda: "fall-over"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.FallOver, ['route_map_name'], name, value)


                    class Bfd(Entity):
                        """
                        Use BFD to detect failure
                        
                        .. attribute:: multi_hop
                        
                        	Force BFD multi\-hop to detect failure
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: single_hop
                        
                        	Force BFD single\-hop to detect failure
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: check_control_plane_failure
                        
                        	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: strict_mode
                        
                        	Enable BFD strict\-mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Neighbor.FallOver.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "fall-over"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                            ])
                            self.multi_hop = None
                            self.single_hop = None
                            self.check_control_plane_failure = None
                            self.strict_mode = None
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                class HaMode(Entity):
                    """
                    high availability mode
                    
                    .. attribute:: graceful_restart
                    
                    	graceful\-restart for this peer
                    	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.HaMode.GracefulRestart>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: sso
                    
                    	stateful\-switchover support for this peer
                    	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.HaMode.Sso>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.HaMode, self).__init__()

                        self.yang_name = "ha-mode"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.Neighbor.HaMode.Sso))])
                        self._leafs = OrderedDict()

                        self.graceful_restart = None
                        self._children_name_map["graceful_restart"] = "graceful-restart"

                        self.sso = None
                        self._children_name_map["sso"] = "sso"
                        self._segment_path = lambda: "ha-mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.HaMode, [], name, value)


                    class GracefulRestart(Entity):
                        """
                        graceful\-restart for this peer
                        
                        .. attribute:: disable
                        
                        	disable graceful\-restart
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Neighbor.HaMode.GracefulRestart, self).__init__()

                            self.yang_name = "graceful-restart"
                            self.yang_parent_name = "ha-mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "graceful-restart"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                    class Sso(Entity):
                        """
                        stateful\-switchover support for this peer
                        
                        .. attribute:: disable
                        
                        	disable stateful\-switchover
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Neighbor.HaMode.Sso, self).__init__()

                            self.yang_name = "sso"
                            self.yang_parent_name = "ha-mode"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "sso"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Neighbor.HaMode.Sso, ['disable'], name, value)


                class Inherit(Entity):
                    """
                    Inherit a template
                    
                    .. attribute:: peer_policy
                    
                    	Inherit a peer\-policy template
                    	**type**\: str
                    
                    .. attribute:: peer_session
                    
                    	Inherit a peer\-session template
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.Inherit, self).__init__()

                        self.yang_name = "inherit"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                        ])
                        self.peer_policy = None
                        self.peer_session = None
                        self._segment_path = lambda: "inherit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                class LocalAs(Entity):
                    """
                    Specify a local\-as number
                    
                    .. attribute:: as_no
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: str
                    
                    .. attribute:: no_prepend
                    
                    	Do not prepend local\-as to updates from ebgp peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: replace_as
                    
                    	Replace real AS with local AS in the EBGP updates
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dual_as
                    
                    	Accept either real AS or local AS from the ebgp peer
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.LocalAs, self).__init__()

                        self.yang_name = "local-as"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                            ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                            ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                        ])
                        self.as_no = None
                        self.no_prepend = None
                        self.replace_as = None
                        self.dual_as = None
                        self._segment_path = lambda: "local-as"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                class LogNeighborChanges(Entity):
                    """
                    Log neighbor up/down and reset reason
                    
                    .. attribute:: disable
                    
                    	disable
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.LogNeighborChanges, self).__init__()

                        self.yang_name = "log-neighbor-changes"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "log-neighbor-changes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.LogNeighborChanges, ['disable'], name, value)


                class Password(Entity):
                    """
                    Set a password
                    
                    .. attribute:: enctype
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..7
                    
                    .. attribute:: text
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.Password, self).__init__()

                        self.yang_name = "password"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                            ('text', (YLeaf(YType.str, 'text'), ['str'])),
                        ])
                        self.enctype = None
                        self.text = None
                        self._segment_path = lambda: "password"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.Password, ['enctype', 'text'], name, value)


                class PathAttribute(Entity):
                    """
                    BGP optional attribute filtering
                    
                    .. attribute:: discard
                    
                    	Discard matching path\-attribute for this neighbor
                    	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.PathAttribute.Discard>`
                    
                    .. attribute:: treat_as_withdraw
                    
                    	Treat\-as\-withdraw matching path\-attribute for this neighbor
                    	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.PathAttribute, self).__init__()

                        self.yang_name = "path-attribute"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw))])
                        self._leafs = OrderedDict()

                        self.discard = Native.Router.Bgp.Neighbor.PathAttribute.Discard()
                        self.discard.parent = self
                        self._children_name_map["discard"] = "discard"

                        self.treat_as_withdraw = Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw()
                        self.treat_as_withdraw.parent = self
                        self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                        self._segment_path = lambda: "path-attribute"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.PathAttribute, [], name, value)


                    class Discard(Entity):
                        """
                        Discard matching path\-attribute for this neighbor
                        
                        .. attribute:: attibute_type
                        
                        	
                        	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.PathAttribute.Discard.AttibuteType>`
                        
                        .. attribute:: range
                        
                        	
                        	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.PathAttribute.Discard.Range>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Neighbor.PathAttribute.Discard, self).__init__()

                            self.yang_name = "discard"
                            self.yang_parent_name = "path-attribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.Neighbor.PathAttribute.Discard.Range))])
                            self._leafs = OrderedDict()

                            self.attibute_type = Native.Router.Bgp.Neighbor.PathAttribute.Discard.AttibuteType()
                            self.attibute_type.parent = self
                            self._children_name_map["attibute_type"] = "attibute_type"

                            self.range = Native.Router.Bgp.Neighbor.PathAttribute.Discard.Range()
                            self.range.parent = self
                            self._children_name_map["range"] = "range"
                            self._segment_path = lambda: "discard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Neighbor.PathAttribute.Discard, [], name, value)


                        class AttibuteType(Entity):
                            """
                            
                            
                            .. attribute:: type
                            
                            	path attribute type
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: in_
                            
                            	Perform inbound path\-attribute filtering
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                self.yang_name = "attibute_type"
                                self.yang_parent_name = "discard"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.type = None
                                self.in_ = None
                                self._segment_path = lambda: "attibute_type"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: start_value
                            
                            	path attribute range start value
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: end_value
                            
                            	path attribute range end value
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: in_
                            
                            	Perform inbound path\-attribute filtering
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "discard"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                    ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.start_value = None
                                self.end_value = None
                                self.in_ = None
                                self._segment_path = lambda: "range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                    class TreatAsWithdraw(Entity):
                        """
                        Treat\-as\-withdraw matching path\-attribute for this neighbor
                        
                        .. attribute:: attibute_type
                        
                        	
                        	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                        
                        .. attribute:: range
                        
                        	
                        	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                            self.yang_name = "treat-as-withdraw"
                            self.yang_parent_name = "path-attribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                            self._leafs = OrderedDict()

                            self.attibute_type = Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                            self.attibute_type.parent = self
                            self._children_name_map["attibute_type"] = "attibute_type"

                            self.range = Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                            self.range.parent = self
                            self._children_name_map["range"] = "range"
                            self._segment_path = lambda: "treat-as-withdraw"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                        class AttibuteType(Entity):
                            """
                            
                            
                            .. attribute:: type
                            
                            	path attribute type
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: in_
                            
                            	Perform inbound path\-attribute filtering
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                self.yang_name = "attibute_type"
                                self.yang_parent_name = "treat-as-withdraw"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.type = None
                                self.in_ = None
                                self._segment_path = lambda: "attibute_type"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: start_value
                            
                            	path attribute range start value
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: end_value
                            
                            	path attribute range end value
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: in_
                            
                            	Perform inbound path\-attribute filtering
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "treat-as-withdraw"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                    ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ])
                                self.start_value = None
                                self.end_value = None
                                self.in_ = None
                                self._segment_path = lambda: "range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                class Timers(Entity):
                    """
                    BGP per neighbor timers
                    
                    .. attribute:: keepalive_interval
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: holdtime
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: minimum_neighbor_hold
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.Timers, self).__init__()

                        self.yang_name = "timers"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                            ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                            ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                        ])
                        self.keepalive_interval = None
                        self.holdtime = None
                        self.minimum_neighbor_hold = None
                        self._segment_path = lambda: "timers"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                class Transport(Entity):
                    """
                    Transport options
                    
                    .. attribute:: connection_mode
                    
                    	Specify passive or active connection
                    	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.Transport.ConnectionMode>`
                    
                    .. attribute:: multi_session
                    
                    	Use multi\-session for transport
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: path_mtu_discovery
                    
                    	Use transport path MTU discovery
                    	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.Transport.PathMtuDiscovery>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.Transport, self).__init__()

                        self.yang_name = "transport"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.Neighbor.Transport.PathMtuDiscovery))])
                        self._leafs = OrderedDict([
                            ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Neighbor.Transport.ConnectionMode')])),
                            ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                        ])
                        self.connection_mode = None
                        self.multi_session = None

                        self.path_mtu_discovery = None
                        self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                        self._segment_path = lambda: "transport"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                    class ConnectionMode(Enum):
                        """
                        ConnectionMode (Enum Class)

                        Specify passive or active connection

                        .. data:: active = 0

                        .. data:: passive = 1

                        """

                        active = Enum.YLeaf(0, "active")

                        passive = Enum.YLeaf(1, "passive")



                    class PathMtuDiscovery(Entity):
                        """
                        Use transport path MTU discovery
                        
                        .. attribute:: disable
                        
                        	disable
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                            self.yang_name = "path-mtu-discovery"
                            self.yang_parent_name = "transport"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ])
                            self.disable = None
                            self._segment_path = lambda: "path-mtu-discovery"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                class TtlSecurity(Entity):
                    """
                    BGP ttl security check
                    
                    .. attribute:: hops
                    
                    	IP hops
                    	**type**\: int
                    
                    	**range:** 1..254
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.TtlSecurity, self).__init__()

                        self.yang_name = "ttl-security"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                        ])
                        self.hops = None
                        self._segment_path = lambda: "ttl-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.TtlSecurity, ['hops'], name, value)


                class UpdateSource(Entity):
                    """
                    Source of routing updates
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.UpdateSource.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.UpdateSource.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.UpdateSource.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Neighbor.UpdateSource.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Neighbor.UpdateSource, self).__init__()

                        self.yang_name = "update-source"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.Neighbor.UpdateSource.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Router.Bgp.Neighbor.UpdateSource.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Router.Bgp.Neighbor.UpdateSource.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Router.Bgp.Neighbor.UpdateSource.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Router.Bgp.Neighbor.UpdateSource.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "update-source"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "update-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "update-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "update-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "update-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


            class AddressFamily(Entity):
                """
                Enter Address Family command mode
                
                .. attribute:: with_vrf
                
                	
                	**type**\:  :py:class:`WithVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf>`
                
                .. attribute:: no_vrf
                
                	
                	**type**\:  :py:class:`NoVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Bgp.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "bgp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("with-vrf", ("with_vrf", Native.Router.Bgp.AddressFamily.WithVrf)), ("no-vrf", ("no_vrf", Native.Router.Bgp.AddressFamily.NoVrf))])
                    self._leafs = OrderedDict()

                    self.with_vrf = Native.Router.Bgp.AddressFamily.WithVrf()
                    self.with_vrf.parent = self
                    self._children_name_map["with_vrf"] = "with-vrf"

                    self.no_vrf = Native.Router.Bgp.AddressFamily.NoVrf()
                    self.no_vrf.parent = self
                    self._children_name_map["no_vrf"] = "no-vrf"
                    self._segment_path = lambda: "address-family"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Bgp.AddressFamily, [], name, value)


                class WithVrf(Entity):
                    """
                    
                    
                    .. attribute:: ipv4
                    
                    	Address family
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Address family
                    	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.AddressFamily.WithVrf, self).__init__()

                        self.yang_name = "with-vrf"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4)), ("ipv6", ("ipv6", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6))])
                        self._leafs = OrderedDict()

                        self.ipv4 = YList(self)
                        self.ipv6 = YList(self)
                        self._segment_path = lambda: "with-vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf, [], name, value)


                    class Ipv4(Entity):
                        """
                        Address family
                        
                        .. attribute:: af_name  (key)
                        
                        	
                        	**type**\:  :py:class:`BgpIpv4AfType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.BgpIpv4AfType>`
                        
                        .. attribute:: vrf
                        
                        	
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "with-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'BgpIpv4AfType', '')])),
                            ])
                            self.af_name = None

                            self.vrf = YList(self)
                            self._segment_path = lambda: "ipv4" + "[af-name='" + str(self.af_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4, ['af_name'], name, value)


                        class Vrf(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ipv4_unicast
                            
                            	IPv4 Unicast VRF address family
                            	**type**\:  :py:class:`Ipv4Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast>`
                            
                            .. attribute:: ipv4_multicast
                            
                            	IPv4 Multicast VRF address family
                            	**type**\:  :py:class:`Ipv4Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast>`
                            
                            .. attribute:: ipv4_flowspec
                            
                            	IPv4 Flowspec VRF address family
                            	**type**\:  :py:class:`Ipv4Flowspec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec>`
                            
                            .. attribute:: ipv4_mvpn
                            
                            	IPv4 MVPN VRF address family
                            	**type**\:  :py:class:`Ipv4Mvpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn>`
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("ipv4-unicast", ("ipv4_unicast", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast)), ("ipv4-multicast", ("ipv4_multicast", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast)), ("ipv4-flowspec", ("ipv4_flowspec", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec)), ("ipv4-mvpn", ("ipv4_mvpn", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.ipv4_unicast = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast()
                                self.ipv4_unicast.parent = self
                                self._children_name_map["ipv4_unicast"] = "ipv4-unicast"

                                self.ipv4_multicast = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast()
                                self.ipv4_multicast.parent = self
                                self._children_name_map["ipv4_multicast"] = "ipv4-multicast"

                                self.ipv4_flowspec = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec()
                                self.ipv4_flowspec.parent = self
                                self._children_name_map["ipv4_flowspec"] = "ipv4-flowspec"

                                self.ipv4_mvpn = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn()
                                self.ipv4_mvpn.parent = self
                                self._children_name_map["ipv4_mvpn"] = "ipv4-mvpn"
                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf, ['name'], name, value)


                            class Ipv4Unicast(Entity):
                                """
                                IPv4 Unicast VRF address family
                                
                                .. attribute:: advertise
                                
                                	Configure path advertise/export to other address\-family
                                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Advertise>`
                                
                                .. attribute:: aggregate_address
                                
                                	Configure BGP aggregate entries
                                	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.AggregateAddress>`
                                
                                .. attribute:: bgp
                                
                                	
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_>`
                                
                                .. attribute:: default_information
                                
                                	Control distribution of default information
                                	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DefaultInformation>`
                                
                                .. attribute:: default_metric
                                
                                	Set metric of redistributed routes
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: distance
                                
                                	Define an administrative distance
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance>`
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks in routing updates
                                	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList>`
                                
                                .. attribute:: import_
                                
                                	Configure path import
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import>`
                                
                                .. attribute:: maximum_paths
                                
                                	Forward packets over multiple paths
                                	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths>`
                                
                                .. attribute:: peer_group
                                
                                	
                                	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup>`
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor>`
                                
                                .. attribute:: network
                                
                                	
                                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network>`
                                
                                .. attribute:: redistribute
                                
                                	Redistribute information from another routing protocol
                                	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute>`
                                
                                .. attribute:: snmp
                                
                                	Modify snmp parameters
                                	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: synchronization
                                
                                	Perform IGP synchronization
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: table_map
                                
                                	Map external entry attributes into routing table
                                	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.TableMap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast, self).__init__()

                                    self.yang_name = "ipv4-unicast"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Advertise)), ("aggregate-address", ("aggregate_address", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList)), ("import", ("import_", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp)), ("table-map", ("table_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.TableMap))])
                                    self._leafs = OrderedDict([
                                        ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                        ('synchronization', (YLeaf(YType.empty, 'synchronization'), ['Empty'])),
                                    ])
                                    self.default_metric = None
                                    self.synchronization = None

                                    self.advertise = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Advertise()
                                    self.advertise.parent = self
                                    self._children_name_map["advertise"] = "advertise"

                                    self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.default_information = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DefaultInformation()
                                    self.default_information.parent = self
                                    self._children_name_map["default_information"] = "default-information"

                                    self.distance = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.import_ = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.maximum_paths = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths()
                                    self.maximum_paths.parent = self
                                    self._children_name_map["maximum_paths"] = "maximum-paths"

                                    self.peer_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup()
                                    self.peer_group.parent = self
                                    self._children_name_map["peer_group"] = "peer-group"

                                    self.network = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network()
                                    self.network.parent = self
                                    self._children_name_map["network"] = "network"

                                    self.redistribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute()
                                    self.redistribute.parent = self
                                    self._children_name_map["redistribute"] = "redistribute"

                                    self.snmp = None
                                    self._children_name_map["snmp"] = "snmp"

                                    self.table_map = None
                                    self._children_name_map["table_map"] = "table-map"

                                    self.aggregate_address = YList(self)
                                    self.distribute_list = YList(self)
                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "ipv4-unicast"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast, ['default_metric', 'synchronization'], name, value)


                                class Advertise(Entity):
                                    """
                                    Configure path advertise/export to other address\-family
                                    
                                    .. attribute:: l2vpn
                                    
                                    	Address family for VRF advertise/export
                                    	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Advertise.L2vpn>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Advertise, self).__init__()

                                        self.yang_name = "advertise"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn", ("l2vpn", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Advertise.L2vpn))])
                                        self._leafs = OrderedDict()

                                        self.l2vpn = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Advertise.L2vpn()
                                        self.l2vpn.parent = self
                                        self._children_name_map["l2vpn"] = "l2vpn"
                                        self._segment_path = lambda: "advertise"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Advertise, [], name, value)


                                    class L2vpn(Entity):
                                        """
                                        Address family for VRF advertise/export
                                        
                                        .. attribute:: evpn
                                        
                                        	Advertise/export prefixes to l2vpn evpn table
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Advertise.L2vpn, self).__init__()

                                            self.yang_name = "l2vpn"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                            ])
                                            self.evpn = None
                                            self._segment_path = lambda: "l2vpn"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Advertise.L2vpn, ['evpn'], name, value)


                                class AggregateAddress(Entity):
                                    """
                                    Configure BGP aggregate entries
                                    
                                    .. attribute:: ipv4_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mask  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: advertise_map
                                    
                                    	Set condition to advertise attribute
                                    	**type**\: str
                                    
                                    .. attribute:: as_set
                                    
                                    	Generate AS set path information
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attribute_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: as_override
                                    
                                    	Override matching AS\-number while sending update
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: summary_only
                                    
                                    	Filter more specific routes from updates
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: suppress_map
                                    
                                    	Conditionally filter more specific routes from updates
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.AggregateAddress, self).__init__()

                                        self.yang_name = "aggregate-address"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ipv4_address','ipv4_mask']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mask', (YLeaf(YType.str, 'ipv4-mask'), ['str'])),
                                            ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                            ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                            ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                            ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                            ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                        ])
                                        self.ipv4_address = None
                                        self.ipv4_mask = None
                                        self.advertise_map = None
                                        self.as_set = None
                                        self.attribute_map = None
                                        self.as_override = None
                                        self.route_map = None
                                        self.summary_only = None
                                        self.suppress_map = None
                                        self._segment_path = lambda: "aggregate-address" + "[ipv4-address='" + str(self.ipv4_address) + "']" + "[ipv4-mask='" + str(self.ipv4_mask) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.AggregateAddress, ['ipv4_address', 'ipv4_mask', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                                class Bgp_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: additional_paths
                                    
                                    	Additional paths in the BGP table
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths>`
                                    
                                    .. attribute:: advertise_best_external
                                    
                                    	Advertise best external path to internal peers
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Configure aggregation timer
                                    	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AggregateTimer>`
                                    
                                    .. attribute:: bestpath
                                    
                                    	Change the default bestpath selection
                                    	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath>`
                                    
                                    .. attribute:: dampening
                                    
                                    	Enable route\-flap dampening
                                    	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Dampening>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: recursion
                                    
                                    	recursion rule for the nexthops
                                    	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Recursion>`
                                    
                                    .. attribute:: redistribute_internal
                                    
                                    	Allow redistribution of iBGP into IGPs (dangerous)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	bgp route\-map commands
                                    	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouteMap>`
                                    
                                    .. attribute:: router_id
                                    
                                    	Override configured router identifier (peers will reset)
                                    	**type**\:  :py:class:`RouterId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer>`
                                    
                                    .. attribute:: suppress_inactive
                                    
                                    	Suppress routes that are not in the routing table
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Dampening)), ("recursion", ("recursion", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouteMap)), ("router-id", ("router_id", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                            ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                            ('suppress_inactive', (YLeaf(YType.empty, 'suppress-inactive'), ['Empty'])),
                                        ])
                                        self.advertise_best_external = None
                                        self.redistribute_internal = None
                                        self.suppress_inactive = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.aggregate_timer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AggregateTimer()
                                        self.aggregate_timer.parent = self
                                        self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                        self.bestpath = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath()
                                        self.bestpath.parent = self
                                        self._children_name_map["bestpath"] = "bestpath"

                                        self.dampening = None
                                        self._children_name_map["dampening"] = "dampening"

                                        self.recursion = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Recursion()
                                        self.recursion.parent = self
                                        self._children_name_map["recursion"] = "recursion"

                                        self.route_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouteMap()
                                        self.route_map.parent = self
                                        self._children_name_map["route_map"] = "route-map"

                                        self.router_id = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId()
                                        self.router_id.parent = self
                                        self._children_name_map["router_id"] = "router-id"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_, ['advertise_best_external', 'redistribute_internal', 'suppress_inactive'], name, value)


                                    class AdditionalPaths(Entity):
                                        """
                                        Additional paths in the BGP table
                                        
                                        .. attribute:: install
                                        
                                        	Additional paths to install into RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: select
                                        
                                        	Selection criteria to pick the paths
                                        	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select>`
                                        
                                        .. attribute:: send
                                        
                                        	Send additional paths to neighbors
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Send>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Send))])
                                            self._leafs = OrderedDict([
                                                ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.install = None
                                            self.receive = None

                                            self.select = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select()
                                            self.select.parent = self
                                            self._children_name_map["select"] = "select"

                                            self.send = None
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                        class Select(Entity):
                                            """
                                            Selection criteria to pick the paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: backup
                                            
                                            	Select backup path
                                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Select best\-external path
                                            	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best path
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                self.yang_name = "select"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"

                                                self.backup = None
                                                self._children_name_map["backup"] = "backup"

                                                self.best = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.best_external = None
                                                self._children_name_map["best_external"] = "best-external"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "select"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                            class All(Entity):
                                                """
                                                Select all available paths
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.best = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.group_best = None
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                            class Backup(Entity):
                                                """
                                                Select backup path
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                    self.yang_name = "backup"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None
                                                    self._segment_path = lambda: "backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.all = None

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.all = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                            class BestExternal(Entity):
                                                """
                                                Select best\-external path
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                    self.yang_name = "best-external"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                    ])
                                                    self.backup = None
                                                    self._segment_path = lambda: "best-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best path
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.all = None
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                        class Send(Entity):
                                            """
                                            Send additional paths to neighbors
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.receive = None
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                    class AggregateTimer(Entity):
                                        """
                                        Configure aggregation timer
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Timer interval
                                        	**type**\: int
                                        
                                        	**range:** 6..60
                                        
                                        .. attribute:: disable_timer
                                        
                                        	Timer interval
                                        	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AggregateTimer, self).__init__()

                                            self.yang_name = "aggregate-timer"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                            ])
                                            self.aggregate_timer = None
                                            self.disable_timer = None
                                            self._segment_path = lambda: "aggregate-timer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                        class DisableTimer(Enum):
                                            """
                                            DisableTimer (Enum Class)

                                            Timer interval

                                            .. data:: Y_0 = 0

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")



                                    class Bestpath(Entity):
                                        """
                                        Change the default bestpath selection
                                        
                                        .. attribute:: igp_metric
                                        
                                        	igp metric
                                        	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath.IgpMetric>`
                                        
                                        .. attribute:: prefix_validate
                                        
                                        	Prefix origin validation
                                        	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath, self).__init__()

                                            self.yang_name = "bestpath"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate))])
                                            self._leafs = OrderedDict()

                                            self.igp_metric = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath.IgpMetric()
                                            self.igp_metric.parent = self
                                            self._children_name_map["igp_metric"] = "igp-metric"

                                            self.prefix_validate = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate()
                                            self.prefix_validate.parent = self
                                            self._children_name_map["prefix_validate"] = "prefix-validate"
                                            self._segment_path = lambda: "bestpath"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath, [], name, value)


                                        class IgpMetric(Entity):
                                            """
                                            igp metric
                                            
                                            .. attribute:: ignore
                                            
                                            	Ignore igp metric in bestpath selection
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                                self.yang_name = "igp-metric"
                                                self.yang_parent_name = "bestpath"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ])
                                                self.ignore = None
                                                self._segment_path = lambda: "igp-metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                        class PrefixValidate(Entity):
                                            """
                                            Prefix origin validation
                                            
                                            .. attribute:: allow_invalid
                                            
                                            	Allow invalid routes to be considered for bestpath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: disable
                                            
                                            	Disable prefix validation
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                                self.yang_name = "prefix-validate"
                                                self.yang_parent_name = "bestpath"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.allow_invalid = None
                                                self.disable = None
                                                self._segment_path = lambda: "prefix-validate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                    class Dampening(Entity):
                                        """
                                        Enable route\-flap dampening
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria for dampening
                                        	**type**\: str
                                        
                                        .. attribute:: dampen
                                        
                                        	
                                        	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Dampening.Dampen>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Dampening.Dampen))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.dampen = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Dampening.Dampen()
                                            self.dampen.parent = self
                                            self._children_name_map["dampen"] = "dampen"
                                            self._segment_path = lambda: "dampening"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                        class Dampen(Entity):
                                            """
                                            
                                            
                                            .. attribute:: half_life_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..45
                                            
                                            .. attribute:: reuse_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: max_suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                                self.yang_name = "dampen"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                    ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                    ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                    ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                ])
                                                self.half_life_time = None
                                                self.reuse_time = None
                                                self.suppress_time = None
                                                self.max_suppress_time = None
                                                self._segment_path = lambda: "dampen"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                    class Recursion(Entity):
                                        """
                                        recursion rule for the nexthops
                                        
                                        .. attribute:: host
                                        
                                        	recursion via host for the nexthops
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Recursion, self).__init__()

                                            self.yang_name = "recursion"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                            ])
                                            self.host = None
                                            self._segment_path = lambda: "recursion"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.Recursion, ['host'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        bgp route\-map commands
                                        
                                        .. attribute:: priority
                                        
                                        	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                            ])
                                            self.priority = None
                                            self._segment_path = lambda: "route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                    class RouterId(Entity):
                                        """
                                        Override configured router identifier (peers will reset)
                                        
                                        .. attribute:: ip_id
                                        
                                        	Manually configured router identifier
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: interface
                                        
                                        	Use IPv4 address on interface
                                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface>`
                                        
                                        .. attribute:: vrf
                                        
                                        	vrf\-specific router id configuration
                                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Vrf_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId, self).__init__()

                                            self.yang_name = "router-id"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface))])
                                            self._leafs = OrderedDict([
                                                ('ip_id', (YLeaf(YType.str, 'ip-id'), ['str'])),
                                                ('vrf', (YLeaf(YType.enumeration, 'vrf'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Vrf_')])),
                                            ])
                                            self.ip_id = None
                                            self.vrf = None

                                            self.interface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface()
                                            self.interface.parent = self
                                            self._children_name_map["interface"] = "interface"
                                            self._segment_path = lambda: "router-id"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId, ['ip_id', 'vrf'], name, value)

                                        class Vrf_(Enum):
                                            """
                                            Vrf\_ (Enum Class)

                                            vrf\-specific router id configuration

                                            .. data:: auto_assign = 0

                                            """

                                            auto_assign = Enum.YLeaf(0, "auto-assign")



                                        class Interface(Entity):
                                            """
                                            Use IPv4 address on interface
                                            
                                            .. attribute:: appnav_compress
                                            
                                            	Service\-Context Virtual Interface Compress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: appnav_uncompress
                                            
                                            	Service\-Context Virtual Interface UnCompress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm
                                            
                                            	ATM interface
                                            	**type**\: str
                                            
                                            .. attribute:: atm_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.ATMSubinterface>`
                                            
                                            .. attribute:: atm_acr
                                            
                                            	ATM\-ACR interface
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]
                                            
                                            .. attribute:: atm_acrsubinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.ATMACRsubinterface>`
                                            
                                            .. attribute:: bdi
                                            
                                            	Bridge\-Domain interface
                                            	**type**\: str
                                            
                                            .. attribute:: cem
                                            
                                            	CEM interface
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9]/){2}[0\-9]
                                            
                                            .. attribute:: cem_acr
                                            
                                            	CEM\-ACR interface
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: embedded_service_engine
                                            
                                            	cisco embedded service engine module
                                            	**type**\: str
                                            
                                            .. attribute:: ethernet
                                            
                                            	IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: fastethernet
                                            
                                            	FastEthernet IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: gigabitethernet
                                            
                                            	GigabitEthernet IEEE 802.3z
                                            	**type**\: str
                                            
                                            .. attribute:: fivegigabitethernet
                                            
                                            	Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twentyfivegige
                                            
                                            	Twenty Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twogigabitethernet
                                            
                                            	Two GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: fortygigabitethernet
                                            
                                            	Forty GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: hundredgige
                                            
                                            	Hundred GigabitEthernet
                                            	**type**\: str
                                            
                                            .. attribute:: lisp
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_subinterface
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.LISPSubinterface>`
                                            
                                            .. attribute:: loopback
                                            
                                            	Loopback interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multilink
                                            
                                            	Multilink\-group interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: nve
                                            
                                            	Network virtualization endpoint interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: overlay
                                            
                                            	Overlay interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: port_channel
                                            
                                            	Ethernet Channel of interfaces
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: port_channel_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.PortChannelSubinterface>`
                                            
                                            .. attribute:: pseudowire
                                            
                                            	Pseudowire Interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sm
                                            
                                            	SM Interface
                                            	**type**\: str
                                            
                                            .. attribute:: cellular
                                            
                                            	Cellular Interface
                                            	**type**\: str
                                            
                                            .. attribute:: serial
                                            
                                            	Serial interface
                                            	**type**\: str
                                            
                                            .. attribute:: tengigabitethernet
                                            
                                            	Ten Gigabit Ethernet
                                            	**type**\: str
                                            
                                            .. attribute:: tunnel
                                            
                                            	Tunnel interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_template
                                            
                                            	Virtual Template interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vlan
                                            
                                            	Iosxr Vlans
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: virtualportgroup
                                            
                                            	Virtual Port Group
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasileft
                                            
                                            	vasileft
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasiright
                                            
                                            	vasiright
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "router-id"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.PortChannelSubinterface))])
                                                self._leafs = OrderedDict([
                                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                                ])
                                                self.appnav_compress = None
                                                self.appnav_uncompress = None
                                                self.atm = None
                                                self.atm_acr = None
                                                self.bdi = None
                                                self.cem = None
                                                self.cem_acr = None
                                                self.embedded_service_engine = None
                                                self.ethernet = None
                                                self.fastethernet = None
                                                self.gigabitethernet = None
                                                self.fivegigabitethernet = None
                                                self.twentyfivegige = None
                                                self.twogigabitethernet = None
                                                self.fortygigabitethernet = None
                                                self.hundredgige = None
                                                self.lisp = None
                                                self.loopback = None
                                                self.multilink = None
                                                self.nve = None
                                                self.overlay = None
                                                self.port_channel = None
                                                self.pseudowire = None
                                                self.sm = None
                                                self.cellular = None
                                                self.serial = None
                                                self.tengigabitethernet = None
                                                self.tunnel = None
                                                self.virtual_template = None
                                                self.vlan = None
                                                self.virtualportgroup = None
                                                self.vasileft = None
                                                self.vasiright = None

                                                self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.ATMSubinterface()
                                                self.atm_subinterface.parent = self
                                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                                self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.ATMACRsubinterface()
                                                self.atm_acrsubinterface.parent = self
                                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                                self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.LISPSubinterface()
                                                self.lisp_subinterface.parent = self
                                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                                self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.PortChannelSubinterface()
                                                self.port_channel_subinterface.parent = self
                                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                                self._segment_path = lambda: "interface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                            class ATMSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.ATMSubinterface, self).__init__()

                                                    self.yang_name = "ATM-subinterface"
                                                    self.yang_parent_name = "interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ])
                                                    self.atm = None
                                                    self._segment_path = lambda: "ATM-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.ATMSubinterface, [u'atm'], name, value)


                                            class ATMACRsubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm_acr
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.ATMACRsubinterface, self).__init__()

                                                    self.yang_name = "ATM-ACRsubinterface"
                                                    self.yang_parent_name = "interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ])
                                                    self.atm_acr = None
                                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                            class LISPSubinterface(Entity):
                                                """
                                                Locator/ID Separation Protocol Virtual Interface
                                                
                                                .. attribute:: lisp
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.LISPSubinterface, self).__init__()

                                                    self.yang_name = "LISP-subinterface"
                                                    self.yang_parent_name = "interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ])
                                                    self.lisp = None
                                                    self._segment_path = lambda: "LISP-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.LISPSubinterface, [u'lisp'], name, value)


                                            class PortChannelSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: port_channel
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.PortChannelSubinterface, self).__init__()

                                                    self.yang_name = "Port-channel-subinterface"
                                                    self.yang_parent_name = "interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                    ])
                                                    self.port_channel = None
                                                    self._segment_path = lambda: "Port-channel-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.RouterId.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: disable
                                            
                                            	Disable slow\-peer detection
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.disable = None
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class DefaultInformation(Entity):
                                    """
                                    Control distribution of default information
                                    
                                    .. attribute:: originate
                                    
                                    	Distribute a default route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DefaultInformation, self).__init__()

                                        self.yang_name = "default-information"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                        ])
                                        self.originate = None
                                        self._segment_path = lambda: "default-information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DefaultInformation, ['originate'], name, value)


                                class Distance(Entity):
                                    """
                                    Define an administrative distance
                                    
                                    .. attribute:: bgp
                                    
                                    	BGP distance
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance.Bgp_>`
                                    
                                    .. attribute:: adm_distance
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance.AdmDistance>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance.AdmDistance))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.adm_distance = YList(self)
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        BGP distance
                                        
                                        .. attribute:: extern_as
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: internal_as
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: local
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "distance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                                ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                                ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                            ])
                                            self.extern_as = None
                                            self.internal_as = None
                                            self.local = None
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                    class AdmDistance(Entity):
                                        """
                                        
                                        
                                        .. attribute:: distance  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: srcip  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: wildbits  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: acl
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..99
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..1999
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance.AdmDistance, self).__init__()

                                            self.yang_name = "adm-distance"
                                            self.yang_parent_name = "distance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['distance','srcip','wildbits']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                                ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                                ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                                ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                            ])
                                            self.distance = None
                                            self.srcip = None
                                            self.wildbits = None
                                            self.acl = None
                                            self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter networks in routing updates
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 100..199
                                    
                                    		**type**\: int
                                    
                                    			**range:** 2000..2699
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    .. attribute:: in_
                                    
                                    	Filter incoming routing updates
                                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList.In>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: out
                                    
                                    	Filter outgoing routing updates
                                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList.Out>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("in", ("in_", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList.In)), ("out", ("out", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList.Out))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['int','int','str'])),
                                        ])
                                        self.id = None

                                        self.in_ = None
                                        self._children_name_map["in_"] = "in"

                                        self.out = None
                                        self._children_name_map["out"] = "out"
                                        self._segment_path = lambda: "distribute-list" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList, ['id'], name, value)


                                    class In(Entity):
                                        """
                                        Filter incoming routing updates
                                        
                                        .. attribute:: interface
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList.In, self).__init__()

                                            self.yang_name = "in"
                                            self.yang_parent_name = "distribute-list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ])
                                            self.interface = None
                                            self._segment_path = lambda: "in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList.In, ['interface'], name, value)


                                    class Out(Entity):
                                        """
                                        Filter outgoing routing updates
                                        
                                        .. attribute:: interface
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList.Out, self).__init__()

                                            self.yang_name = "out"
                                            self.yang_parent_name = "distribute-list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ])
                                            self.interface = None
                                            self._segment_path = lambda: "out"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.DistributeList.Out, ['interface'], name, value)


                                class Import(Entity):
                                    """
                                    Configure path import
                                    
                                    .. attribute:: path
                                    
                                    	Path selection and path limit
                                    	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Path>`
                                    
                                    .. attribute:: vpnv4
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Vpnv4>`
                                    
                                    .. attribute:: vpnv6
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Vpnv6>`
                                    
                                    .. attribute:: l2vpn
                                    
                                    	Configure EVPN to VPN path import
                                    	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.L2vpn>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Path)), ("vpnv4", ("vpnv4", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Vpnv4)), ("vpnv6", ("vpnv6", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Vpnv6)), ("l2vpn", ("l2vpn", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.L2vpn))])
                                        self._leafs = OrderedDict()

                                        self.path = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Path()
                                        self.path.parent = self
                                        self._children_name_map["path"] = "path"

                                        self.vpnv4 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Vpnv4()
                                        self.vpnv4.parent = self
                                        self._children_name_map["vpnv4"] = "vpnv4"

                                        self.vpnv6 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Vpnv6()
                                        self.vpnv6.parent = self
                                        self._children_name_map["vpnv6"] = "vpnv6"

                                        self.l2vpn = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.L2vpn()
                                        self.l2vpn.parent = self
                                        self._children_name_map["l2vpn"] = "l2vpn"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import, [], name, value)


                                    class Path(Entity):
                                        """
                                        Path selection and path limit
                                        
                                        .. attribute:: limit
                                        
                                        	Per net imported path limit
                                        	**type**\: int
                                        
                                        	**range:** 2..255
                                        
                                        .. attribute:: selection
                                        
                                        	Path selection policy
                                        	**type**\:  :py:class:`Selection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Path.Selection>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("selection", ("selection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Path.Selection))])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                                            ])
                                            self.limit = None

                                            self.selection = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Path.Selection()
                                            self.selection.parent = self
                                            self._children_name_map["selection"] = "selection"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Path, ['limit'], name, value)


                                        class Selection(Entity):
                                            """
                                            Path selection policy
                                            
                                            .. attribute:: all
                                            
                                            	Import all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Path.Selection, self).__init__()

                                                self.yang_name = "selection"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "selection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Path.Selection, ['all'], name, value)


                                    class Vpnv4(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Vpnv4, self).__init__()

                                            self.yang_name = "vpnv4"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv4"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Vpnv4, ['unicast', 're_originate'], name, value)


                                    class Vpnv6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	Imported path with RT re\-originate
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Vpnv6, self).__init__()

                                            self.yang_name = "vpnv6"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.Vpnv6, ['unicast', 're_originate'], name, value)


                                    class L2vpn(Entity):
                                        """
                                        Configure EVPN to VPN path import
                                        
                                        .. attribute:: evpn
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.L2vpn, self).__init__()

                                            self.yang_name = "l2vpn"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.evpn = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "l2vpn"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Import.L2vpn, ['evpn', 're_originate'], name, value)


                                class MaximumPaths(Entity):
                                    """
                                    Forward packets over multiple paths
                                    
                                    .. attribute:: ebgp
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: eibgp
                                    
                                    	Both eBGP and iBGP paths as multipath
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: ibgp
                                    
                                    	iBGP\-multipath
                                    	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths.Ibgp>`
                                    
                                    .. attribute:: external_rtfilter
                                    
                                    	VPN prefix multipath on external RT\-Filter peers
                                    	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths.ExternalRtfilter>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths, self).__init__()

                                        self.yang_name = "maximum-paths"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths.ExternalRtfilter))])
                                        self._leafs = OrderedDict([
                                            ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                            ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                        ])
                                        self.ebgp = None
                                        self.eibgp = None

                                        self.ibgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths.Ibgp()
                                        self.ibgp.parent = self
                                        self._children_name_map["ibgp"] = "ibgp"

                                        self.external_rtfilter = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths.ExternalRtfilter()
                                        self.external_rtfilter.parent = self
                                        self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                        self._segment_path = lambda: "maximum-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                    class Ibgp(Entity):
                                        """
                                        iBGP\-multipath
                                        
                                        .. attribute:: unequal_cost
                                        
                                        	Perform un\-equal cost multipath selection
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: max
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths.Ibgp, self).__init__()

                                            self.yang_name = "ibgp"
                                            self.yang_parent_name = "maximum-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                            ])
                                            self.unequal_cost = None
                                            self.max = None
                                            self._segment_path = lambda: "ibgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                    class ExternalRtfilter(Entity):
                                        """
                                        VPN prefix multipath on external RT\-Filter peers
                                        
                                        .. attribute:: max
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                            self.yang_name = "external-rtfilter"
                                            self.yang_parent_name = "maximum-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                            ])
                                            self.max = None
                                            self._segment_path = lambda: "external-rtfilter"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                class PeerGroup(Entity):
                                    """
                                    
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup, self).__init__()

                                        self.yang_name = "peer-group"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor))])
                                        self._leafs = OrderedDict()

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "peer-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: peer_group
                                        
                                        	Member of the peer\-group
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_map
                                        
                                        	specify route\-map for conditional advertisement
                                        	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable a AIGP on neighbor
                                        	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: announce
                                        
                                        	Announce RPKI state using an extended community
                                        	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Announce>`
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AsOverride>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability>`
                                        
                                        .. attribute:: cluster_id
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: description
                                        
                                        	Neighbor specific description
                                        	**type**\: str
                                        
                                        .. attribute:: disable_connected_check
                                        
                                        	one\-hop away EBGP peer using loopback address
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: distribute_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.DistributeList>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ebgp_multihop
                                        
                                        	Allow EBGP neighbors not on directly connected networks
                                        	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.EbgpMultihop>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: fall_over
                                        
                                        	session fall on peer route lost
                                        	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FallOver>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FilterList>`
                                        
                                        .. attribute:: ha_mode
                                        
                                        	high availability mode
                                        	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Inherit>`
                                        
                                        .. attribute:: local_as
                                        
                                        	Specify a local\-as number
                                        	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.LocalAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: log_neighbor_changes
                                        
                                        	Log neighbor up/down and reset reason
                                        	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.LogNeighborChanges>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: password
                                        
                                        	Set a password
                                        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Password>`
                                        
                                        .. attribute:: path_attribute
                                        
                                        	BGP optional attribute filtering
                                        	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remote_as
                                        
                                        	Specify a BGP peer\-group remote\-as
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: send_label
                                        
                                        	Send NLRI + MPLS Label to this peer
                                        	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendLabel>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: shutdown
                                        
                                        	Administratively shut down this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: timers
                                        
                                        	BGP per neighbor timers
                                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Timers>`
                                        
                                        .. attribute:: translate_update
                                        
                                        	Translate update to MBGP format
                                        	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate>`
                                        
                                        .. attribute:: transport
                                        
                                        	Transport options
                                        	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Transport>`
                                        
                                        .. attribute:: ttl_security
                                        
                                        	BGP ttl security check
                                        	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TtlSecurity>`
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: update_source
                                        
                                        	Source of routing updates
                                        	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource>`
                                        
                                        .. attribute:: version
                                        
                                        	Set the BGP version to match a neighbor
                                        	**type**\: int
                                        
                                        	**range:** 4..None
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "peer-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.DistributeList)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FallOver)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FilterList)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Timers)), ("translate-update", ("translate_update", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ('peer_group', (YLeaf(YType.empty, 'peer-group'), ['Empty'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.peer_group = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.cluster_id = None
                                            self.description = None
                                            self.disable_connected_check = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.remote_as = None
                                            self.route_reflector_client = None
                                            self.shutdown = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.version = None
                                            self.weight = None

                                            self.advertise_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap()
                                            self.advertise_map.parent = self
                                            self._children_name_map["advertise_map"] = "advertise-map"

                                            self.aigp = None
                                            self._children_name_map["aigp"] = "aigp"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.announce = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Announce()
                                            self.announce.parent = self
                                            self._children_name_map["announce"] = "announce"

                                            self.as_override = None
                                            self._children_name_map["as_override"] = "as-override"

                                            self.capability = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.ebgp_multihop = None
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                            self.fall_over = None
                                            self._children_name_map["fall_over"] = "fall-over"

                                            self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode()
                                            self.ha_mode.parent = self
                                            self._children_name_map["ha_mode"] = "ha-mode"

                                            self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.local_as = None
                                            self._children_name_map["local_as"] = "local-as"

                                            self.log_neighbor_changes = None
                                            self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                            self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"

                                            self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute()
                                            self.path_attribute.parent = self
                                            self._children_name_map["path_attribute"] = "path-attribute"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.send_label = None
                                            self._children_name_map["send_label"] = "send-label"

                                            self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"

                                            self.translate_update = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate()
                                            self.translate_update.parent = self
                                            self._children_name_map["translate_update"] = "translate-update"

                                            self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Transport()
                                            self.transport.parent = self
                                            self._children_name_map["transport"] = "transport"

                                            self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TtlSecurity()
                                            self.ttl_security.parent = self
                                            self._children_name_map["ttl_security"] = "ttl-security"

                                            self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource()
                                            self.update_source.parent = self
                                            self._children_name_map["update_source"] = "update-source"

                                            self.distribute_list = YList(self)
                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor, ['id', 'peer_group', 'activate', 'advertisement_interval', 'allow_policy', 'cluster_id', 'description', 'disable_connected_check', 'dmzlink_bw', 'next_hop_unchanged', 'remote_as', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'version', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AdvertiseMap(Entity):
                                            """
                                            specify route\-map for conditional advertisement
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap, self).__init__()

                                                self.yang_name = "advertise-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name))])
                                                self._leafs = OrderedDict()

                                                self.name = YList(self)
                                                self._segment_path = lambda: "advertise-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap, [], name, value)


                                            class Name(Entity):
                                                """
                                                
                                                
                                                .. attribute:: word  (key)
                                                
                                                	advertise route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: non_exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, self).__init__()

                                                    self.yang_name = "name"
                                                    self.yang_parent_name = "advertise-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                        ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                        ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                    ])
                                                    self.word = None
                                                    self.exist_map = None
                                                    self.non_exist_map = None
                                                    self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                        class Aigp(Entity):
                                            """
                                            Enable a AIGP on neighbor
                                            
                                            .. attribute:: send
                                            
                                            	Cost community or MED carrying AIGP VALUE
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                                self.yang_name = "aigp"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.send = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send()
                                                self.send.parent = self
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "aigp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                            class Send(Entity):
                                                """
                                                Cost community or MED carrying AIGP VALUE
                                                
                                                .. attribute:: cost_community
                                                
                                                	Cost extended community carrying AIGP Value
                                                	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                                
                                                .. attribute:: med
                                                
                                                	Med carrying AIGP Value
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "aigp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                    ])
                                                    self.med = None

                                                    self.cost_community = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                    self.cost_community.parent = self
                                                    self._children_name_map["cost_community"] = "cost-community"
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                                class CostCommunity(Entity):
                                                    """
                                                    Cost extended community carrying AIGP Value
                                                    
                                                    .. attribute:: cc_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                        self.yang_name = "cost-community"
                                                        self.yang_parent_name = "send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                        self._leafs = OrderedDict()

                                                        self.cc_range = YList(self)
                                                        self._segment_path = lambda: "cost-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                    class CcRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Community ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: poi
                                                        
                                                        	Point of insertion
                                                        	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                            self.yang_name = "cc-range"
                                                            self.yang_parent_name = "cost-community"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ])
                                                            self.range = None

                                                            self.poi = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                            self.poi.parent = self
                                                            self._children_name_map["poi"] = "poi"
                                                            self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                        class Poi(Entity):
                                                            """
                                                            Point of insertion
                                                            
                                                            .. attribute:: igp_cost
                                                            
                                                            	Point of insertion after IGP
                                                            	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            .. attribute:: pre_bestpath
                                                            
                                                            	Point of insertion at beginning
                                                            	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                self.yang_name = "poi"
                                                                self.yang_parent_name = "cc-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                self._leafs = OrderedDict()

                                                                self.igp_cost = None
                                                                self._children_name_map["igp_cost"] = "igp-cost"

                                                                self.pre_bestpath = None
                                                                self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                self._segment_path = lambda: "poi"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                            class IgpCost(Entity):
                                                                """
                                                                Point of insertion after IGP
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                    self.yang_name = "igp-cost"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "igp-cost"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                            class PreBestpath(Entity):
                                                                """
                                                                Point of insertion at beginning
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                    self.yang_name = "pre-bestpath"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "pre-bestpath"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Announce(Entity):
                                            """
                                            Announce RPKI state using an extended community
                                            
                                            .. attribute:: rpki
                                            
                                            	Announce RPKI information using an extended community
                                            	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Announce, self).__init__()

                                                self.yang_name = "announce"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki))])
                                                self._leafs = OrderedDict()

                                                self.rpki = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki()
                                                self.rpki.parent = self
                                                self._children_name_map["rpki"] = "rpki"
                                                self._segment_path = lambda: "announce"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Announce, [], name, value)


                                            class Rpki(Entity):
                                                """
                                                Announce RPKI information using an extended community
                                                
                                                .. attribute:: state
                                                
                                                	Announce RPKI state information using an extended community
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki, self).__init__()

                                                    self.yang_name = "rpki"
                                                    self.yang_parent_name = "announce"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                    ])
                                                    self.state = None
                                                    self._segment_path = lambda: "rpki"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki, ['state'], name, value)


                                        class AsOverride(Entity):
                                            """
                                            Override matching AS\-number while sending update
                                            
                                            .. attribute:: disable
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AsOverride, self).__init__()

                                                self.yang_name = "as-override"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "as-override"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.AsOverride, ['disable'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class DistributeList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                            
                                            .. attribute:: accesslist
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..199
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..2699
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                                self.yang_name = "distribute-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                    ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                ])
                                                self.inout = None
                                                self.accesslist = None
                                                self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class EbgpMultihop(Entity):
                                            """
                                            Allow EBGP neighbors not on directly connected networks
                                            
                                            .. attribute:: max_hop
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.EbgpMultihop, self).__init__()

                                                self.yang_name = "ebgp-multihop"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                                ])
                                                self.max_hop = None
                                                self._segment_path = lambda: "ebgp-multihop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                        class FallOver(Entity):
                                            """
                                            session fall on peer route lost
                                            
                                            .. attribute:: bfd
                                            
                                            	Use BFD to detect failure
                                            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FallOver.Bfd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FallOver, self).__init__()

                                                self.yang_name = "fall-over"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FallOver.Bfd))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.route_map_name = None

                                                self.bfd = None
                                                self._children_name_map["bfd"] = "bfd"
                                                self._segment_path = lambda: "fall-over"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FallOver, ['route_map_name'], name, value)


                                            class Bfd(Entity):
                                                """
                                                Use BFD to detect failure
                                                
                                                .. attribute:: multi_hop
                                                
                                                	Force BFD multi\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: single_hop
                                                
                                                	Force BFD single\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: check_control_plane_failure
                                                
                                                	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: strict_mode
                                                
                                                	Enable BFD strict\-mode
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FallOver.Bfd, self).__init__()

                                                    self.yang_name = "bfd"
                                                    self.yang_parent_name = "fall-over"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                        ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                        ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                        ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                    ])
                                                    self.multi_hop = None
                                                    self.single_hop = None
                                                    self.check_control_plane_failure = None
                                                    self.strict_mode = None
                                                    self._segment_path = lambda: "bfd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class HaMode(Entity):
                                            """
                                            high availability mode
                                            
                                            .. attribute:: graceful_restart
                                            
                                            	graceful\-restart for this peer
                                            	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode.GracefulRestart>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: sso
                                            
                                            	stateful\-switchover support for this peer
                                            	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode.Sso>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode, self).__init__()

                                                self.yang_name = "ha-mode"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode.Sso))])
                                                self._leafs = OrderedDict()

                                                self.graceful_restart = None
                                                self._children_name_map["graceful_restart"] = "graceful-restart"

                                                self.sso = None
                                                self._children_name_map["sso"] = "sso"
                                                self._segment_path = lambda: "ha-mode"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode, [], name, value)


                                            class GracefulRestart(Entity):
                                                """
                                                graceful\-restart for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable graceful\-restart
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                    self.yang_name = "graceful-restart"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "graceful-restart"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                            class Sso(Entity):
                                                """
                                                stateful\-switchover support for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable stateful\-switchover
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode.Sso, self).__init__()

                                                    self.yang_name = "sso"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "sso"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.HaMode.Sso, ['disable'], name, value)


                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class LocalAs(Entity):
                                            """
                                            Specify a local\-as number
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: no_prepend
                                            
                                            	Do not prepend local\-as to updates from ebgp peers
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace real AS with local AS in the EBGP updates
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: dual_as
                                            
                                            	Accept either real AS or local AS from the ebgp peer
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.LocalAs, self).__init__()

                                                self.yang_name = "local-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                    ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                                ])
                                                self.as_no = None
                                                self.no_prepend = None
                                                self.replace_as = None
                                                self.dual_as = None
                                                self._segment_path = lambda: "local-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                        class LogNeighborChanges(Entity):
                                            """
                                            Log neighbor up/down and reset reason
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.LogNeighborChanges, self).__init__()

                                                self.yang_name = "log-neighbor-changes"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "log-neighbor-changes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                        class Password(Entity):
                                            """
                                            Set a password
                                            
                                            .. attribute:: enctype
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: text
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Password, self).__init__()

                                                self.yang_name = "password"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                                ])
                                                self.enctype = None
                                                self.text = None
                                                self._segment_path = lambda: "password"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Password, ['enctype', 'text'], name, value)


                                        class PathAttribute(Entity):
                                            """
                                            BGP optional attribute filtering
                                            
                                            .. attribute:: discard
                                            
                                            	Discard matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard>`
                                            
                                            .. attribute:: treat_as_withdraw
                                            
                                            	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute, self).__init__()

                                                self.yang_name = "path-attribute"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw))])
                                                self._leafs = OrderedDict()

                                                self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard()
                                                self.discard.parent = self
                                                self._children_name_map["discard"] = "discard"

                                                self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw()
                                                self.treat_as_withdraw.parent = self
                                                self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                                self._segment_path = lambda: "path-attribute"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute, [], name, value)


                                            class Discard(Entity):
                                                """
                                                Discard matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard, self).__init__()

                                                    self.yang_name = "discard"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "discard"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                            class TreatAsWithdraw(Entity):
                                                """
                                                Treat\-as\-withdraw matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                    self.yang_name = "treat-as-withdraw"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "treat-as-withdraw"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SendLabel(Entity):
                                            """
                                            Send NLRI + MPLS Label to this peer
                                            
                                            .. attribute:: send_label_explicit
                                            
                                            	
                                            	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendLabel, self).__init__()

                                                self.yang_name = "send-label"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit')])),
                                                ])
                                                self.send_label_explicit = None
                                                self._segment_path = lambda: "send-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                            class SendLabelExplicit(Enum):
                                                """
                                                SendLabelExplicit (Enum Class)

                                                .. data:: explicit_null = 0

                                                """

                                                explicit_null = Enum.YLeaf(0, "explicit-null")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class Timers(Entity):
                                            """
                                            BGP per neighbor timers
                                            
                                            .. attribute:: keepalive_interval
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: holdtime
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: minimum_neighbor_hold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Timers, self).__init__()

                                                self.yang_name = "timers"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                    ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                    ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                                ])
                                                self.keepalive_interval = None
                                                self.holdtime = None
                                                self.minimum_neighbor_hold = None
                                                self._segment_path = lambda: "timers"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                        class TranslateUpdate(Entity):
                                            """
                                            Translate update to MBGP format
                                            
                                            .. attribute:: ipv4
                                            
                                            	Address Family
                                            	**type**\:  :py:class:`Ipv4_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate, self).__init__()

                                                self.yang_name = "translate-update"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_))])
                                                self._leafs = OrderedDict()

                                                self.ipv4 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_()
                                                self.ipv4.parent = self
                                                self._children_name_map["ipv4"] = "ipv4"
                                                self._segment_path = lambda: "translate-update"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate, [], name, value)


                                            class Ipv4_(Entity):
                                                """
                                                Address Family
                                                
                                                .. attribute:: multicast
                                                
                                                	Address Family modifier
                                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_, self).__init__()

                                                    self.yang_name = "ipv4"
                                                    self.yang_parent_name = "translate-update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast))])
                                                    self._leafs = OrderedDict()

                                                    self.multicast = None
                                                    self._children_name_map["multicast"] = "multicast"
                                                    self._segment_path = lambda: "ipv4"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_, [], name, value)


                                                class Multicast(Entity):
                                                    """
                                                    Address Family modifier
                                                    
                                                    .. attribute:: unicast
                                                    
                                                    	Address Family modifier
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast, self).__init__()

                                                        self.yang_name = "multicast"
                                                        self.yang_parent_name = "ipv4"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                        ])
                                                        self.unicast = None
                                                        self._segment_path = lambda: "multicast"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast, ['unicast'], name, value)


                                        class Transport(Entity):
                                            """
                                            Transport options
                                            
                                            .. attribute:: connection_mode
                                            
                                            	Specify passive or active connection
                                            	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Transport.ConnectionMode>`
                                            
                                            .. attribute:: multi_session
                                            
                                            	Use multi\-session for transport
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: path_mtu_discovery
                                            
                                            	Use transport path MTU discovery
                                            	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Transport, self).__init__()

                                                self.yang_name = "transport"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery))])
                                                self._leafs = OrderedDict([
                                                    ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Transport.ConnectionMode')])),
                                                    ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                                ])
                                                self.connection_mode = None
                                                self.multi_session = None

                                                self.path_mtu_discovery = None
                                                self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                                self._segment_path = lambda: "transport"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                            class ConnectionMode(Enum):
                                                """
                                                ConnectionMode (Enum Class)

                                                Specify passive or active connection

                                                .. data:: active = 0

                                                .. data:: passive = 1

                                                """

                                                active = Enum.YLeaf(0, "active")

                                                passive = Enum.YLeaf(1, "passive")



                                            class PathMtuDiscovery(Entity):
                                                """
                                                Use transport path MTU discovery
                                                
                                                .. attribute:: disable
                                                
                                                	disable
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                    self.yang_name = "path-mtu-discovery"
                                                    self.yang_parent_name = "transport"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "path-mtu-discovery"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                        class TtlSecurity(Entity):
                                            """
                                            BGP ttl security check
                                            
                                            .. attribute:: hops
                                            
                                            	IP hops
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TtlSecurity, self).__init__()

                                                self.yang_name = "ttl-security"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                                ])
                                                self.hops = None
                                                self._segment_path = lambda: "ttl-security"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.TtlSecurity, ['hops'], name, value)


                                        class UpdateSource(Entity):
                                            """
                                            Source of routing updates
                                            
                                            .. attribute:: appnav_compress
                                            
                                            	Service\-Context Virtual Interface Compress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: appnav_uncompress
                                            
                                            	Service\-Context Virtual Interface UnCompress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm
                                            
                                            	ATM interface
                                            	**type**\: str
                                            
                                            .. attribute:: atm_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface>`
                                            
                                            .. attribute:: atm_acr
                                            
                                            	ATM\-ACR interface
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]
                                            
                                            .. attribute:: atm_acrsubinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface>`
                                            
                                            .. attribute:: bdi
                                            
                                            	Bridge\-Domain interface
                                            	**type**\: str
                                            
                                            .. attribute:: cem
                                            
                                            	CEM interface
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9]/){2}[0\-9]
                                            
                                            .. attribute:: cem_acr
                                            
                                            	CEM\-ACR interface
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: embedded_service_engine
                                            
                                            	cisco embedded service engine module
                                            	**type**\: str
                                            
                                            .. attribute:: ethernet
                                            
                                            	IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: fastethernet
                                            
                                            	FastEthernet IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: gigabitethernet
                                            
                                            	GigabitEthernet IEEE 802.3z
                                            	**type**\: str
                                            
                                            .. attribute:: fivegigabitethernet
                                            
                                            	Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twentyfivegige
                                            
                                            	Twenty Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twogigabitethernet
                                            
                                            	Two GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: fortygigabitethernet
                                            
                                            	Forty GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: hundredgige
                                            
                                            	Hundred GigabitEthernet
                                            	**type**\: str
                                            
                                            .. attribute:: lisp
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_subinterface
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface>`
                                            
                                            .. attribute:: loopback
                                            
                                            	Loopback interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multilink
                                            
                                            	Multilink\-group interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: nve
                                            
                                            	Network virtualization endpoint interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: overlay
                                            
                                            	Overlay interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: port_channel
                                            
                                            	Ethernet Channel of interfaces
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: port_channel_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface>`
                                            
                                            .. attribute:: pseudowire
                                            
                                            	Pseudowire Interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sm
                                            
                                            	SM Interface
                                            	**type**\: str
                                            
                                            .. attribute:: cellular
                                            
                                            	Cellular Interface
                                            	**type**\: str
                                            
                                            .. attribute:: serial
                                            
                                            	Serial interface
                                            	**type**\: str
                                            
                                            .. attribute:: tengigabitethernet
                                            
                                            	Ten Gigabit Ethernet
                                            	**type**\: str
                                            
                                            .. attribute:: tunnel
                                            
                                            	Tunnel interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_template
                                            
                                            	Virtual Template interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vlan
                                            
                                            	Iosxr Vlans
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: virtualportgroup
                                            
                                            	Virtual Port Group
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasileft
                                            
                                            	vasileft
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasiright
                                            
                                            	vasiright
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource, self).__init__()

                                                self.yang_name = "update-source"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface))])
                                                self._leafs = OrderedDict([
                                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                                ])
                                                self.appnav_compress = None
                                                self.appnav_uncompress = None
                                                self.atm = None
                                                self.atm_acr = None
                                                self.bdi = None
                                                self.cem = None
                                                self.cem_acr = None
                                                self.embedded_service_engine = None
                                                self.ethernet = None
                                                self.fastethernet = None
                                                self.gigabitethernet = None
                                                self.fivegigabitethernet = None
                                                self.twentyfivegige = None
                                                self.twogigabitethernet = None
                                                self.fortygigabitethernet = None
                                                self.hundredgige = None
                                                self.lisp = None
                                                self.loopback = None
                                                self.multilink = None
                                                self.nve = None
                                                self.overlay = None
                                                self.port_channel = None
                                                self.pseudowire = None
                                                self.sm = None
                                                self.cellular = None
                                                self.serial = None
                                                self.tengigabitethernet = None
                                                self.tunnel = None
                                                self.virtual_template = None
                                                self.vlan = None
                                                self.virtualportgroup = None
                                                self.vasileft = None
                                                self.vasiright = None

                                                self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface()
                                                self.atm_subinterface.parent = self
                                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                                self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface()
                                                self.atm_acrsubinterface.parent = self
                                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                                self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface()
                                                self.lisp_subinterface.parent = self
                                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                                self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface()
                                                self.port_channel_subinterface.parent = self
                                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                                self._segment_path = lambda: "update-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                            class ATMSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                    self.yang_name = "ATM-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ])
                                                    self.atm = None
                                                    self._segment_path = lambda: "ATM-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                            class ATMACRsubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm_acr
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                    self.yang_name = "ATM-ACRsubinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ])
                                                    self.atm_acr = None
                                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                            class LISPSubinterface(Entity):
                                                """
                                                Locator/ID Separation Protocol Virtual Interface
                                                
                                                .. attribute:: lisp
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                    self.yang_name = "LISP-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ])
                                                    self.lisp = None
                                                    self._segment_path = lambda: "LISP-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                            class PortChannelSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: port_channel
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                    self.yang_name = "Port-channel-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                    ])
                                                    self.port_channel = None
                                                    self._segment_path = lambda: "Port-channel-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_as
                                    
                                    	Specify a BGP peer\-group remote\-as
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertise_map
                                    
                                    	specify route\-map for conditional advertisement
                                    	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AdvertiseMap>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: aigp
                                    
                                    	Enable a AIGP on neighbor
                                    	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: announce
                                    
                                    	Announce RPKI state using an extended community
                                    	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Announce>`
                                    
                                    .. attribute:: as_override
                                    
                                    	Override matching AS\-number while sending update
                                    	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AsOverride>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability>`
                                    
                                    .. attribute:: cluster_id
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: default_originate
                                    
                                    	Originate default route to this neighbor
                                    	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.DefaultOriginate>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: description
                                    
                                    	Neighbor specific description
                                    	**type**\: str
                                    
                                    .. attribute:: disable_connected_check
                                    
                                    	one\-hop away EBGP peer using loopback address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.DistributeList>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ebgp_multihop
                                    
                                    	Allow EBGP neighbors not on directly connected networks
                                    	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.EbgpMultihop>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fall_over
                                    
                                    	session fall on peer route lost
                                    	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FallOver>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FilterList>`
                                    
                                    .. attribute:: ha_mode
                                    
                                    	high availability mode
                                    	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Inherit>`
                                    
                                    .. attribute:: local_as
                                    
                                    	Specify a local\-as number
                                    	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.LocalAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: log_neighbor_changes
                                    
                                    	Log neighbor up/down and reset reason
                                    	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.LogNeighborChanges>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: password
                                    
                                    	Set a password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Password>`
                                    
                                    .. attribute:: path_attribute
                                    
                                    	BGP optional attribute filtering
                                    	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	Member of the peer\-group
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PeerGroup>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: send_label
                                    
                                    	Send NLRI + MPLS Label to this peer
                                    	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendLabel>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: shutdown
                                    
                                    	Administratively shut down this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: timers
                                    
                                    	BGP per neighbor timers
                                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Timers>`
                                    
                                    .. attribute:: translate_update
                                    
                                    	Translate update to MBGP format
                                    	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate>`
                                    
                                    .. attribute:: transport
                                    
                                    	Transport options
                                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Transport>`
                                    
                                    .. attribute:: ttl_security
                                    
                                    	BGP ttl security check
                                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TtlSecurity>`
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: update_source
                                    
                                    	Source of routing updates
                                    	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource>`
                                    
                                    .. attribute:: version
                                    
                                    	Set the BGP version to match a neighbor
                                    	**type**\: int
                                    
                                    	**range:** 4..None
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.DistributeList)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FallOver)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FilterList)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PeerGroup)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Timers)), ("translate-update", ("translate_update", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                            ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.remote_as = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.cluster_id = None
                                        self.description = None
                                        self.disable_connected_check = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.shutdown = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.version = None
                                        self.weight = None

                                        self.advertise_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AdvertiseMap()
                                        self.advertise_map.parent = self
                                        self._children_name_map["advertise_map"] = "advertise-map"

                                        self.aigp = None
                                        self._children_name_map["aigp"] = "aigp"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.announce = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Announce()
                                        self.announce.parent = self
                                        self._children_name_map["announce"] = "announce"

                                        self.as_override = None
                                        self._children_name_map["as_override"] = "as-override"

                                        self.capability = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.default_originate = None
                                        self._children_name_map["default_originate"] = "default-originate"

                                        self.ebgp_multihop = None
                                        self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                        self.fall_over = None
                                        self._children_name_map["fall_over"] = "fall-over"

                                        self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode()
                                        self.ha_mode.parent = self
                                        self._children_name_map["ha_mode"] = "ha-mode"

                                        self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.local_as = None
                                        self._children_name_map["local_as"] = "local-as"

                                        self.log_neighbor_changes = None
                                        self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"

                                        self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute()
                                        self.path_attribute.parent = self
                                        self._children_name_map["path_attribute"] = "path-attribute"

                                        self.peer_group = None
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.send_label = None
                                        self._children_name_map["send_label"] = "send-label"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Timers()
                                        self.timers.parent = self
                                        self._children_name_map["timers"] = "timers"

                                        self.translate_update = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate()
                                        self.translate_update.parent = self
                                        self._children_name_map["translate_update"] = "translate-update"

                                        self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Transport()
                                        self.transport.parent = self
                                        self._children_name_map["transport"] = "transport"

                                        self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TtlSecurity()
                                        self.ttl_security.parent = self
                                        self._children_name_map["ttl_security"] = "ttl-security"

                                        self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource()
                                        self.update_source.parent = self
                                        self._children_name_map["update_source"] = "update-source"

                                        self.distribute_list = YList(self)
                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor, ['id', 'remote_as', 'activate', 'advertisement_interval', 'allow_policy', 'cluster_id', 'description', 'disable_connected_check', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'version', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AdvertiseMap(Entity):
                                        """
                                        specify route\-map for conditional advertisement
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AdvertiseMap.Name>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AdvertiseMap, self).__init__()

                                            self.yang_name = "advertise-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AdvertiseMap.Name))])
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "advertise-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AdvertiseMap, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: word  (key)
                                            
                                            	advertise route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: non_exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AdvertiseMap.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "advertise-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                    ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                    ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                ])
                                                self.word = None
                                                self.exist_map = None
                                                self.non_exist_map = None
                                                self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                    class Aigp(Entity):
                                        """
                                        Enable a AIGP on neighbor
                                        
                                        .. attribute:: send
                                        
                                        	Cost community or MED carrying AIGP VALUE
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp, self).__init__()

                                            self.yang_name = "aigp"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.send = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send()
                                            self.send.parent = self
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "aigp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp, [], name, value)


                                        class Send(Entity):
                                            """
                                            Cost community or MED carrying AIGP VALUE
                                            
                                            .. attribute:: cost_community
                                            
                                            	Cost extended community carrying AIGP Value
                                            	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity>`
                                            
                                            .. attribute:: med
                                            
                                            	Med carrying AIGP Value
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "aigp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                ])
                                                self.med = None

                                                self.cost_community = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity()
                                                self.cost_community.parent = self
                                                self._children_name_map["cost_community"] = "cost-community"
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send, ['med'], name, value)


                                            class CostCommunity(Entity):
                                                """
                                                Cost extended community carrying AIGP Value
                                                
                                                .. attribute:: cc_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                    self.yang_name = "cost-community"
                                                    self.yang_parent_name = "send"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                    self._leafs = OrderedDict()

                                                    self.cc_range = YList(self)
                                                    self._segment_path = lambda: "cost-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                class CcRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Community ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: poi
                                                    
                                                    	Point of insertion
                                                    	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                        self.yang_name = "cc-range"
                                                        self.yang_parent_name = "cost-community"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ])
                                                        self.range = None

                                                        self.poi = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                        self.poi.parent = self
                                                        self._children_name_map["poi"] = "poi"
                                                        self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                    class Poi(Entity):
                                                        """
                                                        Point of insertion
                                                        
                                                        .. attribute:: igp_cost
                                                        
                                                        	Point of insertion after IGP
                                                        	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        .. attribute:: pre_bestpath
                                                        
                                                        	Point of insertion at beginning
                                                        	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                            self.yang_name = "poi"
                                                            self.yang_parent_name = "cc-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                            self._leafs = OrderedDict()

                                                            self.igp_cost = None
                                                            self._children_name_map["igp_cost"] = "igp-cost"

                                                            self.pre_bestpath = None
                                                            self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                            self._segment_path = lambda: "poi"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                        class IgpCost(Entity):
                                                            """
                                                            Point of insertion after IGP
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                self.yang_name = "igp-cost"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "igp-cost"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                        class PreBestpath(Entity):
                                                            """
                                                            Point of insertion at beginning
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                self.yang_name = "pre-bestpath"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "pre-bestpath"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Announce(Entity):
                                        """
                                        Announce RPKI state using an extended community
                                        
                                        .. attribute:: rpki
                                        
                                        	Announce RPKI information using an extended community
                                        	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Announce.Rpki>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Announce, self).__init__()

                                            self.yang_name = "announce"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Announce.Rpki))])
                                            self._leafs = OrderedDict()

                                            self.rpki = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Announce.Rpki()
                                            self.rpki.parent = self
                                            self._children_name_map["rpki"] = "rpki"
                                            self._segment_path = lambda: "announce"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Announce, [], name, value)


                                        class Rpki(Entity):
                                            """
                                            Announce RPKI information using an extended community
                                            
                                            .. attribute:: state
                                            
                                            	Announce RPKI state information using an extended community
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Announce.Rpki, self).__init__()

                                                self.yang_name = "rpki"
                                                self.yang_parent_name = "announce"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                ])
                                                self.state = None
                                                self._segment_path = lambda: "rpki"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Announce.Rpki, ['state'], name, value)


                                    class AsOverride(Entity):
                                        """
                                        Override matching AS\-number while sending update
                                        
                                        .. attribute:: disable
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AsOverride, self).__init__()

                                            self.yang_name = "as-override"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "as-override"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.AsOverride, ['disable'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DefaultOriginate(Entity):
                                        """
                                        Originate default route to this neighbor
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria to originate default
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.DefaultOriginate, self).__init__()

                                            self.yang_name = "default-originate"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "default-originate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.DistributeList.Inout>`
                                        
                                        .. attribute:: accesslist
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.DistributeList.Inout')])),
                                                ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                            ])
                                            self.inout = None
                                            self.accesslist = None
                                            self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class EbgpMultihop(Entity):
                                        """
                                        Allow EBGP neighbors not on directly connected networks
                                        
                                        .. attribute:: max_hop
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.EbgpMultihop, self).__init__()

                                            self.yang_name = "ebgp-multihop"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                            ])
                                            self.max_hop = None
                                            self._segment_path = lambda: "ebgp-multihop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                    class FallOver(Entity):
                                        """
                                        session fall on peer route lost
                                        
                                        .. attribute:: bfd
                                        
                                        	Use BFD to detect failure
                                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FallOver.Bfd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FallOver, self).__init__()

                                            self.yang_name = "fall-over"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FallOver.Bfd))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.route_map_name = None

                                            self.bfd = None
                                            self._children_name_map["bfd"] = "bfd"
                                            self._segment_path = lambda: "fall-over"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FallOver, ['route_map_name'], name, value)


                                        class Bfd(Entity):
                                            """
                                            Use BFD to detect failure
                                            
                                            .. attribute:: multi_hop
                                            
                                            	Force BFD multi\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: single_hop
                                            
                                            	Force BFD single\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: check_control_plane_failure
                                            
                                            	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: strict_mode
                                            
                                            	Enable BFD strict\-mode
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FallOver.Bfd, self).__init__()

                                                self.yang_name = "bfd"
                                                self.yang_parent_name = "fall-over"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                    ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                    ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                    ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                ])
                                                self.multi_hop = None
                                                self.single_hop = None
                                                self.check_control_plane_failure = None
                                                self.strict_mode = None
                                                self._segment_path = lambda: "bfd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class HaMode(Entity):
                                        """
                                        high availability mode
                                        
                                        .. attribute:: graceful_restart
                                        
                                        	graceful\-restart for this peer
                                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode.GracefulRestart>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: sso
                                        
                                        	stateful\-switchover support for this peer
                                        	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode.Sso>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode, self).__init__()

                                            self.yang_name = "ha-mode"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode.Sso))])
                                            self._leafs = OrderedDict()

                                            self.graceful_restart = None
                                            self._children_name_map["graceful_restart"] = "graceful-restart"

                                            self.sso = None
                                            self._children_name_map["sso"] = "sso"
                                            self._segment_path = lambda: "ha-mode"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode, [], name, value)


                                        class GracefulRestart(Entity):
                                            """
                                            graceful\-restart for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable graceful\-restart
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                self.yang_name = "graceful-restart"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "graceful-restart"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                        class Sso(Entity):
                                            """
                                            stateful\-switchover support for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable stateful\-switchover
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode.Sso, self).__init__()

                                                self.yang_name = "sso"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "sso"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.HaMode.Sso, ['disable'], name, value)


                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class LocalAs(Entity):
                                        """
                                        Specify a local\-as number
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: no_prepend
                                        
                                        	Do not prepend local\-as to updates from ebgp peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace real AS with local AS in the EBGP updates
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: dual_as
                                        
                                        	Accept either real AS or local AS from the ebgp peer
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.LocalAs, self).__init__()

                                            self.yang_name = "local-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                            ])
                                            self.as_no = None
                                            self.no_prepend = None
                                            self.replace_as = None
                                            self.dual_as = None
                                            self._segment_path = lambda: "local-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                    class LogNeighborChanges(Entity):
                                        """
                                        Log neighbor up/down and reset reason
                                        
                                        .. attribute:: disable
                                        
                                        	disable
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.LogNeighborChanges, self).__init__()

                                            self.yang_name = "log-neighbor-changes"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "log-neighbor-changes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                    class Password(Entity):
                                        """
                                        Set a password
                                        
                                        .. attribute:: enctype
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: text
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                            ])
                                            self.enctype = None
                                            self.text = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Password, ['enctype', 'text'], name, value)


                                    class PathAttribute(Entity):
                                        """
                                        BGP optional attribute filtering
                                        
                                        .. attribute:: discard
                                        
                                        	Discard matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard>`
                                        
                                        .. attribute:: treat_as_withdraw
                                        
                                        	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute, self).__init__()

                                            self.yang_name = "path-attribute"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw))])
                                            self._leafs = OrderedDict()

                                            self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard()
                                            self.discard.parent = self
                                            self._children_name_map["discard"] = "discard"

                                            self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw()
                                            self.treat_as_withdraw.parent = self
                                            self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                            self._segment_path = lambda: "path-attribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute, [], name, value)


                                        class Discard(Entity):
                                            """
                                            Discard matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard, self).__init__()

                                                self.yang_name = "discard"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "discard"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class TreatAsWithdraw(Entity):
                                            """
                                            Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                self.yang_name = "treat-as-withdraw"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "treat-as-withdraw"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        Member of the peer\-group
                                        
                                        .. attribute:: peer_group_name
                                        
                                        	peer\-group name
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                            ])
                                            self.peer_group_name = None
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SendLabel(Entity):
                                        """
                                        Send NLRI + MPLS Label to this peer
                                        
                                        .. attribute:: send_label_explicit
                                        
                                        	
                                        	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendLabel.SendLabelExplicit>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendLabel, self).__init__()

                                            self.yang_name = "send-label"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendLabel.SendLabelExplicit')])),
                                            ])
                                            self.send_label_explicit = None
                                            self._segment_path = lambda: "send-label"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                        class SendLabelExplicit(Enum):
                                            """
                                            SendLabelExplicit (Enum Class)

                                            .. data:: explicit_null = 0

                                            """

                                            explicit_null = Enum.YLeaf(0, "explicit-null")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Timers(Entity):
                                        """
                                        BGP per neighbor timers
                                        
                                        .. attribute:: keepalive_interval
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: holdtime
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: minimum_neighbor_hold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Timers, self).__init__()

                                            self.yang_name = "timers"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                            ])
                                            self.keepalive_interval = None
                                            self.holdtime = None
                                            self.minimum_neighbor_hold = None
                                            self._segment_path = lambda: "timers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                    class TranslateUpdate(Entity):
                                        """
                                        Translate update to MBGP format
                                        
                                        .. attribute:: ipv4
                                        
                                        	Address Family
                                        	**type**\:  :py:class:`Ipv4_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate, self).__init__()

                                            self.yang_name = "translate-update"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_))])
                                            self._leafs = OrderedDict()

                                            self.ipv4 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_()
                                            self.ipv4.parent = self
                                            self._children_name_map["ipv4"] = "ipv4"
                                            self._segment_path = lambda: "translate-update"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate, [], name, value)


                                        class Ipv4_(Entity):
                                            """
                                            Address Family
                                            
                                            .. attribute:: multicast
                                            
                                            	Address Family modifier
                                            	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_, self).__init__()

                                                self.yang_name = "ipv4"
                                                self.yang_parent_name = "translate-update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast))])
                                                self._leafs = OrderedDict()

                                                self.multicast = None
                                                self._children_name_map["multicast"] = "multicast"
                                                self._segment_path = lambda: "ipv4"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_, [], name, value)


                                            class Multicast(Entity):
                                                """
                                                Address Family modifier
                                                
                                                .. attribute:: unicast
                                                
                                                	Address Family modifier
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast, self).__init__()

                                                    self.yang_name = "multicast"
                                                    self.yang_parent_name = "ipv4"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                    ])
                                                    self.unicast = None
                                                    self._segment_path = lambda: "multicast"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast, ['unicast'], name, value)


                                    class Transport(Entity):
                                        """
                                        Transport options
                                        
                                        .. attribute:: connection_mode
                                        
                                        	Specify passive or active connection
                                        	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Transport.ConnectionMode>`
                                        
                                        .. attribute:: multi_session
                                        
                                        	Use multi\-session for transport
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: path_mtu_discovery
                                        
                                        	Use transport path MTU discovery
                                        	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Transport.PathMtuDiscovery>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Transport, self).__init__()

                                            self.yang_name = "transport"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Transport.PathMtuDiscovery))])
                                            self._leafs = OrderedDict([
                                                ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Transport.ConnectionMode')])),
                                                ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                            ])
                                            self.connection_mode = None
                                            self.multi_session = None

                                            self.path_mtu_discovery = None
                                            self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                            self._segment_path = lambda: "transport"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                        class ConnectionMode(Enum):
                                            """
                                            ConnectionMode (Enum Class)

                                            Specify passive or active connection

                                            .. data:: active = 0

                                            .. data:: passive = 1

                                            """

                                            active = Enum.YLeaf(0, "active")

                                            passive = Enum.YLeaf(1, "passive")



                                        class PathMtuDiscovery(Entity):
                                            """
                                            Use transport path MTU discovery
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                self.yang_name = "path-mtu-discovery"
                                                self.yang_parent_name = "transport"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "path-mtu-discovery"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                    class TtlSecurity(Entity):
                                        """
                                        BGP ttl security check
                                        
                                        .. attribute:: hops
                                        
                                        	IP hops
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TtlSecurity, self).__init__()

                                            self.yang_name = "ttl-security"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                            ])
                                            self.hops = None
                                            self._segment_path = lambda: "ttl-security"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.TtlSecurity, ['hops'], name, value)


                                    class UpdateSource(Entity):
                                        """
                                        Source of routing updates
                                        
                                        .. attribute:: appnav_compress
                                        
                                        	Service\-Context Virtual Interface Compress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: appnav_uncompress
                                        
                                        	Service\-Context Virtual Interface UnCompress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm
                                        
                                        	ATM interface
                                        	**type**\: str
                                        
                                        .. attribute:: atm_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.ATMSubinterface>`
                                        
                                        .. attribute:: atm_acr
                                        
                                        	ATM\-ACR interface
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9]
                                        
                                        .. attribute:: atm_acrsubinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.ATMACRsubinterface>`
                                        
                                        .. attribute:: bdi
                                        
                                        	Bridge\-Domain interface
                                        	**type**\: str
                                        
                                        .. attribute:: cem
                                        
                                        	CEM interface
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9]/){2}[0\-9]
                                        
                                        .. attribute:: cem_acr
                                        
                                        	CEM\-ACR interface
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: embedded_service_engine
                                        
                                        	cisco embedded service engine module
                                        	**type**\: str
                                        
                                        .. attribute:: ethernet
                                        
                                        	IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: fastethernet
                                        
                                        	FastEthernet IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: gigabitethernet
                                        
                                        	GigabitEthernet IEEE 802.3z
                                        	**type**\: str
                                        
                                        .. attribute:: fivegigabitethernet
                                        
                                        	Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twentyfivegige
                                        
                                        	Twenty Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twogigabitethernet
                                        
                                        	Two GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: fortygigabitethernet
                                        
                                        	Forty GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: hundredgige
                                        
                                        	Hundred GigabitEthernet
                                        	**type**\: str
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_subinterface
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.LISPSubinterface>`
                                        
                                        .. attribute:: loopback
                                        
                                        	Loopback interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multilink
                                        
                                        	Multilink\-group interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: nve
                                        
                                        	Network virtualization endpoint interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: overlay
                                        
                                        	Overlay interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: port_channel
                                        
                                        	Ethernet Channel of interfaces
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: port_channel_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.PortChannelSubinterface>`
                                        
                                        .. attribute:: pseudowire
                                        
                                        	Pseudowire Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sm
                                        
                                        	SM Interface
                                        	**type**\: str
                                        
                                        .. attribute:: cellular
                                        
                                        	Cellular Interface
                                        	**type**\: str
                                        
                                        .. attribute:: serial
                                        
                                        	Serial interface
                                        	**type**\: str
                                        
                                        .. attribute:: tengigabitethernet
                                        
                                        	Ten Gigabit Ethernet
                                        	**type**\: str
                                        
                                        .. attribute:: tunnel
                                        
                                        	Tunnel interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_template
                                        
                                        	Virtual Template interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vlan
                                        
                                        	Iosxr Vlans
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: virtualportgroup
                                        
                                        	Virtual Port Group
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasileft
                                        
                                        	vasileft
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasiright
                                        
                                        	vasiright
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource, self).__init__()

                                            self.yang_name = "update-source"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.PortChannelSubinterface))])
                                            self._leafs = OrderedDict([
                                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                            ])
                                            self.appnav_compress = None
                                            self.appnav_uncompress = None
                                            self.atm = None
                                            self.atm_acr = None
                                            self.bdi = None
                                            self.cem = None
                                            self.cem_acr = None
                                            self.embedded_service_engine = None
                                            self.ethernet = None
                                            self.fastethernet = None
                                            self.gigabitethernet = None
                                            self.fivegigabitethernet = None
                                            self.twentyfivegige = None
                                            self.twogigabitethernet = None
                                            self.fortygigabitethernet = None
                                            self.hundredgige = None
                                            self.lisp = None
                                            self.loopback = None
                                            self.multilink = None
                                            self.nve = None
                                            self.overlay = None
                                            self.port_channel = None
                                            self.pseudowire = None
                                            self.sm = None
                                            self.cellular = None
                                            self.serial = None
                                            self.tengigabitethernet = None
                                            self.tunnel = None
                                            self.virtual_template = None
                                            self.vlan = None
                                            self.virtualportgroup = None
                                            self.vasileft = None
                                            self.vasiright = None

                                            self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.ATMSubinterface()
                                            self.atm_subinterface.parent = self
                                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                            self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.ATMACRsubinterface()
                                            self.atm_acrsubinterface.parent = self
                                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                            self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.LISPSubinterface()
                                            self.lisp_subinterface.parent = self
                                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                            self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.PortChannelSubinterface()
                                            self.port_channel_subinterface.parent = self
                                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                            self._segment_path = lambda: "update-source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                        class ATMSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                self.yang_name = "ATM-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ])
                                                self.atm = None
                                                self._segment_path = lambda: "ATM-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                        class ATMACRsubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm_acr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                self.yang_name = "ATM-ACRsubinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ])
                                                self.atm_acr = None
                                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                        class LISPSubinterface(Entity):
                                            """
                                            Locator/ID Separation Protocol Virtual Interface
                                            
                                            .. attribute:: lisp
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                self.yang_name = "LISP-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ])
                                                self.lisp = None
                                                self._segment_path = lambda: "LISP-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                        class PortChannelSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: port_channel
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                self.yang_name = "Port-channel-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                ])
                                                self.port_channel = None
                                                self._segment_path = lambda: "Port-channel-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Network(Entity):
                                    """
                                    
                                    
                                    .. attribute:: with_mask
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network.WithMask>`
                                    
                                    .. attribute:: no_mask
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network.NoMask>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network.NoMask))])
                                        self._leafs = OrderedDict()

                                        self.with_mask = YList(self)
                                        self.no_mask = YList(self)
                                        self._segment_path = lambda: "network"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network, [], name, value)


                                    class WithMask(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: number  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: mask  (key)
                                        
                                        	Network mask
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to modify the attributes
                                        	**type**\: str
                                        
                                        .. attribute:: backdoor
                                        
                                        	Specify a BGP backdoor route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: evpn
                                        
                                        	Advertise or export to EVPN address\-family
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network.WithMask, self).__init__()

                                            self.yang_name = "with-mask"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['number','mask']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.mask = None
                                            self.route_map = None
                                            self.backdoor = None
                                            self.evpn = None
                                            self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor', 'evpn'], name, value)


                                    class NoMask(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: number  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to modify the attributes
                                        	**type**\: str
                                        
                                        .. attribute:: backdoor
                                        
                                        	Specify a BGP backdoor route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: evpn
                                        
                                        	Advertise or export to EVPN address\-family
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network.NoMask, self).__init__()

                                            self.yang_name = "no-mask"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['number']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.route_map = None
                                            self.backdoor = None
                                            self.evpn = None
                                            self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Network.NoMask, ['number', 'route_map', 'backdoor', 'evpn'], name, value)


                                class Redistribute(Entity):
                                    """
                                    Redistribute information from another routing protocol
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Application>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Bgp_>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: dvmrp
                                    
                                    	Redistribution of DVMRP into BGP IPv4 Multicast
                                    	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Dvmrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator/ID Separation Protocol
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Lisp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Rip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute, self).__init__()

                                        self.yang_name = "redistribute"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static))])
                                        self._leafs = OrderedDict()

                                        self.application = None
                                        self._children_name_map["application"] = "application"

                                        self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.dvmrp = None
                                        self._children_name_map["dvmrp"] = "dvmrp"

                                        self.eigrp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Eigrp()
                                        self.eigrp.parent = self
                                        self._children_name_map["eigrp"] = "eigrp"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.lisp = None
                                        self._children_name_map["lisp"] = "lisp"

                                        self.iso_igrp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp()
                                        self.iso_igrp.parent = self
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.rip = None
                                        self._children_name_map["rip"] = "rip"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "redistribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Application.Name>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Application.Name))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Application, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	WORD \:\: Route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Application.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                    class Bgp_(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.as_no = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                    class Dvmrp(Entity):
                                        """
                                        Redistribution of DVMRP into BGP IPv4 Multicast
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Dvmrp, self).__init__()

                                            self.yang_name = "dvmrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "dvmrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.as_no = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "eigrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.IsisArea>`
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.Default>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.Default))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.default = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis, [], name, value)


                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: routes
                                            
                                            	
                                            	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.IsisArea.Routes>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                    ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                    ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.IsisArea.Routes')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.ip = None
                                                self.clns = None
                                                self.routes = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                            class Routes(Enum):
                                                """
                                                Routes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class Default(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: routes
                                            
                                            	
                                            	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.Default.Routes>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                    ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                    ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.Default.Routes')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.ip = None
                                                self.clns = None
                                                self.routes = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                            class Routes(Enum):
                                                """
                                                Routes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class Lisp(Entity):
                                        """
                                        Locator/ID Separation Protocol
                                        
                                        .. attribute:: include_connected
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.include_connected = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: iso_igrp_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp.Default>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp.Default))])
                                            self._leafs = OrderedDict()

                                            self.default = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.iso_igrp_area = YList(self)
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp, [], name, value)


                                        class IsoIgrpArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                                self.yang_name = "iso-igrp-area"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.name = None
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                        class Default(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.Vrf_>`
                                        
                                        .. attribute:: non_vrf
                                        
                                        	
                                        	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.NonVrf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.Vrf_)), ("non-vrf", ("non_vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.NonVrf))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.non_vrf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.NonVrf()
                                            self.non_vrf.parent = self
                                            self._children_name_map["non_vrf"] = "non-vrf"

                                            self.vrf = YList(self)
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf, ['id'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VPN Routing/Forwarding Instance
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.Vrf_.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.Vrf_.Match))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.Vrf_.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.Vrf_, ['name', 'metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.Vrf_.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True


                                        class NonVrf(Entity):
                                            """
                                            
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.NonVrf, self).__init__()

                                                self.yang_name = "non-vrf"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match))])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "non-vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                .. attribute:: internal
                                                
                                                	Redistribute OSPF internal routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: external
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: external2
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: nssa_external
                                                
                                                	Redistribute OSPF NSSA external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "non-vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                        ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.internal = None
                                                    self.external = None
                                                    self.external2 = None
                                                    self.nssa_external = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospfv3.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospfv3.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospfv3.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: external2
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospfv3.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                    ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.internal = None
                                                self.external = None
                                                self.external2 = None
                                                self.nssa_external = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: name
                                        
                                        	User selected string identifying this process
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self.name = None
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static.Clns>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ip
                                        
                                        	
                                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static.Ip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static.Ip))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None

                                            self.clns = None
                                            self._children_name_map["clns"] = "clns"

                                            self.ip = None
                                            self._children_name_map["ip"] = "ip"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                        class Clns(Entity):
                                            """
                                            Redistribution of OSI dynamic routes
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static.Clns, self).__init__()

                                                self.yang_name = "clns"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "clns"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                        class Ip(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static.Ip, self).__init__()

                                                self.yang_name = "ip"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                                class Snmp(Entity):
                                    """
                                    Modify snmp parameters
                                    
                                    .. attribute:: context
                                    
                                    	Configure a SNMP context
                                    	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp.Context>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp, self).__init__()

                                        self.yang_name = "snmp"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp.Context))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.context = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp.Context()
                                        self.context.parent = self
                                        self._children_name_map["context"] = "context"
                                        self._segment_path = lambda: "snmp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp, [], name, value)


                                    class Context(Entity):
                                        """
                                        Configure a SNMP context
                                        
                                        .. attribute:: context_word
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp.Context.ContextWord>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp.Context, self).__init__()

                                            self.yang_name = "context"
                                            self.yang_parent_name = "snmp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp.Context.ContextWord))])
                                            self._leafs = OrderedDict()

                                            self.context_word = YList(self)
                                            self._segment_path = lambda: "context"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp.Context, [], name, value)


                                        class ContextWord(Entity):
                                            """
                                            
                                            
                                            .. attribute:: context_word  (key)
                                            
                                            	Context Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp.Context.ContextWord, self).__init__()

                                                self.yang_name = "context_word"
                                                self.yang_parent_name = "context"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['context_word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                ])
                                                self.context_word = None
                                                self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                                class TableMap(Entity):
                                    """
                                    Map external entry attributes into routing table
                                    
                                    .. attribute:: name
                                    
                                    	WORD \:\: Route\-map name
                                    	**type**\: str
                                    
                                    .. attribute:: filter
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.TableMap, self).__init__()

                                        self.yang_name = "table-map"
                                        self.yang_parent_name = "ipv4-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                                        ])
                                        self.name = None
                                        self.filter = None
                                        self._segment_path = lambda: "table-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Unicast.TableMap, ['name', 'filter'], name, value)


                            class Ipv4Multicast(Entity):
                                """
                                IPv4 Multicast VRF address family
                                
                                .. attribute:: aggregate_address
                                
                                	Configure BGP aggregate entries
                                	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.AggregateAddress>`
                                
                                .. attribute:: bgp
                                
                                	
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_>`
                                
                                .. attribute:: default_information
                                
                                	Control distribution of default information
                                	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.DefaultInformation>`
                                
                                .. attribute:: default_metric
                                
                                	Set metric of redistributed routes
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: distance
                                
                                	Define an administrative distance
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance>`
                                
                                .. attribute:: import_
                                
                                	Configure path import
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import>`
                                
                                .. attribute:: peer_group
                                
                                	
                                	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup>`
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor>`
                                
                                .. attribute:: network
                                
                                	
                                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network>`
                                
                                .. attribute:: redistribute
                                
                                	Redistribute information from another routing protocol
                                	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute>`
                                
                                .. attribute:: snmp
                                
                                	Modify snmp parameters
                                	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: table_map
                                
                                	Map external entry attributes into routing table
                                	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.TableMap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast, self).__init__()

                                    self.yang_name = "ipv4-multicast"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance)), ("import", ("import_", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp)), ("table-map", ("table_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.TableMap))])
                                    self._leafs = OrderedDict([
                                        ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                    ])
                                    self.default_metric = None

                                    self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.default_information = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.DefaultInformation()
                                    self.default_information.parent = self
                                    self._children_name_map["default_information"] = "default-information"

                                    self.distance = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.import_ = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.peer_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup()
                                    self.peer_group.parent = self
                                    self._children_name_map["peer_group"] = "peer-group"

                                    self.network = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network()
                                    self.network.parent = self
                                    self._children_name_map["network"] = "network"

                                    self.redistribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute()
                                    self.redistribute.parent = self
                                    self._children_name_map["redistribute"] = "redistribute"

                                    self.snmp = None
                                    self._children_name_map["snmp"] = "snmp"

                                    self.table_map = None
                                    self._children_name_map["table_map"] = "table-map"

                                    self.aggregate_address = YList(self)
                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "ipv4-multicast"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast, ['default_metric'], name, value)


                                class AggregateAddress(Entity):
                                    """
                                    Configure BGP aggregate entries
                                    
                                    .. attribute:: ipv4_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mask  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: advertise_map
                                    
                                    	Set condition to advertise attribute
                                    	**type**\: str
                                    
                                    .. attribute:: as_set
                                    
                                    	Generate AS set path information
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attribute_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: as_override
                                    
                                    	Override matching AS\-number while sending update
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: summary_only
                                    
                                    	Filter more specific routes from updates
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: suppress_map
                                    
                                    	Conditionally filter more specific routes from updates
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.AggregateAddress, self).__init__()

                                        self.yang_name = "aggregate-address"
                                        self.yang_parent_name = "ipv4-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ipv4_address','ipv4_mask']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mask', (YLeaf(YType.str, 'ipv4-mask'), ['str'])),
                                            ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                            ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                            ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                            ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                            ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                        ])
                                        self.ipv4_address = None
                                        self.ipv4_mask = None
                                        self.advertise_map = None
                                        self.as_set = None
                                        self.attribute_map = None
                                        self.as_override = None
                                        self.route_map = None
                                        self.summary_only = None
                                        self.suppress_map = None
                                        self._segment_path = lambda: "aggregate-address" + "[ipv4-address='" + str(self.ipv4_address) + "']" + "[ipv4-mask='" + str(self.ipv4_mask) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.AggregateAddress, ['ipv4_address', 'ipv4_mask', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                                class Bgp_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: additional_paths
                                    
                                    	Additional paths in the BGP table
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths>`
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Configure aggregation timer
                                    	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AggregateTimer>`
                                    
                                    .. attribute:: dampening
                                    
                                    	Enable route\-flap dampening
                                    	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.Dampening>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: redistribute_internal
                                    
                                    	Allow redistribution of iBGP into IGPs (dangerous)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	bgp route\-map commands
                                    	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.RouteMap>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "ipv4-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AggregateTimer)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.Dampening)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                        ])
                                        self.redistribute_internal = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.aggregate_timer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AggregateTimer()
                                        self.aggregate_timer.parent = self
                                        self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                        self.dampening = None
                                        self._children_name_map["dampening"] = "dampening"

                                        self.route_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.RouteMap()
                                        self.route_map.parent = self
                                        self._children_name_map["route_map"] = "route-map"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_, ['redistribute_internal'], name, value)


                                    class AdditionalPaths(Entity):
                                        """
                                        Additional paths in the BGP table
                                        
                                        .. attribute:: install
                                        
                                        	Additional paths to install into RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: select
                                        
                                        	Selection criteria to pick the paths
                                        	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select>`
                                        
                                        .. attribute:: send
                                        
                                        	Send additional paths to neighbors
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Send>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Send))])
                                            self._leafs = OrderedDict([
                                                ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.install = None
                                            self.receive = None

                                            self.select = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select()
                                            self.select.parent = self
                                            self._children_name_map["select"] = "select"

                                            self.send = None
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                        class Select(Entity):
                                            """
                                            Selection criteria to pick the paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: backup
                                            
                                            	Select backup path
                                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Backup>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Select best\-external path
                                            	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best path
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                self.yang_name = "select"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"

                                                self.backup = None
                                                self._children_name_map["backup"] = "backup"

                                                self.best = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.best_external = None
                                                self._children_name_map["best_external"] = "best-external"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "select"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                            class All(Entity):
                                                """
                                                Select all available paths
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.best = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.group_best = None
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                            class Backup(Entity):
                                                """
                                                Select backup path
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                    self.yang_name = "backup"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None
                                                    self._segment_path = lambda: "backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.all = None

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.all = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                            class BestExternal(Entity):
                                                """
                                                Select best\-external path
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                    self.yang_name = "best-external"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                    ])
                                                    self.backup = None
                                                    self._segment_path = lambda: "best-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best path
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.all = None
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                        class Send(Entity):
                                            """
                                            Send additional paths to neighbors
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.receive = None
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                    class AggregateTimer(Entity):
                                        """
                                        Configure aggregation timer
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Timer interval
                                        	**type**\: int
                                        
                                        	**range:** 6..60
                                        
                                        .. attribute:: disable_timer
                                        
                                        	Timer interval
                                        	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AggregateTimer.DisableTimer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AggregateTimer, self).__init__()

                                            self.yang_name = "aggregate-timer"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AggregateTimer.DisableTimer')])),
                                            ])
                                            self.aggregate_timer = None
                                            self.disable_timer = None
                                            self._segment_path = lambda: "aggregate-timer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                        class DisableTimer(Enum):
                                            """
                                            DisableTimer (Enum Class)

                                            Timer interval

                                            .. data:: Y_0 = 0

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")



                                    class Dampening(Entity):
                                        """
                                        Enable route\-flap dampening
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria for dampening
                                        	**type**\: str
                                        
                                        .. attribute:: dampen
                                        
                                        	
                                        	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.Dampening.Dampen>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.Dampening.Dampen))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.dampen = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.Dampening.Dampen()
                                            self.dampen.parent = self
                                            self._children_name_map["dampen"] = "dampen"
                                            self._segment_path = lambda: "dampening"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.Dampening, ['route_map'], name, value)


                                        class Dampen(Entity):
                                            """
                                            
                                            
                                            .. attribute:: half_life_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..45
                                            
                                            .. attribute:: reuse_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: max_suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.Dampening.Dampen, self).__init__()

                                                self.yang_name = "dampen"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                    ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                    ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                    ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                ])
                                                self.half_life_time = None
                                                self.reuse_time = None
                                                self.suppress_time = None
                                                self.max_suppress_time = None
                                                self._segment_path = lambda: "dampen"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        bgp route\-map commands
                                        
                                        .. attribute:: priority
                                        
                                        	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                            ])
                                            self.priority = None
                                            self._segment_path = lambda: "route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.RouteMap, ['priority'], name, value)


                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: disable
                                            
                                            	Disable slow\-peer detection
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.disable = None
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class DefaultInformation(Entity):
                                    """
                                    Control distribution of default information
                                    
                                    .. attribute:: originate
                                    
                                    	Distribute a default route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.DefaultInformation, self).__init__()

                                        self.yang_name = "default-information"
                                        self.yang_parent_name = "ipv4-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                        ])
                                        self.originate = None
                                        self._segment_path = lambda: "default-information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.DefaultInformation, ['originate'], name, value)


                                class Distance(Entity):
                                    """
                                    Define an administrative distance
                                    
                                    .. attribute:: bgp
                                    
                                    	BGP distance
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance.Bgp_>`
                                    
                                    .. attribute:: adm_distance
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance.AdmDistance>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv4-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance.AdmDistance))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.adm_distance = YList(self)
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        BGP distance
                                        
                                        .. attribute:: extern_as
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: internal_as
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: local
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "distance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                                ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                                ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                            ])
                                            self.extern_as = None
                                            self.internal_as = None
                                            self.local = None
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                    class AdmDistance(Entity):
                                        """
                                        
                                        
                                        .. attribute:: distance  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: srcip  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: wildbits  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: acl
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..99
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..1999
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance.AdmDistance, self).__init__()

                                            self.yang_name = "adm-distance"
                                            self.yang_parent_name = "distance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['distance','srcip','wildbits']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                                ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                                ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                                ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                            ])
                                            self.distance = None
                                            self.srcip = None
                                            self.wildbits = None
                                            self.acl = None
                                            self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                                class Import(Entity):
                                    """
                                    Configure path import
                                    
                                    .. attribute:: path
                                    
                                    	Path selection and path limit
                                    	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Path>`
                                    
                                    .. attribute:: vpnv4
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Vpnv4>`
                                    
                                    .. attribute:: vpnv6
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Vpnv6>`
                                    
                                    .. attribute:: l2vpn
                                    
                                    	Configure EVPN to VPN path import
                                    	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.L2vpn>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv4-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Path)), ("vpnv4", ("vpnv4", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Vpnv4)), ("vpnv6", ("vpnv6", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Vpnv6)), ("l2vpn", ("l2vpn", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.L2vpn))])
                                        self._leafs = OrderedDict()

                                        self.path = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Path()
                                        self.path.parent = self
                                        self._children_name_map["path"] = "path"

                                        self.vpnv4 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Vpnv4()
                                        self.vpnv4.parent = self
                                        self._children_name_map["vpnv4"] = "vpnv4"

                                        self.vpnv6 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Vpnv6()
                                        self.vpnv6.parent = self
                                        self._children_name_map["vpnv6"] = "vpnv6"

                                        self.l2vpn = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.L2vpn()
                                        self.l2vpn.parent = self
                                        self._children_name_map["l2vpn"] = "l2vpn"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import, [], name, value)


                                    class Path(Entity):
                                        """
                                        Path selection and path limit
                                        
                                        .. attribute:: limit
                                        
                                        	Per net imported path limit
                                        	**type**\: int
                                        
                                        	**range:** 2..255
                                        
                                        .. attribute:: selection
                                        
                                        	Path selection policy
                                        	**type**\:  :py:class:`Selection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Path.Selection>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("selection", ("selection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Path.Selection))])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                                            ])
                                            self.limit = None

                                            self.selection = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Path.Selection()
                                            self.selection.parent = self
                                            self._children_name_map["selection"] = "selection"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Path, ['limit'], name, value)


                                        class Selection(Entity):
                                            """
                                            Path selection policy
                                            
                                            .. attribute:: all
                                            
                                            	Import all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Path.Selection, self).__init__()

                                                self.yang_name = "selection"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "selection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Path.Selection, ['all'], name, value)


                                    class Vpnv4(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Vpnv4, self).__init__()

                                            self.yang_name = "vpnv4"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv4"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Vpnv4, ['unicast', 're_originate'], name, value)


                                    class Vpnv6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	Imported path with RT re\-originate
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Vpnv6, self).__init__()

                                            self.yang_name = "vpnv6"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.Vpnv6, ['unicast', 're_originate'], name, value)


                                    class L2vpn(Entity):
                                        """
                                        Configure EVPN to VPN path import
                                        
                                        .. attribute:: evpn
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.L2vpn, self).__init__()

                                            self.yang_name = "l2vpn"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.evpn = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "l2vpn"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Import.L2vpn, ['evpn', 're_originate'], name, value)


                                class PeerGroup(Entity):
                                    """
                                    
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup, self).__init__()

                                        self.yang_name = "peer-group"
                                        self.yang_parent_name = "ipv4-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor))])
                                        self._leafs = OrderedDict()

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "peer-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: peer_group
                                        
                                        	Member of the peer\-group
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_map
                                        
                                        	specify route\-map for conditional advertisement
                                        	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable a AIGP on neighbor
                                        	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AsOverride>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability>`
                                        
                                        .. attribute:: cluster_id
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: description
                                        
                                        	Neighbor specific description
                                        	**type**\: str
                                        
                                        .. attribute:: disable_connected_check
                                        
                                        	one\-hop away EBGP peer using loopback address
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ebgp_multihop
                                        
                                        	Allow EBGP neighbors not on directly connected networks
                                        	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.EbgpMultihop>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: fall_over
                                        
                                        	session fall on peer route lost
                                        	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FallOver>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FilterList>`
                                        
                                        .. attribute:: ha_mode
                                        
                                        	high availability mode
                                        	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Inherit>`
                                        
                                        .. attribute:: local_as
                                        
                                        	Specify a local\-as number
                                        	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.LocalAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: log_neighbor_changes
                                        
                                        	Log neighbor up/down and reset reason
                                        	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.LogNeighborChanges>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: password
                                        
                                        	Set a password
                                        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Password>`
                                        
                                        .. attribute:: path_attribute
                                        
                                        	BGP optional attribute filtering
                                        	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remote_as
                                        
                                        	Specify a BGP peer\-group remote\-as
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: shutdown
                                        
                                        	Administratively shut down this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: timers
                                        
                                        	BGP per neighbor timers
                                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Timers>`
                                        
                                        .. attribute:: transport
                                        
                                        	Transport options
                                        	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Transport>`
                                        
                                        .. attribute:: ttl_security
                                        
                                        	BGP ttl security check
                                        	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.TtlSecurity>`
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: update_source
                                        
                                        	Source of routing updates
                                        	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource>`
                                        
                                        .. attribute:: version
                                        
                                        	Set the BGP version to match a neighbor
                                        	**type**\: int
                                        
                                        	**range:** 4..None
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "peer-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AllowasIn)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.DefaultOriginate)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FallOver)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FilterList)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Timers)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ('peer_group', (YLeaf(YType.empty, 'peer-group'), ['Empty'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.peer_group = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.cluster_id = None
                                            self.description = None
                                            self.disable_connected_check = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.remote_as = None
                                            self.route_reflector_client = None
                                            self.shutdown = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.version = None
                                            self.weight = None

                                            self.advertise_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap()
                                            self.advertise_map.parent = self
                                            self._children_name_map["advertise_map"] = "advertise-map"

                                            self.aigp = None
                                            self._children_name_map["aigp"] = "aigp"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.as_override = None
                                            self._children_name_map["as_override"] = "as-override"

                                            self.capability = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.ebgp_multihop = None
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                            self.fall_over = None
                                            self._children_name_map["fall_over"] = "fall-over"

                                            self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode()
                                            self.ha_mode.parent = self
                                            self._children_name_map["ha_mode"] = "ha-mode"

                                            self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.local_as = None
                                            self._children_name_map["local_as"] = "local-as"

                                            self.log_neighbor_changes = None
                                            self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                            self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"

                                            self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute()
                                            self.path_attribute.parent = self
                                            self._children_name_map["path_attribute"] = "path-attribute"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"

                                            self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Transport()
                                            self.transport.parent = self
                                            self._children_name_map["transport"] = "transport"

                                            self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.TtlSecurity()
                                            self.ttl_security.parent = self
                                            self._children_name_map["ttl_security"] = "ttl-security"

                                            self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource()
                                            self.update_source.parent = self
                                            self._children_name_map["update_source"] = "update-source"

                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor, ['id', 'peer_group', 'activate', 'advertisement_interval', 'allow_policy', 'cluster_id', 'description', 'disable_connected_check', 'dmzlink_bw', 'next_hop_unchanged', 'remote_as', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'version', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AdvertiseMap(Entity):
                                            """
                                            specify route\-map for conditional advertisement
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap.Name>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap, self).__init__()

                                                self.yang_name = "advertise-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap.Name))])
                                                self._leafs = OrderedDict()

                                                self.name = YList(self)
                                                self._segment_path = lambda: "advertise-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap, [], name, value)


                                            class Name(Entity):
                                                """
                                                
                                                
                                                .. attribute:: word  (key)
                                                
                                                	advertise route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: non_exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap.Name, self).__init__()

                                                    self.yang_name = "name"
                                                    self.yang_parent_name = "advertise-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                        ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                        ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                    ])
                                                    self.word = None
                                                    self.exist_map = None
                                                    self.non_exist_map = None
                                                    self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                        class Aigp(Entity):
                                            """
                                            Enable a AIGP on neighbor
                                            
                                            .. attribute:: send
                                            
                                            	Cost community or MED carrying AIGP VALUE
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                                self.yang_name = "aigp"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.send = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send()
                                                self.send.parent = self
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "aigp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                            class Send(Entity):
                                                """
                                                Cost community or MED carrying AIGP VALUE
                                                
                                                .. attribute:: cost_community
                                                
                                                	Cost extended community carrying AIGP Value
                                                	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                                
                                                .. attribute:: med
                                                
                                                	Med carrying AIGP Value
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "aigp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                    ])
                                                    self.med = None

                                                    self.cost_community = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                    self.cost_community.parent = self
                                                    self._children_name_map["cost_community"] = "cost-community"
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                                class CostCommunity(Entity):
                                                    """
                                                    Cost extended community carrying AIGP Value
                                                    
                                                    .. attribute:: cc_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                        self.yang_name = "cost-community"
                                                        self.yang_parent_name = "send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                        self._leafs = OrderedDict()

                                                        self.cc_range = YList(self)
                                                        self._segment_path = lambda: "cost-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                    class CcRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Community ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: poi
                                                        
                                                        	Point of insertion
                                                        	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                            self.yang_name = "cc-range"
                                                            self.yang_parent_name = "cost-community"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ])
                                                            self.range = None

                                                            self.poi = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                            self.poi.parent = self
                                                            self._children_name_map["poi"] = "poi"
                                                            self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                        class Poi(Entity):
                                                            """
                                                            Point of insertion
                                                            
                                                            .. attribute:: igp_cost
                                                            
                                                            	Point of insertion after IGP
                                                            	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            .. attribute:: pre_bestpath
                                                            
                                                            	Point of insertion at beginning
                                                            	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                self.yang_name = "poi"
                                                                self.yang_parent_name = "cc-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                self._leafs = OrderedDict()

                                                                self.igp_cost = None
                                                                self._children_name_map["igp_cost"] = "igp-cost"

                                                                self.pre_bestpath = None
                                                                self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                self._segment_path = lambda: "poi"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                            class IgpCost(Entity):
                                                                """
                                                                Point of insertion after IGP
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                    self.yang_name = "igp-cost"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "igp-cost"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                            class PreBestpath(Entity):
                                                                """
                                                                Point of insertion at beginning
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                    self.yang_name = "pre-bestpath"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "pre-bestpath"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class AsOverride(Entity):
                                            """
                                            Override matching AS\-number while sending update
                                            
                                            .. attribute:: disable
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AsOverride, self).__init__()

                                                self.yang_name = "as-override"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "as-override"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.AsOverride, ['disable'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class EbgpMultihop(Entity):
                                            """
                                            Allow EBGP neighbors not on directly connected networks
                                            
                                            .. attribute:: max_hop
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.EbgpMultihop, self).__init__()

                                                self.yang_name = "ebgp-multihop"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                                ])
                                                self.max_hop = None
                                                self._segment_path = lambda: "ebgp-multihop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                        class FallOver(Entity):
                                            """
                                            session fall on peer route lost
                                            
                                            .. attribute:: bfd
                                            
                                            	Use BFD to detect failure
                                            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FallOver.Bfd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FallOver, self).__init__()

                                                self.yang_name = "fall-over"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FallOver.Bfd))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.route_map_name = None

                                                self.bfd = None
                                                self._children_name_map["bfd"] = "bfd"
                                                self._segment_path = lambda: "fall-over"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FallOver, ['route_map_name'], name, value)


                                            class Bfd(Entity):
                                                """
                                                Use BFD to detect failure
                                                
                                                .. attribute:: multi_hop
                                                
                                                	Force BFD multi\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: single_hop
                                                
                                                	Force BFD single\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: check_control_plane_failure
                                                
                                                	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: strict_mode
                                                
                                                	Enable BFD strict\-mode
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FallOver.Bfd, self).__init__()

                                                    self.yang_name = "bfd"
                                                    self.yang_parent_name = "fall-over"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                        ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                        ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                        ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                    ])
                                                    self.multi_hop = None
                                                    self.single_hop = None
                                                    self.check_control_plane_failure = None
                                                    self.strict_mode = None
                                                    self._segment_path = lambda: "bfd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class HaMode(Entity):
                                            """
                                            high availability mode
                                            
                                            .. attribute:: graceful_restart
                                            
                                            	graceful\-restart for this peer
                                            	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode.GracefulRestart>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: sso
                                            
                                            	stateful\-switchover support for this peer
                                            	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode.Sso>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode, self).__init__()

                                                self.yang_name = "ha-mode"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode.Sso))])
                                                self._leafs = OrderedDict()

                                                self.graceful_restart = None
                                                self._children_name_map["graceful_restart"] = "graceful-restart"

                                                self.sso = None
                                                self._children_name_map["sso"] = "sso"
                                                self._segment_path = lambda: "ha-mode"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode, [], name, value)


                                            class GracefulRestart(Entity):
                                                """
                                                graceful\-restart for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable graceful\-restart
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                    self.yang_name = "graceful-restart"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "graceful-restart"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                            class Sso(Entity):
                                                """
                                                stateful\-switchover support for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable stateful\-switchover
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode.Sso, self).__init__()

                                                    self.yang_name = "sso"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "sso"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.HaMode.Sso, ['disable'], name, value)


                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class LocalAs(Entity):
                                            """
                                            Specify a local\-as number
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: no_prepend
                                            
                                            	Do not prepend local\-as to updates from ebgp peers
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace real AS with local AS in the EBGP updates
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: dual_as
                                            
                                            	Accept either real AS or local AS from the ebgp peer
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.LocalAs, self).__init__()

                                                self.yang_name = "local-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                    ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                                ])
                                                self.as_no = None
                                                self.no_prepend = None
                                                self.replace_as = None
                                                self.dual_as = None
                                                self._segment_path = lambda: "local-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                        class LogNeighborChanges(Entity):
                                            """
                                            Log neighbor up/down and reset reason
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.LogNeighborChanges, self).__init__()

                                                self.yang_name = "log-neighbor-changes"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "log-neighbor-changes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                        class Password(Entity):
                                            """
                                            Set a password
                                            
                                            .. attribute:: enctype
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: text
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Password, self).__init__()

                                                self.yang_name = "password"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                                ])
                                                self.enctype = None
                                                self.text = None
                                                self._segment_path = lambda: "password"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Password, ['enctype', 'text'], name, value)


                                        class PathAttribute(Entity):
                                            """
                                            BGP optional attribute filtering
                                            
                                            .. attribute:: discard
                                            
                                            	Discard matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard>`
                                            
                                            .. attribute:: treat_as_withdraw
                                            
                                            	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute, self).__init__()

                                                self.yang_name = "path-attribute"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw))])
                                                self._leafs = OrderedDict()

                                                self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard()
                                                self.discard.parent = self
                                                self._children_name_map["discard"] = "discard"

                                                self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw()
                                                self.treat_as_withdraw.parent = self
                                                self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                                self._segment_path = lambda: "path-attribute"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute, [], name, value)


                                            class Discard(Entity):
                                                """
                                                Discard matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard, self).__init__()

                                                    self.yang_name = "discard"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "discard"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                            class TreatAsWithdraw(Entity):
                                                """
                                                Treat\-as\-withdraw matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                    self.yang_name = "treat-as-withdraw"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "treat-as-withdraw"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class Timers(Entity):
                                            """
                                            BGP per neighbor timers
                                            
                                            .. attribute:: keepalive_interval
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: holdtime
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: minimum_neighbor_hold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Timers, self).__init__()

                                                self.yang_name = "timers"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                    ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                    ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                                ])
                                                self.keepalive_interval = None
                                                self.holdtime = None
                                                self.minimum_neighbor_hold = None
                                                self._segment_path = lambda: "timers"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                        class Transport(Entity):
                                            """
                                            Transport options
                                            
                                            .. attribute:: connection_mode
                                            
                                            	Specify passive or active connection
                                            	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Transport.ConnectionMode>`
                                            
                                            .. attribute:: multi_session
                                            
                                            	Use multi\-session for transport
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: path_mtu_discovery
                                            
                                            	Use transport path MTU discovery
                                            	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Transport, self).__init__()

                                                self.yang_name = "transport"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery))])
                                                self._leafs = OrderedDict([
                                                    ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Transport.ConnectionMode')])),
                                                    ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                                ])
                                                self.connection_mode = None
                                                self.multi_session = None

                                                self.path_mtu_discovery = None
                                                self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                                self._segment_path = lambda: "transport"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                            class ConnectionMode(Enum):
                                                """
                                                ConnectionMode (Enum Class)

                                                Specify passive or active connection

                                                .. data:: active = 0

                                                .. data:: passive = 1

                                                """

                                                active = Enum.YLeaf(0, "active")

                                                passive = Enum.YLeaf(1, "passive")



                                            class PathMtuDiscovery(Entity):
                                                """
                                                Use transport path MTU discovery
                                                
                                                .. attribute:: disable
                                                
                                                	disable
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                    self.yang_name = "path-mtu-discovery"
                                                    self.yang_parent_name = "transport"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "path-mtu-discovery"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                        class TtlSecurity(Entity):
                                            """
                                            BGP ttl security check
                                            
                                            .. attribute:: hops
                                            
                                            	IP hops
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.TtlSecurity, self).__init__()

                                                self.yang_name = "ttl-security"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                                ])
                                                self.hops = None
                                                self._segment_path = lambda: "ttl-security"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.TtlSecurity, ['hops'], name, value)


                                        class UpdateSource(Entity):
                                            """
                                            Source of routing updates
                                            
                                            .. attribute:: appnav_compress
                                            
                                            	Service\-Context Virtual Interface Compress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: appnav_uncompress
                                            
                                            	Service\-Context Virtual Interface UnCompress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm
                                            
                                            	ATM interface
                                            	**type**\: str
                                            
                                            .. attribute:: atm_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface>`
                                            
                                            .. attribute:: atm_acr
                                            
                                            	ATM\-ACR interface
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]
                                            
                                            .. attribute:: atm_acrsubinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface>`
                                            
                                            .. attribute:: bdi
                                            
                                            	Bridge\-Domain interface
                                            	**type**\: str
                                            
                                            .. attribute:: cem
                                            
                                            	CEM interface
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9]/){2}[0\-9]
                                            
                                            .. attribute:: cem_acr
                                            
                                            	CEM\-ACR interface
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: embedded_service_engine
                                            
                                            	cisco embedded service engine module
                                            	**type**\: str
                                            
                                            .. attribute:: ethernet
                                            
                                            	IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: fastethernet
                                            
                                            	FastEthernet IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: gigabitethernet
                                            
                                            	GigabitEthernet IEEE 802.3z
                                            	**type**\: str
                                            
                                            .. attribute:: fivegigabitethernet
                                            
                                            	Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twentyfivegige
                                            
                                            	Twenty Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twogigabitethernet
                                            
                                            	Two GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: fortygigabitethernet
                                            
                                            	Forty GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: hundredgige
                                            
                                            	Hundred GigabitEthernet
                                            	**type**\: str
                                            
                                            .. attribute:: lisp
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_subinterface
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface>`
                                            
                                            .. attribute:: loopback
                                            
                                            	Loopback interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multilink
                                            
                                            	Multilink\-group interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: nve
                                            
                                            	Network virtualization endpoint interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: overlay
                                            
                                            	Overlay interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: port_channel
                                            
                                            	Ethernet Channel of interfaces
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: port_channel_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface>`
                                            
                                            .. attribute:: pseudowire
                                            
                                            	Pseudowire Interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sm
                                            
                                            	SM Interface
                                            	**type**\: str
                                            
                                            .. attribute:: cellular
                                            
                                            	Cellular Interface
                                            	**type**\: str
                                            
                                            .. attribute:: serial
                                            
                                            	Serial interface
                                            	**type**\: str
                                            
                                            .. attribute:: tengigabitethernet
                                            
                                            	Ten Gigabit Ethernet
                                            	**type**\: str
                                            
                                            .. attribute:: tunnel
                                            
                                            	Tunnel interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_template
                                            
                                            	Virtual Template interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vlan
                                            
                                            	Iosxr Vlans
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: virtualportgroup
                                            
                                            	Virtual Port Group
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasileft
                                            
                                            	vasileft
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasiright
                                            
                                            	vasiright
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource, self).__init__()

                                                self.yang_name = "update-source"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface))])
                                                self._leafs = OrderedDict([
                                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                                ])
                                                self.appnav_compress = None
                                                self.appnav_uncompress = None
                                                self.atm = None
                                                self.atm_acr = None
                                                self.bdi = None
                                                self.cem = None
                                                self.cem_acr = None
                                                self.embedded_service_engine = None
                                                self.ethernet = None
                                                self.fastethernet = None
                                                self.gigabitethernet = None
                                                self.fivegigabitethernet = None
                                                self.twentyfivegige = None
                                                self.twogigabitethernet = None
                                                self.fortygigabitethernet = None
                                                self.hundredgige = None
                                                self.lisp = None
                                                self.loopback = None
                                                self.multilink = None
                                                self.nve = None
                                                self.overlay = None
                                                self.port_channel = None
                                                self.pseudowire = None
                                                self.sm = None
                                                self.cellular = None
                                                self.serial = None
                                                self.tengigabitethernet = None
                                                self.tunnel = None
                                                self.virtual_template = None
                                                self.vlan = None
                                                self.virtualportgroup = None
                                                self.vasileft = None
                                                self.vasiright = None

                                                self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface()
                                                self.atm_subinterface.parent = self
                                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                                self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface()
                                                self.atm_acrsubinterface.parent = self
                                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                                self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface()
                                                self.lisp_subinterface.parent = self
                                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                                self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface()
                                                self.port_channel_subinterface.parent = self
                                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                                self._segment_path = lambda: "update-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                            class ATMSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                    self.yang_name = "ATM-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ])
                                                    self.atm = None
                                                    self._segment_path = lambda: "ATM-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                            class ATMACRsubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm_acr
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                    self.yang_name = "ATM-ACRsubinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ])
                                                    self.atm_acr = None
                                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                            class LISPSubinterface(Entity):
                                                """
                                                Locator/ID Separation Protocol Virtual Interface
                                                
                                                .. attribute:: lisp
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                    self.yang_name = "LISP-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ])
                                                    self.lisp = None
                                                    self._segment_path = lambda: "LISP-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                            class PortChannelSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: port_channel
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                    self.yang_name = "Port-channel-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                    ])
                                                    self.port_channel = None
                                                    self._segment_path = lambda: "Port-channel-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_as
                                    
                                    	Specify a BGP peer\-group remote\-as
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertise_map
                                    
                                    	specify route\-map for conditional advertisement
                                    	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AdvertiseMap>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: aigp
                                    
                                    	Enable a AIGP on neighbor
                                    	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: as_override
                                    
                                    	Override matching AS\-number while sending update
                                    	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AsOverride>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability>`
                                    
                                    .. attribute:: cluster_id
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: default_originate
                                    
                                    	Originate default route to this neighbor
                                    	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.DefaultOriginate>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: description
                                    
                                    	Neighbor specific description
                                    	**type**\: str
                                    
                                    .. attribute:: disable_connected_check
                                    
                                    	one\-hop away EBGP peer using loopback address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ebgp_multihop
                                    
                                    	Allow EBGP neighbors not on directly connected networks
                                    	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.EbgpMultihop>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fall_over
                                    
                                    	session fall on peer route lost
                                    	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FallOver>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FilterList>`
                                    
                                    .. attribute:: ha_mode
                                    
                                    	high availability mode
                                    	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Inherit>`
                                    
                                    .. attribute:: local_as
                                    
                                    	Specify a local\-as number
                                    	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.LocalAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: log_neighbor_changes
                                    
                                    	Log neighbor up/down and reset reason
                                    	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.LogNeighborChanges>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: password
                                    
                                    	Set a password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Password>`
                                    
                                    .. attribute:: path_attribute
                                    
                                    	BGP optional attribute filtering
                                    	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	Member of the peer\-group
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PeerGroup>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: shutdown
                                    
                                    	Administratively shut down this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: timers
                                    
                                    	BGP per neighbor timers
                                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Timers>`
                                    
                                    .. attribute:: transport
                                    
                                    	Transport options
                                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Transport>`
                                    
                                    .. attribute:: ttl_security
                                    
                                    	BGP ttl security check
                                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.TtlSecurity>`
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: update_source
                                    
                                    	Source of routing updates
                                    	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource>`
                                    
                                    .. attribute:: version
                                    
                                    	Set the BGP version to match a neighbor
                                    	**type**\: int
                                    
                                    	**range:** 4..None
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "ipv4-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AllowasIn)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.DefaultOriginate)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FallOver)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FilterList)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PeerGroup)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Timers)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                            ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.remote_as = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.cluster_id = None
                                        self.description = None
                                        self.disable_connected_check = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.shutdown = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.version = None
                                        self.weight = None

                                        self.advertise_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AdvertiseMap()
                                        self.advertise_map.parent = self
                                        self._children_name_map["advertise_map"] = "advertise-map"

                                        self.aigp = None
                                        self._children_name_map["aigp"] = "aigp"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.as_override = None
                                        self._children_name_map["as_override"] = "as-override"

                                        self.capability = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.default_originate = None
                                        self._children_name_map["default_originate"] = "default-originate"

                                        self.ebgp_multihop = None
                                        self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                        self.fall_over = None
                                        self._children_name_map["fall_over"] = "fall-over"

                                        self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode()
                                        self.ha_mode.parent = self
                                        self._children_name_map["ha_mode"] = "ha-mode"

                                        self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.local_as = None
                                        self._children_name_map["local_as"] = "local-as"

                                        self.log_neighbor_changes = None
                                        self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"

                                        self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute()
                                        self.path_attribute.parent = self
                                        self._children_name_map["path_attribute"] = "path-attribute"

                                        self.peer_group = None
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Timers()
                                        self.timers.parent = self
                                        self._children_name_map["timers"] = "timers"

                                        self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Transport()
                                        self.transport.parent = self
                                        self._children_name_map["transport"] = "transport"

                                        self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.TtlSecurity()
                                        self.ttl_security.parent = self
                                        self._children_name_map["ttl_security"] = "ttl-security"

                                        self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource()
                                        self.update_source.parent = self
                                        self._children_name_map["update_source"] = "update-source"

                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor, ['id', 'remote_as', 'activate', 'advertisement_interval', 'allow_policy', 'cluster_id', 'description', 'disable_connected_check', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'version', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AdvertiseMap(Entity):
                                        """
                                        specify route\-map for conditional advertisement
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AdvertiseMap.Name>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AdvertiseMap, self).__init__()

                                            self.yang_name = "advertise-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AdvertiseMap.Name))])
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "advertise-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AdvertiseMap, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: word  (key)
                                            
                                            	advertise route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: non_exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AdvertiseMap.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "advertise-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                    ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                    ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                ])
                                                self.word = None
                                                self.exist_map = None
                                                self.non_exist_map = None
                                                self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                    class Aigp(Entity):
                                        """
                                        Enable a AIGP on neighbor
                                        
                                        .. attribute:: send
                                        
                                        	Cost community or MED carrying AIGP VALUE
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp, self).__init__()

                                            self.yang_name = "aigp"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.send = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send()
                                            self.send.parent = self
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "aigp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp, [], name, value)


                                        class Send(Entity):
                                            """
                                            Cost community or MED carrying AIGP VALUE
                                            
                                            .. attribute:: cost_community
                                            
                                            	Cost extended community carrying AIGP Value
                                            	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity>`
                                            
                                            .. attribute:: med
                                            
                                            	Med carrying AIGP Value
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "aigp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                ])
                                                self.med = None

                                                self.cost_community = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity()
                                                self.cost_community.parent = self
                                                self._children_name_map["cost_community"] = "cost-community"
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send, ['med'], name, value)


                                            class CostCommunity(Entity):
                                                """
                                                Cost extended community carrying AIGP Value
                                                
                                                .. attribute:: cc_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                    self.yang_name = "cost-community"
                                                    self.yang_parent_name = "send"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                    self._leafs = OrderedDict()

                                                    self.cc_range = YList(self)
                                                    self._segment_path = lambda: "cost-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                class CcRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Community ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: poi
                                                    
                                                    	Point of insertion
                                                    	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                        self.yang_name = "cc-range"
                                                        self.yang_parent_name = "cost-community"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ])
                                                        self.range = None

                                                        self.poi = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                        self.poi.parent = self
                                                        self._children_name_map["poi"] = "poi"
                                                        self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                    class Poi(Entity):
                                                        """
                                                        Point of insertion
                                                        
                                                        .. attribute:: igp_cost
                                                        
                                                        	Point of insertion after IGP
                                                        	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        .. attribute:: pre_bestpath
                                                        
                                                        	Point of insertion at beginning
                                                        	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                            self.yang_name = "poi"
                                                            self.yang_parent_name = "cc-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                            self._leafs = OrderedDict()

                                                            self.igp_cost = None
                                                            self._children_name_map["igp_cost"] = "igp-cost"

                                                            self.pre_bestpath = None
                                                            self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                            self._segment_path = lambda: "poi"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                        class IgpCost(Entity):
                                                            """
                                                            Point of insertion after IGP
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                self.yang_name = "igp-cost"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "igp-cost"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                        class PreBestpath(Entity):
                                                            """
                                                            Point of insertion at beginning
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                self.yang_name = "pre-bestpath"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "pre-bestpath"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class AsOverride(Entity):
                                        """
                                        Override matching AS\-number while sending update
                                        
                                        .. attribute:: disable
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AsOverride, self).__init__()

                                            self.yang_name = "as-override"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "as-override"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.AsOverride, ['disable'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DefaultOriginate(Entity):
                                        """
                                        Originate default route to this neighbor
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria to originate default
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.DefaultOriginate, self).__init__()

                                            self.yang_name = "default-originate"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "default-originate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                    class EbgpMultihop(Entity):
                                        """
                                        Allow EBGP neighbors not on directly connected networks
                                        
                                        .. attribute:: max_hop
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.EbgpMultihop, self).__init__()

                                            self.yang_name = "ebgp-multihop"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                            ])
                                            self.max_hop = None
                                            self._segment_path = lambda: "ebgp-multihop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                    class FallOver(Entity):
                                        """
                                        session fall on peer route lost
                                        
                                        .. attribute:: bfd
                                        
                                        	Use BFD to detect failure
                                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FallOver.Bfd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FallOver, self).__init__()

                                            self.yang_name = "fall-over"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FallOver.Bfd))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.route_map_name = None

                                            self.bfd = None
                                            self._children_name_map["bfd"] = "bfd"
                                            self._segment_path = lambda: "fall-over"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FallOver, ['route_map_name'], name, value)


                                        class Bfd(Entity):
                                            """
                                            Use BFD to detect failure
                                            
                                            .. attribute:: multi_hop
                                            
                                            	Force BFD multi\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: single_hop
                                            
                                            	Force BFD single\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: check_control_plane_failure
                                            
                                            	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: strict_mode
                                            
                                            	Enable BFD strict\-mode
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FallOver.Bfd, self).__init__()

                                                self.yang_name = "bfd"
                                                self.yang_parent_name = "fall-over"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                    ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                    ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                    ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                ])
                                                self.multi_hop = None
                                                self.single_hop = None
                                                self.check_control_plane_failure = None
                                                self.strict_mode = None
                                                self._segment_path = lambda: "bfd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class HaMode(Entity):
                                        """
                                        high availability mode
                                        
                                        .. attribute:: graceful_restart
                                        
                                        	graceful\-restart for this peer
                                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode.GracefulRestart>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: sso
                                        
                                        	stateful\-switchover support for this peer
                                        	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode.Sso>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode, self).__init__()

                                            self.yang_name = "ha-mode"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode.Sso))])
                                            self._leafs = OrderedDict()

                                            self.graceful_restart = None
                                            self._children_name_map["graceful_restart"] = "graceful-restart"

                                            self.sso = None
                                            self._children_name_map["sso"] = "sso"
                                            self._segment_path = lambda: "ha-mode"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode, [], name, value)


                                        class GracefulRestart(Entity):
                                            """
                                            graceful\-restart for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable graceful\-restart
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                self.yang_name = "graceful-restart"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "graceful-restart"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                        class Sso(Entity):
                                            """
                                            stateful\-switchover support for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable stateful\-switchover
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode.Sso, self).__init__()

                                                self.yang_name = "sso"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "sso"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.HaMode.Sso, ['disable'], name, value)


                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class LocalAs(Entity):
                                        """
                                        Specify a local\-as number
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: no_prepend
                                        
                                        	Do not prepend local\-as to updates from ebgp peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace real AS with local AS in the EBGP updates
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: dual_as
                                        
                                        	Accept either real AS or local AS from the ebgp peer
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.LocalAs, self).__init__()

                                            self.yang_name = "local-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                            ])
                                            self.as_no = None
                                            self.no_prepend = None
                                            self.replace_as = None
                                            self.dual_as = None
                                            self._segment_path = lambda: "local-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                    class LogNeighborChanges(Entity):
                                        """
                                        Log neighbor up/down and reset reason
                                        
                                        .. attribute:: disable
                                        
                                        	disable
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.LogNeighborChanges, self).__init__()

                                            self.yang_name = "log-neighbor-changes"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "log-neighbor-changes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.NextHopSelf, ['all'], name, value)


                                    class Password(Entity):
                                        """
                                        Set a password
                                        
                                        .. attribute:: enctype
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: text
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                            ])
                                            self.enctype = None
                                            self.text = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Password, ['enctype', 'text'], name, value)


                                    class PathAttribute(Entity):
                                        """
                                        BGP optional attribute filtering
                                        
                                        .. attribute:: discard
                                        
                                        	Discard matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard>`
                                        
                                        .. attribute:: treat_as_withdraw
                                        
                                        	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute, self).__init__()

                                            self.yang_name = "path-attribute"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw))])
                                            self._leafs = OrderedDict()

                                            self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard()
                                            self.discard.parent = self
                                            self._children_name_map["discard"] = "discard"

                                            self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw()
                                            self.treat_as_withdraw.parent = self
                                            self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                            self._segment_path = lambda: "path-attribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute, [], name, value)


                                        class Discard(Entity):
                                            """
                                            Discard matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard, self).__init__()

                                                self.yang_name = "discard"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "discard"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class TreatAsWithdraw(Entity):
                                            """
                                            Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                self.yang_name = "treat-as-withdraw"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "treat-as-withdraw"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        Member of the peer\-group
                                        
                                        .. attribute:: peer_group_name
                                        
                                        	peer\-group name
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                            ])
                                            self.peer_group_name = None
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Timers(Entity):
                                        """
                                        BGP per neighbor timers
                                        
                                        .. attribute:: keepalive_interval
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: holdtime
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: minimum_neighbor_hold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Timers, self).__init__()

                                            self.yang_name = "timers"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                            ])
                                            self.keepalive_interval = None
                                            self.holdtime = None
                                            self.minimum_neighbor_hold = None
                                            self._segment_path = lambda: "timers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                    class Transport(Entity):
                                        """
                                        Transport options
                                        
                                        .. attribute:: connection_mode
                                        
                                        	Specify passive or active connection
                                        	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Transport.ConnectionMode>`
                                        
                                        .. attribute:: multi_session
                                        
                                        	Use multi\-session for transport
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: path_mtu_discovery
                                        
                                        	Use transport path MTU discovery
                                        	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Transport.PathMtuDiscovery>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Transport, self).__init__()

                                            self.yang_name = "transport"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Transport.PathMtuDiscovery))])
                                            self._leafs = OrderedDict([
                                                ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Transport.ConnectionMode')])),
                                                ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                            ])
                                            self.connection_mode = None
                                            self.multi_session = None

                                            self.path_mtu_discovery = None
                                            self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                            self._segment_path = lambda: "transport"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                        class ConnectionMode(Enum):
                                            """
                                            ConnectionMode (Enum Class)

                                            Specify passive or active connection

                                            .. data:: active = 0

                                            .. data:: passive = 1

                                            """

                                            active = Enum.YLeaf(0, "active")

                                            passive = Enum.YLeaf(1, "passive")



                                        class PathMtuDiscovery(Entity):
                                            """
                                            Use transport path MTU discovery
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                self.yang_name = "path-mtu-discovery"
                                                self.yang_parent_name = "transport"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "path-mtu-discovery"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                    class TtlSecurity(Entity):
                                        """
                                        BGP ttl security check
                                        
                                        .. attribute:: hops
                                        
                                        	IP hops
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.TtlSecurity, self).__init__()

                                            self.yang_name = "ttl-security"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                            ])
                                            self.hops = None
                                            self._segment_path = lambda: "ttl-security"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.TtlSecurity, ['hops'], name, value)


                                    class UpdateSource(Entity):
                                        """
                                        Source of routing updates
                                        
                                        .. attribute:: appnav_compress
                                        
                                        	Service\-Context Virtual Interface Compress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: appnav_uncompress
                                        
                                        	Service\-Context Virtual Interface UnCompress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm
                                        
                                        	ATM interface
                                        	**type**\: str
                                        
                                        .. attribute:: atm_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.ATMSubinterface>`
                                        
                                        .. attribute:: atm_acr
                                        
                                        	ATM\-ACR interface
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9]
                                        
                                        .. attribute:: atm_acrsubinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.ATMACRsubinterface>`
                                        
                                        .. attribute:: bdi
                                        
                                        	Bridge\-Domain interface
                                        	**type**\: str
                                        
                                        .. attribute:: cem
                                        
                                        	CEM interface
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9]/){2}[0\-9]
                                        
                                        .. attribute:: cem_acr
                                        
                                        	CEM\-ACR interface
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: embedded_service_engine
                                        
                                        	cisco embedded service engine module
                                        	**type**\: str
                                        
                                        .. attribute:: ethernet
                                        
                                        	IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: fastethernet
                                        
                                        	FastEthernet IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: gigabitethernet
                                        
                                        	GigabitEthernet IEEE 802.3z
                                        	**type**\: str
                                        
                                        .. attribute:: fivegigabitethernet
                                        
                                        	Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twentyfivegige
                                        
                                        	Twenty Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twogigabitethernet
                                        
                                        	Two GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: fortygigabitethernet
                                        
                                        	Forty GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: hundredgige
                                        
                                        	Hundred GigabitEthernet
                                        	**type**\: str
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_subinterface
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.LISPSubinterface>`
                                        
                                        .. attribute:: loopback
                                        
                                        	Loopback interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multilink
                                        
                                        	Multilink\-group interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: nve
                                        
                                        	Network virtualization endpoint interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: overlay
                                        
                                        	Overlay interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: port_channel
                                        
                                        	Ethernet Channel of interfaces
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: port_channel_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.PortChannelSubinterface>`
                                        
                                        .. attribute:: pseudowire
                                        
                                        	Pseudowire Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sm
                                        
                                        	SM Interface
                                        	**type**\: str
                                        
                                        .. attribute:: cellular
                                        
                                        	Cellular Interface
                                        	**type**\: str
                                        
                                        .. attribute:: serial
                                        
                                        	Serial interface
                                        	**type**\: str
                                        
                                        .. attribute:: tengigabitethernet
                                        
                                        	Ten Gigabit Ethernet
                                        	**type**\: str
                                        
                                        .. attribute:: tunnel
                                        
                                        	Tunnel interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_template
                                        
                                        	Virtual Template interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vlan
                                        
                                        	Iosxr Vlans
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: virtualportgroup
                                        
                                        	Virtual Port Group
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasileft
                                        
                                        	vasileft
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasiright
                                        
                                        	vasiright
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource, self).__init__()

                                            self.yang_name = "update-source"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.PortChannelSubinterface))])
                                            self._leafs = OrderedDict([
                                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                            ])
                                            self.appnav_compress = None
                                            self.appnav_uncompress = None
                                            self.atm = None
                                            self.atm_acr = None
                                            self.bdi = None
                                            self.cem = None
                                            self.cem_acr = None
                                            self.embedded_service_engine = None
                                            self.ethernet = None
                                            self.fastethernet = None
                                            self.gigabitethernet = None
                                            self.fivegigabitethernet = None
                                            self.twentyfivegige = None
                                            self.twogigabitethernet = None
                                            self.fortygigabitethernet = None
                                            self.hundredgige = None
                                            self.lisp = None
                                            self.loopback = None
                                            self.multilink = None
                                            self.nve = None
                                            self.overlay = None
                                            self.port_channel = None
                                            self.pseudowire = None
                                            self.sm = None
                                            self.cellular = None
                                            self.serial = None
                                            self.tengigabitethernet = None
                                            self.tunnel = None
                                            self.virtual_template = None
                                            self.vlan = None
                                            self.virtualportgroup = None
                                            self.vasileft = None
                                            self.vasiright = None

                                            self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.ATMSubinterface()
                                            self.atm_subinterface.parent = self
                                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                            self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.ATMACRsubinterface()
                                            self.atm_acrsubinterface.parent = self
                                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                            self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.LISPSubinterface()
                                            self.lisp_subinterface.parent = self
                                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                            self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.PortChannelSubinterface()
                                            self.port_channel_subinterface.parent = self
                                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                            self._segment_path = lambda: "update-source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                        class ATMSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                self.yang_name = "ATM-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ])
                                                self.atm = None
                                                self._segment_path = lambda: "ATM-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                        class ATMACRsubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm_acr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                self.yang_name = "ATM-ACRsubinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ])
                                                self.atm_acr = None
                                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                        class LISPSubinterface(Entity):
                                            """
                                            Locator/ID Separation Protocol Virtual Interface
                                            
                                            .. attribute:: lisp
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                self.yang_name = "LISP-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ])
                                                self.lisp = None
                                                self._segment_path = lambda: "LISP-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                        class PortChannelSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: port_channel
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                self.yang_name = "Port-channel-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                ])
                                                self.port_channel = None
                                                self._segment_path = lambda: "Port-channel-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Network(Entity):
                                    """
                                    
                                    
                                    .. attribute:: with_mask
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network.WithMask>`
                                    
                                    .. attribute:: no_mask
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network.NoMask>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "ipv4-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network.NoMask))])
                                        self._leafs = OrderedDict()

                                        self.with_mask = YList(self)
                                        self.no_mask = YList(self)
                                        self._segment_path = lambda: "network"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network, [], name, value)


                                    class WithMask(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: number  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: mask  (key)
                                        
                                        	Network mask
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to modify the attributes
                                        	**type**\: str
                                        
                                        .. attribute:: backdoor
                                        
                                        	Specify a BGP backdoor route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: evpn
                                        
                                        	Advertise or export to EVPN address\-family
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network.WithMask, self).__init__()

                                            self.yang_name = "with-mask"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['number','mask']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.mask = None
                                            self.route_map = None
                                            self.backdoor = None
                                            self.evpn = None
                                            self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor', 'evpn'], name, value)


                                    class NoMask(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: number  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to modify the attributes
                                        	**type**\: str
                                        
                                        .. attribute:: backdoor
                                        
                                        	Specify a BGP backdoor route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: evpn
                                        
                                        	Advertise or export to EVPN address\-family
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network.NoMask, self).__init__()

                                            self.yang_name = "no-mask"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['number']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.route_map = None
                                            self.backdoor = None
                                            self.evpn = None
                                            self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Network.NoMask, ['number', 'route_map', 'backdoor', 'evpn'], name, value)


                                class Redistribute(Entity):
                                    """
                                    Redistribute information from another routing protocol
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Application>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Bgp_>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: dvmrp
                                    
                                    	Redistribution of DVMRP into BGP IPv4 Multicast
                                    	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Dvmrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator/ID Separation Protocol
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Lisp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Rip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute, self).__init__()

                                        self.yang_name = "redistribute"
                                        self.yang_parent_name = "ipv4-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static))])
                                        self._leafs = OrderedDict()

                                        self.application = None
                                        self._children_name_map["application"] = "application"

                                        self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.dvmrp = None
                                        self._children_name_map["dvmrp"] = "dvmrp"

                                        self.eigrp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Eigrp()
                                        self.eigrp.parent = self
                                        self._children_name_map["eigrp"] = "eigrp"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.lisp = None
                                        self._children_name_map["lisp"] = "lisp"

                                        self.iso_igrp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp()
                                        self.iso_igrp.parent = self
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.rip = None
                                        self._children_name_map["rip"] = "rip"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "redistribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Application.Name>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Application.Name))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Application, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	WORD \:\: Route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Application.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                    class Bgp_(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.as_no = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                    class Dvmrp(Entity):
                                        """
                                        Redistribution of DVMRP into BGP IPv4 Multicast
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Dvmrp, self).__init__()

                                            self.yang_name = "dvmrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "dvmrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.as_no = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "eigrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.IsisArea>`
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.Default>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.Default))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.default = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis, [], name, value)


                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: routes
                                            
                                            	
                                            	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.IsisArea.Routes>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                    ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                    ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.IsisArea.Routes')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.ip = None
                                                self.clns = None
                                                self.routes = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                            class Routes(Enum):
                                                """
                                                Routes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class Default(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: routes
                                            
                                            	
                                            	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.Default.Routes>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                    ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                    ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.Default.Routes')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.ip = None
                                                self.clns = None
                                                self.routes = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                            class Routes(Enum):
                                                """
                                                Routes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class Lisp(Entity):
                                        """
                                        Locator/ID Separation Protocol
                                        
                                        .. attribute:: include_connected
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.include_connected = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: iso_igrp_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp.Default>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp.Default))])
                                            self._leafs = OrderedDict()

                                            self.default = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.iso_igrp_area = YList(self)
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp, [], name, value)


                                        class IsoIgrpArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                                self.yang_name = "iso-igrp-area"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.name = None
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                        class Default(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.Vrf_>`
                                        
                                        .. attribute:: non_vrf
                                        
                                        	
                                        	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.NonVrf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.Vrf_)), ("non-vrf", ("non_vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.NonVrf))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.non_vrf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.NonVrf()
                                            self.non_vrf.parent = self
                                            self._children_name_map["non_vrf"] = "non-vrf"

                                            self.vrf = YList(self)
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf, ['id'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VPN Routing/Forwarding Instance
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.Vrf_.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.Vrf_.Match))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.Vrf_.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.Vrf_, ['name', 'metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.Vrf_.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True


                                        class NonVrf(Entity):
                                            """
                                            
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.NonVrf.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.NonVrf, self).__init__()

                                                self.yang_name = "non-vrf"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.NonVrf.Match))])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.NonVrf.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "non-vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                .. attribute:: internal
                                                
                                                	Redistribute OSPF internal routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: external
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: external2
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: nssa_external
                                                
                                                	Redistribute OSPF NSSA external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "non-vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                        ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.internal = None
                                                    self.external = None
                                                    self.external2 = None
                                                    self.nssa_external = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospfv3.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospfv3.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospfv3.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: external2
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospfv3.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                    ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.internal = None
                                                self.external = None
                                                self.external2 = None
                                                self.nssa_external = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: name
                                        
                                        	User selected string identifying this process
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self.name = None
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static.Clns>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ip
                                        
                                        	
                                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static.Ip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static.Ip))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None

                                            self.clns = None
                                            self._children_name_map["clns"] = "clns"

                                            self.ip = None
                                            self._children_name_map["ip"] = "ip"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                        class Clns(Entity):
                                            """
                                            Redistribution of OSI dynamic routes
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static.Clns, self).__init__()

                                                self.yang_name = "clns"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "clns"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                        class Ip(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static.Ip, self).__init__()

                                                self.yang_name = "ip"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                                class Snmp(Entity):
                                    """
                                    Modify snmp parameters
                                    
                                    .. attribute:: context
                                    
                                    	Configure a SNMP context
                                    	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp.Context>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp, self).__init__()

                                        self.yang_name = "snmp"
                                        self.yang_parent_name = "ipv4-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp.Context))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.context = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp.Context()
                                        self.context.parent = self
                                        self._children_name_map["context"] = "context"
                                        self._segment_path = lambda: "snmp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp, [], name, value)


                                    class Context(Entity):
                                        """
                                        Configure a SNMP context
                                        
                                        .. attribute:: context_word
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp.Context.ContextWord>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp.Context, self).__init__()

                                            self.yang_name = "context"
                                            self.yang_parent_name = "snmp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp.Context.ContextWord))])
                                            self._leafs = OrderedDict()

                                            self.context_word = YList(self)
                                            self._segment_path = lambda: "context"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp.Context, [], name, value)


                                        class ContextWord(Entity):
                                            """
                                            
                                            
                                            .. attribute:: context_word  (key)
                                            
                                            	Context Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp.Context.ContextWord, self).__init__()

                                                self.yang_name = "context_word"
                                                self.yang_parent_name = "context"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['context_word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                ])
                                                self.context_word = None
                                                self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                                class TableMap(Entity):
                                    """
                                    Map external entry attributes into routing table
                                    
                                    .. attribute:: name
                                    
                                    	WORD \:\: Route\-map name
                                    	**type**\: str
                                    
                                    .. attribute:: filter
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.TableMap, self).__init__()

                                        self.yang_name = "table-map"
                                        self.yang_parent_name = "ipv4-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                                        ])
                                        self.name = None
                                        self.filter = None
                                        self._segment_path = lambda: "table-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Multicast.TableMap, ['name', 'filter'], name, value)


                            class Ipv4Flowspec(Entity):
                                """
                                IPv4 Flowspec VRF address family
                                
                                .. attribute:: bgp
                                
                                	
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_>`
                                
                                .. attribute:: default_information
                                
                                	Control distribution of default information
                                	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.DefaultInformation>`
                                
                                .. attribute:: default_metric
                                
                                	Set metric of redistributed routes
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: import_
                                
                                	Configure path import
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import>`
                                
                                .. attribute:: maximum_paths
                                
                                	Forward packets over multiple paths
                                	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths>`
                                
                                .. attribute:: peer_group
                                
                                	
                                	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup>`
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor>`
                                
                                .. attribute:: network
                                
                                	
                                	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network>`
                                
                                .. attribute:: snmp
                                
                                	Modify snmp parameters
                                	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec, self).__init__()

                                    self.yang_name = "ipv4-flowspec"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.DefaultInformation)), ("import", ("import_", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp))])
                                    self._leafs = OrderedDict([
                                        ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                    ])
                                    self.default_metric = None

                                    self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.default_information = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.DefaultInformation()
                                    self.default_information.parent = self
                                    self._children_name_map["default_information"] = "default-information"

                                    self.import_ = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.maximum_paths = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths()
                                    self.maximum_paths.parent = self
                                    self._children_name_map["maximum_paths"] = "maximum-paths"

                                    self.peer_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup()
                                    self.peer_group.parent = self
                                    self._children_name_map["peer_group"] = "peer-group"

                                    self.network = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network()
                                    self.network.parent = self
                                    self._children_name_map["network"] = "network"

                                    self.snmp = None
                                    self._children_name_map["snmp"] = "snmp"

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "ipv4-flowspec"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec, ['default_metric'], name, value)


                                class Bgp_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	bgp route\-map commands
                                    	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.RouteMap>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "ipv4-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer))])
                                        self._leafs = OrderedDict()

                                        self.route_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.RouteMap()
                                        self.route_map.parent = self
                                        self._children_name_map["route_map"] = "route-map"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_, [], name, value)


                                    class RouteMap(Entity):
                                        """
                                        bgp route\-map commands
                                        
                                        .. attribute:: priority
                                        
                                        	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                            ])
                                            self.priority = None
                                            self._segment_path = lambda: "route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.RouteMap, ['priority'], name, value)


                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: disable
                                            
                                            	Disable slow\-peer detection
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.disable = None
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class DefaultInformation(Entity):
                                    """
                                    Control distribution of default information
                                    
                                    .. attribute:: originate
                                    
                                    	Distribute a default route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.DefaultInformation, self).__init__()

                                        self.yang_name = "default-information"
                                        self.yang_parent_name = "ipv4-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                        ])
                                        self.originate = None
                                        self._segment_path = lambda: "default-information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.DefaultInformation, ['originate'], name, value)


                                class Import(Entity):
                                    """
                                    Configure path import
                                    
                                    .. attribute:: path
                                    
                                    	Path selection and path limit
                                    	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Path>`
                                    
                                    .. attribute:: vpnv4
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Vpnv4>`
                                    
                                    .. attribute:: vpnv6
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Vpnv6>`
                                    
                                    .. attribute:: l2vpn
                                    
                                    	Configure EVPN to VPN path import
                                    	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.L2vpn>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv4-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Path)), ("vpnv4", ("vpnv4", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Vpnv4)), ("vpnv6", ("vpnv6", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Vpnv6)), ("l2vpn", ("l2vpn", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.L2vpn))])
                                        self._leafs = OrderedDict()

                                        self.path = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Path()
                                        self.path.parent = self
                                        self._children_name_map["path"] = "path"

                                        self.vpnv4 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Vpnv4()
                                        self.vpnv4.parent = self
                                        self._children_name_map["vpnv4"] = "vpnv4"

                                        self.vpnv6 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Vpnv6()
                                        self.vpnv6.parent = self
                                        self._children_name_map["vpnv6"] = "vpnv6"

                                        self.l2vpn = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.L2vpn()
                                        self.l2vpn.parent = self
                                        self._children_name_map["l2vpn"] = "l2vpn"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import, [], name, value)


                                    class Path(Entity):
                                        """
                                        Path selection and path limit
                                        
                                        .. attribute:: limit
                                        
                                        	Per net imported path limit
                                        	**type**\: int
                                        
                                        	**range:** 2..255
                                        
                                        .. attribute:: selection
                                        
                                        	Path selection policy
                                        	**type**\:  :py:class:`Selection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Path.Selection>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("selection", ("selection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Path.Selection))])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                                            ])
                                            self.limit = None

                                            self.selection = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Path.Selection()
                                            self.selection.parent = self
                                            self._children_name_map["selection"] = "selection"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Path, ['limit'], name, value)


                                        class Selection(Entity):
                                            """
                                            Path selection policy
                                            
                                            .. attribute:: all
                                            
                                            	Import all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Path.Selection, self).__init__()

                                                self.yang_name = "selection"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "selection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Path.Selection, ['all'], name, value)


                                    class Vpnv4(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Vpnv4, self).__init__()

                                            self.yang_name = "vpnv4"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv4"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Vpnv4, ['unicast', 're_originate'], name, value)


                                    class Vpnv6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	Imported path with RT re\-originate
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Vpnv6, self).__init__()

                                            self.yang_name = "vpnv6"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.Vpnv6, ['unicast', 're_originate'], name, value)


                                    class L2vpn(Entity):
                                        """
                                        Configure EVPN to VPN path import
                                        
                                        .. attribute:: evpn
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.L2vpn, self).__init__()

                                            self.yang_name = "l2vpn"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.evpn = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "l2vpn"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Import.L2vpn, ['evpn', 're_originate'], name, value)


                                class MaximumPaths(Entity):
                                    """
                                    Forward packets over multiple paths
                                    
                                    .. attribute:: ebgp
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: eibgp
                                    
                                    	Both eBGP and iBGP paths as multipath
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: ibgp
                                    
                                    	iBGP\-multipath
                                    	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths.Ibgp>`
                                    
                                    .. attribute:: external_rtfilter
                                    
                                    	VPN prefix multipath on external RT\-Filter peers
                                    	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths.ExternalRtfilter>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths, self).__init__()

                                        self.yang_name = "maximum-paths"
                                        self.yang_parent_name = "ipv4-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths.ExternalRtfilter))])
                                        self._leafs = OrderedDict([
                                            ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                            ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                        ])
                                        self.ebgp = None
                                        self.eibgp = None

                                        self.ibgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths.Ibgp()
                                        self.ibgp.parent = self
                                        self._children_name_map["ibgp"] = "ibgp"

                                        self.external_rtfilter = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths.ExternalRtfilter()
                                        self.external_rtfilter.parent = self
                                        self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                        self._segment_path = lambda: "maximum-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                    class Ibgp(Entity):
                                        """
                                        iBGP\-multipath
                                        
                                        .. attribute:: unequal_cost
                                        
                                        	Perform un\-equal cost multipath selection
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: max
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths.Ibgp, self).__init__()

                                            self.yang_name = "ibgp"
                                            self.yang_parent_name = "maximum-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                            ])
                                            self.unequal_cost = None
                                            self.max = None
                                            self._segment_path = lambda: "ibgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                    class ExternalRtfilter(Entity):
                                        """
                                        VPN prefix multipath on external RT\-Filter peers
                                        
                                        .. attribute:: max
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths.ExternalRtfilter, self).__init__()

                                            self.yang_name = "external-rtfilter"
                                            self.yang_parent_name = "maximum-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                            ])
                                            self.max = None
                                            self._segment_path = lambda: "external-rtfilter"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                class PeerGroup(Entity):
                                    """
                                    
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup, self).__init__()

                                        self.yang_name = "peer-group"
                                        self.yang_parent_name = "ipv4-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor))])
                                        self._leafs = OrderedDict()

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "peer-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: peer_group
                                        
                                        	Member of the peer\-group
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: cluster_id
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	Neighbor specific description
                                        	**type**\: str
                                        
                                        .. attribute:: disable_connected_check
                                        
                                        	one\-hop away EBGP peer using loopback address
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ebgp_multihop
                                        
                                        	Allow EBGP neighbors not on directly connected networks
                                        	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.EbgpMultihop>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: fall_over
                                        
                                        	session fall on peer route lost
                                        	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.FallOver>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ha_mode
                                        
                                        	high availability mode
                                        	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Inherit>`
                                        
                                        .. attribute:: local_as
                                        
                                        	Specify a local\-as number
                                        	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.LocalAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: log_neighbor_changes
                                        
                                        	Log neighbor up/down and reset reason
                                        	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.LogNeighborChanges>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: password
                                        
                                        	Set a password
                                        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Password>`
                                        
                                        .. attribute:: path_attribute
                                        
                                        	BGP optional attribute filtering
                                        	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute>`
                                        
                                        .. attribute:: remote_as
                                        
                                        	Specify a BGP peer\-group remote\-as
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: shutdown
                                        
                                        	Administratively shut down this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: timers
                                        
                                        	BGP per neighbor timers
                                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Timers>`
                                        
                                        .. attribute:: transport
                                        
                                        	Transport options
                                        	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Transport>`
                                        
                                        .. attribute:: ttl_security
                                        
                                        	BGP ttl security check
                                        	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.TtlSecurity>`
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: update_source
                                        
                                        	Source of routing updates
                                        	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource>`
                                        
                                        .. attribute:: version
                                        
                                        	Set the BGP version to match a neighbor
                                        	**type**\: int
                                        
                                        	**range:** 4..None
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "peer-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.AllowasIn)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.FallOver)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Timers)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ('peer_group', (YLeaf(YType.empty, 'peer-group'), ['Empty'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.peer_group = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.cluster_id = None
                                            self.description = None
                                            self.disable_connected_check = None
                                            self.next_hop_unchanged = None
                                            self.remote_as = None
                                            self.route_reflector_client = None
                                            self.shutdown = None
                                            self.soft_reconfiguration = None
                                            self.unsuppress_map = None
                                            self.version = None
                                            self.weight = None

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.ebgp_multihop = None
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                            self.fall_over = None
                                            self._children_name_map["fall_over"] = "fall-over"

                                            self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode()
                                            self.ha_mode.parent = self
                                            self._children_name_map["ha_mode"] = "ha-mode"

                                            self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.local_as = None
                                            self._children_name_map["local_as"] = "local-as"

                                            self.log_neighbor_changes = None
                                            self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                            self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"

                                            self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute()
                                            self.path_attribute.parent = self
                                            self._children_name_map["path_attribute"] = "path-attribute"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"

                                            self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Transport()
                                            self.transport.parent = self
                                            self._children_name_map["transport"] = "transport"

                                            self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.TtlSecurity()
                                            self.ttl_security.parent = self
                                            self._children_name_map["ttl_security"] = "ttl-security"

                                            self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource()
                                            self.update_source.parent = self
                                            self._children_name_map["update_source"] = "update-source"

                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor, ['id', 'peer_group', 'activate', 'advertisement_interval', 'cluster_id', 'description', 'disable_connected_check', 'next_hop_unchanged', 'remote_as', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'unsuppress_map', 'version', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class EbgpMultihop(Entity):
                                            """
                                            Allow EBGP neighbors not on directly connected networks
                                            
                                            .. attribute:: max_hop
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.EbgpMultihop, self).__init__()

                                                self.yang_name = "ebgp-multihop"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                                ])
                                                self.max_hop = None
                                                self._segment_path = lambda: "ebgp-multihop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                        class FallOver(Entity):
                                            """
                                            session fall on peer route lost
                                            
                                            .. attribute:: bfd
                                            
                                            	Use BFD to detect failure
                                            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.FallOver.Bfd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.FallOver, self).__init__()

                                                self.yang_name = "fall-over"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.FallOver.Bfd))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.route_map_name = None

                                                self.bfd = None
                                                self._children_name_map["bfd"] = "bfd"
                                                self._segment_path = lambda: "fall-over"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.FallOver, ['route_map_name'], name, value)


                                            class Bfd(Entity):
                                                """
                                                Use BFD to detect failure
                                                
                                                .. attribute:: multi_hop
                                                
                                                	Force BFD multi\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: single_hop
                                                
                                                	Force BFD single\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: check_control_plane_failure
                                                
                                                	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: strict_mode
                                                
                                                	Enable BFD strict\-mode
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.FallOver.Bfd, self).__init__()

                                                    self.yang_name = "bfd"
                                                    self.yang_parent_name = "fall-over"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                        ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                        ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                        ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                    ])
                                                    self.multi_hop = None
                                                    self.single_hop = None
                                                    self.check_control_plane_failure = None
                                                    self.strict_mode = None
                                                    self._segment_path = lambda: "bfd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                        class HaMode(Entity):
                                            """
                                            high availability mode
                                            
                                            .. attribute:: graceful_restart
                                            
                                            	graceful\-restart for this peer
                                            	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode.GracefulRestart>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: sso
                                            
                                            	stateful\-switchover support for this peer
                                            	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode.Sso>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode, self).__init__()

                                                self.yang_name = "ha-mode"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode.Sso))])
                                                self._leafs = OrderedDict()

                                                self.graceful_restart = None
                                                self._children_name_map["graceful_restart"] = "graceful-restart"

                                                self.sso = None
                                                self._children_name_map["sso"] = "sso"
                                                self._segment_path = lambda: "ha-mode"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode, [], name, value)


                                            class GracefulRestart(Entity):
                                                """
                                                graceful\-restart for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable graceful\-restart
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                    self.yang_name = "graceful-restart"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "graceful-restart"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                            class Sso(Entity):
                                                """
                                                stateful\-switchover support for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable stateful\-switchover
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode.Sso, self).__init__()

                                                    self.yang_name = "sso"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "sso"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.HaMode.Sso, ['disable'], name, value)


                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class LocalAs(Entity):
                                            """
                                            Specify a local\-as number
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: no_prepend
                                            
                                            	Do not prepend local\-as to updates from ebgp peers
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace real AS with local AS in the EBGP updates
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: dual_as
                                            
                                            	Accept either real AS or local AS from the ebgp peer
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.LocalAs, self).__init__()

                                                self.yang_name = "local-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                    ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                                ])
                                                self.as_no = None
                                                self.no_prepend = None
                                                self.replace_as = None
                                                self.dual_as = None
                                                self._segment_path = lambda: "local-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                        class LogNeighborChanges(Entity):
                                            """
                                            Log neighbor up/down and reset reason
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.LogNeighborChanges, self).__init__()

                                                self.yang_name = "log-neighbor-changes"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "log-neighbor-changes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                        class Password(Entity):
                                            """
                                            Set a password
                                            
                                            .. attribute:: enctype
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: text
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Password, self).__init__()

                                                self.yang_name = "password"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                                ])
                                                self.enctype = None
                                                self.text = None
                                                self._segment_path = lambda: "password"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Password, ['enctype', 'text'], name, value)


                                        class PathAttribute(Entity):
                                            """
                                            BGP optional attribute filtering
                                            
                                            .. attribute:: discard
                                            
                                            	Discard matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard>`
                                            
                                            .. attribute:: treat_as_withdraw
                                            
                                            	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute, self).__init__()

                                                self.yang_name = "path-attribute"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw))])
                                                self._leafs = OrderedDict()

                                                self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard()
                                                self.discard.parent = self
                                                self._children_name_map["discard"] = "discard"

                                                self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw()
                                                self.treat_as_withdraw.parent = self
                                                self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                                self._segment_path = lambda: "path-attribute"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute, [], name, value)


                                            class Discard(Entity):
                                                """
                                                Discard matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard, self).__init__()

                                                    self.yang_name = "discard"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "discard"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                            class TreatAsWithdraw(Entity):
                                                """
                                                Treat\-as\-withdraw matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                    self.yang_name = "treat-as-withdraw"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "treat-as-withdraw"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class Timers(Entity):
                                            """
                                            BGP per neighbor timers
                                            
                                            .. attribute:: keepalive_interval
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: holdtime
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: minimum_neighbor_hold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Timers, self).__init__()

                                                self.yang_name = "timers"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                    ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                    ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                                ])
                                                self.keepalive_interval = None
                                                self.holdtime = None
                                                self.minimum_neighbor_hold = None
                                                self._segment_path = lambda: "timers"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                        class Transport(Entity):
                                            """
                                            Transport options
                                            
                                            .. attribute:: connection_mode
                                            
                                            	Specify passive or active connection
                                            	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Transport.ConnectionMode>`
                                            
                                            .. attribute:: multi_session
                                            
                                            	Use multi\-session for transport
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: path_mtu_discovery
                                            
                                            	Use transport path MTU discovery
                                            	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Transport.PathMtuDiscovery>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Transport, self).__init__()

                                                self.yang_name = "transport"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Transport.PathMtuDiscovery))])
                                                self._leafs = OrderedDict([
                                                    ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Transport.ConnectionMode')])),
                                                    ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                                ])
                                                self.connection_mode = None
                                                self.multi_session = None

                                                self.path_mtu_discovery = None
                                                self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                                self._segment_path = lambda: "transport"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                            class ConnectionMode(Enum):
                                                """
                                                ConnectionMode (Enum Class)

                                                Specify passive or active connection

                                                .. data:: active = 0

                                                .. data:: passive = 1

                                                """

                                                active = Enum.YLeaf(0, "active")

                                                passive = Enum.YLeaf(1, "passive")



                                            class PathMtuDiscovery(Entity):
                                                """
                                                Use transport path MTU discovery
                                                
                                                .. attribute:: disable
                                                
                                                	disable
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                    self.yang_name = "path-mtu-discovery"
                                                    self.yang_parent_name = "transport"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "path-mtu-discovery"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                        class TtlSecurity(Entity):
                                            """
                                            BGP ttl security check
                                            
                                            .. attribute:: hops
                                            
                                            	IP hops
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.TtlSecurity, self).__init__()

                                                self.yang_name = "ttl-security"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                                ])
                                                self.hops = None
                                                self._segment_path = lambda: "ttl-security"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.TtlSecurity, ['hops'], name, value)


                                        class UpdateSource(Entity):
                                            """
                                            Source of routing updates
                                            
                                            .. attribute:: appnav_compress
                                            
                                            	Service\-Context Virtual Interface Compress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: appnav_uncompress
                                            
                                            	Service\-Context Virtual Interface UnCompress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm
                                            
                                            	ATM interface
                                            	**type**\: str
                                            
                                            .. attribute:: atm_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.ATMSubinterface>`
                                            
                                            .. attribute:: atm_acr
                                            
                                            	ATM\-ACR interface
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]
                                            
                                            .. attribute:: atm_acrsubinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface>`
                                            
                                            .. attribute:: bdi
                                            
                                            	Bridge\-Domain interface
                                            	**type**\: str
                                            
                                            .. attribute:: cem
                                            
                                            	CEM interface
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9]/){2}[0\-9]
                                            
                                            .. attribute:: cem_acr
                                            
                                            	CEM\-ACR interface
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: embedded_service_engine
                                            
                                            	cisco embedded service engine module
                                            	**type**\: str
                                            
                                            .. attribute:: ethernet
                                            
                                            	IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: fastethernet
                                            
                                            	FastEthernet IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: gigabitethernet
                                            
                                            	GigabitEthernet IEEE 802.3z
                                            	**type**\: str
                                            
                                            .. attribute:: fivegigabitethernet
                                            
                                            	Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twentyfivegige
                                            
                                            	Twenty Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twogigabitethernet
                                            
                                            	Two GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: fortygigabitethernet
                                            
                                            	Forty GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: hundredgige
                                            
                                            	Hundred GigabitEthernet
                                            	**type**\: str
                                            
                                            .. attribute:: lisp
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_subinterface
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.LISPSubinterface>`
                                            
                                            .. attribute:: loopback
                                            
                                            	Loopback interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multilink
                                            
                                            	Multilink\-group interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: nve
                                            
                                            	Network virtualization endpoint interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: overlay
                                            
                                            	Overlay interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: port_channel
                                            
                                            	Ethernet Channel of interfaces
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: port_channel_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface>`
                                            
                                            .. attribute:: pseudowire
                                            
                                            	Pseudowire Interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sm
                                            
                                            	SM Interface
                                            	**type**\: str
                                            
                                            .. attribute:: cellular
                                            
                                            	Cellular Interface
                                            	**type**\: str
                                            
                                            .. attribute:: serial
                                            
                                            	Serial interface
                                            	**type**\: str
                                            
                                            .. attribute:: tengigabitethernet
                                            
                                            	Ten Gigabit Ethernet
                                            	**type**\: str
                                            
                                            .. attribute:: tunnel
                                            
                                            	Tunnel interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_template
                                            
                                            	Virtual Template interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vlan
                                            
                                            	Iosxr Vlans
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: virtualportgroup
                                            
                                            	Virtual Port Group
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasileft
                                            
                                            	vasileft
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasiright
                                            
                                            	vasiright
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource, self).__init__()

                                                self.yang_name = "update-source"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface))])
                                                self._leafs = OrderedDict([
                                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                                ])
                                                self.appnav_compress = None
                                                self.appnav_uncompress = None
                                                self.atm = None
                                                self.atm_acr = None
                                                self.bdi = None
                                                self.cem = None
                                                self.cem_acr = None
                                                self.embedded_service_engine = None
                                                self.ethernet = None
                                                self.fastethernet = None
                                                self.gigabitethernet = None
                                                self.fivegigabitethernet = None
                                                self.twentyfivegige = None
                                                self.twogigabitethernet = None
                                                self.fortygigabitethernet = None
                                                self.hundredgige = None
                                                self.lisp = None
                                                self.loopback = None
                                                self.multilink = None
                                                self.nve = None
                                                self.overlay = None
                                                self.port_channel = None
                                                self.pseudowire = None
                                                self.sm = None
                                                self.cellular = None
                                                self.serial = None
                                                self.tengigabitethernet = None
                                                self.tunnel = None
                                                self.virtual_template = None
                                                self.vlan = None
                                                self.virtualportgroup = None
                                                self.vasileft = None
                                                self.vasiright = None

                                                self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.ATMSubinterface()
                                                self.atm_subinterface.parent = self
                                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                                self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface()
                                                self.atm_acrsubinterface.parent = self
                                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                                self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.LISPSubinterface()
                                                self.lisp_subinterface.parent = self
                                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                                self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface()
                                                self.port_channel_subinterface.parent = self
                                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                                self._segment_path = lambda: "update-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                            class ATMSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                    self.yang_name = "ATM-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ])
                                                    self.atm = None
                                                    self._segment_path = lambda: "ATM-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                            class ATMACRsubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm_acr
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                    self.yang_name = "ATM-ACRsubinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ])
                                                    self.atm_acr = None
                                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                            class LISPSubinterface(Entity):
                                                """
                                                Locator/ID Separation Protocol Virtual Interface
                                                
                                                .. attribute:: lisp
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                    self.yang_name = "LISP-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ])
                                                    self.lisp = None
                                                    self._segment_path = lambda: "LISP-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                            class PortChannelSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: port_channel
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                    self.yang_name = "Port-channel-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                    ])
                                                    self.port_channel = None
                                                    self._segment_path = lambda: "Port-channel-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_as
                                    
                                    	Specify a BGP peer\-group remote\-as
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: cluster_id
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	Neighbor specific description
                                    	**type**\: str
                                    
                                    .. attribute:: disable_connected_check
                                    
                                    	one\-hop away EBGP peer using loopback address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ebgp_multihop
                                    
                                    	Allow EBGP neighbors not on directly connected networks
                                    	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.EbgpMultihop>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fall_over
                                    
                                    	session fall on peer route lost
                                    	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.FallOver>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ha_mode
                                    
                                    	high availability mode
                                    	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Inherit>`
                                    
                                    .. attribute:: local_as
                                    
                                    	Specify a local\-as number
                                    	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.LocalAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: log_neighbor_changes
                                    
                                    	Log neighbor up/down and reset reason
                                    	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.LogNeighborChanges>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: password
                                    
                                    	Set a password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Password>`
                                    
                                    .. attribute:: path_attribute
                                    
                                    	BGP optional attribute filtering
                                    	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	Member of the peer\-group
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PeerGroup>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: shutdown
                                    
                                    	Administratively shut down this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: timers
                                    
                                    	BGP per neighbor timers
                                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Timers>`
                                    
                                    .. attribute:: transport
                                    
                                    	Transport options
                                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Transport>`
                                    
                                    .. attribute:: ttl_security
                                    
                                    	BGP ttl security check
                                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.TtlSecurity>`
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: update_source
                                    
                                    	Source of routing updates
                                    	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource>`
                                    
                                    .. attribute:: version
                                    
                                    	Set the BGP version to match a neighbor
                                    	**type**\: int
                                    
                                    	**range:** 4..None
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "ipv4-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.AllowasIn)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.FallOver)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PeerGroup)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Timers)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                            ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SoftReconfiguration')])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.remote_as = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.cluster_id = None
                                        self.description = None
                                        self.disable_connected_check = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.shutdown = None
                                        self.soft_reconfiguration = None
                                        self.unsuppress_map = None
                                        self.version = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.ebgp_multihop = None
                                        self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                        self.fall_over = None
                                        self._children_name_map["fall_over"] = "fall-over"

                                        self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode()
                                        self.ha_mode.parent = self
                                        self._children_name_map["ha_mode"] = "ha-mode"

                                        self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.local_as = None
                                        self._children_name_map["local_as"] = "local-as"

                                        self.log_neighbor_changes = None
                                        self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"

                                        self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute()
                                        self.path_attribute.parent = self
                                        self._children_name_map["path_attribute"] = "path-attribute"

                                        self.peer_group = None
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Timers()
                                        self.timers.parent = self
                                        self._children_name_map["timers"] = "timers"

                                        self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Transport()
                                        self.transport.parent = self
                                        self._children_name_map["transport"] = "transport"

                                        self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.TtlSecurity()
                                        self.ttl_security.parent = self
                                        self._children_name_map["ttl_security"] = "ttl-security"

                                        self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource()
                                        self.update_source.parent = self
                                        self._children_name_map["update_source"] = "update-source"

                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor, ['id', 'remote_as', 'activate', 'advertisement_interval', 'cluster_id', 'description', 'disable_connected_check', 'next_hop_unchanged', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'unsuppress_map', 'version', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class EbgpMultihop(Entity):
                                        """
                                        Allow EBGP neighbors not on directly connected networks
                                        
                                        .. attribute:: max_hop
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.EbgpMultihop, self).__init__()

                                            self.yang_name = "ebgp-multihop"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                            ])
                                            self.max_hop = None
                                            self._segment_path = lambda: "ebgp-multihop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                    class FallOver(Entity):
                                        """
                                        session fall on peer route lost
                                        
                                        .. attribute:: bfd
                                        
                                        	Use BFD to detect failure
                                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.FallOver.Bfd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.FallOver, self).__init__()

                                            self.yang_name = "fall-over"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.FallOver.Bfd))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.route_map_name = None

                                            self.bfd = None
                                            self._children_name_map["bfd"] = "bfd"
                                            self._segment_path = lambda: "fall-over"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.FallOver, ['route_map_name'], name, value)


                                        class Bfd(Entity):
                                            """
                                            Use BFD to detect failure
                                            
                                            .. attribute:: multi_hop
                                            
                                            	Force BFD multi\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: single_hop
                                            
                                            	Force BFD single\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: check_control_plane_failure
                                            
                                            	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: strict_mode
                                            
                                            	Enable BFD strict\-mode
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.FallOver.Bfd, self).__init__()

                                                self.yang_name = "bfd"
                                                self.yang_parent_name = "fall-over"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                    ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                    ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                    ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                ])
                                                self.multi_hop = None
                                                self.single_hop = None
                                                self.check_control_plane_failure = None
                                                self.strict_mode = None
                                                self._segment_path = lambda: "bfd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                    class HaMode(Entity):
                                        """
                                        high availability mode
                                        
                                        .. attribute:: graceful_restart
                                        
                                        	graceful\-restart for this peer
                                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode.GracefulRestart>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: sso
                                        
                                        	stateful\-switchover support for this peer
                                        	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode.Sso>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode, self).__init__()

                                            self.yang_name = "ha-mode"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode.Sso))])
                                            self._leafs = OrderedDict()

                                            self.graceful_restart = None
                                            self._children_name_map["graceful_restart"] = "graceful-restart"

                                            self.sso = None
                                            self._children_name_map["sso"] = "sso"
                                            self._segment_path = lambda: "ha-mode"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode, [], name, value)


                                        class GracefulRestart(Entity):
                                            """
                                            graceful\-restart for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable graceful\-restart
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                self.yang_name = "graceful-restart"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "graceful-restart"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                        class Sso(Entity):
                                            """
                                            stateful\-switchover support for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable stateful\-switchover
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode.Sso, self).__init__()

                                                self.yang_name = "sso"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "sso"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.HaMode.Sso, ['disable'], name, value)


                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class LocalAs(Entity):
                                        """
                                        Specify a local\-as number
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: no_prepend
                                        
                                        	Do not prepend local\-as to updates from ebgp peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace real AS with local AS in the EBGP updates
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: dual_as
                                        
                                        	Accept either real AS or local AS from the ebgp peer
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.LocalAs, self).__init__()

                                            self.yang_name = "local-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                            ])
                                            self.as_no = None
                                            self.no_prepend = None
                                            self.replace_as = None
                                            self.dual_as = None
                                            self._segment_path = lambda: "local-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                    class LogNeighborChanges(Entity):
                                        """
                                        Log neighbor up/down and reset reason
                                        
                                        .. attribute:: disable
                                        
                                        	disable
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.LogNeighborChanges, self).__init__()

                                            self.yang_name = "log-neighbor-changes"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "log-neighbor-changes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.NextHopSelf, ['all'], name, value)


                                    class Password(Entity):
                                        """
                                        Set a password
                                        
                                        .. attribute:: enctype
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: text
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                            ])
                                            self.enctype = None
                                            self.text = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Password, ['enctype', 'text'], name, value)


                                    class PathAttribute(Entity):
                                        """
                                        BGP optional attribute filtering
                                        
                                        .. attribute:: discard
                                        
                                        	Discard matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard>`
                                        
                                        .. attribute:: treat_as_withdraw
                                        
                                        	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute, self).__init__()

                                            self.yang_name = "path-attribute"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw))])
                                            self._leafs = OrderedDict()

                                            self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard()
                                            self.discard.parent = self
                                            self._children_name_map["discard"] = "discard"

                                            self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw()
                                            self.treat_as_withdraw.parent = self
                                            self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                            self._segment_path = lambda: "path-attribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute, [], name, value)


                                        class Discard(Entity):
                                            """
                                            Discard matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard, self).__init__()

                                                self.yang_name = "discard"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "discard"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class TreatAsWithdraw(Entity):
                                            """
                                            Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                self.yang_name = "treat-as-withdraw"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "treat-as-withdraw"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        Member of the peer\-group
                                        
                                        .. attribute:: peer_group_name
                                        
                                        	peer\-group name
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                            ])
                                            self.peer_group_name = None
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Timers(Entity):
                                        """
                                        BGP per neighbor timers
                                        
                                        .. attribute:: keepalive_interval
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: holdtime
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: minimum_neighbor_hold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Timers, self).__init__()

                                            self.yang_name = "timers"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                            ])
                                            self.keepalive_interval = None
                                            self.holdtime = None
                                            self.minimum_neighbor_hold = None
                                            self._segment_path = lambda: "timers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                    class Transport(Entity):
                                        """
                                        Transport options
                                        
                                        .. attribute:: connection_mode
                                        
                                        	Specify passive or active connection
                                        	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Transport.ConnectionMode>`
                                        
                                        .. attribute:: multi_session
                                        
                                        	Use multi\-session for transport
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: path_mtu_discovery
                                        
                                        	Use transport path MTU discovery
                                        	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Transport.PathMtuDiscovery>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Transport, self).__init__()

                                            self.yang_name = "transport"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Transport.PathMtuDiscovery))])
                                            self._leafs = OrderedDict([
                                                ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Transport.ConnectionMode')])),
                                                ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                            ])
                                            self.connection_mode = None
                                            self.multi_session = None

                                            self.path_mtu_discovery = None
                                            self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                            self._segment_path = lambda: "transport"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                        class ConnectionMode(Enum):
                                            """
                                            ConnectionMode (Enum Class)

                                            Specify passive or active connection

                                            .. data:: active = 0

                                            .. data:: passive = 1

                                            """

                                            active = Enum.YLeaf(0, "active")

                                            passive = Enum.YLeaf(1, "passive")



                                        class PathMtuDiscovery(Entity):
                                            """
                                            Use transport path MTU discovery
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                self.yang_name = "path-mtu-discovery"
                                                self.yang_parent_name = "transport"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "path-mtu-discovery"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                    class TtlSecurity(Entity):
                                        """
                                        BGP ttl security check
                                        
                                        .. attribute:: hops
                                        
                                        	IP hops
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.TtlSecurity, self).__init__()

                                            self.yang_name = "ttl-security"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                            ])
                                            self.hops = None
                                            self._segment_path = lambda: "ttl-security"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.TtlSecurity, ['hops'], name, value)


                                    class UpdateSource(Entity):
                                        """
                                        Source of routing updates
                                        
                                        .. attribute:: appnav_compress
                                        
                                        	Service\-Context Virtual Interface Compress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: appnav_uncompress
                                        
                                        	Service\-Context Virtual Interface UnCompress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm
                                        
                                        	ATM interface
                                        	**type**\: str
                                        
                                        .. attribute:: atm_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.ATMSubinterface>`
                                        
                                        .. attribute:: atm_acr
                                        
                                        	ATM\-ACR interface
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9]
                                        
                                        .. attribute:: atm_acrsubinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.ATMACRsubinterface>`
                                        
                                        .. attribute:: bdi
                                        
                                        	Bridge\-Domain interface
                                        	**type**\: str
                                        
                                        .. attribute:: cem
                                        
                                        	CEM interface
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9]/){2}[0\-9]
                                        
                                        .. attribute:: cem_acr
                                        
                                        	CEM\-ACR interface
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: embedded_service_engine
                                        
                                        	cisco embedded service engine module
                                        	**type**\: str
                                        
                                        .. attribute:: ethernet
                                        
                                        	IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: fastethernet
                                        
                                        	FastEthernet IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: gigabitethernet
                                        
                                        	GigabitEthernet IEEE 802.3z
                                        	**type**\: str
                                        
                                        .. attribute:: fivegigabitethernet
                                        
                                        	Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twentyfivegige
                                        
                                        	Twenty Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twogigabitethernet
                                        
                                        	Two GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: fortygigabitethernet
                                        
                                        	Forty GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: hundredgige
                                        
                                        	Hundred GigabitEthernet
                                        	**type**\: str
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_subinterface
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.LISPSubinterface>`
                                        
                                        .. attribute:: loopback
                                        
                                        	Loopback interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multilink
                                        
                                        	Multilink\-group interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: nve
                                        
                                        	Network virtualization endpoint interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: overlay
                                        
                                        	Overlay interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: port_channel
                                        
                                        	Ethernet Channel of interfaces
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: port_channel_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.PortChannelSubinterface>`
                                        
                                        .. attribute:: pseudowire
                                        
                                        	Pseudowire Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sm
                                        
                                        	SM Interface
                                        	**type**\: str
                                        
                                        .. attribute:: cellular
                                        
                                        	Cellular Interface
                                        	**type**\: str
                                        
                                        .. attribute:: serial
                                        
                                        	Serial interface
                                        	**type**\: str
                                        
                                        .. attribute:: tengigabitethernet
                                        
                                        	Ten Gigabit Ethernet
                                        	**type**\: str
                                        
                                        .. attribute:: tunnel
                                        
                                        	Tunnel interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_template
                                        
                                        	Virtual Template interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vlan
                                        
                                        	Iosxr Vlans
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: virtualportgroup
                                        
                                        	Virtual Port Group
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasileft
                                        
                                        	vasileft
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasiright
                                        
                                        	vasiright
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource, self).__init__()

                                            self.yang_name = "update-source"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.PortChannelSubinterface))])
                                            self._leafs = OrderedDict([
                                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                            ])
                                            self.appnav_compress = None
                                            self.appnav_uncompress = None
                                            self.atm = None
                                            self.atm_acr = None
                                            self.bdi = None
                                            self.cem = None
                                            self.cem_acr = None
                                            self.embedded_service_engine = None
                                            self.ethernet = None
                                            self.fastethernet = None
                                            self.gigabitethernet = None
                                            self.fivegigabitethernet = None
                                            self.twentyfivegige = None
                                            self.twogigabitethernet = None
                                            self.fortygigabitethernet = None
                                            self.hundredgige = None
                                            self.lisp = None
                                            self.loopback = None
                                            self.multilink = None
                                            self.nve = None
                                            self.overlay = None
                                            self.port_channel = None
                                            self.pseudowire = None
                                            self.sm = None
                                            self.cellular = None
                                            self.serial = None
                                            self.tengigabitethernet = None
                                            self.tunnel = None
                                            self.virtual_template = None
                                            self.vlan = None
                                            self.virtualportgroup = None
                                            self.vasileft = None
                                            self.vasiright = None

                                            self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.ATMSubinterface()
                                            self.atm_subinterface.parent = self
                                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                            self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.ATMACRsubinterface()
                                            self.atm_acrsubinterface.parent = self
                                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                            self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.LISPSubinterface()
                                            self.lisp_subinterface.parent = self
                                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                            self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.PortChannelSubinterface()
                                            self.port_channel_subinterface.parent = self
                                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                            self._segment_path = lambda: "update-source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                        class ATMSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                self.yang_name = "ATM-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ])
                                                self.atm = None
                                                self._segment_path = lambda: "ATM-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                        class ATMACRsubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm_acr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                self.yang_name = "ATM-ACRsubinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ])
                                                self.atm_acr = None
                                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                        class LISPSubinterface(Entity):
                                            """
                                            Locator/ID Separation Protocol Virtual Interface
                                            
                                            .. attribute:: lisp
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                self.yang_name = "LISP-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ])
                                                self.lisp = None
                                                self._segment_path = lambda: "LISP-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                        class PortChannelSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: port_channel
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                self.yang_name = "Port-channel-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                ])
                                                self.port_channel = None
                                                self._segment_path = lambda: "Port-channel-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Network(Entity):
                                    """
                                    
                                    
                                    .. attribute:: with_mask
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network.WithMask>`
                                    
                                    .. attribute:: no_mask
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network.NoMask>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "ipv4-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network.NoMask))])
                                        self._leafs = OrderedDict()

                                        self.with_mask = YList(self)
                                        self.no_mask = YList(self)
                                        self._segment_path = lambda: "network"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network, [], name, value)


                                    class WithMask(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: number  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: mask  (key)
                                        
                                        	Network mask
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to modify the attributes
                                        	**type**\: str
                                        
                                        .. attribute:: backdoor
                                        
                                        	Specify a BGP backdoor route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: evpn
                                        
                                        	Advertise or export to EVPN address\-family
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network.WithMask, self).__init__()

                                            self.yang_name = "with-mask"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['number','mask']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.mask = None
                                            self.route_map = None
                                            self.backdoor = None
                                            self.evpn = None
                                            self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor', 'evpn'], name, value)


                                    class NoMask(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: number  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to modify the attributes
                                        	**type**\: str
                                        
                                        .. attribute:: backdoor
                                        
                                        	Specify a BGP backdoor route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: evpn
                                        
                                        	Advertise or export to EVPN address\-family
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network.NoMask, self).__init__()

                                            self.yang_name = "no-mask"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['number']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.route_map = None
                                            self.backdoor = None
                                            self.evpn = None
                                            self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Network.NoMask, ['number', 'route_map', 'backdoor', 'evpn'], name, value)


                                class Snmp(Entity):
                                    """
                                    Modify snmp parameters
                                    
                                    .. attribute:: context
                                    
                                    	Configure a SNMP context
                                    	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp.Context>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp, self).__init__()

                                        self.yang_name = "snmp"
                                        self.yang_parent_name = "ipv4-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp.Context))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.context = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp.Context()
                                        self.context.parent = self
                                        self._children_name_map["context"] = "context"
                                        self._segment_path = lambda: "snmp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp, [], name, value)


                                    class Context(Entity):
                                        """
                                        Configure a SNMP context
                                        
                                        .. attribute:: context_word
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp.Context.ContextWord>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp.Context, self).__init__()

                                            self.yang_name = "context"
                                            self.yang_parent_name = "snmp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp.Context.ContextWord))])
                                            self._leafs = OrderedDict()

                                            self.context_word = YList(self)
                                            self._segment_path = lambda: "context"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp.Context, [], name, value)


                                        class ContextWord(Entity):
                                            """
                                            
                                            
                                            .. attribute:: context_word  (key)
                                            
                                            	Context Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp.Context.ContextWord, self).__init__()

                                                self.yang_name = "context_word"
                                                self.yang_parent_name = "context"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['context_word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                ])
                                                self.context_word = None
                                                self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Flowspec.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class Ipv4Mvpn(Entity):
                                """
                                IPv4 MVPN VRF address family
                                
                                .. attribute:: bgp
                                
                                	
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn, self).__init__()

                                    self.yang_name = "ipv4-mvpn"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_))])
                                    self._leafs = OrderedDict()

                                    self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"
                                    self._segment_path = lambda: "ipv4-mvpn"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn, [], name, value)


                                class Bgp_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: dampening
                                    
                                    	Enable route\-flap dampening
                                    	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_.Dampening>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "ipv4-mvpn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampening", ("dampening", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_.Dampening))])
                                        self._leafs = OrderedDict()

                                        self.dampening = None
                                        self._children_name_map["dampening"] = "dampening"
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_, [], name, value)


                                    class Dampening(Entity):
                                        """
                                        Enable route\-flap dampening
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria for dampening
                                        	**type**\: str
                                        
                                        .. attribute:: dampen
                                        
                                        	
                                        	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_.Dampening.Dampen>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_.Dampening.Dampen))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.dampen = Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_.Dampening.Dampen()
                                            self.dampen.parent = self
                                            self._children_name_map["dampen"] = "dampen"
                                            self._segment_path = lambda: "dampening"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_.Dampening, ['route_map'], name, value)


                                        class Dampen(Entity):
                                            """
                                            
                                            
                                            .. attribute:: half_life_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..45
                                            
                                            .. attribute:: reuse_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: max_suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_.Dampening.Dampen, self).__init__()

                                                self.yang_name = "dampen"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                    ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                    ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                    ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                ])
                                                self.half_life_time = None
                                                self.reuse_time = None
                                                self.suppress_time = None
                                                self.max_suppress_time = None
                                                self._segment_path = lambda: "dampen"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv4.Vrf.Ipv4Mvpn.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                    class Ipv6(Entity):
                        """
                        Address family
                        
                        .. attribute:: af_name  (key)
                        
                        	
                        	**type**\:  :py:class:`BgpIpv6AfType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.BgpIpv6AfType>`
                        
                        .. attribute:: vrf
                        
                        	
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "with-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'BgpIpv6AfType', '')])),
                            ])
                            self.af_name = None

                            self.vrf = YList(self)
                            self._segment_path = lambda: "ipv6" + "[af-name='" + str(self.af_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6, ['af_name'], name, value)


                        class Vrf(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ipv6_unicast
                            
                            	IPv6 Unicast VRF address family
                            	**type**\:  :py:class:`Ipv6Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast>`
                            
                            .. attribute:: ipv6_multicast
                            
                            	IPv6 Multicast VRF address family
                            	**type**\:  :py:class:`Ipv6Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast>`
                            
                            .. attribute:: ipv6_flowspec
                            
                            	IPv6 Flowspec VRF address family
                            	**type**\:  :py:class:`Ipv6Flowspec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec>`
                            
                            .. attribute:: ipv6_mvpn
                            
                            	IPv6 Unicast VRF address family
                            	**type**\:  :py:class:`Ipv6Mvpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn>`
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("ipv6-unicast", ("ipv6_unicast", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast)), ("ipv6-multicast", ("ipv6_multicast", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast)), ("ipv6-flowspec", ("ipv6_flowspec", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec)), ("ipv6-mvpn", ("ipv6_mvpn", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.ipv6_unicast = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast()
                                self.ipv6_unicast.parent = self
                                self._children_name_map["ipv6_unicast"] = "ipv6-unicast"

                                self.ipv6_multicast = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast()
                                self.ipv6_multicast.parent = self
                                self._children_name_map["ipv6_multicast"] = "ipv6-multicast"

                                self.ipv6_flowspec = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec()
                                self.ipv6_flowspec.parent = self
                                self._children_name_map["ipv6_flowspec"] = "ipv6-flowspec"

                                self.ipv6_mvpn = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn()
                                self.ipv6_mvpn.parent = self
                                self._children_name_map["ipv6_mvpn"] = "ipv6-mvpn"
                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf, ['name'], name, value)


                            class Ipv6Unicast(Entity):
                                """
                                IPv6 Unicast VRF address family
                                
                                .. attribute:: advertise
                                
                                	Configure path advertise/export to other address\-family
                                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Advertise>`
                                
                                .. attribute:: aggregate_address
                                
                                	Configure BGP aggregate entries
                                	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.AggregateAddress>`
                                
                                .. attribute:: bgp
                                
                                	
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_>`
                                
                                .. attribute:: default_information
                                
                                	Control distribution of default information
                                	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.DefaultInformation>`
                                
                                .. attribute:: default_metric
                                
                                	Set metric of redistributed routes
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: distance
                                
                                	Define an administrative distance
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance>`
                                
                                .. attribute:: import_
                                
                                	Configure path import
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import>`
                                
                                .. attribute:: maximum_paths
                                
                                	Forward packets over multiple paths
                                	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths>`
                                
                                .. attribute:: peer_group
                                
                                	
                                	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup>`
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor>`
                                
                                .. attribute:: network
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Network>`
                                
                                .. attribute:: redistribute
                                
                                	Redistribute information from another routing protocol
                                	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute>`
                                
                                .. attribute:: snmp
                                
                                	Modify snmp parameters
                                	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: synchronization
                                
                                	Perform IGP synchronization
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: table_map
                                
                                	Map external entry attributes into routing table
                                	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.TableMap>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast, self).__init__()

                                    self.yang_name = "ipv6-unicast"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Advertise)), ("aggregate-address", ("aggregate_address", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance)), ("import", ("import_", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp)), ("table-map", ("table_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.TableMap))])
                                    self._leafs = OrderedDict([
                                        ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                        ('synchronization', (YLeaf(YType.empty, 'synchronization'), ['Empty'])),
                                    ])
                                    self.default_metric = None
                                    self.synchronization = None

                                    self.advertise = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Advertise()
                                    self.advertise.parent = self
                                    self._children_name_map["advertise"] = "advertise"

                                    self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.default_information = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.DefaultInformation()
                                    self.default_information.parent = self
                                    self._children_name_map["default_information"] = "default-information"

                                    self.distance = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.import_ = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.maximum_paths = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths()
                                    self.maximum_paths.parent = self
                                    self._children_name_map["maximum_paths"] = "maximum-paths"

                                    self.peer_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup()
                                    self.peer_group.parent = self
                                    self._children_name_map["peer_group"] = "peer-group"

                                    self.redistribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute()
                                    self.redistribute.parent = self
                                    self._children_name_map["redistribute"] = "redistribute"

                                    self.snmp = None
                                    self._children_name_map["snmp"] = "snmp"

                                    self.table_map = None
                                    self._children_name_map["table_map"] = "table-map"

                                    self.aggregate_address = YList(self)
                                    self.neighbor = YList(self)
                                    self.network = YList(self)
                                    self._segment_path = lambda: "ipv6-unicast"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast, ['default_metric', 'synchronization'], name, value)


                                class Advertise(Entity):
                                    """
                                    Configure path advertise/export to other address\-family
                                    
                                    .. attribute:: l2vpn
                                    
                                    	Address family for VRF advertise/export
                                    	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Advertise.L2vpn>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Advertise, self).__init__()

                                        self.yang_name = "advertise"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn", ("l2vpn", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Advertise.L2vpn))])
                                        self._leafs = OrderedDict()

                                        self.l2vpn = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Advertise.L2vpn()
                                        self.l2vpn.parent = self
                                        self._children_name_map["l2vpn"] = "l2vpn"
                                        self._segment_path = lambda: "advertise"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Advertise, [], name, value)


                                    class L2vpn(Entity):
                                        """
                                        Address family for VRF advertise/export
                                        
                                        .. attribute:: evpn
                                        
                                        	Advertise/export prefixes to l2vpn evpn table
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Advertise.L2vpn, self).__init__()

                                            self.yang_name = "l2vpn"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                            ])
                                            self.evpn = None
                                            self._segment_path = lambda: "l2vpn"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Advertise.L2vpn, ['evpn'], name, value)


                                class AggregateAddress(Entity):
                                    """
                                    Configure BGP aggregate entries
                                    
                                    .. attribute:: ipv6_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: advertise_map
                                    
                                    	Set condition to advertise attribute
                                    	**type**\: str
                                    
                                    .. attribute:: as_set
                                    
                                    	Generate AS set path information
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attribute_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: as_override
                                    
                                    	Override matching AS\-number while sending update
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: summary_only
                                    
                                    	Filter more specific routes from updates
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: suppress_map
                                    
                                    	Conditionally filter more specific routes from updates
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.AggregateAddress, self).__init__()

                                        self.yang_name = "aggregate-address"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ipv6_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                            ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                            ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                            ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                            ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                        ])
                                        self.ipv6_address = None
                                        self.advertise_map = None
                                        self.as_set = None
                                        self.attribute_map = None
                                        self.as_override = None
                                        self.route_map = None
                                        self.summary_only = None
                                        self.suppress_map = None
                                        self._segment_path = lambda: "aggregate-address" + "[ipv6-address='" + str(self.ipv6_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.AggregateAddress, ['ipv6_address', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                                class Bgp_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: additional_paths
                                    
                                    	Additional paths in the BGP table
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths>`
                                    
                                    .. attribute:: advertise_best_external
                                    
                                    	Advertise best external path to internal peers
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Configure aggregation timer
                                    	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AggregateTimer>`
                                    
                                    .. attribute:: bestpath
                                    
                                    	Change the default bestpath selection
                                    	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath>`
                                    
                                    .. attribute:: dampening
                                    
                                    	Enable route\-flap dampening
                                    	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Dampening>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: recursion
                                    
                                    	recursion rule for the nexthops
                                    	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Recursion>`
                                    
                                    .. attribute:: redistribute_internal
                                    
                                    	Allow redistribution of iBGP into IGPs (dangerous)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	bgp route\-map commands
                                    	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouteMap>`
                                    
                                    .. attribute:: router_id
                                    
                                    	Override configured router identifier (peers will reset)
                                    	**type**\:  :py:class:`RouterId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer>`
                                    
                                    .. attribute:: suppress_inactive
                                    
                                    	Suppress routes that are not in the routing table
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Dampening)), ("recursion", ("recursion", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouteMap)), ("router-id", ("router_id", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                            ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                            ('suppress_inactive', (YLeaf(YType.empty, 'suppress-inactive'), ['Empty'])),
                                        ])
                                        self.advertise_best_external = None
                                        self.redistribute_internal = None
                                        self.suppress_inactive = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.aggregate_timer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AggregateTimer()
                                        self.aggregate_timer.parent = self
                                        self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                        self.bestpath = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath()
                                        self.bestpath.parent = self
                                        self._children_name_map["bestpath"] = "bestpath"

                                        self.dampening = None
                                        self._children_name_map["dampening"] = "dampening"

                                        self.recursion = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Recursion()
                                        self.recursion.parent = self
                                        self._children_name_map["recursion"] = "recursion"

                                        self.route_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouteMap()
                                        self.route_map.parent = self
                                        self._children_name_map["route_map"] = "route-map"

                                        self.router_id = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId()
                                        self.router_id.parent = self
                                        self._children_name_map["router_id"] = "router-id"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_, ['advertise_best_external', 'redistribute_internal', 'suppress_inactive'], name, value)


                                    class AdditionalPaths(Entity):
                                        """
                                        Additional paths in the BGP table
                                        
                                        .. attribute:: install
                                        
                                        	Additional paths to install into RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: select
                                        
                                        	Selection criteria to pick the paths
                                        	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select>`
                                        
                                        .. attribute:: send
                                        
                                        	Send additional paths to neighbors
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Send>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Send))])
                                            self._leafs = OrderedDict([
                                                ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.install = None
                                            self.receive = None

                                            self.select = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select()
                                            self.select.parent = self
                                            self._children_name_map["select"] = "select"

                                            self.send = None
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                        class Select(Entity):
                                            """
                                            Selection criteria to pick the paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: backup
                                            
                                            	Select backup path
                                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Select best\-external path
                                            	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best path
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                self.yang_name = "select"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"

                                                self.backup = None
                                                self._children_name_map["backup"] = "backup"

                                                self.best = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.best_external = None
                                                self._children_name_map["best_external"] = "best-external"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "select"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                            class All(Entity):
                                                """
                                                Select all available paths
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.best = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.group_best = None
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                            class Backup(Entity):
                                                """
                                                Select backup path
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                    self.yang_name = "backup"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None
                                                    self._segment_path = lambda: "backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.all = None

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.all = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                            class BestExternal(Entity):
                                                """
                                                Select best\-external path
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                    self.yang_name = "best-external"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                    ])
                                                    self.backup = None
                                                    self._segment_path = lambda: "best-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best path
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.all = None
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                        class Send(Entity):
                                            """
                                            Send additional paths to neighbors
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.receive = None
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                    class AggregateTimer(Entity):
                                        """
                                        Configure aggregation timer
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Timer interval
                                        	**type**\: int
                                        
                                        	**range:** 6..60
                                        
                                        .. attribute:: disable_timer
                                        
                                        	Timer interval
                                        	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AggregateTimer, self).__init__()

                                            self.yang_name = "aggregate-timer"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                            ])
                                            self.aggregate_timer = None
                                            self.disable_timer = None
                                            self._segment_path = lambda: "aggregate-timer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                        class DisableTimer(Enum):
                                            """
                                            DisableTimer (Enum Class)

                                            Timer interval

                                            .. data:: Y_0 = 0

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")



                                    class Bestpath(Entity):
                                        """
                                        Change the default bestpath selection
                                        
                                        .. attribute:: igp_metric
                                        
                                        	igp metric
                                        	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath.IgpMetric>`
                                        
                                        .. attribute:: prefix_validate
                                        
                                        	Prefix origin validation
                                        	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath, self).__init__()

                                            self.yang_name = "bestpath"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate))])
                                            self._leafs = OrderedDict()

                                            self.igp_metric = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath.IgpMetric()
                                            self.igp_metric.parent = self
                                            self._children_name_map["igp_metric"] = "igp-metric"

                                            self.prefix_validate = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate()
                                            self.prefix_validate.parent = self
                                            self._children_name_map["prefix_validate"] = "prefix-validate"
                                            self._segment_path = lambda: "bestpath"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath, [], name, value)


                                        class IgpMetric(Entity):
                                            """
                                            igp metric
                                            
                                            .. attribute:: ignore
                                            
                                            	Ignore igp metric in bestpath selection
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                                self.yang_name = "igp-metric"
                                                self.yang_parent_name = "bestpath"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                ])
                                                self.ignore = None
                                                self._segment_path = lambda: "igp-metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                        class PrefixValidate(Entity):
                                            """
                                            Prefix origin validation
                                            
                                            .. attribute:: allow_invalid
                                            
                                            	Allow invalid routes to be considered for bestpath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: disable
                                            
                                            	Disable prefix validation
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                                self.yang_name = "prefix-validate"
                                                self.yang_parent_name = "bestpath"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.allow_invalid = None
                                                self.disable = None
                                                self._segment_path = lambda: "prefix-validate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                    class Dampening(Entity):
                                        """
                                        Enable route\-flap dampening
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria for dampening
                                        	**type**\: str
                                        
                                        .. attribute:: dampen
                                        
                                        	
                                        	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Dampening.Dampen>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Dampening.Dampen))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.dampen = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Dampening.Dampen()
                                            self.dampen.parent = self
                                            self._children_name_map["dampen"] = "dampen"
                                            self._segment_path = lambda: "dampening"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                        class Dampen(Entity):
                                            """
                                            
                                            
                                            .. attribute:: half_life_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..45
                                            
                                            .. attribute:: reuse_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: max_suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                                self.yang_name = "dampen"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                    ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                    ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                    ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                ])
                                                self.half_life_time = None
                                                self.reuse_time = None
                                                self.suppress_time = None
                                                self.max_suppress_time = None
                                                self._segment_path = lambda: "dampen"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                    class Recursion(Entity):
                                        """
                                        recursion rule for the nexthops
                                        
                                        .. attribute:: host
                                        
                                        	recursion via host for the nexthops
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Recursion, self).__init__()

                                            self.yang_name = "recursion"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                            ])
                                            self.host = None
                                            self._segment_path = lambda: "recursion"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.Recursion, ['host'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        bgp route\-map commands
                                        
                                        .. attribute:: priority
                                        
                                        	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                            ])
                                            self.priority = None
                                            self._segment_path = lambda: "route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                    class RouterId(Entity):
                                        """
                                        Override configured router identifier (peers will reset)
                                        
                                        .. attribute:: ip_id
                                        
                                        	Manually configured router identifier
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: interface
                                        
                                        	Use IPv4 address on interface
                                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface>`
                                        
                                        .. attribute:: vrf
                                        
                                        	vrf\-specific router id configuration
                                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Vrf_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId, self).__init__()

                                            self.yang_name = "router-id"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface))])
                                            self._leafs = OrderedDict([
                                                ('ip_id', (YLeaf(YType.str, 'ip-id'), ['str'])),
                                                ('vrf', (YLeaf(YType.enumeration, 'vrf'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Vrf_')])),
                                            ])
                                            self.ip_id = None
                                            self.vrf = None

                                            self.interface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface()
                                            self.interface.parent = self
                                            self._children_name_map["interface"] = "interface"
                                            self._segment_path = lambda: "router-id"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId, ['ip_id', 'vrf'], name, value)

                                        class Vrf_(Enum):
                                            """
                                            Vrf\_ (Enum Class)

                                            vrf\-specific router id configuration

                                            .. data:: auto_assign = 0

                                            """

                                            auto_assign = Enum.YLeaf(0, "auto-assign")



                                        class Interface(Entity):
                                            """
                                            Use IPv4 address on interface
                                            
                                            .. attribute:: appnav_compress
                                            
                                            	Service\-Context Virtual Interface Compress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: appnav_uncompress
                                            
                                            	Service\-Context Virtual Interface UnCompress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm
                                            
                                            	ATM interface
                                            	**type**\: str
                                            
                                            .. attribute:: atm_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.ATMSubinterface>`
                                            
                                            .. attribute:: atm_acr
                                            
                                            	ATM\-ACR interface
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]
                                            
                                            .. attribute:: atm_acrsubinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.ATMACRsubinterface>`
                                            
                                            .. attribute:: bdi
                                            
                                            	Bridge\-Domain interface
                                            	**type**\: str
                                            
                                            .. attribute:: cem
                                            
                                            	CEM interface
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9]/){2}[0\-9]
                                            
                                            .. attribute:: cem_acr
                                            
                                            	CEM\-ACR interface
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: embedded_service_engine
                                            
                                            	cisco embedded service engine module
                                            	**type**\: str
                                            
                                            .. attribute:: ethernet
                                            
                                            	IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: fastethernet
                                            
                                            	FastEthernet IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: gigabitethernet
                                            
                                            	GigabitEthernet IEEE 802.3z
                                            	**type**\: str
                                            
                                            .. attribute:: fivegigabitethernet
                                            
                                            	Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twentyfivegige
                                            
                                            	Twenty Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twogigabitethernet
                                            
                                            	Two GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: fortygigabitethernet
                                            
                                            	Forty GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: hundredgige
                                            
                                            	Hundred GigabitEthernet
                                            	**type**\: str
                                            
                                            .. attribute:: lisp
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_subinterface
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.LISPSubinterface>`
                                            
                                            .. attribute:: loopback
                                            
                                            	Loopback interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multilink
                                            
                                            	Multilink\-group interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: nve
                                            
                                            	Network virtualization endpoint interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: overlay
                                            
                                            	Overlay interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: port_channel
                                            
                                            	Ethernet Channel of interfaces
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: port_channel_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.PortChannelSubinterface>`
                                            
                                            .. attribute:: pseudowire
                                            
                                            	Pseudowire Interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sm
                                            
                                            	SM Interface
                                            	**type**\: str
                                            
                                            .. attribute:: cellular
                                            
                                            	Cellular Interface
                                            	**type**\: str
                                            
                                            .. attribute:: serial
                                            
                                            	Serial interface
                                            	**type**\: str
                                            
                                            .. attribute:: tengigabitethernet
                                            
                                            	Ten Gigabit Ethernet
                                            	**type**\: str
                                            
                                            .. attribute:: tunnel
                                            
                                            	Tunnel interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_template
                                            
                                            	Virtual Template interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vlan
                                            
                                            	Iosxr Vlans
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: virtualportgroup
                                            
                                            	Virtual Port Group
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasileft
                                            
                                            	vasileft
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasiright
                                            
                                            	vasiright
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "router-id"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.PortChannelSubinterface))])
                                                self._leafs = OrderedDict([
                                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                                ])
                                                self.appnav_compress = None
                                                self.appnav_uncompress = None
                                                self.atm = None
                                                self.atm_acr = None
                                                self.bdi = None
                                                self.cem = None
                                                self.cem_acr = None
                                                self.embedded_service_engine = None
                                                self.ethernet = None
                                                self.fastethernet = None
                                                self.gigabitethernet = None
                                                self.fivegigabitethernet = None
                                                self.twentyfivegige = None
                                                self.twogigabitethernet = None
                                                self.fortygigabitethernet = None
                                                self.hundredgige = None
                                                self.lisp = None
                                                self.loopback = None
                                                self.multilink = None
                                                self.nve = None
                                                self.overlay = None
                                                self.port_channel = None
                                                self.pseudowire = None
                                                self.sm = None
                                                self.cellular = None
                                                self.serial = None
                                                self.tengigabitethernet = None
                                                self.tunnel = None
                                                self.virtual_template = None
                                                self.vlan = None
                                                self.virtualportgroup = None
                                                self.vasileft = None
                                                self.vasiright = None

                                                self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.ATMSubinterface()
                                                self.atm_subinterface.parent = self
                                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                                self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.ATMACRsubinterface()
                                                self.atm_acrsubinterface.parent = self
                                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                                self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.LISPSubinterface()
                                                self.lisp_subinterface.parent = self
                                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                                self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.PortChannelSubinterface()
                                                self.port_channel_subinterface.parent = self
                                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                                self._segment_path = lambda: "interface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                            class ATMSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.ATMSubinterface, self).__init__()

                                                    self.yang_name = "ATM-subinterface"
                                                    self.yang_parent_name = "interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ])
                                                    self.atm = None
                                                    self._segment_path = lambda: "ATM-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.ATMSubinterface, [u'atm'], name, value)


                                            class ATMACRsubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm_acr
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.ATMACRsubinterface, self).__init__()

                                                    self.yang_name = "ATM-ACRsubinterface"
                                                    self.yang_parent_name = "interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ])
                                                    self.atm_acr = None
                                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                            class LISPSubinterface(Entity):
                                                """
                                                Locator/ID Separation Protocol Virtual Interface
                                                
                                                .. attribute:: lisp
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.LISPSubinterface, self).__init__()

                                                    self.yang_name = "LISP-subinterface"
                                                    self.yang_parent_name = "interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ])
                                                    self.lisp = None
                                                    self._segment_path = lambda: "LISP-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.LISPSubinterface, [u'lisp'], name, value)


                                            class PortChannelSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: port_channel
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.PortChannelSubinterface, self).__init__()

                                                    self.yang_name = "Port-channel-subinterface"
                                                    self.yang_parent_name = "interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                    ])
                                                    self.port_channel = None
                                                    self._segment_path = lambda: "Port-channel-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.RouterId.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: disable
                                            
                                            	Disable slow\-peer detection
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.disable = None
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class DefaultInformation(Entity):
                                    """
                                    Control distribution of default information
                                    
                                    .. attribute:: originate
                                    
                                    	Distribute a default route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.DefaultInformation, self).__init__()

                                        self.yang_name = "default-information"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                        ])
                                        self.originate = None
                                        self._segment_path = lambda: "default-information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.DefaultInformation, ['originate'], name, value)


                                class Distance(Entity):
                                    """
                                    Define an administrative distance
                                    
                                    .. attribute:: bgp
                                    
                                    	BGP distance
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance.Bgp_>`
                                    
                                    .. attribute:: adm_distance
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance.AdmDistance>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance.AdmDistance))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.adm_distance = YList(self)
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        BGP distance
                                        
                                        .. attribute:: extern_as
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: internal_as
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: local
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "distance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                                ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                                ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                            ])
                                            self.extern_as = None
                                            self.internal_as = None
                                            self.local = None
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                    class AdmDistance(Entity):
                                        """
                                        
                                        
                                        .. attribute:: distance  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: srcip  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: wildbits  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: acl
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..99
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..1999
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance.AdmDistance, self).__init__()

                                            self.yang_name = "adm-distance"
                                            self.yang_parent_name = "distance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['distance','srcip','wildbits']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                                ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                                ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                                ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                            ])
                                            self.distance = None
                                            self.srcip = None
                                            self.wildbits = None
                                            self.acl = None
                                            self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                                class Import(Entity):
                                    """
                                    Configure path import
                                    
                                    .. attribute:: path
                                    
                                    	Path selection and path limit
                                    	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Path>`
                                    
                                    .. attribute:: vpnv4
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Vpnv4>`
                                    
                                    .. attribute:: vpnv6
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Vpnv6>`
                                    
                                    .. attribute:: l2vpn
                                    
                                    	Configure EVPN to VPN path import
                                    	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.L2vpn>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Path)), ("vpnv4", ("vpnv4", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Vpnv4)), ("vpnv6", ("vpnv6", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Vpnv6)), ("l2vpn", ("l2vpn", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.L2vpn))])
                                        self._leafs = OrderedDict()

                                        self.path = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Path()
                                        self.path.parent = self
                                        self._children_name_map["path"] = "path"

                                        self.vpnv4 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Vpnv4()
                                        self.vpnv4.parent = self
                                        self._children_name_map["vpnv4"] = "vpnv4"

                                        self.vpnv6 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Vpnv6()
                                        self.vpnv6.parent = self
                                        self._children_name_map["vpnv6"] = "vpnv6"

                                        self.l2vpn = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.L2vpn()
                                        self.l2vpn.parent = self
                                        self._children_name_map["l2vpn"] = "l2vpn"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import, [], name, value)


                                    class Path(Entity):
                                        """
                                        Path selection and path limit
                                        
                                        .. attribute:: limit
                                        
                                        	Per net imported path limit
                                        	**type**\: int
                                        
                                        	**range:** 2..255
                                        
                                        .. attribute:: selection
                                        
                                        	Path selection policy
                                        	**type**\:  :py:class:`Selection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Path.Selection>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("selection", ("selection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Path.Selection))])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                                            ])
                                            self.limit = None

                                            self.selection = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Path.Selection()
                                            self.selection.parent = self
                                            self._children_name_map["selection"] = "selection"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Path, ['limit'], name, value)


                                        class Selection(Entity):
                                            """
                                            Path selection policy
                                            
                                            .. attribute:: all
                                            
                                            	Import all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Path.Selection, self).__init__()

                                                self.yang_name = "selection"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "selection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Path.Selection, ['all'], name, value)


                                    class Vpnv4(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Vpnv4, self).__init__()

                                            self.yang_name = "vpnv4"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv4"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Vpnv4, ['unicast', 're_originate'], name, value)


                                    class Vpnv6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	Imported path with RT re\-originate
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Vpnv6, self).__init__()

                                            self.yang_name = "vpnv6"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.Vpnv6, ['unicast', 're_originate'], name, value)


                                    class L2vpn(Entity):
                                        """
                                        Configure EVPN to VPN path import
                                        
                                        .. attribute:: evpn
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.L2vpn, self).__init__()

                                            self.yang_name = "l2vpn"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.evpn = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "l2vpn"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Import.L2vpn, ['evpn', 're_originate'], name, value)


                                class MaximumPaths(Entity):
                                    """
                                    Forward packets over multiple paths
                                    
                                    .. attribute:: ebgp
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: eibgp
                                    
                                    	Both eBGP and iBGP paths as multipath
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: ibgp
                                    
                                    	iBGP\-multipath
                                    	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths.Ibgp>`
                                    
                                    .. attribute:: external_rtfilter
                                    
                                    	VPN prefix multipath on external RT\-Filter peers
                                    	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths.ExternalRtfilter>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths, self).__init__()

                                        self.yang_name = "maximum-paths"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths.ExternalRtfilter))])
                                        self._leafs = OrderedDict([
                                            ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                            ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                        ])
                                        self.ebgp = None
                                        self.eibgp = None

                                        self.ibgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths.Ibgp()
                                        self.ibgp.parent = self
                                        self._children_name_map["ibgp"] = "ibgp"

                                        self.external_rtfilter = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths.ExternalRtfilter()
                                        self.external_rtfilter.parent = self
                                        self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                        self._segment_path = lambda: "maximum-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                    class Ibgp(Entity):
                                        """
                                        iBGP\-multipath
                                        
                                        .. attribute:: unequal_cost
                                        
                                        	Perform un\-equal cost multipath selection
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: max
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths.Ibgp, self).__init__()

                                            self.yang_name = "ibgp"
                                            self.yang_parent_name = "maximum-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                            ])
                                            self.unequal_cost = None
                                            self.max = None
                                            self._segment_path = lambda: "ibgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                    class ExternalRtfilter(Entity):
                                        """
                                        VPN prefix multipath on external RT\-Filter peers
                                        
                                        .. attribute:: max
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                            self.yang_name = "external-rtfilter"
                                            self.yang_parent_name = "maximum-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                            ])
                                            self.max = None
                                            self._segment_path = lambda: "external-rtfilter"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                class PeerGroup(Entity):
                                    """
                                    
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup, self).__init__()

                                        self.yang_name = "peer-group"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor))])
                                        self._leafs = OrderedDict()

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "peer-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: peer_group
                                        
                                        	Member of the peer\-group
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_map
                                        
                                        	specify route\-map for conditional advertisement
                                        	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable a AIGP on neighbor
                                        	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: announce
                                        
                                        	Announce RPKI state using an extended community
                                        	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Announce>`
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AsOverride>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability>`
                                        
                                        .. attribute:: cluster_id
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: description
                                        
                                        	Neighbor specific description
                                        	**type**\: str
                                        
                                        .. attribute:: disable_connected_check
                                        
                                        	one\-hop away EBGP peer using loopback address
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ebgp_multihop
                                        
                                        	Allow EBGP neighbors not on directly connected networks
                                        	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.EbgpMultihop>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: fall_over
                                        
                                        	session fall on peer route lost
                                        	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FallOver>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FilterList>`
                                        
                                        .. attribute:: ha_mode
                                        
                                        	high availability mode
                                        	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Inherit>`
                                        
                                        .. attribute:: local_as
                                        
                                        	Specify a local\-as number
                                        	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.LocalAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: log_neighbor_changes
                                        
                                        	Log neighbor up/down and reset reason
                                        	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.LogNeighborChanges>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: password
                                        
                                        	Set a password
                                        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Password>`
                                        
                                        .. attribute:: path_attribute
                                        
                                        	BGP optional attribute filtering
                                        	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remote_as
                                        
                                        	Specify a BGP peer\-group remote\-as
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: send_label
                                        
                                        	Send NLRI + MPLS Label to this peer
                                        	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendLabel>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: shutdown
                                        
                                        	Administratively shut down this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: timers
                                        
                                        	BGP per neighbor timers
                                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Timers>`
                                        
                                        .. attribute:: translate_update
                                        
                                        	Translate update to MBGP format
                                        	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate>`
                                        
                                        .. attribute:: transport
                                        
                                        	Transport options
                                        	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Transport>`
                                        
                                        .. attribute:: ttl_security
                                        
                                        	BGP ttl security check
                                        	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TtlSecurity>`
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: update_source
                                        
                                        	Source of routing updates
                                        	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource>`
                                        
                                        .. attribute:: version
                                        
                                        	Set the BGP version to match a neighbor
                                        	**type**\: int
                                        
                                        	**range:** 4..None
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "peer-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FallOver)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FilterList)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Timers)), ("translate-update", ("translate_update", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ('peer_group', (YLeaf(YType.empty, 'peer-group'), ['Empty'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.peer_group = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.cluster_id = None
                                            self.description = None
                                            self.disable_connected_check = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.remote_as = None
                                            self.route_reflector_client = None
                                            self.shutdown = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.version = None
                                            self.weight = None

                                            self.advertise_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap()
                                            self.advertise_map.parent = self
                                            self._children_name_map["advertise_map"] = "advertise-map"

                                            self.aigp = None
                                            self._children_name_map["aigp"] = "aigp"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.announce = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Announce()
                                            self.announce.parent = self
                                            self._children_name_map["announce"] = "announce"

                                            self.as_override = None
                                            self._children_name_map["as_override"] = "as-override"

                                            self.capability = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.ebgp_multihop = None
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                            self.fall_over = None
                                            self._children_name_map["fall_over"] = "fall-over"

                                            self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode()
                                            self.ha_mode.parent = self
                                            self._children_name_map["ha_mode"] = "ha-mode"

                                            self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.local_as = None
                                            self._children_name_map["local_as"] = "local-as"

                                            self.log_neighbor_changes = None
                                            self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                            self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"

                                            self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute()
                                            self.path_attribute.parent = self
                                            self._children_name_map["path_attribute"] = "path-attribute"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.send_label = None
                                            self._children_name_map["send_label"] = "send-label"

                                            self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"

                                            self.translate_update = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate()
                                            self.translate_update.parent = self
                                            self._children_name_map["translate_update"] = "translate-update"

                                            self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Transport()
                                            self.transport.parent = self
                                            self._children_name_map["transport"] = "transport"

                                            self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TtlSecurity()
                                            self.ttl_security.parent = self
                                            self._children_name_map["ttl_security"] = "ttl-security"

                                            self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource()
                                            self.update_source.parent = self
                                            self._children_name_map["update_source"] = "update-source"

                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor, ['id', 'peer_group', 'activate', 'advertisement_interval', 'allow_policy', 'cluster_id', 'description', 'disable_connected_check', 'dmzlink_bw', 'next_hop_unchanged', 'remote_as', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'version', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AdvertiseMap(Entity):
                                            """
                                            specify route\-map for conditional advertisement
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap, self).__init__()

                                                self.yang_name = "advertise-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name))])
                                                self._leafs = OrderedDict()

                                                self.name = YList(self)
                                                self._segment_path = lambda: "advertise-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap, [], name, value)


                                            class Name(Entity):
                                                """
                                                
                                                
                                                .. attribute:: word  (key)
                                                
                                                	advertise route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: non_exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, self).__init__()

                                                    self.yang_name = "name"
                                                    self.yang_parent_name = "advertise-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                        ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                        ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                    ])
                                                    self.word = None
                                                    self.exist_map = None
                                                    self.non_exist_map = None
                                                    self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                        class Aigp(Entity):
                                            """
                                            Enable a AIGP on neighbor
                                            
                                            .. attribute:: send
                                            
                                            	Cost community or MED carrying AIGP VALUE
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                                self.yang_name = "aigp"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.send = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send()
                                                self.send.parent = self
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "aigp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                            class Send(Entity):
                                                """
                                                Cost community or MED carrying AIGP VALUE
                                                
                                                .. attribute:: cost_community
                                                
                                                	Cost extended community carrying AIGP Value
                                                	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                                
                                                .. attribute:: med
                                                
                                                	Med carrying AIGP Value
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "aigp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                    ])
                                                    self.med = None

                                                    self.cost_community = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                    self.cost_community.parent = self
                                                    self._children_name_map["cost_community"] = "cost-community"
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                                class CostCommunity(Entity):
                                                    """
                                                    Cost extended community carrying AIGP Value
                                                    
                                                    .. attribute:: cc_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                        self.yang_name = "cost-community"
                                                        self.yang_parent_name = "send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                        self._leafs = OrderedDict()

                                                        self.cc_range = YList(self)
                                                        self._segment_path = lambda: "cost-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                    class CcRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Community ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: poi
                                                        
                                                        	Point of insertion
                                                        	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                            self.yang_name = "cc-range"
                                                            self.yang_parent_name = "cost-community"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ])
                                                            self.range = None

                                                            self.poi = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                            self.poi.parent = self
                                                            self._children_name_map["poi"] = "poi"
                                                            self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                        class Poi(Entity):
                                                            """
                                                            Point of insertion
                                                            
                                                            .. attribute:: igp_cost
                                                            
                                                            	Point of insertion after IGP
                                                            	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            .. attribute:: pre_bestpath
                                                            
                                                            	Point of insertion at beginning
                                                            	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                self.yang_name = "poi"
                                                                self.yang_parent_name = "cc-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                self._leafs = OrderedDict()

                                                                self.igp_cost = None
                                                                self._children_name_map["igp_cost"] = "igp-cost"

                                                                self.pre_bestpath = None
                                                                self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                self._segment_path = lambda: "poi"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                            class IgpCost(Entity):
                                                                """
                                                                Point of insertion after IGP
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                    self.yang_name = "igp-cost"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "igp-cost"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                            class PreBestpath(Entity):
                                                                """
                                                                Point of insertion at beginning
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                    self.yang_name = "pre-bestpath"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "pre-bestpath"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Announce(Entity):
                                            """
                                            Announce RPKI state using an extended community
                                            
                                            .. attribute:: rpki
                                            
                                            	Announce RPKI information using an extended community
                                            	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Announce, self).__init__()

                                                self.yang_name = "announce"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki))])
                                                self._leafs = OrderedDict()

                                                self.rpki = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki()
                                                self.rpki.parent = self
                                                self._children_name_map["rpki"] = "rpki"
                                                self._segment_path = lambda: "announce"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Announce, [], name, value)


                                            class Rpki(Entity):
                                                """
                                                Announce RPKI information using an extended community
                                                
                                                .. attribute:: state
                                                
                                                	Announce RPKI state information using an extended community
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki, self).__init__()

                                                    self.yang_name = "rpki"
                                                    self.yang_parent_name = "announce"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                    ])
                                                    self.state = None
                                                    self._segment_path = lambda: "rpki"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki, ['state'], name, value)


                                        class AsOverride(Entity):
                                            """
                                            Override matching AS\-number while sending update
                                            
                                            .. attribute:: disable
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AsOverride, self).__init__()

                                                self.yang_name = "as-override"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "as-override"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.AsOverride, ['disable'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class EbgpMultihop(Entity):
                                            """
                                            Allow EBGP neighbors not on directly connected networks
                                            
                                            .. attribute:: max_hop
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.EbgpMultihop, self).__init__()

                                                self.yang_name = "ebgp-multihop"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                                ])
                                                self.max_hop = None
                                                self._segment_path = lambda: "ebgp-multihop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                        class FallOver(Entity):
                                            """
                                            session fall on peer route lost
                                            
                                            .. attribute:: bfd
                                            
                                            	Use BFD to detect failure
                                            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FallOver.Bfd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FallOver, self).__init__()

                                                self.yang_name = "fall-over"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FallOver.Bfd))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.route_map_name = None

                                                self.bfd = None
                                                self._children_name_map["bfd"] = "bfd"
                                                self._segment_path = lambda: "fall-over"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FallOver, ['route_map_name'], name, value)


                                            class Bfd(Entity):
                                                """
                                                Use BFD to detect failure
                                                
                                                .. attribute:: multi_hop
                                                
                                                	Force BFD multi\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: single_hop
                                                
                                                	Force BFD single\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: check_control_plane_failure
                                                
                                                	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: strict_mode
                                                
                                                	Enable BFD strict\-mode
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FallOver.Bfd, self).__init__()

                                                    self.yang_name = "bfd"
                                                    self.yang_parent_name = "fall-over"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                        ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                        ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                        ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                    ])
                                                    self.multi_hop = None
                                                    self.single_hop = None
                                                    self.check_control_plane_failure = None
                                                    self.strict_mode = None
                                                    self._segment_path = lambda: "bfd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class HaMode(Entity):
                                            """
                                            high availability mode
                                            
                                            .. attribute:: graceful_restart
                                            
                                            	graceful\-restart for this peer
                                            	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode.GracefulRestart>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: sso
                                            
                                            	stateful\-switchover support for this peer
                                            	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode.Sso>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode, self).__init__()

                                                self.yang_name = "ha-mode"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode.Sso))])
                                                self._leafs = OrderedDict()

                                                self.graceful_restart = None
                                                self._children_name_map["graceful_restart"] = "graceful-restart"

                                                self.sso = None
                                                self._children_name_map["sso"] = "sso"
                                                self._segment_path = lambda: "ha-mode"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode, [], name, value)


                                            class GracefulRestart(Entity):
                                                """
                                                graceful\-restart for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable graceful\-restart
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                    self.yang_name = "graceful-restart"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "graceful-restart"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                            class Sso(Entity):
                                                """
                                                stateful\-switchover support for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable stateful\-switchover
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode.Sso, self).__init__()

                                                    self.yang_name = "sso"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "sso"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.HaMode.Sso, ['disable'], name, value)


                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class LocalAs(Entity):
                                            """
                                            Specify a local\-as number
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: no_prepend
                                            
                                            	Do not prepend local\-as to updates from ebgp peers
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace real AS with local AS in the EBGP updates
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: dual_as
                                            
                                            	Accept either real AS or local AS from the ebgp peer
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.LocalAs, self).__init__()

                                                self.yang_name = "local-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                    ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                                ])
                                                self.as_no = None
                                                self.no_prepend = None
                                                self.replace_as = None
                                                self.dual_as = None
                                                self._segment_path = lambda: "local-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                        class LogNeighborChanges(Entity):
                                            """
                                            Log neighbor up/down and reset reason
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.LogNeighborChanges, self).__init__()

                                                self.yang_name = "log-neighbor-changes"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "log-neighbor-changes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                        class Password(Entity):
                                            """
                                            Set a password
                                            
                                            .. attribute:: enctype
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: text
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Password, self).__init__()

                                                self.yang_name = "password"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                                ])
                                                self.enctype = None
                                                self.text = None
                                                self._segment_path = lambda: "password"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Password, ['enctype', 'text'], name, value)


                                        class PathAttribute(Entity):
                                            """
                                            BGP optional attribute filtering
                                            
                                            .. attribute:: discard
                                            
                                            	Discard matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard>`
                                            
                                            .. attribute:: treat_as_withdraw
                                            
                                            	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute, self).__init__()

                                                self.yang_name = "path-attribute"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw))])
                                                self._leafs = OrderedDict()

                                                self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard()
                                                self.discard.parent = self
                                                self._children_name_map["discard"] = "discard"

                                                self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw()
                                                self.treat_as_withdraw.parent = self
                                                self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                                self._segment_path = lambda: "path-attribute"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute, [], name, value)


                                            class Discard(Entity):
                                                """
                                                Discard matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard, self).__init__()

                                                    self.yang_name = "discard"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "discard"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                            class TreatAsWithdraw(Entity):
                                                """
                                                Treat\-as\-withdraw matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                    self.yang_name = "treat-as-withdraw"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "treat-as-withdraw"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SendLabel(Entity):
                                            """
                                            Send NLRI + MPLS Label to this peer
                                            
                                            .. attribute:: send_label_explicit
                                            
                                            	
                                            	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendLabel, self).__init__()

                                                self.yang_name = "send-label"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit')])),
                                                ])
                                                self.send_label_explicit = None
                                                self._segment_path = lambda: "send-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                            class SendLabelExplicit(Enum):
                                                """
                                                SendLabelExplicit (Enum Class)

                                                .. data:: explicit_null = 0

                                                """

                                                explicit_null = Enum.YLeaf(0, "explicit-null")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class Timers(Entity):
                                            """
                                            BGP per neighbor timers
                                            
                                            .. attribute:: keepalive_interval
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: holdtime
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: minimum_neighbor_hold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Timers, self).__init__()

                                                self.yang_name = "timers"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                    ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                    ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                                ])
                                                self.keepalive_interval = None
                                                self.holdtime = None
                                                self.minimum_neighbor_hold = None
                                                self._segment_path = lambda: "timers"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                        class TranslateUpdate(Entity):
                                            """
                                            Translate update to MBGP format
                                            
                                            .. attribute:: ipv4
                                            
                                            	Address Family
                                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate, self).__init__()

                                                self.yang_name = "translate-update"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4))])
                                                self._leafs = OrderedDict()

                                                self.ipv4 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4()
                                                self.ipv4.parent = self
                                                self._children_name_map["ipv4"] = "ipv4"
                                                self._segment_path = lambda: "translate-update"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate, [], name, value)


                                            class Ipv4(Entity):
                                                """
                                                Address Family
                                                
                                                .. attribute:: multicast
                                                
                                                	Address Family modifier
                                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4, self).__init__()

                                                    self.yang_name = "ipv4"
                                                    self.yang_parent_name = "translate-update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast))])
                                                    self._leafs = OrderedDict()

                                                    self.multicast = None
                                                    self._children_name_map["multicast"] = "multicast"
                                                    self._segment_path = lambda: "ipv4"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4, [], name, value)


                                                class Multicast(Entity):
                                                    """
                                                    Address Family modifier
                                                    
                                                    .. attribute:: unicast
                                                    
                                                    	Address Family modifier
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast, self).__init__()

                                                        self.yang_name = "multicast"
                                                        self.yang_parent_name = "ipv4"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                        ])
                                                        self.unicast = None
                                                        self._segment_path = lambda: "multicast"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast, ['unicast'], name, value)


                                        class Transport(Entity):
                                            """
                                            Transport options
                                            
                                            .. attribute:: connection_mode
                                            
                                            	Specify passive or active connection
                                            	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Transport.ConnectionMode>`
                                            
                                            .. attribute:: multi_session
                                            
                                            	Use multi\-session for transport
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: path_mtu_discovery
                                            
                                            	Use transport path MTU discovery
                                            	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Transport, self).__init__()

                                                self.yang_name = "transport"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery))])
                                                self._leafs = OrderedDict([
                                                    ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Transport.ConnectionMode')])),
                                                    ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                                ])
                                                self.connection_mode = None
                                                self.multi_session = None

                                                self.path_mtu_discovery = None
                                                self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                                self._segment_path = lambda: "transport"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                            class ConnectionMode(Enum):
                                                """
                                                ConnectionMode (Enum Class)

                                                Specify passive or active connection

                                                .. data:: active = 0

                                                .. data:: passive = 1

                                                """

                                                active = Enum.YLeaf(0, "active")

                                                passive = Enum.YLeaf(1, "passive")



                                            class PathMtuDiscovery(Entity):
                                                """
                                                Use transport path MTU discovery
                                                
                                                .. attribute:: disable
                                                
                                                	disable
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                    self.yang_name = "path-mtu-discovery"
                                                    self.yang_parent_name = "transport"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "path-mtu-discovery"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                        class TtlSecurity(Entity):
                                            """
                                            BGP ttl security check
                                            
                                            .. attribute:: hops
                                            
                                            	IP hops
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TtlSecurity, self).__init__()

                                                self.yang_name = "ttl-security"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                                ])
                                                self.hops = None
                                                self._segment_path = lambda: "ttl-security"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.TtlSecurity, ['hops'], name, value)


                                        class UpdateSource(Entity):
                                            """
                                            Source of routing updates
                                            
                                            .. attribute:: appnav_compress
                                            
                                            	Service\-Context Virtual Interface Compress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: appnav_uncompress
                                            
                                            	Service\-Context Virtual Interface UnCompress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm
                                            
                                            	ATM interface
                                            	**type**\: str
                                            
                                            .. attribute:: atm_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface>`
                                            
                                            .. attribute:: atm_acr
                                            
                                            	ATM\-ACR interface
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]
                                            
                                            .. attribute:: atm_acrsubinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface>`
                                            
                                            .. attribute:: bdi
                                            
                                            	Bridge\-Domain interface
                                            	**type**\: str
                                            
                                            .. attribute:: cem
                                            
                                            	CEM interface
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9]/){2}[0\-9]
                                            
                                            .. attribute:: cem_acr
                                            
                                            	CEM\-ACR interface
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: embedded_service_engine
                                            
                                            	cisco embedded service engine module
                                            	**type**\: str
                                            
                                            .. attribute:: ethernet
                                            
                                            	IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: fastethernet
                                            
                                            	FastEthernet IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: gigabitethernet
                                            
                                            	GigabitEthernet IEEE 802.3z
                                            	**type**\: str
                                            
                                            .. attribute:: fivegigabitethernet
                                            
                                            	Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twentyfivegige
                                            
                                            	Twenty Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twogigabitethernet
                                            
                                            	Two GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: fortygigabitethernet
                                            
                                            	Forty GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: hundredgige
                                            
                                            	Hundred GigabitEthernet
                                            	**type**\: str
                                            
                                            .. attribute:: lisp
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_subinterface
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface>`
                                            
                                            .. attribute:: loopback
                                            
                                            	Loopback interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multilink
                                            
                                            	Multilink\-group interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: nve
                                            
                                            	Network virtualization endpoint interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: overlay
                                            
                                            	Overlay interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: port_channel
                                            
                                            	Ethernet Channel of interfaces
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: port_channel_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface>`
                                            
                                            .. attribute:: pseudowire
                                            
                                            	Pseudowire Interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sm
                                            
                                            	SM Interface
                                            	**type**\: str
                                            
                                            .. attribute:: cellular
                                            
                                            	Cellular Interface
                                            	**type**\: str
                                            
                                            .. attribute:: serial
                                            
                                            	Serial interface
                                            	**type**\: str
                                            
                                            .. attribute:: tengigabitethernet
                                            
                                            	Ten Gigabit Ethernet
                                            	**type**\: str
                                            
                                            .. attribute:: tunnel
                                            
                                            	Tunnel interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_template
                                            
                                            	Virtual Template interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vlan
                                            
                                            	Iosxr Vlans
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: virtualportgroup
                                            
                                            	Virtual Port Group
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasileft
                                            
                                            	vasileft
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasiright
                                            
                                            	vasiright
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource, self).__init__()

                                                self.yang_name = "update-source"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface))])
                                                self._leafs = OrderedDict([
                                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                                ])
                                                self.appnav_compress = None
                                                self.appnav_uncompress = None
                                                self.atm = None
                                                self.atm_acr = None
                                                self.bdi = None
                                                self.cem = None
                                                self.cem_acr = None
                                                self.embedded_service_engine = None
                                                self.ethernet = None
                                                self.fastethernet = None
                                                self.gigabitethernet = None
                                                self.fivegigabitethernet = None
                                                self.twentyfivegige = None
                                                self.twogigabitethernet = None
                                                self.fortygigabitethernet = None
                                                self.hundredgige = None
                                                self.lisp = None
                                                self.loopback = None
                                                self.multilink = None
                                                self.nve = None
                                                self.overlay = None
                                                self.port_channel = None
                                                self.pseudowire = None
                                                self.sm = None
                                                self.cellular = None
                                                self.serial = None
                                                self.tengigabitethernet = None
                                                self.tunnel = None
                                                self.virtual_template = None
                                                self.vlan = None
                                                self.virtualportgroup = None
                                                self.vasileft = None
                                                self.vasiright = None

                                                self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface()
                                                self.atm_subinterface.parent = self
                                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                                self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface()
                                                self.atm_acrsubinterface.parent = self
                                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                                self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface()
                                                self.lisp_subinterface.parent = self
                                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                                self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface()
                                                self.port_channel_subinterface.parent = self
                                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                                self._segment_path = lambda: "update-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                            class ATMSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                    self.yang_name = "ATM-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ])
                                                    self.atm = None
                                                    self._segment_path = lambda: "ATM-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                            class ATMACRsubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm_acr
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                    self.yang_name = "ATM-ACRsubinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ])
                                                    self.atm_acr = None
                                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                            class LISPSubinterface(Entity):
                                                """
                                                Locator/ID Separation Protocol Virtual Interface
                                                
                                                .. attribute:: lisp
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                    self.yang_name = "LISP-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ])
                                                    self.lisp = None
                                                    self._segment_path = lambda: "LISP-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                            class PortChannelSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: port_channel
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                    self.yang_name = "Port-channel-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                    ])
                                                    self.port_channel = None
                                                    self._segment_path = lambda: "Port-channel-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_as
                                    
                                    	Specify a BGP peer\-group remote\-as
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertise_map
                                    
                                    	specify route\-map for conditional advertisement
                                    	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AdvertiseMap>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: aigp
                                    
                                    	Enable a AIGP on neighbor
                                    	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: announce
                                    
                                    	Announce RPKI state using an extended community
                                    	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Announce>`
                                    
                                    .. attribute:: as_override
                                    
                                    	Override matching AS\-number while sending update
                                    	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AsOverride>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability>`
                                    
                                    .. attribute:: cluster_id
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: default_originate
                                    
                                    	Originate default route to this neighbor
                                    	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.DefaultOriginate>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: description
                                    
                                    	Neighbor specific description
                                    	**type**\: str
                                    
                                    .. attribute:: disable_connected_check
                                    
                                    	one\-hop away EBGP peer using loopback address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ebgp_multihop
                                    
                                    	Allow EBGP neighbors not on directly connected networks
                                    	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.EbgpMultihop>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fall_over
                                    
                                    	session fall on peer route lost
                                    	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FallOver>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FilterList>`
                                    
                                    .. attribute:: ha_mode
                                    
                                    	high availability mode
                                    	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Inherit>`
                                    
                                    .. attribute:: local_as
                                    
                                    	Specify a local\-as number
                                    	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.LocalAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: log_neighbor_changes
                                    
                                    	Log neighbor up/down and reset reason
                                    	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.LogNeighborChanges>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: password
                                    
                                    	Set a password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Password>`
                                    
                                    .. attribute:: path_attribute
                                    
                                    	BGP optional attribute filtering
                                    	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	Member of the peer\-group
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PeerGroup>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: send_label
                                    
                                    	Send NLRI + MPLS Label to this peer
                                    	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendLabel>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: shutdown
                                    
                                    	Administratively shut down this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: timers
                                    
                                    	BGP per neighbor timers
                                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Timers>`
                                    
                                    .. attribute:: translate_update
                                    
                                    	Translate update to MBGP format
                                    	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate>`
                                    
                                    .. attribute:: transport
                                    
                                    	Transport options
                                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Transport>`
                                    
                                    .. attribute:: ttl_security
                                    
                                    	BGP ttl security check
                                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TtlSecurity>`
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: update_source
                                    
                                    	Source of routing updates
                                    	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource>`
                                    
                                    .. attribute:: version
                                    
                                    	Set the BGP version to match a neighbor
                                    	**type**\: int
                                    
                                    	**range:** 4..None
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.DefaultOriginate)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FallOver)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FilterList)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PeerGroup)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Timers)), ("translate-update", ("translate_update", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                            ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.remote_as = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.cluster_id = None
                                        self.description = None
                                        self.disable_connected_check = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.shutdown = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.version = None
                                        self.weight = None

                                        self.advertise_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AdvertiseMap()
                                        self.advertise_map.parent = self
                                        self._children_name_map["advertise_map"] = "advertise-map"

                                        self.aigp = None
                                        self._children_name_map["aigp"] = "aigp"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.announce = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Announce()
                                        self.announce.parent = self
                                        self._children_name_map["announce"] = "announce"

                                        self.as_override = None
                                        self._children_name_map["as_override"] = "as-override"

                                        self.capability = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.default_originate = None
                                        self._children_name_map["default_originate"] = "default-originate"

                                        self.ebgp_multihop = None
                                        self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                        self.fall_over = None
                                        self._children_name_map["fall_over"] = "fall-over"

                                        self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode()
                                        self.ha_mode.parent = self
                                        self._children_name_map["ha_mode"] = "ha-mode"

                                        self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.local_as = None
                                        self._children_name_map["local_as"] = "local-as"

                                        self.log_neighbor_changes = None
                                        self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"

                                        self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute()
                                        self.path_attribute.parent = self
                                        self._children_name_map["path_attribute"] = "path-attribute"

                                        self.peer_group = None
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.send_label = None
                                        self._children_name_map["send_label"] = "send-label"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Timers()
                                        self.timers.parent = self
                                        self._children_name_map["timers"] = "timers"

                                        self.translate_update = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate()
                                        self.translate_update.parent = self
                                        self._children_name_map["translate_update"] = "translate-update"

                                        self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Transport()
                                        self.transport.parent = self
                                        self._children_name_map["transport"] = "transport"

                                        self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TtlSecurity()
                                        self.ttl_security.parent = self
                                        self._children_name_map["ttl_security"] = "ttl-security"

                                        self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource()
                                        self.update_source.parent = self
                                        self._children_name_map["update_source"] = "update-source"

                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor, ['id', 'remote_as', 'activate', 'advertisement_interval', 'allow_policy', 'cluster_id', 'description', 'disable_connected_check', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'version', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AdvertiseMap(Entity):
                                        """
                                        specify route\-map for conditional advertisement
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AdvertiseMap.Name>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AdvertiseMap, self).__init__()

                                            self.yang_name = "advertise-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AdvertiseMap.Name))])
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "advertise-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AdvertiseMap, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: word  (key)
                                            
                                            	advertise route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: non_exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AdvertiseMap.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "advertise-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                    ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                    ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                ])
                                                self.word = None
                                                self.exist_map = None
                                                self.non_exist_map = None
                                                self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                    class Aigp(Entity):
                                        """
                                        Enable a AIGP on neighbor
                                        
                                        .. attribute:: send
                                        
                                        	Cost community or MED carrying AIGP VALUE
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp, self).__init__()

                                            self.yang_name = "aigp"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.send = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send()
                                            self.send.parent = self
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "aigp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp, [], name, value)


                                        class Send(Entity):
                                            """
                                            Cost community or MED carrying AIGP VALUE
                                            
                                            .. attribute:: cost_community
                                            
                                            	Cost extended community carrying AIGP Value
                                            	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity>`
                                            
                                            .. attribute:: med
                                            
                                            	Med carrying AIGP Value
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "aigp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                ])
                                                self.med = None

                                                self.cost_community = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity()
                                                self.cost_community.parent = self
                                                self._children_name_map["cost_community"] = "cost-community"
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send, ['med'], name, value)


                                            class CostCommunity(Entity):
                                                """
                                                Cost extended community carrying AIGP Value
                                                
                                                .. attribute:: cc_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                    self.yang_name = "cost-community"
                                                    self.yang_parent_name = "send"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                    self._leafs = OrderedDict()

                                                    self.cc_range = YList(self)
                                                    self._segment_path = lambda: "cost-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                class CcRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Community ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: poi
                                                    
                                                    	Point of insertion
                                                    	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                        self.yang_name = "cc-range"
                                                        self.yang_parent_name = "cost-community"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ])
                                                        self.range = None

                                                        self.poi = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                        self.poi.parent = self
                                                        self._children_name_map["poi"] = "poi"
                                                        self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                    class Poi(Entity):
                                                        """
                                                        Point of insertion
                                                        
                                                        .. attribute:: igp_cost
                                                        
                                                        	Point of insertion after IGP
                                                        	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        .. attribute:: pre_bestpath
                                                        
                                                        	Point of insertion at beginning
                                                        	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                            self.yang_name = "poi"
                                                            self.yang_parent_name = "cc-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                            self._leafs = OrderedDict()

                                                            self.igp_cost = None
                                                            self._children_name_map["igp_cost"] = "igp-cost"

                                                            self.pre_bestpath = None
                                                            self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                            self._segment_path = lambda: "poi"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                        class IgpCost(Entity):
                                                            """
                                                            Point of insertion after IGP
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                self.yang_name = "igp-cost"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "igp-cost"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                        class PreBestpath(Entity):
                                                            """
                                                            Point of insertion at beginning
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                self.yang_name = "pre-bestpath"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "pre-bestpath"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Announce(Entity):
                                        """
                                        Announce RPKI state using an extended community
                                        
                                        .. attribute:: rpki
                                        
                                        	Announce RPKI information using an extended community
                                        	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Announce.Rpki>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Announce, self).__init__()

                                            self.yang_name = "announce"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Announce.Rpki))])
                                            self._leafs = OrderedDict()

                                            self.rpki = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Announce.Rpki()
                                            self.rpki.parent = self
                                            self._children_name_map["rpki"] = "rpki"
                                            self._segment_path = lambda: "announce"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Announce, [], name, value)


                                        class Rpki(Entity):
                                            """
                                            Announce RPKI information using an extended community
                                            
                                            .. attribute:: state
                                            
                                            	Announce RPKI state information using an extended community
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Announce.Rpki, self).__init__()

                                                self.yang_name = "rpki"
                                                self.yang_parent_name = "announce"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                ])
                                                self.state = None
                                                self._segment_path = lambda: "rpki"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Announce.Rpki, ['state'], name, value)


                                    class AsOverride(Entity):
                                        """
                                        Override matching AS\-number while sending update
                                        
                                        .. attribute:: disable
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AsOverride, self).__init__()

                                            self.yang_name = "as-override"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "as-override"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.AsOverride, ['disable'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DefaultOriginate(Entity):
                                        """
                                        Originate default route to this neighbor
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria to originate default
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.DefaultOriginate, self).__init__()

                                            self.yang_name = "default-originate"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "default-originate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                    class EbgpMultihop(Entity):
                                        """
                                        Allow EBGP neighbors not on directly connected networks
                                        
                                        .. attribute:: max_hop
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.EbgpMultihop, self).__init__()

                                            self.yang_name = "ebgp-multihop"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                            ])
                                            self.max_hop = None
                                            self._segment_path = lambda: "ebgp-multihop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                    class FallOver(Entity):
                                        """
                                        session fall on peer route lost
                                        
                                        .. attribute:: bfd
                                        
                                        	Use BFD to detect failure
                                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FallOver.Bfd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FallOver, self).__init__()

                                            self.yang_name = "fall-over"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FallOver.Bfd))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.route_map_name = None

                                            self.bfd = None
                                            self._children_name_map["bfd"] = "bfd"
                                            self._segment_path = lambda: "fall-over"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FallOver, ['route_map_name'], name, value)


                                        class Bfd(Entity):
                                            """
                                            Use BFD to detect failure
                                            
                                            .. attribute:: multi_hop
                                            
                                            	Force BFD multi\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: single_hop
                                            
                                            	Force BFD single\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: check_control_plane_failure
                                            
                                            	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: strict_mode
                                            
                                            	Enable BFD strict\-mode
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FallOver.Bfd, self).__init__()

                                                self.yang_name = "bfd"
                                                self.yang_parent_name = "fall-over"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                    ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                    ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                    ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                ])
                                                self.multi_hop = None
                                                self.single_hop = None
                                                self.check_control_plane_failure = None
                                                self.strict_mode = None
                                                self._segment_path = lambda: "bfd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class HaMode(Entity):
                                        """
                                        high availability mode
                                        
                                        .. attribute:: graceful_restart
                                        
                                        	graceful\-restart for this peer
                                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode.GracefulRestart>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: sso
                                        
                                        	stateful\-switchover support for this peer
                                        	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode.Sso>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode, self).__init__()

                                            self.yang_name = "ha-mode"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode.Sso))])
                                            self._leafs = OrderedDict()

                                            self.graceful_restart = None
                                            self._children_name_map["graceful_restart"] = "graceful-restart"

                                            self.sso = None
                                            self._children_name_map["sso"] = "sso"
                                            self._segment_path = lambda: "ha-mode"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode, [], name, value)


                                        class GracefulRestart(Entity):
                                            """
                                            graceful\-restart for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable graceful\-restart
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                self.yang_name = "graceful-restart"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "graceful-restart"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                        class Sso(Entity):
                                            """
                                            stateful\-switchover support for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable stateful\-switchover
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode.Sso, self).__init__()

                                                self.yang_name = "sso"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "sso"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.HaMode.Sso, ['disable'], name, value)


                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class LocalAs(Entity):
                                        """
                                        Specify a local\-as number
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: no_prepend
                                        
                                        	Do not prepend local\-as to updates from ebgp peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace real AS with local AS in the EBGP updates
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: dual_as
                                        
                                        	Accept either real AS or local AS from the ebgp peer
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.LocalAs, self).__init__()

                                            self.yang_name = "local-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                            ])
                                            self.as_no = None
                                            self.no_prepend = None
                                            self.replace_as = None
                                            self.dual_as = None
                                            self._segment_path = lambda: "local-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                    class LogNeighborChanges(Entity):
                                        """
                                        Log neighbor up/down and reset reason
                                        
                                        .. attribute:: disable
                                        
                                        	disable
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.LogNeighborChanges, self).__init__()

                                            self.yang_name = "log-neighbor-changes"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "log-neighbor-changes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                    class Password(Entity):
                                        """
                                        Set a password
                                        
                                        .. attribute:: enctype
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: text
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                            ])
                                            self.enctype = None
                                            self.text = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Password, ['enctype', 'text'], name, value)


                                    class PathAttribute(Entity):
                                        """
                                        BGP optional attribute filtering
                                        
                                        .. attribute:: discard
                                        
                                        	Discard matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard>`
                                        
                                        .. attribute:: treat_as_withdraw
                                        
                                        	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute, self).__init__()

                                            self.yang_name = "path-attribute"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw))])
                                            self._leafs = OrderedDict()

                                            self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard()
                                            self.discard.parent = self
                                            self._children_name_map["discard"] = "discard"

                                            self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw()
                                            self.treat_as_withdraw.parent = self
                                            self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                            self._segment_path = lambda: "path-attribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute, [], name, value)


                                        class Discard(Entity):
                                            """
                                            Discard matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard, self).__init__()

                                                self.yang_name = "discard"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "discard"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class TreatAsWithdraw(Entity):
                                            """
                                            Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                self.yang_name = "treat-as-withdraw"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "treat-as-withdraw"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        Member of the peer\-group
                                        
                                        .. attribute:: peer_group_name
                                        
                                        	peer\-group name
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                            ])
                                            self.peer_group_name = None
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SendLabel(Entity):
                                        """
                                        Send NLRI + MPLS Label to this peer
                                        
                                        .. attribute:: send_label_explicit
                                        
                                        	
                                        	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendLabel.SendLabelExplicit>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendLabel, self).__init__()

                                            self.yang_name = "send-label"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendLabel.SendLabelExplicit')])),
                                            ])
                                            self.send_label_explicit = None
                                            self._segment_path = lambda: "send-label"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                        class SendLabelExplicit(Enum):
                                            """
                                            SendLabelExplicit (Enum Class)

                                            .. data:: explicit_null = 0

                                            """

                                            explicit_null = Enum.YLeaf(0, "explicit-null")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Timers(Entity):
                                        """
                                        BGP per neighbor timers
                                        
                                        .. attribute:: keepalive_interval
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: holdtime
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: minimum_neighbor_hold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Timers, self).__init__()

                                            self.yang_name = "timers"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                            ])
                                            self.keepalive_interval = None
                                            self.holdtime = None
                                            self.minimum_neighbor_hold = None
                                            self._segment_path = lambda: "timers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                    class TranslateUpdate(Entity):
                                        """
                                        Translate update to MBGP format
                                        
                                        .. attribute:: ipv4
                                        
                                        	Address Family
                                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate, self).__init__()

                                            self.yang_name = "translate-update"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4))])
                                            self._leafs = OrderedDict()

                                            self.ipv4 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4()
                                            self.ipv4.parent = self
                                            self._children_name_map["ipv4"] = "ipv4"
                                            self._segment_path = lambda: "translate-update"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate, [], name, value)


                                        class Ipv4(Entity):
                                            """
                                            Address Family
                                            
                                            .. attribute:: multicast
                                            
                                            	Address Family modifier
                                            	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4, self).__init__()

                                                self.yang_name = "ipv4"
                                                self.yang_parent_name = "translate-update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast))])
                                                self._leafs = OrderedDict()

                                                self.multicast = None
                                                self._children_name_map["multicast"] = "multicast"
                                                self._segment_path = lambda: "ipv4"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4, [], name, value)


                                            class Multicast(Entity):
                                                """
                                                Address Family modifier
                                                
                                                .. attribute:: unicast
                                                
                                                	Address Family modifier
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast, self).__init__()

                                                    self.yang_name = "multicast"
                                                    self.yang_parent_name = "ipv4"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                    ])
                                                    self.unicast = None
                                                    self._segment_path = lambda: "multicast"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast, ['unicast'], name, value)


                                    class Transport(Entity):
                                        """
                                        Transport options
                                        
                                        .. attribute:: connection_mode
                                        
                                        	Specify passive or active connection
                                        	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Transport.ConnectionMode>`
                                        
                                        .. attribute:: multi_session
                                        
                                        	Use multi\-session for transport
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: path_mtu_discovery
                                        
                                        	Use transport path MTU discovery
                                        	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Transport.PathMtuDiscovery>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Transport, self).__init__()

                                            self.yang_name = "transport"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Transport.PathMtuDiscovery))])
                                            self._leafs = OrderedDict([
                                                ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Transport.ConnectionMode')])),
                                                ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                            ])
                                            self.connection_mode = None
                                            self.multi_session = None

                                            self.path_mtu_discovery = None
                                            self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                            self._segment_path = lambda: "transport"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                        class ConnectionMode(Enum):
                                            """
                                            ConnectionMode (Enum Class)

                                            Specify passive or active connection

                                            .. data:: active = 0

                                            .. data:: passive = 1

                                            """

                                            active = Enum.YLeaf(0, "active")

                                            passive = Enum.YLeaf(1, "passive")



                                        class PathMtuDiscovery(Entity):
                                            """
                                            Use transport path MTU discovery
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                self.yang_name = "path-mtu-discovery"
                                                self.yang_parent_name = "transport"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "path-mtu-discovery"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                    class TtlSecurity(Entity):
                                        """
                                        BGP ttl security check
                                        
                                        .. attribute:: hops
                                        
                                        	IP hops
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TtlSecurity, self).__init__()

                                            self.yang_name = "ttl-security"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                            ])
                                            self.hops = None
                                            self._segment_path = lambda: "ttl-security"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.TtlSecurity, ['hops'], name, value)


                                    class UpdateSource(Entity):
                                        """
                                        Source of routing updates
                                        
                                        .. attribute:: appnav_compress
                                        
                                        	Service\-Context Virtual Interface Compress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: appnav_uncompress
                                        
                                        	Service\-Context Virtual Interface UnCompress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm
                                        
                                        	ATM interface
                                        	**type**\: str
                                        
                                        .. attribute:: atm_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.ATMSubinterface>`
                                        
                                        .. attribute:: atm_acr
                                        
                                        	ATM\-ACR interface
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9]
                                        
                                        .. attribute:: atm_acrsubinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.ATMACRsubinterface>`
                                        
                                        .. attribute:: bdi
                                        
                                        	Bridge\-Domain interface
                                        	**type**\: str
                                        
                                        .. attribute:: cem
                                        
                                        	CEM interface
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9]/){2}[0\-9]
                                        
                                        .. attribute:: cem_acr
                                        
                                        	CEM\-ACR interface
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: embedded_service_engine
                                        
                                        	cisco embedded service engine module
                                        	**type**\: str
                                        
                                        .. attribute:: ethernet
                                        
                                        	IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: fastethernet
                                        
                                        	FastEthernet IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: gigabitethernet
                                        
                                        	GigabitEthernet IEEE 802.3z
                                        	**type**\: str
                                        
                                        .. attribute:: fivegigabitethernet
                                        
                                        	Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twentyfivegige
                                        
                                        	Twenty Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twogigabitethernet
                                        
                                        	Two GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: fortygigabitethernet
                                        
                                        	Forty GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: hundredgige
                                        
                                        	Hundred GigabitEthernet
                                        	**type**\: str
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_subinterface
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.LISPSubinterface>`
                                        
                                        .. attribute:: loopback
                                        
                                        	Loopback interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multilink
                                        
                                        	Multilink\-group interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: nve
                                        
                                        	Network virtualization endpoint interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: overlay
                                        
                                        	Overlay interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: port_channel
                                        
                                        	Ethernet Channel of interfaces
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: port_channel_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.PortChannelSubinterface>`
                                        
                                        .. attribute:: pseudowire
                                        
                                        	Pseudowire Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sm
                                        
                                        	SM Interface
                                        	**type**\: str
                                        
                                        .. attribute:: cellular
                                        
                                        	Cellular Interface
                                        	**type**\: str
                                        
                                        .. attribute:: serial
                                        
                                        	Serial interface
                                        	**type**\: str
                                        
                                        .. attribute:: tengigabitethernet
                                        
                                        	Ten Gigabit Ethernet
                                        	**type**\: str
                                        
                                        .. attribute:: tunnel
                                        
                                        	Tunnel interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_template
                                        
                                        	Virtual Template interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vlan
                                        
                                        	Iosxr Vlans
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: virtualportgroup
                                        
                                        	Virtual Port Group
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasileft
                                        
                                        	vasileft
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasiright
                                        
                                        	vasiright
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource, self).__init__()

                                            self.yang_name = "update-source"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.PortChannelSubinterface))])
                                            self._leafs = OrderedDict([
                                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                            ])
                                            self.appnav_compress = None
                                            self.appnav_uncompress = None
                                            self.atm = None
                                            self.atm_acr = None
                                            self.bdi = None
                                            self.cem = None
                                            self.cem_acr = None
                                            self.embedded_service_engine = None
                                            self.ethernet = None
                                            self.fastethernet = None
                                            self.gigabitethernet = None
                                            self.fivegigabitethernet = None
                                            self.twentyfivegige = None
                                            self.twogigabitethernet = None
                                            self.fortygigabitethernet = None
                                            self.hundredgige = None
                                            self.lisp = None
                                            self.loopback = None
                                            self.multilink = None
                                            self.nve = None
                                            self.overlay = None
                                            self.port_channel = None
                                            self.pseudowire = None
                                            self.sm = None
                                            self.cellular = None
                                            self.serial = None
                                            self.tengigabitethernet = None
                                            self.tunnel = None
                                            self.virtual_template = None
                                            self.vlan = None
                                            self.virtualportgroup = None
                                            self.vasileft = None
                                            self.vasiright = None

                                            self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.ATMSubinterface()
                                            self.atm_subinterface.parent = self
                                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                            self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.ATMACRsubinterface()
                                            self.atm_acrsubinterface.parent = self
                                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                            self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.LISPSubinterface()
                                            self.lisp_subinterface.parent = self
                                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                            self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.PortChannelSubinterface()
                                            self.port_channel_subinterface.parent = self
                                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                            self._segment_path = lambda: "update-source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                        class ATMSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                self.yang_name = "ATM-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ])
                                                self.atm = None
                                                self._segment_path = lambda: "ATM-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                        class ATMACRsubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm_acr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                self.yang_name = "ATM-ACRsubinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ])
                                                self.atm_acr = None
                                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                        class LISPSubinterface(Entity):
                                            """
                                            Locator/ID Separation Protocol Virtual Interface
                                            
                                            .. attribute:: lisp
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                self.yang_name = "LISP-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ])
                                                self.lisp = None
                                                self._segment_path = lambda: "LISP-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                        class PortChannelSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: port_channel
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                self.yang_name = "Port-channel-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                ])
                                                self.port_channel = None
                                                self._segment_path = lambda: "Port-channel-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Network(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: evpn
                                    
                                    	Advertise or export to EVPN address\-family
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                            ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self.evpn = None
                                        self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Network, ['number', 'route_map', 'backdoor', 'evpn'], name, value)


                                class Redistribute(Entity):
                                    """
                                    Redistribute information from another routing protocol
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Application>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Bgp_>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: dvmrp
                                    
                                    	Redistribution of DVMRP into BGP IPv4 Multicast
                                    	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Dvmrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator/ID Separation Protocol
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Lisp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Rip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute, self).__init__()

                                        self.yang_name = "redistribute"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static))])
                                        self._leafs = OrderedDict()

                                        self.application = None
                                        self._children_name_map["application"] = "application"

                                        self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.dvmrp = None
                                        self._children_name_map["dvmrp"] = "dvmrp"

                                        self.eigrp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Eigrp()
                                        self.eigrp.parent = self
                                        self._children_name_map["eigrp"] = "eigrp"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.lisp = None
                                        self._children_name_map["lisp"] = "lisp"

                                        self.iso_igrp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp()
                                        self.iso_igrp.parent = self
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.rip = None
                                        self._children_name_map["rip"] = "rip"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "redistribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Application.Name>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Application.Name))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Application, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	WORD \:\: Route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Application.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                    class Bgp_(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.as_no = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                    class Dvmrp(Entity):
                                        """
                                        Redistribution of DVMRP into BGP IPv4 Multicast
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Dvmrp, self).__init__()

                                            self.yang_name = "dvmrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "dvmrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.as_no = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "eigrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.IsisArea>`
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.Default>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.Default))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.default = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis, [], name, value)


                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: routes
                                            
                                            	
                                            	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.IsisArea.Routes>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                    ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                    ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.IsisArea.Routes')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.ip = None
                                                self.clns = None
                                                self.routes = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                            class Routes(Enum):
                                                """
                                                Routes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class Default(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: routes
                                            
                                            	
                                            	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.Default.Routes>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                    ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                    ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.Default.Routes')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.ip = None
                                                self.clns = None
                                                self.routes = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                            class Routes(Enum):
                                                """
                                                Routes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class Lisp(Entity):
                                        """
                                        Locator/ID Separation Protocol
                                        
                                        .. attribute:: include_connected
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.include_connected = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: iso_igrp_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp.Default>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp.Default))])
                                            self._leafs = OrderedDict()

                                            self.default = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.iso_igrp_area = YList(self)
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp, [], name, value)


                                        class IsoIgrpArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                                self.yang_name = "iso-igrp-area"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.name = None
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                        class Default(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.Vrf_>`
                                        
                                        .. attribute:: non_vrf
                                        
                                        	
                                        	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.NonVrf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.Vrf_)), ("non-vrf", ("non_vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.NonVrf))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.non_vrf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.NonVrf()
                                            self.non_vrf.parent = self
                                            self._children_name_map["non_vrf"] = "non-vrf"

                                            self.vrf = YList(self)
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf, ['id'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VPN Routing/Forwarding Instance
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.Vrf_.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.Vrf_.Match))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.Vrf_.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.Vrf_, ['name', 'metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.Vrf_.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True


                                        class NonVrf(Entity):
                                            """
                                            
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.NonVrf, self).__init__()

                                                self.yang_name = "non-vrf"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match))])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "non-vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                .. attribute:: internal
                                                
                                                	Redistribute OSPF internal routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: external
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: external2
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: nssa_external
                                                
                                                	Redistribute OSPF NSSA external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "non-vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                        ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.internal = None
                                                    self.external = None
                                                    self.external2 = None
                                                    self.nssa_external = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospfv3.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospfv3.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospfv3.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: external2
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospfv3.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                    ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.internal = None
                                                self.external = None
                                                self.external2 = None
                                                self.nssa_external = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: name
                                        
                                        	User selected string identifying this process
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self.name = None
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static.Clns>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ip
                                        
                                        	
                                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static.Ip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static.Ip))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None

                                            self.clns = None
                                            self._children_name_map["clns"] = "clns"

                                            self.ip = None
                                            self._children_name_map["ip"] = "ip"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                        class Clns(Entity):
                                            """
                                            Redistribution of OSI dynamic routes
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static.Clns, self).__init__()

                                                self.yang_name = "clns"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "clns"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                        class Ip(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static.Ip, self).__init__()

                                                self.yang_name = "ip"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                                class Snmp(Entity):
                                    """
                                    Modify snmp parameters
                                    
                                    .. attribute:: context
                                    
                                    	Configure a SNMP context
                                    	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp.Context>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp, self).__init__()

                                        self.yang_name = "snmp"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp.Context))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.context = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp.Context()
                                        self.context.parent = self
                                        self._children_name_map["context"] = "context"
                                        self._segment_path = lambda: "snmp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp, [], name, value)


                                    class Context(Entity):
                                        """
                                        Configure a SNMP context
                                        
                                        .. attribute:: context_word
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp.Context.ContextWord>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp.Context, self).__init__()

                                            self.yang_name = "context"
                                            self.yang_parent_name = "snmp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp.Context.ContextWord))])
                                            self._leafs = OrderedDict()

                                            self.context_word = YList(self)
                                            self._segment_path = lambda: "context"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp.Context, [], name, value)


                                        class ContextWord(Entity):
                                            """
                                            
                                            
                                            .. attribute:: context_word  (key)
                                            
                                            	Context Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp.Context.ContextWord, self).__init__()

                                                self.yang_name = "context_word"
                                                self.yang_parent_name = "context"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['context_word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                ])
                                                self.context_word = None
                                                self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                                class TableMap(Entity):
                                    """
                                    Map external entry attributes into routing table
                                    
                                    .. attribute:: name
                                    
                                    	WORD \:\: Route\-map name
                                    	**type**\: str
                                    
                                    .. attribute:: filter
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.TableMap, self).__init__()

                                        self.yang_name = "table-map"
                                        self.yang_parent_name = "ipv6-unicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                                        ])
                                        self.name = None
                                        self.filter = None
                                        self._segment_path = lambda: "table-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Unicast.TableMap, ['name', 'filter'], name, value)


                            class Ipv6Multicast(Entity):
                                """
                                IPv6 Multicast VRF address family
                                
                                .. attribute:: aggregate_address
                                
                                	Configure BGP aggregate entries
                                	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.AggregateAddress>`
                                
                                .. attribute:: bgp
                                
                                	
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_>`
                                
                                .. attribute:: distance
                                
                                	Define an administrative distance
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance>`
                                
                                .. attribute:: import_
                                
                                	Configure path import
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import>`
                                
                                .. attribute:: peer_group
                                
                                	
                                	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup>`
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor>`
                                
                                .. attribute:: network
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Network>`
                                
                                .. attribute:: redistribute
                                
                                	Redistribute information from another routing protocol
                                	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute>`
                                
                                .. attribute:: snmp
                                
                                	Modify snmp parameters
                                	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast, self).__init__()

                                    self.yang_name = "ipv6-multicast"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_)), ("distance", ("distance", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance)), ("import", ("import_", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp))])
                                    self._leafs = OrderedDict()

                                    self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.distance = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.import_ = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.peer_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup()
                                    self.peer_group.parent = self
                                    self._children_name_map["peer_group"] = "peer-group"

                                    self.redistribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute()
                                    self.redistribute.parent = self
                                    self._children_name_map["redistribute"] = "redistribute"

                                    self.snmp = None
                                    self._children_name_map["snmp"] = "snmp"

                                    self.aggregate_address = YList(self)
                                    self.neighbor = YList(self)
                                    self.network = YList(self)
                                    self._segment_path = lambda: "ipv6-multicast"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast, [], name, value)


                                class AggregateAddress(Entity):
                                    """
                                    Configure BGP aggregate entries
                                    
                                    .. attribute:: ipv6_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: advertise_map
                                    
                                    	Set condition to advertise attribute
                                    	**type**\: str
                                    
                                    .. attribute:: as_set
                                    
                                    	Generate AS set path information
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attribute_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: as_override
                                    
                                    	Override matching AS\-number while sending update
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: summary_only
                                    
                                    	Filter more specific routes from updates
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: suppress_map
                                    
                                    	Conditionally filter more specific routes from updates
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.AggregateAddress, self).__init__()

                                        self.yang_name = "aggregate-address"
                                        self.yang_parent_name = "ipv6-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ipv6_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                            ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                            ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                            ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                            ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                        ])
                                        self.ipv6_address = None
                                        self.advertise_map = None
                                        self.as_set = None
                                        self.attribute_map = None
                                        self.as_override = None
                                        self.route_map = None
                                        self.summary_only = None
                                        self.suppress_map = None
                                        self._segment_path = lambda: "aggregate-address" + "[ipv6-address='" + str(self.ipv6_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.AggregateAddress, ['ipv6_address', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                                class Bgp_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: additional_paths
                                    
                                    	Additional paths in the BGP table
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths>`
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Configure aggregation timer
                                    	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AggregateTimer>`
                                    
                                    .. attribute:: dampening
                                    
                                    	Enable route\-flap dampening
                                    	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.Dampening>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: redistribute_internal
                                    
                                    	Allow redistribution of iBGP into IGPs (dangerous)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	bgp route\-map commands
                                    	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.RouteMap>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "ipv6-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AggregateTimer)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.Dampening)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                        ])
                                        self.redistribute_internal = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.aggregate_timer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AggregateTimer()
                                        self.aggregate_timer.parent = self
                                        self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                        self.dampening = None
                                        self._children_name_map["dampening"] = "dampening"

                                        self.route_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.RouteMap()
                                        self.route_map.parent = self
                                        self._children_name_map["route_map"] = "route-map"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_, ['redistribute_internal'], name, value)


                                    class AdditionalPaths(Entity):
                                        """
                                        Additional paths in the BGP table
                                        
                                        .. attribute:: install
                                        
                                        	Additional paths to install into RIB
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: select
                                        
                                        	Selection criteria to pick the paths
                                        	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select>`
                                        
                                        .. attribute:: send
                                        
                                        	Send additional paths to neighbors
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Send>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Send))])
                                            self._leafs = OrderedDict([
                                                ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.install = None
                                            self.receive = None

                                            self.select = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select()
                                            self.select.parent = self
                                            self._children_name_map["select"] = "select"

                                            self.send = None
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                        class Select(Entity):
                                            """
                                            Selection criteria to pick the paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: backup
                                            
                                            	Select backup path
                                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Backup>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Select best\-external path
                                            	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best path
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                self.yang_name = "select"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"

                                                self.backup = None
                                                self._children_name_map["backup"] = "backup"

                                                self.best = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.best_external = None
                                                self._children_name_map["best_external"] = "best-external"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "select"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                            class All(Entity):
                                                """
                                                Select all available paths
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.best = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.group_best = None
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                            class Backup(Entity):
                                                """
                                                Select backup path
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                    self.yang_name = "backup"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None
                                                    self._segment_path = lambda: "backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.all = None

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.all = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                            class BestExternal(Entity):
                                                """
                                                Select best\-external path
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                    self.yang_name = "best-external"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                    ])
                                                    self.backup = None
                                                    self._segment_path = lambda: "best-external"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best path
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "select"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.all = None
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                        class Send(Entity):
                                            """
                                            Send additional paths to neighbors
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.receive = None
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                    class AggregateTimer(Entity):
                                        """
                                        Configure aggregation timer
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Timer interval
                                        	**type**\: int
                                        
                                        	**range:** 6..60
                                        
                                        .. attribute:: disable_timer
                                        
                                        	Timer interval
                                        	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AggregateTimer.DisableTimer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AggregateTimer, self).__init__()

                                            self.yang_name = "aggregate-timer"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AggregateTimer.DisableTimer')])),
                                            ])
                                            self.aggregate_timer = None
                                            self.disable_timer = None
                                            self._segment_path = lambda: "aggregate-timer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                        class DisableTimer(Enum):
                                            """
                                            DisableTimer (Enum Class)

                                            Timer interval

                                            .. data:: Y_0 = 0

                                            """

                                            Y_0 = Enum.YLeaf(0, "0")



                                    class Dampening(Entity):
                                        """
                                        Enable route\-flap dampening
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria for dampening
                                        	**type**\: str
                                        
                                        .. attribute:: dampen
                                        
                                        	
                                        	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.Dampening.Dampen>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.Dampening.Dampen))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.dampen = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.Dampening.Dampen()
                                            self.dampen.parent = self
                                            self._children_name_map["dampen"] = "dampen"
                                            self._segment_path = lambda: "dampening"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.Dampening, ['route_map'], name, value)


                                        class Dampen(Entity):
                                            """
                                            
                                            
                                            .. attribute:: half_life_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..45
                                            
                                            .. attribute:: reuse_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: max_suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.Dampening.Dampen, self).__init__()

                                                self.yang_name = "dampen"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                    ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                    ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                    ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                ])
                                                self.half_life_time = None
                                                self.reuse_time = None
                                                self.suppress_time = None
                                                self.max_suppress_time = None
                                                self._segment_path = lambda: "dampen"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        bgp route\-map commands
                                        
                                        .. attribute:: priority
                                        
                                        	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                            ])
                                            self.priority = None
                                            self._segment_path = lambda: "route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.RouteMap, ['priority'], name, value)


                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: disable
                                            
                                            	Disable slow\-peer detection
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.disable = None
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class Distance(Entity):
                                    """
                                    Define an administrative distance
                                    
                                    .. attribute:: bgp
                                    
                                    	BGP distance
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance.Bgp_>`
                                    
                                    .. attribute:: adm_distance
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance.AdmDistance>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv6-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance.AdmDistance))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.adm_distance = YList(self)
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        BGP distance
                                        
                                        .. attribute:: extern_as
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: internal_as
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: local
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "distance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                                ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                                ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                            ])
                                            self.extern_as = None
                                            self.internal_as = None
                                            self.local = None
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                    class AdmDistance(Entity):
                                        """
                                        
                                        
                                        .. attribute:: distance  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: srcip  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: wildbits  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: acl
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..99
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..1999
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance.AdmDistance, self).__init__()

                                            self.yang_name = "adm-distance"
                                            self.yang_parent_name = "distance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['distance','srcip','wildbits']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                                ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                                ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                                ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                            ])
                                            self.distance = None
                                            self.srcip = None
                                            self.wildbits = None
                                            self.acl = None
                                            self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                                class Import(Entity):
                                    """
                                    Configure path import
                                    
                                    .. attribute:: path
                                    
                                    	Path selection and path limit
                                    	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Path>`
                                    
                                    .. attribute:: vpnv4
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Vpnv4>`
                                    
                                    .. attribute:: vpnv6
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Vpnv6>`
                                    
                                    .. attribute:: l2vpn
                                    
                                    	Configure EVPN to VPN path import
                                    	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.L2vpn>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv6-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Path)), ("vpnv4", ("vpnv4", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Vpnv4)), ("vpnv6", ("vpnv6", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Vpnv6)), ("l2vpn", ("l2vpn", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.L2vpn))])
                                        self._leafs = OrderedDict()

                                        self.path = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Path()
                                        self.path.parent = self
                                        self._children_name_map["path"] = "path"

                                        self.vpnv4 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Vpnv4()
                                        self.vpnv4.parent = self
                                        self._children_name_map["vpnv4"] = "vpnv4"

                                        self.vpnv6 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Vpnv6()
                                        self.vpnv6.parent = self
                                        self._children_name_map["vpnv6"] = "vpnv6"

                                        self.l2vpn = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.L2vpn()
                                        self.l2vpn.parent = self
                                        self._children_name_map["l2vpn"] = "l2vpn"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import, [], name, value)


                                    class Path(Entity):
                                        """
                                        Path selection and path limit
                                        
                                        .. attribute:: limit
                                        
                                        	Per net imported path limit
                                        	**type**\: int
                                        
                                        	**range:** 2..255
                                        
                                        .. attribute:: selection
                                        
                                        	Path selection policy
                                        	**type**\:  :py:class:`Selection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Path.Selection>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("selection", ("selection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Path.Selection))])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                                            ])
                                            self.limit = None

                                            self.selection = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Path.Selection()
                                            self.selection.parent = self
                                            self._children_name_map["selection"] = "selection"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Path, ['limit'], name, value)


                                        class Selection(Entity):
                                            """
                                            Path selection policy
                                            
                                            .. attribute:: all
                                            
                                            	Import all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Path.Selection, self).__init__()

                                                self.yang_name = "selection"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "selection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Path.Selection, ['all'], name, value)


                                    class Vpnv4(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Vpnv4, self).__init__()

                                            self.yang_name = "vpnv4"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv4"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Vpnv4, ['unicast', 're_originate'], name, value)


                                    class Vpnv6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	Imported path with RT re\-originate
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Vpnv6, self).__init__()

                                            self.yang_name = "vpnv6"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.Vpnv6, ['unicast', 're_originate'], name, value)


                                    class L2vpn(Entity):
                                        """
                                        Configure EVPN to VPN path import
                                        
                                        .. attribute:: evpn
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.L2vpn, self).__init__()

                                            self.yang_name = "l2vpn"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.evpn = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "l2vpn"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Import.L2vpn, ['evpn', 're_originate'], name, value)


                                class PeerGroup(Entity):
                                    """
                                    
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup, self).__init__()

                                        self.yang_name = "peer-group"
                                        self.yang_parent_name = "ipv6-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor))])
                                        self._leafs = OrderedDict()

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "peer-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: peer_group
                                        
                                        	Member of the peer\-group
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable a AIGP on neighbor
                                        	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.AsOverride>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability>`
                                        
                                        .. attribute:: cluster_id
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: description
                                        
                                        	Neighbor specific description
                                        	**type**\: str
                                        
                                        .. attribute:: disable_connected_check
                                        
                                        	one\-hop away EBGP peer using loopback address
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ebgp_multihop
                                        
                                        	Allow EBGP neighbors not on directly connected networks
                                        	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.EbgpMultihop>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: fall_over
                                        
                                        	session fall on peer route lost
                                        	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FallOver>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FilterList>`
                                        
                                        .. attribute:: ha_mode
                                        
                                        	high availability mode
                                        	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Inherit>`
                                        
                                        .. attribute:: local_as
                                        
                                        	Specify a local\-as number
                                        	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.LocalAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: log_neighbor_changes
                                        
                                        	Log neighbor up/down and reset reason
                                        	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.LogNeighborChanges>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: password
                                        
                                        	Set a password
                                        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Password>`
                                        
                                        .. attribute:: path_attribute
                                        
                                        	BGP optional attribute filtering
                                        	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remote_as
                                        
                                        	Specify a BGP peer\-group remote\-as
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: shutdown
                                        
                                        	Administratively shut down this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: timers
                                        
                                        	BGP per neighbor timers
                                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Timers>`
                                        
                                        .. attribute:: transport
                                        
                                        	Transport options
                                        	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Transport>`
                                        
                                        .. attribute:: ttl_security
                                        
                                        	BGP ttl security check
                                        	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.TtlSecurity>`
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: update_source
                                        
                                        	Source of routing updates
                                        	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource>`
                                        
                                        .. attribute:: version
                                        
                                        	Set the BGP version to match a neighbor
                                        	**type**\: int
                                        
                                        	**range:** 4..None
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "peer-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("aigp", ("aigp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.AllowasIn)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.DefaultOriginate)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FallOver)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FilterList)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Timers)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ('peer_group', (YLeaf(YType.empty, 'peer-group'), ['Empty'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.peer_group = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.cluster_id = None
                                            self.description = None
                                            self.disable_connected_check = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.remote_as = None
                                            self.route_reflector_client = None
                                            self.shutdown = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.version = None
                                            self.weight = None

                                            self.aigp = None
                                            self._children_name_map["aigp"] = "aigp"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.as_override = None
                                            self._children_name_map["as_override"] = "as-override"

                                            self.capability = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.ebgp_multihop = None
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                            self.fall_over = None
                                            self._children_name_map["fall_over"] = "fall-over"

                                            self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode()
                                            self.ha_mode.parent = self
                                            self._children_name_map["ha_mode"] = "ha-mode"

                                            self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.local_as = None
                                            self._children_name_map["local_as"] = "local-as"

                                            self.log_neighbor_changes = None
                                            self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                            self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"

                                            self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute()
                                            self.path_attribute.parent = self
                                            self._children_name_map["path_attribute"] = "path-attribute"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"

                                            self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Transport()
                                            self.transport.parent = self
                                            self._children_name_map["transport"] = "transport"

                                            self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.TtlSecurity()
                                            self.ttl_security.parent = self
                                            self._children_name_map["ttl_security"] = "ttl-security"

                                            self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource()
                                            self.update_source.parent = self
                                            self._children_name_map["update_source"] = "update-source"

                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor, ['id', 'peer_group', 'activate', 'advertisement_interval', 'allow_policy', 'cluster_id', 'description', 'disable_connected_check', 'dmzlink_bw', 'next_hop_unchanged', 'remote_as', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'version', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class Aigp(Entity):
                                            """
                                            Enable a AIGP on neighbor
                                            
                                            .. attribute:: send
                                            
                                            	Cost community or MED carrying AIGP VALUE
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                                self.yang_name = "aigp"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.send = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send()
                                                self.send.parent = self
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "aigp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                            class Send(Entity):
                                                """
                                                Cost community or MED carrying AIGP VALUE
                                                
                                                .. attribute:: cost_community
                                                
                                                	Cost extended community carrying AIGP Value
                                                	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                                
                                                .. attribute:: med
                                                
                                                	Med carrying AIGP Value
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "aigp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                    ])
                                                    self.med = None

                                                    self.cost_community = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                    self.cost_community.parent = self
                                                    self._children_name_map["cost_community"] = "cost-community"
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                                class CostCommunity(Entity):
                                                    """
                                                    Cost extended community carrying AIGP Value
                                                    
                                                    .. attribute:: cc_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                        self.yang_name = "cost-community"
                                                        self.yang_parent_name = "send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                        self._leafs = OrderedDict()

                                                        self.cc_range = YList(self)
                                                        self._segment_path = lambda: "cost-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                    class CcRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Community ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: poi
                                                        
                                                        	Point of insertion
                                                        	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                            self.yang_name = "cc-range"
                                                            self.yang_parent_name = "cost-community"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ])
                                                            self.range = None

                                                            self.poi = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                            self.poi.parent = self
                                                            self._children_name_map["poi"] = "poi"
                                                            self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                        class Poi(Entity):
                                                            """
                                                            Point of insertion
                                                            
                                                            .. attribute:: igp_cost
                                                            
                                                            	Point of insertion after IGP
                                                            	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            .. attribute:: pre_bestpath
                                                            
                                                            	Point of insertion at beginning
                                                            	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                self.yang_name = "poi"
                                                                self.yang_parent_name = "cc-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                self._leafs = OrderedDict()

                                                                self.igp_cost = None
                                                                self._children_name_map["igp_cost"] = "igp-cost"

                                                                self.pre_bestpath = None
                                                                self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                self._segment_path = lambda: "poi"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                            class IgpCost(Entity):
                                                                """
                                                                Point of insertion after IGP
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                    self.yang_name = "igp-cost"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "igp-cost"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                            class PreBestpath(Entity):
                                                                """
                                                                Point of insertion at beginning
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                    self.yang_name = "pre-bestpath"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "pre-bestpath"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class AsOverride(Entity):
                                            """
                                            Override matching AS\-number while sending update
                                            
                                            .. attribute:: disable
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.AsOverride, self).__init__()

                                                self.yang_name = "as-override"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "as-override"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.AsOverride, ['disable'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class EbgpMultihop(Entity):
                                            """
                                            Allow EBGP neighbors not on directly connected networks
                                            
                                            .. attribute:: max_hop
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.EbgpMultihop, self).__init__()

                                                self.yang_name = "ebgp-multihop"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                                ])
                                                self.max_hop = None
                                                self._segment_path = lambda: "ebgp-multihop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                        class FallOver(Entity):
                                            """
                                            session fall on peer route lost
                                            
                                            .. attribute:: bfd
                                            
                                            	Use BFD to detect failure
                                            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FallOver.Bfd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FallOver, self).__init__()

                                                self.yang_name = "fall-over"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FallOver.Bfd))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.route_map_name = None

                                                self.bfd = None
                                                self._children_name_map["bfd"] = "bfd"
                                                self._segment_path = lambda: "fall-over"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FallOver, ['route_map_name'], name, value)


                                            class Bfd(Entity):
                                                """
                                                Use BFD to detect failure
                                                
                                                .. attribute:: multi_hop
                                                
                                                	Force BFD multi\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: single_hop
                                                
                                                	Force BFD single\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: check_control_plane_failure
                                                
                                                	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: strict_mode
                                                
                                                	Enable BFD strict\-mode
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FallOver.Bfd, self).__init__()

                                                    self.yang_name = "bfd"
                                                    self.yang_parent_name = "fall-over"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                        ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                        ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                        ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                    ])
                                                    self.multi_hop = None
                                                    self.single_hop = None
                                                    self.check_control_plane_failure = None
                                                    self.strict_mode = None
                                                    self._segment_path = lambda: "bfd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class HaMode(Entity):
                                            """
                                            high availability mode
                                            
                                            .. attribute:: graceful_restart
                                            
                                            	graceful\-restart for this peer
                                            	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode.GracefulRestart>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: sso
                                            
                                            	stateful\-switchover support for this peer
                                            	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode.Sso>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode, self).__init__()

                                                self.yang_name = "ha-mode"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode.Sso))])
                                                self._leafs = OrderedDict()

                                                self.graceful_restart = None
                                                self._children_name_map["graceful_restart"] = "graceful-restart"

                                                self.sso = None
                                                self._children_name_map["sso"] = "sso"
                                                self._segment_path = lambda: "ha-mode"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode, [], name, value)


                                            class GracefulRestart(Entity):
                                                """
                                                graceful\-restart for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable graceful\-restart
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                    self.yang_name = "graceful-restart"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "graceful-restart"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                            class Sso(Entity):
                                                """
                                                stateful\-switchover support for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable stateful\-switchover
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode.Sso, self).__init__()

                                                    self.yang_name = "sso"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "sso"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.HaMode.Sso, ['disable'], name, value)


                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class LocalAs(Entity):
                                            """
                                            Specify a local\-as number
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: no_prepend
                                            
                                            	Do not prepend local\-as to updates from ebgp peers
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace real AS with local AS in the EBGP updates
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: dual_as
                                            
                                            	Accept either real AS or local AS from the ebgp peer
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.LocalAs, self).__init__()

                                                self.yang_name = "local-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                    ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                                ])
                                                self.as_no = None
                                                self.no_prepend = None
                                                self.replace_as = None
                                                self.dual_as = None
                                                self._segment_path = lambda: "local-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                        class LogNeighborChanges(Entity):
                                            """
                                            Log neighbor up/down and reset reason
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.LogNeighborChanges, self).__init__()

                                                self.yang_name = "log-neighbor-changes"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "log-neighbor-changes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                        class Password(Entity):
                                            """
                                            Set a password
                                            
                                            .. attribute:: enctype
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: text
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Password, self).__init__()

                                                self.yang_name = "password"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                                ])
                                                self.enctype = None
                                                self.text = None
                                                self._segment_path = lambda: "password"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Password, ['enctype', 'text'], name, value)


                                        class PathAttribute(Entity):
                                            """
                                            BGP optional attribute filtering
                                            
                                            .. attribute:: discard
                                            
                                            	Discard matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard>`
                                            
                                            .. attribute:: treat_as_withdraw
                                            
                                            	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute, self).__init__()

                                                self.yang_name = "path-attribute"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw))])
                                                self._leafs = OrderedDict()

                                                self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard()
                                                self.discard.parent = self
                                                self._children_name_map["discard"] = "discard"

                                                self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw()
                                                self.treat_as_withdraw.parent = self
                                                self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                                self._segment_path = lambda: "path-attribute"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute, [], name, value)


                                            class Discard(Entity):
                                                """
                                                Discard matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard, self).__init__()

                                                    self.yang_name = "discard"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "discard"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                            class TreatAsWithdraw(Entity):
                                                """
                                                Treat\-as\-withdraw matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                    self.yang_name = "treat-as-withdraw"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "treat-as-withdraw"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class Timers(Entity):
                                            """
                                            BGP per neighbor timers
                                            
                                            .. attribute:: keepalive_interval
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: holdtime
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: minimum_neighbor_hold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Timers, self).__init__()

                                                self.yang_name = "timers"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                    ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                    ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                                ])
                                                self.keepalive_interval = None
                                                self.holdtime = None
                                                self.minimum_neighbor_hold = None
                                                self._segment_path = lambda: "timers"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                        class Transport(Entity):
                                            """
                                            Transport options
                                            
                                            .. attribute:: connection_mode
                                            
                                            	Specify passive or active connection
                                            	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Transport.ConnectionMode>`
                                            
                                            .. attribute:: multi_session
                                            
                                            	Use multi\-session for transport
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: path_mtu_discovery
                                            
                                            	Use transport path MTU discovery
                                            	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Transport, self).__init__()

                                                self.yang_name = "transport"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery))])
                                                self._leafs = OrderedDict([
                                                    ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Transport.ConnectionMode')])),
                                                    ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                                ])
                                                self.connection_mode = None
                                                self.multi_session = None

                                                self.path_mtu_discovery = None
                                                self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                                self._segment_path = lambda: "transport"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                            class ConnectionMode(Enum):
                                                """
                                                ConnectionMode (Enum Class)

                                                Specify passive or active connection

                                                .. data:: active = 0

                                                .. data:: passive = 1

                                                """

                                                active = Enum.YLeaf(0, "active")

                                                passive = Enum.YLeaf(1, "passive")



                                            class PathMtuDiscovery(Entity):
                                                """
                                                Use transport path MTU discovery
                                                
                                                .. attribute:: disable
                                                
                                                	disable
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                    self.yang_name = "path-mtu-discovery"
                                                    self.yang_parent_name = "transport"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "path-mtu-discovery"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                        class TtlSecurity(Entity):
                                            """
                                            BGP ttl security check
                                            
                                            .. attribute:: hops
                                            
                                            	IP hops
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.TtlSecurity, self).__init__()

                                                self.yang_name = "ttl-security"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                                ])
                                                self.hops = None
                                                self._segment_path = lambda: "ttl-security"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.TtlSecurity, ['hops'], name, value)


                                        class UpdateSource(Entity):
                                            """
                                            Source of routing updates
                                            
                                            .. attribute:: appnav_compress
                                            
                                            	Service\-Context Virtual Interface Compress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: appnav_uncompress
                                            
                                            	Service\-Context Virtual Interface UnCompress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm
                                            
                                            	ATM interface
                                            	**type**\: str
                                            
                                            .. attribute:: atm_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface>`
                                            
                                            .. attribute:: atm_acr
                                            
                                            	ATM\-ACR interface
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]
                                            
                                            .. attribute:: atm_acrsubinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface>`
                                            
                                            .. attribute:: bdi
                                            
                                            	Bridge\-Domain interface
                                            	**type**\: str
                                            
                                            .. attribute:: cem
                                            
                                            	CEM interface
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9]/){2}[0\-9]
                                            
                                            .. attribute:: cem_acr
                                            
                                            	CEM\-ACR interface
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: embedded_service_engine
                                            
                                            	cisco embedded service engine module
                                            	**type**\: str
                                            
                                            .. attribute:: ethernet
                                            
                                            	IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: fastethernet
                                            
                                            	FastEthernet IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: gigabitethernet
                                            
                                            	GigabitEthernet IEEE 802.3z
                                            	**type**\: str
                                            
                                            .. attribute:: fivegigabitethernet
                                            
                                            	Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twentyfivegige
                                            
                                            	Twenty Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twogigabitethernet
                                            
                                            	Two GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: fortygigabitethernet
                                            
                                            	Forty GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: hundredgige
                                            
                                            	Hundred GigabitEthernet
                                            	**type**\: str
                                            
                                            .. attribute:: lisp
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_subinterface
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface>`
                                            
                                            .. attribute:: loopback
                                            
                                            	Loopback interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multilink
                                            
                                            	Multilink\-group interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: nve
                                            
                                            	Network virtualization endpoint interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: overlay
                                            
                                            	Overlay interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: port_channel
                                            
                                            	Ethernet Channel of interfaces
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: port_channel_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface>`
                                            
                                            .. attribute:: pseudowire
                                            
                                            	Pseudowire Interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sm
                                            
                                            	SM Interface
                                            	**type**\: str
                                            
                                            .. attribute:: cellular
                                            
                                            	Cellular Interface
                                            	**type**\: str
                                            
                                            .. attribute:: serial
                                            
                                            	Serial interface
                                            	**type**\: str
                                            
                                            .. attribute:: tengigabitethernet
                                            
                                            	Ten Gigabit Ethernet
                                            	**type**\: str
                                            
                                            .. attribute:: tunnel
                                            
                                            	Tunnel interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_template
                                            
                                            	Virtual Template interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vlan
                                            
                                            	Iosxr Vlans
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: virtualportgroup
                                            
                                            	Virtual Port Group
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasileft
                                            
                                            	vasileft
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasiright
                                            
                                            	vasiright
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource, self).__init__()

                                                self.yang_name = "update-source"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface))])
                                                self._leafs = OrderedDict([
                                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                                ])
                                                self.appnav_compress = None
                                                self.appnav_uncompress = None
                                                self.atm = None
                                                self.atm_acr = None
                                                self.bdi = None
                                                self.cem = None
                                                self.cem_acr = None
                                                self.embedded_service_engine = None
                                                self.ethernet = None
                                                self.fastethernet = None
                                                self.gigabitethernet = None
                                                self.fivegigabitethernet = None
                                                self.twentyfivegige = None
                                                self.twogigabitethernet = None
                                                self.fortygigabitethernet = None
                                                self.hundredgige = None
                                                self.lisp = None
                                                self.loopback = None
                                                self.multilink = None
                                                self.nve = None
                                                self.overlay = None
                                                self.port_channel = None
                                                self.pseudowire = None
                                                self.sm = None
                                                self.cellular = None
                                                self.serial = None
                                                self.tengigabitethernet = None
                                                self.tunnel = None
                                                self.virtual_template = None
                                                self.vlan = None
                                                self.virtualportgroup = None
                                                self.vasileft = None
                                                self.vasiright = None

                                                self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface()
                                                self.atm_subinterface.parent = self
                                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                                self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface()
                                                self.atm_acrsubinterface.parent = self
                                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                                self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface()
                                                self.lisp_subinterface.parent = self
                                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                                self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface()
                                                self.port_channel_subinterface.parent = self
                                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                                self._segment_path = lambda: "update-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                            class ATMSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                    self.yang_name = "ATM-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ])
                                                    self.atm = None
                                                    self._segment_path = lambda: "ATM-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                            class ATMACRsubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm_acr
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                    self.yang_name = "ATM-ACRsubinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ])
                                                    self.atm_acr = None
                                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                            class LISPSubinterface(Entity):
                                                """
                                                Locator/ID Separation Protocol Virtual Interface
                                                
                                                .. attribute:: lisp
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                    self.yang_name = "LISP-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ])
                                                    self.lisp = None
                                                    self._segment_path = lambda: "LISP-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                            class PortChannelSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: port_channel
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                    self.yang_name = "Port-channel-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                    ])
                                                    self.port_channel = None
                                                    self._segment_path = lambda: "Port-channel-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_as
                                    
                                    	Specify a BGP peer\-group remote\-as
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: aigp
                                    
                                    	Enable a AIGP on neighbor
                                    	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: as_override
                                    
                                    	Override matching AS\-number while sending update
                                    	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.AsOverride>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability>`
                                    
                                    .. attribute:: cluster_id
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: default_originate
                                    
                                    	Originate default route to this neighbor
                                    	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.DefaultOriginate>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: description
                                    
                                    	Neighbor specific description
                                    	**type**\: str
                                    
                                    .. attribute:: disable_connected_check
                                    
                                    	one\-hop away EBGP peer using loopback address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ebgp_multihop
                                    
                                    	Allow EBGP neighbors not on directly connected networks
                                    	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.EbgpMultihop>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fall_over
                                    
                                    	session fall on peer route lost
                                    	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FallOver>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FilterList>`
                                    
                                    .. attribute:: ha_mode
                                    
                                    	high availability mode
                                    	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Inherit>`
                                    
                                    .. attribute:: local_as
                                    
                                    	Specify a local\-as number
                                    	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.LocalAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: log_neighbor_changes
                                    
                                    	Log neighbor up/down and reset reason
                                    	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.LogNeighborChanges>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: password
                                    
                                    	Set a password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Password>`
                                    
                                    .. attribute:: path_attribute
                                    
                                    	BGP optional attribute filtering
                                    	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	Member of the peer\-group
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PeerGroup>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: shutdown
                                    
                                    	Administratively shut down this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: timers
                                    
                                    	BGP per neighbor timers
                                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Timers>`
                                    
                                    .. attribute:: transport
                                    
                                    	Transport options
                                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Transport>`
                                    
                                    .. attribute:: ttl_security
                                    
                                    	BGP ttl security check
                                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.TtlSecurity>`
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: update_source
                                    
                                    	Source of routing updates
                                    	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource>`
                                    
                                    .. attribute:: version
                                    
                                    	Set the BGP version to match a neighbor
                                    	**type**\: int
                                    
                                    	**range:** 4..None
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "ipv6-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("aigp", ("aigp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.AllowasIn)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.DefaultOriginate)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FallOver)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FilterList)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PeerGroup)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Timers)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                            ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.remote_as = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.cluster_id = None
                                        self.description = None
                                        self.disable_connected_check = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.shutdown = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.version = None
                                        self.weight = None

                                        self.aigp = None
                                        self._children_name_map["aigp"] = "aigp"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.as_override = None
                                        self._children_name_map["as_override"] = "as-override"

                                        self.capability = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.default_originate = None
                                        self._children_name_map["default_originate"] = "default-originate"

                                        self.ebgp_multihop = None
                                        self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                        self.fall_over = None
                                        self._children_name_map["fall_over"] = "fall-over"

                                        self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode()
                                        self.ha_mode.parent = self
                                        self._children_name_map["ha_mode"] = "ha-mode"

                                        self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.local_as = None
                                        self._children_name_map["local_as"] = "local-as"

                                        self.log_neighbor_changes = None
                                        self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"

                                        self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute()
                                        self.path_attribute.parent = self
                                        self._children_name_map["path_attribute"] = "path-attribute"

                                        self.peer_group = None
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Timers()
                                        self.timers.parent = self
                                        self._children_name_map["timers"] = "timers"

                                        self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Transport()
                                        self.transport.parent = self
                                        self._children_name_map["transport"] = "transport"

                                        self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.TtlSecurity()
                                        self.ttl_security.parent = self
                                        self._children_name_map["ttl_security"] = "ttl-security"

                                        self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource()
                                        self.update_source.parent = self
                                        self._children_name_map["update_source"] = "update-source"

                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor, ['id', 'remote_as', 'activate', 'advertisement_interval', 'allow_policy', 'cluster_id', 'description', 'disable_connected_check', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'version', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class Aigp(Entity):
                                        """
                                        Enable a AIGP on neighbor
                                        
                                        .. attribute:: send
                                        
                                        	Cost community or MED carrying AIGP VALUE
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp, self).__init__()

                                            self.yang_name = "aigp"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.send = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send()
                                            self.send.parent = self
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "aigp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp, [], name, value)


                                        class Send(Entity):
                                            """
                                            Cost community or MED carrying AIGP VALUE
                                            
                                            .. attribute:: cost_community
                                            
                                            	Cost extended community carrying AIGP Value
                                            	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity>`
                                            
                                            .. attribute:: med
                                            
                                            	Med carrying AIGP Value
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "aigp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                ])
                                                self.med = None

                                                self.cost_community = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity()
                                                self.cost_community.parent = self
                                                self._children_name_map["cost_community"] = "cost-community"
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send, ['med'], name, value)


                                            class CostCommunity(Entity):
                                                """
                                                Cost extended community carrying AIGP Value
                                                
                                                .. attribute:: cc_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                    self.yang_name = "cost-community"
                                                    self.yang_parent_name = "send"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                    self._leafs = OrderedDict()

                                                    self.cc_range = YList(self)
                                                    self._segment_path = lambda: "cost-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                class CcRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Community ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: poi
                                                    
                                                    	Point of insertion
                                                    	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                        self.yang_name = "cc-range"
                                                        self.yang_parent_name = "cost-community"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ])
                                                        self.range = None

                                                        self.poi = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                        self.poi.parent = self
                                                        self._children_name_map["poi"] = "poi"
                                                        self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                    class Poi(Entity):
                                                        """
                                                        Point of insertion
                                                        
                                                        .. attribute:: igp_cost
                                                        
                                                        	Point of insertion after IGP
                                                        	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        .. attribute:: pre_bestpath
                                                        
                                                        	Point of insertion at beginning
                                                        	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                            self.yang_name = "poi"
                                                            self.yang_parent_name = "cc-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                            self._leafs = OrderedDict()

                                                            self.igp_cost = None
                                                            self._children_name_map["igp_cost"] = "igp-cost"

                                                            self.pre_bestpath = None
                                                            self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                            self._segment_path = lambda: "poi"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                        class IgpCost(Entity):
                                                            """
                                                            Point of insertion after IGP
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                self.yang_name = "igp-cost"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "igp-cost"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                        class PreBestpath(Entity):
                                                            """
                                                            Point of insertion at beginning
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                self.yang_name = "pre-bestpath"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "pre-bestpath"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class AsOverride(Entity):
                                        """
                                        Override matching AS\-number while sending update
                                        
                                        .. attribute:: disable
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.AsOverride, self).__init__()

                                            self.yang_name = "as-override"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "as-override"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.AsOverride, ['disable'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DefaultOriginate(Entity):
                                        """
                                        Originate default route to this neighbor
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria to originate default
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.DefaultOriginate, self).__init__()

                                            self.yang_name = "default-originate"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "default-originate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                    class EbgpMultihop(Entity):
                                        """
                                        Allow EBGP neighbors not on directly connected networks
                                        
                                        .. attribute:: max_hop
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.EbgpMultihop, self).__init__()

                                            self.yang_name = "ebgp-multihop"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                            ])
                                            self.max_hop = None
                                            self._segment_path = lambda: "ebgp-multihop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                    class FallOver(Entity):
                                        """
                                        session fall on peer route lost
                                        
                                        .. attribute:: bfd
                                        
                                        	Use BFD to detect failure
                                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FallOver.Bfd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FallOver, self).__init__()

                                            self.yang_name = "fall-over"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FallOver.Bfd))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.route_map_name = None

                                            self.bfd = None
                                            self._children_name_map["bfd"] = "bfd"
                                            self._segment_path = lambda: "fall-over"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FallOver, ['route_map_name'], name, value)


                                        class Bfd(Entity):
                                            """
                                            Use BFD to detect failure
                                            
                                            .. attribute:: multi_hop
                                            
                                            	Force BFD multi\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: single_hop
                                            
                                            	Force BFD single\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: check_control_plane_failure
                                            
                                            	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: strict_mode
                                            
                                            	Enable BFD strict\-mode
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FallOver.Bfd, self).__init__()

                                                self.yang_name = "bfd"
                                                self.yang_parent_name = "fall-over"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                    ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                    ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                    ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                ])
                                                self.multi_hop = None
                                                self.single_hop = None
                                                self.check_control_plane_failure = None
                                                self.strict_mode = None
                                                self._segment_path = lambda: "bfd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class HaMode(Entity):
                                        """
                                        high availability mode
                                        
                                        .. attribute:: graceful_restart
                                        
                                        	graceful\-restart for this peer
                                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode.GracefulRestart>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: sso
                                        
                                        	stateful\-switchover support for this peer
                                        	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode.Sso>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode, self).__init__()

                                            self.yang_name = "ha-mode"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode.Sso))])
                                            self._leafs = OrderedDict()

                                            self.graceful_restart = None
                                            self._children_name_map["graceful_restart"] = "graceful-restart"

                                            self.sso = None
                                            self._children_name_map["sso"] = "sso"
                                            self._segment_path = lambda: "ha-mode"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode, [], name, value)


                                        class GracefulRestart(Entity):
                                            """
                                            graceful\-restart for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable graceful\-restart
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                self.yang_name = "graceful-restart"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "graceful-restart"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                        class Sso(Entity):
                                            """
                                            stateful\-switchover support for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable stateful\-switchover
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode.Sso, self).__init__()

                                                self.yang_name = "sso"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "sso"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.HaMode.Sso, ['disable'], name, value)


                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class LocalAs(Entity):
                                        """
                                        Specify a local\-as number
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: no_prepend
                                        
                                        	Do not prepend local\-as to updates from ebgp peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace real AS with local AS in the EBGP updates
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: dual_as
                                        
                                        	Accept either real AS or local AS from the ebgp peer
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.LocalAs, self).__init__()

                                            self.yang_name = "local-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                            ])
                                            self.as_no = None
                                            self.no_prepend = None
                                            self.replace_as = None
                                            self.dual_as = None
                                            self._segment_path = lambda: "local-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                    class LogNeighborChanges(Entity):
                                        """
                                        Log neighbor up/down and reset reason
                                        
                                        .. attribute:: disable
                                        
                                        	disable
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.LogNeighborChanges, self).__init__()

                                            self.yang_name = "log-neighbor-changes"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "log-neighbor-changes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.NextHopSelf, ['all'], name, value)


                                    class Password(Entity):
                                        """
                                        Set a password
                                        
                                        .. attribute:: enctype
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: text
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                            ])
                                            self.enctype = None
                                            self.text = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Password, ['enctype', 'text'], name, value)


                                    class PathAttribute(Entity):
                                        """
                                        BGP optional attribute filtering
                                        
                                        .. attribute:: discard
                                        
                                        	Discard matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard>`
                                        
                                        .. attribute:: treat_as_withdraw
                                        
                                        	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute, self).__init__()

                                            self.yang_name = "path-attribute"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw))])
                                            self._leafs = OrderedDict()

                                            self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard()
                                            self.discard.parent = self
                                            self._children_name_map["discard"] = "discard"

                                            self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw()
                                            self.treat_as_withdraw.parent = self
                                            self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                            self._segment_path = lambda: "path-attribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute, [], name, value)


                                        class Discard(Entity):
                                            """
                                            Discard matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard, self).__init__()

                                                self.yang_name = "discard"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "discard"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class TreatAsWithdraw(Entity):
                                            """
                                            Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                self.yang_name = "treat-as-withdraw"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "treat-as-withdraw"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        Member of the peer\-group
                                        
                                        .. attribute:: peer_group_name
                                        
                                        	peer\-group name
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                            ])
                                            self.peer_group_name = None
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Timers(Entity):
                                        """
                                        BGP per neighbor timers
                                        
                                        .. attribute:: keepalive_interval
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: holdtime
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: minimum_neighbor_hold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Timers, self).__init__()

                                            self.yang_name = "timers"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                            ])
                                            self.keepalive_interval = None
                                            self.holdtime = None
                                            self.minimum_neighbor_hold = None
                                            self._segment_path = lambda: "timers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                    class Transport(Entity):
                                        """
                                        Transport options
                                        
                                        .. attribute:: connection_mode
                                        
                                        	Specify passive or active connection
                                        	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Transport.ConnectionMode>`
                                        
                                        .. attribute:: multi_session
                                        
                                        	Use multi\-session for transport
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: path_mtu_discovery
                                        
                                        	Use transport path MTU discovery
                                        	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Transport.PathMtuDiscovery>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Transport, self).__init__()

                                            self.yang_name = "transport"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Transport.PathMtuDiscovery))])
                                            self._leafs = OrderedDict([
                                                ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Transport.ConnectionMode')])),
                                                ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                            ])
                                            self.connection_mode = None
                                            self.multi_session = None

                                            self.path_mtu_discovery = None
                                            self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                            self._segment_path = lambda: "transport"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                        class ConnectionMode(Enum):
                                            """
                                            ConnectionMode (Enum Class)

                                            Specify passive or active connection

                                            .. data:: active = 0

                                            .. data:: passive = 1

                                            """

                                            active = Enum.YLeaf(0, "active")

                                            passive = Enum.YLeaf(1, "passive")



                                        class PathMtuDiscovery(Entity):
                                            """
                                            Use transport path MTU discovery
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                self.yang_name = "path-mtu-discovery"
                                                self.yang_parent_name = "transport"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "path-mtu-discovery"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                    class TtlSecurity(Entity):
                                        """
                                        BGP ttl security check
                                        
                                        .. attribute:: hops
                                        
                                        	IP hops
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.TtlSecurity, self).__init__()

                                            self.yang_name = "ttl-security"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                            ])
                                            self.hops = None
                                            self._segment_path = lambda: "ttl-security"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.TtlSecurity, ['hops'], name, value)


                                    class UpdateSource(Entity):
                                        """
                                        Source of routing updates
                                        
                                        .. attribute:: appnav_compress
                                        
                                        	Service\-Context Virtual Interface Compress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: appnav_uncompress
                                        
                                        	Service\-Context Virtual Interface UnCompress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm
                                        
                                        	ATM interface
                                        	**type**\: str
                                        
                                        .. attribute:: atm_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.ATMSubinterface>`
                                        
                                        .. attribute:: atm_acr
                                        
                                        	ATM\-ACR interface
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9]
                                        
                                        .. attribute:: atm_acrsubinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.ATMACRsubinterface>`
                                        
                                        .. attribute:: bdi
                                        
                                        	Bridge\-Domain interface
                                        	**type**\: str
                                        
                                        .. attribute:: cem
                                        
                                        	CEM interface
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9]/){2}[0\-9]
                                        
                                        .. attribute:: cem_acr
                                        
                                        	CEM\-ACR interface
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: embedded_service_engine
                                        
                                        	cisco embedded service engine module
                                        	**type**\: str
                                        
                                        .. attribute:: ethernet
                                        
                                        	IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: fastethernet
                                        
                                        	FastEthernet IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: gigabitethernet
                                        
                                        	GigabitEthernet IEEE 802.3z
                                        	**type**\: str
                                        
                                        .. attribute:: fivegigabitethernet
                                        
                                        	Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twentyfivegige
                                        
                                        	Twenty Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twogigabitethernet
                                        
                                        	Two GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: fortygigabitethernet
                                        
                                        	Forty GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: hundredgige
                                        
                                        	Hundred GigabitEthernet
                                        	**type**\: str
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_subinterface
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.LISPSubinterface>`
                                        
                                        .. attribute:: loopback
                                        
                                        	Loopback interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multilink
                                        
                                        	Multilink\-group interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: nve
                                        
                                        	Network virtualization endpoint interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: overlay
                                        
                                        	Overlay interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: port_channel
                                        
                                        	Ethernet Channel of interfaces
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: port_channel_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.PortChannelSubinterface>`
                                        
                                        .. attribute:: pseudowire
                                        
                                        	Pseudowire Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sm
                                        
                                        	SM Interface
                                        	**type**\: str
                                        
                                        .. attribute:: cellular
                                        
                                        	Cellular Interface
                                        	**type**\: str
                                        
                                        .. attribute:: serial
                                        
                                        	Serial interface
                                        	**type**\: str
                                        
                                        .. attribute:: tengigabitethernet
                                        
                                        	Ten Gigabit Ethernet
                                        	**type**\: str
                                        
                                        .. attribute:: tunnel
                                        
                                        	Tunnel interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_template
                                        
                                        	Virtual Template interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vlan
                                        
                                        	Iosxr Vlans
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: virtualportgroup
                                        
                                        	Virtual Port Group
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasileft
                                        
                                        	vasileft
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasiright
                                        
                                        	vasiright
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource, self).__init__()

                                            self.yang_name = "update-source"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.PortChannelSubinterface))])
                                            self._leafs = OrderedDict([
                                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                            ])
                                            self.appnav_compress = None
                                            self.appnav_uncompress = None
                                            self.atm = None
                                            self.atm_acr = None
                                            self.bdi = None
                                            self.cem = None
                                            self.cem_acr = None
                                            self.embedded_service_engine = None
                                            self.ethernet = None
                                            self.fastethernet = None
                                            self.gigabitethernet = None
                                            self.fivegigabitethernet = None
                                            self.twentyfivegige = None
                                            self.twogigabitethernet = None
                                            self.fortygigabitethernet = None
                                            self.hundredgige = None
                                            self.lisp = None
                                            self.loopback = None
                                            self.multilink = None
                                            self.nve = None
                                            self.overlay = None
                                            self.port_channel = None
                                            self.pseudowire = None
                                            self.sm = None
                                            self.cellular = None
                                            self.serial = None
                                            self.tengigabitethernet = None
                                            self.tunnel = None
                                            self.virtual_template = None
                                            self.vlan = None
                                            self.virtualportgroup = None
                                            self.vasileft = None
                                            self.vasiright = None

                                            self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.ATMSubinterface()
                                            self.atm_subinterface.parent = self
                                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                            self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.ATMACRsubinterface()
                                            self.atm_acrsubinterface.parent = self
                                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                            self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.LISPSubinterface()
                                            self.lisp_subinterface.parent = self
                                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                            self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.PortChannelSubinterface()
                                            self.port_channel_subinterface.parent = self
                                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                            self._segment_path = lambda: "update-source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                        class ATMSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                self.yang_name = "ATM-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ])
                                                self.atm = None
                                                self._segment_path = lambda: "ATM-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                        class ATMACRsubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm_acr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                self.yang_name = "ATM-ACRsubinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ])
                                                self.atm_acr = None
                                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                        class LISPSubinterface(Entity):
                                            """
                                            Locator/ID Separation Protocol Virtual Interface
                                            
                                            .. attribute:: lisp
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                self.yang_name = "LISP-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ])
                                                self.lisp = None
                                                self._segment_path = lambda: "LISP-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                        class PortChannelSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: port_channel
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                self.yang_name = "Port-channel-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                ])
                                                self.port_channel = None
                                                self._segment_path = lambda: "Port-channel-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Network(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: evpn
                                    
                                    	Advertise or export to EVPN address\-family
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "ipv6-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                            ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self.evpn = None
                                        self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Network, ['number', 'route_map', 'backdoor', 'evpn'], name, value)


                                class Redistribute(Entity):
                                    """
                                    Redistribute information from another routing protocol
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Application>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Bgp_>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: dvmrp
                                    
                                    	Redistribution of DVMRP into BGP IPv4 Multicast
                                    	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Dvmrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator/ID Separation Protocol
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Lisp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Rip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute, self).__init__()

                                        self.yang_name = "redistribute"
                                        self.yang_parent_name = "ipv6-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static))])
                                        self._leafs = OrderedDict()

                                        self.application = None
                                        self._children_name_map["application"] = "application"

                                        self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.dvmrp = None
                                        self._children_name_map["dvmrp"] = "dvmrp"

                                        self.eigrp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Eigrp()
                                        self.eigrp.parent = self
                                        self._children_name_map["eigrp"] = "eigrp"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.lisp = None
                                        self._children_name_map["lisp"] = "lisp"

                                        self.iso_igrp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp()
                                        self.iso_igrp.parent = self
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.rip = None
                                        self._children_name_map["rip"] = "rip"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "redistribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Application.Name>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Application.Name))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Application, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	WORD \:\: Route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Application.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                    class Bgp_(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.as_no = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                    class Dvmrp(Entity):
                                        """
                                        Redistribution of DVMRP into BGP IPv4 Multicast
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Dvmrp, self).__init__()

                                            self.yang_name = "dvmrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "dvmrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.as_no = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "eigrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.IsisArea>`
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.Default>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.Default))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.default = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis, [], name, value)


                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: routes
                                            
                                            	
                                            	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.IsisArea.Routes>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                    ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                    ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.IsisArea.Routes')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.ip = None
                                                self.clns = None
                                                self.routes = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                            class Routes(Enum):
                                                """
                                                Routes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class Default(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: routes
                                            
                                            	
                                            	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.Default.Routes>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                    ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                    ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.Default.Routes')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.ip = None
                                                self.clns = None
                                                self.routes = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                            class Routes(Enum):
                                                """
                                                Routes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class Lisp(Entity):
                                        """
                                        Locator/ID Separation Protocol
                                        
                                        .. attribute:: include_connected
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.include_connected = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: iso_igrp_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp.Default>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp.Default))])
                                            self._leafs = OrderedDict()

                                            self.default = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.iso_igrp_area = YList(self)
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp, [], name, value)


                                        class IsoIgrpArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                                self.yang_name = "iso-igrp-area"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.name = None
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                        class Default(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.Vrf_>`
                                        
                                        .. attribute:: non_vrf
                                        
                                        	
                                        	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.NonVrf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.Vrf_)), ("non-vrf", ("non_vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.NonVrf))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.non_vrf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.NonVrf()
                                            self.non_vrf.parent = self
                                            self._children_name_map["non_vrf"] = "non-vrf"

                                            self.vrf = YList(self)
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf, ['id'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VPN Routing/Forwarding Instance
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.Vrf_.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.Vrf_.Match))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.Vrf_.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.Vrf_, ['name', 'metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.Vrf_.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True


                                        class NonVrf(Entity):
                                            """
                                            
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.NonVrf.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.NonVrf, self).__init__()

                                                self.yang_name = "non-vrf"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.NonVrf.Match))])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.NonVrf.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "non-vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                .. attribute:: internal
                                                
                                                	Redistribute OSPF internal routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: external
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: external2
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: nssa_external
                                                
                                                	Redistribute OSPF NSSA external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "non-vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                        ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.internal = None
                                                    self.external = None
                                                    self.external2 = None
                                                    self.nssa_external = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospfv3.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospfv3.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospfv3.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: external2
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospfv3.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                    ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.internal = None
                                                self.external = None
                                                self.external2 = None
                                                self.nssa_external = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: name
                                        
                                        	User selected string identifying this process
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self.name = None
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static.Clns>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ip
                                        
                                        	
                                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static.Ip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static.Ip))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None

                                            self.clns = None
                                            self._children_name_map["clns"] = "clns"

                                            self.ip = None
                                            self._children_name_map["ip"] = "ip"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                        class Clns(Entity):
                                            """
                                            Redistribution of OSI dynamic routes
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static.Clns, self).__init__()

                                                self.yang_name = "clns"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "clns"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                        class Ip(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static.Ip, self).__init__()

                                                self.yang_name = "ip"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                                class Snmp(Entity):
                                    """
                                    Modify snmp parameters
                                    
                                    .. attribute:: context
                                    
                                    	Configure a SNMP context
                                    	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp.Context>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp, self).__init__()

                                        self.yang_name = "snmp"
                                        self.yang_parent_name = "ipv6-multicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp.Context))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.context = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp.Context()
                                        self.context.parent = self
                                        self._children_name_map["context"] = "context"
                                        self._segment_path = lambda: "snmp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp, [], name, value)


                                    class Context(Entity):
                                        """
                                        Configure a SNMP context
                                        
                                        .. attribute:: context_word
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp.Context.ContextWord>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp.Context, self).__init__()

                                            self.yang_name = "context"
                                            self.yang_parent_name = "snmp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp.Context.ContextWord))])
                                            self._leafs = OrderedDict()

                                            self.context_word = YList(self)
                                            self._segment_path = lambda: "context"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp.Context, [], name, value)


                                        class ContextWord(Entity):
                                            """
                                            
                                            
                                            .. attribute:: context_word  (key)
                                            
                                            	Context Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp.Context.ContextWord, self).__init__()

                                                self.yang_name = "context_word"
                                                self.yang_parent_name = "context"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['context_word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                ])
                                                self.context_word = None
                                                self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Multicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class Ipv6Flowspec(Entity):
                                """
                                IPv6 Flowspec VRF address family
                                
                                .. attribute:: aggregate_address
                                
                                	Configure BGP aggregate entries
                                	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.AggregateAddress>`
                                
                                .. attribute:: bgp
                                
                                	
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_>`
                                
                                .. attribute:: default_information
                                
                                	Control distribution of default information
                                	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.DefaultInformation>`
                                
                                .. attribute:: default_metric
                                
                                	Set metric of redistributed routes
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: distance
                                
                                	Define an administrative distance
                                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance>`
                                
                                .. attribute:: import_
                                
                                	Configure path import
                                	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import>`
                                
                                .. attribute:: maximum_paths
                                
                                	Forward packets over multiple paths
                                	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths>`
                                
                                .. attribute:: peer_group
                                
                                	
                                	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup>`
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor>`
                                
                                .. attribute:: network
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Network>`
                                
                                .. attribute:: redistribute
                                
                                	Redistribute information from another routing protocol
                                	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute>`
                                
                                .. attribute:: snmp
                                
                                	Modify snmp parameters
                                	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec, self).__init__()

                                    self.yang_name = "ipv6-flowspec"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance)), ("import", ("import_", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp))])
                                    self._leafs = OrderedDict([
                                        ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                    ])
                                    self.default_metric = None

                                    self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.default_information = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.DefaultInformation()
                                    self.default_information.parent = self
                                    self._children_name_map["default_information"] = "default-information"

                                    self.distance = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"

                                    self.import_ = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import()
                                    self.import_.parent = self
                                    self._children_name_map["import_"] = "import"

                                    self.maximum_paths = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths()
                                    self.maximum_paths.parent = self
                                    self._children_name_map["maximum_paths"] = "maximum-paths"

                                    self.peer_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup()
                                    self.peer_group.parent = self
                                    self._children_name_map["peer_group"] = "peer-group"

                                    self.redistribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute()
                                    self.redistribute.parent = self
                                    self._children_name_map["redistribute"] = "redistribute"

                                    self.snmp = None
                                    self._children_name_map["snmp"] = "snmp"

                                    self.aggregate_address = YList(self)
                                    self.neighbor = YList(self)
                                    self.network = YList(self)
                                    self._segment_path = lambda: "ipv6-flowspec"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec, ['default_metric'], name, value)


                                class AggregateAddress(Entity):
                                    """
                                    Configure BGP aggregate entries
                                    
                                    .. attribute:: ipv6_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: advertise_map
                                    
                                    	Set condition to advertise attribute
                                    	**type**\: str
                                    
                                    .. attribute:: as_set
                                    
                                    	Generate AS set path information
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: attribute_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: as_override
                                    
                                    	Override matching AS\-number while sending update
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: route_map
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: summary_only
                                    
                                    	Filter more specific routes from updates
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: suppress_map
                                    
                                    	Conditionally filter more specific routes from updates
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.AggregateAddress, self).__init__()

                                        self.yang_name = "aggregate-address"
                                        self.yang_parent_name = "ipv6-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ipv6_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                            ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                            ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                            ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                            ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                        ])
                                        self.ipv6_address = None
                                        self.advertise_map = None
                                        self.as_set = None
                                        self.attribute_map = None
                                        self.as_override = None
                                        self.route_map = None
                                        self.summary_only = None
                                        self.suppress_map = None
                                        self._segment_path = lambda: "aggregate-address" + "[ipv6-address='" + str(self.ipv6_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.AggregateAddress, ['ipv6_address', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                                class Bgp_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	bgp route\-map commands
                                    	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.RouteMap>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "ipv6-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer))])
                                        self._leafs = OrderedDict()

                                        self.route_map = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.RouteMap()
                                        self.route_map.parent = self
                                        self._children_name_map["route_map"] = "route-map"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_, [], name, value)


                                    class RouteMap(Entity):
                                        """
                                        bgp route\-map commands
                                        
                                        .. attribute:: priority
                                        
                                        	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                            ])
                                            self.priority = None
                                            self._segment_path = lambda: "route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.RouteMap, ['priority'], name, value)


                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: disable
                                            
                                            	Disable slow\-peer detection
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.disable = None
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class DefaultInformation(Entity):
                                    """
                                    Control distribution of default information
                                    
                                    .. attribute:: originate
                                    
                                    	Distribute a default route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.DefaultInformation, self).__init__()

                                        self.yang_name = "default-information"
                                        self.yang_parent_name = "ipv6-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                        ])
                                        self.originate = None
                                        self._segment_path = lambda: "default-information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.DefaultInformation, ['originate'], name, value)


                                class Distance(Entity):
                                    """
                                    Define an administrative distance
                                    
                                    .. attribute:: bgp
                                    
                                    	BGP distance
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance.Bgp_>`
                                    
                                    .. attribute:: adm_distance
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance.AdmDistance>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "ipv6-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance.AdmDistance))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.adm_distance = YList(self)
                                        self._segment_path = lambda: "distance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        BGP distance
                                        
                                        .. attribute:: extern_as
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: internal_as
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: local
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "distance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                                ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                                ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                            ])
                                            self.extern_as = None
                                            self.internal_as = None
                                            self.local = None
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                    class AdmDistance(Entity):
                                        """
                                        
                                        
                                        .. attribute:: distance  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: srcip  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: wildbits  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: acl
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..99
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..1999
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance.AdmDistance, self).__init__()

                                            self.yang_name = "adm-distance"
                                            self.yang_parent_name = "distance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['distance','srcip','wildbits']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                                ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                                ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                                ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                            ])
                                            self.distance = None
                                            self.srcip = None
                                            self.wildbits = None
                                            self.acl = None
                                            self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                                class Import(Entity):
                                    """
                                    Configure path import
                                    
                                    .. attribute:: path
                                    
                                    	Path selection and path limit
                                    	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Path>`
                                    
                                    .. attribute:: vpnv4
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Vpnv4>`
                                    
                                    .. attribute:: vpnv6
                                    
                                    	
                                    	**type**\:  :py:class:`Vpnv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Vpnv6>`
                                    
                                    .. attribute:: l2vpn
                                    
                                    	Configure EVPN to VPN path import
                                    	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.L2vpn>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import, self).__init__()

                                        self.yang_name = "import"
                                        self.yang_parent_name = "ipv6-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Path)), ("vpnv4", ("vpnv4", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Vpnv4)), ("vpnv6", ("vpnv6", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Vpnv6)), ("l2vpn", ("l2vpn", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.L2vpn))])
                                        self._leafs = OrderedDict()

                                        self.path = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Path()
                                        self.path.parent = self
                                        self._children_name_map["path"] = "path"

                                        self.vpnv4 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Vpnv4()
                                        self.vpnv4.parent = self
                                        self._children_name_map["vpnv4"] = "vpnv4"

                                        self.vpnv6 = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Vpnv6()
                                        self.vpnv6.parent = self
                                        self._children_name_map["vpnv6"] = "vpnv6"

                                        self.l2vpn = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.L2vpn()
                                        self.l2vpn.parent = self
                                        self._children_name_map["l2vpn"] = "l2vpn"
                                        self._segment_path = lambda: "import"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import, [], name, value)


                                    class Path(Entity):
                                        """
                                        Path selection and path limit
                                        
                                        .. attribute:: limit
                                        
                                        	Per net imported path limit
                                        	**type**\: int
                                        
                                        	**range:** 2..255
                                        
                                        .. attribute:: selection
                                        
                                        	Path selection policy
                                        	**type**\:  :py:class:`Selection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Path.Selection>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("selection", ("selection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Path.Selection))])
                                            self._leafs = OrderedDict([
                                                ('limit', (YLeaf(YType.uint8, 'limit'), ['int'])),
                                            ])
                                            self.limit = None

                                            self.selection = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Path.Selection()
                                            self.selection.parent = self
                                            self._children_name_map["selection"] = "selection"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Path, ['limit'], name, value)


                                        class Selection(Entity):
                                            """
                                            Path selection policy
                                            
                                            .. attribute:: all
                                            
                                            	Import all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Path.Selection, self).__init__()

                                                self.yang_name = "selection"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "selection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Path.Selection, ['all'], name, value)


                                    class Vpnv4(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Vpnv4, self).__init__()

                                            self.yang_name = "vpnv4"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv4"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Vpnv4, ['unicast', 're_originate'], name, value)


                                    class Vpnv6(Entity):
                                        """
                                        
                                        
                                        .. attribute:: unicast
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	Imported path with RT re\-originate
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Vpnv6, self).__init__()

                                            self.yang_name = "vpnv6"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.unicast = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "vpnv6"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.Vpnv6, ['unicast', 're_originate'], name, value)


                                    class L2vpn(Entity):
                                        """
                                        Configure EVPN to VPN path import
                                        
                                        .. attribute:: evpn
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: re_originate
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.L2vpn, self).__init__()

                                            self.yang_name = "l2vpn"
                                            self.yang_parent_name = "import"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                                ('re_originate', (YLeaf(YType.empty, 're-originate'), ['Empty'])),
                                            ])
                                            self.evpn = None
                                            self.re_originate = None
                                            self._segment_path = lambda: "l2vpn"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Import.L2vpn, ['evpn', 're_originate'], name, value)


                                class MaximumPaths(Entity):
                                    """
                                    Forward packets over multiple paths
                                    
                                    .. attribute:: ebgp
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: eibgp
                                    
                                    	Both eBGP and iBGP paths as multipath
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: ibgp
                                    
                                    	iBGP\-multipath
                                    	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths.Ibgp>`
                                    
                                    .. attribute:: external_rtfilter
                                    
                                    	VPN prefix multipath on external RT\-Filter peers
                                    	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths.ExternalRtfilter>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths, self).__init__()

                                        self.yang_name = "maximum-paths"
                                        self.yang_parent_name = "ipv6-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths.ExternalRtfilter))])
                                        self._leafs = OrderedDict([
                                            ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                            ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                        ])
                                        self.ebgp = None
                                        self.eibgp = None

                                        self.ibgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths.Ibgp()
                                        self.ibgp.parent = self
                                        self._children_name_map["ibgp"] = "ibgp"

                                        self.external_rtfilter = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths.ExternalRtfilter()
                                        self.external_rtfilter.parent = self
                                        self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                        self._segment_path = lambda: "maximum-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                    class Ibgp(Entity):
                                        """
                                        iBGP\-multipath
                                        
                                        .. attribute:: unequal_cost
                                        
                                        	Perform un\-equal cost multipath selection
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: max
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths.Ibgp, self).__init__()

                                            self.yang_name = "ibgp"
                                            self.yang_parent_name = "maximum-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                            ])
                                            self.unequal_cost = None
                                            self.max = None
                                            self._segment_path = lambda: "ibgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                    class ExternalRtfilter(Entity):
                                        """
                                        VPN prefix multipath on external RT\-Filter peers
                                        
                                        .. attribute:: max
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths.ExternalRtfilter, self).__init__()

                                            self.yang_name = "external-rtfilter"
                                            self.yang_parent_name = "maximum-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                            ])
                                            self.max = None
                                            self._segment_path = lambda: "external-rtfilter"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                class PeerGroup(Entity):
                                    """
                                    
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup, self).__init__()

                                        self.yang_name = "peer-group"
                                        self.yang_parent_name = "ipv6-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor))])
                                        self._leafs = OrderedDict()

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "peer-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: peer_group
                                        
                                        	Member of the peer\-group
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: cluster_id
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	Neighbor specific description
                                        	**type**\: str
                                        
                                        .. attribute:: disable_connected_check
                                        
                                        	one\-hop away EBGP peer using loopback address
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: ebgp_multihop
                                        
                                        	Allow EBGP neighbors not on directly connected networks
                                        	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.EbgpMultihop>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: fall_over
                                        
                                        	session fall on peer route lost
                                        	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.FallOver>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ha_mode
                                        
                                        	high availability mode
                                        	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Inherit>`
                                        
                                        .. attribute:: local_as
                                        
                                        	Specify a local\-as number
                                        	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.LocalAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: log_neighbor_changes
                                        
                                        	Log neighbor up/down and reset reason
                                        	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.LogNeighborChanges>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: password
                                        
                                        	Set a password
                                        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Password>`
                                        
                                        .. attribute:: path_attribute
                                        
                                        	BGP optional attribute filtering
                                        	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute>`
                                        
                                        .. attribute:: remote_as
                                        
                                        	Specify a BGP peer\-group remote\-as
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: shutdown
                                        
                                        	Administratively shut down this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: timers
                                        
                                        	BGP per neighbor timers
                                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Timers>`
                                        
                                        .. attribute:: transport
                                        
                                        	Transport options
                                        	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Transport>`
                                        
                                        .. attribute:: ttl_security
                                        
                                        	BGP ttl security check
                                        	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.TtlSecurity>`
                                        
                                        .. attribute:: update_source
                                        
                                        	Source of routing updates
                                        	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource>`
                                        
                                        .. attribute:: version
                                        
                                        	Set the BGP version to match a neighbor
                                        	**type**\: int
                                        
                                        	**range:** 4..None
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "peer-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.AllowasIn)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.FallOver)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Timers)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ('peer_group', (YLeaf(YType.empty, 'peer-group'), ['Empty'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.peer_group = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.cluster_id = None
                                            self.description = None
                                            self.disable_connected_check = None
                                            self.next_hop_unchanged = None
                                            self.remote_as = None
                                            self.route_reflector_client = None
                                            self.shutdown = None
                                            self.soft_reconfiguration = None
                                            self.version = None
                                            self.weight = None

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.ebgp_multihop = None
                                            self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                            self.fall_over = None
                                            self._children_name_map["fall_over"] = "fall-over"

                                            self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode()
                                            self.ha_mode.parent = self
                                            self._children_name_map["ha_mode"] = "ha-mode"

                                            self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.local_as = None
                                            self._children_name_map["local_as"] = "local-as"

                                            self.log_neighbor_changes = None
                                            self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                            self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Password()
                                            self.password.parent = self
                                            self._children_name_map["password"] = "password"

                                            self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute()
                                            self.path_attribute.parent = self
                                            self._children_name_map["path_attribute"] = "path-attribute"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Timers()
                                            self.timers.parent = self
                                            self._children_name_map["timers"] = "timers"

                                            self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Transport()
                                            self.transport.parent = self
                                            self._children_name_map["transport"] = "transport"

                                            self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.TtlSecurity()
                                            self.ttl_security.parent = self
                                            self._children_name_map["ttl_security"] = "ttl-security"

                                            self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource()
                                            self.update_source.parent = self
                                            self._children_name_map["update_source"] = "update-source"

                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor, ['id', 'peer_group', 'activate', 'advertisement_interval', 'cluster_id', 'description', 'disable_connected_check', 'next_hop_unchanged', 'remote_as', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'version', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class EbgpMultihop(Entity):
                                            """
                                            Allow EBGP neighbors not on directly connected networks
                                            
                                            .. attribute:: max_hop
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.EbgpMultihop, self).__init__()

                                                self.yang_name = "ebgp-multihop"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                                ])
                                                self.max_hop = None
                                                self._segment_path = lambda: "ebgp-multihop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                        class FallOver(Entity):
                                            """
                                            session fall on peer route lost
                                            
                                            .. attribute:: bfd
                                            
                                            	Use BFD to detect failure
                                            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.FallOver.Bfd>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.FallOver, self).__init__()

                                                self.yang_name = "fall-over"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.FallOver.Bfd))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.route_map_name = None

                                                self.bfd = None
                                                self._children_name_map["bfd"] = "bfd"
                                                self._segment_path = lambda: "fall-over"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.FallOver, ['route_map_name'], name, value)


                                            class Bfd(Entity):
                                                """
                                                Use BFD to detect failure
                                                
                                                .. attribute:: multi_hop
                                                
                                                	Force BFD multi\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: single_hop
                                                
                                                	Force BFD single\-hop to detect failure
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: check_control_plane_failure
                                                
                                                	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: strict_mode
                                                
                                                	Enable BFD strict\-mode
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.FallOver.Bfd, self).__init__()

                                                    self.yang_name = "bfd"
                                                    self.yang_parent_name = "fall-over"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                        ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                        ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                        ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                    ])
                                                    self.multi_hop = None
                                                    self.single_hop = None
                                                    self.check_control_plane_failure = None
                                                    self.strict_mode = None
                                                    self._segment_path = lambda: "bfd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                        class HaMode(Entity):
                                            """
                                            high availability mode
                                            
                                            .. attribute:: graceful_restart
                                            
                                            	graceful\-restart for this peer
                                            	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode.GracefulRestart>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: sso
                                            
                                            	stateful\-switchover support for this peer
                                            	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode.Sso>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode, self).__init__()

                                                self.yang_name = "ha-mode"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode.Sso))])
                                                self._leafs = OrderedDict()

                                                self.graceful_restart = None
                                                self._children_name_map["graceful_restart"] = "graceful-restart"

                                                self.sso = None
                                                self._children_name_map["sso"] = "sso"
                                                self._segment_path = lambda: "ha-mode"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode, [], name, value)


                                            class GracefulRestart(Entity):
                                                """
                                                graceful\-restart for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable graceful\-restart
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                    self.yang_name = "graceful-restart"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "graceful-restart"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                            class Sso(Entity):
                                                """
                                                stateful\-switchover support for this peer
                                                
                                                .. attribute:: disable
                                                
                                                	disable stateful\-switchover
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode.Sso, self).__init__()

                                                    self.yang_name = "sso"
                                                    self.yang_parent_name = "ha-mode"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "sso"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.HaMode.Sso, ['disable'], name, value)


                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class LocalAs(Entity):
                                            """
                                            Specify a local\-as number
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: no_prepend
                                            
                                            	Do not prepend local\-as to updates from ebgp peers
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace real AS with local AS in the EBGP updates
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: dual_as
                                            
                                            	Accept either real AS or local AS from the ebgp peer
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.LocalAs, self).__init__()

                                                self.yang_name = "local-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                    ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                                ])
                                                self.as_no = None
                                                self.no_prepend = None
                                                self.replace_as = None
                                                self.dual_as = None
                                                self._segment_path = lambda: "local-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                        class LogNeighborChanges(Entity):
                                            """
                                            Log neighbor up/down and reset reason
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.LogNeighborChanges, self).__init__()

                                                self.yang_name = "log-neighbor-changes"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "log-neighbor-changes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                        class Password(Entity):
                                            """
                                            Set a password
                                            
                                            .. attribute:: enctype
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..7
                                            
                                            .. attribute:: text
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Password, self).__init__()

                                                self.yang_name = "password"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                                ])
                                                self.enctype = None
                                                self.text = None
                                                self._segment_path = lambda: "password"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Password, ['enctype', 'text'], name, value)


                                        class PathAttribute(Entity):
                                            """
                                            BGP optional attribute filtering
                                            
                                            .. attribute:: discard
                                            
                                            	Discard matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard>`
                                            
                                            .. attribute:: treat_as_withdraw
                                            
                                            	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute, self).__init__()

                                                self.yang_name = "path-attribute"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw))])
                                                self._leafs = OrderedDict()

                                                self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard()
                                                self.discard.parent = self
                                                self._children_name_map["discard"] = "discard"

                                                self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw()
                                                self.treat_as_withdraw.parent = self
                                                self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                                self._segment_path = lambda: "path-attribute"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute, [], name, value)


                                            class Discard(Entity):
                                                """
                                                Discard matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard, self).__init__()

                                                    self.yang_name = "discard"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "discard"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "discard"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                            class TreatAsWithdraw(Entity):
                                                """
                                                Treat\-as\-withdraw matching path\-attribute for this neighbor
                                                
                                                .. attribute:: attibute_type
                                                
                                                	
                                                	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                    self.yang_name = "treat-as-withdraw"
                                                    self.yang_parent_name = "path-attribute"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                    self.attibute_type.parent = self
                                                    self._children_name_map["attibute_type"] = "attibute_type"

                                                    self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                    self.range.parent = self
                                                    self._children_name_map["range"] = "range"
                                                    self._segment_path = lambda: "treat-as-withdraw"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                                class AttibuteType(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: type
                                                    
                                                    	path attribute type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                        self.yang_name = "attibute_type"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.type = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "attibute_type"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: start_value
                                                    
                                                    	path attribute range start value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: end_value
                                                    
                                                    	path attribute range end value
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..255
                                                    
                                                    .. attribute:: in_
                                                    
                                                    	Perform inbound path\-attribute filtering
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "treat-as-withdraw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                            ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                        ])
                                                        self.start_value = None
                                                        self.end_value = None
                                                        self.in_ = None
                                                        self._segment_path = lambda: "range"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class Timers(Entity):
                                            """
                                            BGP per neighbor timers
                                            
                                            .. attribute:: keepalive_interval
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: holdtime
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: minimum_neighbor_hold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Timers, self).__init__()

                                                self.yang_name = "timers"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                    ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                    ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                                ])
                                                self.keepalive_interval = None
                                                self.holdtime = None
                                                self.minimum_neighbor_hold = None
                                                self._segment_path = lambda: "timers"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                        class Transport(Entity):
                                            """
                                            Transport options
                                            
                                            .. attribute:: connection_mode
                                            
                                            	Specify passive or active connection
                                            	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Transport.ConnectionMode>`
                                            
                                            .. attribute:: multi_session
                                            
                                            	Use multi\-session for transport
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: path_mtu_discovery
                                            
                                            	Use transport path MTU discovery
                                            	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Transport.PathMtuDiscovery>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Transport, self).__init__()

                                                self.yang_name = "transport"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Transport.PathMtuDiscovery))])
                                                self._leafs = OrderedDict([
                                                    ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Transport.ConnectionMode')])),
                                                    ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                                ])
                                                self.connection_mode = None
                                                self.multi_session = None

                                                self.path_mtu_discovery = None
                                                self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                                self._segment_path = lambda: "transport"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                            class ConnectionMode(Enum):
                                                """
                                                ConnectionMode (Enum Class)

                                                Specify passive or active connection

                                                .. data:: active = 0

                                                .. data:: passive = 1

                                                """

                                                active = Enum.YLeaf(0, "active")

                                                passive = Enum.YLeaf(1, "passive")



                                            class PathMtuDiscovery(Entity):
                                                """
                                                Use transport path MTU discovery
                                                
                                                .. attribute:: disable
                                                
                                                	disable
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                    self.yang_name = "path-mtu-discovery"
                                                    self.yang_parent_name = "transport"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "path-mtu-discovery"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                        class TtlSecurity(Entity):
                                            """
                                            BGP ttl security check
                                            
                                            .. attribute:: hops
                                            
                                            	IP hops
                                            	**type**\: int
                                            
                                            	**range:** 1..254
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.TtlSecurity, self).__init__()

                                                self.yang_name = "ttl-security"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                                ])
                                                self.hops = None
                                                self._segment_path = lambda: "ttl-security"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.TtlSecurity, ['hops'], name, value)


                                        class UpdateSource(Entity):
                                            """
                                            Source of routing updates
                                            
                                            .. attribute:: appnav_compress
                                            
                                            	Service\-Context Virtual Interface Compress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: appnav_uncompress
                                            
                                            	Service\-Context Virtual Interface UnCompress
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm
                                            
                                            	ATM interface
                                            	**type**\: str
                                            
                                            .. attribute:: atm_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.ATMSubinterface>`
                                            
                                            .. attribute:: atm_acr
                                            
                                            	ATM\-ACR interface
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]
                                            
                                            .. attribute:: atm_acrsubinterface
                                            
                                            	
                                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface>`
                                            
                                            .. attribute:: bdi
                                            
                                            	Bridge\-Domain interface
                                            	**type**\: str
                                            
                                            .. attribute:: cem
                                            
                                            	CEM interface
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9]/){2}[0\-9]
                                            
                                            .. attribute:: cem_acr
                                            
                                            	CEM\-ACR interface
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: embedded_service_engine
                                            
                                            	cisco embedded service engine module
                                            	**type**\: str
                                            
                                            .. attribute:: ethernet
                                            
                                            	IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: fastethernet
                                            
                                            	FastEthernet IEEE 802.3
                                            	**type**\: str
                                            
                                            .. attribute:: gigabitethernet
                                            
                                            	GigabitEthernet IEEE 802.3z
                                            	**type**\: str
                                            
                                            .. attribute:: fivegigabitethernet
                                            
                                            	Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twentyfivegige
                                            
                                            	Twenty Five GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: twogigabitethernet
                                            
                                            	Two GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: fortygigabitethernet
                                            
                                            	Forty GigabitEthernet 
                                            	**type**\: str
                                            
                                            .. attribute:: hundredgige
                                            
                                            	Hundred GigabitEthernet
                                            	**type**\: str
                                            
                                            .. attribute:: lisp
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\: str
                                            
                                            .. attribute:: lisp_subinterface
                                            
                                            	Locator/ID Separation Protocol Virtual Interface
                                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.LISPSubinterface>`
                                            
                                            .. attribute:: loopback
                                            
                                            	Loopback interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multilink
                                            
                                            	Multilink\-group interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: nve
                                            
                                            	Network virtualization endpoint interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: overlay
                                            
                                            	Overlay interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: port_channel
                                            
                                            	Ethernet Channel of interfaces
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: port_channel_subinterface
                                            
                                            	
                                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface>`
                                            
                                            .. attribute:: pseudowire
                                            
                                            	Pseudowire Interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sm
                                            
                                            	SM Interface
                                            	**type**\: str
                                            
                                            .. attribute:: cellular
                                            
                                            	Cellular Interface
                                            	**type**\: str
                                            
                                            .. attribute:: serial
                                            
                                            	Serial interface
                                            	**type**\: str
                                            
                                            .. attribute:: tengigabitethernet
                                            
                                            	Ten Gigabit Ethernet
                                            	**type**\: str
                                            
                                            .. attribute:: tunnel
                                            
                                            	Tunnel interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_template
                                            
                                            	Virtual Template interface
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vlan
                                            
                                            	Iosxr Vlans
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: virtualportgroup
                                            
                                            	Virtual Port Group
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasileft
                                            
                                            	vasileft
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vasiright
                                            
                                            	vasiright
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource, self).__init__()

                                                self.yang_name = "update-source"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface))])
                                                self._leafs = OrderedDict([
                                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                                ])
                                                self.appnav_compress = None
                                                self.appnav_uncompress = None
                                                self.atm = None
                                                self.atm_acr = None
                                                self.bdi = None
                                                self.cem = None
                                                self.cem_acr = None
                                                self.embedded_service_engine = None
                                                self.ethernet = None
                                                self.fastethernet = None
                                                self.gigabitethernet = None
                                                self.fivegigabitethernet = None
                                                self.twentyfivegige = None
                                                self.twogigabitethernet = None
                                                self.fortygigabitethernet = None
                                                self.hundredgige = None
                                                self.lisp = None
                                                self.loopback = None
                                                self.multilink = None
                                                self.nve = None
                                                self.overlay = None
                                                self.port_channel = None
                                                self.pseudowire = None
                                                self.sm = None
                                                self.cellular = None
                                                self.serial = None
                                                self.tengigabitethernet = None
                                                self.tunnel = None
                                                self.virtual_template = None
                                                self.vlan = None
                                                self.virtualportgroup = None
                                                self.vasileft = None
                                                self.vasiright = None

                                                self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.ATMSubinterface()
                                                self.atm_subinterface.parent = self
                                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                                self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface()
                                                self.atm_acrsubinterface.parent = self
                                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                                self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.LISPSubinterface()
                                                self.lisp_subinterface.parent = self
                                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                                self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface()
                                                self.port_channel_subinterface.parent = self
                                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                                self._segment_path = lambda: "update-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                            class ATMSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                    self.yang_name = "ATM-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                    ])
                                                    self.atm = None
                                                    self._segment_path = lambda: "ATM-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                            class ATMACRsubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: atm_acr
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                    self.yang_name = "ATM-ACRsubinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                    ])
                                                    self.atm_acr = None
                                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                            class LISPSubinterface(Entity):
                                                """
                                                Locator/ID Separation Protocol Virtual Interface
                                                
                                                .. attribute:: lisp
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                    self.yang_name = "LISP-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                    ])
                                                    self.lisp = None
                                                    self._segment_path = lambda: "LISP-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                            class PortChannelSubinterface(Entity):
                                                """
                                                
                                                
                                                .. attribute:: port_channel
                                                
                                                	
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                    self.yang_name = "Port-channel-subinterface"
                                                    self.yang_parent_name = "update-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                    ])
                                                    self.port_channel = None
                                                    self._segment_path = lambda: "Port-channel-subinterface"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_as
                                    
                                    	Specify a BGP peer\-group remote\-as
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: cluster_id
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	Neighbor specific description
                                    	**type**\: str
                                    
                                    .. attribute:: disable_connected_check
                                    
                                    	one\-hop away EBGP peer using loopback address
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ebgp_multihop
                                    
                                    	Allow EBGP neighbors not on directly connected networks
                                    	**type**\:  :py:class:`EbgpMultihop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.EbgpMultihop>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fall_over
                                    
                                    	session fall on peer route lost
                                    	**type**\:  :py:class:`FallOver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.FallOver>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ha_mode
                                    
                                    	high availability mode
                                    	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Inherit>`
                                    
                                    .. attribute:: local_as
                                    
                                    	Specify a local\-as number
                                    	**type**\:  :py:class:`LocalAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.LocalAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: log_neighbor_changes
                                    
                                    	Log neighbor up/down and reset reason
                                    	**type**\:  :py:class:`LogNeighborChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.LogNeighborChanges>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: password
                                    
                                    	Set a password
                                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Password>`
                                    
                                    .. attribute:: path_attribute
                                    
                                    	BGP optional attribute filtering
                                    	**type**\:  :py:class:`PathAttribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	Member of the peer\-group
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PeerGroup>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: shutdown
                                    
                                    	Administratively shut down this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: timers
                                    
                                    	BGP per neighbor timers
                                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Timers>`
                                    
                                    .. attribute:: transport
                                    
                                    	Transport options
                                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Transport>`
                                    
                                    .. attribute:: ttl_security
                                    
                                    	BGP ttl security check
                                    	**type**\:  :py:class:`TtlSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.TtlSecurity>`
                                    
                                    .. attribute:: update_source
                                    
                                    	Source of routing updates
                                    	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource>`
                                    
                                    .. attribute:: version
                                    
                                    	Set the BGP version to match a neighbor
                                    	**type**\: int
                                    
                                    	**range:** 4..None
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "ipv6-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.AllowasIn)), ("ebgp-multihop", ("ebgp_multihop", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.EbgpMultihop)), ("fall-over", ("fall_over", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.FallOver)), ("ha-mode", ("ha_mode", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Inherit)), ("local-as", ("local_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.LocalAs)), ("log-neighbor-changes", ("log_neighbor_changes", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.LogNeighborChanges)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.NextHopSelf)), ("password", ("password", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Password)), ("path-attribute", ("path_attribute", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PeerGroup)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer)), ("timers", ("timers", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Timers)), ("transport", ("transport", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Transport)), ("ttl-security", ("ttl_security", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.TtlSecurity)), ("update-source", ("update_source", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                            ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('cluster_id', (YLeaf(YType.str, 'cluster-id'), ['int','str'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('disable_connected_check', (YLeaf(YType.empty, 'disable-connected-check'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SoftReconfiguration')])),
                                            ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.remote_as = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.cluster_id = None
                                        self.description = None
                                        self.disable_connected_check = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.shutdown = None
                                        self.soft_reconfiguration = None
                                        self.version = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.ebgp_multihop = None
                                        self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                        self.fall_over = None
                                        self._children_name_map["fall_over"] = "fall-over"

                                        self.ha_mode = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode()
                                        self.ha_mode.parent = self
                                        self._children_name_map["ha_mode"] = "ha-mode"

                                        self.inherit = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.local_as = None
                                        self._children_name_map["local_as"] = "local-as"

                                        self.log_neighbor_changes = None
                                        self._children_name_map["log_neighbor_changes"] = "log-neighbor-changes"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.password = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Password()
                                        self.password.parent = self
                                        self._children_name_map["password"] = "password"

                                        self.path_attribute = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute()
                                        self.path_attribute.parent = self
                                        self._children_name_map["path_attribute"] = "path-attribute"

                                        self.peer_group = None
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.timers = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Timers()
                                        self.timers.parent = self
                                        self._children_name_map["timers"] = "timers"

                                        self.transport = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Transport()
                                        self.transport.parent = self
                                        self._children_name_map["transport"] = "transport"

                                        self.ttl_security = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.TtlSecurity()
                                        self.ttl_security.parent = self
                                        self._children_name_map["ttl_security"] = "ttl-security"

                                        self.update_source = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource()
                                        self.update_source.parent = self
                                        self._children_name_map["update_source"] = "update-source"

                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor, ['id', 'remote_as', 'activate', 'advertisement_interval', 'cluster_id', 'description', 'disable_connected_check', 'next_hop_unchanged', 'route_reflector_client', 'shutdown', 'soft_reconfiguration', 'version', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class EbgpMultihop(Entity):
                                        """
                                        Allow EBGP neighbors not on directly connected networks
                                        
                                        .. attribute:: max_hop
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.EbgpMultihop, self).__init__()

                                            self.yang_name = "ebgp-multihop"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('max_hop', (YLeaf(YType.uint8, 'max-hop'), ['int'])),
                                            ])
                                            self.max_hop = None
                                            self._segment_path = lambda: "ebgp-multihop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.EbgpMultihop, ['max_hop'], name, value)


                                    class FallOver(Entity):
                                        """
                                        session fall on peer route lost
                                        
                                        .. attribute:: bfd
                                        
                                        	Use BFD to detect failure
                                        	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.FallOver.Bfd>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.FallOver, self).__init__()

                                            self.yang_name = "fall-over"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bfd", ("bfd", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.FallOver.Bfd))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.route_map_name = None

                                            self.bfd = None
                                            self._children_name_map["bfd"] = "bfd"
                                            self._segment_path = lambda: "fall-over"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.FallOver, ['route_map_name'], name, value)


                                        class Bfd(Entity):
                                            """
                                            Use BFD to detect failure
                                            
                                            .. attribute:: multi_hop
                                            
                                            	Force BFD multi\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: single_hop
                                            
                                            	Force BFD single\-hop to detect failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: check_control_plane_failure
                                            
                                            	Retrieve control plane dependent failure info from BFD for BGP GR/NSR operation
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: strict_mode
                                            
                                            	Enable BFD strict\-mode
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.FallOver.Bfd, self).__init__()

                                                self.yang_name = "bfd"
                                                self.yang_parent_name = "fall-over"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('multi_hop', (YLeaf(YType.empty, 'multi-hop'), ['Empty'])),
                                                    ('single_hop', (YLeaf(YType.empty, 'single-hop'), ['Empty'])),
                                                    ('check_control_plane_failure', (YLeaf(YType.empty, 'check-control-plane-failure'), ['Empty'])),
                                                    ('strict_mode', (YLeaf(YType.empty, 'strict-mode'), ['Empty'])),
                                                ])
                                                self.multi_hop = None
                                                self.single_hop = None
                                                self.check_control_plane_failure = None
                                                self.strict_mode = None
                                                self._segment_path = lambda: "bfd"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.FallOver.Bfd, ['multi_hop', 'single_hop', 'check_control_plane_failure', 'strict_mode'], name, value)


                                    class HaMode(Entity):
                                        """
                                        high availability mode
                                        
                                        .. attribute:: graceful_restart
                                        
                                        	graceful\-restart for this peer
                                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode.GracefulRestart>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: sso
                                        
                                        	stateful\-switchover support for this peer
                                        	**type**\:  :py:class:`Sso <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode.Sso>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode, self).__init__()

                                            self.yang_name = "ha-mode"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode.GracefulRestart)), ("sso", ("sso", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode.Sso))])
                                            self._leafs = OrderedDict()

                                            self.graceful_restart = None
                                            self._children_name_map["graceful_restart"] = "graceful-restart"

                                            self.sso = None
                                            self._children_name_map["sso"] = "sso"
                                            self._segment_path = lambda: "ha-mode"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode, [], name, value)


                                        class GracefulRestart(Entity):
                                            """
                                            graceful\-restart for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable graceful\-restart
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode.GracefulRestart, self).__init__()

                                                self.yang_name = "graceful-restart"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "graceful-restart"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode.GracefulRestart, ['disable'], name, value)


                                        class Sso(Entity):
                                            """
                                            stateful\-switchover support for this peer
                                            
                                            .. attribute:: disable
                                            
                                            	disable stateful\-switchover
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode.Sso, self).__init__()

                                                self.yang_name = "sso"
                                                self.yang_parent_name = "ha-mode"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "sso"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.HaMode.Sso, ['disable'], name, value)


                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class LocalAs(Entity):
                                        """
                                        Specify a local\-as number
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: no_prepend
                                        
                                        	Do not prepend local\-as to updates from ebgp peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace real AS with local AS in the EBGP updates
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: dual_as
                                        
                                        	Accept either real AS or local AS from the ebgp peer
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.LocalAs, self).__init__()

                                            self.yang_name = "local-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                ('no_prepend', (YLeaf(YType.empty, 'no-prepend'), ['Empty'])),
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ('dual_as', (YLeaf(YType.empty, 'dual-as'), ['Empty'])),
                                            ])
                                            self.as_no = None
                                            self.no_prepend = None
                                            self.replace_as = None
                                            self.dual_as = None
                                            self._segment_path = lambda: "local-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.LocalAs, ['as_no', 'no_prepend', 'replace_as', 'dual_as'], name, value)


                                    class LogNeighborChanges(Entity):
                                        """
                                        Log neighbor up/down and reset reason
                                        
                                        .. attribute:: disable
                                        
                                        	disable
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.LogNeighborChanges, self).__init__()

                                            self.yang_name = "log-neighbor-changes"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "log-neighbor-changes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.LogNeighborChanges, ['disable'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.NextHopSelf, ['all'], name, value)


                                    class Password(Entity):
                                        """
                                        Set a password
                                        
                                        .. attribute:: enctype
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..7
                                        
                                        .. attribute:: text
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Password, self).__init__()

                                            self.yang_name = "password"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                            ])
                                            self.enctype = None
                                            self.text = None
                                            self._segment_path = lambda: "password"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Password, ['enctype', 'text'], name, value)


                                    class PathAttribute(Entity):
                                        """
                                        BGP optional attribute filtering
                                        
                                        .. attribute:: discard
                                        
                                        	Discard matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`Discard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard>`
                                        
                                        .. attribute:: treat_as_withdraw
                                        
                                        	Treat\-as\-withdraw matching path\-attribute for this neighbor
                                        	**type**\:  :py:class:`TreatAsWithdraw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute, self).__init__()

                                            self.yang_name = "path-attribute"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("discard", ("discard", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard)), ("treat-as-withdraw", ("treat_as_withdraw", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw))])
                                            self._leafs = OrderedDict()

                                            self.discard = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard()
                                            self.discard.parent = self
                                            self._children_name_map["discard"] = "discard"

                                            self.treat_as_withdraw = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw()
                                            self.treat_as_withdraw.parent = self
                                            self._children_name_map["treat_as_withdraw"] = "treat-as-withdraw"
                                            self._segment_path = lambda: "path-attribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute, [], name, value)


                                        class Discard(Entity):
                                            """
                                            Discard matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard, self).__init__()

                                                self.yang_name = "discard"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "discard"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "discard"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.Discard.Range, ['start_value', 'end_value', 'in_'], name, value)


                                        class TreatAsWithdraw(Entity):
                                            """
                                            Treat\-as\-withdraw matching path\-attribute for this neighbor
                                            
                                            .. attribute:: attibute_type
                                            
                                            	
                                            	**type**\:  :py:class:`AttibuteType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType>`
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\:  :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw, self).__init__()

                                                self.yang_name = "treat-as-withdraw"
                                                self.yang_parent_name = "path-attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("attibute_type", ("attibute_type", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType)), ("range", ("range", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.Range))])
                                                self._leafs = OrderedDict()

                                                self.attibute_type = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType()
                                                self.attibute_type.parent = self
                                                self._children_name_map["attibute_type"] = "attibute_type"

                                                self.range = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.Range()
                                                self.range.parent = self
                                                self._children_name_map["range"] = "range"
                                                self._segment_path = lambda: "treat-as-withdraw"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw, [], name, value)


                                            class AttibuteType(Entity):
                                                """
                                                
                                                
                                                .. attribute:: type
                                                
                                                	path attribute type
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, self).__init__()

                                                    self.yang_name = "attibute_type"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.type = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "attibute_type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.AttibuteType, ['type', 'in_'], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: start_value
                                                
                                                	path attribute range start value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: end_value
                                                
                                                	path attribute range end value
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: in_
                                                
                                                	Perform inbound path\-attribute filtering
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "treat-as-withdraw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('start_value', (YLeaf(YType.uint8, 'start_value'), ['int'])),
                                                        ('end_value', (YLeaf(YType.uint8, 'end_value'), ['int'])),
                                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                                    ])
                                                    self.start_value = None
                                                    self.end_value = None
                                                    self.in_ = None
                                                    self._segment_path = lambda: "range"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PathAttribute.TreatAsWithdraw.Range, ['start_value', 'end_value', 'in_'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        Member of the peer\-group
                                        
                                        .. attribute:: peer_group_name
                                        
                                        	peer\-group name
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                            ])
                                            self.peer_group_name = None
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Timers(Entity):
                                        """
                                        BGP per neighbor timers
                                        
                                        .. attribute:: keepalive_interval
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: holdtime
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: minimum_neighbor_hold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Timers, self).__init__()

                                            self.yang_name = "timers"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                                                ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                                                ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                                            ])
                                            self.keepalive_interval = None
                                            self.holdtime = None
                                            self.minimum_neighbor_hold = None
                                            self._segment_path = lambda: "timers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Timers, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


                                    class Transport(Entity):
                                        """
                                        Transport options
                                        
                                        .. attribute:: connection_mode
                                        
                                        	Specify passive or active connection
                                        	**type**\:  :py:class:`ConnectionMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Transport.ConnectionMode>`
                                        
                                        .. attribute:: multi_session
                                        
                                        	Use multi\-session for transport
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: path_mtu_discovery
                                        
                                        	Use transport path MTU discovery
                                        	**type**\:  :py:class:`PathMtuDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Transport.PathMtuDiscovery>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Transport, self).__init__()

                                            self.yang_name = "transport"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("path-mtu-discovery", ("path_mtu_discovery", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Transport.PathMtuDiscovery))])
                                            self._leafs = OrderedDict([
                                                ('connection_mode', (YLeaf(YType.enumeration, 'connection-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Transport.ConnectionMode')])),
                                                ('multi_session', (YLeaf(YType.empty, 'multi-session'), ['Empty'])),
                                            ])
                                            self.connection_mode = None
                                            self.multi_session = None

                                            self.path_mtu_discovery = None
                                            self._children_name_map["path_mtu_discovery"] = "path-mtu-discovery"
                                            self._segment_path = lambda: "transport"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Transport, ['connection_mode', 'multi_session'], name, value)

                                        class ConnectionMode(Enum):
                                            """
                                            ConnectionMode (Enum Class)

                                            Specify passive or active connection

                                            .. data:: active = 0

                                            .. data:: passive = 1

                                            """

                                            active = Enum.YLeaf(0, "active")

                                            passive = Enum.YLeaf(1, "passive")



                                        class PathMtuDiscovery(Entity):
                                            """
                                            Use transport path MTU discovery
                                            
                                            .. attribute:: disable
                                            
                                            	disable
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Transport.PathMtuDiscovery, self).__init__()

                                                self.yang_name = "path-mtu-discovery"
                                                self.yang_parent_name = "transport"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "path-mtu-discovery"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.Transport.PathMtuDiscovery, ['disable'], name, value)


                                    class TtlSecurity(Entity):
                                        """
                                        BGP ttl security check
                                        
                                        .. attribute:: hops
                                        
                                        	IP hops
                                        	**type**\: int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.TtlSecurity, self).__init__()

                                            self.yang_name = "ttl-security"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('hops', (YLeaf(YType.uint8, 'hops'), ['int'])),
                                            ])
                                            self.hops = None
                                            self._segment_path = lambda: "ttl-security"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.TtlSecurity, ['hops'], name, value)


                                    class UpdateSource(Entity):
                                        """
                                        Source of routing updates
                                        
                                        .. attribute:: appnav_compress
                                        
                                        	Service\-Context Virtual Interface Compress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: appnav_uncompress
                                        
                                        	Service\-Context Virtual Interface UnCompress
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm
                                        
                                        	ATM interface
                                        	**type**\: str
                                        
                                        .. attribute:: atm_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.ATMSubinterface>`
                                        
                                        .. attribute:: atm_acr
                                        
                                        	ATM\-ACR interface
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9]
                                        
                                        .. attribute:: atm_acrsubinterface
                                        
                                        	
                                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.ATMACRsubinterface>`
                                        
                                        .. attribute:: bdi
                                        
                                        	Bridge\-Domain interface
                                        	**type**\: str
                                        
                                        .. attribute:: cem
                                        
                                        	CEM interface
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9]/){2}[0\-9]
                                        
                                        .. attribute:: cem_acr
                                        
                                        	CEM\-ACR interface
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: embedded_service_engine
                                        
                                        	cisco embedded service engine module
                                        	**type**\: str
                                        
                                        .. attribute:: ethernet
                                        
                                        	IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: fastethernet
                                        
                                        	FastEthernet IEEE 802.3
                                        	**type**\: str
                                        
                                        .. attribute:: gigabitethernet
                                        
                                        	GigabitEthernet IEEE 802.3z
                                        	**type**\: str
                                        
                                        .. attribute:: fivegigabitethernet
                                        
                                        	Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twentyfivegige
                                        
                                        	Twenty Five GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: twogigabitethernet
                                        
                                        	Two GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: fortygigabitethernet
                                        
                                        	Forty GigabitEthernet 
                                        	**type**\: str
                                        
                                        .. attribute:: hundredgige
                                        
                                        	Hundred GigabitEthernet
                                        	**type**\: str
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\: str
                                        
                                        .. attribute:: lisp_subinterface
                                        
                                        	Locator/ID Separation Protocol Virtual Interface
                                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.LISPSubinterface>`
                                        
                                        .. attribute:: loopback
                                        
                                        	Loopback interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multilink
                                        
                                        	Multilink\-group interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: nve
                                        
                                        	Network virtualization endpoint interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: overlay
                                        
                                        	Overlay interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: port_channel
                                        
                                        	Ethernet Channel of interfaces
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: port_channel_subinterface
                                        
                                        	
                                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.PortChannelSubinterface>`
                                        
                                        .. attribute:: pseudowire
                                        
                                        	Pseudowire Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sm
                                        
                                        	SM Interface
                                        	**type**\: str
                                        
                                        .. attribute:: cellular
                                        
                                        	Cellular Interface
                                        	**type**\: str
                                        
                                        .. attribute:: serial
                                        
                                        	Serial interface
                                        	**type**\: str
                                        
                                        .. attribute:: tengigabitethernet
                                        
                                        	Ten Gigabit Ethernet
                                        	**type**\: str
                                        
                                        .. attribute:: tunnel
                                        
                                        	Tunnel interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_template
                                        
                                        	Virtual Template interface
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vlan
                                        
                                        	Iosxr Vlans
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: virtualportgroup
                                        
                                        	Virtual Port Group
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasileft
                                        
                                        	vasileft
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vasiright
                                        
                                        	vasiright
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource, self).__init__()

                                            self.yang_name = "update-source"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.PortChannelSubinterface))])
                                            self._leafs = OrderedDict([
                                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                            ])
                                            self.appnav_compress = None
                                            self.appnav_uncompress = None
                                            self.atm = None
                                            self.atm_acr = None
                                            self.bdi = None
                                            self.cem = None
                                            self.cem_acr = None
                                            self.embedded_service_engine = None
                                            self.ethernet = None
                                            self.fastethernet = None
                                            self.gigabitethernet = None
                                            self.fivegigabitethernet = None
                                            self.twentyfivegige = None
                                            self.twogigabitethernet = None
                                            self.fortygigabitethernet = None
                                            self.hundredgige = None
                                            self.lisp = None
                                            self.loopback = None
                                            self.multilink = None
                                            self.nve = None
                                            self.overlay = None
                                            self.port_channel = None
                                            self.pseudowire = None
                                            self.sm = None
                                            self.cellular = None
                                            self.serial = None
                                            self.tengigabitethernet = None
                                            self.tunnel = None
                                            self.virtual_template = None
                                            self.vlan = None
                                            self.virtualportgroup = None
                                            self.vasileft = None
                                            self.vasiright = None

                                            self.atm_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.ATMSubinterface()
                                            self.atm_subinterface.parent = self
                                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                            self.atm_acrsubinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.ATMACRsubinterface()
                                            self.atm_acrsubinterface.parent = self
                                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                            self.lisp_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.LISPSubinterface()
                                            self.lisp_subinterface.parent = self
                                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                            self.port_channel_subinterface = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.PortChannelSubinterface()
                                            self.port_channel_subinterface.parent = self
                                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                            self._segment_path = lambda: "update-source"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                        class ATMSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                                self.yang_name = "ATM-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                                ])
                                                self.atm = None
                                                self._segment_path = lambda: "ATM-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                        class ATMACRsubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: atm_acr
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                                self.yang_name = "ATM-ACRsubinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                                ])
                                                self.atm_acr = None
                                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                        class LISPSubinterface(Entity):
                                            """
                                            Locator/ID Separation Protocol Virtual Interface
                                            
                                            .. attribute:: lisp
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                                self.yang_name = "LISP-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                                ])
                                                self.lisp = None
                                                self._segment_path = lambda: "LISP-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                        class PortChannelSubinterface(Entity):
                                            """
                                            
                                            
                                            .. attribute:: port_channel
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                                self.yang_name = "Port-channel-subinterface"
                                                self.yang_parent_name = "update-source"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                                ])
                                                self.port_channel = None
                                                self._segment_path = lambda: "Port-channel-subinterface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                                class Network(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: evpn
                                    
                                    	Advertise or export to EVPN address\-family
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "ipv6-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                            ('evpn', (YLeaf(YType.empty, 'evpn'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self.evpn = None
                                        self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Network, ['number', 'route_map', 'backdoor', 'evpn'], name, value)


                                class Redistribute(Entity):
                                    """
                                    Redistribute information from another routing protocol
                                    
                                    .. attribute:: application
                                    
                                    	Application
                                    	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Application>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: bgp
                                    
                                    	Border Gateway Protocol (BGP)
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Bgp_>`
                                    
                                    .. attribute:: connected
                                    
                                    	Connected
                                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Connected>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: dvmrp
                                    
                                    	Redistribution of DVMRP into BGP IPv4 Multicast
                                    	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Dvmrp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp
                                    
                                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Eigrp>`
                                    
                                    .. attribute:: isis
                                    
                                    	ISO IS\-IS
                                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: lisp
                                    
                                    	Locator/ID Separation Protocol
                                    	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Lisp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: iso_igrp
                                    
                                    	IGRP for OSI networks
                                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp>`
                                    
                                    .. attribute:: mobile
                                    
                                    	Mobile routes
                                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Mobile>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: odr
                                    
                                    	On Demand stub Routes
                                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Odr>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ospf
                                    
                                    	Open Shortest Path First (OSPF)
                                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf>`
                                    
                                    .. attribute:: ospfv3
                                    
                                    	OSPFv3
                                    	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospfv3>`
                                    
                                    .. attribute:: rip
                                    
                                    	Routing Information Protocol (RIP)
                                    	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Rip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: static
                                    
                                    	Static routes
                                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute, self).__init__()

                                        self.yang_name = "redistribute"
                                        self.yang_parent_name = "ipv6-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static))])
                                        self._leafs = OrderedDict()

                                        self.application = None
                                        self._children_name_map["application"] = "application"

                                        self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.connected = None
                                        self._children_name_map["connected"] = "connected"

                                        self.dvmrp = None
                                        self._children_name_map["dvmrp"] = "dvmrp"

                                        self.eigrp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Eigrp()
                                        self.eigrp.parent = self
                                        self._children_name_map["eigrp"] = "eigrp"

                                        self.isis = None
                                        self._children_name_map["isis"] = "isis"

                                        self.lisp = None
                                        self._children_name_map["lisp"] = "lisp"

                                        self.iso_igrp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp()
                                        self.iso_igrp.parent = self
                                        self._children_name_map["iso_igrp"] = "iso-igrp"

                                        self.mobile = None
                                        self._children_name_map["mobile"] = "mobile"

                                        self.odr = None
                                        self._children_name_map["odr"] = "odr"

                                        self.rip = None
                                        self._children_name_map["rip"] = "rip"

                                        self.static = None
                                        self._children_name_map["static"] = "static"

                                        self.ospf = YList(self)
                                        self.ospfv3 = YList(self)
                                        self._segment_path = lambda: "redistribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute, [], name, value)


                                    class Application(Entity):
                                        """
                                        Application
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Application.Name>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Application, self).__init__()

                                            self.yang_name = "application"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Application.Name))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "application"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Application, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	WORD \:\: Route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Application.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "application"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                    class Bgp_(Entity):
                                        """
                                        Border Gateway Protocol (BGP)
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..4294967295
                                        
                                        		**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.as_no = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                    class Connected(Entity):
                                        """
                                        Connected
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Connected, self).__init__()

                                            self.yang_name = "connected"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "connected"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                    class Dvmrp(Entity):
                                        """
                                        Redistribution of DVMRP into BGP IPv4 Multicast
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Dvmrp, self).__init__()

                                            self.yang_name = "dvmrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "dvmrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                    class Eigrp(Entity):
                                        """
                                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        
                                        .. attribute:: as_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Eigrp, self).__init__()

                                            self.yang_name = "eigrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.as_no = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "eigrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                    class Isis(Entity):
                                        """
                                        ISO IS\-IS
                                        
                                        .. attribute:: isis_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.IsisArea>`
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.Default>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis, self).__init__()

                                            self.yang_name = "isis"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.Default))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.default = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.isis_area = YList(self)
                                            self._segment_path = lambda: "isis"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis, [], name, value)


                                        class IsisArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: routes
                                            
                                            	
                                            	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.IsisArea.Routes>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.IsisArea, self).__init__()

                                                self.yang_name = "isis-area"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                    ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                    ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.IsisArea.Routes')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.ip = None
                                                self.clns = None
                                                self.routes = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                            class Routes(Enum):
                                                """
                                                Routes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class Default(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ip
                                            
                                            	Redistribution of IP dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: routes
                                            
                                            	
                                            	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.Default.Routes>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "isis"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                    ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                    ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.Default.Routes')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.ip = None
                                                self.clns = None
                                                self.routes = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                            class Routes(Enum):
                                                """
                                                Routes (Enum Class)

                                                .. data:: level_1 = 0

                                                .. data:: level_2 = 1

                                                .. data:: level_1_2 = 2

                                                """

                                                level_1 = Enum.YLeaf(0, "level-1")

                                                level_2 = Enum.YLeaf(1, "level-2")

                                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class Lisp(Entity):
                                        """
                                        Locator/ID Separation Protocol
                                        
                                        .. attribute:: include_connected
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Lisp, self).__init__()

                                            self.yang_name = "lisp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.include_connected = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "lisp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                    class IsoIgrp(Entity):
                                        """
                                        IGRP for OSI networks
                                        
                                        .. attribute:: iso_igrp_area
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp.IsoIgrpArea>`
                                        
                                        .. attribute:: default
                                        
                                        	
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp.Default>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp, self).__init__()

                                            self.yang_name = "iso-igrp"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp.Default))])
                                            self._leafs = OrderedDict()

                                            self.default = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.iso_igrp_area = YList(self)
                                            self._segment_path = lambda: "iso-igrp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp, [], name, value)


                                        class IsoIgrpArea(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                                self.yang_name = "iso-igrp-area"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.name = None
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                        class Default(Entity):
                                            """
                                            
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "iso-igrp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                    class Mobile(Entity):
                                        """
                                        Mobile routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Mobile, self).__init__()

                                            self.yang_name = "mobile"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "mobile"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                    class Odr(Entity):
                                        """
                                        On Demand stub Routes
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Odr, self).__init__()

                                            self.yang_name = "odr"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "odr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                    class Ospf(Entity):
                                        """
                                        Open Shortest Path First (OSPF)
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: vrf
                                        
                                        	VPN Routing/Forwarding Instance
                                        	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.Vrf_>`
                                        
                                        .. attribute:: non_vrf
                                        
                                        	
                                        	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.NonVrf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf, self).__init__()

                                            self.yang_name = "ospf"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.Vrf_)), ("non-vrf", ("non_vrf", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.NonVrf))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.non_vrf = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.NonVrf()
                                            self.non_vrf.parent = self
                                            self._children_name_map["non_vrf"] = "non-vrf"

                                            self.vrf = YList(self)
                                            self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf, ['id'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VPN Routing/Forwarding Instance
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.Vrf_.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.Vrf_.Match))])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.name = None
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.Vrf_.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.Vrf_, ['name', 'metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.Vrf_.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True


                                        class NonVrf(Entity):
                                            """
                                            
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.NonVrf.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.NonVrf, self).__init__()

                                                self.yang_name = "non-vrf"
                                                self.yang_parent_name = "ospf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.NonVrf.Match))])
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.NonVrf.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "non-vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                .. attribute:: internal
                                                
                                                	Redistribute OSPF internal routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: external
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: external2
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: nssa_external
                                                
                                                	Redistribute OSPF NSSA external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "non-vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                        ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.internal = None
                                                    self.external = None
                                                    self.external2 = None
                                                    self.nssa_external = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                    class Ospfv3(Entity):
                                        """
                                        OSPFv3
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospfv3.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospfv3, self).__init__()

                                            self.yang_name = "ospfv3"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospfv3.Match))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.id = None
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospfv3.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: external2
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospfv3.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "ospfv3"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                    ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.internal = None
                                                self.external = None
                                                self.external2 = None
                                                self.nssa_external = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                    class Rip(Entity):
                                        """
                                        Routing Information Protocol (RIP)
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: name
                                        
                                        	User selected string identifying this process
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Rip, self).__init__()

                                            self.yang_name = "rip"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self.name = None
                                            self._segment_path = lambda: "rip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                    class Static(Entity):
                                        """
                                        Static routes
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static.Clns>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ip
                                        
                                        	
                                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static.Ip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static, self).__init__()

                                            self.yang_name = "static"
                                            self.yang_parent_name = "redistribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static.Ip))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None

                                            self.clns = None
                                            self._children_name_map["clns"] = "clns"

                                            self.ip = None
                                            self._children_name_map["ip"] = "ip"
                                            self._segment_path = lambda: "static"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static, ['metric', 'route_map'], name, value)


                                        class Clns(Entity):
                                            """
                                            Redistribution of OSI dynamic routes
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static.Clns, self).__init__()

                                                self.yang_name = "clns"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "clns"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                        class Ip(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static.Ip, self).__init__()

                                                self.yang_name = "ip"
                                                self.yang_parent_name = "static"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                                class Snmp(Entity):
                                    """
                                    Modify snmp parameters
                                    
                                    .. attribute:: context
                                    
                                    	Configure a SNMP context
                                    	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp.Context>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp, self).__init__()

                                        self.yang_name = "snmp"
                                        self.yang_parent_name = "ipv6-flowspec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp.Context))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.context = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp.Context()
                                        self.context.parent = self
                                        self._children_name_map["context"] = "context"
                                        self._segment_path = lambda: "snmp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp, [], name, value)


                                    class Context(Entity):
                                        """
                                        Configure a SNMP context
                                        
                                        .. attribute:: context_word
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp.Context.ContextWord>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp.Context, self).__init__()

                                            self.yang_name = "context"
                                            self.yang_parent_name = "snmp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp.Context.ContextWord))])
                                            self._leafs = OrderedDict()

                                            self.context_word = YList(self)
                                            self._segment_path = lambda: "context"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp.Context, [], name, value)


                                        class ContextWord(Entity):
                                            """
                                            
                                            
                                            .. attribute:: context_word  (key)
                                            
                                            	Context Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp.Context.ContextWord, self).__init__()

                                                self.yang_name = "context_word"
                                                self.yang_parent_name = "context"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['context_word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                ])
                                                self.context_word = None
                                                self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Flowspec.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class Ipv6Mvpn(Entity):
                                """
                                IPv6 Unicast VRF address family
                                
                                .. attribute:: bgp
                                
                                	
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn, self).__init__()

                                    self.yang_name = "ipv6-mvpn"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_))])
                                    self._leafs = OrderedDict()

                                    self.bgp = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"
                                    self._segment_path = lambda: "ipv6-mvpn"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn, [], name, value)


                                class Bgp_(Entity):
                                    """
                                    
                                    
                                    .. attribute:: dampening
                                    
                                    	Enable route\-flap dampening
                                    	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_.Dampening>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "ipv6-mvpn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampening", ("dampening", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_.Dampening))])
                                        self._leafs = OrderedDict()

                                        self.dampening = None
                                        self._children_name_map["dampening"] = "dampening"
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_, [], name, value)


                                    class Dampening(Entity):
                                        """
                                        Enable route\-flap dampening
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria for dampening
                                        	**type**\: str
                                        
                                        .. attribute:: dampen
                                        
                                        	
                                        	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_.Dampening.Dampen>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "bgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_.Dampening.Dampen))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.dampen = Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_.Dampening.Dampen()
                                            self.dampen.parent = self
                                            self._children_name_map["dampen"] = "dampen"
                                            self._segment_path = lambda: "dampening"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_.Dampening, ['route_map'], name, value)


                                        class Dampen(Entity):
                                            """
                                            
                                            
                                            .. attribute:: half_life_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..45
                                            
                                            .. attribute:: reuse_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..20000
                                            
                                            .. attribute:: max_suppress_time
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_.Dampening.Dampen, self).__init__()

                                                self.yang_name = "dampen"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                    ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                    ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                    ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                ])
                                                self.half_life_time = None
                                                self.reuse_time = None
                                                self.suppress_time = None
                                                self.max_suppress_time = None
                                                self._segment_path = lambda: "dampen"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.WithVrf.Ipv6.Vrf.Ipv6Mvpn.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                class NoVrf(Entity):
                    """
                    
                    
                    .. attribute:: ipv4
                    
                    	Address family
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4>`
                    
                    .. attribute:: ipv6
                    
                    	Address family
                    	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6>`
                    
                    .. attribute:: vpnv4
                    
                    	Address family
                    	**type**\: list of  		 :py:class:`Vpnv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4>`
                    
                    .. attribute:: vpnv6
                    
                    	Address family
                    	**type**\: list of  		 :py:class:`Vpnv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6>`
                    
                    .. attribute:: nsap
                    
                    	Address family
                    	**type**\: list of  		 :py:class:`Nsap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap>`
                    
                    .. attribute:: l2vpn
                    
                    	Address family
                    	**type**\: list of  		 :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn>`
                    
                    .. attribute:: rtfilter
                    
                    	Address family
                    	**type**\: list of  		 :py:class:`Rtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.AddressFamily.NoVrf, self).__init__()

                        self.yang_name = "no-vrf"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4)), ("ipv6", ("ipv6", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6)), ("vpnv4", ("vpnv4", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4)), ("vpnv6", ("vpnv6", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6)), ("nsap", ("nsap", Native.Router.Bgp.AddressFamily.NoVrf.Nsap)), ("l2vpn", ("l2vpn", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn)), ("rtfilter", ("rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter))])
                        self._leafs = OrderedDict()

                        self.ipv4 = YList(self)
                        self.ipv6 = YList(self)
                        self.vpnv4 = YList(self)
                        self.vpnv6 = YList(self)
                        self.nsap = YList(self)
                        self.l2vpn = YList(self)
                        self.rtfilter = YList(self)
                        self._segment_path = lambda: "no-vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf, [], name, value)


                    class Ipv4(Entity):
                        """
                        Address family
                        
                        .. attribute:: af_name  (key)
                        
                        	
                        	**type**\:  :py:class:`BgpIpv4AfType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.BgpIpv4AfType>`
                        
                        .. attribute:: ipv4_unicast
                        
                        	IPv4 Unicast address family
                        	**type**\:  :py:class:`Ipv4Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast>`
                        
                        .. attribute:: ipv4_multicast
                        
                        	IPv4 Multicast address family
                        	**type**\:  :py:class:`Ipv4Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast>`
                        
                        .. attribute:: ipv4_flowspec
                        
                        	Ipv4 Flowspec address family
                        	**type**\:  :py:class:`Ipv4Flowspec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec>`
                        
                        .. attribute:: ipv4_mvpn
                        
                        	IPv4 MVPN address family
                        	**type**\:  :py:class:`Ipv4Mvpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn>`
                        
                        .. attribute:: ipv4_mdt
                        
                        	IPv4 MDT address family
                        	**type**\:  :py:class:`Ipv4Mdt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "no-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("ipv4-unicast", ("ipv4_unicast", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast)), ("ipv4-multicast", ("ipv4_multicast", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast)), ("ipv4-flowspec", ("ipv4_flowspec", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec)), ("ipv4-mvpn", ("ipv4_mvpn", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn)), ("ipv4-mdt", ("ipv4_mdt", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'BgpIpv4AfType', '')])),
                            ])
                            self.af_name = None

                            self.ipv4_unicast = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast()
                            self.ipv4_unicast.parent = self
                            self._children_name_map["ipv4_unicast"] = "ipv4-unicast"

                            self.ipv4_multicast = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast()
                            self.ipv4_multicast.parent = self
                            self._children_name_map["ipv4_multicast"] = "ipv4-multicast"

                            self.ipv4_flowspec = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec()
                            self.ipv4_flowspec.parent = self
                            self._children_name_map["ipv4_flowspec"] = "ipv4-flowspec"

                            self.ipv4_mvpn = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn()
                            self.ipv4_mvpn.parent = self
                            self._children_name_map["ipv4_mvpn"] = "ipv4-mvpn"

                            self.ipv4_mdt = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt()
                            self.ipv4_mdt.parent = self
                            self._children_name_map["ipv4_mdt"] = "ipv4-mdt"
                            self._segment_path = lambda: "ipv4" + "[af-name='" + str(self.af_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4, ['af_name'], name, value)


                        class Ipv4Unicast(Entity):
                            """
                            IPv4 Unicast address family
                            
                            .. attribute:: aggregate_address
                            
                            	Configure BGP aggregate entries
                            	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress>`
                            
                            .. attribute:: auto_summary
                            
                            	Enable automatic network number summarization
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation>`
                            
                            .. attribute:: default_metric
                            
                            	Set metric of redistributed routes
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: distance
                            
                            	Define an administrative distance
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance>`
                            
                            .. attribute:: distribute_list
                            
                            	Filter networks in routing updates
                            	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList>`
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor>`
                            
                            .. attribute:: network
                            
                            	
                            	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network>`
                            
                            .. attribute:: redistribute
                            
                            	Redistribute information from another routing protocol
                            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute>`
                            
                            .. attribute:: segment_routing
                            
                            	segment\-routing
                            	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: synchronization
                            
                            	Perform IGP synchronization
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: table_map
                            
                            	Map external entry attributes into routing table
                            	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast, self).__init__()

                                self.yang_name = "ipv4-unicast"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute)), ("segment-routing", ("segment_routing", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp)), ("table-map", ("table_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap))])
                                self._leafs = OrderedDict([
                                    ('auto_summary', (YLeaf(YType.empty, 'auto-summary'), ['Empty'])),
                                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                    ('synchronization', (YLeaf(YType.empty, 'synchronization'), ['Empty'])),
                                ])
                                self.auto_summary = None
                                self.default_metric = None
                                self.synchronization = None

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.default_information = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.distance = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.maximum_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths()
                                self.maximum_paths.parent = self
                                self._children_name_map["maximum_paths"] = "maximum-paths"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.network = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network()
                                self.network.parent = self
                                self._children_name_map["network"] = "network"

                                self.redistribute = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute()
                                self.redistribute.parent = self
                                self._children_name_map["redistribute"] = "redistribute"

                                self.segment_routing = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting()
                                self.segment_routing.parent = self
                                self._children_name_map["segment_routing"] = "segment-routing"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.table_map = None
                                self._children_name_map["table_map"] = "table-map"

                                self.aggregate_address = YList(self)
                                self.distribute_list = YList(self)
                                self.neighbor = YList(self)
                                self._segment_path = lambda: "ipv4-unicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast, ['auto_summary', 'default_metric', 'synchronization'], name, value)


                            class AggregateAddress(Entity):
                                """
                                Configure BGP aggregate entries
                                
                                .. attribute:: ipv4_address  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mask  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: advertise_map
                                
                                	Set condition to advertise attribute
                                	**type**\: str
                                
                                .. attribute:: as_set
                                
                                	Generate AS set path information
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: attribute_map
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: as_override
                                
                                	Override matching AS\-number while sending update
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: summary_only
                                
                                	Filter more specific routes from updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: suppress_map
                                
                                	Conditionally filter more specific routes from updates
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress, self).__init__()

                                    self.yang_name = "aggregate-address"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv4_address','ipv4_mask']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mask', (YLeaf(YType.str, 'ipv4-mask'), ['str'])),
                                        ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                        ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                        ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                        ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                    ])
                                    self.ipv4_address = None
                                    self.ipv4_mask = None
                                    self.advertise_map = None
                                    self.as_set = None
                                    self.attribute_map = None
                                    self.as_override = None
                                    self.route_map = None
                                    self.summary_only = None
                                    self.suppress_map = None
                                    self._segment_path = lambda: "aggregate-address" + "[ipv4-address='" + str(self.ipv4_address) + "']" + "[ipv4-mask='" + str(self.ipv4_mask) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress, ['ipv4_address', 'ipv4_mask', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: additional_paths
                                
                                	Additional paths in the BGP table
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths>`
                                
                                .. attribute:: advertise_best_external
                                
                                	Advertise best external path to internal peers
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: aggregate_timer
                                
                                	Configure aggregation timer
                                	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer>`
                                
                                .. attribute:: bestpath
                                
                                	Change the default bestpath selection
                                	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath>`
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: inject_map
                                
                                	Route map which specifies prefixes to inject
                                	**type**\: list of  		 :py:class:`InjectMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop>`
                                
                                .. attribute:: recursion
                                
                                	recursion rule for the nexthops
                                	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion>`
                                
                                .. attribute:: redistribute_internal
                                
                                	Allow redistribution of iBGP into IGPs (dangerous)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: suppress_inactive
                                
                                	Suppress routes that are not in the routing table
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: update_group
                                
                                	Manage peers in bgp update groups
                                	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening)), ("inject-map", ("inject_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup))])
                                    self._leafs = OrderedDict([
                                        ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                        ('suppress_inactive', (YLeaf(YType.empty, 'suppress-inactive'), ['Empty'])),
                                    ])
                                    self.advertise_best_external = None
                                    self.dmzlink_bw = None
                                    self.redistribute_internal = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None
                                    self.suppress_inactive = None

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.aggregate_timer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer()
                                    self.aggregate_timer.parent = self
                                    self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                    self.bestpath = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath()
                                    self.bestpath.parent = self
                                    self._children_name_map["bestpath"] = "bestpath"

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.recursion = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion()
                                    self.recursion.parent = self
                                    self._children_name_map["recursion"] = "recursion"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup()
                                    self.update_group.parent = self
                                    self._children_name_map["update_group"] = "update-group"

                                    self.inject_map = YList(self)
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup', 'suppress_inactive'], name, value)


                                class AdditionalPaths(Entity):
                                    """
                                    Additional paths in the BGP table
                                    
                                    .. attribute:: install
                                    
                                    	Additional paths to install into RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: select
                                    
                                    	Selection criteria to pick the paths
                                    	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to neighbors
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.install = None
                                        self.receive = None

                                        self.select = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select()
                                        self.select.parent = self
                                        self._children_name_map["select"] = "select"

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                    class Select(Entity):
                                        """
                                        Selection criteria to pick the paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: backup
                                        
                                        	Select backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Select best\-external path
                                        	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best path
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                            self.yang_name = "select"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.best_external = None
                                            self._children_name_map["best_external"] = "best-external"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "select"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best path
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best path
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                        class Backup(Entity):
                                            """
                                            Select backup path
                                            
                                            .. attribute:: best_external
                                            
                                            	Select best\-external path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                self._leafs = OrderedDict()

                                                self.range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                        class BestExternal(Entity):
                                            """
                                            Select best\-external path
                                            
                                            .. attribute:: backup
                                            
                                            	Select backup path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                self.yang_name = "best-external"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                ])
                                                self.backup = None
                                                self._segment_path = lambda: "best-external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best path
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to neighbors
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                class AggregateTimer(Entity):
                                    """
                                    Configure aggregation timer
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Timer interval
                                    	**type**\: int
                                    
                                    	**range:** 6..60
                                    
                                    .. attribute:: disable_timer
                                    
                                    	Timer interval
                                    	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer, self).__init__()

                                        self.yang_name = "aggregate-timer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                            ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                        ])
                                        self.aggregate_timer = None
                                        self.disable_timer = None
                                        self._segment_path = lambda: "aggregate-timer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                    class DisableTimer(Enum):
                                        """
                                        DisableTimer (Enum Class)

                                        Timer interval

                                        .. data:: Y_0 = 0

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")



                                class Bestpath(Entity):
                                    """
                                    Change the default bestpath selection
                                    
                                    .. attribute:: igp_metric
                                    
                                    	igp metric
                                    	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric>`
                                    
                                    .. attribute:: prefix_validate
                                    
                                    	Prefix origin validation
                                    	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath, self).__init__()

                                        self.yang_name = "bestpath"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate))])
                                        self._leafs = OrderedDict()

                                        self.igp_metric = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric()
                                        self.igp_metric.parent = self
                                        self._children_name_map["igp_metric"] = "igp-metric"

                                        self.prefix_validate = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate()
                                        self.prefix_validate.parent = self
                                        self._children_name_map["prefix_validate"] = "prefix-validate"
                                        self._segment_path = lambda: "bestpath"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath, [], name, value)


                                    class IgpMetric(Entity):
                                        """
                                        igp metric
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore igp metric in bestpath selection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                            self.yang_name = "igp-metric"
                                            self.yang_parent_name = "bestpath"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ])
                                            self.ignore = None
                                            self._segment_path = lambda: "igp-metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                    class PrefixValidate(Entity):
                                        """
                                        Prefix origin validation
                                        
                                        .. attribute:: allow_invalid
                                        
                                        	Allow invalid routes to be considered for bestpath
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: disable
                                        
                                        	Disable prefix validation
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                            self.yang_name = "prefix-validate"
                                            self.yang_parent_name = "bestpath"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.allow_invalid = None
                                            self.disable = None
                                            self._segment_path = lambda: "prefix-validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria for dampening
                                    	**type**\: str
                                    
                                    .. attribute:: dampen
                                    
                                    	
                                    	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.dampen = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen()
                                        self.dampen.parent = self
                                        self._children_name_map["dampen"] = "dampen"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                    class Dampen(Entity):
                                        """
                                        
                                        
                                        .. attribute:: half_life_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..45
                                        
                                        .. attribute:: reuse_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: max_suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                            self.yang_name = "dampen"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                            ])
                                            self.half_life_time = None
                                            self.reuse_time = None
                                            self.suppress_time = None
                                            self.max_suppress_time = None
                                            self._segment_path = lambda: "dampen"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                class InjectMap(Entity):
                                    """
                                    Route map which specifies prefixes to inject
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: exist_map
                                    
                                    	Route map which specifies exist condition
                                    	**type**\: str
                                    
                                    .. attribute:: copy_attributes
                                    
                                    	Copy attributes from aggregate
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap, self).__init__()

                                        self.yang_name = "inject-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                            ('copy_attributes', (YLeaf(YType.empty, 'copy-attributes'), ['Empty'])),
                                        ])
                                        self.name = None
                                        self.exist_map = None
                                        self.copy_attributes = None
                                        self._segment_path = lambda: "inject-map" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap, ['name', 'exist_map', 'copy_attributes'], name, value)


                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class Recursion(Entity):
                                    """
                                    recursion rule for the nexthops
                                    
                                    .. attribute:: host
                                    
                                    	recursion via host for the nexthops
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion, self).__init__()

                                        self.yang_name = "recursion"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                        ])
                                        self.host = None
                                        self._segment_path = lambda: "recursion"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion, ['host'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    Manage peers in bgp update groups
                                    
                                    .. attribute:: split
                                    
                                    	Split update groups based on Policy
                                    	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split))])
                                        self._leafs = OrderedDict()

                                        self.split = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split()
                                        self.split.parent = self
                                        self._children_name_map["split"] = "split"
                                        self._segment_path = lambda: "update-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup, [], name, value)


                                    class Split(Entity):
                                        """
                                        Split update groups based on Policy
                                        
                                        .. attribute:: as_override
                                        
                                        	Keep peers with as\-override in different update groups
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                            self.yang_name = "split"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ])
                                            self.as_override = None
                                            self._segment_path = lambda: "split"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                    ])
                                    self.originate = None
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation, ['originate'], name, value)


                            class Distance(Entity):
                                """
                                Define an administrative distance
                                
                                .. attribute:: bgp
                                
                                	BGP distance
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_>`
                                
                                .. attribute:: adm_distance
                                
                                	
                                	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance))])
                                    self._leafs = OrderedDict()

                                    self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.adm_distance = YList(self)
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance, [], name, value)


                                class Bgp_(Entity):
                                    """
                                    BGP distance
                                    
                                    .. attribute:: extern_as
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: internal_as
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                            ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                            ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                        ])
                                        self.extern_as = None
                                        self.internal_as = None
                                        self.local = None
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                class AdmDistance(Entity):
                                    """
                                    
                                    
                                    .. attribute:: distance  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: srcip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: wildbits  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: acl
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..99
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..1999
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance, self).__init__()

                                        self.yang_name = "adm-distance"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['distance','srcip','wildbits']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                            ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                            ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                        ])
                                        self.distance = None
                                        self.srcip = None
                                        self.wildbits = None
                                        self.acl = None
                                        self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                            class DistributeList(Entity):
                                """
                                Filter networks in routing updates
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 100..199
                                
                                		**type**\: int
                                
                                			**range:** 2000..2699
                                
                                		**type**\: str
                                
                                			**pattern:** [a\-zA\-Z].\*
                                
                                .. attribute:: in_
                                
                                	Filter incoming routing updates
                                	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: out
                                
                                	Filter outgoing routing updates
                                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList, self).__init__()

                                    self.yang_name = "distribute-list"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("in", ("in_", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In)), ("out", ("out", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['int','int','str'])),
                                    ])
                                    self.id = None

                                    self.in_ = None
                                    self._children_name_map["in_"] = "in"

                                    self.out = None
                                    self._children_name_map["out"] = "out"
                                    self._segment_path = lambda: "distribute-list" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList, ['id'], name, value)


                                class In(Entity):
                                    """
                                    Filter incoming routing updates
                                    
                                    .. attribute:: interface
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In, self).__init__()

                                        self.yang_name = "in"
                                        self.yang_parent_name = "distribute-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ])
                                        self.interface = None
                                        self._segment_path = lambda: "in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In, ['interface'], name, value)


                                class Out(Entity):
                                    """
                                    Filter outgoing routing updates
                                    
                                    .. attribute:: interface
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out, self).__init__()

                                        self.yang_name = "out"
                                        self.yang_parent_name = "distribute-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ])
                                        self.interface = None
                                        self._segment_path = lambda: "out"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out, ['interface'], name, value)


                            class MaximumPaths(Entity):
                                """
                                Forward packets over multiple paths
                                
                                .. attribute:: ebgp
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: eibgp
                                
                                	Both eBGP and iBGP paths as multipath
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: ibgp
                                
                                	iBGP\-multipath
                                	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp>`
                                
                                .. attribute:: external_rtfilter
                                
                                	VPN prefix multipath on external RT\-Filter peers
                                	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths, self).__init__()

                                    self.yang_name = "maximum-paths"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter))])
                                    self._leafs = OrderedDict([
                                        ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                        ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                    ])
                                    self.ebgp = None
                                    self.eibgp = None

                                    self.ibgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"

                                    self.external_rtfilter = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter()
                                    self.external_rtfilter.parent = self
                                    self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                    self._segment_path = lambda: "maximum-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                class Ibgp(Entity):
                                    """
                                    iBGP\-multipath
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Perform un\-equal cost multipath selection
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.unequal_cost = None
                                        self.max = None
                                        self._segment_path = lambda: "ibgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                class ExternalRtfilter(Entity):
                                    """
                                    VPN prefix multipath on external RT\-Filter peers
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                        self.yang_name = "external-rtfilter"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.max = None
                                        self._segment_path = lambda: "external-rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: additional_paths
                                    
                                    	
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths>`
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise to this neighbor
                                    	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise>`
                                    
                                    .. attribute:: advertise_map
                                    
                                    	specify route\-map for conditional advertisement
                                    	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: aigp
                                    
                                    	Enable a AIGP on neighbor
                                    	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: announce
                                    
                                    	Announce RPKI state using an extended community
                                    	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce>`
                                    
                                    .. attribute:: as_override
                                    
                                    	Override matching AS\-number while sending update
                                    	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability>`
                                    
                                    .. attribute:: default_originate
                                    
                                    	Originate default route to this neighbor
                                    	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	Member of the peer\-group
                                    	**type**\:  :py:class:`PeerGroup_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: send_label
                                    
                                    	Send NLRI + MPLS Label to this peer
                                    	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: translate_update
                                    
                                    	Translate update to MBGP format
                                    	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate>`
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise()
                                        self.advertise.parent = self
                                        self._children_name_map["advertise"] = "advertise"

                                        self.advertise_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap()
                                        self.advertise_map.parent = self
                                        self._children_name_map["advertise_map"] = "advertise-map"

                                        self.aigp = None
                                        self._children_name_map["aigp"] = "aigp"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.announce = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce()
                                        self.announce.parent = self
                                        self._children_name_map["announce"] = "announce"

                                        self.as_override = None
                                        self._children_name_map["as_override"] = "as-override"

                                        self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.default_originate = None
                                        self._children_name_map["default_originate"] = "default-originate"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.peer_group = None
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.send_label = None
                                        self._children_name_map["send_label"] = "send-label"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.translate_update = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate()
                                        self.translate_update.parent = self
                                        self._children_name_map["translate_update"] = "translate-update"

                                        self.distribute_list = YList(self)
                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AdditionalPaths(Entity):
                                        """
                                        
                                        
                                        .. attribute:: disable
                                        
                                        	Disable additional paths for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send
                                        
                                        	Send additional paths to this neighbor
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send))])
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self.receive = None

                                            self.send = None
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                        class Send(Entity):
                                            """
                                            Send additional paths to this neighbor
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.receive = None
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                    class Advertise(Entity):
                                        """
                                        Advertise to this neighbor
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Advertise additional paths
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Advertise best\-external (at RRs best\-internal) path
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: diverse_path
                                        
                                        	Advertise diverse path
                                        	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                            self.yang_name = "advertise"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                            self._leafs = OrderedDict([
                                                ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                            ])
                                            self.best_external = None

                                            self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                            self.diverse_path.parent = self
                                            self._children_name_map["diverse_path"] = "diverse-path"
                                            self._segment_path = lambda: "advertise"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Advertise additional paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                            class All(Entity):
                                                """
                                                Select all available paths
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.group_best = None
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.all = None

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "best-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.all = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.all = None
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                        class DiversePath(Entity):
                                            """
                                            Advertise diverse path
                                            
                                            .. attribute:: backup
                                            
                                            	Diverse path can be backup path
                                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                self.yang_name = "diverse-path"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None

                                                self.backup = None
                                                self._children_name_map["backup"] = "backup"
                                                self._segment_path = lambda: "diverse-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                            class Backup(Entity):
                                                """
                                                Diverse path can be backup path
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                    self.yang_name = "backup"
                                                    self.yang_parent_name = "diverse-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None
                                                    self._segment_path = lambda: "backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                    class AdvertiseMap(Entity):
                                        """
                                        specify route\-map for conditional advertisement
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap, self).__init__()

                                            self.yang_name = "advertise-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name))])
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "advertise-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: word  (key)
                                            
                                            	advertise route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: non_exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "advertise-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                    ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                    ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                ])
                                                self.word = None
                                                self.exist_map = None
                                                self.non_exist_map = None
                                                self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                    class Aigp(Entity):
                                        """
                                        Enable a AIGP on neighbor
                                        
                                        .. attribute:: send
                                        
                                        	Cost community or MED carrying AIGP VALUE
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                            self.yang_name = "aigp"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.send = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send()
                                            self.send.parent = self
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "aigp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                        class Send(Entity):
                                            """
                                            Cost community or MED carrying AIGP VALUE
                                            
                                            .. attribute:: cost_community
                                            
                                            	Cost extended community carrying AIGP Value
                                            	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                            
                                            .. attribute:: med
                                            
                                            	Med carrying AIGP Value
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "aigp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                ])
                                                self.med = None

                                                self.cost_community = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                self.cost_community.parent = self
                                                self._children_name_map["cost_community"] = "cost-community"
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                            class CostCommunity(Entity):
                                                """
                                                Cost extended community carrying AIGP Value
                                                
                                                .. attribute:: cc_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                    self.yang_name = "cost-community"
                                                    self.yang_parent_name = "send"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                    self._leafs = OrderedDict()

                                                    self.cc_range = YList(self)
                                                    self._segment_path = lambda: "cost-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                class CcRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Community ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: poi
                                                    
                                                    	Point of insertion
                                                    	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                        self.yang_name = "cc-range"
                                                        self.yang_parent_name = "cost-community"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ])
                                                        self.range = None

                                                        self.poi = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                        self.poi.parent = self
                                                        self._children_name_map["poi"] = "poi"
                                                        self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                    class Poi(Entity):
                                                        """
                                                        Point of insertion
                                                        
                                                        .. attribute:: igp_cost
                                                        
                                                        	Point of insertion after IGP
                                                        	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        .. attribute:: pre_bestpath
                                                        
                                                        	Point of insertion at beginning
                                                        	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                            self.yang_name = "poi"
                                                            self.yang_parent_name = "cc-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                            self._leafs = OrderedDict()

                                                            self.igp_cost = None
                                                            self._children_name_map["igp_cost"] = "igp-cost"

                                                            self.pre_bestpath = None
                                                            self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                            self._segment_path = lambda: "poi"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                        class IgpCost(Entity):
                                                            """
                                                            Point of insertion after IGP
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                self.yang_name = "igp-cost"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "igp-cost"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                        class PreBestpath(Entity):
                                                            """
                                                            Point of insertion at beginning
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                self.yang_name = "pre-bestpath"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "pre-bestpath"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Announce(Entity):
                                        """
                                        Announce RPKI state using an extended community
                                        
                                        .. attribute:: rpki
                                        
                                        	Announce RPKI information using an extended community
                                        	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce, self).__init__()

                                            self.yang_name = "announce"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki))])
                                            self._leafs = OrderedDict()

                                            self.rpki = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki()
                                            self.rpki.parent = self
                                            self._children_name_map["rpki"] = "rpki"
                                            self._segment_path = lambda: "announce"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce, [], name, value)


                                        class Rpki(Entity):
                                            """
                                            Announce RPKI information using an extended community
                                            
                                            .. attribute:: state
                                            
                                            	Announce RPKI state information using an extended community
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki, self).__init__()

                                                self.yang_name = "rpki"
                                                self.yang_parent_name = "announce"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                ])
                                                self.state = None
                                                self._segment_path = lambda: "rpki"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki, ['state'], name, value)


                                    class AsOverride(Entity):
                                        """
                                        Override matching AS\-number while sending update
                                        
                                        .. attribute:: disable
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride, self).__init__()

                                            self.yang_name = "as-override"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "as-override"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride, ['disable'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DefaultOriginate(Entity):
                                        """
                                        Originate default route to this neighbor
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria to originate default
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                            self.yang_name = "default-originate"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "default-originate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                        
                                        .. attribute:: accesslist
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                            ])
                                            self.inout = None
                                            self.accesslist = None
                                            self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PeerGroup_(Entity):
                                        """
                                        Member of the peer\-group
                                        
                                        .. attribute:: peer_group_name
                                        
                                        	peer\-group name
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                            ])
                                            self.peer_group_name = None
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_, ['peer_group_name'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SendLabel(Entity):
                                        """
                                        Send NLRI + MPLS Label to this peer
                                        
                                        .. attribute:: send_label_explicit
                                        
                                        	
                                        	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel, self).__init__()

                                            self.yang_name = "send-label"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit')])),
                                            ])
                                            self.send_label_explicit = None
                                            self._segment_path = lambda: "send-label"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                        class SendLabelExplicit(Enum):
                                            """
                                            SendLabelExplicit (Enum Class)

                                            .. data:: explicit_null = 0

                                            """

                                            explicit_null = Enum.YLeaf(0, "explicit-null")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class TranslateUpdate(Entity):
                                        """
                                        Translate update to MBGP format
                                        
                                        .. attribute:: ipv4
                                        
                                        	Address Family
                                        	**type**\:  :py:class:`Ipv4_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate, self).__init__()

                                            self.yang_name = "translate-update"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_))])
                                            self._leafs = OrderedDict()

                                            self.ipv4 = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_()
                                            self.ipv4.parent = self
                                            self._children_name_map["ipv4"] = "ipv4"
                                            self._segment_path = lambda: "translate-update"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate, [], name, value)


                                        class Ipv4_(Entity):
                                            """
                                            Address Family
                                            
                                            .. attribute:: multicast
                                            
                                            	Address Family modifier
                                            	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_, self).__init__()

                                                self.yang_name = "ipv4"
                                                self.yang_parent_name = "translate-update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast))])
                                                self._leafs = OrderedDict()

                                                self.multicast = None
                                                self._children_name_map["multicast"] = "multicast"
                                                self._segment_path = lambda: "ipv4"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_, [], name, value)


                                            class Multicast(Entity):
                                                """
                                                Address Family modifier
                                                
                                                .. attribute:: unicast
                                                
                                                	Address Family modifier
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast, self).__init__()

                                                    self.yang_name = "multicast"
                                                    self.yang_parent_name = "ipv4"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                    ])
                                                    self.unicast = None
                                                    self._segment_path = lambda: "multicast"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast, ['unicast'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: additional_paths
                                
                                	
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths>`
                                
                                .. attribute:: advertise
                                
                                	Advertise to this neighbor
                                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise>`
                                
                                .. attribute:: advertise_map
                                
                                	specify route\-map for conditional advertisement
                                	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: aigp
                                
                                	Enable a AIGP on neighbor
                                	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: announce
                                
                                	Announce RPKI state using an extended community
                                	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce>`
                                
                                .. attribute:: as_override
                                
                                	Override matching AS\-number while sending update
                                	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: capability
                                
                                	Advertise capability to the peer
                                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability>`
                                
                                .. attribute:: default_originate
                                
                                	Originate default route to this neighbor
                                	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: distribute_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: peer_group
                                
                                	Member of the peer\-group
                                	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: send_label
                                
                                	Send NLRI + MPLS Label to this peer
                                	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: translate_update
                                
                                	Translate update to MBGP format
                                	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate>`
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.dmzlink_bw = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise()
                                    self.advertise.parent = self
                                    self._children_name_map["advertise"] = "advertise"

                                    self.advertise_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap()
                                    self.advertise_map.parent = self
                                    self._children_name_map["advertise_map"] = "advertise-map"

                                    self.aigp = None
                                    self._children_name_map["aigp"] = "aigp"

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.announce = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce()
                                    self.announce.parent = self
                                    self._children_name_map["announce"] = "announce"

                                    self.as_override = None
                                    self._children_name_map["as_override"] = "as-override"

                                    self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability()
                                    self.capability.parent = self
                                    self._children_name_map["capability"] = "capability"

                                    self.default_originate = None
                                    self._children_name_map["default_originate"] = "default-originate"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.peer_group = None
                                    self._children_name_map["peer_group"] = "peer-group"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.send_label = None
                                    self._children_name_map["send_label"] = "send-label"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.translate_update = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate()
                                    self.translate_update.parent = self
                                    self._children_name_map["translate_update"] = "translate-update"

                                    self.distribute_list = YList(self)
                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AdditionalPaths(Entity):
                                    """
                                    
                                    
                                    .. attribute:: disable
                                    
                                    	Disable additional paths for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to this neighbor
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.disable = None
                                        self.receive = None

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to this neighbor
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                class Advertise(Entity):
                                    """
                                    Advertise to this neighbor
                                    
                                    .. attribute:: additional_paths
                                    
                                    	Advertise additional paths
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths>`
                                    
                                    .. attribute:: best_external
                                    
                                    	Advertise best\-external (at RRs best\-internal) path
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: diverse_path
                                    
                                    	Advertise diverse path
                                    	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise, self).__init__()

                                        self.yang_name = "advertise"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath))])
                                        self._leafs = OrderedDict([
                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                        ])
                                        self.best_external = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath()
                                        self.diverse_path.parent = self
                                        self._children_name_map["diverse_path"] = "diverse-path"
                                        self._segment_path = lambda: "advertise"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                    class AdditionalPaths(Entity):
                                        """
                                        Advertise additional paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best paths
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: best_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                self._leafs = OrderedDict()

                                                self.best_range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                            class BestRange(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                    self.yang_name = "best-range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "best-range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                    class DiversePath(Entity):
                                        """
                                        Advertise diverse path
                                        
                                        .. attribute:: backup
                                        
                                        	Diverse path can be backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: mpath
                                        
                                        	Diverse path can be multipath
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                            self.yang_name = "diverse-path"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                            self._leafs = OrderedDict([
                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                            ])
                                            self.mpath = None

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"
                                            self._segment_path = lambda: "diverse-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                        class Backup(Entity):
                                            """
                                            Diverse path can be backup path
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "diverse-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                class AdvertiseMap(Entity):
                                    """
                                    specify route\-map for conditional advertisement
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap, self).__init__()

                                        self.yang_name = "advertise-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name))])
                                        self._leafs = OrderedDict()

                                        self.name = YList(self)
                                        self._segment_path = lambda: "advertise-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap, [], name, value)


                                    class Name(Entity):
                                        """
                                        
                                        
                                        .. attribute:: word  (key)
                                        
                                        	advertise route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: exist_map
                                        
                                        	condition route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: non_exist_map
                                        
                                        	condition route\-map name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name, self).__init__()

                                            self.yang_name = "name"
                                            self.yang_parent_name = "advertise-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                            ])
                                            self.word = None
                                            self.exist_map = None
                                            self.non_exist_map = None
                                            self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                class Aigp(Entity):
                                    """
                                    Enable a AIGP on neighbor
                                    
                                    .. attribute:: send
                                    
                                    	Cost community or MED carrying AIGP VALUE
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp, self).__init__()

                                        self.yang_name = "aigp"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.send = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send()
                                        self.send.parent = self
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "aigp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp, [], name, value)


                                    class Send(Entity):
                                        """
                                        Cost community or MED carrying AIGP VALUE
                                        
                                        .. attribute:: cost_community
                                        
                                        	Cost extended community carrying AIGP Value
                                        	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity>`
                                        
                                        .. attribute:: med
                                        
                                        	Med carrying AIGP Value
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "aigp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity))])
                                            self._leafs = OrderedDict([
                                                ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                            ])
                                            self.med = None

                                            self.cost_community = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity()
                                            self.cost_community.parent = self
                                            self._children_name_map["cost_community"] = "cost-community"
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send, ['med'], name, value)


                                        class CostCommunity(Entity):
                                            """
                                            Cost extended community carrying AIGP Value
                                            
                                            .. attribute:: cc_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                self.yang_name = "cost-community"
                                                self.yang_parent_name = "send"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                self._leafs = OrderedDict()

                                                self.cc_range = YList(self)
                                                self._segment_path = lambda: "cost-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                            class CcRange(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Community ID
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: poi
                                                
                                                	Point of insertion
                                                	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                    self.yang_name = "cc-range"
                                                    self.yang_parent_name = "cost-community"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                    ])
                                                    self.range = None

                                                    self.poi = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                    self.poi.parent = self
                                                    self._children_name_map["poi"] = "poi"
                                                    self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                class Poi(Entity):
                                                    """
                                                    Point of insertion
                                                    
                                                    .. attribute:: igp_cost
                                                    
                                                    	Point of insertion after IGP
                                                    	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: pre_bestpath
                                                    
                                                    	Point of insertion at beginning
                                                    	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                        self.yang_name = "poi"
                                                        self.yang_parent_name = "cc-range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                        self._leafs = OrderedDict()

                                                        self.igp_cost = None
                                                        self._children_name_map["igp_cost"] = "igp-cost"

                                                        self.pre_bestpath = None
                                                        self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                        self._segment_path = lambda: "poi"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                    class IgpCost(Entity):
                                                        """
                                                        Point of insertion after IGP
                                                        
                                                        .. attribute:: transitive
                                                        
                                                        	Cost community is transitive
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                            self.yang_name = "igp-cost"
                                                            self.yang_parent_name = "poi"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                            ])
                                                            self.transitive = None
                                                            self._segment_path = lambda: "igp-cost"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                    class PreBestpath(Entity):
                                                        """
                                                        Point of insertion at beginning
                                                        
                                                        .. attribute:: transitive
                                                        
                                                        	Cost community is transitive
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                            self.yang_name = "pre-bestpath"
                                                            self.yang_parent_name = "poi"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                            ])
                                                            self.transitive = None
                                                            self._segment_path = lambda: "pre-bestpath"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Announce(Entity):
                                    """
                                    Announce RPKI state using an extended community
                                    
                                    .. attribute:: rpki
                                    
                                    	Announce RPKI information using an extended community
                                    	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce, self).__init__()

                                        self.yang_name = "announce"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki))])
                                        self._leafs = OrderedDict()

                                        self.rpki = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki()
                                        self.rpki.parent = self
                                        self._children_name_map["rpki"] = "rpki"
                                        self._segment_path = lambda: "announce"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce, [], name, value)


                                    class Rpki(Entity):
                                        """
                                        Announce RPKI information using an extended community
                                        
                                        .. attribute:: state
                                        
                                        	Announce RPKI state information using an extended community
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki, self).__init__()

                                            self.yang_name = "rpki"
                                            self.yang_parent_name = "announce"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                            ])
                                            self.state = None
                                            self._segment_path = lambda: "rpki"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki, ['state'], name, value)


                                class AsOverride(Entity):
                                    """
                                    Override matching AS\-number while sending update
                                    
                                    .. attribute:: disable
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride, self).__init__()

                                        self.yang_name = "as-override"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ])
                                        self.disable = None
                                        self._segment_path = lambda: "as-override"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride, ['disable'], name, value)


                                class Capability(Entity):
                                    """
                                    Advertise capability to the peer
                                    
                                    .. attribute:: orf
                                    
                                    	Advertise ORF capability to the peer
                                    	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability, self).__init__()

                                        self.yang_name = "capability"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf))])
                                        self._leafs = OrderedDict()

                                        self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf()
                                        self.orf.parent = self
                                        self._children_name_map["orf"] = "orf"
                                        self._segment_path = lambda: "capability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability, [], name, value)


                                    class Orf(Entity):
                                        """
                                        Advertise ORF capability to the peer
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Advertise prefix list ORF capability to this neighbor
                                        	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf.PrefixList>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf, self).__init__()

                                            self.yang_name = "orf"
                                            self.yang_parent_name = "capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf.PrefixList')])),
                                            ])
                                            self.prefix_list = []
                                            self._segment_path = lambda: "orf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                        class PrefixList(Enum):
                                            """
                                            PrefixList (Enum Class)

                                            Advertise prefix list ORF capability to this neighbor

                                            .. data:: both = 0

                                            .. data:: receive = 1

                                            .. data:: send = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            receive = Enum.YLeaf(1, "receive")

                                            send = Enum.YLeaf(2, "send")



                                class DefaultOriginate(Entity):
                                    """
                                    Originate default route to this neighbor
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria to originate default
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate, self).__init__()

                                        self.yang_name = "default-originate"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "default-originate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList.Inout>`
                                    
                                    .. attribute:: accesslist
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..199
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..2699
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList.Inout')])),
                                            ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                        ])
                                        self.inout = None
                                        self.accesslist = None
                                        self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                class PeerGroup(Entity):
                                    """
                                    Member of the peer\-group
                                    
                                    .. attribute:: peer_group_name
                                    
                                    	peer\-group name
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup, self).__init__()

                                        self.yang_name = "peer-group"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                        ])
                                        self.peer_group_name = None
                                        self._segment_path = lambda: "peer-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SendLabel(Entity):
                                    """
                                    Send NLRI + MPLS Label to this peer
                                    
                                    .. attribute:: send_label_explicit
                                    
                                    	
                                    	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel.SendLabelExplicit>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel, self).__init__()

                                        self.yang_name = "send-label"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel.SendLabelExplicit')])),
                                        ])
                                        self.send_label_explicit = None
                                        self._segment_path = lambda: "send-label"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                    class SendLabelExplicit(Enum):
                                        """
                                        SendLabelExplicit (Enum Class)

                                        .. data:: explicit_null = 0

                                        """

                                        explicit_null = Enum.YLeaf(0, "explicit-null")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class TranslateUpdate(Entity):
                                    """
                                    Translate update to MBGP format
                                    
                                    .. attribute:: ipv4
                                    
                                    	Address Family
                                    	**type**\:  :py:class:`Ipv4_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate, self).__init__()

                                        self.yang_name = "translate-update"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_))])
                                        self._leafs = OrderedDict()

                                        self.ipv4 = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_()
                                        self.ipv4.parent = self
                                        self._children_name_map["ipv4"] = "ipv4"
                                        self._segment_path = lambda: "translate-update"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate, [], name, value)


                                    class Ipv4_(Entity):
                                        """
                                        Address Family
                                        
                                        .. attribute:: multicast
                                        
                                        	Address Family modifier
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_, self).__init__()

                                            self.yang_name = "ipv4"
                                            self.yang_parent_name = "translate-update"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast))])
                                            self._leafs = OrderedDict()

                                            self.multicast = None
                                            self._children_name_map["multicast"] = "multicast"
                                            self._segment_path = lambda: "ipv4"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_, [], name, value)


                                        class Multicast(Entity):
                                            """
                                            Address Family modifier
                                            
                                            .. attribute:: unicast
                                            
                                            	Address Family modifier
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "ipv4"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ])
                                                self.unicast = None
                                                self._segment_path = lambda: "multicast"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast, ['unicast'], name, value)


                            class Network(Entity):
                                """
                                
                                
                                .. attribute:: with_mask
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask>`
                                
                                .. attribute:: no_mask
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network, self).__init__()

                                    self.yang_name = "network"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask))])
                                    self._leafs = OrderedDict()

                                    self.with_mask = YList(self)
                                    self.no_mask = YList(self)
                                    self._segment_path = lambda: "network"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network, [], name, value)


                                class WithMask(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mask  (key)
                                    
                                    	Network mask
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask, self).__init__()

                                        self.yang_name = "with-mask"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number','mask']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.mask = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor'], name, value)


                                class NoMask(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask, self).__init__()

                                        self.yang_name = "no-mask"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask, ['number', 'route_map', 'backdoor'], name, value)


                            class Redistribute(Entity):
                                """
                                Redistribute information from another routing protocol
                                
                                .. attribute:: application
                                
                                	Application
                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dvmrp
                                
                                	Redistribution of DVMRP into BGP IPv4 Multicast
                                	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol
                                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: iso_igrp
                                
                                	IGRP for OSI networks
                                	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp>`
                                
                                .. attribute:: mobile
                                
                                	Mobile routes
                                	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: odr
                                
                                	On Demand stub Routes
                                	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute, self).__init__()

                                    self.yang_name = "redistribute"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static))])
                                    self._leafs = OrderedDict()

                                    self.application = None
                                    self._children_name_map["application"] = "application"

                                    self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.connected = None
                                    self._children_name_map["connected"] = "connected"

                                    self.dvmrp = None
                                    self._children_name_map["dvmrp"] = "dvmrp"

                                    self.eigrp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp()
                                    self.eigrp.parent = self
                                    self._children_name_map["eigrp"] = "eigrp"

                                    self.isis = None
                                    self._children_name_map["isis"] = "isis"

                                    self.lisp = None
                                    self._children_name_map["lisp"] = "lisp"

                                    self.iso_igrp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp()
                                    self.iso_igrp.parent = self
                                    self._children_name_map["iso_igrp"] = "iso-igrp"

                                    self.mobile = None
                                    self._children_name_map["mobile"] = "mobile"

                                    self.odr = None
                                    self._children_name_map["odr"] = "odr"

                                    self.rip = None
                                    self._children_name_map["rip"] = "rip"

                                    self.static = None
                                    self._children_name_map["static"] = "static"

                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "redistribute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute, [], name, value)


                                class Application(Entity):
                                    """
                                    Application
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application, self).__init__()

                                        self.yang_name = "application"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.name = YList(self)
                                        self._segment_path = lambda: "application"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application, [], name, value)


                                    class Name(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	WORD \:\: Route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name, self).__init__()

                                            self.yang_name = "name"
                                            self.yang_parent_name = "application"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                class Bgp_(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: as_no
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_no = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                class Dvmrp(Entity):
                                    """
                                    Redistribution of DVMRP into BGP IPv4 Multicast
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp, self).__init__()

                                        self.yang_name = "dvmrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.route_map = None
                                        self.metric = None
                                        self._segment_path = lambda: "dvmrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: as_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_no = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "eigrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: isis_area
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea>`
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.isis_area = YList(self)
                                        self._segment_path = lambda: "isis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis, [], name, value)


                                    class IsisArea(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: routes
                                        
                                        	
                                        	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea.Routes>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea, self).__init__()

                                            self.yang_name = "isis-area"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea.Routes')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.ip = None
                                            self.clns = None
                                            self.routes = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                        class Routes(Enum):
                                            """
                                            Routes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class Default(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: routes
                                        
                                        	
                                        	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default.Routes>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default.Routes')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.ip = None
                                            self.clns = None
                                            self.routes = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                        class Routes(Enum):
                                            """
                                            Routes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class Lisp(Entity):
                                    """
                                    Locator/ID Separation Protocol
                                    
                                    .. attribute:: include_connected
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp, self).__init__()

                                        self.yang_name = "lisp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.include_connected = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "lisp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                class IsoIgrp(Entity):
                                    """
                                    IGRP for OSI networks
                                    
                                    .. attribute:: iso_igrp_area
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp, self).__init__()

                                        self.yang_name = "iso-igrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default))])
                                        self._leafs = OrderedDict()

                                        self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.iso_igrp_area = YList(self)
                                        self._segment_path = lambda: "iso-igrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp, [], name, value)


                                    class IsoIgrpArea(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                            self.yang_name = "iso-igrp-area"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.name = None
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                    class Default(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                class Mobile(Entity):
                                    """
                                    Mobile routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile, self).__init__()

                                        self.yang_name = "mobile"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "mobile"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                class Odr(Entity):
                                    """
                                    On Demand stub Routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr, self).__init__()

                                        self.yang_name = "odr"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "odr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: vrf
                                    
                                    	VPN Routing/Forwarding Instance
                                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf>`
                                    
                                    .. attribute:: non_vrf
                                    
                                    	
                                    	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf)), ("non-vrf", ("non_vrf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.non_vrf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf()
                                        self.non_vrf.parent = self
                                        self._children_name_map["non_vrf"] = "non-vrf"

                                        self.vrf = YList(self)
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf, ['id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VPN Routing/Forwarding Instance
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf.Match))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf, ['name', 'metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict()
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True


                                    class NonVrf(Entity):
                                        """
                                        
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf, self).__init__()

                                            self.yang_name = "non-vrf"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match))])
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "non-vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: external2
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "non-vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                    ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.internal = None
                                                self.external = None
                                                self.external2 = None
                                                self.nssa_external = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: match
                                    
                                    	
                                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.id = None
                                        self.metric = None
                                        self.route_map = None

                                        self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match()
                                        self.match.parent = self
                                        self._children_name_map["match"] = "match"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                    class Match(Entity):
                                        """
                                        
                                        
                                        .. attribute:: internal
                                        
                                        	Redistribute OSPF internal routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: external
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: external2
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: nssa_external
                                        
                                        	Redistribute OSPF NSSA external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match, self).__init__()

                                            self.yang_name = "match"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.internal = None
                                            self.external = None
                                            self.external2 = None
                                            self.nssa_external = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "match"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: name
                                    
                                    	User selected string identifying this process
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self.name = None
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: clns
                                    
                                    	Redistribution of OSI dynamic routes
                                    	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ip
                                    
                                    	
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None

                                        self.clns = None
                                        self._children_name_map["clns"] = "clns"

                                        self.ip = None
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                    class Clns(Entity):
                                        """
                                        Redistribution of OSI dynamic routes
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns, self).__init__()

                                            self.yang_name = "clns"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "clns"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                    class Ip(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                            class SegmentRouting(Entity):
                                """
                                segment\-routing
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting, self).__init__()

                                    self.yang_name = "segment-routing"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                    ])
                                    self.mpls = None
                                    self._segment_path = lambda: "segment-routing"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting, ['mpls'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class TableMap(Entity):
                                """
                                Map external entry attributes into routing table
                                
                                .. attribute:: name
                                
                                	WORD \:\: Route\-map name
                                	**type**\: str
                                
                                .. attribute:: filter
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap, self).__init__()

                                    self.yang_name = "table-map"
                                    self.yang_parent_name = "ipv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                                    ])
                                    self.name = None
                                    self.filter = None
                                    self._segment_path = lambda: "table-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap, ['name', 'filter'], name, value)


                        class Ipv4Multicast(Entity):
                            """
                            IPv4 Multicast address family
                            
                            .. attribute:: aggregate_address
                            
                            	Configure BGP aggregate entries
                            	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.AggregateAddress>`
                            
                            .. attribute:: auto_summary
                            
                            	Enable automatic network number summarization
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.DefaultInformation>`
                            
                            .. attribute:: default_metric
                            
                            	Set metric of redistributed routes
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: distance
                            
                            	Define an administrative distance
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor>`
                            
                            .. attribute:: network
                            
                            	
                            	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network>`
                            
                            .. attribute:: redistribute
                            
                            	Redistribute information from another routing protocol
                            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: table_map
                            
                            	Map external entry attributes into routing table
                            	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.TableMap>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast, self).__init__()

                                self.yang_name = "ipv4-multicast"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp)), ("table-map", ("table_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.TableMap))])
                                self._leafs = OrderedDict([
                                    ('auto_summary', (YLeaf(YType.empty, 'auto-summary'), ['Empty'])),
                                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                ])
                                self.auto_summary = None
                                self.default_metric = None

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.default_information = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.distance = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.network = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network()
                                self.network.parent = self
                                self._children_name_map["network"] = "network"

                                self.redistribute = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute()
                                self.redistribute.parent = self
                                self._children_name_map["redistribute"] = "redistribute"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.table_map = None
                                self._children_name_map["table_map"] = "table-map"

                                self.aggregate_address = YList(self)
                                self.neighbor = YList(self)
                                self._segment_path = lambda: "ipv4-multicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast, ['auto_summary', 'default_metric'], name, value)


                            class AggregateAddress(Entity):
                                """
                                Configure BGP aggregate entries
                                
                                .. attribute:: ipv4_address  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mask  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: advertise_map
                                
                                	Set condition to advertise attribute
                                	**type**\: str
                                
                                .. attribute:: as_set
                                
                                	Generate AS set path information
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: attribute_map
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: as_override
                                
                                	Override matching AS\-number while sending update
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: summary_only
                                
                                	Filter more specific routes from updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: suppress_map
                                
                                	Conditionally filter more specific routes from updates
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.AggregateAddress, self).__init__()

                                    self.yang_name = "aggregate-address"
                                    self.yang_parent_name = "ipv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv4_address','ipv4_mask']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mask', (YLeaf(YType.str, 'ipv4-mask'), ['str'])),
                                        ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                        ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                        ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                        ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                    ])
                                    self.ipv4_address = None
                                    self.ipv4_mask = None
                                    self.advertise_map = None
                                    self.as_set = None
                                    self.attribute_map = None
                                    self.as_override = None
                                    self.route_map = None
                                    self.summary_only = None
                                    self.suppress_map = None
                                    self._segment_path = lambda: "aggregate-address" + "[ipv4-address='" + str(self.ipv4_address) + "']" + "[ipv4-mask='" + str(self.ipv4_mask) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.AggregateAddress, ['ipv4_address', 'ipv4_mask', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: additional_paths
                                
                                	Additional paths in the BGP table
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths>`
                                
                                .. attribute:: aggregate_timer
                                
                                	Configure aggregation timer
                                	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AggregateTimer>`
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Nexthop>`
                                
                                .. attribute:: redistribute_internal
                                
                                	Allow redistribution of iBGP into IGPs (dangerous)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: update_group
                                
                                	Manage peers in bgp update groups
                                	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "ipv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AggregateTimer)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Dampening)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Nexthop)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.UpdateGroup))])
                                    self._leafs = OrderedDict([
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                    ])
                                    self.dmzlink_bw = None
                                    self.redistribute_internal = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.aggregate_timer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AggregateTimer()
                                    self.aggregate_timer.parent = self
                                    self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.UpdateGroup()
                                    self.update_group.parent = self
                                    self._children_name_map["update_group"] = "update-group"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_, ['dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                class AdditionalPaths(Entity):
                                    """
                                    Additional paths in the BGP table
                                    
                                    .. attribute:: install
                                    
                                    	Additional paths to install into RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: select
                                    
                                    	Selection criteria to pick the paths
                                    	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to neighbors
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.install = None
                                        self.receive = None

                                        self.select = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select()
                                        self.select.parent = self
                                        self._children_name_map["select"] = "select"

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                    class Select(Entity):
                                        """
                                        Selection criteria to pick the paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: backup
                                        
                                        	Select backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Select best\-external path
                                        	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best path
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                            self.yang_name = "select"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.best_external = None
                                            self._children_name_map["best_external"] = "best-external"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "select"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best path
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best path
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                        class Backup(Entity):
                                            """
                                            Select backup path
                                            
                                            .. attribute:: best_external
                                            
                                            	Select best\-external path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                self._leafs = OrderedDict()

                                                self.range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                        class BestExternal(Entity):
                                            """
                                            Select best\-external path
                                            
                                            .. attribute:: backup
                                            
                                            	Select backup path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                self.yang_name = "best-external"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                ])
                                                self.backup = None
                                                self._segment_path = lambda: "best-external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best path
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to neighbors
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                class AggregateTimer(Entity):
                                    """
                                    Configure aggregation timer
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Timer interval
                                    	**type**\: int
                                    
                                    	**range:** 6..60
                                    
                                    .. attribute:: disable_timer
                                    
                                    	Timer interval
                                    	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AggregateTimer.DisableTimer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AggregateTimer, self).__init__()

                                        self.yang_name = "aggregate-timer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                            ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AggregateTimer.DisableTimer')])),
                                        ])
                                        self.aggregate_timer = None
                                        self.disable_timer = None
                                        self._segment_path = lambda: "aggregate-timer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                    class DisableTimer(Enum):
                                        """
                                        DisableTimer (Enum Class)

                                        Timer interval

                                        .. data:: Y_0 = 0

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")



                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria for dampening
                                    	**type**\: str
                                    
                                    .. attribute:: dampen
                                    
                                    	
                                    	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Dampening.Dampen>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Dampening.Dampen))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.dampen = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Dampening.Dampen()
                                        self.dampen.parent = self
                                        self._children_name_map["dampen"] = "dampen"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Dampening, ['route_map'], name, value)


                                    class Dampen(Entity):
                                        """
                                        
                                        
                                        .. attribute:: half_life_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..45
                                        
                                        .. attribute:: reuse_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: max_suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Dampening.Dampen, self).__init__()

                                            self.yang_name = "dampen"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                            ])
                                            self.half_life_time = None
                                            self.reuse_time = None
                                            self.suppress_time = None
                                            self.max_suppress_time = None
                                            self._segment_path = lambda: "dampen"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    Manage peers in bgp update groups
                                    
                                    .. attribute:: split
                                    
                                    	Split update groups based on Policy
                                    	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.UpdateGroup.Split>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.UpdateGroup.Split))])
                                        self._leafs = OrderedDict()

                                        self.split = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.UpdateGroup.Split()
                                        self.split.parent = self
                                        self._children_name_map["split"] = "split"
                                        self._segment_path = lambda: "update-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.UpdateGroup, [], name, value)


                                    class Split(Entity):
                                        """
                                        Split update groups based on Policy
                                        
                                        .. attribute:: as_override
                                        
                                        	Keep peers with as\-override in different update groups
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.UpdateGroup.Split, self).__init__()

                                            self.yang_name = "split"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ])
                                            self.as_override = None
                                            self._segment_path = lambda: "split"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "ipv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                    ])
                                    self.originate = None
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.DefaultInformation, ['originate'], name, value)


                            class Distance(Entity):
                                """
                                Define an administrative distance
                                
                                .. attribute:: bgp
                                
                                	BGP distance
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance.Bgp_>`
                                
                                .. attribute:: adm_distance
                                
                                	
                                	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance.AdmDistance>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance.AdmDistance))])
                                    self._leafs = OrderedDict()

                                    self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.adm_distance = YList(self)
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance, [], name, value)


                                class Bgp_(Entity):
                                    """
                                    BGP distance
                                    
                                    .. attribute:: extern_as
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: internal_as
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                            ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                            ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                        ])
                                        self.extern_as = None
                                        self.internal_as = None
                                        self.local = None
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                class AdmDistance(Entity):
                                    """
                                    
                                    
                                    .. attribute:: distance  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: srcip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: wildbits  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: acl
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..99
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..1999
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance.AdmDistance, self).__init__()

                                        self.yang_name = "adm-distance"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['distance','srcip','wildbits']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                            ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                            ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                        ])
                                        self.distance = None
                                        self.srcip = None
                                        self.wildbits = None
                                        self.acl = None
                                        self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "ipv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: additional_paths
                                    
                                    	
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdditionalPaths>`
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise to this neighbor
                                    	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise>`
                                    
                                    .. attribute:: advertise_map
                                    
                                    	specify route\-map for conditional advertisement
                                    	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: aigp
                                    
                                    	Enable a AIGP on neighbor
                                    	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability>`
                                    
                                    .. attribute:: default_originate
                                    
                                    	Originate default route to this neighbor
                                    	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.DefaultOriginate>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.DistributeList>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise()
                                        self.advertise.parent = self
                                        self._children_name_map["advertise"] = "advertise"

                                        self.advertise_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap()
                                        self.advertise_map.parent = self
                                        self._children_name_map["advertise_map"] = "advertise-map"

                                        self.aigp = None
                                        self._children_name_map["aigp"] = "aigp"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.default_originate = None
                                        self._children_name_map["default_originate"] = "default-originate"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.distribute_list = YList(self)
                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AdditionalPaths(Entity):
                                        """
                                        
                                        
                                        .. attribute:: disable
                                        
                                        	Disable additional paths for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send
                                        
                                        	Send additional paths to this neighbor
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdditionalPaths.Send>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdditionalPaths.Send))])
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self.receive = None

                                            self.send = None
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                        class Send(Entity):
                                            """
                                            Send additional paths to this neighbor
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdditionalPaths.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.receive = None
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                    class Advertise(Entity):
                                        """
                                        Advertise to this neighbor
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Advertise additional paths
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Advertise best\-external (at RRs best\-internal) path
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: diverse_path
                                        
                                        	Advertise diverse path
                                        	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                            self.yang_name = "advertise"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                            self._leafs = OrderedDict([
                                                ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                            ])
                                            self.best_external = None

                                            self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                            self.diverse_path.parent = self
                                            self._children_name_map["diverse_path"] = "diverse-path"
                                            self._segment_path = lambda: "advertise"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Advertise additional paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                            class All(Entity):
                                                """
                                                Select all available paths
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.group_best = None
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.all = None

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "best-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.all = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.all = None
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                        class DiversePath(Entity):
                                            """
                                            Advertise diverse path
                                            
                                            .. attribute:: backup
                                            
                                            	Diverse path can be backup path
                                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                self.yang_name = "diverse-path"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None

                                                self.backup = None
                                                self._children_name_map["backup"] = "backup"
                                                self._segment_path = lambda: "diverse-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                            class Backup(Entity):
                                                """
                                                Diverse path can be backup path
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                    self.yang_name = "backup"
                                                    self.yang_parent_name = "diverse-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None
                                                    self._segment_path = lambda: "backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                    class AdvertiseMap(Entity):
                                        """
                                        specify route\-map for conditional advertisement
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap.Name>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap, self).__init__()

                                            self.yang_name = "advertise-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap.Name))])
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "advertise-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: word  (key)
                                            
                                            	advertise route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: non_exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "advertise-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                    ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                    ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                ])
                                                self.word = None
                                                self.exist_map = None
                                                self.non_exist_map = None
                                                self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                    class Aigp(Entity):
                                        """
                                        Enable a AIGP on neighbor
                                        
                                        .. attribute:: send
                                        
                                        	Cost community or MED carrying AIGP VALUE
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                            self.yang_name = "aigp"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.send = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send()
                                            self.send.parent = self
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "aigp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                        class Send(Entity):
                                            """
                                            Cost community or MED carrying AIGP VALUE
                                            
                                            .. attribute:: cost_community
                                            
                                            	Cost extended community carrying AIGP Value
                                            	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                            
                                            .. attribute:: med
                                            
                                            	Med carrying AIGP Value
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "aigp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                ])
                                                self.med = None

                                                self.cost_community = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                self.cost_community.parent = self
                                                self._children_name_map["cost_community"] = "cost-community"
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                            class CostCommunity(Entity):
                                                """
                                                Cost extended community carrying AIGP Value
                                                
                                                .. attribute:: cc_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                    self.yang_name = "cost-community"
                                                    self.yang_parent_name = "send"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                    self._leafs = OrderedDict()

                                                    self.cc_range = YList(self)
                                                    self._segment_path = lambda: "cost-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                class CcRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Community ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: poi
                                                    
                                                    	Point of insertion
                                                    	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                        self.yang_name = "cc-range"
                                                        self.yang_parent_name = "cost-community"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ])
                                                        self.range = None

                                                        self.poi = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                        self.poi.parent = self
                                                        self._children_name_map["poi"] = "poi"
                                                        self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                    class Poi(Entity):
                                                        """
                                                        Point of insertion
                                                        
                                                        .. attribute:: igp_cost
                                                        
                                                        	Point of insertion after IGP
                                                        	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        .. attribute:: pre_bestpath
                                                        
                                                        	Point of insertion at beginning
                                                        	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                            self.yang_name = "poi"
                                                            self.yang_parent_name = "cc-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                            self._leafs = OrderedDict()

                                                            self.igp_cost = None
                                                            self._children_name_map["igp_cost"] = "igp-cost"

                                                            self.pre_bestpath = None
                                                            self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                            self._segment_path = lambda: "poi"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                        class IgpCost(Entity):
                                                            """
                                                            Point of insertion after IGP
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                self.yang_name = "igp-cost"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "igp-cost"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                        class PreBestpath(Entity):
                                                            """
                                                            Point of insertion at beginning
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                self.yang_name = "pre-bestpath"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "pre-bestpath"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DefaultOriginate(Entity):
                                        """
                                        Originate default route to this neighbor
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria to originate default
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                            self.yang_name = "default-originate"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "default-originate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                        
                                        .. attribute:: accesslist
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                            ])
                                            self.inout = None
                                            self.accesslist = None
                                            self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: additional_paths
                                
                                	
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdditionalPaths>`
                                
                                .. attribute:: advertise
                                
                                	Advertise to this neighbor
                                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise>`
                                
                                .. attribute:: advertise_map
                                
                                	specify route\-map for conditional advertisement
                                	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdvertiseMap>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: aigp
                                
                                	Enable a AIGP on neighbor
                                	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: capability
                                
                                	Advertise capability to the peer
                                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability>`
                                
                                .. attribute:: default_originate
                                
                                	Originate default route to this neighbor
                                	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.DefaultOriginate>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: distribute_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.DistributeList>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "ipv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.dmzlink_bw = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise()
                                    self.advertise.parent = self
                                    self._children_name_map["advertise"] = "advertise"

                                    self.advertise_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdvertiseMap()
                                    self.advertise_map.parent = self
                                    self._children_name_map["advertise_map"] = "advertise-map"

                                    self.aigp = None
                                    self._children_name_map["aigp"] = "aigp"

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability()
                                    self.capability.parent = self
                                    self._children_name_map["capability"] = "capability"

                                    self.default_originate = None
                                    self._children_name_map["default_originate"] = "default-originate"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.distribute_list = YList(self)
                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AdditionalPaths(Entity):
                                    """
                                    
                                    
                                    .. attribute:: disable
                                    
                                    	Disable additional paths for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to this neighbor
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.disable = None
                                        self.receive = None

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to this neighbor
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                class Advertise(Entity):
                                    """
                                    Advertise to this neighbor
                                    
                                    .. attribute:: additional_paths
                                    
                                    	Advertise additional paths
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths>`
                                    
                                    .. attribute:: best_external
                                    
                                    	Advertise best\-external (at RRs best\-internal) path
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: diverse_path
                                    
                                    	Advertise diverse path
                                    	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.DiversePath>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise, self).__init__()

                                        self.yang_name = "advertise"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.DiversePath))])
                                        self._leafs = OrderedDict([
                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                        ])
                                        self.best_external = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.DiversePath()
                                        self.diverse_path.parent = self
                                        self._children_name_map["diverse_path"] = "diverse-path"
                                        self._segment_path = lambda: "advertise"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise, ['best_external'], name, value)


                                    class AdditionalPaths(Entity):
                                        """
                                        Advertise additional paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best paths
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: best_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                self._leafs = OrderedDict()

                                                self.best_range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                            class BestRange(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                    self.yang_name = "best-range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "best-range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                    class DiversePath(Entity):
                                        """
                                        Advertise diverse path
                                        
                                        .. attribute:: backup
                                        
                                        	Diverse path can be backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.DiversePath.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: mpath
                                        
                                        	Diverse path can be multipath
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.DiversePath, self).__init__()

                                            self.yang_name = "diverse-path"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.DiversePath.Backup))])
                                            self._leafs = OrderedDict([
                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                            ])
                                            self.mpath = None

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"
                                            self._segment_path = lambda: "diverse-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                        class Backup(Entity):
                                            """
                                            Diverse path can be backup path
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "diverse-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                class AdvertiseMap(Entity):
                                    """
                                    specify route\-map for conditional advertisement
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdvertiseMap.Name>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdvertiseMap, self).__init__()

                                        self.yang_name = "advertise-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdvertiseMap.Name))])
                                        self._leafs = OrderedDict()

                                        self.name = YList(self)
                                        self._segment_path = lambda: "advertise-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdvertiseMap, [], name, value)


                                    class Name(Entity):
                                        """
                                        
                                        
                                        .. attribute:: word  (key)
                                        
                                        	advertise route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: exist_map
                                        
                                        	condition route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: non_exist_map
                                        
                                        	condition route\-map name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdvertiseMap.Name, self).__init__()

                                            self.yang_name = "name"
                                            self.yang_parent_name = "advertise-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                            ])
                                            self.word = None
                                            self.exist_map = None
                                            self.non_exist_map = None
                                            self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                class Aigp(Entity):
                                    """
                                    Enable a AIGP on neighbor
                                    
                                    .. attribute:: send
                                    
                                    	Cost community or MED carrying AIGP VALUE
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp, self).__init__()

                                        self.yang_name = "aigp"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.send = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send()
                                        self.send.parent = self
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "aigp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp, [], name, value)


                                    class Send(Entity):
                                        """
                                        Cost community or MED carrying AIGP VALUE
                                        
                                        .. attribute:: cost_community
                                        
                                        	Cost extended community carrying AIGP Value
                                        	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity>`
                                        
                                        .. attribute:: med
                                        
                                        	Med carrying AIGP Value
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "aigp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity))])
                                            self._leafs = OrderedDict([
                                                ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                            ])
                                            self.med = None

                                            self.cost_community = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity()
                                            self.cost_community.parent = self
                                            self._children_name_map["cost_community"] = "cost-community"
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send, ['med'], name, value)


                                        class CostCommunity(Entity):
                                            """
                                            Cost extended community carrying AIGP Value
                                            
                                            .. attribute:: cc_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                self.yang_name = "cost-community"
                                                self.yang_parent_name = "send"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                self._leafs = OrderedDict()

                                                self.cc_range = YList(self)
                                                self._segment_path = lambda: "cost-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                            class CcRange(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Community ID
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: poi
                                                
                                                	Point of insertion
                                                	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                    self.yang_name = "cc-range"
                                                    self.yang_parent_name = "cost-community"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                    ])
                                                    self.range = None

                                                    self.poi = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                    self.poi.parent = self
                                                    self._children_name_map["poi"] = "poi"
                                                    self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                class Poi(Entity):
                                                    """
                                                    Point of insertion
                                                    
                                                    .. attribute:: igp_cost
                                                    
                                                    	Point of insertion after IGP
                                                    	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: pre_bestpath
                                                    
                                                    	Point of insertion at beginning
                                                    	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                        self.yang_name = "poi"
                                                        self.yang_parent_name = "cc-range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                        self._leafs = OrderedDict()

                                                        self.igp_cost = None
                                                        self._children_name_map["igp_cost"] = "igp-cost"

                                                        self.pre_bestpath = None
                                                        self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                        self._segment_path = lambda: "poi"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                    class IgpCost(Entity):
                                                        """
                                                        Point of insertion after IGP
                                                        
                                                        .. attribute:: transitive
                                                        
                                                        	Cost community is transitive
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                            self.yang_name = "igp-cost"
                                                            self.yang_parent_name = "poi"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                            ])
                                                            self.transitive = None
                                                            self._segment_path = lambda: "igp-cost"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                    class PreBestpath(Entity):
                                                        """
                                                        Point of insertion at beginning
                                                        
                                                        .. attribute:: transitive
                                                        
                                                        	Cost community is transitive
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                            self.yang_name = "pre-bestpath"
                                                            self.yang_parent_name = "poi"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                            ])
                                                            self.transitive = None
                                                            self._segment_path = lambda: "pre-bestpath"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Capability(Entity):
                                    """
                                    Advertise capability to the peer
                                    
                                    .. attribute:: orf
                                    
                                    	Advertise ORF capability to the peer
                                    	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability.Orf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability, self).__init__()

                                        self.yang_name = "capability"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability.Orf))])
                                        self._leafs = OrderedDict()

                                        self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability.Orf()
                                        self.orf.parent = self
                                        self._children_name_map["orf"] = "orf"
                                        self._segment_path = lambda: "capability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability, [], name, value)


                                    class Orf(Entity):
                                        """
                                        Advertise ORF capability to the peer
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Advertise prefix list ORF capability to this neighbor
                                        	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability.Orf.PrefixList>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability.Orf, self).__init__()

                                            self.yang_name = "orf"
                                            self.yang_parent_name = "capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability.Orf.PrefixList')])),
                                            ])
                                            self.prefix_list = []
                                            self._segment_path = lambda: "orf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                        class PrefixList(Enum):
                                            """
                                            PrefixList (Enum Class)

                                            Advertise prefix list ORF capability to this neighbor

                                            .. data:: both = 0

                                            .. data:: receive = 1

                                            .. data:: send = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            receive = Enum.YLeaf(1, "receive")

                                            send = Enum.YLeaf(2, "send")



                                class DefaultOriginate(Entity):
                                    """
                                    Originate default route to this neighbor
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria to originate default
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.DefaultOriginate, self).__init__()

                                        self.yang_name = "default-originate"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "default-originate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.DistributeList.Inout>`
                                    
                                    .. attribute:: accesslist
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..199
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..2699
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.DistributeList.Inout')])),
                                            ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                        ])
                                        self.inout = None
                                        self.accesslist = None
                                        self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.NextHopSelf, ['all'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Network(Entity):
                                """
                                
                                
                                .. attribute:: with_mask
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network.WithMask>`
                                
                                .. attribute:: no_mask
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network.NoMask>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network, self).__init__()

                                    self.yang_name = "network"
                                    self.yang_parent_name = "ipv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network.NoMask))])
                                    self._leafs = OrderedDict()

                                    self.with_mask = YList(self)
                                    self.no_mask = YList(self)
                                    self._segment_path = lambda: "network"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network, [], name, value)


                                class WithMask(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mask  (key)
                                    
                                    	Network mask
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network.WithMask, self).__init__()

                                        self.yang_name = "with-mask"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number','mask']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.mask = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor'], name, value)


                                class NoMask(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network.NoMask, self).__init__()

                                        self.yang_name = "no-mask"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Network.NoMask, ['number', 'route_map', 'backdoor'], name, value)


                            class Redistribute(Entity):
                                """
                                Redistribute information from another routing protocol
                                
                                .. attribute:: application
                                
                                	Application
                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Application>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Bgp_>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Connected>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dvmrp
                                
                                	Redistribution of DVMRP into BGP IPv4 Multicast
                                	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Dvmrp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol
                                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Lisp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: iso_igrp
                                
                                	IGRP for OSI networks
                                	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp>`
                                
                                .. attribute:: mobile
                                
                                	Mobile routes
                                	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Mobile>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: odr
                                
                                	On Demand stub Routes
                                	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Odr>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Rip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute, self).__init__()

                                    self.yang_name = "redistribute"
                                    self.yang_parent_name = "ipv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static))])
                                    self._leafs = OrderedDict()

                                    self.application = None
                                    self._children_name_map["application"] = "application"

                                    self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.connected = None
                                    self._children_name_map["connected"] = "connected"

                                    self.dvmrp = None
                                    self._children_name_map["dvmrp"] = "dvmrp"

                                    self.eigrp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Eigrp()
                                    self.eigrp.parent = self
                                    self._children_name_map["eigrp"] = "eigrp"

                                    self.isis = None
                                    self._children_name_map["isis"] = "isis"

                                    self.lisp = None
                                    self._children_name_map["lisp"] = "lisp"

                                    self.iso_igrp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp()
                                    self.iso_igrp.parent = self
                                    self._children_name_map["iso_igrp"] = "iso-igrp"

                                    self.mobile = None
                                    self._children_name_map["mobile"] = "mobile"

                                    self.odr = None
                                    self._children_name_map["odr"] = "odr"

                                    self.rip = None
                                    self._children_name_map["rip"] = "rip"

                                    self.static = None
                                    self._children_name_map["static"] = "static"

                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "redistribute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute, [], name, value)


                                class Application(Entity):
                                    """
                                    Application
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Application.Name>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Application, self).__init__()

                                        self.yang_name = "application"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Application.Name))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.name = YList(self)
                                        self._segment_path = lambda: "application"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Application, [], name, value)


                                    class Name(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	WORD \:\: Route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Application.Name, self).__init__()

                                            self.yang_name = "name"
                                            self.yang_parent_name = "application"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                class Bgp_(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: as_no
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_no = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                class Dvmrp(Entity):
                                    """
                                    Redistribution of DVMRP into BGP IPv4 Multicast
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Dvmrp, self).__init__()

                                        self.yang_name = "dvmrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.route_map = None
                                        self.metric = None
                                        self._segment_path = lambda: "dvmrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: as_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_no = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "eigrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: isis_area
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.IsisArea>`
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.Default>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.Default))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.Default()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.isis_area = YList(self)
                                        self._segment_path = lambda: "isis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis, [], name, value)


                                    class IsisArea(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: routes
                                        
                                        	
                                        	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.IsisArea.Routes>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.IsisArea, self).__init__()

                                            self.yang_name = "isis-area"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.IsisArea.Routes')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.ip = None
                                            self.clns = None
                                            self.routes = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                        class Routes(Enum):
                                            """
                                            Routes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class Default(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: routes
                                        
                                        	
                                        	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.Default.Routes>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.Default, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.Default.Routes')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.ip = None
                                            self.clns = None
                                            self.routes = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                        class Routes(Enum):
                                            """
                                            Routes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class Lisp(Entity):
                                    """
                                    Locator/ID Separation Protocol
                                    
                                    .. attribute:: include_connected
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Lisp, self).__init__()

                                        self.yang_name = "lisp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.include_connected = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "lisp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                class IsoIgrp(Entity):
                                    """
                                    IGRP for OSI networks
                                    
                                    .. attribute:: iso_igrp_area
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp.Default>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp, self).__init__()

                                        self.yang_name = "iso-igrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp.Default))])
                                        self._leafs = OrderedDict()

                                        self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp.Default()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.iso_igrp_area = YList(self)
                                        self._segment_path = lambda: "iso-igrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp, [], name, value)


                                    class IsoIgrpArea(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                            self.yang_name = "iso-igrp-area"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.name = None
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                    class Default(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp.Default, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                class Mobile(Entity):
                                    """
                                    Mobile routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Mobile, self).__init__()

                                        self.yang_name = "mobile"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "mobile"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                class Odr(Entity):
                                    """
                                    On Demand stub Routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Odr, self).__init__()

                                        self.yang_name = "odr"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "odr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: vrf
                                    
                                    	VPN Routing/Forwarding Instance
                                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.Vrf>`
                                    
                                    .. attribute:: non_vrf
                                    
                                    	
                                    	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.NonVrf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.Vrf)), ("non-vrf", ("non_vrf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.NonVrf))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.non_vrf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.NonVrf()
                                        self.non_vrf.parent = self
                                        self._children_name_map["non_vrf"] = "non-vrf"

                                        self.vrf = YList(self)
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf, ['id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VPN Routing/Forwarding Instance
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.Vrf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.Vrf.Match))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.Vrf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.Vrf, ['name', 'metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.Vrf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict()
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True


                                    class NonVrf(Entity):
                                        """
                                        
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.NonVrf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.NonVrf, self).__init__()

                                            self.yang_name = "non-vrf"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.NonVrf.Match))])
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.NonVrf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "non-vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: external2
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "non-vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                    ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.internal = None
                                                self.external = None
                                                self.external2 = None
                                                self.nssa_external = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: match
                                    
                                    	
                                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospfv3.Match>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospfv3.Match))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.id = None
                                        self.metric = None
                                        self.route_map = None

                                        self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospfv3.Match()
                                        self.match.parent = self
                                        self._children_name_map["match"] = "match"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                    class Match(Entity):
                                        """
                                        
                                        
                                        .. attribute:: internal
                                        
                                        	Redistribute OSPF internal routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: external
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: external2
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: nssa_external
                                        
                                        	Redistribute OSPF NSSA external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospfv3.Match, self).__init__()

                                            self.yang_name = "match"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.internal = None
                                            self.external = None
                                            self.external2 = None
                                            self.nssa_external = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "match"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: name
                                    
                                    	User selected string identifying this process
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self.name = None
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: clns
                                    
                                    	Redistribution of OSI dynamic routes
                                    	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static.Clns>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ip
                                    
                                    	
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static.Ip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static.Ip))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None

                                        self.clns = None
                                        self._children_name_map["clns"] = "clns"

                                        self.ip = None
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                    class Clns(Entity):
                                        """
                                        Redistribution of OSI dynamic routes
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static.Clns, self).__init__()

                                            self.yang_name = "clns"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "clns"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                    class Ip(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "ipv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class TableMap(Entity):
                                """
                                Map external entry attributes into routing table
                                
                                .. attribute:: name
                                
                                	WORD \:\: Route\-map name
                                	**type**\: str
                                
                                .. attribute:: filter
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.TableMap, self).__init__()

                                    self.yang_name = "table-map"
                                    self.yang_parent_name = "ipv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                                    ])
                                    self.name = None
                                    self.filter = None
                                    self._segment_path = lambda: "table-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Multicast.TableMap, ['name', 'filter'], name, value)


                        class Ipv4Flowspec(Entity):
                            """
                            Ipv4 Flowspec address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.DefaultInformation>`
                            
                            .. attribute:: default_metric
                            
                            	Set metric of redistributed routes
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor>`
                            
                            .. attribute:: network
                            
                            	
                            	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec, self).__init__()

                                self.yang_name = "ipv4-flowspec"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.DefaultInformation)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp))])
                                self._leafs = OrderedDict([
                                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                ])
                                self.default_metric = None

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.default_information = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.maximum_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths()
                                self.maximum_paths.parent = self
                                self._children_name_map["maximum_paths"] = "maximum-paths"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.network = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network()
                                self.network.parent = self
                                self._children_name_map["network"] = "network"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "ipv4-flowspec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec, ['default_metric'], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.Nexthop>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "ipv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.Nexthop)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                    ])
                                    self.scan_time = None

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_, ['scan_time'], name, value)


                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "ipv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                    ])
                                    self.originate = None
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.DefaultInformation, ['originate'], name, value)


                            class MaximumPaths(Entity):
                                """
                                Forward packets over multiple paths
                                
                                .. attribute:: ebgp
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: eibgp
                                
                                	Both eBGP and iBGP paths as multipath
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: ibgp
                                
                                	iBGP\-multipath
                                	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths.Ibgp>`
                                
                                .. attribute:: external_rtfilter
                                
                                	VPN prefix multipath on external RT\-Filter peers
                                	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths.ExternalRtfilter>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths, self).__init__()

                                    self.yang_name = "maximum-paths"
                                    self.yang_parent_name = "ipv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths.ExternalRtfilter))])
                                    self._leafs = OrderedDict([
                                        ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                        ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                    ])
                                    self.ebgp = None
                                    self.eibgp = None

                                    self.ibgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"

                                    self.external_rtfilter = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths.ExternalRtfilter()
                                    self.external_rtfilter.parent = self
                                    self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                    self._segment_path = lambda: "maximum-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                class Ibgp(Entity):
                                    """
                                    iBGP\-multipath
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Perform un\-equal cost multipath selection
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.unequal_cost = None
                                        self.max = None
                                        self._segment_path = lambda: "ibgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                class ExternalRtfilter(Entity):
                                    """
                                    VPN prefix multipath on external RT\-Filter peers
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths.ExternalRtfilter, self).__init__()

                                        self.yang_name = "external-rtfilter"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.max = None
                                        self._segment_path = lambda: "external-rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "ipv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.AllowasIn)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "ipv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.AllowasIn)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SoftReconfiguration')])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor, ['id', 'activate', 'advertisement_interval', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.NextHopSelf, ['all'], name, value)


                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Network(Entity):
                                """
                                
                                
                                .. attribute:: with_mask
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network.WithMask>`
                                
                                .. attribute:: no_mask
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network.NoMask>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network, self).__init__()

                                    self.yang_name = "network"
                                    self.yang_parent_name = "ipv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network.NoMask))])
                                    self._leafs = OrderedDict()

                                    self.with_mask = YList(self)
                                    self.no_mask = YList(self)
                                    self._segment_path = lambda: "network"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network, [], name, value)


                                class WithMask(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mask  (key)
                                    
                                    	Network mask
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network.WithMask, self).__init__()

                                        self.yang_name = "with-mask"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number','mask']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.mask = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor'], name, value)


                                class NoMask(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network.NoMask, self).__init__()

                                        self.yang_name = "no-mask"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Network.NoMask, ['number', 'route_map', 'backdoor'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "ipv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Flowspec.Snmp.Context.ContextWord, ['context_word'], name, value)


                        class Ipv4Mvpn(Entity):
                            """
                            IPv4 MVPN address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.DefaultInformation>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn, self).__init__()

                                self.yang_name = "ipv4-mvpn"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.DefaultInformation)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.default_information = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "ipv4-mvpn"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn, [], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	Configure BGP defaults
                                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Default>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Nexthop>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "ipv4-mvpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Nexthop)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                    ])
                                    self.dmzlink_bw = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None

                                    self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Default()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_, ['dmzlink_bw', 'scan_time', 'soft_reconfig_backup'], name, value)


                                class Default(Entity):
                                    """
                                    Configure BGP defaults
                                    
                                    .. attribute:: route_target
                                    
                                    	Control behavior based on Route\-Target attributes
                                    	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Default.RouteTarget>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Default, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Default.RouteTarget')])),
                                        ])
                                        self.route_target = None
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Default, ['route_target'], name, value)

                                    class RouteTarget(Enum):
                                        """
                                        RouteTarget (Enum Class)

                                        Control behavior based on Route\-Target attributes

                                        .. data:: filter = 0

                                        """

                                        filter = Enum.YLeaf(0, "filter")



                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "ipv4-mvpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                    ])
                                    self.originate = None
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.DefaultInformation, ['originate'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "ipv4-mvpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.AllowasIn)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "ipv4-mvpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.AllowasIn)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.AllowasIn, ['as_number'], name, value)


                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.NextHopSelf, ['all'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "ipv4-mvpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mvpn.Snmp.Context.ContextWord, ['context_word'], name, value)


                        class Ipv4Mdt(Entity):
                            """
                            IPv4 MDT address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.DefaultInformation>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt, self).__init__()

                                self.yang_name = "ipv4-mdt"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.DefaultInformation)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.default_information = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "ipv4-mdt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt, [], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Nexthop>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "ipv4-mdt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dampening", ("dampening", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Dampening)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Nexthop)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                    ])
                                    self.dmzlink_bw = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_, ['dmzlink_bw', 'scan_time', 'soft_reconfig_backup'], name, value)


                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria for dampening
                                    	**type**\: str
                                    
                                    .. attribute:: dampen
                                    
                                    	
                                    	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Dampening.Dampen>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Dampening.Dampen))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.dampen = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Dampening.Dampen()
                                        self.dampen.parent = self
                                        self._children_name_map["dampen"] = "dampen"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Dampening, ['route_map'], name, value)


                                    class Dampen(Entity):
                                        """
                                        
                                        
                                        .. attribute:: half_life_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..45
                                        
                                        .. attribute:: reuse_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: max_suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Dampening.Dampen, self).__init__()

                                            self.yang_name = "dampen"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                            ])
                                            self.half_life_time = None
                                            self.reuse_time = None
                                            self.suppress_time = None
                                            self.max_suppress_time = None
                                            self._segment_path = lambda: "dampen"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "ipv4-mdt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                    ])
                                    self.originate = None
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.DefaultInformation, ['originate'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "ipv4-mdt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.AllowasIn)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "ipv4-mdt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.AllowasIn)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.AllowasIn, ['as_number'], name, value)


                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.NextHopSelf, ['all'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "ipv4-mdt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv4.Ipv4Mdt.Snmp.Context.ContextWord, ['context_word'], name, value)


                    class Ipv6(Entity):
                        """
                        Address family
                        
                        .. attribute:: af_name  (key)
                        
                        	
                        	**type**\:  :py:class:`BgpIpv6AfType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.BgpIpv6AfType>`
                        
                        .. attribute:: ipv6_unicast
                        
                        	IPv6 Unicast address family
                        	**type**\:  :py:class:`Ipv6Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast>`
                        
                        .. attribute:: ipv6_multicast
                        
                        	IPv6 Multicast address family
                        	**type**\:  :py:class:`Ipv6Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast>`
                        
                        .. attribute:: ipv6_flowspec
                        
                        	IPv6 Flowspec address family
                        	**type**\:  :py:class:`Ipv6Flowspec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec>`
                        
                        .. attribute:: ipv6_mvpn
                        
                        	IPv6 MVPN address family
                        	**type**\:  :py:class:`Ipv6Mvpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "no-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("ipv6-unicast", ("ipv6_unicast", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast)), ("ipv6-multicast", ("ipv6_multicast", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast)), ("ipv6-flowspec", ("ipv6_flowspec", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec)), ("ipv6-mvpn", ("ipv6_mvpn", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'BgpIpv6AfType', '')])),
                            ])
                            self.af_name = None

                            self.ipv6_unicast = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast()
                            self.ipv6_unicast.parent = self
                            self._children_name_map["ipv6_unicast"] = "ipv6-unicast"

                            self.ipv6_multicast = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast()
                            self.ipv6_multicast.parent = self
                            self._children_name_map["ipv6_multicast"] = "ipv6-multicast"

                            self.ipv6_flowspec = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec()
                            self.ipv6_flowspec.parent = self
                            self._children_name_map["ipv6_flowspec"] = "ipv6-flowspec"

                            self.ipv6_mvpn = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn()
                            self.ipv6_mvpn.parent = self
                            self._children_name_map["ipv6_mvpn"] = "ipv6-mvpn"
                            self._segment_path = lambda: "ipv6" + "[af-name='" + str(self.af_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6, ['af_name'], name, value)


                        class Ipv6Unicast(Entity):
                            """
                            IPv6 Unicast address family
                            
                            .. attribute:: aggregate_address
                            
                            	Configure BGP aggregate entries
                            	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress>`
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation>`
                            
                            .. attribute:: default_metric
                            
                            	Set metric of redistributed routes
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: distance
                            
                            	Define an administrative distance
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance>`
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor>`
                            
                            .. attribute:: network
                            
                            	Specify a network to announce via BGP
                            	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network>`
                            
                            .. attribute:: redistribute
                            
                            	Redistribute information from another routing protocol
                            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: synchronization
                            
                            	Perform IGP synchronization
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: table_map
                            
                            	Map external entry attributes into routing table
                            	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast, self).__init__()

                                self.yang_name = "ipv6-unicast"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp)), ("table-map", ("table_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap))])
                                self._leafs = OrderedDict([
                                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                    ('synchronization', (YLeaf(YType.empty, 'synchronization'), ['Empty'])),
                                ])
                                self.default_metric = None
                                self.synchronization = None

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.default_information = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.distance = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.maximum_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths()
                                self.maximum_paths.parent = self
                                self._children_name_map["maximum_paths"] = "maximum-paths"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.redistribute = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute()
                                self.redistribute.parent = self
                                self._children_name_map["redistribute"] = "redistribute"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.table_map = None
                                self._children_name_map["table_map"] = "table-map"

                                self.aggregate_address = YList(self)
                                self.neighbor = YList(self)
                                self.network = YList(self)
                                self._segment_path = lambda: "ipv6-unicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast, ['default_metric', 'synchronization'], name, value)


                            class AggregateAddress(Entity):
                                """
                                Configure BGP aggregate entries
                                
                                .. attribute:: ipv6_address  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: advertise_map
                                
                                	Set condition to advertise attribute
                                	**type**\: str
                                
                                .. attribute:: as_set
                                
                                	Generate AS set path information
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: attribute_map
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: as_override
                                
                                	Override matching AS\-number while sending update
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: summary_only
                                
                                	Filter more specific routes from updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: suppress_map
                                
                                	Conditionally filter more specific routes from updates
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress, self).__init__()

                                    self.yang_name = "aggregate-address"
                                    self.yang_parent_name = "ipv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv6_address']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                        ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                        ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                        ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                    ])
                                    self.ipv6_address = None
                                    self.advertise_map = None
                                    self.as_set = None
                                    self.attribute_map = None
                                    self.as_override = None
                                    self.route_map = None
                                    self.summary_only = None
                                    self.suppress_map = None
                                    self._segment_path = lambda: "aggregate-address" + "[ipv6-address='" + str(self.ipv6_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress, ['ipv6_address', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: additional_paths
                                
                                	Additional paths in the BGP table
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths>`
                                
                                .. attribute:: advertise_best_external
                                
                                	Advertise best external path to internal peers
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: aggregate_timer
                                
                                	Configure aggregation timer
                                	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer>`
                                
                                .. attribute:: bestpath
                                
                                	Change the default bestpath selection
                                	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath>`
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: inject_map
                                
                                	Route map which specifies prefixes to inject
                                	**type**\: list of  		 :py:class:`InjectMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop>`
                                
                                .. attribute:: recursion
                                
                                	recursion rule for the nexthops
                                	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion>`
                                
                                .. attribute:: redistribute_internal
                                
                                	Allow redistribution of iBGP into IGPs (dangerous)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: suppress_inactive
                                
                                	Suppress routes that are not in the routing table
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: update_group
                                
                                	Manage peers in bgp update groups
                                	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "ipv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening)), ("inject-map", ("inject_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup))])
                                    self._leafs = OrderedDict([
                                        ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                        ('suppress_inactive', (YLeaf(YType.empty, 'suppress-inactive'), ['Empty'])),
                                    ])
                                    self.advertise_best_external = None
                                    self.dmzlink_bw = None
                                    self.redistribute_internal = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None
                                    self.suppress_inactive = None

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.aggregate_timer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer()
                                    self.aggregate_timer.parent = self
                                    self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                    self.bestpath = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath()
                                    self.bestpath.parent = self
                                    self._children_name_map["bestpath"] = "bestpath"

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.recursion = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion()
                                    self.recursion.parent = self
                                    self._children_name_map["recursion"] = "recursion"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup()
                                    self.update_group.parent = self
                                    self._children_name_map["update_group"] = "update-group"

                                    self.inject_map = YList(self)
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup', 'suppress_inactive'], name, value)


                                class AdditionalPaths(Entity):
                                    """
                                    Additional paths in the BGP table
                                    
                                    .. attribute:: install
                                    
                                    	Additional paths to install into RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: select
                                    
                                    	Selection criteria to pick the paths
                                    	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to neighbors
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.install = None
                                        self.receive = None

                                        self.select = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select()
                                        self.select.parent = self
                                        self._children_name_map["select"] = "select"

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                    class Select(Entity):
                                        """
                                        Selection criteria to pick the paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: backup
                                        
                                        	Select backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Select best\-external path
                                        	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best path
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                            self.yang_name = "select"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.best_external = None
                                            self._children_name_map["best_external"] = "best-external"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "select"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best path
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best path
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                        class Backup(Entity):
                                            """
                                            Select backup path
                                            
                                            .. attribute:: best_external
                                            
                                            	Select best\-external path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                self._leafs = OrderedDict()

                                                self.range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                        class BestExternal(Entity):
                                            """
                                            Select best\-external path
                                            
                                            .. attribute:: backup
                                            
                                            	Select backup path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                self.yang_name = "best-external"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                ])
                                                self.backup = None
                                                self._segment_path = lambda: "best-external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best path
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to neighbors
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                class AggregateTimer(Entity):
                                    """
                                    Configure aggregation timer
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Timer interval
                                    	**type**\: int
                                    
                                    	**range:** 6..60
                                    
                                    .. attribute:: disable_timer
                                    
                                    	Timer interval
                                    	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer, self).__init__()

                                        self.yang_name = "aggregate-timer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                            ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                        ])
                                        self.aggregate_timer = None
                                        self.disable_timer = None
                                        self._segment_path = lambda: "aggregate-timer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                    class DisableTimer(Enum):
                                        """
                                        DisableTimer (Enum Class)

                                        Timer interval

                                        .. data:: Y_0 = 0

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")



                                class Bestpath(Entity):
                                    """
                                    Change the default bestpath selection
                                    
                                    .. attribute:: igp_metric
                                    
                                    	igp metric
                                    	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric>`
                                    
                                    .. attribute:: prefix_validate
                                    
                                    	Prefix origin validation
                                    	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath, self).__init__()

                                        self.yang_name = "bestpath"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate))])
                                        self._leafs = OrderedDict()

                                        self.igp_metric = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric()
                                        self.igp_metric.parent = self
                                        self._children_name_map["igp_metric"] = "igp-metric"

                                        self.prefix_validate = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate()
                                        self.prefix_validate.parent = self
                                        self._children_name_map["prefix_validate"] = "prefix-validate"
                                        self._segment_path = lambda: "bestpath"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath, [], name, value)


                                    class IgpMetric(Entity):
                                        """
                                        igp metric
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore igp metric in bestpath selection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                            self.yang_name = "igp-metric"
                                            self.yang_parent_name = "bestpath"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ])
                                            self.ignore = None
                                            self._segment_path = lambda: "igp-metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                    class PrefixValidate(Entity):
                                        """
                                        Prefix origin validation
                                        
                                        .. attribute:: allow_invalid
                                        
                                        	Allow invalid routes to be considered for bestpath
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: disable
                                        
                                        	Disable prefix validation
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                            self.yang_name = "prefix-validate"
                                            self.yang_parent_name = "bestpath"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.allow_invalid = None
                                            self.disable = None
                                            self._segment_path = lambda: "prefix-validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria for dampening
                                    	**type**\: str
                                    
                                    .. attribute:: dampen
                                    
                                    	
                                    	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.dampen = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen()
                                        self.dampen.parent = self
                                        self._children_name_map["dampen"] = "dampen"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                    class Dampen(Entity):
                                        """
                                        
                                        
                                        .. attribute:: half_life_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..45
                                        
                                        .. attribute:: reuse_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: max_suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                            self.yang_name = "dampen"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                            ])
                                            self.half_life_time = None
                                            self.reuse_time = None
                                            self.suppress_time = None
                                            self.max_suppress_time = None
                                            self._segment_path = lambda: "dampen"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                class InjectMap(Entity):
                                    """
                                    Route map which specifies prefixes to inject
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: exist_map
                                    
                                    	Route map which specifies exist condition
                                    	**type**\: str
                                    
                                    .. attribute:: copy_attributes
                                    
                                    	Copy attributes from aggregate
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap, self).__init__()

                                        self.yang_name = "inject-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                            ('copy_attributes', (YLeaf(YType.empty, 'copy-attributes'), ['Empty'])),
                                        ])
                                        self.name = None
                                        self.exist_map = None
                                        self.copy_attributes = None
                                        self._segment_path = lambda: "inject-map" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap, ['name', 'exist_map', 'copy_attributes'], name, value)


                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class Recursion(Entity):
                                    """
                                    recursion rule for the nexthops
                                    
                                    .. attribute:: host
                                    
                                    	recursion via host for the nexthops
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion, self).__init__()

                                        self.yang_name = "recursion"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                        ])
                                        self.host = None
                                        self._segment_path = lambda: "recursion"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion, ['host'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    Manage peers in bgp update groups
                                    
                                    .. attribute:: split
                                    
                                    	Split update groups based on Policy
                                    	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split))])
                                        self._leafs = OrderedDict()

                                        self.split = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split()
                                        self.split.parent = self
                                        self._children_name_map["split"] = "split"
                                        self._segment_path = lambda: "update-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup, [], name, value)


                                    class Split(Entity):
                                        """
                                        Split update groups based on Policy
                                        
                                        .. attribute:: as_override
                                        
                                        	Keep peers with as\-override in different update groups
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                            self.yang_name = "split"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ])
                                            self.as_override = None
                                            self._segment_path = lambda: "split"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "ipv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                    ])
                                    self.originate = None
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation, ['originate'], name, value)


                            class Distance(Entity):
                                """
                                Define an administrative distance
                                
                                .. attribute:: bgp
                                
                                	BGP distance
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_>`
                                
                                .. attribute:: adm_distance
                                
                                	
                                	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance))])
                                    self._leafs = OrderedDict()

                                    self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.adm_distance = YList(self)
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance, [], name, value)


                                class Bgp_(Entity):
                                    """
                                    BGP distance
                                    
                                    .. attribute:: extern_as
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: internal_as
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                            ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                            ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                        ])
                                        self.extern_as = None
                                        self.internal_as = None
                                        self.local = None
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                class AdmDistance(Entity):
                                    """
                                    
                                    
                                    .. attribute:: distance  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: srcip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: wildbits  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: acl
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..99
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..1999
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance, self).__init__()

                                        self.yang_name = "adm-distance"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['distance','srcip','wildbits']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                            ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                            ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                        ])
                                        self.distance = None
                                        self.srcip = None
                                        self.wildbits = None
                                        self.acl = None
                                        self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                            class MaximumPaths(Entity):
                                """
                                Forward packets over multiple paths
                                
                                .. attribute:: ebgp
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: eibgp
                                
                                	Both eBGP and iBGP paths as multipath
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: ibgp
                                
                                	iBGP\-multipath
                                	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp>`
                                
                                .. attribute:: external_rtfilter
                                
                                	VPN prefix multipath on external RT\-Filter peers
                                	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths, self).__init__()

                                    self.yang_name = "maximum-paths"
                                    self.yang_parent_name = "ipv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter))])
                                    self._leafs = OrderedDict([
                                        ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                        ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                    ])
                                    self.ebgp = None
                                    self.eibgp = None

                                    self.ibgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"

                                    self.external_rtfilter = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter()
                                    self.external_rtfilter.parent = self
                                    self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                    self._segment_path = lambda: "maximum-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                class Ibgp(Entity):
                                    """
                                    iBGP\-multipath
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Perform un\-equal cost multipath selection
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.unequal_cost = None
                                        self.max = None
                                        self._segment_path = lambda: "ibgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                class ExternalRtfilter(Entity):
                                    """
                                    VPN prefix multipath on external RT\-Filter peers
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                        self.yang_name = "external-rtfilter"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.max = None
                                        self._segment_path = lambda: "external-rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "ipv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: additional_paths
                                    
                                    	
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths>`
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise to this neighbor
                                    	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise>`
                                    
                                    .. attribute:: advertise_map
                                    
                                    	specify route\-map for conditional advertisement
                                    	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap>`
                                    
                                    .. attribute:: aigp
                                    
                                    	Enable a AIGP on neighbor
                                    	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: announce
                                    
                                    	Announce RPKI state using an extended community
                                    	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce>`
                                    
                                    .. attribute:: as_override
                                    
                                    	Override matching AS\-number while sending update
                                    	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability>`
                                    
                                    .. attribute:: default_originate
                                    
                                    	Originate default route to this neighbor
                                    	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: send_label
                                    
                                    	Send NLRI + MPLS Label to this peer
                                    	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: translate_update
                                    
                                    	Translate update to MBGP format
                                    	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate>`
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.allow_policy = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise()
                                        self.advertise.parent = self
                                        self._children_name_map["advertise"] = "advertise"

                                        self.advertise_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap()
                                        self.advertise_map.parent = self
                                        self._children_name_map["advertise_map"] = "advertise-map"

                                        self.aigp = None
                                        self._children_name_map["aigp"] = "aigp"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.announce = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce()
                                        self.announce.parent = self
                                        self._children_name_map["announce"] = "announce"

                                        self.as_override = None
                                        self._children_name_map["as_override"] = "as-override"

                                        self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.default_originate = None
                                        self._children_name_map["default_originate"] = "default-originate"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.send_label = None
                                        self._children_name_map["send_label"] = "send-label"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.translate_update = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate()
                                        self.translate_update.parent = self
                                        self._children_name_map["translate_update"] = "translate-update"

                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor, ['id', 'activate', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AdditionalPaths(Entity):
                                        """
                                        
                                        
                                        .. attribute:: disable
                                        
                                        	Disable additional paths for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send
                                        
                                        	Send additional paths to this neighbor
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send))])
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self.receive = None

                                            self.send = None
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                        class Send(Entity):
                                            """
                                            Send additional paths to this neighbor
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.receive = None
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                    class Advertise(Entity):
                                        """
                                        Advertise to this neighbor
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Advertise additional paths
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Advertise best\-external (at RRs best\-internal) path
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: diverse_path
                                        
                                        	Advertise diverse path
                                        	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                            self.yang_name = "advertise"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                            self._leafs = OrderedDict([
                                                ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                            ])
                                            self.best_external = None

                                            self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                            self.diverse_path.parent = self
                                            self._children_name_map["diverse_path"] = "diverse-path"
                                            self._segment_path = lambda: "advertise"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Advertise additional paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                            class All(Entity):
                                                """
                                                Select all available paths
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.group_best = None
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.all = None

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "best-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.all = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.all = None
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                        class DiversePath(Entity):
                                            """
                                            Advertise diverse path
                                            
                                            .. attribute:: backup
                                            
                                            	Diverse path can be backup path
                                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                self.yang_name = "diverse-path"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None

                                                self.backup = None
                                                self._children_name_map["backup"] = "backup"
                                                self._segment_path = lambda: "diverse-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                            class Backup(Entity):
                                                """
                                                Diverse path can be backup path
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                    self.yang_name = "backup"
                                                    self.yang_parent_name = "diverse-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None
                                                    self._segment_path = lambda: "backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                    class AdvertiseMap(Entity):
                                        """
                                        specify route\-map for conditional advertisement
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap, self).__init__()

                                            self.yang_name = "advertise-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name))])
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "advertise-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: word  (key)
                                            
                                            	advertise route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: non_exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "advertise-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                    ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                    ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                ])
                                                self.word = None
                                                self.exist_map = None
                                                self.non_exist_map = None
                                                self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                    class Aigp(Entity):
                                        """
                                        Enable a AIGP on neighbor
                                        
                                        .. attribute:: send
                                        
                                        	Cost community or MED carrying AIGP VALUE
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                            self.yang_name = "aigp"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.send = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send()
                                            self.send.parent = self
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "aigp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                        class Send(Entity):
                                            """
                                            Cost community or MED carrying AIGP VALUE
                                            
                                            .. attribute:: cost_community
                                            
                                            	Cost extended community carrying AIGP Value
                                            	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                            
                                            .. attribute:: med
                                            
                                            	Med carrying AIGP Value
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "aigp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                ])
                                                self.med = None

                                                self.cost_community = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                self.cost_community.parent = self
                                                self._children_name_map["cost_community"] = "cost-community"
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                            class CostCommunity(Entity):
                                                """
                                                Cost extended community carrying AIGP Value
                                                
                                                .. attribute:: cc_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                    self.yang_name = "cost-community"
                                                    self.yang_parent_name = "send"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                    self._leafs = OrderedDict()

                                                    self.cc_range = YList(self)
                                                    self._segment_path = lambda: "cost-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                class CcRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Community ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: poi
                                                    
                                                    	Point of insertion
                                                    	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                        self.yang_name = "cc-range"
                                                        self.yang_parent_name = "cost-community"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ])
                                                        self.range = None

                                                        self.poi = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                        self.poi.parent = self
                                                        self._children_name_map["poi"] = "poi"
                                                        self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                    class Poi(Entity):
                                                        """
                                                        Point of insertion
                                                        
                                                        .. attribute:: igp_cost
                                                        
                                                        	Point of insertion after IGP
                                                        	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        .. attribute:: pre_bestpath
                                                        
                                                        	Point of insertion at beginning
                                                        	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                            self.yang_name = "poi"
                                                            self.yang_parent_name = "cc-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                            self._leafs = OrderedDict()

                                                            self.igp_cost = None
                                                            self._children_name_map["igp_cost"] = "igp-cost"

                                                            self.pre_bestpath = None
                                                            self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                            self._segment_path = lambda: "poi"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                        class IgpCost(Entity):
                                                            """
                                                            Point of insertion after IGP
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                self.yang_name = "igp-cost"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "igp-cost"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                        class PreBestpath(Entity):
                                                            """
                                                            Point of insertion at beginning
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                self.yang_name = "pre-bestpath"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "pre-bestpath"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Announce(Entity):
                                        """
                                        Announce RPKI state using an extended community
                                        
                                        .. attribute:: rpki
                                        
                                        	Announce RPKI information using an extended community
                                        	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce, self).__init__()

                                            self.yang_name = "announce"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki))])
                                            self._leafs = OrderedDict()

                                            self.rpki = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki()
                                            self.rpki.parent = self
                                            self._children_name_map["rpki"] = "rpki"
                                            self._segment_path = lambda: "announce"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce, [], name, value)


                                        class Rpki(Entity):
                                            """
                                            Announce RPKI information using an extended community
                                            
                                            .. attribute:: state
                                            
                                            	Announce RPKI state information using an extended community
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki, self).__init__()

                                                self.yang_name = "rpki"
                                                self.yang_parent_name = "announce"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                ])
                                                self.state = None
                                                self._segment_path = lambda: "rpki"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki, ['state'], name, value)


                                    class AsOverride(Entity):
                                        """
                                        Override matching AS\-number while sending update
                                        
                                        .. attribute:: disable
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride, self).__init__()

                                            self.yang_name = "as-override"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self._segment_path = lambda: "as-override"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride, ['disable'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DefaultOriginate(Entity):
                                        """
                                        Originate default route to this neighbor
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria to originate default
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                            self.yang_name = "default-originate"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "default-originate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SendLabel(Entity):
                                        """
                                        Send NLRI + MPLS Label to this peer
                                        
                                        .. attribute:: send_label_explicit
                                        
                                        	
                                        	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel, self).__init__()

                                            self.yang_name = "send-label"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit')])),
                                            ])
                                            self.send_label_explicit = None
                                            self._segment_path = lambda: "send-label"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                        class SendLabelExplicit(Enum):
                                            """
                                            SendLabelExplicit (Enum Class)

                                            .. data:: explicit_null = 0

                                            """

                                            explicit_null = Enum.YLeaf(0, "explicit-null")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class TranslateUpdate(Entity):
                                        """
                                        Translate update to MBGP format
                                        
                                        .. attribute:: ipv4
                                        
                                        	Address Family
                                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate, self).__init__()

                                            self.yang_name = "translate-update"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4))])
                                            self._leafs = OrderedDict()

                                            self.ipv4 = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4()
                                            self.ipv4.parent = self
                                            self._children_name_map["ipv4"] = "ipv4"
                                            self._segment_path = lambda: "translate-update"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate, [], name, value)


                                        class Ipv4(Entity):
                                            """
                                            Address Family
                                            
                                            .. attribute:: multicast
                                            
                                            	Address Family modifier
                                            	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4, self).__init__()

                                                self.yang_name = "ipv4"
                                                self.yang_parent_name = "translate-update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast))])
                                                self._leafs = OrderedDict()

                                                self.multicast = None
                                                self._children_name_map["multicast"] = "multicast"
                                                self._segment_path = lambda: "ipv4"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4, [], name, value)


                                            class Multicast(Entity):
                                                """
                                                Address Family modifier
                                                
                                                .. attribute:: unicast
                                                
                                                	Address Family modifier
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast, self).__init__()

                                                    self.yang_name = "multicast"
                                                    self.yang_parent_name = "ipv4"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                    ])
                                                    self.unicast = None
                                                    self._segment_path = lambda: "multicast"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast, ['unicast'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: additional_paths
                                
                                	
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths>`
                                
                                .. attribute:: advertise
                                
                                	Advertise to this neighbor
                                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise>`
                                
                                .. attribute:: advertise_map
                                
                                	specify route\-map for conditional advertisement
                                	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap>`
                                
                                .. attribute:: aigp
                                
                                	Enable a AIGP on neighbor
                                	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: announce
                                
                                	Announce RPKI state using an extended community
                                	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce>`
                                
                                .. attribute:: as_override
                                
                                	Override matching AS\-number while sending update
                                	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: capability
                                
                                	Advertise capability to the peer
                                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability>`
                                
                                .. attribute:: default_originate
                                
                                	Originate default route to this neighbor
                                	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dmzlink_bw
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: send_label
                                
                                	Send NLRI + MPLS Label to this peer
                                	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: translate_update
                                
                                	Translate update to MBGP format
                                	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate>`
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "ipv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.allow_policy = None
                                    self.dmzlink_bw = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise()
                                    self.advertise.parent = self
                                    self._children_name_map["advertise"] = "advertise"

                                    self.advertise_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap()
                                    self.advertise_map.parent = self
                                    self._children_name_map["advertise_map"] = "advertise-map"

                                    self.aigp = None
                                    self._children_name_map["aigp"] = "aigp"

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.announce = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce()
                                    self.announce.parent = self
                                    self._children_name_map["announce"] = "announce"

                                    self.as_override = None
                                    self._children_name_map["as_override"] = "as-override"

                                    self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability()
                                    self.capability.parent = self
                                    self._children_name_map["capability"] = "capability"

                                    self.default_originate = None
                                    self._children_name_map["default_originate"] = "default-originate"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.send_label = None
                                    self._children_name_map["send_label"] = "send-label"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.translate_update = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate()
                                    self.translate_update.parent = self
                                    self._children_name_map["translate_update"] = "translate-update"

                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor, ['id', 'activate', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AdditionalPaths(Entity):
                                    """
                                    
                                    
                                    .. attribute:: disable
                                    
                                    	Disable additional paths for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to this neighbor
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.disable = None
                                        self.receive = None

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to this neighbor
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                class Advertise(Entity):
                                    """
                                    Advertise to this neighbor
                                    
                                    .. attribute:: additional_paths
                                    
                                    	Advertise additional paths
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths>`
                                    
                                    .. attribute:: best_external
                                    
                                    	Advertise best\-external (at RRs best\-internal) path
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: diverse_path
                                    
                                    	Advertise diverse path
                                    	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise, self).__init__()

                                        self.yang_name = "advertise"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath))])
                                        self._leafs = OrderedDict([
                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                        ])
                                        self.best_external = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath()
                                        self.diverse_path.parent = self
                                        self._children_name_map["diverse_path"] = "diverse-path"
                                        self._segment_path = lambda: "advertise"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                    class AdditionalPaths(Entity):
                                        """
                                        Advertise additional paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best paths
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: best_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                self._leafs = OrderedDict()

                                                self.best_range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                            class BestRange(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                    self.yang_name = "best-range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "best-range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                    class DiversePath(Entity):
                                        """
                                        Advertise diverse path
                                        
                                        .. attribute:: backup
                                        
                                        	Diverse path can be backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: mpath
                                        
                                        	Diverse path can be multipath
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                            self.yang_name = "diverse-path"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                            self._leafs = OrderedDict([
                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                            ])
                                            self.mpath = None

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"
                                            self._segment_path = lambda: "diverse-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                        class Backup(Entity):
                                            """
                                            Diverse path can be backup path
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "diverse-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                class AdvertiseMap(Entity):
                                    """
                                    specify route\-map for conditional advertisement
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap, self).__init__()

                                        self.yang_name = "advertise-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name))])
                                        self._leafs = OrderedDict()

                                        self.name = YList(self)
                                        self._segment_path = lambda: "advertise-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap, [], name, value)


                                    class Name(Entity):
                                        """
                                        
                                        
                                        .. attribute:: word  (key)
                                        
                                        	advertise route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: exist_map
                                        
                                        	condition route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: non_exist_map
                                        
                                        	condition route\-map name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name, self).__init__()

                                            self.yang_name = "name"
                                            self.yang_parent_name = "advertise-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                            ])
                                            self.word = None
                                            self.exist_map = None
                                            self.non_exist_map = None
                                            self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                class Aigp(Entity):
                                    """
                                    Enable a AIGP on neighbor
                                    
                                    .. attribute:: send
                                    
                                    	Cost community or MED carrying AIGP VALUE
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp, self).__init__()

                                        self.yang_name = "aigp"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.send = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send()
                                        self.send.parent = self
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "aigp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp, [], name, value)


                                    class Send(Entity):
                                        """
                                        Cost community or MED carrying AIGP VALUE
                                        
                                        .. attribute:: cost_community
                                        
                                        	Cost extended community carrying AIGP Value
                                        	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity>`
                                        
                                        .. attribute:: med
                                        
                                        	Med carrying AIGP Value
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "aigp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity))])
                                            self._leafs = OrderedDict([
                                                ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                            ])
                                            self.med = None

                                            self.cost_community = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity()
                                            self.cost_community.parent = self
                                            self._children_name_map["cost_community"] = "cost-community"
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send, ['med'], name, value)


                                        class CostCommunity(Entity):
                                            """
                                            Cost extended community carrying AIGP Value
                                            
                                            .. attribute:: cc_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                self.yang_name = "cost-community"
                                                self.yang_parent_name = "send"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                self._leafs = OrderedDict()

                                                self.cc_range = YList(self)
                                                self._segment_path = lambda: "cost-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                            class CcRange(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Community ID
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: poi
                                                
                                                	Point of insertion
                                                	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                    self.yang_name = "cc-range"
                                                    self.yang_parent_name = "cost-community"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                    ])
                                                    self.range = None

                                                    self.poi = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                    self.poi.parent = self
                                                    self._children_name_map["poi"] = "poi"
                                                    self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                class Poi(Entity):
                                                    """
                                                    Point of insertion
                                                    
                                                    .. attribute:: igp_cost
                                                    
                                                    	Point of insertion after IGP
                                                    	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: pre_bestpath
                                                    
                                                    	Point of insertion at beginning
                                                    	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                        self.yang_name = "poi"
                                                        self.yang_parent_name = "cc-range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                        self._leafs = OrderedDict()

                                                        self.igp_cost = None
                                                        self._children_name_map["igp_cost"] = "igp-cost"

                                                        self.pre_bestpath = None
                                                        self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                        self._segment_path = lambda: "poi"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                    class IgpCost(Entity):
                                                        """
                                                        Point of insertion after IGP
                                                        
                                                        .. attribute:: transitive
                                                        
                                                        	Cost community is transitive
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                            self.yang_name = "igp-cost"
                                                            self.yang_parent_name = "poi"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                            ])
                                                            self.transitive = None
                                                            self._segment_path = lambda: "igp-cost"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                    class PreBestpath(Entity):
                                                        """
                                                        Point of insertion at beginning
                                                        
                                                        .. attribute:: transitive
                                                        
                                                        	Cost community is transitive
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                            self.yang_name = "pre-bestpath"
                                                            self.yang_parent_name = "poi"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                            ])
                                                            self.transitive = None
                                                            self._segment_path = lambda: "pre-bestpath"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Announce(Entity):
                                    """
                                    Announce RPKI state using an extended community
                                    
                                    .. attribute:: rpki
                                    
                                    	Announce RPKI information using an extended community
                                    	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce, self).__init__()

                                        self.yang_name = "announce"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki))])
                                        self._leafs = OrderedDict()

                                        self.rpki = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki()
                                        self.rpki.parent = self
                                        self._children_name_map["rpki"] = "rpki"
                                        self._segment_path = lambda: "announce"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce, [], name, value)


                                    class Rpki(Entity):
                                        """
                                        Announce RPKI information using an extended community
                                        
                                        .. attribute:: state
                                        
                                        	Announce RPKI state information using an extended community
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki, self).__init__()

                                            self.yang_name = "rpki"
                                            self.yang_parent_name = "announce"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                            ])
                                            self.state = None
                                            self._segment_path = lambda: "rpki"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki, ['state'], name, value)


                                class AsOverride(Entity):
                                    """
                                    Override matching AS\-number while sending update
                                    
                                    .. attribute:: disable
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride, self).__init__()

                                        self.yang_name = "as-override"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                        ])
                                        self.disable = None
                                        self._segment_path = lambda: "as-override"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride, ['disable'], name, value)


                                class Capability(Entity):
                                    """
                                    Advertise capability to the peer
                                    
                                    .. attribute:: orf
                                    
                                    	Advertise ORF capability to the peer
                                    	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability, self).__init__()

                                        self.yang_name = "capability"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf))])
                                        self._leafs = OrderedDict()

                                        self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf()
                                        self.orf.parent = self
                                        self._children_name_map["orf"] = "orf"
                                        self._segment_path = lambda: "capability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability, [], name, value)


                                    class Orf(Entity):
                                        """
                                        Advertise ORF capability to the peer
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Advertise prefix list ORF capability to this neighbor
                                        	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf.PrefixList>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf, self).__init__()

                                            self.yang_name = "orf"
                                            self.yang_parent_name = "capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf.PrefixList')])),
                                            ])
                                            self.prefix_list = []
                                            self._segment_path = lambda: "orf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                        class PrefixList(Enum):
                                            """
                                            PrefixList (Enum Class)

                                            Advertise prefix list ORF capability to this neighbor

                                            .. data:: both = 0

                                            .. data:: receive = 1

                                            .. data:: send = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            receive = Enum.YLeaf(1, "receive")

                                            send = Enum.YLeaf(2, "send")



                                class DefaultOriginate(Entity):
                                    """
                                    Originate default route to this neighbor
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria to originate default
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate, self).__init__()

                                        self.yang_name = "default-originate"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "default-originate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SendLabel(Entity):
                                    """
                                    Send NLRI + MPLS Label to this peer
                                    
                                    .. attribute:: send_label_explicit
                                    
                                    	
                                    	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel.SendLabelExplicit>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel, self).__init__()

                                        self.yang_name = "send-label"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel.SendLabelExplicit')])),
                                        ])
                                        self.send_label_explicit = None
                                        self._segment_path = lambda: "send-label"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                    class SendLabelExplicit(Enum):
                                        """
                                        SendLabelExplicit (Enum Class)

                                        .. data:: explicit_null = 0

                                        """

                                        explicit_null = Enum.YLeaf(0, "explicit-null")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class TranslateUpdate(Entity):
                                    """
                                    Translate update to MBGP format
                                    
                                    .. attribute:: ipv4
                                    
                                    	Address Family
                                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate, self).__init__()

                                        self.yang_name = "translate-update"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4))])
                                        self._leafs = OrderedDict()

                                        self.ipv4 = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4()
                                        self.ipv4.parent = self
                                        self._children_name_map["ipv4"] = "ipv4"
                                        self._segment_path = lambda: "translate-update"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate, [], name, value)


                                    class Ipv4(Entity):
                                        """
                                        Address Family
                                        
                                        .. attribute:: multicast
                                        
                                        	Address Family modifier
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4, self).__init__()

                                            self.yang_name = "ipv4"
                                            self.yang_parent_name = "translate-update"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast))])
                                            self._leafs = OrderedDict()

                                            self.multicast = None
                                            self._children_name_map["multicast"] = "multicast"
                                            self._segment_path = lambda: "ipv4"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4, [], name, value)


                                        class Multicast(Entity):
                                            """
                                            Address Family modifier
                                            
                                            .. attribute:: unicast
                                            
                                            	Address Family modifier
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "ipv4"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                ])
                                                self.unicast = None
                                                self._segment_path = lambda: "multicast"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast, ['unicast'], name, value)


                            class Network(Entity):
                                """
                                Specify a network to announce via BGP
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: route_map
                                
                                	Route\-map to modify the attributes
                                	**type**\: str
                                
                                .. attribute:: backdoor
                                
                                	Specify a BGP backdoor route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network, self).__init__()

                                    self.yang_name = "network"
                                    self.yang_parent_name = "ipv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.route_map = None
                                    self.backdoor = None
                                    self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network, ['number', 'route_map', 'backdoor'], name, value)


                            class Redistribute(Entity):
                                """
                                Redistribute information from another routing protocol
                                
                                .. attribute:: application
                                
                                	Application
                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dvmrp
                                
                                	Redistribution of DVMRP into BGP IPv4 Multicast
                                	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol
                                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: iso_igrp
                                
                                	IGRP for OSI networks
                                	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp>`
                                
                                .. attribute:: mobile
                                
                                	Mobile routes
                                	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: odr
                                
                                	On Demand stub Routes
                                	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute, self).__init__()

                                    self.yang_name = "redistribute"
                                    self.yang_parent_name = "ipv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static))])
                                    self._leafs = OrderedDict()

                                    self.application = None
                                    self._children_name_map["application"] = "application"

                                    self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.connected = None
                                    self._children_name_map["connected"] = "connected"

                                    self.dvmrp = None
                                    self._children_name_map["dvmrp"] = "dvmrp"

                                    self.eigrp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp()
                                    self.eigrp.parent = self
                                    self._children_name_map["eigrp"] = "eigrp"

                                    self.isis = None
                                    self._children_name_map["isis"] = "isis"

                                    self.lisp = None
                                    self._children_name_map["lisp"] = "lisp"

                                    self.iso_igrp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp()
                                    self.iso_igrp.parent = self
                                    self._children_name_map["iso_igrp"] = "iso-igrp"

                                    self.mobile = None
                                    self._children_name_map["mobile"] = "mobile"

                                    self.odr = None
                                    self._children_name_map["odr"] = "odr"

                                    self.rip = None
                                    self._children_name_map["rip"] = "rip"

                                    self.static = None
                                    self._children_name_map["static"] = "static"

                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "redistribute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute, [], name, value)


                                class Application(Entity):
                                    """
                                    Application
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application, self).__init__()

                                        self.yang_name = "application"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.name = YList(self)
                                        self._segment_path = lambda: "application"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application, [], name, value)


                                    class Name(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	WORD \:\: Route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name, self).__init__()

                                            self.yang_name = "name"
                                            self.yang_parent_name = "application"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                class Bgp_(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: as_no
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_no = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                class Dvmrp(Entity):
                                    """
                                    Redistribution of DVMRP into BGP IPv4 Multicast
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp, self).__init__()

                                        self.yang_name = "dvmrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.route_map = None
                                        self.metric = None
                                        self._segment_path = lambda: "dvmrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: as_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_no = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "eigrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: isis_area
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea>`
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.isis_area = YList(self)
                                        self._segment_path = lambda: "isis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis, [], name, value)


                                    class IsisArea(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: routes
                                        
                                        	
                                        	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea.Routes>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea, self).__init__()

                                            self.yang_name = "isis-area"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea.Routes')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.ip = None
                                            self.clns = None
                                            self.routes = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                        class Routes(Enum):
                                            """
                                            Routes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class Default(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: routes
                                        
                                        	
                                        	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default.Routes>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default.Routes')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.ip = None
                                            self.clns = None
                                            self.routes = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                        class Routes(Enum):
                                            """
                                            Routes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class Lisp(Entity):
                                    """
                                    Locator/ID Separation Protocol
                                    
                                    .. attribute:: include_connected
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp, self).__init__()

                                        self.yang_name = "lisp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.include_connected = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "lisp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                class IsoIgrp(Entity):
                                    """
                                    IGRP for OSI networks
                                    
                                    .. attribute:: iso_igrp_area
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp, self).__init__()

                                        self.yang_name = "iso-igrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default))])
                                        self._leafs = OrderedDict()

                                        self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.iso_igrp_area = YList(self)
                                        self._segment_path = lambda: "iso-igrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp, [], name, value)


                                    class IsoIgrpArea(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                            self.yang_name = "iso-igrp-area"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.name = None
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                    class Default(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                class Mobile(Entity):
                                    """
                                    Mobile routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile, self).__init__()

                                        self.yang_name = "mobile"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "mobile"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                class Odr(Entity):
                                    """
                                    On Demand stub Routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr, self).__init__()

                                        self.yang_name = "odr"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "odr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: vrf
                                    
                                    	VPN Routing/Forwarding Instance
                                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf>`
                                    
                                    .. attribute:: non_vrf
                                    
                                    	
                                    	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf)), ("non-vrf", ("non_vrf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.non_vrf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf()
                                        self.non_vrf.parent = self
                                        self._children_name_map["non_vrf"] = "non-vrf"

                                        self.vrf = YList(self)
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf, ['id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VPN Routing/Forwarding Instance
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf.Match))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf, ['name', 'metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict()
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True


                                    class NonVrf(Entity):
                                        """
                                        
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf, self).__init__()

                                            self.yang_name = "non-vrf"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match))])
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "non-vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: external2
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "non-vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                    ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.internal = None
                                                self.external = None
                                                self.external2 = None
                                                self.nssa_external = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: match
                                    
                                    	
                                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.id = None
                                        self.metric = None
                                        self.route_map = None

                                        self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match()
                                        self.match.parent = self
                                        self._children_name_map["match"] = "match"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                    class Match(Entity):
                                        """
                                        
                                        
                                        .. attribute:: internal
                                        
                                        	Redistribute OSPF internal routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: external
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: external2
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: nssa_external
                                        
                                        	Redistribute OSPF NSSA external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match, self).__init__()

                                            self.yang_name = "match"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.internal = None
                                            self.external = None
                                            self.external2 = None
                                            self.nssa_external = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "match"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: name
                                    
                                    	User selected string identifying this process
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self.name = None
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: clns
                                    
                                    	Redistribution of OSI dynamic routes
                                    	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ip
                                    
                                    	
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None

                                        self.clns = None
                                        self._children_name_map["clns"] = "clns"

                                        self.ip = None
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                    class Clns(Entity):
                                        """
                                        Redistribution of OSI dynamic routes
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns, self).__init__()

                                            self.yang_name = "clns"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "clns"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                    class Ip(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "ipv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class TableMap(Entity):
                                """
                                Map external entry attributes into routing table
                                
                                .. attribute:: name
                                
                                	WORD \:\: Route\-map name
                                	**type**\: str
                                
                                .. attribute:: filter
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap, self).__init__()

                                    self.yang_name = "table-map"
                                    self.yang_parent_name = "ipv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                                    ])
                                    self.name = None
                                    self.filter = None
                                    self._segment_path = lambda: "table-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap, ['name', 'filter'], name, value)


                        class Ipv6Multicast(Entity):
                            """
                            IPv6 Multicast address family
                            
                            .. attribute:: aggregate_address
                            
                            	Configure BGP aggregate entries
                            	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.AggregateAddress>`
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_>`
                            
                            .. attribute:: distance
                            
                            	Define an administrative distance
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor>`
                            
                            .. attribute:: network
                            
                            	Specify a network to announce via BGP
                            	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Network>`
                            
                            .. attribute:: redistribute
                            
                            	Redistribute information from another routing protocol
                            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast, self).__init__()

                                self.yang_name = "ipv6-multicast"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_)), ("distance", ("distance", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.distance = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.redistribute = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute()
                                self.redistribute.parent = self
                                self._children_name_map["redistribute"] = "redistribute"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.aggregate_address = YList(self)
                                self.neighbor = YList(self)
                                self.network = YList(self)
                                self._segment_path = lambda: "ipv6-multicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast, [], name, value)


                            class AggregateAddress(Entity):
                                """
                                Configure BGP aggregate entries
                                
                                .. attribute:: ipv6_address  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: advertise_map
                                
                                	Set condition to advertise attribute
                                	**type**\: str
                                
                                .. attribute:: as_set
                                
                                	Generate AS set path information
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: attribute_map
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: as_override
                                
                                	Override matching AS\-number while sending update
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: summary_only
                                
                                	Filter more specific routes from updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: suppress_map
                                
                                	Conditionally filter more specific routes from updates
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.AggregateAddress, self).__init__()

                                    self.yang_name = "aggregate-address"
                                    self.yang_parent_name = "ipv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv6_address']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                        ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                        ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                        ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                    ])
                                    self.ipv6_address = None
                                    self.advertise_map = None
                                    self.as_set = None
                                    self.attribute_map = None
                                    self.as_override = None
                                    self.route_map = None
                                    self.summary_only = None
                                    self.suppress_map = None
                                    self._segment_path = lambda: "aggregate-address" + "[ipv6-address='" + str(self.ipv6_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.AggregateAddress, ['ipv6_address', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: additional_paths
                                
                                	Additional paths in the BGP table
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths>`
                                
                                .. attribute:: aggregate_timer
                                
                                	Configure aggregation timer
                                	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AggregateTimer>`
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Nexthop>`
                                
                                .. attribute:: redistribute_internal
                                
                                	Allow redistribution of iBGP into IGPs (dangerous)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: update_group
                                
                                	Manage peers in bgp update groups
                                	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "ipv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AggregateTimer)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Dampening)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Nexthop)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.UpdateGroup))])
                                    self._leafs = OrderedDict([
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                    ])
                                    self.dmzlink_bw = None
                                    self.redistribute_internal = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.aggregate_timer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AggregateTimer()
                                    self.aggregate_timer.parent = self
                                    self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.UpdateGroup()
                                    self.update_group.parent = self
                                    self._children_name_map["update_group"] = "update-group"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_, ['dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                class AdditionalPaths(Entity):
                                    """
                                    Additional paths in the BGP table
                                    
                                    .. attribute:: install
                                    
                                    	Additional paths to install into RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: select
                                    
                                    	Selection criteria to pick the paths
                                    	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to neighbors
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.install = None
                                        self.receive = None

                                        self.select = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select()
                                        self.select.parent = self
                                        self._children_name_map["select"] = "select"

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                    class Select(Entity):
                                        """
                                        Selection criteria to pick the paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: backup
                                        
                                        	Select backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Select best\-external path
                                        	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best path
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                            self.yang_name = "select"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.best_external = None
                                            self._children_name_map["best_external"] = "best-external"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "select"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best path
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best path
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                        class Backup(Entity):
                                            """
                                            Select backup path
                                            
                                            .. attribute:: best_external
                                            
                                            	Select best\-external path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                self._leafs = OrderedDict()

                                                self.range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                        class BestExternal(Entity):
                                            """
                                            Select best\-external path
                                            
                                            .. attribute:: backup
                                            
                                            	Select backup path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                self.yang_name = "best-external"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                ])
                                                self.backup = None
                                                self._segment_path = lambda: "best-external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best path
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to neighbors
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                class AggregateTimer(Entity):
                                    """
                                    Configure aggregation timer
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Timer interval
                                    	**type**\: int
                                    
                                    	**range:** 6..60
                                    
                                    .. attribute:: disable_timer
                                    
                                    	Timer interval
                                    	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AggregateTimer.DisableTimer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AggregateTimer, self).__init__()

                                        self.yang_name = "aggregate-timer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                            ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AggregateTimer.DisableTimer')])),
                                        ])
                                        self.aggregate_timer = None
                                        self.disable_timer = None
                                        self._segment_path = lambda: "aggregate-timer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                    class DisableTimer(Enum):
                                        """
                                        DisableTimer (Enum Class)

                                        Timer interval

                                        .. data:: Y_0 = 0

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")



                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria for dampening
                                    	**type**\: str
                                    
                                    .. attribute:: dampen
                                    
                                    	
                                    	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Dampening.Dampen>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Dampening.Dampen))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.dampen = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Dampening.Dampen()
                                        self.dampen.parent = self
                                        self._children_name_map["dampen"] = "dampen"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Dampening, ['route_map'], name, value)


                                    class Dampen(Entity):
                                        """
                                        
                                        
                                        .. attribute:: half_life_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..45
                                        
                                        .. attribute:: reuse_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: max_suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Dampening.Dampen, self).__init__()

                                            self.yang_name = "dampen"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                            ])
                                            self.half_life_time = None
                                            self.reuse_time = None
                                            self.suppress_time = None
                                            self.max_suppress_time = None
                                            self._segment_path = lambda: "dampen"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    Manage peers in bgp update groups
                                    
                                    .. attribute:: split
                                    
                                    	Split update groups based on Policy
                                    	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.UpdateGroup.Split>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.UpdateGroup.Split))])
                                        self._leafs = OrderedDict()

                                        self.split = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.UpdateGroup.Split()
                                        self.split.parent = self
                                        self._children_name_map["split"] = "split"
                                        self._segment_path = lambda: "update-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.UpdateGroup, [], name, value)


                                    class Split(Entity):
                                        """
                                        Split update groups based on Policy
                                        
                                        .. attribute:: as_override
                                        
                                        	Keep peers with as\-override in different update groups
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.UpdateGroup.Split, self).__init__()

                                            self.yang_name = "split"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ])
                                            self.as_override = None
                                            self._segment_path = lambda: "split"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                            class Distance(Entity):
                                """
                                Define an administrative distance
                                
                                .. attribute:: bgp
                                
                                	BGP distance
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance.Bgp_>`
                                
                                .. attribute:: adm_distance
                                
                                	
                                	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance.AdmDistance>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance.AdmDistance))])
                                    self._leafs = OrderedDict()

                                    self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.adm_distance = YList(self)
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance, [], name, value)


                                class Bgp_(Entity):
                                    """
                                    BGP distance
                                    
                                    .. attribute:: extern_as
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: internal_as
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                            ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                            ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                        ])
                                        self.extern_as = None
                                        self.internal_as = None
                                        self.local = None
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                class AdmDistance(Entity):
                                    """
                                    
                                    
                                    .. attribute:: distance  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: srcip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: wildbits  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: acl
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..99
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..1999
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance.AdmDistance, self).__init__()

                                        self.yang_name = "adm-distance"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['distance','srcip','wildbits']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                            ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                            ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                        ])
                                        self.distance = None
                                        self.srcip = None
                                        self.wildbits = None
                                        self.acl = None
                                        self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "ipv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: additional_paths
                                    
                                    	
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdditionalPaths>`
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise to this neighbor
                                    	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise>`
                                    
                                    .. attribute:: advertise_map
                                    
                                    	specify route\-map for conditional advertisement
                                    	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdvertiseMap>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: aigp
                                    
                                    	Enable a AIGP on neighbor
                                    	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability>`
                                    
                                    .. attribute:: default_originate
                                    
                                    	Originate default route to this neighbor
                                    	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.DefaultOriginate>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.DistributeList>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise()
                                        self.advertise.parent = self
                                        self._children_name_map["advertise"] = "advertise"

                                        self.advertise_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdvertiseMap()
                                        self.advertise_map.parent = self
                                        self._children_name_map["advertise_map"] = "advertise-map"

                                        self.aigp = None
                                        self._children_name_map["aigp"] = "aigp"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.default_originate = None
                                        self._children_name_map["default_originate"] = "default-originate"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.distribute_list = YList(self)
                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AdditionalPaths(Entity):
                                        """
                                        
                                        
                                        .. attribute:: disable
                                        
                                        	Disable additional paths for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send
                                        
                                        	Send additional paths to this neighbor
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdditionalPaths.Send>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdditionalPaths.Send))])
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self.receive = None

                                            self.send = None
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                        class Send(Entity):
                                            """
                                            Send additional paths to this neighbor
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdditionalPaths.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.receive = None
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                    class Advertise(Entity):
                                        """
                                        Advertise to this neighbor
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Advertise additional paths
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Advertise best\-external (at RRs best\-internal) path
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: diverse_path
                                        
                                        	Advertise diverse path
                                        	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                            self.yang_name = "advertise"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                            self._leafs = OrderedDict([
                                                ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                            ])
                                            self.best_external = None

                                            self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                            self.diverse_path.parent = self
                                            self._children_name_map["diverse_path"] = "diverse-path"
                                            self._segment_path = lambda: "advertise"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Advertise additional paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                            class All(Entity):
                                                """
                                                Select all available paths
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.group_best = None
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.all = None

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "best-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.all = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.all = None
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                        class DiversePath(Entity):
                                            """
                                            Advertise diverse path
                                            
                                            .. attribute:: backup
                                            
                                            	Diverse path can be backup path
                                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                self.yang_name = "diverse-path"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None

                                                self.backup = None
                                                self._children_name_map["backup"] = "backup"
                                                self._segment_path = lambda: "diverse-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                            class Backup(Entity):
                                                """
                                                Diverse path can be backup path
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                    self.yang_name = "backup"
                                                    self.yang_parent_name = "diverse-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None
                                                    self._segment_path = lambda: "backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                    class AdvertiseMap(Entity):
                                        """
                                        specify route\-map for conditional advertisement
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdvertiseMap.Name>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdvertiseMap, self).__init__()

                                            self.yang_name = "advertise-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdvertiseMap.Name))])
                                            self._leafs = OrderedDict()

                                            self.name = YList(self)
                                            self._segment_path = lambda: "advertise-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdvertiseMap, [], name, value)


                                        class Name(Entity):
                                            """
                                            
                                            
                                            .. attribute:: word  (key)
                                            
                                            	advertise route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            .. attribute:: non_exist_map
                                            
                                            	condition route\-map name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdvertiseMap.Name, self).__init__()

                                                self.yang_name = "name"
                                                self.yang_parent_name = "advertise-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['word']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                    ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                    ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                ])
                                                self.word = None
                                                self.exist_map = None
                                                self.non_exist_map = None
                                                self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                    class Aigp(Entity):
                                        """
                                        Enable a AIGP on neighbor
                                        
                                        .. attribute:: send
                                        
                                        	Cost community or MED carrying AIGP VALUE
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                            self.yang_name = "aigp"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.send = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send()
                                            self.send.parent = self
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "aigp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                        class Send(Entity):
                                            """
                                            Cost community or MED carrying AIGP VALUE
                                            
                                            .. attribute:: cost_community
                                            
                                            	Cost extended community carrying AIGP Value
                                            	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                            
                                            .. attribute:: med
                                            
                                            	Med carrying AIGP Value
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "aigp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                ])
                                                self.med = None

                                                self.cost_community = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                self.cost_community.parent = self
                                                self._children_name_map["cost_community"] = "cost-community"
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                            class CostCommunity(Entity):
                                                """
                                                Cost extended community carrying AIGP Value
                                                
                                                .. attribute:: cc_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                    self.yang_name = "cost-community"
                                                    self.yang_parent_name = "send"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                    self._leafs = OrderedDict()

                                                    self.cc_range = YList(self)
                                                    self._segment_path = lambda: "cost-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                class CcRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Community ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: poi
                                                    
                                                    	Point of insertion
                                                    	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                        self.yang_name = "cc-range"
                                                        self.yang_parent_name = "cost-community"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ])
                                                        self.range = None

                                                        self.poi = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                        self.poi.parent = self
                                                        self._children_name_map["poi"] = "poi"
                                                        self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                    class Poi(Entity):
                                                        """
                                                        Point of insertion
                                                        
                                                        .. attribute:: igp_cost
                                                        
                                                        	Point of insertion after IGP
                                                        	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        .. attribute:: pre_bestpath
                                                        
                                                        	Point of insertion at beginning
                                                        	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                            self.yang_name = "poi"
                                                            self.yang_parent_name = "cc-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                            self._leafs = OrderedDict()

                                                            self.igp_cost = None
                                                            self._children_name_map["igp_cost"] = "igp-cost"

                                                            self.pre_bestpath = None
                                                            self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                            self._segment_path = lambda: "poi"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                        class IgpCost(Entity):
                                                            """
                                                            Point of insertion after IGP
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                self.yang_name = "igp-cost"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "igp-cost"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                        class PreBestpath(Entity):
                                                            """
                                                            Point of insertion at beginning
                                                            
                                                            .. attribute:: transitive
                                                            
                                                            	Cost community is transitive
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                self.yang_name = "pre-bestpath"
                                                                self.yang_parent_name = "poi"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                ])
                                                                self.transitive = None
                                                                self._segment_path = lambda: "pre-bestpath"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DefaultOriginate(Entity):
                                        """
                                        Originate default route to this neighbor
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria to originate default
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                            self.yang_name = "default-originate"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "default-originate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                        
                                        .. attribute:: accesslist
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                            ])
                                            self.inout = None
                                            self.accesslist = None
                                            self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: additional_paths
                                
                                	
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdditionalPaths>`
                                
                                .. attribute:: advertise
                                
                                	Advertise to this neighbor
                                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise>`
                                
                                .. attribute:: advertise_map
                                
                                	specify route\-map for conditional advertisement
                                	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdvertiseMap>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: aigp
                                
                                	Enable a AIGP on neighbor
                                	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: capability
                                
                                	Advertise capability to the peer
                                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability>`
                                
                                .. attribute:: default_originate
                                
                                	Originate default route to this neighbor
                                	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.DefaultOriginate>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: distribute_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.DistributeList>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "ipv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.dmzlink_bw = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise()
                                    self.advertise.parent = self
                                    self._children_name_map["advertise"] = "advertise"

                                    self.advertise_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdvertiseMap()
                                    self.advertise_map.parent = self
                                    self._children_name_map["advertise_map"] = "advertise-map"

                                    self.aigp = None
                                    self._children_name_map["aigp"] = "aigp"

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability()
                                    self.capability.parent = self
                                    self._children_name_map["capability"] = "capability"

                                    self.default_originate = None
                                    self._children_name_map["default_originate"] = "default-originate"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.distribute_list = YList(self)
                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AdditionalPaths(Entity):
                                    """
                                    
                                    
                                    .. attribute:: disable
                                    
                                    	Disable additional paths for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to this neighbor
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.disable = None
                                        self.receive = None

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to this neighbor
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                class Advertise(Entity):
                                    """
                                    Advertise to this neighbor
                                    
                                    .. attribute:: additional_paths
                                    
                                    	Advertise additional paths
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths>`
                                    
                                    .. attribute:: best_external
                                    
                                    	Advertise best\-external (at RRs best\-internal) path
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: diverse_path
                                    
                                    	Advertise diverse path
                                    	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.DiversePath>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise, self).__init__()

                                        self.yang_name = "advertise"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.DiversePath))])
                                        self._leafs = OrderedDict([
                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                        ])
                                        self.best_external = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.DiversePath()
                                        self.diverse_path.parent = self
                                        self._children_name_map["diverse_path"] = "diverse-path"
                                        self._segment_path = lambda: "advertise"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise, ['best_external'], name, value)


                                    class AdditionalPaths(Entity):
                                        """
                                        Advertise additional paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best paths
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: best_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                self._leafs = OrderedDict()

                                                self.best_range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                            class BestRange(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                    self.yang_name = "best-range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "best-range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                    class DiversePath(Entity):
                                        """
                                        Advertise diverse path
                                        
                                        .. attribute:: backup
                                        
                                        	Diverse path can be backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.DiversePath.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: mpath
                                        
                                        	Diverse path can be multipath
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.DiversePath, self).__init__()

                                            self.yang_name = "diverse-path"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.DiversePath.Backup))])
                                            self._leafs = OrderedDict([
                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                            ])
                                            self.mpath = None

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"
                                            self._segment_path = lambda: "diverse-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                        class Backup(Entity):
                                            """
                                            Diverse path can be backup path
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "diverse-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                class AdvertiseMap(Entity):
                                    """
                                    specify route\-map for conditional advertisement
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdvertiseMap.Name>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdvertiseMap, self).__init__()

                                        self.yang_name = "advertise-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdvertiseMap.Name))])
                                        self._leafs = OrderedDict()

                                        self.name = YList(self)
                                        self._segment_path = lambda: "advertise-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdvertiseMap, [], name, value)


                                    class Name(Entity):
                                        """
                                        
                                        
                                        .. attribute:: word  (key)
                                        
                                        	advertise route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: exist_map
                                        
                                        	condition route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: non_exist_map
                                        
                                        	condition route\-map name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdvertiseMap.Name, self).__init__()

                                            self.yang_name = "name"
                                            self.yang_parent_name = "advertise-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                            ])
                                            self.word = None
                                            self.exist_map = None
                                            self.non_exist_map = None
                                            self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                class Aigp(Entity):
                                    """
                                    Enable a AIGP on neighbor
                                    
                                    .. attribute:: send
                                    
                                    	Cost community or MED carrying AIGP VALUE
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp, self).__init__()

                                        self.yang_name = "aigp"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.send = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send()
                                        self.send.parent = self
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "aigp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp, [], name, value)


                                    class Send(Entity):
                                        """
                                        Cost community or MED carrying AIGP VALUE
                                        
                                        .. attribute:: cost_community
                                        
                                        	Cost extended community carrying AIGP Value
                                        	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity>`
                                        
                                        .. attribute:: med
                                        
                                        	Med carrying AIGP Value
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "aigp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity))])
                                            self._leafs = OrderedDict([
                                                ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                            ])
                                            self.med = None

                                            self.cost_community = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity()
                                            self.cost_community.parent = self
                                            self._children_name_map["cost_community"] = "cost-community"
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send, ['med'], name, value)


                                        class CostCommunity(Entity):
                                            """
                                            Cost extended community carrying AIGP Value
                                            
                                            .. attribute:: cc_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                self.yang_name = "cost-community"
                                                self.yang_parent_name = "send"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                self._leafs = OrderedDict()

                                                self.cc_range = YList(self)
                                                self._segment_path = lambda: "cost-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                            class CcRange(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Community ID
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: poi
                                                
                                                	Point of insertion
                                                	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                    self.yang_name = "cc-range"
                                                    self.yang_parent_name = "cost-community"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                    ])
                                                    self.range = None

                                                    self.poi = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                    self.poi.parent = self
                                                    self._children_name_map["poi"] = "poi"
                                                    self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                class Poi(Entity):
                                                    """
                                                    Point of insertion
                                                    
                                                    .. attribute:: igp_cost
                                                    
                                                    	Point of insertion after IGP
                                                    	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: pre_bestpath
                                                    
                                                    	Point of insertion at beginning
                                                    	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                        self.yang_name = "poi"
                                                        self.yang_parent_name = "cc-range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                        self._leafs = OrderedDict()

                                                        self.igp_cost = None
                                                        self._children_name_map["igp_cost"] = "igp-cost"

                                                        self.pre_bestpath = None
                                                        self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                        self._segment_path = lambda: "poi"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                    class IgpCost(Entity):
                                                        """
                                                        Point of insertion after IGP
                                                        
                                                        .. attribute:: transitive
                                                        
                                                        	Cost community is transitive
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                            self.yang_name = "igp-cost"
                                                            self.yang_parent_name = "poi"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                            ])
                                                            self.transitive = None
                                                            self._segment_path = lambda: "igp-cost"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                    class PreBestpath(Entity):
                                                        """
                                                        Point of insertion at beginning
                                                        
                                                        .. attribute:: transitive
                                                        
                                                        	Cost community is transitive
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                            self.yang_name = "pre-bestpath"
                                                            self.yang_parent_name = "poi"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                            ])
                                                            self.transitive = None
                                                            self._segment_path = lambda: "pre-bestpath"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Capability(Entity):
                                    """
                                    Advertise capability to the peer
                                    
                                    .. attribute:: orf
                                    
                                    	Advertise ORF capability to the peer
                                    	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability.Orf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability, self).__init__()

                                        self.yang_name = "capability"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability.Orf))])
                                        self._leafs = OrderedDict()

                                        self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability.Orf()
                                        self.orf.parent = self
                                        self._children_name_map["orf"] = "orf"
                                        self._segment_path = lambda: "capability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability, [], name, value)


                                    class Orf(Entity):
                                        """
                                        Advertise ORF capability to the peer
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Advertise prefix list ORF capability to this neighbor
                                        	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability.Orf.PrefixList>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability.Orf, self).__init__()

                                            self.yang_name = "orf"
                                            self.yang_parent_name = "capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability.Orf.PrefixList')])),
                                            ])
                                            self.prefix_list = []
                                            self._segment_path = lambda: "orf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                        class PrefixList(Enum):
                                            """
                                            PrefixList (Enum Class)

                                            Advertise prefix list ORF capability to this neighbor

                                            .. data:: both = 0

                                            .. data:: receive = 1

                                            .. data:: send = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            receive = Enum.YLeaf(1, "receive")

                                            send = Enum.YLeaf(2, "send")



                                class DefaultOriginate(Entity):
                                    """
                                    Originate default route to this neighbor
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria to originate default
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.DefaultOriginate, self).__init__()

                                        self.yang_name = "default-originate"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "default-originate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.DistributeList.Inout>`
                                    
                                    .. attribute:: accesslist
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..199
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..2699
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.DistributeList.Inout')])),
                                            ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                        ])
                                        self.inout = None
                                        self.accesslist = None
                                        self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.NextHopSelf, ['all'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Network(Entity):
                                """
                                Specify a network to announce via BGP
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: route_map
                                
                                	Route\-map to modify the attributes
                                	**type**\: str
                                
                                .. attribute:: backdoor
                                
                                	Specify a BGP backdoor route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Network, self).__init__()

                                    self.yang_name = "network"
                                    self.yang_parent_name = "ipv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.route_map = None
                                    self.backdoor = None
                                    self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Network, ['number', 'route_map', 'backdoor'], name, value)


                            class Redistribute(Entity):
                                """
                                Redistribute information from another routing protocol
                                
                                .. attribute:: application
                                
                                	Application
                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Application>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Bgp_>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Connected>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dvmrp
                                
                                	Redistribution of DVMRP into BGP IPv4 Multicast
                                	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Dvmrp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol
                                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Lisp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: iso_igrp
                                
                                	IGRP for OSI networks
                                	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp>`
                                
                                .. attribute:: mobile
                                
                                	Mobile routes
                                	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Mobile>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: odr
                                
                                	On Demand stub Routes
                                	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Odr>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Rip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute, self).__init__()

                                    self.yang_name = "redistribute"
                                    self.yang_parent_name = "ipv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static))])
                                    self._leafs = OrderedDict()

                                    self.application = None
                                    self._children_name_map["application"] = "application"

                                    self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.connected = None
                                    self._children_name_map["connected"] = "connected"

                                    self.dvmrp = None
                                    self._children_name_map["dvmrp"] = "dvmrp"

                                    self.eigrp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Eigrp()
                                    self.eigrp.parent = self
                                    self._children_name_map["eigrp"] = "eigrp"

                                    self.isis = None
                                    self._children_name_map["isis"] = "isis"

                                    self.lisp = None
                                    self._children_name_map["lisp"] = "lisp"

                                    self.iso_igrp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp()
                                    self.iso_igrp.parent = self
                                    self._children_name_map["iso_igrp"] = "iso-igrp"

                                    self.mobile = None
                                    self._children_name_map["mobile"] = "mobile"

                                    self.odr = None
                                    self._children_name_map["odr"] = "odr"

                                    self.rip = None
                                    self._children_name_map["rip"] = "rip"

                                    self.static = None
                                    self._children_name_map["static"] = "static"

                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "redistribute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute, [], name, value)


                                class Application(Entity):
                                    """
                                    Application
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Application.Name>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Application, self).__init__()

                                        self.yang_name = "application"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Application.Name))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.name = YList(self)
                                        self._segment_path = lambda: "application"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Application, [], name, value)


                                    class Name(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	WORD \:\: Route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Application.Name, self).__init__()

                                            self.yang_name = "name"
                                            self.yang_parent_name = "application"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                class Bgp_(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: as_no
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_no = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                class Dvmrp(Entity):
                                    """
                                    Redistribution of DVMRP into BGP IPv4 Multicast
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Dvmrp, self).__init__()

                                        self.yang_name = "dvmrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.route_map = None
                                        self.metric = None
                                        self._segment_path = lambda: "dvmrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: as_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_no = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "eigrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: isis_area
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.IsisArea>`
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.Default>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.Default))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.Default()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.isis_area = YList(self)
                                        self._segment_path = lambda: "isis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis, [], name, value)


                                    class IsisArea(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: routes
                                        
                                        	
                                        	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.IsisArea.Routes>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.IsisArea, self).__init__()

                                            self.yang_name = "isis-area"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.IsisArea.Routes')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.ip = None
                                            self.clns = None
                                            self.routes = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                        class Routes(Enum):
                                            """
                                            Routes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class Default(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: routes
                                        
                                        	
                                        	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.Default.Routes>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.Default, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.Default.Routes')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.ip = None
                                            self.clns = None
                                            self.routes = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                        class Routes(Enum):
                                            """
                                            Routes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class Lisp(Entity):
                                    """
                                    Locator/ID Separation Protocol
                                    
                                    .. attribute:: include_connected
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Lisp, self).__init__()

                                        self.yang_name = "lisp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.include_connected = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "lisp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                class IsoIgrp(Entity):
                                    """
                                    IGRP for OSI networks
                                    
                                    .. attribute:: iso_igrp_area
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp.Default>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp, self).__init__()

                                        self.yang_name = "iso-igrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp.Default))])
                                        self._leafs = OrderedDict()

                                        self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp.Default()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.iso_igrp_area = YList(self)
                                        self._segment_path = lambda: "iso-igrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp, [], name, value)


                                    class IsoIgrpArea(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                            self.yang_name = "iso-igrp-area"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.name = None
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                    class Default(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp.Default, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                class Mobile(Entity):
                                    """
                                    Mobile routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Mobile, self).__init__()

                                        self.yang_name = "mobile"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "mobile"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                class Odr(Entity):
                                    """
                                    On Demand stub Routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Odr, self).__init__()

                                        self.yang_name = "odr"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "odr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: vrf
                                    
                                    	VPN Routing/Forwarding Instance
                                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.Vrf>`
                                    
                                    .. attribute:: non_vrf
                                    
                                    	
                                    	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.NonVrf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.Vrf)), ("non-vrf", ("non_vrf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.NonVrf))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.non_vrf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.NonVrf()
                                        self.non_vrf.parent = self
                                        self._children_name_map["non_vrf"] = "non-vrf"

                                        self.vrf = YList(self)
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf, ['id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VPN Routing/Forwarding Instance
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.Vrf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.Vrf.Match))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.Vrf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.Vrf, ['name', 'metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.Vrf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict()
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True


                                    class NonVrf(Entity):
                                        """
                                        
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.NonVrf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.NonVrf, self).__init__()

                                            self.yang_name = "non-vrf"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.NonVrf.Match))])
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.NonVrf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "non-vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: external2
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "non-vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                    ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.internal = None
                                                self.external = None
                                                self.external2 = None
                                                self.nssa_external = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: match
                                    
                                    	
                                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospfv3.Match>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospfv3.Match))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.id = None
                                        self.metric = None
                                        self.route_map = None

                                        self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospfv3.Match()
                                        self.match.parent = self
                                        self._children_name_map["match"] = "match"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                    class Match(Entity):
                                        """
                                        
                                        
                                        .. attribute:: internal
                                        
                                        	Redistribute OSPF internal routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: external
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: external2
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: nssa_external
                                        
                                        	Redistribute OSPF NSSA external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospfv3.Match, self).__init__()

                                            self.yang_name = "match"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.internal = None
                                            self.external = None
                                            self.external2 = None
                                            self.nssa_external = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "match"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: name
                                    
                                    	User selected string identifying this process
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self.name = None
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: clns
                                    
                                    	Redistribution of OSI dynamic routes
                                    	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static.Clns>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ip
                                    
                                    	
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static.Ip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static.Ip))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None

                                        self.clns = None
                                        self._children_name_map["clns"] = "clns"

                                        self.ip = None
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                    class Clns(Entity):
                                        """
                                        Redistribution of OSI dynamic routes
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static.Clns, self).__init__()

                                            self.yang_name = "clns"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "clns"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                    class Ip(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "ipv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Multicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                        class Ipv6Flowspec(Entity):
                            """
                            IPv6 Flowspec address family
                            
                            .. attribute:: aggregate_address
                            
                            	Configure BGP aggregate entries
                            	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.AggregateAddress>`
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.DefaultInformation>`
                            
                            .. attribute:: default_metric
                            
                            	Set metric of redistributed routes
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: distance
                            
                            	Define an administrative distance
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor>`
                            
                            .. attribute:: network
                            
                            	Specify a network to announce via BGP
                            	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Network>`
                            
                            .. attribute:: redistribute
                            
                            	Redistribute information from another routing protocol
                            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec, self).__init__()

                                self.yang_name = "ipv6-flowspec"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp))])
                                self._leafs = OrderedDict([
                                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                ])
                                self.default_metric = None

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.default_information = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.distance = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.redistribute = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute()
                                self.redistribute.parent = self
                                self._children_name_map["redistribute"] = "redistribute"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.aggregate_address = YList(self)
                                self.neighbor = YList(self)
                                self.network = YList(self)
                                self._segment_path = lambda: "ipv6-flowspec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec, ['default_metric'], name, value)


                            class AggregateAddress(Entity):
                                """
                                Configure BGP aggregate entries
                                
                                .. attribute:: ipv6_address  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: advertise_map
                                
                                	Set condition to advertise attribute
                                	**type**\: str
                                
                                .. attribute:: as_set
                                
                                	Generate AS set path information
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: attribute_map
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: as_override
                                
                                	Override matching AS\-number while sending update
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: summary_only
                                
                                	Filter more specific routes from updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: suppress_map
                                
                                	Conditionally filter more specific routes from updates
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.AggregateAddress, self).__init__()

                                    self.yang_name = "aggregate-address"
                                    self.yang_parent_name = "ipv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv6_address']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                        ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                        ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                        ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                    ])
                                    self.ipv6_address = None
                                    self.advertise_map = None
                                    self.as_set = None
                                    self.attribute_map = None
                                    self.as_override = None
                                    self.route_map = None
                                    self.summary_only = None
                                    self.suppress_map = None
                                    self._segment_path = lambda: "aggregate-address" + "[ipv6-address='" + str(self.ipv6_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.AggregateAddress, ['ipv6_address', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.Nexthop>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "ipv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.Nexthop)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                    ])
                                    self.scan_time = None

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_, ['scan_time'], name, value)


                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "ipv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                    ])
                                    self.originate = None
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.DefaultInformation, ['originate'], name, value)


                            class Distance(Entity):
                                """
                                Define an administrative distance
                                
                                .. attribute:: bgp
                                
                                	BGP distance
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance.Bgp_>`
                                
                                .. attribute:: adm_distance
                                
                                	
                                	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance.AdmDistance>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "ipv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance.AdmDistance))])
                                    self._leafs = OrderedDict()

                                    self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.adm_distance = YList(self)
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance, [], name, value)


                                class Bgp_(Entity):
                                    """
                                    BGP distance
                                    
                                    .. attribute:: extern_as
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: internal_as
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: local
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                            ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                            ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                        ])
                                        self.extern_as = None
                                        self.internal_as = None
                                        self.local = None
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                class AdmDistance(Entity):
                                    """
                                    
                                    
                                    .. attribute:: distance  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: srcip  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: wildbits  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: acl
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..99
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..1999
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance.AdmDistance, self).__init__()

                                        self.yang_name = "adm-distance"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['distance','srcip','wildbits']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                            ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                            ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                        ])
                                        self.distance = None
                                        self.srcip = None
                                        self.wildbits = None
                                        self.acl = None
                                        self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "ipv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.AllowasIn)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "ipv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.AllowasIn)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SoftReconfiguration')])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor, ['id', 'activate', 'advertisement_interval', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.NextHopSelf, ['all'], name, value)


                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Network(Entity):
                                """
                                Specify a network to announce via BGP
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: route_map
                                
                                	Route\-map to modify the attributes
                                	**type**\: str
                                
                                .. attribute:: backdoor
                                
                                	Specify a BGP backdoor route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Network, self).__init__()

                                    self.yang_name = "network"
                                    self.yang_parent_name = "ipv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                    ])
                                    self.number = None
                                    self.route_map = None
                                    self.backdoor = None
                                    self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Network, ['number', 'route_map', 'backdoor'], name, value)


                            class Redistribute(Entity):
                                """
                                Redistribute information from another routing protocol
                                
                                .. attribute:: application
                                
                                	Application
                                	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Application>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bgp
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Bgp_>`
                                
                                .. attribute:: connected
                                
                                	Connected
                                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Connected>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dvmrp
                                
                                	Redistribution of DVMRP into BGP IPv4 Multicast
                                	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Dvmrp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Eigrp>`
                                
                                .. attribute:: isis
                                
                                	ISO IS\-IS
                                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol
                                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Lisp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: iso_igrp
                                
                                	IGRP for OSI networks
                                	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp>`
                                
                                .. attribute:: mobile
                                
                                	Mobile routes
                                	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Mobile>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: odr
                                
                                	On Demand stub Routes
                                	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Odr>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPF)
                                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf>`
                                
                                .. attribute:: ospfv3
                                
                                	OSPFv3
                                	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospfv3>`
                                
                                .. attribute:: rip
                                
                                	Routing Information Protocol (RIP)
                                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Rip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: static
                                
                                	Static routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute, self).__init__()

                                    self.yang_name = "redistribute"
                                    self.yang_parent_name = "ipv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static))])
                                    self._leafs = OrderedDict()

                                    self.application = None
                                    self._children_name_map["application"] = "application"

                                    self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Bgp_()
                                    self.bgp.parent = self
                                    self._children_name_map["bgp"] = "bgp"

                                    self.connected = None
                                    self._children_name_map["connected"] = "connected"

                                    self.dvmrp = None
                                    self._children_name_map["dvmrp"] = "dvmrp"

                                    self.eigrp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Eigrp()
                                    self.eigrp.parent = self
                                    self._children_name_map["eigrp"] = "eigrp"

                                    self.isis = None
                                    self._children_name_map["isis"] = "isis"

                                    self.lisp = None
                                    self._children_name_map["lisp"] = "lisp"

                                    self.iso_igrp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp()
                                    self.iso_igrp.parent = self
                                    self._children_name_map["iso_igrp"] = "iso-igrp"

                                    self.mobile = None
                                    self._children_name_map["mobile"] = "mobile"

                                    self.odr = None
                                    self._children_name_map["odr"] = "odr"

                                    self.rip = None
                                    self._children_name_map["rip"] = "rip"

                                    self.static = None
                                    self._children_name_map["static"] = "static"

                                    self.ospf = YList(self)
                                    self.ospfv3 = YList(self)
                                    self._segment_path = lambda: "redistribute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute, [], name, value)


                                class Application(Entity):
                                    """
                                    Application
                                    
                                    .. attribute:: name
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Application.Name>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Application, self).__init__()

                                        self.yang_name = "application"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Application.Name))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.name = YList(self)
                                        self._segment_path = lambda: "application"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Application, [], name, value)


                                    class Name(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	WORD \:\: Route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Application.Name, self).__init__()

                                            self.yang_name = "name"
                                            self.yang_parent_name = "application"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                class Bgp_(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: as_no
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..4294967295
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Bgp_, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_no = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "bgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                class Connected(Entity):
                                    """
                                    Connected
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Connected, self).__init__()

                                        self.yang_name = "connected"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "connected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                class Dvmrp(Entity):
                                    """
                                    Redistribution of DVMRP into BGP IPv4 Multicast
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Dvmrp, self).__init__()

                                        self.yang_name = "dvmrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ])
                                        self.route_map = None
                                        self.metric = None
                                        self._segment_path = lambda: "dvmrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                class Eigrp(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: as_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.as_no = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "eigrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                class Isis(Entity):
                                    """
                                    ISO IS\-IS
                                    
                                    .. attribute:: isis_area
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.IsisArea>`
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.Default>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis, self).__init__()

                                        self.yang_name = "isis"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.Default))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.Default()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.isis_area = YList(self)
                                        self._segment_path = lambda: "isis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis, [], name, value)


                                    class IsisArea(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: routes
                                        
                                        	
                                        	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.IsisArea.Routes>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.IsisArea, self).__init__()

                                            self.yang_name = "isis-area"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.IsisArea.Routes')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.ip = None
                                            self.clns = None
                                            self.routes = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                        class Routes(Enum):
                                            """
                                            Routes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class Default(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ip
                                        
                                        	Redistribution of IP dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: clns
                                        
                                        	Redistribution of OSI dynamic routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: routes
                                        
                                        	
                                        	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.Default.Routes>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.Default, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "isis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.Default.Routes')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.ip = None
                                            self.clns = None
                                            self.routes = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                        class Routes(Enum):
                                            """
                                            Routes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class Lisp(Entity):
                                    """
                                    Locator/ID Separation Protocol
                                    
                                    .. attribute:: include_connected
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Lisp, self).__init__()

                                        self.yang_name = "lisp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.include_connected = None
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "lisp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                class IsoIgrp(Entity):
                                    """
                                    IGRP for OSI networks
                                    
                                    .. attribute:: iso_igrp_area
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp.IsoIgrpArea>`
                                    
                                    .. attribute:: default
                                    
                                    	
                                    	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp.Default>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp, self).__init__()

                                        self.yang_name = "iso-igrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp.Default))])
                                        self._leafs = OrderedDict()

                                        self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp.Default()
                                        self.default.parent = self
                                        self._children_name_map["default"] = "default"

                                        self.iso_igrp_area = YList(self)
                                        self._segment_path = lambda: "iso-igrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp, [], name, value)


                                    class IsoIgrpArea(Entity):
                                        """
                                        
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                            self.yang_name = "iso-igrp-area"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.name = None
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                    class Default(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp.Default, self).__init__()

                                            self.yang_name = "default"
                                            self.yang_parent_name = "iso-igrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "default"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                class Mobile(Entity):
                                    """
                                    Mobile routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Mobile, self).__init__()

                                        self.yang_name = "mobile"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "mobile"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                class Odr(Entity):
                                    """
                                    On Demand stub Routes
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Odr, self).__init__()

                                        self.yang_name = "odr"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self._segment_path = lambda: "odr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPF)
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: vrf
                                    
                                    	VPN Routing/Forwarding Instance
                                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.Vrf>`
                                    
                                    .. attribute:: non_vrf
                                    
                                    	
                                    	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.NonVrf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.Vrf)), ("non-vrf", ("non_vrf", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.NonVrf))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                        ])
                                        self.id = None

                                        self.non_vrf = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.NonVrf()
                                        self.non_vrf.parent = self
                                        self._children_name_map["non_vrf"] = "non-vrf"

                                        self.vrf = YList(self)
                                        self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf, ['id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VPN Routing/Forwarding Instance
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.Vrf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.Vrf.Match))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.name = None
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.Vrf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.Vrf, ['name', 'metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.Vrf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict()
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True


                                    class NonVrf(Entity):
                                        """
                                        
                                        
                                        .. attribute:: match
                                        
                                        	
                                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.NonVrf.Match>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.NonVrf, self).__init__()

                                            self.yang_name = "non-vrf"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.NonVrf.Match))])
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None

                                            self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.NonVrf.Match()
                                            self.match.parent = self
                                            self._children_name_map["match"] = "match"
                                            self._segment_path = lambda: "non-vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                        class Match(Entity):
                                            """
                                            
                                            
                                            .. attribute:: internal
                                            
                                            	Redistribute OSPF internal routes
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: external
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: external2
                                            
                                            	Redistribute OSPF external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: nssa_external
                                            
                                            	Redistribute OSPF NSSA external routes
                                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                self.yang_name = "match"
                                                self.yang_parent_name = "non-vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                    ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.internal = None
                                                self.external = None
                                                self.external2 = None
                                                self.nssa_external = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "match"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                class Ospfv3(Entity):
                                    """
                                    OSPFv3
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: match
                                    
                                    	
                                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospfv3.Match>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospfv3, self).__init__()

                                        self.yang_name = "ospfv3"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospfv3.Match))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.id = None
                                        self.metric = None
                                        self.route_map = None

                                        self.match = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospfv3.Match()
                                        self.match.parent = self
                                        self._children_name_map["match"] = "match"
                                        self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                    class Match(Entity):
                                        """
                                        
                                        
                                        .. attribute:: internal
                                        
                                        	Redistribute OSPF internal routes
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: external
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: external2
                                        
                                        	Redistribute OSPF external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: nssa_external
                                        
                                        	Redistribute OSPF NSSA external routes
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospfv3.Match, self).__init__()

                                            self.yang_name = "match"
                                            self.yang_parent_name = "ospfv3"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.internal = None
                                            self.external = None
                                            self.external2 = None
                                            self.nssa_external = None
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "match"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                class Rip(Entity):
                                    """
                                    Routing Information Protocol (RIP)
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: name
                                    
                                    	User selected string identifying this process
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Rip, self).__init__()

                                        self.yang_name = "rip"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None
                                        self.name = None
                                        self._segment_path = lambda: "rip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                class Static(Entity):
                                    """
                                    Static routes
                                    
                                    .. attribute:: clns
                                    
                                    	Redistribution of OSI dynamic routes
                                    	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static.Clns>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: ip
                                    
                                    	
                                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static.Ip>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static.Ip))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.metric = None
                                        self.route_map = None

                                        self.clns = None
                                        self._children_name_map["clns"] = "clns"

                                        self.ip = None
                                        self._children_name_map["ip"] = "ip"
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static, ['metric', 'route_map'], name, value)


                                    class Clns(Entity):
                                        """
                                        Redistribution of OSI dynamic routes
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static.Clns, self).__init__()

                                            self.yang_name = "clns"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ])
                                            self.route_map = None
                                            self.metric = None
                                            self._segment_path = lambda: "clns"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                    class Ip(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static.Ip, self).__init__()

                                            self.yang_name = "ip"
                                            self.yang_parent_name = "static"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.metric = None
                                            self.route_map = None
                                            self._segment_path = lambda: "ip"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "ipv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Flowspec.Snmp.Context.ContextWord, ['context_word'], name, value)


                        class Ipv6Mvpn(Entity):
                            """
                            IPv6 MVPN address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.DefaultInformation>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn, self).__init__()

                                self.yang_name = "ipv6-mvpn"
                                self.yang_parent_name = "ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.DefaultInformation)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.default_information = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "ipv6-mvpn"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn, [], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	Configure BGP defaults
                                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Default>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Nexthop>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "ipv6-mvpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Nexthop)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                    ])
                                    self.dmzlink_bw = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None

                                    self.default = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Default()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_, ['dmzlink_bw', 'scan_time', 'soft_reconfig_backup'], name, value)


                                class Default(Entity):
                                    """
                                    Configure BGP defaults
                                    
                                    .. attribute:: route_target
                                    
                                    	Control behavior based on Route\-Target attributes
                                    	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Default.RouteTarget>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Default, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Default.RouteTarget')])),
                                        ])
                                        self.route_target = None
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Default, ['route_target'], name, value)

                                    class RouteTarget(Enum):
                                        """
                                        RouteTarget (Enum Class)

                                        Control behavior based on Route\-Target attributes

                                        .. data:: filter = 0

                                        """

                                        filter = Enum.YLeaf(0, "filter")



                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "ipv6-mvpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                    ])
                                    self.originate = None
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.DefaultInformation, ['originate'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "ipv6-mvpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.AllowasIn)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "ipv6-mvpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.AllowasIn)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.AllowasIn, ['as_number'], name, value)


                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.NextHopSelf, ['all'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "ipv6-mvpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Ipv6.Ipv6Mvpn.Snmp.Context.ContextWord, ['context_word'], name, value)


                    class Vpnv4(Entity):
                        """
                        Address family
                        
                        .. attribute:: af_name  (key)
                        
                        	
                        	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.AfName>`
                        
                        .. attribute:: vpnv4_unicast
                        
                        	VPNv4 Unicast address family
                        	**type**\:  :py:class:`Vpnv4Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast>`
                        
                        .. attribute:: vpnv4_multicast
                        
                        	VPNv4 Multiicast address family
                        	**type**\:  :py:class:`Vpnv4Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast>`
                        
                        .. attribute:: vpnv4_flowspec
                        
                        	VPNv4 Flowspec address family
                        	**type**\:  :py:class:`Vpnv4Flowspec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4, self).__init__()

                            self.yang_name = "vpnv4"
                            self.yang_parent_name = "no-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("vpnv4-unicast", ("vpnv4_unicast", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast)), ("vpnv4-multicast", ("vpnv4_multicast", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast)), ("vpnv4-flowspec", ("vpnv4_flowspec", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.AfName')])),
                            ])
                            self.af_name = None

                            self.vpnv4_unicast = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast()
                            self.vpnv4_unicast.parent = self
                            self._children_name_map["vpnv4_unicast"] = "vpnv4-unicast"

                            self.vpnv4_multicast = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast()
                            self.vpnv4_multicast.parent = self
                            self._children_name_map["vpnv4_multicast"] = "vpnv4-multicast"

                            self.vpnv4_flowspec = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec()
                            self.vpnv4_flowspec.parent = self
                            self._children_name_map["vpnv4_flowspec"] = "vpnv4-flowspec"
                            self._segment_path = lambda: "vpnv4" + "[af-name='" + str(self.af_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4, ['af_name'], name, value)

                        class AfName(Enum):
                            """
                            AfName (Enum Class)

                            .. data:: unicast = 0

                            .. data:: multicast = 1

                            .. data:: flowspec = 2

                            """

                            unicast = Enum.YLeaf(0, "unicast")

                            multicast = Enum.YLeaf(1, "multicast")

                            flowspec = Enum.YLeaf(2, "flowspec")



                        class Vpnv4Unicast(Entity):
                            """
                            VPNv4 Unicast address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_>`
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor>`
                            
                            .. attribute:: network
                            
                            	
                            	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast, self).__init__()

                                self.yang_name = "vpnv4-unicast"
                                self.yang_parent_name = "vpnv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.maximum_paths = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths()
                                self.maximum_paths.parent = self
                                self._children_name_map["maximum_paths"] = "maximum-paths"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.network = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network()
                                self.network.parent = self
                                self._children_name_map["network"] = "network"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "vpnv4-unicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast, [], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: additional_paths
                                
                                	Additional paths in the BGP table
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths>`
                                
                                .. attribute:: advertise_best_external
                                
                                	Advertise best external path to internal peers
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: aggregate_timer
                                
                                	Configure aggregation timer
                                	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer>`
                                
                                .. attribute:: bestpath
                                
                                	Change the default bestpath selection
                                	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath>`
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: default
                                
                                	Configure BGP defaults
                                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop>`
                                
                                .. attribute:: recursion
                                
                                	recursion rule for the nexthops
                                	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion>`
                                
                                .. attribute:: redistribute_internal
                                
                                	Allow redistribution of iBGP into IGPs (dangerous)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: update_group
                                
                                	Manage peers in bgp update groups
                                	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "vpnv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup))])
                                    self._leafs = OrderedDict([
                                        ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                    ])
                                    self.advertise_best_external = None
                                    self.dmzlink_bw = None
                                    self.redistribute_internal = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.aggregate_timer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer()
                                    self.aggregate_timer.parent = self
                                    self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                    self.bestpath = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath()
                                    self.bestpath.parent = self
                                    self._children_name_map["bestpath"] = "bestpath"

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"

                                    self.default = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.recursion = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion()
                                    self.recursion.parent = self
                                    self._children_name_map["recursion"] = "recursion"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup()
                                    self.update_group.parent = self
                                    self._children_name_map["update_group"] = "update-group"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                class AdditionalPaths(Entity):
                                    """
                                    Additional paths in the BGP table
                                    
                                    .. attribute:: install
                                    
                                    	Additional paths to install into RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: select
                                    
                                    	Selection criteria to pick the paths
                                    	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to neighbors
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.install = None
                                        self.receive = None

                                        self.select = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select()
                                        self.select.parent = self
                                        self._children_name_map["select"] = "select"

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                    class Select(Entity):
                                        """
                                        Selection criteria to pick the paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: backup
                                        
                                        	Select backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Select best\-external path
                                        	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best path
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                            self.yang_name = "select"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.best_external = None
                                            self._children_name_map["best_external"] = "best-external"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "select"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best path
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best path
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                        class Backup(Entity):
                                            """
                                            Select backup path
                                            
                                            .. attribute:: best_external
                                            
                                            	Select best\-external path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                self._leafs = OrderedDict()

                                                self.range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                        class BestExternal(Entity):
                                            """
                                            Select best\-external path
                                            
                                            .. attribute:: backup
                                            
                                            	Select backup path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                self.yang_name = "best-external"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                ])
                                                self.backup = None
                                                self._segment_path = lambda: "best-external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best path
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to neighbors
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                class AggregateTimer(Entity):
                                    """
                                    Configure aggregation timer
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Timer interval
                                    	**type**\: int
                                    
                                    	**range:** 6..60
                                    
                                    .. attribute:: disable_timer
                                    
                                    	Timer interval
                                    	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer, self).__init__()

                                        self.yang_name = "aggregate-timer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                            ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                        ])
                                        self.aggregate_timer = None
                                        self.disable_timer = None
                                        self._segment_path = lambda: "aggregate-timer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                    class DisableTimer(Enum):
                                        """
                                        DisableTimer (Enum Class)

                                        Timer interval

                                        .. data:: Y_0 = 0

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")



                                class Bestpath(Entity):
                                    """
                                    Change the default bestpath selection
                                    
                                    .. attribute:: igp_metric
                                    
                                    	igp metric
                                    	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric>`
                                    
                                    .. attribute:: prefix_validate
                                    
                                    	Prefix origin validation
                                    	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath, self).__init__()

                                        self.yang_name = "bestpath"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate))])
                                        self._leafs = OrderedDict()

                                        self.igp_metric = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric()
                                        self.igp_metric.parent = self
                                        self._children_name_map["igp_metric"] = "igp-metric"

                                        self.prefix_validate = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate()
                                        self.prefix_validate.parent = self
                                        self._children_name_map["prefix_validate"] = "prefix-validate"
                                        self._segment_path = lambda: "bestpath"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath, [], name, value)


                                    class IgpMetric(Entity):
                                        """
                                        igp metric
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore igp metric in bestpath selection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                            self.yang_name = "igp-metric"
                                            self.yang_parent_name = "bestpath"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ])
                                            self.ignore = None
                                            self._segment_path = lambda: "igp-metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                    class PrefixValidate(Entity):
                                        """
                                        Prefix origin validation
                                        
                                        .. attribute:: allow_invalid
                                        
                                        	Allow invalid routes to be considered for bestpath
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: disable
                                        
                                        	Disable prefix validation
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                            self.yang_name = "prefix-validate"
                                            self.yang_parent_name = "bestpath"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.allow_invalid = None
                                            self.disable = None
                                            self._segment_path = lambda: "prefix-validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria for dampening
                                    	**type**\: str
                                    
                                    .. attribute:: dampen
                                    
                                    	
                                    	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.dampen = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen()
                                        self.dampen.parent = self
                                        self._children_name_map["dampen"] = "dampen"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                    class Dampen(Entity):
                                        """
                                        
                                        
                                        .. attribute:: half_life_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..45
                                        
                                        .. attribute:: reuse_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: max_suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                            self.yang_name = "dampen"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                            ])
                                            self.half_life_time = None
                                            self.reuse_time = None
                                            self.suppress_time = None
                                            self.max_suppress_time = None
                                            self._segment_path = lambda: "dampen"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                class Default(Entity):
                                    """
                                    Configure BGP defaults
                                    
                                    .. attribute:: route_target
                                    
                                    	Control behavior based on Route\-Target attributes
                                    	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default.RouteTarget>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default.RouteTarget')])),
                                        ])
                                        self.route_target = None
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default, ['route_target'], name, value)

                                    class RouteTarget(Enum):
                                        """
                                        RouteTarget (Enum Class)

                                        Control behavior based on Route\-Target attributes

                                        .. data:: filter = 0

                                        """

                                        filter = Enum.YLeaf(0, "filter")



                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class Recursion(Entity):
                                    """
                                    recursion rule for the nexthops
                                    
                                    .. attribute:: host
                                    
                                    	recursion via host for the nexthops
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion, self).__init__()

                                        self.yang_name = "recursion"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                        ])
                                        self.host = None
                                        self._segment_path = lambda: "recursion"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion, ['host'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    Manage peers in bgp update groups
                                    
                                    .. attribute:: split
                                    
                                    	Split update groups based on Policy
                                    	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split))])
                                        self._leafs = OrderedDict()

                                        self.split = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split()
                                        self.split.parent = self
                                        self._children_name_map["split"] = "split"
                                        self._segment_path = lambda: "update-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup, [], name, value)


                                    class Split(Entity):
                                        """
                                        Split update groups based on Policy
                                        
                                        .. attribute:: as_override
                                        
                                        	Keep peers with as\-override in different update groups
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                            self.yang_name = "split"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ])
                                            self.as_override = None
                                            self._segment_path = lambda: "split"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                            class MaximumPaths(Entity):
                                """
                                Forward packets over multiple paths
                                
                                .. attribute:: ebgp
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: eibgp
                                
                                	Both eBGP and iBGP paths as multipath
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: ibgp
                                
                                	iBGP\-multipath
                                	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp>`
                                
                                .. attribute:: external_rtfilter
                                
                                	VPN prefix multipath on external RT\-Filter peers
                                	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths, self).__init__()

                                    self.yang_name = "maximum-paths"
                                    self.yang_parent_name = "vpnv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter))])
                                    self._leafs = OrderedDict([
                                        ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                        ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                    ])
                                    self.ebgp = None
                                    self.eibgp = None

                                    self.ibgp = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"

                                    self.external_rtfilter = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter()
                                    self.external_rtfilter.parent = self
                                    self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                    self._segment_path = lambda: "maximum-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                class Ibgp(Entity):
                                    """
                                    iBGP\-multipath
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Perform un\-equal cost multipath selection
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.unequal_cost = None
                                        self.max = None
                                        self._segment_path = lambda: "ibgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                class ExternalRtfilter(Entity):
                                    """
                                    VPN prefix multipath on external RT\-Filter peers
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                        self.yang_name = "external-rtfilter"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.max = None
                                        self._segment_path = lambda: "external-rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "vpnv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise to this neighbor
                                    	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: send_label
                                    
                                    	Send NLRI + MPLS Label to this peer
                                    	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise()
                                        self.advertise.parent = self
                                        self._children_name_map["advertise"] = "advertise"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.send_label = None
                                        self._children_name_map["send_label"] = "send-label"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.distribute_list = YList(self)
                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class Advertise(Entity):
                                        """
                                        Advertise to this neighbor
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Advertise additional paths
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Advertise best\-external (at RRs best\-internal) path
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: diverse_path
                                        
                                        	Advertise diverse path
                                        	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                            self.yang_name = "advertise"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                            self._leafs = OrderedDict([
                                                ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                            ])
                                            self.best_external = None

                                            self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                            self.diverse_path.parent = self
                                            self._children_name_map["diverse_path"] = "diverse-path"
                                            self._segment_path = lambda: "advertise"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Advertise additional paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                            class All(Entity):
                                                """
                                                Select all available paths
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.group_best = None
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.all = None

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "best-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.all = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.all = None
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                        class DiversePath(Entity):
                                            """
                                            Advertise diverse path
                                            
                                            .. attribute:: backup
                                            
                                            	Diverse path can be backup path
                                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                self.yang_name = "diverse-path"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None

                                                self.backup = None
                                                self._children_name_map["backup"] = "backup"
                                                self._segment_path = lambda: "diverse-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                            class Backup(Entity):
                                                """
                                                Diverse path can be backup path
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                    self.yang_name = "backup"
                                                    self.yang_parent_name = "diverse-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None
                                                    self._segment_path = lambda: "backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DistributeList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                        
                                        .. attribute:: accesslist
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                            ])
                                            self.inout = None
                                            self.accesslist = None
                                            self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SendLabel(Entity):
                                        """
                                        Send NLRI + MPLS Label to this peer
                                        
                                        .. attribute:: send_label_explicit
                                        
                                        	
                                        	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel, self).__init__()

                                            self.yang_name = "send-label"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit')])),
                                            ])
                                            self.send_label_explicit = None
                                            self._segment_path = lambda: "send-label"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                        class SendLabelExplicit(Enum):
                                            """
                                            SendLabelExplicit (Enum Class)

                                            .. data:: explicit_null = 0

                                            """

                                            explicit_null = Enum.YLeaf(0, "explicit-null")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertise
                                
                                	Advertise to this neighbor
                                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: capability
                                
                                	Advertise capability to the peer
                                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability>`
                                
                                .. attribute:: distribute_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: send_label
                                
                                	Send NLRI + MPLS Label to this peer
                                	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "vpnv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.dmzlink_bw = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise()
                                    self.advertise.parent = self
                                    self._children_name_map["advertise"] = "advertise"

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability()
                                    self.capability.parent = self
                                    self._children_name_map["capability"] = "capability"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.send_label = None
                                    self._children_name_map["send_label"] = "send-label"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.distribute_list = YList(self)
                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class Advertise(Entity):
                                    """
                                    Advertise to this neighbor
                                    
                                    .. attribute:: additional_paths
                                    
                                    	Advertise additional paths
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths>`
                                    
                                    .. attribute:: best_external
                                    
                                    	Advertise best\-external (at RRs best\-internal) path
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: diverse_path
                                    
                                    	Advertise diverse path
                                    	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise, self).__init__()

                                        self.yang_name = "advertise"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath))])
                                        self._leafs = OrderedDict([
                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                        ])
                                        self.best_external = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath()
                                        self.diverse_path.parent = self
                                        self._children_name_map["diverse_path"] = "diverse-path"
                                        self._segment_path = lambda: "advertise"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                    class AdditionalPaths(Entity):
                                        """
                                        Advertise additional paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best paths
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: best_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                self._leafs = OrderedDict()

                                                self.best_range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                            class BestRange(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                    self.yang_name = "best-range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "best-range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                    class DiversePath(Entity):
                                        """
                                        Advertise diverse path
                                        
                                        .. attribute:: backup
                                        
                                        	Diverse path can be backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: mpath
                                        
                                        	Diverse path can be multipath
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                            self.yang_name = "diverse-path"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                            self._leafs = OrderedDict([
                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                            ])
                                            self.mpath = None

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"
                                            self._segment_path = lambda: "diverse-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                        class Backup(Entity):
                                            """
                                            Diverse path can be backup path
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "diverse-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Capability(Entity):
                                    """
                                    Advertise capability to the peer
                                    
                                    .. attribute:: orf
                                    
                                    	Advertise ORF capability to the peer
                                    	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability, self).__init__()

                                        self.yang_name = "capability"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf))])
                                        self._leafs = OrderedDict()

                                        self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf()
                                        self.orf.parent = self
                                        self._children_name_map["orf"] = "orf"
                                        self._segment_path = lambda: "capability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability, [], name, value)


                                    class Orf(Entity):
                                        """
                                        Advertise ORF capability to the peer
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Advertise prefix list ORF capability to this neighbor
                                        	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf.PrefixList>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf, self).__init__()

                                            self.yang_name = "orf"
                                            self.yang_parent_name = "capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf.PrefixList')])),
                                            ])
                                            self.prefix_list = []
                                            self._segment_path = lambda: "orf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                        class PrefixList(Enum):
                                            """
                                            PrefixList (Enum Class)

                                            Advertise prefix list ORF capability to this neighbor

                                            .. data:: both = 0

                                            .. data:: receive = 1

                                            .. data:: send = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            receive = Enum.YLeaf(1, "receive")

                                            send = Enum.YLeaf(2, "send")



                                class DistributeList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList.Inout>`
                                    
                                    .. attribute:: accesslist
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..199
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..2699
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList.Inout')])),
                                            ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                        ])
                                        self.inout = None
                                        self.accesslist = None
                                        self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SendLabel(Entity):
                                    """
                                    Send NLRI + MPLS Label to this peer
                                    
                                    .. attribute:: send_label_explicit
                                    
                                    	
                                    	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel.SendLabelExplicit>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel, self).__init__()

                                        self.yang_name = "send-label"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel.SendLabelExplicit')])),
                                        ])
                                        self.send_label_explicit = None
                                        self._segment_path = lambda: "send-label"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                    class SendLabelExplicit(Enum):
                                        """
                                        SendLabelExplicit (Enum Class)

                                        .. data:: explicit_null = 0

                                        """

                                        explicit_null = Enum.YLeaf(0, "explicit-null")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Network(Entity):
                                """
                                
                                
                                .. attribute:: with_mask
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask>`
                                
                                .. attribute:: no_mask
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network, self).__init__()

                                    self.yang_name = "network"
                                    self.yang_parent_name = "vpnv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask))])
                                    self._leafs = OrderedDict()

                                    self.with_mask = YList(self)
                                    self.no_mask = YList(self)
                                    self._segment_path = lambda: "network"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network, [], name, value)


                                class WithMask(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mask  (key)
                                    
                                    	Network mask
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask, self).__init__()

                                        self.yang_name = "with-mask"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number','mask']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.mask = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor'], name, value)


                                class NoMask(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask, self).__init__()

                                        self.yang_name = "no-mask"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask, ['number', 'route_map', 'backdoor'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "vpnv4-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                        class Vpnv4Multicast(Entity):
                            """
                            VPNv4 Multiicast address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_>`
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast, self).__init__()

                                self.yang_name = "vpnv4-multicast"
                                self.yang_parent_name = "vpnv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.maximum_paths = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths()
                                self.maximum_paths.parent = self
                                self._children_name_map["maximum_paths"] = "maximum-paths"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "vpnv4-multicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast, [], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: aggregate_timer
                                
                                	Configure aggregation timer
                                	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.AggregateTimer>`
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: default
                                
                                	Configure BGP defaults
                                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Default>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Nexthop>`
                                
                                .. attribute:: redistribute_internal
                                
                                	Allow redistribution of iBGP into IGPs (dangerous)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: update_group
                                
                                	Manage peers in bgp update groups
                                	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "vpnv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.AggregateTimer)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Dampening)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Nexthop)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.UpdateGroup))])
                                    self._leafs = OrderedDict([
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                    ])
                                    self.dmzlink_bw = None
                                    self.redistribute_internal = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None

                                    self.aggregate_timer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.AggregateTimer()
                                    self.aggregate_timer.parent = self
                                    self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"

                                    self.default = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Default()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.UpdateGroup()
                                    self.update_group.parent = self
                                    self._children_name_map["update_group"] = "update-group"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_, ['dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                class AggregateTimer(Entity):
                                    """
                                    Configure aggregation timer
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Timer interval
                                    	**type**\: int
                                    
                                    	**range:** 6..60
                                    
                                    .. attribute:: disable_timer
                                    
                                    	Timer interval
                                    	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.AggregateTimer.DisableTimer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.AggregateTimer, self).__init__()

                                        self.yang_name = "aggregate-timer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                            ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.AggregateTimer.DisableTimer')])),
                                        ])
                                        self.aggregate_timer = None
                                        self.disable_timer = None
                                        self._segment_path = lambda: "aggregate-timer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                    class DisableTimer(Enum):
                                        """
                                        DisableTimer (Enum Class)

                                        Timer interval

                                        .. data:: Y_0 = 0

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")



                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria for dampening
                                    	**type**\: str
                                    
                                    .. attribute:: dampen
                                    
                                    	
                                    	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Dampening.Dampen>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Dampening.Dampen))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.dampen = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Dampening.Dampen()
                                        self.dampen.parent = self
                                        self._children_name_map["dampen"] = "dampen"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Dampening, ['route_map'], name, value)


                                    class Dampen(Entity):
                                        """
                                        
                                        
                                        .. attribute:: half_life_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..45
                                        
                                        .. attribute:: reuse_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: max_suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Dampening.Dampen, self).__init__()

                                            self.yang_name = "dampen"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                            ])
                                            self.half_life_time = None
                                            self.reuse_time = None
                                            self.suppress_time = None
                                            self.max_suppress_time = None
                                            self._segment_path = lambda: "dampen"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                class Default(Entity):
                                    """
                                    Configure BGP defaults
                                    
                                    .. attribute:: route_target
                                    
                                    	Control behavior based on Route\-Target attributes
                                    	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Default.RouteTarget>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Default, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Default.RouteTarget')])),
                                        ])
                                        self.route_target = None
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Default, ['route_target'], name, value)

                                    class RouteTarget(Enum):
                                        """
                                        RouteTarget (Enum Class)

                                        Control behavior based on Route\-Target attributes

                                        .. data:: filter = 0

                                        """

                                        filter = Enum.YLeaf(0, "filter")



                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    Manage peers in bgp update groups
                                    
                                    .. attribute:: split
                                    
                                    	Split update groups based on Policy
                                    	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.UpdateGroup.Split>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.UpdateGroup.Split))])
                                        self._leafs = OrderedDict()

                                        self.split = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.UpdateGroup.Split()
                                        self.split.parent = self
                                        self._children_name_map["split"] = "split"
                                        self._segment_path = lambda: "update-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.UpdateGroup, [], name, value)


                                    class Split(Entity):
                                        """
                                        Split update groups based on Policy
                                        
                                        .. attribute:: as_override
                                        
                                        	Keep peers with as\-override in different update groups
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.UpdateGroup.Split, self).__init__()

                                            self.yang_name = "split"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ])
                                            self.as_override = None
                                            self._segment_path = lambda: "split"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                            class MaximumPaths(Entity):
                                """
                                Forward packets over multiple paths
                                
                                .. attribute:: ebgp
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: eibgp
                                
                                	Both eBGP and iBGP paths as multipath
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: ibgp
                                
                                	iBGP\-multipath
                                	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths.Ibgp>`
                                
                                .. attribute:: external_rtfilter
                                
                                	VPN prefix multipath on external RT\-Filter peers
                                	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths.ExternalRtfilter>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths, self).__init__()

                                    self.yang_name = "maximum-paths"
                                    self.yang_parent_name = "vpnv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths.ExternalRtfilter))])
                                    self._leafs = OrderedDict([
                                        ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                        ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                    ])
                                    self.ebgp = None
                                    self.eibgp = None

                                    self.ibgp = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"

                                    self.external_rtfilter = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths.ExternalRtfilter()
                                    self.external_rtfilter.parent = self
                                    self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                    self._segment_path = lambda: "maximum-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                class Ibgp(Entity):
                                    """
                                    iBGP\-multipath
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Perform un\-equal cost multipath selection
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.unequal_cost = None
                                        self.max = None
                                        self._segment_path = lambda: "ibgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                class ExternalRtfilter(Entity):
                                    """
                                    VPN prefix multipath on external RT\-Filter peers
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                        self.yang_name = "external-rtfilter"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.max = None
                                        self._segment_path = lambda: "external-rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "vpnv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.DistributeList>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.distribute_list = YList(self)
                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DistributeList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                        
                                        .. attribute:: accesslist
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                            ])
                                            self.inout = None
                                            self.accesslist = None
                                            self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: capability
                                
                                	Advertise capability to the peer
                                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability>`
                                
                                .. attribute:: distribute_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.DistributeList>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "vpnv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.dmzlink_bw = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability()
                                    self.capability.parent = self
                                    self._children_name_map["capability"] = "capability"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.distribute_list = YList(self)
                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Capability(Entity):
                                    """
                                    Advertise capability to the peer
                                    
                                    .. attribute:: orf
                                    
                                    	Advertise ORF capability to the peer
                                    	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability.Orf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability, self).__init__()

                                        self.yang_name = "capability"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability.Orf))])
                                        self._leafs = OrderedDict()

                                        self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability.Orf()
                                        self.orf.parent = self
                                        self._children_name_map["orf"] = "orf"
                                        self._segment_path = lambda: "capability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability, [], name, value)


                                    class Orf(Entity):
                                        """
                                        Advertise ORF capability to the peer
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Advertise prefix list ORF capability to this neighbor
                                        	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability.Orf.PrefixList>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability.Orf, self).__init__()

                                            self.yang_name = "orf"
                                            self.yang_parent_name = "capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability.Orf.PrefixList')])),
                                            ])
                                            self.prefix_list = []
                                            self._segment_path = lambda: "orf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                        class PrefixList(Enum):
                                            """
                                            PrefixList (Enum Class)

                                            Advertise prefix list ORF capability to this neighbor

                                            .. data:: both = 0

                                            .. data:: receive = 1

                                            .. data:: send = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            receive = Enum.YLeaf(1, "receive")

                                            send = Enum.YLeaf(2, "send")



                                class DistributeList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.DistributeList.Inout>`
                                    
                                    .. attribute:: accesslist
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..199
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..2699
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.DistributeList.Inout')])),
                                            ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                        ])
                                        self.inout = None
                                        self.accesslist = None
                                        self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.NextHopSelf, ['all'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "vpnv4-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Multicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                        class Vpnv4Flowspec(Entity):
                            """
                            VPNv4 Flowspec address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_>`
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec, self).__init__()

                                self.yang_name = "vpnv4-flowspec"
                                self.yang_parent_name = "vpnv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.maximum_paths = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths()
                                self.maximum_paths.parent = self
                                self._children_name_map["maximum_paths"] = "maximum-paths"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "vpnv4-flowspec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec, [], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.Nexthop>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "vpnv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.Nexthop)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                    ])
                                    self.scan_time = None

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_, ['scan_time'], name, value)


                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class MaximumPaths(Entity):
                                """
                                Forward packets over multiple paths
                                
                                .. attribute:: ebgp
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: eibgp
                                
                                	Both eBGP and iBGP paths as multipath
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: ibgp
                                
                                	iBGP\-multipath
                                	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths.Ibgp>`
                                
                                .. attribute:: external_rtfilter
                                
                                	VPN prefix multipath on external RT\-Filter peers
                                	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths.ExternalRtfilter>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths, self).__init__()

                                    self.yang_name = "maximum-paths"
                                    self.yang_parent_name = "vpnv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths.ExternalRtfilter))])
                                    self._leafs = OrderedDict([
                                        ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                        ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                    ])
                                    self.ebgp = None
                                    self.eibgp = None

                                    self.ibgp = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"

                                    self.external_rtfilter = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths.ExternalRtfilter()
                                    self.external_rtfilter.parent = self
                                    self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                    self._segment_path = lambda: "maximum-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                class Ibgp(Entity):
                                    """
                                    iBGP\-multipath
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Perform un\-equal cost multipath selection
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.unequal_cost = None
                                        self.max = None
                                        self._segment_path = lambda: "ibgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                class ExternalRtfilter(Entity):
                                    """
                                    VPN prefix multipath on external RT\-Filter peers
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths.ExternalRtfilter, self).__init__()

                                        self.yang_name = "external-rtfilter"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.max = None
                                        self._segment_path = lambda: "external-rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "vpnv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.AllowasIn)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "vpnv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.AllowasIn)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SoftReconfiguration')])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor, ['id', 'activate', 'advertisement_interval', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.NextHopSelf, ['all'], name, value)


                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "vpnv4-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv4.Vpnv4Flowspec.Snmp.Context.ContextWord, ['context_word'], name, value)


                    class Vpnv6(Entity):
                        """
                        Address family
                        
                        .. attribute:: af_name  (key)
                        
                        	
                        	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.AfName>`
                        
                        .. attribute:: vpnv6_unicast
                        
                        	VPNv6 Unicast address family
                        	**type**\:  :py:class:`Vpnv6Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast>`
                        
                        .. attribute:: vpnv6_multicast
                        
                        	VPNv6 Multiicast address family
                        	**type**\:  :py:class:`Vpnv6Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast>`
                        
                        .. attribute:: vpnv6_flowspec
                        
                        	VPNv6 Flowspec address family
                        	**type**\:  :py:class:`Vpnv6Flowspec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6, self).__init__()

                            self.yang_name = "vpnv6"
                            self.yang_parent_name = "no-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("vpnv6-unicast", ("vpnv6_unicast", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast)), ("vpnv6-multicast", ("vpnv6_multicast", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast)), ("vpnv6-flowspec", ("vpnv6_flowspec", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.AfName')])),
                            ])
                            self.af_name = None

                            self.vpnv6_unicast = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast()
                            self.vpnv6_unicast.parent = self
                            self._children_name_map["vpnv6_unicast"] = "vpnv6-unicast"

                            self.vpnv6_multicast = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast()
                            self.vpnv6_multicast.parent = self
                            self._children_name_map["vpnv6_multicast"] = "vpnv6-multicast"

                            self.vpnv6_flowspec = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec()
                            self.vpnv6_flowspec.parent = self
                            self._children_name_map["vpnv6_flowspec"] = "vpnv6-flowspec"
                            self._segment_path = lambda: "vpnv6" + "[af-name='" + str(self.af_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6, ['af_name'], name, value)

                        class AfName(Enum):
                            """
                            AfName (Enum Class)

                            .. data:: unicast = 0

                            .. data:: multicast = 1

                            .. data:: flowspec = 2

                            """

                            unicast = Enum.YLeaf(0, "unicast")

                            multicast = Enum.YLeaf(1, "multicast")

                            flowspec = Enum.YLeaf(2, "flowspec")



                        class Vpnv6Unicast(Entity):
                            """
                            VPNv6 Unicast address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast, self).__init__()

                                self.yang_name = "vpnv6-unicast"
                                self.yang_parent_name = "vpnv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "vpnv6-unicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast, [], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: additional_paths
                                
                                	Additional paths in the BGP table
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths>`
                                
                                .. attribute:: advertise_best_external
                                
                                	Advertise best external path to internal peers
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: aggregate_timer
                                
                                	Configure aggregation timer
                                	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer>`
                                
                                .. attribute:: bestpath
                                
                                	Change the default bestpath selection
                                	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath>`
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: default
                                
                                	Configure BGP defaults
                                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop>`
                                
                                .. attribute:: recursion
                                
                                	recursion rule for the nexthops
                                	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion>`
                                
                                .. attribute:: redistribute_internal
                                
                                	Allow redistribution of iBGP into IGPs (dangerous)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: update_group
                                
                                	Manage peers in bgp update groups
                                	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "vpnv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup))])
                                    self._leafs = OrderedDict([
                                        ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                    ])
                                    self.advertise_best_external = None
                                    self.dmzlink_bw = None
                                    self.redistribute_internal = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.aggregate_timer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer()
                                    self.aggregate_timer.parent = self
                                    self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                    self.bestpath = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath()
                                    self.bestpath.parent = self
                                    self._children_name_map["bestpath"] = "bestpath"

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"

                                    self.default = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.recursion = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion()
                                    self.recursion.parent = self
                                    self._children_name_map["recursion"] = "recursion"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup()
                                    self.update_group.parent = self
                                    self._children_name_map["update_group"] = "update-group"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                class AdditionalPaths(Entity):
                                    """
                                    Additional paths in the BGP table
                                    
                                    .. attribute:: install
                                    
                                    	Additional paths to install into RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: select
                                    
                                    	Selection criteria to pick the paths
                                    	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to neighbors
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.install = None
                                        self.receive = None

                                        self.select = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select()
                                        self.select.parent = self
                                        self._children_name_map["select"] = "select"

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                    class Select(Entity):
                                        """
                                        Selection criteria to pick the paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: backup
                                        
                                        	Select backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Select best\-external path
                                        	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best path
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                            self.yang_name = "select"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.best_external = None
                                            self._children_name_map["best_external"] = "best-external"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "select"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best path
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best path
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                        class Backup(Entity):
                                            """
                                            Select backup path
                                            
                                            .. attribute:: best_external
                                            
                                            	Select best\-external path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                self._leafs = OrderedDict()

                                                self.range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                        class BestExternal(Entity):
                                            """
                                            Select best\-external path
                                            
                                            .. attribute:: backup
                                            
                                            	Select backup path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                self.yang_name = "best-external"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                ])
                                                self.backup = None
                                                self._segment_path = lambda: "best-external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best path
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to neighbors
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                class AggregateTimer(Entity):
                                    """
                                    Configure aggregation timer
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Timer interval
                                    	**type**\: int
                                    
                                    	**range:** 6..60
                                    
                                    .. attribute:: disable_timer
                                    
                                    	Timer interval
                                    	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer, self).__init__()

                                        self.yang_name = "aggregate-timer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                            ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                        ])
                                        self.aggregate_timer = None
                                        self.disable_timer = None
                                        self._segment_path = lambda: "aggregate-timer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                    class DisableTimer(Enum):
                                        """
                                        DisableTimer (Enum Class)

                                        Timer interval

                                        .. data:: Y_0 = 0

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")



                                class Bestpath(Entity):
                                    """
                                    Change the default bestpath selection
                                    
                                    .. attribute:: igp_metric
                                    
                                    	igp metric
                                    	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric>`
                                    
                                    .. attribute:: prefix_validate
                                    
                                    	Prefix origin validation
                                    	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath, self).__init__()

                                        self.yang_name = "bestpath"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate))])
                                        self._leafs = OrderedDict()

                                        self.igp_metric = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric()
                                        self.igp_metric.parent = self
                                        self._children_name_map["igp_metric"] = "igp-metric"

                                        self.prefix_validate = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate()
                                        self.prefix_validate.parent = self
                                        self._children_name_map["prefix_validate"] = "prefix-validate"
                                        self._segment_path = lambda: "bestpath"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath, [], name, value)


                                    class IgpMetric(Entity):
                                        """
                                        igp metric
                                        
                                        .. attribute:: ignore
                                        
                                        	Ignore igp metric in bestpath selection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                            self.yang_name = "igp-metric"
                                            self.yang_parent_name = "bestpath"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                            ])
                                            self.ignore = None
                                            self._segment_path = lambda: "igp-metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                    class PrefixValidate(Entity):
                                        """
                                        Prefix origin validation
                                        
                                        .. attribute:: allow_invalid
                                        
                                        	Allow invalid routes to be considered for bestpath
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: disable
                                        
                                        	Disable prefix validation
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                            self.yang_name = "prefix-validate"
                                            self.yang_parent_name = "bestpath"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ])
                                            self.allow_invalid = None
                                            self.disable = None
                                            self._segment_path = lambda: "prefix-validate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria for dampening
                                    	**type**\: str
                                    
                                    .. attribute:: dampen
                                    
                                    	
                                    	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.dampen = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen()
                                        self.dampen.parent = self
                                        self._children_name_map["dampen"] = "dampen"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                    class Dampen(Entity):
                                        """
                                        
                                        
                                        .. attribute:: half_life_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..45
                                        
                                        .. attribute:: reuse_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: max_suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                            self.yang_name = "dampen"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                            ])
                                            self.half_life_time = None
                                            self.reuse_time = None
                                            self.suppress_time = None
                                            self.max_suppress_time = None
                                            self._segment_path = lambda: "dampen"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                class Default(Entity):
                                    """
                                    Configure BGP defaults
                                    
                                    .. attribute:: route_target
                                    
                                    	Control behavior based on Route\-Target attributes
                                    	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default.RouteTarget>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default.RouteTarget')])),
                                        ])
                                        self.route_target = None
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default, ['route_target'], name, value)

                                    class RouteTarget(Enum):
                                        """
                                        RouteTarget (Enum Class)

                                        Control behavior based on Route\-Target attributes

                                        .. data:: filter = 0

                                        """

                                        filter = Enum.YLeaf(0, "filter")



                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class Recursion(Entity):
                                    """
                                    recursion rule for the nexthops
                                    
                                    .. attribute:: host
                                    
                                    	recursion via host for the nexthops
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion, self).__init__()

                                        self.yang_name = "recursion"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                        ])
                                        self.host = None
                                        self._segment_path = lambda: "recursion"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion, ['host'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    Manage peers in bgp update groups
                                    
                                    .. attribute:: split
                                    
                                    	Split update groups based on Policy
                                    	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split))])
                                        self._leafs = OrderedDict()

                                        self.split = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split()
                                        self.split.parent = self
                                        self._children_name_map["split"] = "split"
                                        self._segment_path = lambda: "update-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup, [], name, value)


                                    class Split(Entity):
                                        """
                                        Split update groups based on Policy
                                        
                                        .. attribute:: as_override
                                        
                                        	Keep peers with as\-override in different update groups
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                            self.yang_name = "split"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ])
                                            self.as_override = None
                                            self._segment_path = lambda: "split"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "vpnv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise to this neighbor
                                    	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise()
                                        self.advertise.parent = self
                                        self._children_name_map["advertise"] = "advertise"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.distribute_list = YList(self)
                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class Advertise(Entity):
                                        """
                                        Advertise to this neighbor
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Advertise additional paths
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Advertise best\-external (at RRs best\-internal) path
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: diverse_path
                                        
                                        	Advertise diverse path
                                        	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                            self.yang_name = "advertise"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                            self._leafs = OrderedDict([
                                                ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                            ])
                                            self.best_external = None

                                            self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                            self.diverse_path.parent = self
                                            self._children_name_map["diverse_path"] = "diverse-path"
                                            self._segment_path = lambda: "advertise"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Advertise additional paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                            class All(Entity):
                                                """
                                                Select all available paths
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.group_best = None
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.all = None

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "best-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.all = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.all = None
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                        class DiversePath(Entity):
                                            """
                                            Advertise diverse path
                                            
                                            .. attribute:: backup
                                            
                                            	Diverse path can be backup path
                                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                self.yang_name = "diverse-path"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None

                                                self.backup = None
                                                self._children_name_map["backup"] = "backup"
                                                self._segment_path = lambda: "diverse-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                            class Backup(Entity):
                                                """
                                                Diverse path can be backup path
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                    self.yang_name = "backup"
                                                    self.yang_parent_name = "diverse-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None
                                                    self._segment_path = lambda: "backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                        
                                        .. attribute:: accesslist
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                            ])
                                            self.inout = None
                                            self.accesslist = None
                                            self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertise
                                
                                	Advertise to this neighbor
                                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: distribute_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "vpnv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.dmzlink_bw = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise()
                                    self.advertise.parent = self
                                    self._children_name_map["advertise"] = "advertise"

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.distribute_list = YList(self)
                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class Advertise(Entity):
                                    """
                                    Advertise to this neighbor
                                    
                                    .. attribute:: additional_paths
                                    
                                    	Advertise additional paths
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths>`
                                    
                                    .. attribute:: best_external
                                    
                                    	Advertise best\-external (at RRs best\-internal) path
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: diverse_path
                                    
                                    	Advertise diverse path
                                    	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise, self).__init__()

                                        self.yang_name = "advertise"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath))])
                                        self._leafs = OrderedDict([
                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                        ])
                                        self.best_external = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath()
                                        self.diverse_path.parent = self
                                        self._children_name_map["diverse_path"] = "diverse-path"
                                        self._segment_path = lambda: "advertise"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                    class AdditionalPaths(Entity):
                                        """
                                        Advertise additional paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best paths
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: best_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                self._leafs = OrderedDict()

                                                self.best_range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                            class BestRange(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                    self.yang_name = "best-range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "best-range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                    class DiversePath(Entity):
                                        """
                                        Advertise diverse path
                                        
                                        .. attribute:: backup
                                        
                                        	Diverse path can be backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: mpath
                                        
                                        	Diverse path can be multipath
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                            self.yang_name = "diverse-path"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                            self._leafs = OrderedDict([
                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                            ])
                                            self.mpath = None

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"
                                            self._segment_path = lambda: "diverse-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                        class Backup(Entity):
                                            """
                                            Diverse path can be backup path
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "diverse-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList.Inout>`
                                    
                                    .. attribute:: accesslist
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..199
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..2699
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList.Inout')])),
                                            ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                        ])
                                        self.inout = None
                                        self.accesslist = None
                                        self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "vpnv6-unicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                        class Vpnv6Multicast(Entity):
                            """
                            VPNv6 Multiicast address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast, self).__init__()

                                self.yang_name = "vpnv6-multicast"
                                self.yang_parent_name = "vpnv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "vpnv6-multicast"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast, [], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: aggregate_timer
                                
                                	Configure aggregation timer
                                	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.AggregateTimer>`
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: default
                                
                                	Configure BGP defaults
                                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Default>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Nexthop>`
                                
                                .. attribute:: redistribute_internal
                                
                                	Allow redistribution of iBGP into IGPs (dangerous)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: update_group
                                
                                	Manage peers in bgp update groups
                                	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "vpnv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.AggregateTimer)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Dampening)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Nexthop)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.UpdateGroup))])
                                    self._leafs = OrderedDict([
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                    ])
                                    self.dmzlink_bw = None
                                    self.redistribute_internal = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None

                                    self.aggregate_timer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.AggregateTimer()
                                    self.aggregate_timer.parent = self
                                    self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"

                                    self.default = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Default()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.UpdateGroup()
                                    self.update_group.parent = self
                                    self._children_name_map["update_group"] = "update-group"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_, ['dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                class AggregateTimer(Entity):
                                    """
                                    Configure aggregation timer
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Timer interval
                                    	**type**\: int
                                    
                                    	**range:** 6..60
                                    
                                    .. attribute:: disable_timer
                                    
                                    	Timer interval
                                    	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.AggregateTimer.DisableTimer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.AggregateTimer, self).__init__()

                                        self.yang_name = "aggregate-timer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                            ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.AggregateTimer.DisableTimer')])),
                                        ])
                                        self.aggregate_timer = None
                                        self.disable_timer = None
                                        self._segment_path = lambda: "aggregate-timer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                    class DisableTimer(Enum):
                                        """
                                        DisableTimer (Enum Class)

                                        Timer interval

                                        .. data:: Y_0 = 0

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")



                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria for dampening
                                    	**type**\: str
                                    
                                    .. attribute:: dampen
                                    
                                    	
                                    	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Dampening.Dampen>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Dampening.Dampen))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.dampen = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Dampening.Dampen()
                                        self.dampen.parent = self
                                        self._children_name_map["dampen"] = "dampen"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Dampening, ['route_map'], name, value)


                                    class Dampen(Entity):
                                        """
                                        
                                        
                                        .. attribute:: half_life_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..45
                                        
                                        .. attribute:: reuse_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: max_suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Dampening.Dampen, self).__init__()

                                            self.yang_name = "dampen"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                            ])
                                            self.half_life_time = None
                                            self.reuse_time = None
                                            self.suppress_time = None
                                            self.max_suppress_time = None
                                            self._segment_path = lambda: "dampen"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                class Default(Entity):
                                    """
                                    Configure BGP defaults
                                    
                                    .. attribute:: route_target
                                    
                                    	Control behavior based on Route\-Target attributes
                                    	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Default.RouteTarget>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Default, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Default.RouteTarget')])),
                                        ])
                                        self.route_target = None
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Default, ['route_target'], name, value)

                                    class RouteTarget(Enum):
                                        """
                                        RouteTarget (Enum Class)

                                        Control behavior based on Route\-Target attributes

                                        .. data:: filter = 0

                                        """

                                        filter = Enum.YLeaf(0, "filter")



                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    Manage peers in bgp update groups
                                    
                                    .. attribute:: split
                                    
                                    	Split update groups based on Policy
                                    	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.UpdateGroup.Split>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.UpdateGroup.Split))])
                                        self._leafs = OrderedDict()

                                        self.split = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.UpdateGroup.Split()
                                        self.split.parent = self
                                        self._children_name_map["split"] = "split"
                                        self._segment_path = lambda: "update-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.UpdateGroup, [], name, value)


                                    class Split(Entity):
                                        """
                                        Split update groups based on Policy
                                        
                                        .. attribute:: as_override
                                        
                                        	Keep peers with as\-override in different update groups
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.UpdateGroup.Split, self).__init__()

                                            self.yang_name = "split"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                            ])
                                            self.as_override = None
                                            self._segment_path = lambda: "split"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "vpnv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.DistributeList>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.distribute_list = YList(self)
                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DistributeList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                        
                                        .. attribute:: accesslist
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                            ])
                                            self.inout = None
                                            self.accesslist = None
                                            self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: capability
                                
                                	Advertise capability to the peer
                                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability>`
                                
                                .. attribute:: distribute_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.DistributeList>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "vpnv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.dmzlink_bw = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability()
                                    self.capability.parent = self
                                    self._children_name_map["capability"] = "capability"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.distribute_list = YList(self)
                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Capability(Entity):
                                    """
                                    Advertise capability to the peer
                                    
                                    .. attribute:: orf
                                    
                                    	Advertise ORF capability to the peer
                                    	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability.Orf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability, self).__init__()

                                        self.yang_name = "capability"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability.Orf))])
                                        self._leafs = OrderedDict()

                                        self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability.Orf()
                                        self.orf.parent = self
                                        self._children_name_map["orf"] = "orf"
                                        self._segment_path = lambda: "capability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability, [], name, value)


                                    class Orf(Entity):
                                        """
                                        Advertise ORF capability to the peer
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Advertise prefix list ORF capability to this neighbor
                                        	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability.Orf.PrefixList>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability.Orf, self).__init__()

                                            self.yang_name = "orf"
                                            self.yang_parent_name = "capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability.Orf.PrefixList')])),
                                            ])
                                            self.prefix_list = []
                                            self._segment_path = lambda: "orf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                        class PrefixList(Enum):
                                            """
                                            PrefixList (Enum Class)

                                            Advertise prefix list ORF capability to this neighbor

                                            .. data:: both = 0

                                            .. data:: receive = 1

                                            .. data:: send = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            receive = Enum.YLeaf(1, "receive")

                                            send = Enum.YLeaf(2, "send")



                                class DistributeList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.DistributeList.Inout>`
                                    
                                    .. attribute:: accesslist
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..199
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..2699
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.DistributeList.Inout')])),
                                            ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                        ])
                                        self.inout = None
                                        self.accesslist = None
                                        self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.NextHopSelf, ['all'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "vpnv6-multicast"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Multicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                        class Vpnv6Flowspec(Entity):
                            """
                            VPNv6 Flowspec address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_>`
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec, self).__init__()

                                self.yang_name = "vpnv6-flowspec"
                                self.yang_parent_name = "vpnv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.maximum_paths = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths()
                                self.maximum_paths.parent = self
                                self._children_name_map["maximum_paths"] = "maximum-paths"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "vpnv6-flowspec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec, [], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.Nexthop>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "vpnv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.Nexthop)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                    ])
                                    self.scan_time = None

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_, ['scan_time'], name, value)


                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class MaximumPaths(Entity):
                                """
                                Forward packets over multiple paths
                                
                                .. attribute:: ebgp
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: eibgp
                                
                                	Both eBGP and iBGP paths as multipath
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: ibgp
                                
                                	iBGP\-multipath
                                	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths.Ibgp>`
                                
                                .. attribute:: external_rtfilter
                                
                                	VPN prefix multipath on external RT\-Filter peers
                                	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths.ExternalRtfilter>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths, self).__init__()

                                    self.yang_name = "maximum-paths"
                                    self.yang_parent_name = "vpnv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths.ExternalRtfilter))])
                                    self._leafs = OrderedDict([
                                        ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                        ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                    ])
                                    self.ebgp = None
                                    self.eibgp = None

                                    self.ibgp = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"

                                    self.external_rtfilter = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths.ExternalRtfilter()
                                    self.external_rtfilter.parent = self
                                    self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                    self._segment_path = lambda: "maximum-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                class Ibgp(Entity):
                                    """
                                    iBGP\-multipath
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Perform un\-equal cost multipath selection
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.unequal_cost = None
                                        self.max = None
                                        self._segment_path = lambda: "ibgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                class ExternalRtfilter(Entity):
                                    """
                                    VPN prefix multipath on external RT\-Filter peers
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths.ExternalRtfilter, self).__init__()

                                        self.yang_name = "external-rtfilter"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.max = None
                                        self._segment_path = lambda: "external-rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "vpnv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.AllowasIn)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "vpnv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.AllowasIn)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SoftReconfiguration')])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor, ['id', 'activate', 'advertisement_interval', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.NextHopSelf, ['all'], name, value)


                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "vpnv6-flowspec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Vpnv6.Vpnv6Flowspec.Snmp.Context.ContextWord, ['context_word'], name, value)


                    class Nsap(Entity):
                        """
                        Address family
                        
                        .. attribute:: af_name  (key)
                        
                        	
                        	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.AfName>`
                        
                        .. attribute:: nsap
                        
                        	NSAP address family
                        	**type**\:  :py:class:`Nsap_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap, self).__init__()

                            self.yang_name = "nsap"
                            self.yang_parent_name = "no-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("nsap", ("nsap", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.AfName')])),
                            ])
                            self.af_name = None

                            self.nsap = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_()
                            self.nsap.parent = self
                            self._children_name_map["nsap"] = "nsap"
                            self._segment_path = lambda: "nsap" + "[af-name='" + str(self.af_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap, ['af_name'], name, value)

                        class AfName(Enum):
                            """
                            AfName (Enum Class)

                            .. data:: unicast = 0

                            """

                            unicast = Enum.YLeaf(0, "unicast")



                        class Nsap_(Entity):
                            """
                            NSAP address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation>`
                            
                            .. attribute:: default_metric
                            
                            	Set metric of redistributed routes
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor>`
                            
                            .. attribute:: network
                            
                            	Specify a network to announce via BGP
                            	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Network>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_, self).__init__()

                                self.yang_name = "nsap"
                                self.yang_parent_name = "nsap"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor)), ("network", ("network", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Network)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp))])
                                self._leafs = OrderedDict([
                                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                ])
                                self.default_metric = None

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.default_information = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.maximum_paths = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths()
                                self.maximum_paths.parent = self
                                self._children_name_map["maximum_paths"] = "maximum-paths"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self.network = YList(self)
                                self._segment_path = lambda: "nsap"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_, ['default_metric'], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: aggregate_timer
                                
                                	Configure aggregation timer
                                	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer>`
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dmzlink_bw
                                
                                	Use DMZ Link Bandwidth as weight for BGP multipaths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop>`
                                
                                .. attribute:: redistribute_internal
                                
                                	Allow redistribution of iBGP into IGPs (dangerous)
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: route_map
                                
                                	bgp route\-map commands
                                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer>`
                                
                                .. attribute:: soft_reconfig_backup
                                
                                	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "nsap"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer)), ("dampening", ("dampening", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                        ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                    ])
                                    self.dmzlink_bw = None
                                    self.redistribute_internal = None
                                    self.scan_time = None
                                    self.soft_reconfig_backup = None

                                    self.aggregate_timer = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer()
                                    self.aggregate_timer.parent = self
                                    self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.route_map = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap()
                                    self.route_map.parent = self
                                    self._children_name_map["route_map"] = "route-map"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_, ['dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                class AggregateTimer(Entity):
                                    """
                                    Configure aggregation timer
                                    
                                    .. attribute:: aggregate_timer
                                    
                                    	Timer interval
                                    	**type**\: int
                                    
                                    	**range:** 6..60
                                    
                                    .. attribute:: disable_timer
                                    
                                    	Timer interval
                                    	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer.DisableTimer>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer, self).__init__()

                                        self.yang_name = "aggregate-timer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                            ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer.DisableTimer')])),
                                        ])
                                        self.aggregate_timer = None
                                        self.disable_timer = None
                                        self._segment_path = lambda: "aggregate-timer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                    class DisableTimer(Enum):
                                        """
                                        DisableTimer (Enum Class)

                                        Timer interval

                                        .. data:: Y_0 = 0

                                        """

                                        Y_0 = Enum.YLeaf(0, "0")



                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria for dampening
                                    	**type**\: str
                                    
                                    .. attribute:: dampen
                                    
                                    	
                                    	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.dampen = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen()
                                        self.dampen.parent = self
                                        self._children_name_map["dampen"] = "dampen"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening, ['route_map'], name, value)


                                    class Dampen(Entity):
                                        """
                                        
                                        
                                        .. attribute:: half_life_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..45
                                        
                                        .. attribute:: reuse_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: max_suppress_time
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen, self).__init__()

                                            self.yang_name = "dampen"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                            ])
                                            self.half_life_time = None
                                            self.reuse_time = None
                                            self.suppress_time = None
                                            self.max_suppress_time = None
                                            self._segment_path = lambda: "dampen"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class RouteMap(Entity):
                                    """
                                    bgp route\-map commands
                                    
                                    .. attribute:: priority
                                    
                                    	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                        ])
                                        self.priority = None
                                        self._segment_path = lambda: "route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap, ['priority'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "nsap"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                    ])
                                    self.originate = None
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation, ['originate'], name, value)


                            class MaximumPaths(Entity):
                                """
                                Forward packets over multiple paths
                                
                                .. attribute:: ebgp
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: eibgp
                                
                                	Both eBGP and iBGP paths as multipath
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: ibgp
                                
                                	iBGP\-multipath
                                	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp>`
                                
                                .. attribute:: external_rtfilter
                                
                                	VPN prefix multipath on external RT\-Filter peers
                                	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths, self).__init__()

                                    self.yang_name = "maximum-paths"
                                    self.yang_parent_name = "nsap"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter))])
                                    self._leafs = OrderedDict([
                                        ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                        ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                    ])
                                    self.ebgp = None
                                    self.eibgp = None

                                    self.ibgp = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"

                                    self.external_rtfilter = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter()
                                    self.external_rtfilter.parent = self
                                    self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                    self._segment_path = lambda: "maximum-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                class Ibgp(Entity):
                                    """
                                    iBGP\-multipath
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Perform un\-equal cost multipath selection
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.unequal_cost = None
                                        self.max = None
                                        self._segment_path = lambda: "ibgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                class ExternalRtfilter(Entity):
                                    """
                                    VPN prefix multipath on external RT\-Filter peers
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter, self).__init__()

                                        self.yang_name = "external-rtfilter"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.max = None
                                        self._segment_path = lambda: "external-rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "nsap"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability>`
                                    
                                    .. attribute:: default_originate
                                    
                                    	Originate default route to this neighbor
                                    	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soo = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.default_originate = None
                                        self._children_name_map["default_originate"] = "default-originate"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soo', 'weight'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DefaultOriginate(Entity):
                                        """
                                        Originate default route to this neighbor
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria to originate default
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                            self.yang_name = "default-originate"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "default-originate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: capability
                                
                                	Advertise capability to the peer
                                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability>`
                                
                                .. attribute:: default_originate
                                
                                	Originate default route to this neighbor
                                	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dmzlink_bw
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "nsap"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.dmzlink_bw = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soo = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability()
                                    self.capability.parent = self
                                    self._children_name_map["capability"] = "capability"

                                    self.default_originate = None
                                    self._children_name_map["default_originate"] = "default-originate"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soo', 'weight'], name, value)


                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Capability(Entity):
                                    """
                                    Advertise capability to the peer
                                    
                                    .. attribute:: orf
                                    
                                    	Advertise ORF capability to the peer
                                    	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability, self).__init__()

                                        self.yang_name = "capability"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf))])
                                        self._leafs = OrderedDict()

                                        self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf()
                                        self.orf.parent = self
                                        self._children_name_map["orf"] = "orf"
                                        self._segment_path = lambda: "capability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability, [], name, value)


                                    class Orf(Entity):
                                        """
                                        Advertise ORF capability to the peer
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Advertise prefix list ORF capability to this neighbor
                                        	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf.PrefixList>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf, self).__init__()

                                            self.yang_name = "orf"
                                            self.yang_parent_name = "capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf.PrefixList')])),
                                            ])
                                            self.prefix_list = []
                                            self._segment_path = lambda: "orf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                        class PrefixList(Enum):
                                            """
                                            PrefixList (Enum Class)

                                            Advertise prefix list ORF capability to this neighbor

                                            .. data:: both = 0

                                            .. data:: receive = 1

                                            .. data:: send = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            receive = Enum.YLeaf(1, "receive")

                                            send = Enum.YLeaf(2, "send")



                                class DefaultOriginate(Entity):
                                    """
                                    Originate default route to this neighbor
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria to originate default
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate, self).__init__()

                                        self.yang_name = "default-originate"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "default-originate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf, ['all'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Network(Entity):
                                """
                                Specify a network to announce via BGP
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_map
                                
                                	Route\-map to modify the attributes
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Network, self).__init__()

                                    self.yang_name = "network"
                                    self.yang_parent_name = "nsap"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.number = None
                                    self.route_map = None
                                    self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Network, ['number', 'route_map'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "nsap"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord, ['context_word'], name, value)


                    class L2vpn(Entity):
                        """
                        Address family
                        
                        .. attribute:: af_name  (key)
                        
                        	
                        	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.AfName>`
                        
                        .. attribute:: l2vpn_evpn
                        
                        	L2VPN EVPN address family
                        	**type**\:  :py:class:`L2vpnEvpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn>`
                        
                        .. attribute:: l2vpn_vpls
                        
                        	L2VPN VPLS address family
                        	**type**\:  :py:class:`L2vpnVpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn, self).__init__()

                            self.yang_name = "l2vpn"
                            self.yang_parent_name = "no-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("l2vpn-evpn", ("l2vpn_evpn", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn)), ("l2vpn-vpls", ("l2vpn_vpls", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.AfName')])),
                            ])
                            self.af_name = None

                            self.l2vpn_evpn = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn()
                            self.l2vpn_evpn.parent = self
                            self._children_name_map["l2vpn_evpn"] = "l2vpn-evpn"

                            self.l2vpn_vpls = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls()
                            self.l2vpn_vpls.parent = self
                            self._children_name_map["l2vpn_vpls"] = "l2vpn-vpls"
                            self._segment_path = lambda: "l2vpn" + "[af-name='" + str(self.af_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn, ['af_name'], name, value)

                        class AfName(Enum):
                            """
                            AfName (Enum Class)

                            .. data:: evpn = 0

                            .. data:: vpls = 1

                            """

                            evpn = Enum.YLeaf(0, "evpn")

                            vpls = Enum.YLeaf(1, "vpls")



                        class L2vpnEvpn(Entity):
                            """
                            L2VPN EVPN address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation>`
                            
                            .. attribute:: default_metric
                            
                            	Set metric of redistributed routes
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor>`
                            
                            .. attribute:: activate
                            
                            	Enable the address family for this neighbor
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: advertisement_interval
                            
                            	Minimum interval between sending BGP routing updates
                            	**type**\: int
                            
                            	**range:** 0..600
                            
                            .. attribute:: allow_policy
                            
                            	Enable the policy support for this IBGP Neighbor
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: allowas_in
                            
                            	Accept as\-path with my AS present in it
                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: capability
                            
                            	Advertise capability to the peer
                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability>`
                            
                            .. attribute:: inherit
                            
                            	Inherit a template
                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit>`
                            
                            .. attribute:: maximum_prefix
                            
                            	Maximum number of prefixes accepted from this peer
                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix>`
                            
                            .. attribute:: next_hop_self
                            
                            	Disable the next hop calculation for this neighbor
                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: next_hop_unchanged
                            
                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: remove_private_as
                            
                            	Remove private AS number from outbound updates
                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: route_map
                            
                            	Apply route map to neighbor
                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap>`
                            
                            .. attribute:: route_reflector_client
                            
                            	Configure a neighbor as Route Reflector client
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: send_community
                            
                            	Send Community attribute to this neighbor
                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: slow_peer
                            
                            	Configure slow\-peer
                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer>`
                            
                            .. attribute:: soft_reconfiguration
                            
                            	Per neighbor soft reconfiguration
                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SoftReconfiguration>`
                            
                            .. attribute:: soo
                            
                            	ASN\:nn or IP\-address\:nn VPN extended community
                            	**type**\: str
                            
                            .. attribute:: unsuppress_map
                            
                            	Route\-map to selectively unsuppress suppressed routes
                            	**type**\: str
                            
                            .. attribute:: weight
                            
                            	Set default weight for routes from this neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: network
                            
                            	
                            	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn, self).__init__()

                                self.yang_name = "l2vpn-evpn"
                                self.yang_parent_name = "l2vpn"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer)), ("network", ("network", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp))])
                                self._leafs = OrderedDict([
                                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SoftReconfiguration')])),
                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                ])
                                self.default_metric = None
                                self.activate = None
                                self.advertisement_interval = None
                                self.allow_policy = None
                                self.next_hop_unchanged = None
                                self.route_reflector_client = None
                                self.soft_reconfiguration = None
                                self.soo = None
                                self.unsuppress_map = None
                                self.weight = None

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.default_information = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.maximum_paths = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths()
                                self.maximum_paths.parent = self
                                self._children_name_map["maximum_paths"] = "maximum-paths"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.allowas_in = None
                                self._children_name_map["allowas_in"] = "allowas-in"

                                self.capability = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability()
                                self.capability.parent = self
                                self._children_name_map["capability"] = "capability"

                                self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit()
                                self.inherit.parent = self
                                self._children_name_map["inherit"] = "inherit"

                                self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix()
                                self.maximum_prefix.parent = self
                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                self.next_hop_self = None
                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                self.remove_private_as = None
                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                self.send_community = None
                                self._children_name_map["send_community"] = "send-community"

                                self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer()
                                self.slow_peer.parent = self
                                self._children_name_map["slow_peer"] = "slow-peer"

                                self.network = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network()
                                self.network.parent = self
                                self._children_name_map["network"] = "network"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self.route_map = YList(self)
                                self._segment_path = lambda: "l2vpn-evpn"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn, ['default_metric', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                            class SoftReconfiguration(Enum):
                                """
                                SoftReconfiguration (Enum Class)

                                Per neighbor soft reconfiguration

                                .. data:: inbound = 0

                                """

                                inbound = Enum.YLeaf(0, "inbound")



                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: additional_paths
                                
                                	Additional paths in the BGP table
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths>`
                                
                                .. attribute:: default
                                
                                	Configure BGP defaults
                                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths)), ("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default))])
                                    self._leafs = OrderedDict()

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.default = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_, [], name, value)


                                class AdditionalPaths(Entity):
                                    """
                                    Additional paths in the BGP table
                                    
                                    .. attribute:: install
                                    
                                    	Additional paths to install into RIB
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: select
                                    
                                    	Selection criteria to pick the paths
                                    	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to neighbors
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.install = None
                                        self.receive = None

                                        self.select = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select()
                                        self.select.parent = self
                                        self._children_name_map["select"] = "select"

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                    class Select(Entity):
                                        """
                                        Selection criteria to pick the paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: backup
                                        
                                        	Select backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Select best\-external path
                                        	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best path
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select, self).__init__()

                                            self.yang_name = "select"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.best_external = None
                                            self._children_name_map["best_external"] = "best-external"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "select"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best path
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best path
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                        class Backup(Entity):
                                            """
                                            Select backup path
                                            
                                            .. attribute:: best_external
                                            
                                            	Select best\-external path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                self._leafs = OrderedDict()

                                                self.range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                            class Range(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                    self.yang_name = "range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                        class BestExternal(Entity):
                                            """
                                            Select best\-external path
                                            
                                            .. attribute:: backup
                                            
                                            	Select backup path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                self.yang_name = "best-external"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                ])
                                                self.backup = None
                                                self._segment_path = lambda: "best-external"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best path
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "select"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to neighbors
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                class Default(Entity):
                                    """
                                    Configure BGP defaults
                                    
                                    .. attribute:: route_target
                                    
                                    	Control behavior based on Route\-Target attributes
                                    	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default.RouteTarget>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default.RouteTarget')])),
                                        ])
                                        self.route_target = None
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default, ['route_target'], name, value)

                                    class RouteTarget(Enum):
                                        """
                                        RouteTarget (Enum Class)

                                        Control behavior based on Route\-Target attributes

                                        .. data:: filter = 0

                                        """

                                        filter = Enum.YLeaf(0, "filter")



                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                    ])
                                    self.originate = None
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation, ['originate'], name, value)


                            class MaximumPaths(Entity):
                                """
                                Forward packets over multiple paths
                                
                                .. attribute:: ebgp
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: eibgp
                                
                                	Both eBGP and iBGP paths as multipath
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: ibgp
                                
                                	iBGP\-multipath
                                	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp>`
                                
                                .. attribute:: external_rtfilter
                                
                                	VPN prefix multipath on external RT\-Filter peers
                                	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths, self).__init__()

                                    self.yang_name = "maximum-paths"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter))])
                                    self._leafs = OrderedDict([
                                        ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                        ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                    ])
                                    self.ebgp = None
                                    self.eibgp = None

                                    self.ibgp = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"

                                    self.external_rtfilter = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter()
                                    self.external_rtfilter.parent = self
                                    self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                    self._segment_path = lambda: "maximum-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                class Ibgp(Entity):
                                    """
                                    iBGP\-multipath
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Perform un\-equal cost multipath selection
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.unequal_cost = None
                                        self.max = None
                                        self._segment_path = lambda: "ibgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                class ExternalRtfilter(Entity):
                                    """
                                    VPN prefix multipath on external RT\-Filter peers
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter, self).__init__()

                                        self.yang_name = "external-rtfilter"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.max = None
                                        self._segment_path = lambda: "external-rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: additional_paths
                                    
                                    	
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths>`
                                    
                                    .. attribute:: advertise
                                    
                                    	Advertise to this neighbor
                                    	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList>`
                                    
                                    .. attribute:: dmzlink_bw
                                    
                                    	Propagate the DMZ link bandwidth
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: encap
                                    
                                    	Preferred encapsulation for neighbor
                                    	**type**\:  :py:class:`Encap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap>`
                                    
                                    .. attribute:: filter_list
                                    
                                    	Establish BGP filters
                                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	Member of the peer\-group
                                    	**type**\:  :py:class:`PeerGroup_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Filter updates to/from this neighbor
                                    	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList)), ("encap", ("encap", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.dmzlink_bw = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise()
                                        self.advertise.parent = self
                                        self._children_name_map["advertise"] = "advertise"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.encap = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap()
                                        self.encap.parent = self
                                        self._children_name_map["encap"] = "encap"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.peer_group = None
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.distribute_list = YList(self)
                                        self.filter_list = YList(self)
                                        self.prefix_list = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AdditionalPaths(Entity):
                                        """
                                        
                                        
                                        .. attribute:: disable
                                        
                                        	Disable additional paths for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from neighbors
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send
                                        
                                        	Send additional paths to this neighbor
                                        	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send))])
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.disable = None
                                            self.receive = None

                                            self.send = None
                                            self._children_name_map["send"] = "send"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                        class Send(Entity):
                                            """
                                            Send additional paths to this neighbor
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send, self).__init__()

                                                self.yang_name = "send"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.receive = None
                                                self._segment_path = lambda: "send"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                    class Advertise(Entity):
                                        """
                                        Advertise to this neighbor
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Advertise additional paths
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                        
                                        .. attribute:: best_external
                                        
                                        	Advertise best\-external (at RRs best\-internal) path
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: diverse_path
                                        
                                        	Advertise diverse path
                                        	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise, self).__init__()

                                            self.yang_name = "advertise"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath))])
                                            self._leafs = OrderedDict([
                                                ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                            ])
                                            self.best_external = None

                                            self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath()
                                            self.diverse_path.parent = self
                                            self._children_name_map["diverse_path"] = "diverse-path"
                                            self._segment_path = lambda: "advertise"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Advertise additional paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                            class All(Entity):
                                                """
                                                Select all available paths
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.best = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.group_best = None
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "all"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.all = None

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "best-range"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.all = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.all = None
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                        class DiversePath(Entity):
                                            """
                                            Advertise diverse path
                                            
                                            .. attribute:: backup
                                            
                                            	Diverse path can be backup path
                                            	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                self.yang_name = "diverse-path"
                                                self.yang_parent_name = "advertise"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None

                                                self.backup = None
                                                self._children_name_map["backup"] = "backup"
                                                self._segment_path = lambda: "diverse-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                            class Backup(Entity):
                                                """
                                                Diverse path can be backup path
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                    self.yang_name = "backup"
                                                    self.yang_parent_name = "diverse-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None
                                                    self._segment_path = lambda: "backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList.Inout>`
                                        
                                        .. attribute:: accesslist
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 1300..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                            ])
                                            self.inout = None
                                            self.accesslist = None
                                            self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Encap(Entity):
                                        """
                                        Preferred encapsulation for neighbor
                                        
                                        .. attribute:: mpls
                                        
                                        	Neighbor prefers MPLS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: vxlan
                                        
                                        	Neighbor prefers VxLAN
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap, self).__init__()

                                            self.yang_name = "encap"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                                ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                            ])
                                            self.mpls = None
                                            self.vxlan = None
                                            self._segment_path = lambda: "encap"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap, ['mpls', 'vxlan'], name, value)


                                    class FilterList(Entity):
                                        """
                                        Establish BGP filters
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList.Inout>`
                                        
                                        .. attribute:: as_path_list
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..500
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList, self).__init__()

                                            self.yang_name = "filter-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList.Inout')])),
                                                ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                            ])
                                            self.inout = None
                                            self.as_path_list = None
                                            self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class PeerGroup_(Entity):
                                        """
                                        Member of the peer\-group
                                        
                                        .. attribute:: peer_group_name
                                        
                                        	peer\-group name
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                            ])
                                            self.peer_group_name = None
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_, ['peer_group_name'], name, value)


                                    class PrefixList(Entity):
                                        """
                                        Filter updates to/from this neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList.Inout>`
                                        
                                        .. attribute:: prefix_list_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList, self).__init__()

                                            self.yang_name = "prefix-list"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.prefix_list_name = None
                                            self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: additional_paths
                                
                                	
                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths>`
                                
                                .. attribute:: advertise
                                
                                	Advertise to this neighbor
                                	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: distribute_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList>`
                                
                                .. attribute:: dmzlink_bw
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: encap
                                
                                	Preferred encapsulation for neighbor
                                	**type**\:  :py:class:`Encap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap>`
                                
                                .. attribute:: filter_list
                                
                                	Establish BGP filters
                                	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: peer_group
                                
                                	Member of the peer\-group
                                	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: prefix_list
                                
                                	Filter updates to/from this neighbor
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList)), ("encap", ("encap", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap)), ("filter-list", ("filter_list", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup)), ("prefix-list", ("prefix_list", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.dmzlink_bw = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths()
                                    self.additional_paths.parent = self
                                    self._children_name_map["additional_paths"] = "additional-paths"

                                    self.advertise = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise()
                                    self.advertise.parent = self
                                    self._children_name_map["advertise"] = "advertise"

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.encap = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap()
                                    self.encap.parent = self
                                    self._children_name_map["encap"] = "encap"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.peer_group = None
                                    self._children_name_map["peer_group"] = "peer-group"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.distribute_list = YList(self)
                                    self.filter_list = YList(self)
                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AdditionalPaths(Entity):
                                    """
                                    
                                    
                                    .. attribute:: disable
                                    
                                    	Disable additional paths for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: receive
                                    
                                    	Receive additional paths from neighbors
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send
                                    
                                    	Send additional paths to this neighbor
                                    	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths, self).__init__()

                                        self.yang_name = "additional-paths"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send))])
                                        self._leafs = OrderedDict([
                                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                        ])
                                        self.disable = None
                                        self.receive = None

                                        self.send = None
                                        self._children_name_map["send"] = "send"
                                        self._segment_path = lambda: "additional-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                    class Send(Entity):
                                        """
                                        Send additional paths to this neighbor
                                        
                                        .. attribute:: receive
                                        
                                        	Receive additional paths from this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send, self).__init__()

                                            self.yang_name = "send"
                                            self.yang_parent_name = "additional-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                            ])
                                            self.receive = None
                                            self._segment_path = lambda: "send"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                class Advertise(Entity):
                                    """
                                    Advertise to this neighbor
                                    
                                    .. attribute:: additional_paths
                                    
                                    	Advertise additional paths
                                    	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths>`
                                    
                                    .. attribute:: best_external
                                    
                                    	Advertise best\-external (at RRs best\-internal) path
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: diverse_path
                                    
                                    	Advertise diverse path
                                    	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise, self).__init__()

                                        self.yang_name = "advertise"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath))])
                                        self._leafs = OrderedDict([
                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                        ])
                                        self.best_external = None

                                        self.additional_paths = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths()
                                        self.additional_paths.parent = self
                                        self._children_name_map["additional_paths"] = "additional-paths"

                                        self.diverse_path = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath()
                                        self.diverse_path.parent = self
                                        self._children_name_map["diverse_path"] = "diverse-path"
                                        self._segment_path = lambda: "advertise"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise, ['best_external'], name, value)


                                    class AdditionalPaths(Entity):
                                        """
                                        Advertise additional paths
                                        
                                        .. attribute:: all
                                        
                                        	Select all available paths
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: best
                                        
                                        	Select best N paths
                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best>`
                                        
                                        .. attribute:: group_best
                                        
                                        	Select group\-best paths
                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                            self.yang_name = "additional-paths"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"

                                            self.best = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best()
                                            self.best.parent = self
                                            self._children_name_map["best"] = "best"

                                            self.group_best = None
                                            self._children_name_map["group_best"] = "group-best"
                                            self._segment_path = lambda: "additional-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                        class All(Entity):
                                            """
                                            Select all available paths
                                            
                                            .. attribute:: best
                                            
                                            	Select best N paths
                                            	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                            
                                            .. attribute:: group_best
                                            
                                            	Select group\-best paths
                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.best = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                self.best.parent = self
                                                self._children_name_map["best"] = "best"

                                                self.group_best = None
                                                self._children_name_map["group_best"] = "group-best"
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                            class Best(Entity):
                                                """
                                                Select best N paths
                                                
                                                .. attribute:: best_range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                    self.yang_name = "best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                    self._leafs = OrderedDict()

                                                    self.best_range = YList(self)
                                                    self._segment_path = lambda: "best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                class BestRange(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                        self.yang_name = "best-range"
                                                        self.yang_parent_name = "best"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                        ])
                                                        self.range = None
                                                        self.group_best = None
                                                        self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                            class GroupBest(Entity):
                                                """
                                                Select group\-best paths
                                                
                                                .. attribute:: best
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                    self.yang_name = "group-best"
                                                    self.yang_parent_name = "all"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                    ])
                                                    self.best = None
                                                    self._segment_path = lambda: "group-best"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                        class Best(Entity):
                                            """
                                            Select best N paths
                                            
                                            .. attribute:: best_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                self.yang_name = "best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                self._leafs = OrderedDict()

                                                self.best_range = YList(self)
                                                self._segment_path = lambda: "best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                            class BestRange(Entity):
                                                """
                                                
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Number of best paths in additional paths to be selected
                                                	**type**\: int
                                                
                                                	**range:** 2..3
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                    self.yang_name = "best-range"
                                                    self.yang_parent_name = "best"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.range = None
                                                    self.all = None

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "best-range"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                        ])
                                                        self.all = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                        class GroupBest(Entity):
                                            """
                                            Select group\-best paths
                                            
                                            .. attribute:: all
                                            
                                            	Select all available paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: best
                                            
                                            	Number of best paths in additional paths to be selected
                                            	**type**\: int
                                            
                                            	**range:** 2..3
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                self.yang_name = "group-best"
                                                self.yang_parent_name = "additional-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                ])
                                                self.all = None
                                                self.best = None
                                                self._segment_path = lambda: "group-best"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                    class DiversePath(Entity):
                                        """
                                        Advertise diverse path
                                        
                                        .. attribute:: backup
                                        
                                        	Diverse path can be backup path
                                        	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: mpath
                                        
                                        	Diverse path can be multipath
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath, self).__init__()

                                            self.yang_name = "diverse-path"
                                            self.yang_parent_name = "advertise"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup))])
                                            self._leafs = OrderedDict([
                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                            ])
                                            self.mpath = None

                                            self.backup = None
                                            self._children_name_map["backup"] = "backup"
                                            self._segment_path = lambda: "diverse-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                        class Backup(Entity):
                                            """
                                            Diverse path can be backup path
                                            
                                            .. attribute:: mpath
                                            
                                            	Diverse path can be multipath
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "diverse-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                ])
                                                self.mpath = None
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn, ['as_number'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList.Inout>`
                                    
                                    .. attribute:: accesslist
                                    
                                    	
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1..199
                                    
                                    		**type**\: int
                                    
                                    			**range:** 1300..2699
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** [a\-zA\-Z].\*
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList.Inout')])),
                                            ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                        ])
                                        self.inout = None
                                        self.accesslist = None
                                        self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Encap(Entity):
                                    """
                                    Preferred encapsulation for neighbor
                                    
                                    .. attribute:: mpls
                                    
                                    	Neighbor prefers MPLS
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: vxlan
                                    
                                    	Neighbor prefers VxLAN
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap, self).__init__()

                                        self.yang_name = "encap"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                            ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                        ])
                                        self.mpls = None
                                        self.vxlan = None
                                        self._segment_path = lambda: "encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap, ['mpls', 'vxlan'], name, value)


                                class FilterList(Entity):
                                    """
                                    Establish BGP filters
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList.Inout>`
                                    
                                    .. attribute:: as_path_list
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..500
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList, self).__init__()

                                        self.yang_name = "filter-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList.Inout')])),
                                            ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                        ])
                                        self.inout = None
                                        self.as_path_list = None
                                        self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf, ['all'], name, value)


                                class PeerGroup(Entity):
                                    """
                                    Member of the peer\-group
                                    
                                    .. attribute:: peer_group_name
                                    
                                    	peer\-group name
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup, self).__init__()

                                        self.yang_name = "peer-group"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                        ])
                                        self.peer_group_name = None
                                        self._segment_path = lambda: "peer-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter updates to/from this neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList.Inout>`
                                    
                                    .. attribute:: prefix_list_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList.Inout')])),
                                            ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.prefix_list_name = None
                                        self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class AllowasIn(Entity):
                                """
                                Accept as\-path with my AS present in it
                                
                                .. attribute:: as_number
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..10
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn, self).__init__()

                                    self.yang_name = "allowas-in"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                    ])
                                    self.as_number = None
                                    self._segment_path = lambda: "allowas-in"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn, ['as_number'], name, value)


                            class Capability(Entity):
                                """
                                Advertise capability to the peer
                                
                                .. attribute:: orf
                                
                                	Advertise ORF capability to the peer
                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability, self).__init__()

                                    self.yang_name = "capability"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf))])
                                    self._leafs = OrderedDict()

                                    self.orf = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf()
                                    self.orf.parent = self
                                    self._children_name_map["orf"] = "orf"
                                    self._segment_path = lambda: "capability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability, [], name, value)


                                class Orf(Entity):
                                    """
                                    Advertise ORF capability to the peer
                                    
                                    .. attribute:: prefix_list
                                    
                                    	Advertise prefix list ORF capability to this neighbor
                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf.PrefixList>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf, self).__init__()

                                        self.yang_name = "orf"
                                        self.yang_parent_name = "capability"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf.PrefixList')])),
                                        ])
                                        self.prefix_list = []
                                        self._segment_path = lambda: "orf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf, ['prefix_list'], name, value)

                                    class PrefixList(Enum):
                                        """
                                        PrefixList (Enum Class)

                                        Advertise prefix list ORF capability to this neighbor

                                        .. data:: both = 0

                                        .. data:: receive = 1

                                        .. data:: send = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        receive = Enum.YLeaf(1, "receive")

                                        send = Enum.YLeaf(2, "send")



                            class Inherit(Entity):
                                """
                                Inherit a template
                                
                                .. attribute:: peer_policy
                                
                                	Inherit a peer\-policy template
                                	**type**\: str
                                
                                .. attribute:: peer_session
                                
                                	Inherit a peer\-session template
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit, self).__init__()

                                    self.yang_name = "inherit"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                    ])
                                    self.peer_policy = None
                                    self.peer_session = None
                                    self._segment_path = lambda: "inherit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit, ['peer_policy', 'peer_session'], name, value)


                            class MaximumPrefix(Entity):
                                """
                                Maximum number of prefixes accepted from this peer
                                
                                .. attribute:: max_prefix_no
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..2147483647
                                
                                .. attribute:: threshold
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: restart
                                
                                	Restart bgp connection after limit is exceeded
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: warning_only
                                
                                	Only give warning message when limit is exceeded
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix, self).__init__()

                                    self.yang_name = "maximum-prefix"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                    ])
                                    self.max_prefix_no = None
                                    self.threshold = None
                                    self.restart = None
                                    self.warning_only = None
                                    self._segment_path = lambda: "maximum-prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                            class NextHopSelf(Entity):
                                """
                                Disable the next hop calculation for this neighbor
                                
                                .. attribute:: all
                                
                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf, self).__init__()

                                    self.yang_name = "next-hop-self"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                    ])
                                    self.all = None
                                    self._segment_path = lambda: "next-hop-self"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf, ['all'], name, value)


                            class RemovePrivateAs(Entity):
                                """
                                Remove private AS number from outbound updates
                                
                                .. attribute:: all
                                
                                	Remove all private AS numbers
                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs, self).__init__()

                                    self.yang_name = "remove-private-as"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.all = None
                                    self._children_name_map["all"] = "all"
                                    self._segment_path = lambda: "remove-private-as"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs, [], name, value)


                                class All(Entity):
                                    """
                                    Remove all private AS numbers
                                    
                                    .. attribute:: replace_as
                                    
                                    	Replace all private AS numbers with local AS
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All, self).__init__()

                                        self.yang_name = "all"
                                        self.yang_parent_name = "remove-private-as"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                        ])
                                        self.replace_as = None
                                        self._segment_path = lambda: "all"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All, ['replace_as'], name, value)


                            class RouteMap(Entity):
                                """
                                Apply route map to neighbor
                                
                                .. attribute:: inout  (key)
                                
                                	
                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap.Inout>`
                                
                                .. attribute:: route_map_name
                                
                                	
                                	**type**\: str
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap, self).__init__()

                                    self.yang_name = "route-map"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['inout']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap.Inout')])),
                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                    ])
                                    self.inout = None
                                    self.route_map_name = None
                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap, ['inout', 'route_map_name'], name, value)

                                class Inout(Enum):
                                    """
                                    Inout (Enum Class)

                                    .. data:: in_ = 0

                                    .. data:: out = 1

                                    """

                                    in_ = Enum.YLeaf(0, "in")

                                    out = Enum.YLeaf(1, "out")



                            class SendCommunity(Entity):
                                """
                                Send Community attribute to this neighbor
                                
                                .. attribute:: send_community_where
                                
                                	
                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity.SendCommunityWhere>`
                                
                                	**default value**\: standard
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity, self).__init__()

                                    self.yang_name = "send-community"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity.SendCommunityWhere')])),
                                    ])
                                    self.send_community_where = None
                                    self._segment_path = lambda: "send-community"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity, ['send_community_where'], name, value)

                                class SendCommunityWhere(Enum):
                                    """
                                    SendCommunityWhere (Enum Class)

                                    .. data:: both = 0

                                    .. data:: extended = 1

                                    .. data:: standard = 2

                                    """

                                    both = Enum.YLeaf(0, "both")

                                    extended = Enum.YLeaf(1, "extended")

                                    standard = Enum.YLeaf(2, "standard")



                            class SlowPeer(Entity):
                                """
                                Configure slow\-peer
                                
                                .. attribute:: detection
                                
                                	Slow\-peer detection
                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: split_update_group
                                
                                	Configure slow\-peer split\-update\-group
                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer, self).__init__()

                                    self.yang_name = "slow-peer"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup))])
                                    self._leafs = OrderedDict()

                                    self.detection = None
                                    self._children_name_map["detection"] = "detection"

                                    self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup()
                                    self.split_update_group.parent = self
                                    self._children_name_map["split_update_group"] = "split-update-group"
                                    self._segment_path = lambda: "slow-peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer, [], name, value)


                                class Detection(Entity):
                                    """
                                    Slow\-peer detection
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold value (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 120..3600
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection, self).__init__()

                                        self.yang_name = "detection"
                                        self.yang_parent_name = "slow-peer"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                        ])
                                        self.threshold = None
                                        self._segment_path = lambda: "detection"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection, ['threshold'], name, value)


                                class SplitUpdateGroup(Entity):
                                    """
                                    Configure slow\-peer split\-update\-group
                                    
                                    .. attribute:: dynamic
                                    
                                    	Dynamically split the slow peer to slow\-update group
                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup, self).__init__()

                                        self.yang_name = "split-update-group"
                                        self.yang_parent_name = "slow-peer"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic))])
                                        self._leafs = OrderedDict()

                                        self.dynamic = None
                                        self._children_name_map["dynamic"] = "dynamic"
                                        self._segment_path = lambda: "split-update-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup, [], name, value)


                                    class Dynamic(Entity):
                                        """
                                        Dynamically split the slow peer to slow\-update group
                                        
                                        .. attribute:: permanent
                                        
                                        	Keep the slow\-peer permanently in slow\-update group
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                            self.yang_name = "dynamic"
                                            self.yang_parent_name = "split-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                            ])
                                            self.permanent = None
                                            self._segment_path = lambda: "dynamic"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Network(Entity):
                                """
                                
                                
                                .. attribute:: with_mask
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask>`
                                
                                .. attribute:: no_mask
                                
                                	Specify a network to announce via BGP
                                	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network, self).__init__()

                                    self.yang_name = "network"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask))])
                                    self._leafs = OrderedDict()

                                    self.with_mask = YList(self)
                                    self.no_mask = YList(self)
                                    self._segment_path = lambda: "network"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network, [], name, value)


                                class WithMask(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mask  (key)
                                    
                                    	Network mask
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask, self).__init__()

                                        self.yang_name = "with-mask"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number','mask']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.mask = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor'], name, value)


                                class NoMask(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: number  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to modify the attributes
                                    	**type**\: str
                                    
                                    .. attribute:: backdoor
                                    
                                    	Specify a BGP backdoor route
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask, self).__init__()

                                        self.yang_name = "no-mask"
                                        self.yang_parent_name = "network"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                        ])
                                        self.number = None
                                        self.route_map = None
                                        self.backdoor = None
                                        self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask, ['number', 'route_map', 'backdoor'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "l2vpn-evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord, ['context_word'], name, value)


                        class L2vpnVpls(Entity):
                            """
                            L2VPN VPLS address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_>`
                            
                            .. attribute:: default_information
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls, self).__init__()

                                self.yang_name = "l2vpn-vpls"
                                self.yang_parent_name = "l2vpn"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.default_information = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "l2vpn-vpls"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls, [], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: default
                                
                                	Configure BGP defaults
                                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default>`
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval
                                	**type**\: int
                                
                                	**range:** 5..60
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "l2vpn-vpls"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("default", ("default", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                    ])
                                    self.scan_time = None

                                    self.default = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default()
                                    self.default.parent = self
                                    self._children_name_map["default"] = "default"

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_, ['scan_time'], name, value)


                                class Default(Entity):
                                    """
                                    Configure BGP defaults
                                    
                                    .. attribute:: route_target
                                    
                                    	Control behavior based on Route\-Target attributes
                                    	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default.RouteTarget>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default, self).__init__()

                                        self.yang_name = "default"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default.RouteTarget')])),
                                        ])
                                        self.route_target = None
                                        self._segment_path = lambda: "default"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default, ['route_target'], name, value)

                                    class RouteTarget(Enum):
                                        """
                                        RouteTarget (Enum Class)

                                        Control behavior based on Route\-Target attributes

                                        .. data:: filter = 0

                                        """

                                        filter = Enum.YLeaf(0, "filter")



                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class DefaultInformation(Entity):
                                """
                                Control distribution of default information
                                
                                .. attribute:: originate
                                
                                	Distribute a default route
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation, self).__init__()

                                    self.yang_name = "default-information"
                                    self.yang_parent_name = "l2vpn-vpls"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                    ])
                                    self.originate = None
                                    self._segment_path = lambda: "default-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation, ['originate'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "l2vpn-vpls"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.capability = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: capability
                                
                                	Advertise capability to the peer
                                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability>`
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: unsuppress_map
                                
                                	Route\-map to selectively unsuppress suppressed routes
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "l2vpn-vpls"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.unsuppress_map = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.capability = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability()
                                    self.capability.parent = self
                                    self._children_name_map["capability"] = "capability"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Capability(Entity):
                                    """
                                    Advertise capability to the peer
                                    
                                    .. attribute:: orf
                                    
                                    	Advertise ORF capability to the peer
                                    	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability, self).__init__()

                                        self.yang_name = "capability"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf))])
                                        self._leafs = OrderedDict()

                                        self.orf = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf()
                                        self.orf.parent = self
                                        self._children_name_map["orf"] = "orf"
                                        self._segment_path = lambda: "capability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability, [], name, value)


                                    class Orf(Entity):
                                        """
                                        Advertise ORF capability to the peer
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Advertise prefix list ORF capability to this neighbor
                                        	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf.PrefixList>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf, self).__init__()

                                            self.yang_name = "orf"
                                            self.yang_parent_name = "capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf.PrefixList')])),
                                            ])
                                            self.prefix_list = []
                                            self._segment_path = lambda: "orf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                        class PrefixList(Enum):
                                            """
                                            PrefixList (Enum Class)

                                            Advertise prefix list ORF capability to this neighbor

                                            .. data:: both = 0

                                            .. data:: receive = 1

                                            .. data:: send = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            receive = Enum.YLeaf(1, "receive")

                                            send = Enum.YLeaf(2, "send")



                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf, ['all'], name, value)


                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "l2vpn-vpls"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord, ['context_word'], name, value)


                    class Rtfilter(Entity):
                        """
                        Address family
                        
                        .. attribute:: af_name  (key)
                        
                        	
                        	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.AfName>`
                        
                        .. attribute:: rtfilter
                        
                        	RT\-Filter address family
                        	**type**\:  :py:class:`Rtfilter_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter, self).__init__()

                            self.yang_name = "rtfilter"
                            self.yang_parent_name = "no-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("rtfilter", ("rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Rtfilter.AfName')])),
                            ])
                            self.af_name = None

                            self.rtfilter = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_()
                            self.rtfilter.parent = self
                            self._children_name_map["rtfilter"] = "rtfilter"
                            self._segment_path = lambda: "rtfilter" + "[af-name='" + str(self.af_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter, ['af_name'], name, value)

                        class AfName(Enum):
                            """
                            AfName (Enum Class)

                            .. data:: unicast = 0

                            """

                            unicast = Enum.YLeaf(0, "unicast")



                        class Rtfilter_(Entity):
                            """
                            RT\-Filter address family
                            
                            .. attribute:: bgp
                            
                            	
                            	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_>`
                            
                            .. attribute:: maximum_paths
                            
                            	Forward packets over multiple paths
                            	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths>`
                            
                            .. attribute:: peer_group
                            
                            	
                            	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup>`
                            
                            .. attribute:: neighbor
                            
                            	Specify a neighbor router
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor>`
                            
                            .. attribute:: snmp
                            
                            	Modify snmp parameters
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_, self).__init__()

                                self.yang_name = "rtfilter"
                                self.yang_parent_name = "rtfilter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp))])
                                self._leafs = OrderedDict()

                                self.bgp = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_()
                                self.bgp.parent = self
                                self._children_name_map["bgp"] = "bgp"

                                self.maximum_paths = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths()
                                self.maximum_paths.parent = self
                                self._children_name_map["maximum_paths"] = "maximum-paths"

                                self.peer_group = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup()
                                self.peer_group.parent = self
                                self._children_name_map["peer_group"] = "peer-group"

                                self.snmp = None
                                self._children_name_map["snmp"] = "snmp"

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "rtfilter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_, [], name, value)


                            class Bgp_(Entity):
                                """
                                
                                
                                .. attribute:: nexthop
                                
                                	Nexthop tracking commands
                                	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop>`
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "rtfilter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("nexthop", ("nexthop", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer))])
                                    self._leafs = OrderedDict()

                                    self.nexthop = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"
                                    self._segment_path = lambda: "bgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_, [], name, value)


                                class Nexthop(Entity):
                                    """
                                    Nexthop tracking commands
                                    
                                    .. attribute:: trigger
                                    
                                    	Nexthop triggering
                                    	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map for valid nexthops
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop, self).__init__()

                                        self.yang_name = "nexthop"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.trigger = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger()
                                        self.trigger.parent = self
                                        self._children_name_map["trigger"] = "trigger"
                                        self._segment_path = lambda: "nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop, ['route_map'], name, value)


                                    class Trigger(Entity):
                                        """
                                        Nexthop triggering
                                        
                                        .. attribute:: delay
                                        
                                        	Set the delay to trigger nexthop tracking
                                        	**type**\: int
                                        
                                        	**range:** 0..100
                                        
                                        .. attribute:: enable
                                        
                                        	Enable nexthop tracking
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger, self).__init__()

                                            self.yang_name = "trigger"
                                            self.yang_parent_name = "nexthop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ])
                                            self.delay = None
                                            self.enable = None
                                            self._segment_path = lambda: "trigger"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: disable
                                        
                                        	Disable slow\-peer detection
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.disable = None
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class MaximumPaths(Entity):
                                """
                                Forward packets over multiple paths
                                
                                .. attribute:: ebgp
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: eibgp
                                
                                	Both eBGP and iBGP paths as multipath
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: ibgp
                                
                                	iBGP\-multipath
                                	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp>`
                                
                                .. attribute:: external_rtfilter
                                
                                	VPN prefix multipath on external RT\-Filter peers
                                	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths, self).__init__()

                                    self.yang_name = "maximum-paths"
                                    self.yang_parent_name = "rtfilter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter))])
                                    self._leafs = OrderedDict([
                                        ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                        ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                    ])
                                    self.ebgp = None
                                    self.eibgp = None

                                    self.ibgp = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"

                                    self.external_rtfilter = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter()
                                    self.external_rtfilter.parent = self
                                    self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                    self._segment_path = lambda: "maximum-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                class Ibgp(Entity):
                                    """
                                    iBGP\-multipath
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Perform un\-equal cost multipath selection
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.unequal_cost = None
                                        self.max = None
                                        self._segment_path = lambda: "ibgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                class ExternalRtfilter(Entity):
                                    """
                                    VPN prefix multipath on external RT\-Filter peers
                                    
                                    .. attribute:: max
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..32
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter, self).__init__()

                                        self.yang_name = "external-rtfilter"
                                        self.yang_parent_name = "maximum-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                        ])
                                        self.max = None
                                        self._segment_path = lambda: "external-rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                            class PeerGroup(Entity):
                                """
                                
                                
                                .. attribute:: neighbor
                                
                                	Specify a neighbor router
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "rtfilter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Specify a neighbor router
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability>`
                                    
                                    .. attribute:: default_originate
                                    
                                    	Originate default route to this neighbor
                                    	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "peer-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.id = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.weight = None

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.default_originate = None
                                        self._children_name_map["default_originate"] = "default-originate"

                                        self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class DefaultOriginate(Entity):
                                        """
                                        Originate default route to this neighbor
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to specify criteria to originate default
                                        	**type**\: str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                            self.yang_name = "default-originate"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None
                                            self._segment_path = lambda: "default-originate"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Neighbor(Entity):
                                """
                                Specify a neighbor router
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: activate
                                
                                	Enable the address family for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\: int
                                
                                	**range:** 0..600
                                
                                .. attribute:: allow_policy
                                
                                	Enable the policy support for this IBGP Neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: allowas_in
                                
                                	Accept as\-path with my AS present in it
                                	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: capability
                                
                                	Advertise capability to the peer
                                	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability>`
                                
                                .. attribute:: default_originate
                                
                                	Originate default route to this neighbor
                                	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: inherit
                                
                                	Inherit a template
                                	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit>`
                                
                                .. attribute:: maximum_prefix
                                
                                	Maximum number of prefixes accepted from this peer
                                	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix>`
                                
                                .. attribute:: next_hop_self
                                
                                	Disable the next hop calculation for this neighbor
                                	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_unchanged
                                
                                	Propagate the iBGP paths' next hop unchanged for this neighbor
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS number from outbound updates
                                	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: route_map
                                
                                	Apply route map to neighbor
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap>`
                                
                                .. attribute:: route_reflector_client
                                
                                	Configure a neighbor as Route Reflector client
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_community
                                
                                	Send Community attribute to this neighbor
                                	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: slow_peer
                                
                                	Configure slow\-peer
                                	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer>`
                                
                                .. attribute:: soft_reconfiguration
                                
                                	Per neighbor soft reconfiguration
                                	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SoftReconfiguration>`
                                
                                .. attribute:: soo
                                
                                	ASN\:nn or IP\-address\:nn VPN extended community
                                	**type**\: str
                                
                                .. attribute:: weight
                                
                                	Set default weight for routes from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "rtfilter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate)), ("inherit", ("inherit", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                        ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                        ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                        ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                        ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                        ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                        ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SoftReconfiguration')])),
                                        ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                        ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                    ])
                                    self.id = None
                                    self.activate = None
                                    self.advertisement_interval = None
                                    self.allow_policy = None
                                    self.next_hop_unchanged = None
                                    self.route_reflector_client = None
                                    self.soft_reconfiguration = None
                                    self.soo = None
                                    self.weight = None

                                    self.allowas_in = None
                                    self._children_name_map["allowas_in"] = "allowas-in"

                                    self.capability = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability()
                                    self.capability.parent = self
                                    self._children_name_map["capability"] = "capability"

                                    self.default_originate = None
                                    self._children_name_map["default_originate"] = "default-originate"

                                    self.inherit = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit()
                                    self.inherit.parent = self
                                    self._children_name_map["inherit"] = "inherit"

                                    self.maximum_prefix = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix()
                                    self.maximum_prefix.parent = self
                                    self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                    self.next_hop_self = None
                                    self._children_name_map["next_hop_self"] = "next-hop-self"

                                    self.remove_private_as = None
                                    self._children_name_map["remove_private_as"] = "remove-private-as"

                                    self.send_community = None
                                    self._children_name_map["send_community"] = "send-community"

                                    self.slow_peer = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer()
                                    self.slow_peer.parent = self
                                    self._children_name_map["slow_peer"] = "slow-peer"

                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'weight'], name, value)

                                class SoftReconfiguration(Enum):
                                    """
                                    SoftReconfiguration (Enum Class)

                                    Per neighbor soft reconfiguration

                                    .. data:: inbound = 0

                                    """

                                    inbound = Enum.YLeaf(0, "inbound")



                                class AllowasIn(Entity):
                                    """
                                    Accept as\-path with my AS present in it
                                    
                                    .. attribute:: as_number
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..10
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn, self).__init__()

                                        self.yang_name = "allowas-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                        ])
                                        self.as_number = None
                                        self._segment_path = lambda: "allowas-in"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn, ['as_number'], name, value)


                                class Capability(Entity):
                                    """
                                    Advertise capability to the peer
                                    
                                    .. attribute:: orf
                                    
                                    	Advertise ORF capability to the peer
                                    	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability, self).__init__()

                                        self.yang_name = "capability"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf))])
                                        self._leafs = OrderedDict()

                                        self.orf = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf()
                                        self.orf.parent = self
                                        self._children_name_map["orf"] = "orf"
                                        self._segment_path = lambda: "capability"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability, [], name, value)


                                    class Orf(Entity):
                                        """
                                        Advertise ORF capability to the peer
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Advertise prefix list ORF capability to this neighbor
                                        	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf.PrefixList>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf, self).__init__()

                                            self.yang_name = "orf"
                                            self.yang_parent_name = "capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf.PrefixList')])),
                                            ])
                                            self.prefix_list = []
                                            self._segment_path = lambda: "orf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                        class PrefixList(Enum):
                                            """
                                            PrefixList (Enum Class)

                                            Advertise prefix list ORF capability to this neighbor

                                            .. data:: both = 0

                                            .. data:: receive = 1

                                            .. data:: send = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            receive = Enum.YLeaf(1, "receive")

                                            send = Enum.YLeaf(2, "send")



                                class DefaultOriginate(Entity):
                                    """
                                    Originate default route to this neighbor
                                    
                                    .. attribute:: route_map
                                    
                                    	Route\-map to specify criteria to originate default
                                    	**type**\: str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate, self).__init__()

                                        self.yang_name = "default-originate"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None
                                        self._segment_path = lambda: "default-originate"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                class Inherit(Entity):
                                    """
                                    Inherit a template
                                    
                                    .. attribute:: peer_policy
                                    
                                    	Inherit a peer\-policy template
                                    	**type**\: str
                                    
                                    .. attribute:: peer_session
                                    
                                    	Inherit a peer\-session template
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit, self).__init__()

                                        self.yang_name = "inherit"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                            ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                        ])
                                        self.peer_policy = None
                                        self.peer_session = None
                                        self._segment_path = lambda: "inherit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                class MaximumPrefix(Entity):
                                    """
                                    Maximum number of prefixes accepted from this peer
                                    
                                    .. attribute:: max_prefix_no
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..2147483647
                                    
                                    .. attribute:: threshold
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: restart
                                    
                                    	Restart bgp connection after limit is exceeded
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: warning_only
                                    
                                    	Only give warning message when limit is exceeded
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix, self).__init__()

                                        self.yang_name = "maximum-prefix"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                            ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                            ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                        ])
                                        self.max_prefix_no = None
                                        self.threshold = None
                                        self.restart = None
                                        self.warning_only = None
                                        self._segment_path = lambda: "maximum-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                class NextHopSelf(Entity):
                                    """
                                    Disable the next hop calculation for this neighbor
                                    
                                    .. attribute:: all
                                    
                                    	Enable next\-hop\-self for both eBGP and iBGP received paths
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf, self).__init__()

                                        self.yang_name = "next-hop-self"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                        ])
                                        self.all = None
                                        self._segment_path = lambda: "next-hop-self"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf, ['all'], name, value)


                                class RemovePrivateAs(Entity):
                                    """
                                    Remove private AS number from outbound updates
                                    
                                    .. attribute:: all
                                    
                                    	Remove all private AS numbers
                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs, self).__init__()

                                        self.yang_name = "remove-private-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.all = None
                                        self._children_name_map["all"] = "all"
                                        self._segment_path = lambda: "remove-private-as"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs, [], name, value)


                                    class All(Entity):
                                        """
                                        Remove all private AS numbers
                                        
                                        .. attribute:: replace_as
                                        
                                        	Replace all private AS numbers with local AS
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All, self).__init__()

                                            self.yang_name = "all"
                                            self.yang_parent_name = "remove-private-as"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                            ])
                                            self.replace_as = None
                                            self._segment_path = lambda: "all"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Apply route map to neighbor
                                    
                                    .. attribute:: inout  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap.Inout>`
                                    
                                    .. attribute:: route_map_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['inout']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap.Inout')])),
                                            ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                        ])
                                        self.inout = None
                                        self.route_map_name = None
                                        self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                    class Inout(Enum):
                                        """
                                        Inout (Enum Class)

                                        .. data:: in_ = 0

                                        .. data:: out = 1

                                        """

                                        in_ = Enum.YLeaf(0, "in")

                                        out = Enum.YLeaf(1, "out")



                                class SendCommunity(Entity):
                                    """
                                    Send Community attribute to this neighbor
                                    
                                    .. attribute:: send_community_where
                                    
                                    	
                                    	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity.SendCommunityWhere>`
                                    
                                    	**default value**\: standard
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity, self).__init__()

                                        self.yang_name = "send-community"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity.SendCommunityWhere')])),
                                        ])
                                        self.send_community_where = None
                                        self._segment_path = lambda: "send-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                    class SendCommunityWhere(Enum):
                                        """
                                        SendCommunityWhere (Enum Class)

                                        .. data:: both = 0

                                        .. data:: extended = 1

                                        .. data:: standard = 2

                                        """

                                        both = Enum.YLeaf(0, "both")

                                        extended = Enum.YLeaf(1, "extended")

                                        standard = Enum.YLeaf(2, "standard")



                                class SlowPeer(Entity):
                                    """
                                    Configure slow\-peer
                                    
                                    .. attribute:: detection
                                    
                                    	Slow\-peer detection
                                    	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: split_update_group
                                    
                                    	Configure slow\-peer split\-update\-group
                                    	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer, self).__init__()

                                        self.yang_name = "slow-peer"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.detection = None
                                        self._children_name_map["detection"] = "detection"

                                        self.split_update_group = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup()
                                        self.split_update_group.parent = self
                                        self._children_name_map["split_update_group"] = "split-update-group"
                                        self._segment_path = lambda: "slow-peer"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer, [], name, value)


                                    class Detection(Entity):
                                        """
                                        Slow\-peer detection
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold value (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 120..3600
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection, self).__init__()

                                            self.yang_name = "detection"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                            ])
                                            self.threshold = None
                                            self._segment_path = lambda: "detection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                    class SplitUpdateGroup(Entity):
                                        """
                                        Configure slow\-peer split\-update\-group
                                        
                                        .. attribute:: dynamic
                                        
                                        	Dynamically split the slow peer to slow\-update group
                                        	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                            self.yang_name = "split-update-group"
                                            self.yang_parent_name = "slow-peer"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                            self._leafs = OrderedDict()

                                            self.dynamic = None
                                            self._children_name_map["dynamic"] = "dynamic"
                                            self._segment_path = lambda: "split-update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                        class Dynamic(Entity):
                                            """
                                            Dynamically split the slow peer to slow\-update group
                                            
                                            .. attribute:: permanent
                                            
                                            	Keep the slow\-peer permanently in slow\-update group
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                self.yang_name = "dynamic"
                                                self.yang_parent_name = "split-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                ])
                                                self.permanent = None
                                                self._segment_path = lambda: "dynamic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                            class Snmp(Entity):
                                """
                                Modify snmp parameters
                                
                                .. attribute:: context
                                
                                	Configure a SNMP context
                                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "rtfilter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.context = Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context()
                                    self.context.parent = self
                                    self._children_name_map["context"] = "context"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp, [], name, value)


                                class Context(Entity):
                                    """
                                    Configure a SNMP context
                                    
                                    .. attribute:: context_word
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord>`
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context, self).__init__()

                                        self.yang_name = "context"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord))])
                                        self._leafs = OrderedDict()

                                        self.context_word = YList(self)
                                        self._segment_path = lambda: "context"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context, [], name, value)


                                    class ContextWord(Entity):
                                        """
                                        
                                        
                                        .. attribute:: context_word  (key)
                                        
                                        	Context Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord, self).__init__()

                                            self.yang_name = "context_word"
                                            self.yang_parent_name = "context"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['context_word']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                            ])
                                            self.context_word = None
                                            self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord, ['context_word'], name, value)


            class Template(Entity):
                """
                Enter template command mode
                
                .. attribute:: peer_policy
                
                	Template configuration for policy parameters
                	**type**\: list of  		 :py:class:`PeerPolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerPolicy>`
                
                .. attribute:: peer_session
                
                	Template configuration for session parameters
                	**type**\: list of  		 :py:class:`PeerSession <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerSession>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Bgp.Template, self).__init__()

                    self.yang_name = "template"
                    self.yang_parent_name = "bgp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("peer-policy", ("peer_policy", Native.Router.Bgp.Template.PeerPolicy)), ("peer-session", ("peer_session", Native.Router.Bgp.Template.PeerSession))])
                    self._leafs = OrderedDict()

                    self.peer_policy = YList(self)
                    self.peer_session = YList(self)
                    self._segment_path = lambda: "template"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Bgp.Template, [], name, value)


                class PeerPolicy(Entity):
                    """
                    Template configuration for policy parameters
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: route_map
                    
                    	Apply route map to neighbor
                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerPolicy.RouteMap>`
                    
                    .. attribute:: filter_list
                    
                    	Establish BGP filters
                    	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerPolicy.FilterList>`
                    
                    .. attribute:: inherit
                    
                    	Inherit a template
                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerPolicy.Inherit>`
                    
                    .. attribute:: encap
                    
                    	Preferred Encapsulation for Neighbor
                    	**type**\:  :py:class:`Encap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerPolicy.Encap>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Template.PeerPolicy, self).__init__()

                        self.yang_name = "peer-policy"
                        self.yang_parent_name = "template"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("route-map", ("route_map", Native.Router.Bgp.Template.PeerPolicy.RouteMap)), ("filter-list", ("filter_list", Native.Router.Bgp.Template.PeerPolicy.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Template.PeerPolicy.Inherit)), ("encap", ("encap", Native.Router.Bgp.Template.PeerPolicy.Encap))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None

                        self.inherit = Native.Router.Bgp.Template.PeerPolicy.Inherit()
                        self.inherit.parent = self
                        self._children_name_map["inherit"] = "inherit"

                        self.encap = Native.Router.Bgp.Template.PeerPolicy.Encap()
                        self.encap.parent = self
                        self._children_name_map["encap"] = "encap"

                        self.route_map = YList(self)
                        self.filter_list = YList(self)
                        self._segment_path = lambda: "peer-policy" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Template.PeerPolicy, ['name'], name, value)


                    class RouteMap(Entity):
                        """
                        Apply route map to neighbor
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	Apply map to incoming routes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Apply map to outgong routes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Template.PeerPolicy.RouteMap, self).__init__()

                            self.yang_name = "route-map"
                            self.yang_parent_name = "peer-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.name = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "route-map" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Template.PeerPolicy.RouteMap, ['name', 'in_', 'out'], name, value)


                    class FilterList(Entity):
                        """
                        Establish BGP filters
                        
                        .. attribute:: filter_range  (key)
                        
                        	AS path access list
                        	**type**\: int
                        
                        	**range:** 1..500
                        
                        .. attribute:: in_
                        
                        	Filter incoming routes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Filter outgoing routes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Template.PeerPolicy.FilterList, self).__init__()

                            self.yang_name = "filter-list"
                            self.yang_parent_name = "peer-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['filter_range']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('filter_range', (YLeaf(YType.uint16, 'filter-range'), ['int'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.filter_range = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "filter-list" + "[filter-range='" + str(self.filter_range) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Template.PeerPolicy.FilterList, ['filter_range', 'in_', 'out'], name, value)


                    class Inherit(Entity):
                        """
                        Inherit a template
                        
                        .. attribute:: peer_policy
                        
                        	
                        	**type**\:  :py:class:`PeerPolicy_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerPolicy.Inherit.PeerPolicy_>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Template.PeerPolicy.Inherit, self).__init__()

                            self.yang_name = "inherit"
                            self.yang_parent_name = "peer-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-policy", ("peer_policy", Native.Router.Bgp.Template.PeerPolicy.Inherit.PeerPolicy_))])
                            self._leafs = OrderedDict()

                            self.peer_policy = Native.Router.Bgp.Template.PeerPolicy.Inherit.PeerPolicy_()
                            self.peer_policy.parent = self
                            self._children_name_map["peer_policy"] = "peer-policy"
                            self._segment_path = lambda: "inherit"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Template.PeerPolicy.Inherit, [], name, value)


                        class PeerPolicy_(Entity):
                            """
                            
                            
                            .. attribute:: template
                            
                            	
                            	**type**\: list of  		 :py:class:`Template_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerPolicy.Inherit.PeerPolicy_.Template_>`
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Template.PeerPolicy.Inherit.PeerPolicy_, self).__init__()

                                self.yang_name = "peer-policy"
                                self.yang_parent_name = "inherit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("template", ("template", Native.Router.Bgp.Template.PeerPolicy.Inherit.PeerPolicy_.Template_))])
                                self._leafs = OrderedDict()

                                self.template = YList(self)
                                self._segment_path = lambda: "peer-policy"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Template.PeerPolicy.Inherit.PeerPolicy_, [], name, value)


                            class Template_(Entity):
                                """
                                
                                
                                .. attribute:: name  (key)
                                
                                	Template name
                                	**type**\: str
                                
                                .. attribute:: range
                                
                                	Sequence number
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Template.PeerPolicy.Inherit.PeerPolicy_.Template_, self).__init__()

                                    self.yang_name = "template"
                                    self.yang_parent_name = "peer-policy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                    ])
                                    self.name = None
                                    self.range = None
                                    self._segment_path = lambda: "template" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Template.PeerPolicy.Inherit.PeerPolicy_.Template_, ['name', 'range'], name, value)


                    class Encap(Entity):
                        """
                        Preferred Encapsulation for Neighbor
                        
                        .. attribute:: mpls
                        
                        	Neighbor Prefers MPLS
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vxlan
                        
                        	Neighbor Prefers VxLAN
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Template.PeerPolicy.Encap, self).__init__()

                            self.yang_name = "encap"
                            self.yang_parent_name = "peer-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                            ])
                            self.mpls = None
                            self.vxlan = None
                            self._segment_path = lambda: "encap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Template.PeerPolicy.Encap, ['mpls', 'vxlan'], name, value)


                class PeerSession(Entity):
                    """
                    Template configuration for session parameters
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: ha_mode
                    
                    	high availability mode
                    	**type**\:  :py:class:`HaMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerSession.HaMode>`
                    
                    .. attribute:: password
                    
                    	Set a password
                    	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerSession.Password>`
                    
                    .. attribute:: remote_as
                    
                    	Specify a BGP neighbor
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: str
                    
                    .. attribute:: update_source
                    
                    	Source of routing updates
                    	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerSession.UpdateSource>`
                    
                    .. attribute:: version
                    
                    	Set the BGP version to match a neighbor
                    	**type**\: int
                    
                    	**range:** 4..None
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Template.PeerSession, self).__init__()

                        self.yang_name = "peer-session"
                        self.yang_parent_name = "template"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("ha-mode", ("ha_mode", Native.Router.Bgp.Template.PeerSession.HaMode)), ("password", ("password", Native.Router.Bgp.Template.PeerSession.Password)), ("update-source", ("update_source", Native.Router.Bgp.Template.PeerSession.UpdateSource))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.name = None
                        self.remote_as = None
                        self.version = None

                        self.ha_mode = Native.Router.Bgp.Template.PeerSession.HaMode()
                        self.ha_mode.parent = self
                        self._children_name_map["ha_mode"] = "ha-mode"

                        self.password = Native.Router.Bgp.Template.PeerSession.Password()
                        self.password.parent = self
                        self._children_name_map["password"] = "password"

                        self.update_source = Native.Router.Bgp.Template.PeerSession.UpdateSource()
                        self.update_source.parent = self
                        self._children_name_map["update_source"] = "update-source"
                        self._segment_path = lambda: "peer-session" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Template.PeerSession, ['name', 'remote_as', 'version'], name, value)


                    class HaMode(Entity):
                        """
                        high availability mode
                        
                        .. attribute:: graceful_restart
                        
                        	graceful\-restart for this peer
                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerSession.HaMode.GracefulRestart>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Template.PeerSession.HaMode, self).__init__()

                            self.yang_name = "ha-mode"
                            self.yang_parent_name = "peer-session"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", Native.Router.Bgp.Template.PeerSession.HaMode.GracefulRestart))])
                            self._leafs = OrderedDict()

                            self.graceful_restart = None
                            self._children_name_map["graceful_restart"] = "graceful-restart"
                            self._segment_path = lambda: "ha-mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Template.PeerSession.HaMode, [], name, value)


                        class GracefulRestart(Entity):
                            """
                            graceful\-restart for this peer
                            
                            .. attribute:: disable
                            
                            	disable graceful\-restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Template.PeerSession.HaMode.GracefulRestart, self).__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "ha-mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                ])
                                self.disable = None
                                self._segment_path = lambda: "graceful-restart"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Template.PeerSession.HaMode.GracefulRestart, ['disable'], name, value)


                    class Password(Entity):
                        """
                        Set a password
                        
                        .. attribute:: password_range
                        
                        	
                        	**type**\: list of  		 :py:class:`PasswordRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerSession.Password.PasswordRange>`
                        
                        .. attribute:: password
                        
                        	The password
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Template.PeerSession.Password, self).__init__()

                            self.yang_name = "password"
                            self.yang_parent_name = "peer-session"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("password-range", ("password_range", Native.Router.Bgp.Template.PeerSession.Password.PasswordRange))])
                            self._leafs = OrderedDict([
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                            ])
                            self.password = None

                            self.password_range = YList(self)
                            self._segment_path = lambda: "password"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Template.PeerSession.Password, ['password'], name, value)


                        class PasswordRange(Entity):
                            """
                            
                            
                            .. attribute:: encruption_type_range  (key)
                            
                            	Encryption type (0 to disable encryption, 7 for proprietary)
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: password
                            
                            	The password
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Template.PeerSession.Password.PasswordRange, self).__init__()

                                self.yang_name = "password-range"
                                self.yang_parent_name = "password"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['encruption_type_range']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('encruption_type_range', (YLeaf(YType.uint8, 'encruption-type-range'), ['int'])),
                                    ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                ])
                                self.encruption_type_range = None
                                self.password = None
                                self._segment_path = lambda: "password-range" + "[encruption-type-range='" + str(self.encruption_type_range) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Template.PeerSession.Password.PasswordRange, ['encruption_type_range', 'password'], name, value)


                    class UpdateSource(Entity):
                        """
                        Source of routing updates
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerSession.UpdateSource.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerSession.UpdateSource.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerSession.UpdateSource.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Template.PeerSession.UpdateSource.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Template.PeerSession.UpdateSource, self).__init__()

                            self.yang_name = "update-source"
                            self.yang_parent_name = "peer-session"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.Template.PeerSession.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.Template.PeerSession.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.Template.PeerSession.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.Template.PeerSession.UpdateSource.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Router.Bgp.Template.PeerSession.UpdateSource.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Router.Bgp.Template.PeerSession.UpdateSource.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Router.Bgp.Template.PeerSession.UpdateSource.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Router.Bgp.Template.PeerSession.UpdateSource.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "update-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Template.PeerSession.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Template.PeerSession.UpdateSource.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "update-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Template.PeerSession.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Template.PeerSession.UpdateSource.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "update-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Template.PeerSession.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Template.PeerSession.UpdateSource.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "update-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Template.PeerSession.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Template.PeerSession.UpdateSource.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "update-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Template.PeerSession.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


            class Timers(Entity):
                """
                Adjust routing timers
                
                .. attribute:: bgp
                
                	BGP timers
                	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Timers.Bgp_>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Bgp.Timers, self).__init__()

                    self.yang_name = "timers"
                    self.yang_parent_name = "bgp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Timers.Bgp_))])
                    self._leafs = OrderedDict()

                    self.bgp = Native.Router.Bgp.Timers.Bgp_()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "bgp"
                    self._segment_path = lambda: "timers"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Bgp.Timers, [], name, value)


                class Bgp_(Entity):
                    """
                    BGP timers
                    
                    .. attribute:: keepalive_interval
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    	**default value**\: 60
                    
                    .. attribute:: holdtime
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    	**default value**\: 180
                    
                    .. attribute:: minimum_neighbor_hold
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Timers.Bgp_, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "timers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('keepalive_interval', (YLeaf(YType.uint16, 'keepalive-interval'), ['int'])),
                            ('holdtime', (YLeaf(YType.uint16, 'holdtime'), ['int'])),
                            ('minimum_neighbor_hold', (YLeaf(YType.uint16, 'minimum-neighbor-hold'), ['int'])),
                        ])
                        self.keepalive_interval = None
                        self.holdtime = None
                        self.minimum_neighbor_hold = None
                        self._segment_path = lambda: "bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Timers.Bgp_, ['keepalive_interval', 'holdtime', 'minimum_neighbor_hold'], name, value)


            class Scope(Entity):
                """
                
                
                .. attribute:: global_
                
                	
                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global>`
                
                	**presence node**\: True
                
                .. attribute:: vrf
                
                	
                	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf>`
                
                

                """

                _prefix = 'ios-bgp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Bgp.Scope, self).__init__()

                    self.yang_name = "scope"
                    self.yang_parent_name = "bgp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("global", ("global_", Native.Router.Bgp.Scope.Global)), ("vrf", ("vrf", Native.Router.Bgp.Scope.Vrf))])
                    self._leafs = OrderedDict()

                    self.global_ = None
                    self._children_name_map["global_"] = "global"

                    self.vrf = YList(self)
                    self._segment_path = lambda: "scope"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Bgp.Scope, [], name, value)


                class Global(Entity):
                    """
                    
                    
                    .. attribute:: peer_group
                    
                    	
                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.PeerGroup>`
                    
                    .. attribute:: neighbor
                    
                    	Specify a neighbor router
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.Neighbor>`
                    
                    .. attribute:: address_family
                    
                    	Enter Address Family command mode
                    	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Scope.Global, self).__init__()

                        self.yang_name = "global"
                        self.yang_parent_name = "scope"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.Neighbor)), ("address-family", ("address_family", Native.Router.Bgp.Scope.Global.AddressFamily))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.peer_group = Native.Router.Bgp.Scope.Global.PeerGroup()
                        self.peer_group.parent = self
                        self._children_name_map["peer_group"] = "peer-group"

                        self.address_family = Native.Router.Bgp.Scope.Global.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "global"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Scope.Global, [], name, value)


                    class PeerGroup(Entity):
                        """
                        
                        
                        .. attribute:: neighbor
                        
                        	Specify a neighbor router
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Scope.Global.PeerGroup, self).__init__()

                            self.yang_name = "peer-group"
                            self.yang_parent_name = "global"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor))])
                            self._leafs = OrderedDict()

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "peer-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Scope.Global.PeerGroup, [], name, value)


                        class Neighbor(Entity):
                            """
                            Specify a neighbor router
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: remote_as
                            
                            	Specify a BGP neighbor
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            	**mandatory**\: True
                            
                            .. attribute:: peer_group
                            
                            	Member of the peer\-group
                            	**type**\:  :py:class:`PeerGroup_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.PeerGroup_>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: description
                            
                            	Neighbor specific description
                            	**type**\: str
                            
                            .. attribute:: password
                            
                            	Set a password
                            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.Password>`
                            
                            .. attribute:: update_source
                            
                            	Source of routing updates
                            	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource>`
                            
                            .. attribute:: version
                            
                            	Set the BGP version to match a neighbor
                            	**type**\: int
                            
                            	**range:** 4..None
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "peer-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.PeerGroup_)), ("password", ("password", Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.Password)), ("update-source", ("update_source", Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                                ])
                                self.id = None
                                self.remote_as = None
                                self.description = None
                                self.version = None

                                self.peer_group = None
                                self._children_name_map["peer_group"] = "peer-group"

                                self.password = Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.Password()
                                self.password.parent = self
                                self._children_name_map["password"] = "password"

                                self.update_source = Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource()
                                self.update_source.parent = self
                                self._children_name_map["update_source"] = "update-source"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor, ['id', 'remote_as', 'description', 'version'], name, value)


                            class PeerGroup_(Entity):
                                """
                                Member of the peer\-group
                                
                                .. attribute:: peer_group_name
                                
                                	peer\-group name
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.PeerGroup_, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                    ])
                                    self.peer_group_name = None
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.PeerGroup_, ['peer_group_name'], name, value)


                            class Password(Entity):
                                """
                                Set a password
                                
                                .. attribute:: enctype
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: text
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.Password, self).__init__()

                                    self.yang_name = "password"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                        ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                    ])
                                    self.enctype = None
                                    self.text = None
                                    self._segment_path = lambda: "password"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.Password, ['enctype', 'text'], name, value)


                            class UpdateSource(Entity):
                                """
                                Source of routing updates
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource, self).__init__()

                                    self.yang_name = "update-source"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "update-source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "update-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "update-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "update-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "update-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.PeerGroup.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                    class Neighbor(Entity):
                        """
                        Specify a neighbor router
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_as
                        
                        	Specify a BGP neighbor
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4294967295
                        
                        		**type**\: str
                        
                        	**mandatory**\: True
                        
                        .. attribute:: peer_group
                        
                        	Member of the peer\-group
                        	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.Neighbor.PeerGroup>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: description
                        
                        	Neighbor specific description
                        	**type**\: str
                        
                        .. attribute:: password
                        
                        	Set a password
                        	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.Neighbor.Password>`
                        
                        .. attribute:: update_source
                        
                        	Source of routing updates
                        	**type**\:  :py:class:`UpdateSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource>`
                        
                        .. attribute:: version
                        
                        	Set the BGP version to match a neighbor
                        	**type**\: int
                        
                        	**range:** 4..None
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Scope.Global.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "global"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.Neighbor.PeerGroup)), ("password", ("password", Native.Router.Bgp.Scope.Global.Neighbor.Password)), ("update-source", ("update_source", Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                ('version', (YLeaf(YType.uint16, 'version'), ['int'])),
                            ])
                            self.id = None
                            self.remote_as = None
                            self.description = None
                            self.version = None

                            self.peer_group = None
                            self._children_name_map["peer_group"] = "peer-group"

                            self.password = Native.Router.Bgp.Scope.Global.Neighbor.Password()
                            self.password.parent = self
                            self._children_name_map["password"] = "password"

                            self.update_source = Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource()
                            self.update_source.parent = self
                            self._children_name_map["update_source"] = "update-source"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Scope.Global.Neighbor, ['id', 'remote_as', 'description', 'version'], name, value)


                        class PeerGroup(Entity):
                            """
                            Member of the peer\-group
                            
                            .. attribute:: peer_group_name
                            
                            	peer\-group name
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Scope.Global.Neighbor.PeerGroup, self).__init__()

                                self.yang_name = "peer-group"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                ])
                                self.peer_group_name = None
                                self._segment_path = lambda: "peer-group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Scope.Global.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                        class Password(Entity):
                            """
                            Set a password
                            
                            .. attribute:: enctype
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..7
                            
                            .. attribute:: text
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Scope.Global.Neighbor.Password, self).__init__()

                                self.yang_name = "password"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('enctype', (YLeaf(YType.uint8, 'enctype'), ['int'])),
                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                ])
                                self.enctype = None
                                self.text = None
                                self._segment_path = lambda: "password"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Scope.Global.Neighbor.Password, ['enctype', 'text'], name, value)


                        class UpdateSource(Entity):
                            """
                            Source of routing updates
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource, self).__init__()

                                self.yang_name = "update-source"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "update-source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "update-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "update-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "update-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "update-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.Neighbor.UpdateSource.PortChannelSubinterface, [u'port_channel'], name, value)


                    class AddressFamily(Entity):
                        """
                        Enter Address Family command mode
                        
                        .. attribute:: no_vrf
                        
                        	
                        	**type**\:  :py:class:`NoVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Scope.Global.AddressFamily, self).__init__()

                            self.yang_name = "address-family"
                            self.yang_parent_name = "global"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("no-vrf", ("no_vrf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf))])
                            self._leafs = OrderedDict()

                            self.no_vrf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf()
                            self.no_vrf.parent = self
                            self._children_name_map["no_vrf"] = "no-vrf"
                            self._segment_path = lambda: "address-family"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily, [], name, value)


                        class NoVrf(Entity):
                            """
                            
                            
                            .. attribute:: ipv4
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4>`
                            
                            .. attribute:: ipv6
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6>`
                            
                            .. attribute:: vpnv4
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Vpnv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4>`
                            
                            .. attribute:: vpnv6
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Vpnv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6>`
                            
                            .. attribute:: nsap
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Nsap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap>`
                            
                            .. attribute:: l2vpn
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn>`
                            
                            .. attribute:: rtfilter
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Rtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter>`
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf, self).__init__()

                                self.yang_name = "no-vrf"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4)), ("ipv6", ("ipv6", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6)), ("vpnv4", ("vpnv4", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4)), ("vpnv6", ("vpnv6", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6)), ("nsap", ("nsap", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap)), ("l2vpn", ("l2vpn", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn)), ("rtfilter", ("rtfilter", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter))])
                                self._leafs = OrderedDict()

                                self.ipv4 = YList(self)
                                self.ipv6 = YList(self)
                                self.vpnv4 = YList(self)
                                self.vpnv6 = YList(self)
                                self.nsap = YList(self)
                                self.l2vpn = YList(self)
                                self.rtfilter = YList(self)
                                self._segment_path = lambda: "no-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf, [], name, value)


                            class Ipv4(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`BgpIpv4AfType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.BgpIpv4AfType>`
                                
                                .. attribute:: ipv4_unicast
                                
                                	IPv4 Unicast address family
                                	**type**\:  :py:class:`Ipv4Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("ipv4-unicast", ("ipv4_unicast", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'BgpIpv4AfType', '')])),
                                    ])
                                    self.af_name = None

                                    self.ipv4_unicast = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast()
                                    self.ipv4_unicast.parent = self
                                    self._children_name_map["ipv4_unicast"] = "ipv4-unicast"
                                    self._segment_path = lambda: "ipv4" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4, ['af_name'], name, value)


                                class Ipv4Unicast(Entity):
                                    """
                                    IPv4 Unicast address family
                                    
                                    .. attribute:: aggregate_address
                                    
                                    	Configure BGP aggregate entries
                                    	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress>`
                                    
                                    .. attribute:: auto_summary
                                    
                                    	Enable automatic network number summarization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_>`
                                    
                                    .. attribute:: default_information
                                    
                                    	Control distribution of default information
                                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation>`
                                    
                                    .. attribute:: default_metric
                                    
                                    	Set metric of redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: distance
                                    
                                    	Define an administrative distance
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter networks in routing updates
                                    	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList>`
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor>`
                                    
                                    .. attribute:: network
                                    
                                    	
                                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network>`
                                    
                                    .. attribute:: redistribute
                                    
                                    	Redistribute information from another routing protocol
                                    	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute>`
                                    
                                    .. attribute:: segment_routing
                                    
                                    	segment\-routing
                                    	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: synchronization
                                    
                                    	Perform IGP synchronization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: table_map
                                    
                                    	Map external entry attributes into routing table
                                    	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast, self).__init__()

                                        self.yang_name = "ipv4-unicast"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor)), ("network", ("network", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute)), ("segment-routing", ("segment_routing", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp)), ("table-map", ("table_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap))])
                                        self._leafs = OrderedDict([
                                            ('auto_summary', (YLeaf(YType.empty, 'auto-summary'), ['Empty'])),
                                            ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                            ('synchronization', (YLeaf(YType.empty, 'synchronization'), ['Empty'])),
                                        ])
                                        self.auto_summary = None
                                        self.default_metric = None
                                        self.synchronization = None

                                        self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.default_information = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation()
                                        self.default_information.parent = self
                                        self._children_name_map["default_information"] = "default-information"

                                        self.distance = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.network = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network()
                                        self.network.parent = self
                                        self._children_name_map["network"] = "network"

                                        self.redistribute = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute()
                                        self.redistribute.parent = self
                                        self._children_name_map["redistribute"] = "redistribute"

                                        self.segment_routing = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting()
                                        self.segment_routing.parent = self
                                        self._children_name_map["segment_routing"] = "segment-routing"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.table_map = None
                                        self._children_name_map["table_map"] = "table-map"

                                        self.aggregate_address = YList(self)
                                        self.distribute_list = YList(self)
                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "ipv4-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast, ['auto_summary', 'default_metric', 'synchronization'], name, value)


                                    class AggregateAddress(Entity):
                                        """
                                        Configure BGP aggregate entries
                                        
                                        .. attribute:: ipv4_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mask  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: advertise_map
                                        
                                        	Set condition to advertise attribute
                                        	**type**\: str
                                        
                                        .. attribute:: as_set
                                        
                                        	Generate AS set path information
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: attribute_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: summary_only
                                        
                                        	Filter more specific routes from updates
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_map
                                        
                                        	Conditionally filter more specific routes from updates
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress, self).__init__()

                                            self.yang_name = "aggregate-address"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ipv4_address','ipv4_mask']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mask', (YLeaf(YType.str, 'ipv4-mask'), ['str'])),
                                                ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                                ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                                ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                                ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                            ])
                                            self.ipv4_address = None
                                            self.ipv4_mask = None
                                            self.advertise_map = None
                                            self.as_set = None
                                            self.attribute_map = None
                                            self.as_override = None
                                            self.route_map = None
                                            self.summary_only = None
                                            self.suppress_map = None
                                            self._segment_path = lambda: "aggregate-address" + "[ipv4-address='" + str(self.ipv4_address) + "']" + "[ipv4-mask='" + str(self.ipv4_mask) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress, ['ipv4_address', 'ipv4_mask', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Additional paths in the BGP table
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths>`
                                        
                                        .. attribute:: advertise_best_external
                                        
                                        	Advertise best external path to internal peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Configure aggregation timer
                                        	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer>`
                                        
                                        .. attribute:: bestpath
                                        
                                        	Change the default bestpath selection
                                        	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath>`
                                        
                                        .. attribute:: dampening
                                        
                                        	Enable route\-flap dampening
                                        	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Use DMZ Link Bandwidth as weight for BGP multipaths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: inject_map
                                        
                                        	Route map which specifies prefixes to inject
                                        	**type**\: list of  		 :py:class:`InjectMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop>`
                                        
                                        .. attribute:: recursion
                                        
                                        	recursion rule for the nexthops
                                        	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion>`
                                        
                                        .. attribute:: redistribute_internal
                                        
                                        	Allow redistribution of iBGP into IGPs (dangerous)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	bgp route\-map commands
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfig_backup
                                        
                                        	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_inactive
                                        
                                        	Suppress routes that are not in the routing table
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: update_group
                                        
                                        	Manage peers in bgp update groups
                                        	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening)), ("inject-map", ("inject_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup))])
                                            self._leafs = OrderedDict([
                                                ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                                ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                                ('suppress_inactive', (YLeaf(YType.empty, 'suppress-inactive'), ['Empty'])),
                                            ])
                                            self.advertise_best_external = None
                                            self.dmzlink_bw = None
                                            self.redistribute_internal = None
                                            self.scan_time = None
                                            self.soft_reconfig_backup = None
                                            self.suppress_inactive = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.aggregate_timer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer()
                                            self.aggregate_timer.parent = self
                                            self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                            self.bestpath = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath()
                                            self.bestpath.parent = self
                                            self._children_name_map["bestpath"] = "bestpath"

                                            self.dampening = None
                                            self._children_name_map["dampening"] = "dampening"

                                            self.nexthop = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.recursion = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion()
                                            self.recursion.parent = self
                                            self._children_name_map["recursion"] = "recursion"

                                            self.route_map = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap()
                                            self.route_map.parent = self
                                            self._children_name_map["route_map"] = "route-map"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup()
                                            self.update_group.parent = self
                                            self._children_name_map["update_group"] = "update-group"

                                            self.inject_map = YList(self)
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup', 'suppress_inactive'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Additional paths in the BGP table
                                            
                                            .. attribute:: install
                                            
                                            	Additional paths to install into RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: select
                                            
                                            	Selection criteria to pick the paths
                                            	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to neighbors
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.install = None
                                                self.receive = None

                                                self.select = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select()
                                                self.select.parent = self
                                                self._children_name_map["select"] = "select"

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                            class Select(Entity):
                                                """
                                                Selection criteria to pick the paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                    self.yang_name = "select"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"

                                                    self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.best_external = None
                                                    self._children_name_map["best_external"] = "best-external"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "select"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                            self._leafs = OrderedDict()

                                                            self.range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                        class Range(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best path
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                                self.yang_name = "range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Select backup path
                                                    
                                                    .. attribute:: best_external
                                                    
                                                    	Select best\-external path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                        ])
                                                        self.best_external = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best path
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                                class BestExternal(Entity):
                                                    """
                                                    Select best\-external path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Select backup path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                        self.yang_name = "best-external"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                        ])
                                                        self.backup = None
                                                        self._segment_path = lambda: "best-external"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to neighbors
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                        class AggregateTimer(Entity):
                                            """
                                            Configure aggregation timer
                                            
                                            .. attribute:: aggregate_timer
                                            
                                            	Timer interval
                                            	**type**\: int
                                            
                                            	**range:** 6..60
                                            
                                            .. attribute:: disable_timer
                                            
                                            	Timer interval
                                            	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer, self).__init__()

                                                self.yang_name = "aggregate-timer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                    ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                                ])
                                                self.aggregate_timer = None
                                                self.disable_timer = None
                                                self._segment_path = lambda: "aggregate-timer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                            class DisableTimer(Enum):
                                                """
                                                DisableTimer (Enum Class)

                                                Timer interval

                                                .. data:: Y_0 = 0

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")



                                        class Bestpath(Entity):
                                            """
                                            Change the default bestpath selection
                                            
                                            .. attribute:: igp_metric
                                            
                                            	igp metric
                                            	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric>`
                                            
                                            .. attribute:: prefix_validate
                                            
                                            	Prefix origin validation
                                            	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath, self).__init__()

                                                self.yang_name = "bestpath"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate))])
                                                self._leafs = OrderedDict()

                                                self.igp_metric = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric()
                                                self.igp_metric.parent = self
                                                self._children_name_map["igp_metric"] = "igp-metric"

                                                self.prefix_validate = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate()
                                                self.prefix_validate.parent = self
                                                self._children_name_map["prefix_validate"] = "prefix-validate"
                                                self._segment_path = lambda: "bestpath"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath, [], name, value)


                                            class IgpMetric(Entity):
                                                """
                                                igp metric
                                                
                                                .. attribute:: ignore
                                                
                                                	Ignore igp metric in bestpath selection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                                    self.yang_name = "igp-metric"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ])
                                                    self.ignore = None
                                                    self._segment_path = lambda: "igp-metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                            class PrefixValidate(Entity):
                                                """
                                                Prefix origin validation
                                                
                                                .. attribute:: allow_invalid
                                                
                                                	Allow invalid routes to be considered for bestpath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: disable
                                                
                                                	Disable prefix validation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                                    self.yang_name = "prefix-validate"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.allow_invalid = None
                                                    self.disable = None
                                                    self._segment_path = lambda: "prefix-validate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                        class Dampening(Entity):
                                            """
                                            Enable route\-flap dampening
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria for dampening
                                            	**type**\: str
                                            
                                            .. attribute:: dampen
                                            
                                            	
                                            	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening, self).__init__()

                                                self.yang_name = "dampening"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.dampen = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen()
                                                self.dampen.parent = self
                                                self._children_name_map["dampen"] = "dampen"
                                                self._segment_path = lambda: "dampening"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                            class Dampen(Entity):
                                                """
                                                
                                                
                                                .. attribute:: half_life_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..45
                                                
                                                .. attribute:: reuse_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: max_suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                                    self.yang_name = "dampen"
                                                    self.yang_parent_name = "dampening"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                        ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                        ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                        ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                    ])
                                                    self.half_life_time = None
                                                    self.reuse_time = None
                                                    self.suppress_time = None
                                                    self.max_suppress_time = None
                                                    self._segment_path = lambda: "dampen"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                        class InjectMap(Entity):
                                            """
                                            Route map which specifies prefixes to inject
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: exist_map
                                            
                                            	Route map which specifies exist condition
                                            	**type**\: str
                                            
                                            .. attribute:: copy_attributes
                                            
                                            	Copy attributes from aggregate
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap, self).__init__()

                                                self.yang_name = "inject-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                    ('copy_attributes', (YLeaf(YType.empty, 'copy-attributes'), ['Empty'])),
                                                ])
                                                self.name = None
                                                self.exist_map = None
                                                self.copy_attributes = None
                                                self._segment_path = lambda: "inject-map" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap, ['name', 'exist_map', 'copy_attributes'], name, value)


                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class Recursion(Entity):
                                            """
                                            recursion rule for the nexthops
                                            
                                            .. attribute:: host
                                            
                                            	recursion via host for the nexthops
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion, self).__init__()

                                                self.yang_name = "recursion"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                                ])
                                                self.host = None
                                                self._segment_path = lambda: "recursion"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion, ['host'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            bgp route\-map commands
                                            
                                            .. attribute:: priority
                                            
                                            	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class UpdateGroup(Entity):
                                            """
                                            Manage peers in bgp update groups
                                            
                                            .. attribute:: split
                                            
                                            	Split update groups based on Policy
                                            	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup, self).__init__()

                                                self.yang_name = "update-group"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split))])
                                                self._leafs = OrderedDict()

                                                self.split = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split()
                                                self.split.parent = self
                                                self._children_name_map["split"] = "split"
                                                self._segment_path = lambda: "update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup, [], name, value)


                                            class Split(Entity):
                                                """
                                                Split update groups based on Policy
                                                
                                                .. attribute:: as_override
                                                
                                                	Keep peers with as\-override in different update groups
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                                    self.yang_name = "split"
                                                    self.yang_parent_name = "update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                    ])
                                                    self.as_override = None
                                                    self._segment_path = lambda: "split"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                                    class DefaultInformation(Entity):
                                        """
                                        Control distribution of default information
                                        
                                        .. attribute:: originate
                                        
                                        	Distribute a default route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation, self).__init__()

                                            self.yang_name = "default-information"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                            ])
                                            self.originate = None
                                            self._segment_path = lambda: "default-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation, ['originate'], name, value)


                                    class Distance(Entity):
                                        """
                                        Define an administrative distance
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP distance
                                        	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_>`
                                        
                                        .. attribute:: adm_distance
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance))])
                                            self._leafs = OrderedDict()

                                            self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.adm_distance = YList(self)
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance, [], name, value)


                                        class Bgp_(Entity):
                                            """
                                            BGP distance
                                            
                                            .. attribute:: extern_as
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: internal_as
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: local
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "distance"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                                    ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                                    ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                                ])
                                                self.extern_as = None
                                                self.internal_as = None
                                                self.local = None
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                        class AdmDistance(Entity):
                                            """
                                            
                                            
                                            .. attribute:: distance  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: srcip  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: wildbits  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: acl
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..99
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..1999
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance, self).__init__()

                                                self.yang_name = "adm-distance"
                                                self.yang_parent_name = "distance"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['distance','srcip','wildbits']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                                    ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                                    ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                                    ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                                ])
                                                self.distance = None
                                                self.srcip = None
                                                self.wildbits = None
                                                self.acl = None
                                                self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter networks in routing updates
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 100..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 2000..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        .. attribute:: in_
                                        
                                        	Filter incoming routing updates
                                        	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: out
                                        
                                        	Filter outgoing routing updates
                                        	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("in", ("in_", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In)), ("out", ("out", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','int','str'])),
                                            ])
                                            self.id = None

                                            self.in_ = None
                                            self._children_name_map["in_"] = "in"

                                            self.out = None
                                            self._children_name_map["out"] = "out"
                                            self._segment_path = lambda: "distribute-list" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList, ['id'], name, value)


                                        class In(Entity):
                                            """
                                            Filter incoming routing updates
                                            
                                            .. attribute:: interface
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In, self).__init__()

                                                self.yang_name = "in"
                                                self.yang_parent_name = "distribute-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ])
                                                self.interface = None
                                                self._segment_path = lambda: "in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In, ['interface'], name, value)


                                        class Out(Entity):
                                            """
                                            Filter outgoing routing updates
                                            
                                            .. attribute:: interface
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out, self).__init__()

                                                self.yang_name = "out"
                                                self.yang_parent_name = "distribute-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ])
                                                self.interface = None
                                                self._segment_path = lambda: "out"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out, ['interface'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: additional_paths
                                            
                                            	
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths>`
                                            
                                            .. attribute:: advertise
                                            
                                            	Advertise to this neighbor
                                            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise>`
                                            
                                            .. attribute:: advertise_map
                                            
                                            	specify route\-map for conditional advertisement
                                            	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: aigp
                                            
                                            	Enable a AIGP on neighbor
                                            	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: announce
                                            
                                            	Announce RPKI state using an extended community
                                            	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce>`
                                            
                                            .. attribute:: as_override
                                            
                                            	Override matching AS\-number while sending update
                                            	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: default_originate
                                            
                                            	Originate default route to this neighbor
                                            	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: distribute_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList>`
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: peer_group
                                            
                                            	Member of the peer\-group
                                            	**type**\:  :py:class:`PeerGroup_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: send_label
                                            
                                            	Send NLRI + MPLS Label to this peer
                                            	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: translate_update
                                            
                                            	Translate update to MBGP format
                                            	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate>`
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.advertise = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise()
                                                self.advertise.parent = self
                                                self._children_name_map["advertise"] = "advertise"

                                                self.advertise_map = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap()
                                                self.advertise_map.parent = self
                                                self._children_name_map["advertise_map"] = "advertise-map"

                                                self.aigp = None
                                                self._children_name_map["aigp"] = "aigp"

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.announce = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce()
                                                self.announce.parent = self
                                                self._children_name_map["announce"] = "announce"

                                                self.as_override = None
                                                self._children_name_map["as_override"] = "as-override"

                                                self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.default_originate = None
                                                self._children_name_map["default_originate"] = "default-originate"

                                                self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.peer_group = None
                                                self._children_name_map["peer_group"] = "peer-group"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.send_label = None
                                                self._children_name_map["send_label"] = "send-label"

                                                self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.translate_update = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate()
                                                self.translate_update.parent = self
                                                self._children_name_map["translate_update"] = "translate-update"

                                                self.distribute_list = YList(self)
                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class AdditionalPaths(Entity):
                                                """
                                                
                                                
                                                .. attribute:: disable
                                                
                                                	Disable additional paths for this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: send
                                                
                                                	Send additional paths to this neighbor
                                                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send))])
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self.receive = None

                                                    self.send = None
                                                    self._children_name_map["send"] = "send"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                                class Send(Entity):
                                                    """
                                                    Send additional paths to this neighbor
                                                    
                                                    .. attribute:: receive
                                                    
                                                    	Receive additional paths from this neighbor
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, self).__init__()

                                                        self.yang_name = "send"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                        ])
                                                        self.receive = None
                                                        self._segment_path = lambda: "send"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                            class Advertise(Entity):
                                                """
                                                Advertise to this neighbor
                                                
                                                .. attribute:: additional_paths
                                                
                                                	Advertise additional paths
                                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Advertise best\-external (at RRs best\-internal) path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: diverse_path
                                                
                                                	Advertise diverse path
                                                	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                                    self.yang_name = "advertise"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None

                                                    self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                                    self.additional_paths.parent = self
                                                    self._children_name_map["additional_paths"] = "additional-paths"

                                                    self.diverse_path = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                                    self.diverse_path.parent = self
                                                    self._children_name_map["diverse_path"] = "diverse-path"
                                                    self._segment_path = lambda: "advertise"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                                class AdditionalPaths(Entity):
                                                    """
                                                    Advertise additional paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                        self.yang_name = "additional-paths"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                        self._leafs = OrderedDict()

                                                        self.all = None
                                                        self._children_name_map["all"] = "all"

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "additional-paths"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                    class All(Entity):
                                                        """
                                                        Select all available paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Select best N paths
                                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                            self.yang_name = "all"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict()

                                                            self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                            self.best.parent = self
                                                            self._children_name_map["best"] = "best"

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "all"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                        class Best(Entity):
                                                            """
                                                            Select best N paths
                                                            
                                                            .. attribute:: best_range
                                                            
                                                            	
                                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                                self.yang_name = "best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                                self._leafs = OrderedDict()

                                                                self.best_range = YList(self)
                                                                self._segment_path = lambda: "best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                            class BestRange(Entity):
                                                                """
                                                                
                                                                
                                                                .. attribute:: range  (key)
                                                                
                                                                	Number of best paths in additional paths to be selected
                                                                	**type**\: int
                                                                
                                                                	**range:** 2..3
                                                                
                                                                .. attribute:: group_best
                                                                
                                                                	Select group\-best paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                    self.yang_name = "best-range"
                                                                    self.yang_parent_name = "best"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['range']
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                    ])
                                                                    self.range = None
                                                                    self.group_best = None
                                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: best
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                                ])
                                                                self.best = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.all = None

                                                                self.group_best = None
                                                                self._children_name_map["group_best"] = "group-best"
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                            class GroupBest(Entity):
                                                                """
                                                                Select group\-best paths
                                                                
                                                                .. attribute:: all
                                                                
                                                                	Select all available paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                    self.yang_name = "group-best"
                                                                    self.yang_parent_name = "best-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                    ])
                                                                    self.all = None
                                                                    self._segment_path = lambda: "group-best"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.all = None
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                                class DiversePath(Entity):
                                                    """
                                                    Advertise diverse path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Diverse path can be backup path
                                                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                        self.yang_name = "diverse-path"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None

                                                        self.backup = None
                                                        self._children_name_map["backup"] = "backup"
                                                        self._segment_path = lambda: "diverse-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                    class Backup(Entity):
                                                        """
                                                        Diverse path can be backup path
                                                        
                                                        .. attribute:: mpath
                                                        
                                                        	Diverse path can be multipath
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                            self.yang_name = "backup"
                                                            self.yang_parent_name = "diverse-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                            ])
                                                            self.mpath = None
                                                            self._segment_path = lambda: "backup"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                            class AdvertiseMap(Entity):
                                                """
                                                specify route\-map for conditional advertisement
                                                
                                                .. attribute:: name
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap, self).__init__()

                                                    self.yang_name = "advertise-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name))])
                                                    self._leafs = OrderedDict()

                                                    self.name = YList(self)
                                                    self._segment_path = lambda: "advertise-map"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap, [], name, value)


                                                class Name(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: word  (key)
                                                    
                                                    	advertise route\-map name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: exist_map
                                                    
                                                    	condition route\-map name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: non_exist_map
                                                    
                                                    	condition route\-map name
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, self).__init__()

                                                        self.yang_name = "name"
                                                        self.yang_parent_name = "advertise-map"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['word']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                            ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                            ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                        ])
                                                        self.word = None
                                                        self.exist_map = None
                                                        self.non_exist_map = None
                                                        self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                            class Aigp(Entity):
                                                """
                                                Enable a AIGP on neighbor
                                                
                                                .. attribute:: send
                                                
                                                	Cost community or MED carrying AIGP VALUE
                                                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                                    self.yang_name = "aigp"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.send = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send()
                                                    self.send.parent = self
                                                    self._children_name_map["send"] = "send"
                                                    self._segment_path = lambda: "aigp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                                class Send(Entity):
                                                    """
                                                    Cost community or MED carrying AIGP VALUE
                                                    
                                                    .. attribute:: cost_community
                                                    
                                                    	Cost extended community carrying AIGP Value
                                                    	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                                    
                                                    .. attribute:: med
                                                    
                                                    	Med carrying AIGP Value
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                        self.yang_name = "send"
                                                        self.yang_parent_name = "aigp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                        ])
                                                        self.med = None

                                                        self.cost_community = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                        self.cost_community.parent = self
                                                        self._children_name_map["cost_community"] = "cost-community"
                                                        self._segment_path = lambda: "send"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                                    class CostCommunity(Entity):
                                                        """
                                                        Cost extended community carrying AIGP Value
                                                        
                                                        .. attribute:: cc_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                            self.yang_name = "cost-community"
                                                            self.yang_parent_name = "send"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                            self._leafs = OrderedDict()

                                                            self.cc_range = YList(self)
                                                            self._segment_path = lambda: "cost-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                        class CcRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Community ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: poi
                                                            
                                                            	Point of insertion
                                                            	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                                self.yang_name = "cc-range"
                                                                self.yang_parent_name = "cost-community"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ])
                                                                self.range = None

                                                                self.poi = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                                self.poi.parent = self
                                                                self._children_name_map["poi"] = "poi"
                                                                self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                            class Poi(Entity):
                                                                """
                                                                Point of insertion
                                                                
                                                                .. attribute:: igp_cost
                                                                
                                                                	Point of insertion after IGP
                                                                	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                                
                                                                	**presence node**\: True
                                                                
                                                                .. attribute:: pre_bestpath
                                                                
                                                                	Point of insertion at beginning
                                                                	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                                
                                                                	**presence node**\: True
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                    self.yang_name = "poi"
                                                                    self.yang_parent_name = "cc-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                    self._leafs = OrderedDict()

                                                                    self.igp_cost = None
                                                                    self._children_name_map["igp_cost"] = "igp-cost"

                                                                    self.pre_bestpath = None
                                                                    self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                    self._segment_path = lambda: "poi"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                                class IgpCost(Entity):
                                                                    """
                                                                    Point of insertion after IGP
                                                                    
                                                                    .. attribute:: transitive
                                                                    
                                                                    	Cost community is transitive
                                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                    
                                                                    

                                                                    This class is a :ref:`presence class<presence-class>`

                                                                    """

                                                                    _prefix = 'ios-bgp'
                                                                    _revision = '2018-06-28'

                                                                    def __init__(self):
                                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                        self.yang_name = "igp-cost"
                                                                        self.yang_parent_name = "poi"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self.is_presence_container = True
                                                                        self._leafs = OrderedDict([
                                                                            ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                        ])
                                                                        self.transitive = None
                                                                        self._segment_path = lambda: "igp-cost"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                                class PreBestpath(Entity):
                                                                    """
                                                                    Point of insertion at beginning
                                                                    
                                                                    .. attribute:: transitive
                                                                    
                                                                    	Cost community is transitive
                                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                    
                                                                    

                                                                    This class is a :ref:`presence class<presence-class>`

                                                                    """

                                                                    _prefix = 'ios-bgp'
                                                                    _revision = '2018-06-28'

                                                                    def __init__(self):
                                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                        self.yang_name = "pre-bestpath"
                                                                        self.yang_parent_name = "poi"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self.is_presence_container = True
                                                                        self._leafs = OrderedDict([
                                                                            ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                        ])
                                                                        self.transitive = None
                                                                        self._segment_path = lambda: "pre-bestpath"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Announce(Entity):
                                                """
                                                Announce RPKI state using an extended community
                                                
                                                .. attribute:: rpki
                                                
                                                	Announce RPKI information using an extended community
                                                	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce, self).__init__()

                                                    self.yang_name = "announce"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki))])
                                                    self._leafs = OrderedDict()

                                                    self.rpki = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki()
                                                    self.rpki.parent = self
                                                    self._children_name_map["rpki"] = "rpki"
                                                    self._segment_path = lambda: "announce"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce, [], name, value)


                                                class Rpki(Entity):
                                                    """
                                                    Announce RPKI information using an extended community
                                                    
                                                    .. attribute:: state
                                                    
                                                    	Announce RPKI state information using an extended community
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki, self).__init__()

                                                        self.yang_name = "rpki"
                                                        self.yang_parent_name = "announce"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                        ])
                                                        self.state = None
                                                        self._segment_path = lambda: "rpki"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki, ['state'], name, value)


                                            class AsOverride(Entity):
                                                """
                                                Override matching AS\-number while sending update
                                                
                                                .. attribute:: disable
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride, self).__init__()

                                                    self.yang_name = "as-override"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "as-override"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride, ['disable'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class DefaultOriginate(Entity):
                                                """
                                                Originate default route to this neighbor
                                                
                                                .. attribute:: route_map
                                                
                                                	Route\-map to specify criteria to originate default
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                    self.yang_name = "default-originate"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default-originate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                            class DistributeList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                                
                                                .. attribute:: accesslist
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..199
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1300..2699
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** [a\-zA\-Z].\*
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                                    self.yang_name = "distribute-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                        ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                    ])
                                                    self.inout = None
                                                    self.accesslist = None
                                                    self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PeerGroup_(Entity):
                                                """
                                                Member of the peer\-group
                                                
                                                .. attribute:: peer_group_name
                                                
                                                	peer\-group name
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_, self).__init__()

                                                    self.yang_name = "peer-group"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                                    ])
                                                    self.peer_group_name = None
                                                    self._segment_path = lambda: "peer-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_, ['peer_group_name'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SendLabel(Entity):
                                                """
                                                Send NLRI + MPLS Label to this peer
                                                
                                                .. attribute:: send_label_explicit
                                                
                                                	
                                                	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel, self).__init__()

                                                    self.yang_name = "send-label"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit')])),
                                                    ])
                                                    self.send_label_explicit = None
                                                    self._segment_path = lambda: "send-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                                class SendLabelExplicit(Enum):
                                                    """
                                                    SendLabelExplicit (Enum Class)

                                                    .. data:: explicit_null = 0

                                                    """

                                                    explicit_null = Enum.YLeaf(0, "explicit-null")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                            class TranslateUpdate(Entity):
                                                """
                                                Translate update to MBGP format
                                                
                                                .. attribute:: ipv4
                                                
                                                	Address Family
                                                	**type**\:  :py:class:`Ipv4_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate, self).__init__()

                                                    self.yang_name = "translate-update"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv4 = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_()
                                                    self.ipv4.parent = self
                                                    self._children_name_map["ipv4"] = "ipv4"
                                                    self._segment_path = lambda: "translate-update"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate, [], name, value)


                                                class Ipv4_(Entity):
                                                    """
                                                    Address Family
                                                    
                                                    .. attribute:: multicast
                                                    
                                                    	Address Family modifier
                                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_, self).__init__()

                                                        self.yang_name = "ipv4"
                                                        self.yang_parent_name = "translate-update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast))])
                                                        self._leafs = OrderedDict()

                                                        self.multicast = None
                                                        self._children_name_map["multicast"] = "multicast"
                                                        self._segment_path = lambda: "ipv4"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_, [], name, value)


                                                    class Multicast(Entity):
                                                        """
                                                        Address Family modifier
                                                        
                                                        .. attribute:: unicast
                                                        
                                                        	Address Family modifier
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast, self).__init__()

                                                            self.yang_name = "multicast"
                                                            self.yang_parent_name = "ipv4"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                            ])
                                                            self.unicast = None
                                                            self._segment_path = lambda: "multicast"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast, ['unicast'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: additional_paths
                                        
                                        	
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths>`
                                        
                                        .. attribute:: advertise
                                        
                                        	Advertise to this neighbor
                                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise>`
                                        
                                        .. attribute:: advertise_map
                                        
                                        	specify route\-map for conditional advertisement
                                        	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable a AIGP on neighbor
                                        	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: announce
                                        
                                        	Announce RPKI state using an extended community
                                        	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce>`
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability>`
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: distribute_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: peer_group
                                        
                                        	Member of the peer\-group
                                        	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: send_label
                                        
                                        	Send NLRI + MPLS Label to this peer
                                        	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: translate_update
                                        
                                        	Translate update to MBGP format
                                        	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate>`
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.advertise = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise()
                                            self.advertise.parent = self
                                            self._children_name_map["advertise"] = "advertise"

                                            self.advertise_map = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap()
                                            self.advertise_map.parent = self
                                            self._children_name_map["advertise_map"] = "advertise-map"

                                            self.aigp = None
                                            self._children_name_map["aigp"] = "aigp"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.announce = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce()
                                            self.announce.parent = self
                                            self._children_name_map["announce"] = "announce"

                                            self.as_override = None
                                            self._children_name_map["as_override"] = "as-override"

                                            self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.peer_group = None
                                            self._children_name_map["peer_group"] = "peer-group"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.send_label = None
                                            self._children_name_map["send_label"] = "send-label"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.translate_update = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate()
                                            self.translate_update.parent = self
                                            self._children_name_map["translate_update"] = "translate-update"

                                            self.distribute_list = YList(self)
                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AdditionalPaths(Entity):
                                            """
                                            
                                            
                                            .. attribute:: disable
                                            
                                            	Disable additional paths for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to this neighbor
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self.receive = None

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to this neighbor
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                        class Advertise(Entity):
                                            """
                                            Advertise to this neighbor
                                            
                                            .. attribute:: additional_paths
                                            
                                            	Advertise additional paths
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Advertise best\-external (at RRs best\-internal) path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: diverse_path
                                            
                                            	Advertise diverse path
                                            	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise, self).__init__()

                                                self.yang_name = "advertise"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath))])
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.diverse_path = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath()
                                                self.diverse_path.parent = self
                                                self._children_name_map["diverse_path"] = "diverse-path"
                                                self._segment_path = lambda: "advertise"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                            class AdditionalPaths(Entity):
                                                """
                                                Advertise additional paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "best-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                            class DiversePath(Entity):
                                                """
                                                Advertise diverse path
                                                
                                                .. attribute:: backup
                                                
                                                	Diverse path can be backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                                    self.yang_name = "diverse-path"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"
                                                    self._segment_path = lambda: "diverse-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Diverse path can be backup path
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "diverse-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                        class AdvertiseMap(Entity):
                                            """
                                            specify route\-map for conditional advertisement
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap, self).__init__()

                                                self.yang_name = "advertise-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name))])
                                                self._leafs = OrderedDict()

                                                self.name = YList(self)
                                                self._segment_path = lambda: "advertise-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap, [], name, value)


                                            class Name(Entity):
                                                """
                                                
                                                
                                                .. attribute:: word  (key)
                                                
                                                	advertise route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: non_exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name, self).__init__()

                                                    self.yang_name = "name"
                                                    self.yang_parent_name = "advertise-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                        ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                        ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                    ])
                                                    self.word = None
                                                    self.exist_map = None
                                                    self.non_exist_map = None
                                                    self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                        class Aigp(Entity):
                                            """
                                            Enable a AIGP on neighbor
                                            
                                            .. attribute:: send
                                            
                                            	Cost community or MED carrying AIGP VALUE
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp, self).__init__()

                                                self.yang_name = "aigp"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.send = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send()
                                                self.send.parent = self
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "aigp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp, [], name, value)


                                            class Send(Entity):
                                                """
                                                Cost community or MED carrying AIGP VALUE
                                                
                                                .. attribute:: cost_community
                                                
                                                	Cost extended community carrying AIGP Value
                                                	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity>`
                                                
                                                .. attribute:: med
                                                
                                                	Med carrying AIGP Value
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "aigp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                    ])
                                                    self.med = None

                                                    self.cost_community = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity()
                                                    self.cost_community.parent = self
                                                    self._children_name_map["cost_community"] = "cost-community"
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send, ['med'], name, value)


                                                class CostCommunity(Entity):
                                                    """
                                                    Cost extended community carrying AIGP Value
                                                    
                                                    .. attribute:: cc_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                        self.yang_name = "cost-community"
                                                        self.yang_parent_name = "send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                        self._leafs = OrderedDict()

                                                        self.cc_range = YList(self)
                                                        self._segment_path = lambda: "cost-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                    class CcRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Community ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: poi
                                                        
                                                        	Point of insertion
                                                        	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                            self.yang_name = "cc-range"
                                                            self.yang_parent_name = "cost-community"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ])
                                                            self.range = None

                                                            self.poi = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                            self.poi.parent = self
                                                            self._children_name_map["poi"] = "poi"
                                                            self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                        class Poi(Entity):
                                                            """
                                                            Point of insertion
                                                            
                                                            .. attribute:: igp_cost
                                                            
                                                            	Point of insertion after IGP
                                                            	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            .. attribute:: pre_bestpath
                                                            
                                                            	Point of insertion at beginning
                                                            	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                self.yang_name = "poi"
                                                                self.yang_parent_name = "cc-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                self._leafs = OrderedDict()

                                                                self.igp_cost = None
                                                                self._children_name_map["igp_cost"] = "igp-cost"

                                                                self.pre_bestpath = None
                                                                self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                self._segment_path = lambda: "poi"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                            class IgpCost(Entity):
                                                                """
                                                                Point of insertion after IGP
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                    self.yang_name = "igp-cost"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "igp-cost"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                            class PreBestpath(Entity):
                                                                """
                                                                Point of insertion at beginning
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                    self.yang_name = "pre-bestpath"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "pre-bestpath"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Announce(Entity):
                                            """
                                            Announce RPKI state using an extended community
                                            
                                            .. attribute:: rpki
                                            
                                            	Announce RPKI information using an extended community
                                            	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce, self).__init__()

                                                self.yang_name = "announce"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki))])
                                                self._leafs = OrderedDict()

                                                self.rpki = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki()
                                                self.rpki.parent = self
                                                self._children_name_map["rpki"] = "rpki"
                                                self._segment_path = lambda: "announce"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce, [], name, value)


                                            class Rpki(Entity):
                                                """
                                                Announce RPKI information using an extended community
                                                
                                                .. attribute:: state
                                                
                                                	Announce RPKI state information using an extended community
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki, self).__init__()

                                                    self.yang_name = "rpki"
                                                    self.yang_parent_name = "announce"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                    ])
                                                    self.state = None
                                                    self._segment_path = lambda: "rpki"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki, ['state'], name, value)


                                        class AsOverride(Entity):
                                            """
                                            Override matching AS\-number while sending update
                                            
                                            .. attribute:: disable
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride, self).__init__()

                                                self.yang_name = "as-override"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "as-override"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride, ['disable'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class DistributeList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList.Inout>`
                                            
                                            .. attribute:: accesslist
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..199
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..2699
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList, self).__init__()

                                                self.yang_name = "distribute-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList.Inout')])),
                                                    ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                ])
                                                self.inout = None
                                                self.accesslist = None
                                                self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PeerGroup(Entity):
                                            """
                                            Member of the peer\-group
                                            
                                            .. attribute:: peer_group_name
                                            
                                            	peer\-group name
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup, self).__init__()

                                                self.yang_name = "peer-group"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                                ])
                                                self.peer_group_name = None
                                                self._segment_path = lambda: "peer-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SendLabel(Entity):
                                            """
                                            Send NLRI + MPLS Label to this peer
                                            
                                            .. attribute:: send_label_explicit
                                            
                                            	
                                            	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel.SendLabelExplicit>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel, self).__init__()

                                                self.yang_name = "send-label"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel.SendLabelExplicit')])),
                                                ])
                                                self.send_label_explicit = None
                                                self._segment_path = lambda: "send-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                            class SendLabelExplicit(Enum):
                                                """
                                                SendLabelExplicit (Enum Class)

                                                .. data:: explicit_null = 0

                                                """

                                                explicit_null = Enum.YLeaf(0, "explicit-null")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class TranslateUpdate(Entity):
                                            """
                                            Translate update to MBGP format
                                            
                                            .. attribute:: ipv4
                                            
                                            	Address Family
                                            	**type**\:  :py:class:`Ipv4_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate, self).__init__()

                                                self.yang_name = "translate-update"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_))])
                                                self._leafs = OrderedDict()

                                                self.ipv4 = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_()
                                                self.ipv4.parent = self
                                                self._children_name_map["ipv4"] = "ipv4"
                                                self._segment_path = lambda: "translate-update"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate, [], name, value)


                                            class Ipv4_(Entity):
                                                """
                                                Address Family
                                                
                                                .. attribute:: multicast
                                                
                                                	Address Family modifier
                                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_, self).__init__()

                                                    self.yang_name = "ipv4"
                                                    self.yang_parent_name = "translate-update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast))])
                                                    self._leafs = OrderedDict()

                                                    self.multicast = None
                                                    self._children_name_map["multicast"] = "multicast"
                                                    self._segment_path = lambda: "ipv4"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_, [], name, value)


                                                class Multicast(Entity):
                                                    """
                                                    Address Family modifier
                                                    
                                                    .. attribute:: unicast
                                                    
                                                    	Address Family modifier
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast, self).__init__()

                                                        self.yang_name = "multicast"
                                                        self.yang_parent_name = "ipv4"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                        ])
                                                        self.unicast = None
                                                        self._segment_path = lambda: "multicast"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast, ['unicast'], name, value)


                                    class Network(Entity):
                                        """
                                        
                                        
                                        .. attribute:: with_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask>`
                                        
                                        .. attribute:: no_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask))])
                                            self._leafs = OrderedDict()

                                            self.with_mask = YList(self)
                                            self.no_mask = YList(self)
                                            self._segment_path = lambda: "network"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network, [], name, value)


                                        class WithMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mask  (key)
                                            
                                            	Network mask
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask, self).__init__()

                                                self.yang_name = "with-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number','mask']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.mask = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor'], name, value)


                                        class NoMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask, self).__init__()

                                                self.yang_name = "no-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask, ['number', 'route_map', 'backdoor'], name, value)


                                    class Redistribute(Entity):
                                        """
                                        Redistribute information from another routing protocol
                                        
                                        .. attribute:: application
                                        
                                        	Application
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dvmrp
                                        
                                        	Redistribution of DVMRP into BGP IPv4 Multicast
                                        	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator/ID Separation Protocol
                                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: iso_igrp
                                        
                                        	IGRP for OSI networks
                                        	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile routes
                                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: odr
                                        
                                        	On Demand stub Routes
                                        	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf>`
                                        
                                        .. attribute:: ospfv3
                                        
                                        	OSPFv3
                                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute, self).__init__()

                                            self.yang_name = "redistribute"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.dvmrp = None
                                            self._children_name_map["dvmrp"] = "dvmrp"

                                            self.eigrp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"

                                            self.isis = None
                                            self._children_name_map["isis"] = "isis"

                                            self.lisp = None
                                            self._children_name_map["lisp"] = "lisp"

                                            self.iso_igrp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp()
                                            self.iso_igrp.parent = self
                                            self._children_name_map["iso_igrp"] = "iso-igrp"

                                            self.mobile = None
                                            self._children_name_map["mobile"] = "mobile"

                                            self.odr = None
                                            self._children_name_map["odr"] = "odr"

                                            self.rip = None
                                            self._children_name_map["rip"] = "rip"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.ospf = YList(self)
                                            self.ospfv3 = YList(self)
                                            self._segment_path = lambda: "redistribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.name = YList(self)
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application, [], name, value)


                                            class Name(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	WORD \:\: Route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name, self).__init__()

                                                    self.yang_name = "name"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                        class Bgp_(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.as_no = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                        class Dvmrp(Entity):
                                            """
                                            Redistribution of DVMRP into BGP IPv4 Multicast
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp, self).__init__()

                                                self.yang_name = "dvmrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "dvmrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.as_no = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: isis_area
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea>`
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.default = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default()
                                                self.default.parent = self
                                                self._children_name_map["default"] = "default"

                                                self.isis_area = YList(self)
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis, [], name, value)


                                            class IsisArea(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of IP dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: clns
                                                
                                                	Redistribution of OSI dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: routes
                                                
                                                	
                                                	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea.Routes>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea, self).__init__()

                                                    self.yang_name = "isis-area"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                        ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                        ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea.Routes')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.ip = None
                                                    self.clns = None
                                                    self.routes = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                                class Routes(Enum):
                                                    """
                                                    Routes (Enum Class)

                                                    .. data:: level_1 = 0

                                                    .. data:: level_2 = 1

                                                    .. data:: level_1_2 = 2

                                                    """

                                                    level_1 = Enum.YLeaf(0, "level-1")

                                                    level_2 = Enum.YLeaf(1, "level-2")

                                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class Default(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of IP dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: clns
                                                
                                                	Redistribution of OSI dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: routes
                                                
                                                	
                                                	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default.Routes>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default, self).__init__()

                                                    self.yang_name = "default"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                        ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                        ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default.Routes')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.ip = None
                                                    self.clns = None
                                                    self.routes = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                                class Routes(Enum):
                                                    """
                                                    Routes (Enum Class)

                                                    .. data:: level_1 = 0

                                                    .. data:: level_2 = 1

                                                    .. data:: level_1_2 = 2

                                                    """

                                                    level_1 = Enum.YLeaf(0, "level-1")

                                                    level_2 = Enum.YLeaf(1, "level-2")

                                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class Lisp(Entity):
                                            """
                                            Locator/ID Separation Protocol
                                            
                                            .. attribute:: include_connected
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp, self).__init__()

                                                self.yang_name = "lisp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.include_connected = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "lisp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                        class IsoIgrp(Entity):
                                            """
                                            IGRP for OSI networks
                                            
                                            .. attribute:: iso_igrp_area
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp, self).__init__()

                                                self.yang_name = "iso-igrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default))])
                                                self._leafs = OrderedDict()

                                                self.default = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default()
                                                self.default.parent = self
                                                self._children_name_map["default"] = "default"

                                                self.iso_igrp_area = YList(self)
                                                self._segment_path = lambda: "iso-igrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp, [], name, value)


                                            class IsoIgrpArea(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                                    self.yang_name = "iso-igrp-area"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.name = None
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                            class Default(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default, self).__init__()

                                                    self.yang_name = "default"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "default"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                        class Mobile(Entity):
                                            """
                                            Mobile routes
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "mobile"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                        class Odr(Entity):
                                            """
                                            On Demand stub Routes
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr, self).__init__()

                                                self.yang_name = "odr"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "odr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: vrf
                                            
                                            	VPN Routing/Forwarding Instance
                                            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf>`
                                            
                                            .. attribute:: non_vrf
                                            
                                            	
                                            	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf)), ("non-vrf", ("non_vrf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.non_vrf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf()
                                                self.non_vrf.parent = self
                                                self._children_name_map["non_vrf"] = "non-vrf"

                                                self.vrf = YList(self)
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf, ['id'], name, value)


                                            class Vrf(Entity):
                                                """
                                                VPN Routing/Forwarding Instance
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: match
                                                
                                                	
                                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf.Match>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf.Match))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.metric = None
                                                    self.route_map = None

                                                    self.match = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf.Match()
                                                    self.match.parent = self
                                                    self._children_name_map["match"] = "match"
                                                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf, ['name', 'metric', 'route_map'], name, value)


                                                class Match(Entity):
                                                    """
                                                    
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf.Match, self).__init__()

                                                        self.yang_name = "match"
                                                        self.yang_parent_name = "vrf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict()
                                                        self._segment_path = lambda: "match"
                                                        self._is_frozen = True


                                            class NonVrf(Entity):
                                                """
                                                
                                                
                                                .. attribute:: match
                                                
                                                	
                                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf, self).__init__()

                                                    self.yang_name = "non-vrf"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match))])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.metric = None
                                                    self.route_map = None

                                                    self.match = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match()
                                                    self.match.parent = self
                                                    self._children_name_map["match"] = "match"
                                                    self._segment_path = lambda: "non-vrf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                                class Match(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: internal
                                                    
                                                    	Redistribute OSPF internal routes
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: external
                                                    
                                                    	Redistribute OSPF external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: external2
                                                    
                                                    	Redistribute OSPF external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: nssa_external
                                                    
                                                    	Redistribute OSPF NSSA external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric for redistributed routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map reference
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                        self.yang_name = "match"
                                                        self.yang_parent_name = "non-vrf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                            ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.internal = None
                                                        self.external = None
                                                        self.external2 = None
                                                        self.nssa_external = None
                                                        self.metric = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "match"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                        class Ospfv3(Entity):
                                            """
                                            OSPFv3
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3, self).__init__()

                                                self.yang_name = "ospfv3"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.id = None
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                .. attribute:: internal
                                                
                                                	Redistribute OSPF internal routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: external
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: external2
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: nssa_external
                                                
                                                	Redistribute OSPF NSSA external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "ospfv3"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                        ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.internal = None
                                                    self.external = None
                                                    self.external2 = None
                                                    self.nssa_external = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: name
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self.name = None
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ip
                                            
                                            	
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None

                                                self.clns = None
                                                self._children_name_map["clns"] = "clns"

                                                self.ip = None
                                                self._children_name_map["ip"] = "ip"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                            class Clns(Entity):
                                                """
                                                Redistribution of OSI dynamic routes
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns, self).__init__()

                                                    self.yang_name = "clns"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "clns"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                            class Ip(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                                    class SegmentRouting(Entity):
                                        """
                                        segment\-routing
                                        
                                        .. attribute:: mpls
                                        
                                        	mpls
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting, self).__init__()

                                            self.yang_name = "segment-routing"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                            ])
                                            self.mpls = None
                                            self._segment_path = lambda: "segment-routing"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting, ['mpls'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                                    class TableMap(Entity):
                                        """
                                        Map external entry attributes into routing table
                                        
                                        .. attribute:: name
                                        
                                        	WORD \:\: Route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: filter
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap, self).__init__()

                                            self.yang_name = "table-map"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                                            ])
                                            self.name = None
                                            self.filter = None
                                            self._segment_path = lambda: "table-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap, ['name', 'filter'], name, value)


                            class Ipv6(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`BgpIpv6AfType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.BgpIpv6AfType>`
                                
                                .. attribute:: ipv6_unicast
                                
                                	IPv6 Unicast address family
                                	**type**\:  :py:class:`Ipv6Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("ipv6-unicast", ("ipv6_unicast", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'BgpIpv6AfType', '')])),
                                    ])
                                    self.af_name = None

                                    self.ipv6_unicast = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast()
                                    self.ipv6_unicast.parent = self
                                    self._children_name_map["ipv6_unicast"] = "ipv6-unicast"
                                    self._segment_path = lambda: "ipv6" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6, ['af_name'], name, value)


                                class Ipv6Unicast(Entity):
                                    """
                                    IPv6 Unicast address family
                                    
                                    .. attribute:: aggregate_address
                                    
                                    	Configure BGP aggregate entries
                                    	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress>`
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_>`
                                    
                                    .. attribute:: default_information
                                    
                                    	Control distribution of default information
                                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation>`
                                    
                                    .. attribute:: default_metric
                                    
                                    	Set metric of redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: distance
                                    
                                    	Define an administrative distance
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance>`
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor>`
                                    
                                    .. attribute:: network
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network>`
                                    
                                    .. attribute:: redistribute
                                    
                                    	Redistribute information from another routing protocol
                                    	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: synchronization
                                    
                                    	Perform IGP synchronization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: table_map
                                    
                                    	Map external entry attributes into routing table
                                    	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast, self).__init__()

                                        self.yang_name = "ipv6-unicast"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor)), ("network", ("network", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp)), ("table-map", ("table_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap))])
                                        self._leafs = OrderedDict([
                                            ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                            ('synchronization', (YLeaf(YType.empty, 'synchronization'), ['Empty'])),
                                        ])
                                        self.default_metric = None
                                        self.synchronization = None

                                        self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.default_information = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation()
                                        self.default_information.parent = self
                                        self._children_name_map["default_information"] = "default-information"

                                        self.distance = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.redistribute = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute()
                                        self.redistribute.parent = self
                                        self._children_name_map["redistribute"] = "redistribute"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.table_map = None
                                        self._children_name_map["table_map"] = "table-map"

                                        self.aggregate_address = YList(self)
                                        self.neighbor = YList(self)
                                        self.network = YList(self)
                                        self._segment_path = lambda: "ipv6-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast, ['default_metric', 'synchronization'], name, value)


                                    class AggregateAddress(Entity):
                                        """
                                        Configure BGP aggregate entries
                                        
                                        .. attribute:: ipv6_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: advertise_map
                                        
                                        	Set condition to advertise attribute
                                        	**type**\: str
                                        
                                        .. attribute:: as_set
                                        
                                        	Generate AS set path information
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: attribute_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: summary_only
                                        
                                        	Filter more specific routes from updates
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_map
                                        
                                        	Conditionally filter more specific routes from updates
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress, self).__init__()

                                            self.yang_name = "aggregate-address"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ipv6_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                                ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                                ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                                ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                            ])
                                            self.ipv6_address = None
                                            self.advertise_map = None
                                            self.as_set = None
                                            self.attribute_map = None
                                            self.as_override = None
                                            self.route_map = None
                                            self.summary_only = None
                                            self.suppress_map = None
                                            self._segment_path = lambda: "aggregate-address" + "[ipv6-address='" + str(self.ipv6_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress, ['ipv6_address', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Additional paths in the BGP table
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths>`
                                        
                                        .. attribute:: advertise_best_external
                                        
                                        	Advertise best external path to internal peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Configure aggregation timer
                                        	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer>`
                                        
                                        .. attribute:: bestpath
                                        
                                        	Change the default bestpath selection
                                        	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath>`
                                        
                                        .. attribute:: dampening
                                        
                                        	Enable route\-flap dampening
                                        	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Use DMZ Link Bandwidth as weight for BGP multipaths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: inject_map
                                        
                                        	Route map which specifies prefixes to inject
                                        	**type**\: list of  		 :py:class:`InjectMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop>`
                                        
                                        .. attribute:: recursion
                                        
                                        	recursion rule for the nexthops
                                        	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion>`
                                        
                                        .. attribute:: redistribute_internal
                                        
                                        	Allow redistribution of iBGP into IGPs (dangerous)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	bgp route\-map commands
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfig_backup
                                        
                                        	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_inactive
                                        
                                        	Suppress routes that are not in the routing table
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: update_group
                                        
                                        	Manage peers in bgp update groups
                                        	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening)), ("inject-map", ("inject_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup))])
                                            self._leafs = OrderedDict([
                                                ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                                ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                                ('suppress_inactive', (YLeaf(YType.empty, 'suppress-inactive'), ['Empty'])),
                                            ])
                                            self.advertise_best_external = None
                                            self.dmzlink_bw = None
                                            self.redistribute_internal = None
                                            self.scan_time = None
                                            self.soft_reconfig_backup = None
                                            self.suppress_inactive = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.aggregate_timer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer()
                                            self.aggregate_timer.parent = self
                                            self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                            self.bestpath = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath()
                                            self.bestpath.parent = self
                                            self._children_name_map["bestpath"] = "bestpath"

                                            self.dampening = None
                                            self._children_name_map["dampening"] = "dampening"

                                            self.nexthop = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.recursion = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion()
                                            self.recursion.parent = self
                                            self._children_name_map["recursion"] = "recursion"

                                            self.route_map = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap()
                                            self.route_map.parent = self
                                            self._children_name_map["route_map"] = "route-map"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup()
                                            self.update_group.parent = self
                                            self._children_name_map["update_group"] = "update-group"

                                            self.inject_map = YList(self)
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup', 'suppress_inactive'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Additional paths in the BGP table
                                            
                                            .. attribute:: install
                                            
                                            	Additional paths to install into RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: select
                                            
                                            	Selection criteria to pick the paths
                                            	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to neighbors
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.install = None
                                                self.receive = None

                                                self.select = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select()
                                                self.select.parent = self
                                                self._children_name_map["select"] = "select"

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                            class Select(Entity):
                                                """
                                                Selection criteria to pick the paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                    self.yang_name = "select"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"

                                                    self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.best_external = None
                                                    self._children_name_map["best_external"] = "best-external"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "select"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                            self._leafs = OrderedDict()

                                                            self.range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                        class Range(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best path
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                                self.yang_name = "range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Select backup path
                                                    
                                                    .. attribute:: best_external
                                                    
                                                    	Select best\-external path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                        ])
                                                        self.best_external = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best path
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                                class BestExternal(Entity):
                                                    """
                                                    Select best\-external path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Select backup path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                        self.yang_name = "best-external"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                        ])
                                                        self.backup = None
                                                        self._segment_path = lambda: "best-external"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to neighbors
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                        class AggregateTimer(Entity):
                                            """
                                            Configure aggregation timer
                                            
                                            .. attribute:: aggregate_timer
                                            
                                            	Timer interval
                                            	**type**\: int
                                            
                                            	**range:** 6..60
                                            
                                            .. attribute:: disable_timer
                                            
                                            	Timer interval
                                            	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer, self).__init__()

                                                self.yang_name = "aggregate-timer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                    ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                                ])
                                                self.aggregate_timer = None
                                                self.disable_timer = None
                                                self._segment_path = lambda: "aggregate-timer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                            class DisableTimer(Enum):
                                                """
                                                DisableTimer (Enum Class)

                                                Timer interval

                                                .. data:: Y_0 = 0

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")



                                        class Bestpath(Entity):
                                            """
                                            Change the default bestpath selection
                                            
                                            .. attribute:: igp_metric
                                            
                                            	igp metric
                                            	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric>`
                                            
                                            .. attribute:: prefix_validate
                                            
                                            	Prefix origin validation
                                            	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath, self).__init__()

                                                self.yang_name = "bestpath"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate))])
                                                self._leafs = OrderedDict()

                                                self.igp_metric = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric()
                                                self.igp_metric.parent = self
                                                self._children_name_map["igp_metric"] = "igp-metric"

                                                self.prefix_validate = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate()
                                                self.prefix_validate.parent = self
                                                self._children_name_map["prefix_validate"] = "prefix-validate"
                                                self._segment_path = lambda: "bestpath"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath, [], name, value)


                                            class IgpMetric(Entity):
                                                """
                                                igp metric
                                                
                                                .. attribute:: ignore
                                                
                                                	Ignore igp metric in bestpath selection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                                    self.yang_name = "igp-metric"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ])
                                                    self.ignore = None
                                                    self._segment_path = lambda: "igp-metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                            class PrefixValidate(Entity):
                                                """
                                                Prefix origin validation
                                                
                                                .. attribute:: allow_invalid
                                                
                                                	Allow invalid routes to be considered for bestpath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: disable
                                                
                                                	Disable prefix validation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                                    self.yang_name = "prefix-validate"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.allow_invalid = None
                                                    self.disable = None
                                                    self._segment_path = lambda: "prefix-validate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                        class Dampening(Entity):
                                            """
                                            Enable route\-flap dampening
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria for dampening
                                            	**type**\: str
                                            
                                            .. attribute:: dampen
                                            
                                            	
                                            	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening, self).__init__()

                                                self.yang_name = "dampening"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.dampen = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen()
                                                self.dampen.parent = self
                                                self._children_name_map["dampen"] = "dampen"
                                                self._segment_path = lambda: "dampening"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                            class Dampen(Entity):
                                                """
                                                
                                                
                                                .. attribute:: half_life_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..45
                                                
                                                .. attribute:: reuse_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: max_suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                                    self.yang_name = "dampen"
                                                    self.yang_parent_name = "dampening"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                        ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                        ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                        ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                    ])
                                                    self.half_life_time = None
                                                    self.reuse_time = None
                                                    self.suppress_time = None
                                                    self.max_suppress_time = None
                                                    self._segment_path = lambda: "dampen"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                        class InjectMap(Entity):
                                            """
                                            Route map which specifies prefixes to inject
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: exist_map
                                            
                                            	Route map which specifies exist condition
                                            	**type**\: str
                                            
                                            .. attribute:: copy_attributes
                                            
                                            	Copy attributes from aggregate
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap, self).__init__()

                                                self.yang_name = "inject-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                    ('copy_attributes', (YLeaf(YType.empty, 'copy-attributes'), ['Empty'])),
                                                ])
                                                self.name = None
                                                self.exist_map = None
                                                self.copy_attributes = None
                                                self._segment_path = lambda: "inject-map" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap, ['name', 'exist_map', 'copy_attributes'], name, value)


                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class Recursion(Entity):
                                            """
                                            recursion rule for the nexthops
                                            
                                            .. attribute:: host
                                            
                                            	recursion via host for the nexthops
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion, self).__init__()

                                                self.yang_name = "recursion"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                                ])
                                                self.host = None
                                                self._segment_path = lambda: "recursion"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion, ['host'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            bgp route\-map commands
                                            
                                            .. attribute:: priority
                                            
                                            	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class UpdateGroup(Entity):
                                            """
                                            Manage peers in bgp update groups
                                            
                                            .. attribute:: split
                                            
                                            	Split update groups based on Policy
                                            	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup, self).__init__()

                                                self.yang_name = "update-group"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split))])
                                                self._leafs = OrderedDict()

                                                self.split = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split()
                                                self.split.parent = self
                                                self._children_name_map["split"] = "split"
                                                self._segment_path = lambda: "update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup, [], name, value)


                                            class Split(Entity):
                                                """
                                                Split update groups based on Policy
                                                
                                                .. attribute:: as_override
                                                
                                                	Keep peers with as\-override in different update groups
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                                    self.yang_name = "split"
                                                    self.yang_parent_name = "update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                    ])
                                                    self.as_override = None
                                                    self._segment_path = lambda: "split"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                                    class DefaultInformation(Entity):
                                        """
                                        Control distribution of default information
                                        
                                        .. attribute:: originate
                                        
                                        	Distribute a default route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation, self).__init__()

                                            self.yang_name = "default-information"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                            ])
                                            self.originate = None
                                            self._segment_path = lambda: "default-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation, ['originate'], name, value)


                                    class Distance(Entity):
                                        """
                                        Define an administrative distance
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP distance
                                        	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_>`
                                        
                                        .. attribute:: adm_distance
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance))])
                                            self._leafs = OrderedDict()

                                            self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.adm_distance = YList(self)
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance, [], name, value)


                                        class Bgp_(Entity):
                                            """
                                            BGP distance
                                            
                                            .. attribute:: extern_as
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: internal_as
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: local
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "distance"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                                    ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                                    ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                                ])
                                                self.extern_as = None
                                                self.internal_as = None
                                                self.local = None
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                        class AdmDistance(Entity):
                                            """
                                            
                                            
                                            .. attribute:: distance  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: srcip  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: wildbits  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: acl
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..99
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..1999
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance, self).__init__()

                                                self.yang_name = "adm-distance"
                                                self.yang_parent_name = "distance"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['distance','srcip','wildbits']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                                    ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                                    ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                                    ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                                ])
                                                self.distance = None
                                                self.srcip = None
                                                self.wildbits = None
                                                self.acl = None
                                                self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: additional_paths
                                            
                                            	
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths>`
                                            
                                            .. attribute:: advertise
                                            
                                            	Advertise to this neighbor
                                            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise>`
                                            
                                            .. attribute:: advertise_map
                                            
                                            	specify route\-map for conditional advertisement
                                            	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap>`
                                            
                                            .. attribute:: aigp
                                            
                                            	Enable a AIGP on neighbor
                                            	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: announce
                                            
                                            	Announce RPKI state using an extended community
                                            	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce>`
                                            
                                            .. attribute:: as_override
                                            
                                            	Override matching AS\-number while sending update
                                            	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: default_originate
                                            
                                            	Originate default route to this neighbor
                                            	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: send_label
                                            
                                            	Send NLRI + MPLS Label to this peer
                                            	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: translate_update
                                            
                                            	Translate update to MBGP format
                                            	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate>`
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.advertise = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise()
                                                self.advertise.parent = self
                                                self._children_name_map["advertise"] = "advertise"

                                                self.advertise_map = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap()
                                                self.advertise_map.parent = self
                                                self._children_name_map["advertise_map"] = "advertise-map"

                                                self.aigp = None
                                                self._children_name_map["aigp"] = "aigp"

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.announce = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce()
                                                self.announce.parent = self
                                                self._children_name_map["announce"] = "announce"

                                                self.as_override = None
                                                self._children_name_map["as_override"] = "as-override"

                                                self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.default_originate = None
                                                self._children_name_map["default_originate"] = "default-originate"

                                                self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.send_label = None
                                                self._children_name_map["send_label"] = "send-label"

                                                self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.translate_update = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate()
                                                self.translate_update.parent = self
                                                self._children_name_map["translate_update"] = "translate-update"

                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor, ['id', 'activate', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class AdditionalPaths(Entity):
                                                """
                                                
                                                
                                                .. attribute:: disable
                                                
                                                	Disable additional paths for this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: send
                                                
                                                	Send additional paths to this neighbor
                                                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send))])
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self.receive = None

                                                    self.send = None
                                                    self._children_name_map["send"] = "send"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                                class Send(Entity):
                                                    """
                                                    Send additional paths to this neighbor
                                                    
                                                    .. attribute:: receive
                                                    
                                                    	Receive additional paths from this neighbor
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, self).__init__()

                                                        self.yang_name = "send"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                        ])
                                                        self.receive = None
                                                        self._segment_path = lambda: "send"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                            class Advertise(Entity):
                                                """
                                                Advertise to this neighbor
                                                
                                                .. attribute:: additional_paths
                                                
                                                	Advertise additional paths
                                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Advertise best\-external (at RRs best\-internal) path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: diverse_path
                                                
                                                	Advertise diverse path
                                                	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                                    self.yang_name = "advertise"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None

                                                    self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                                    self.additional_paths.parent = self
                                                    self._children_name_map["additional_paths"] = "additional-paths"

                                                    self.diverse_path = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                                    self.diverse_path.parent = self
                                                    self._children_name_map["diverse_path"] = "diverse-path"
                                                    self._segment_path = lambda: "advertise"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                                class AdditionalPaths(Entity):
                                                    """
                                                    Advertise additional paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                        self.yang_name = "additional-paths"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                        self._leafs = OrderedDict()

                                                        self.all = None
                                                        self._children_name_map["all"] = "all"

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "additional-paths"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                    class All(Entity):
                                                        """
                                                        Select all available paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Select best N paths
                                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                            self.yang_name = "all"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict()

                                                            self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                            self.best.parent = self
                                                            self._children_name_map["best"] = "best"

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "all"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                        class Best(Entity):
                                                            """
                                                            Select best N paths
                                                            
                                                            .. attribute:: best_range
                                                            
                                                            	
                                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                                self.yang_name = "best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                                self._leafs = OrderedDict()

                                                                self.best_range = YList(self)
                                                                self._segment_path = lambda: "best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                            class BestRange(Entity):
                                                                """
                                                                
                                                                
                                                                .. attribute:: range  (key)
                                                                
                                                                	Number of best paths in additional paths to be selected
                                                                	**type**\: int
                                                                
                                                                	**range:** 2..3
                                                                
                                                                .. attribute:: group_best
                                                                
                                                                	Select group\-best paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                    self.yang_name = "best-range"
                                                                    self.yang_parent_name = "best"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['range']
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                    ])
                                                                    self.range = None
                                                                    self.group_best = None
                                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: best
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                                ])
                                                                self.best = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.all = None

                                                                self.group_best = None
                                                                self._children_name_map["group_best"] = "group-best"
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                            class GroupBest(Entity):
                                                                """
                                                                Select group\-best paths
                                                                
                                                                .. attribute:: all
                                                                
                                                                	Select all available paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                    self.yang_name = "group-best"
                                                                    self.yang_parent_name = "best-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                    ])
                                                                    self.all = None
                                                                    self._segment_path = lambda: "group-best"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.all = None
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                                class DiversePath(Entity):
                                                    """
                                                    Advertise diverse path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Diverse path can be backup path
                                                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                        self.yang_name = "diverse-path"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None

                                                        self.backup = None
                                                        self._children_name_map["backup"] = "backup"
                                                        self._segment_path = lambda: "diverse-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                    class Backup(Entity):
                                                        """
                                                        Diverse path can be backup path
                                                        
                                                        .. attribute:: mpath
                                                        
                                                        	Diverse path can be multipath
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                            self.yang_name = "backup"
                                                            self.yang_parent_name = "diverse-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                            ])
                                                            self.mpath = None
                                                            self._segment_path = lambda: "backup"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                            class AdvertiseMap(Entity):
                                                """
                                                specify route\-map for conditional advertisement
                                                
                                                .. attribute:: name
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap, self).__init__()

                                                    self.yang_name = "advertise-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name))])
                                                    self._leafs = OrderedDict()

                                                    self.name = YList(self)
                                                    self._segment_path = lambda: "advertise-map"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap, [], name, value)


                                                class Name(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: word  (key)
                                                    
                                                    	advertise route\-map name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: exist_map
                                                    
                                                    	condition route\-map name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: non_exist_map
                                                    
                                                    	condition route\-map name
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, self).__init__()

                                                        self.yang_name = "name"
                                                        self.yang_parent_name = "advertise-map"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['word']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                            ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                            ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                        ])
                                                        self.word = None
                                                        self.exist_map = None
                                                        self.non_exist_map = None
                                                        self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                            class Aigp(Entity):
                                                """
                                                Enable a AIGP on neighbor
                                                
                                                .. attribute:: send
                                                
                                                	Cost community or MED carrying AIGP VALUE
                                                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                                    self.yang_name = "aigp"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.send = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send()
                                                    self.send.parent = self
                                                    self._children_name_map["send"] = "send"
                                                    self._segment_path = lambda: "aigp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                                class Send(Entity):
                                                    """
                                                    Cost community or MED carrying AIGP VALUE
                                                    
                                                    .. attribute:: cost_community
                                                    
                                                    	Cost extended community carrying AIGP Value
                                                    	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                                    
                                                    .. attribute:: med
                                                    
                                                    	Med carrying AIGP Value
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                        self.yang_name = "send"
                                                        self.yang_parent_name = "aigp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                        ])
                                                        self.med = None

                                                        self.cost_community = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                        self.cost_community.parent = self
                                                        self._children_name_map["cost_community"] = "cost-community"
                                                        self._segment_path = lambda: "send"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                                    class CostCommunity(Entity):
                                                        """
                                                        Cost extended community carrying AIGP Value
                                                        
                                                        .. attribute:: cc_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                            self.yang_name = "cost-community"
                                                            self.yang_parent_name = "send"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                            self._leafs = OrderedDict()

                                                            self.cc_range = YList(self)
                                                            self._segment_path = lambda: "cost-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                        class CcRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Community ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: poi
                                                            
                                                            	Point of insertion
                                                            	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                                self.yang_name = "cc-range"
                                                                self.yang_parent_name = "cost-community"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ])
                                                                self.range = None

                                                                self.poi = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                                self.poi.parent = self
                                                                self._children_name_map["poi"] = "poi"
                                                                self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                            class Poi(Entity):
                                                                """
                                                                Point of insertion
                                                                
                                                                .. attribute:: igp_cost
                                                                
                                                                	Point of insertion after IGP
                                                                	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                                
                                                                	**presence node**\: True
                                                                
                                                                .. attribute:: pre_bestpath
                                                                
                                                                	Point of insertion at beginning
                                                                	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                                
                                                                	**presence node**\: True
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                    self.yang_name = "poi"
                                                                    self.yang_parent_name = "cc-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                    self._leafs = OrderedDict()

                                                                    self.igp_cost = None
                                                                    self._children_name_map["igp_cost"] = "igp-cost"

                                                                    self.pre_bestpath = None
                                                                    self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                    self._segment_path = lambda: "poi"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                                class IgpCost(Entity):
                                                                    """
                                                                    Point of insertion after IGP
                                                                    
                                                                    .. attribute:: transitive
                                                                    
                                                                    	Cost community is transitive
                                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                    
                                                                    

                                                                    This class is a :ref:`presence class<presence-class>`

                                                                    """

                                                                    _prefix = 'ios-bgp'
                                                                    _revision = '2018-06-28'

                                                                    def __init__(self):
                                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                        self.yang_name = "igp-cost"
                                                                        self.yang_parent_name = "poi"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self.is_presence_container = True
                                                                        self._leafs = OrderedDict([
                                                                            ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                        ])
                                                                        self.transitive = None
                                                                        self._segment_path = lambda: "igp-cost"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                                class PreBestpath(Entity):
                                                                    """
                                                                    Point of insertion at beginning
                                                                    
                                                                    .. attribute:: transitive
                                                                    
                                                                    	Cost community is transitive
                                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                    
                                                                    

                                                                    This class is a :ref:`presence class<presence-class>`

                                                                    """

                                                                    _prefix = 'ios-bgp'
                                                                    _revision = '2018-06-28'

                                                                    def __init__(self):
                                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                        self.yang_name = "pre-bestpath"
                                                                        self.yang_parent_name = "poi"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self.is_presence_container = True
                                                                        self._leafs = OrderedDict([
                                                                            ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                        ])
                                                                        self.transitive = None
                                                                        self._segment_path = lambda: "pre-bestpath"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Announce(Entity):
                                                """
                                                Announce RPKI state using an extended community
                                                
                                                .. attribute:: rpki
                                                
                                                	Announce RPKI information using an extended community
                                                	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce, self).__init__()

                                                    self.yang_name = "announce"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki))])
                                                    self._leafs = OrderedDict()

                                                    self.rpki = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki()
                                                    self.rpki.parent = self
                                                    self._children_name_map["rpki"] = "rpki"
                                                    self._segment_path = lambda: "announce"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce, [], name, value)


                                                class Rpki(Entity):
                                                    """
                                                    Announce RPKI information using an extended community
                                                    
                                                    .. attribute:: state
                                                    
                                                    	Announce RPKI state information using an extended community
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki, self).__init__()

                                                        self.yang_name = "rpki"
                                                        self.yang_parent_name = "announce"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                        ])
                                                        self.state = None
                                                        self._segment_path = lambda: "rpki"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki, ['state'], name, value)


                                            class AsOverride(Entity):
                                                """
                                                Override matching AS\-number while sending update
                                                
                                                .. attribute:: disable
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride, self).__init__()

                                                    self.yang_name = "as-override"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "as-override"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride, ['disable'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class DefaultOriginate(Entity):
                                                """
                                                Originate default route to this neighbor
                                                
                                                .. attribute:: route_map
                                                
                                                	Route\-map to specify criteria to originate default
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                    self.yang_name = "default-originate"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default-originate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SendLabel(Entity):
                                                """
                                                Send NLRI + MPLS Label to this peer
                                                
                                                .. attribute:: send_label_explicit
                                                
                                                	
                                                	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel, self).__init__()

                                                    self.yang_name = "send-label"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit')])),
                                                    ])
                                                    self.send_label_explicit = None
                                                    self._segment_path = lambda: "send-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                                class SendLabelExplicit(Enum):
                                                    """
                                                    SendLabelExplicit (Enum Class)

                                                    .. data:: explicit_null = 0

                                                    """

                                                    explicit_null = Enum.YLeaf(0, "explicit-null")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                            class TranslateUpdate(Entity):
                                                """
                                                Translate update to MBGP format
                                                
                                                .. attribute:: ipv4
                                                
                                                	Address Family
                                                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate, self).__init__()

                                                    self.yang_name = "translate-update"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv4 = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4()
                                                    self.ipv4.parent = self
                                                    self._children_name_map["ipv4"] = "ipv4"
                                                    self._segment_path = lambda: "translate-update"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate, [], name, value)


                                                class Ipv4(Entity):
                                                    """
                                                    Address Family
                                                    
                                                    .. attribute:: multicast
                                                    
                                                    	Address Family modifier
                                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4, self).__init__()

                                                        self.yang_name = "ipv4"
                                                        self.yang_parent_name = "translate-update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast))])
                                                        self._leafs = OrderedDict()

                                                        self.multicast = None
                                                        self._children_name_map["multicast"] = "multicast"
                                                        self._segment_path = lambda: "ipv4"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4, [], name, value)


                                                    class Multicast(Entity):
                                                        """
                                                        Address Family modifier
                                                        
                                                        .. attribute:: unicast
                                                        
                                                        	Address Family modifier
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast, self).__init__()

                                                            self.yang_name = "multicast"
                                                            self.yang_parent_name = "ipv4"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                            ])
                                                            self.unicast = None
                                                            self._segment_path = lambda: "multicast"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast, ['unicast'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: additional_paths
                                        
                                        	
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths>`
                                        
                                        .. attribute:: advertise
                                        
                                        	Advertise to this neighbor
                                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise>`
                                        
                                        .. attribute:: advertise_map
                                        
                                        	specify route\-map for conditional advertisement
                                        	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap>`
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable a AIGP on neighbor
                                        	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: announce
                                        
                                        	Announce RPKI state using an extended community
                                        	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce>`
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability>`
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: send_label
                                        
                                        	Send NLRI + MPLS Label to this peer
                                        	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: translate_update
                                        
                                        	Translate update to MBGP format
                                        	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate>`
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.advertise = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise()
                                            self.advertise.parent = self
                                            self._children_name_map["advertise"] = "advertise"

                                            self.advertise_map = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap()
                                            self.advertise_map.parent = self
                                            self._children_name_map["advertise_map"] = "advertise-map"

                                            self.aigp = None
                                            self._children_name_map["aigp"] = "aigp"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.announce = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce()
                                            self.announce.parent = self
                                            self._children_name_map["announce"] = "announce"

                                            self.as_override = None
                                            self._children_name_map["as_override"] = "as-override"

                                            self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.send_label = None
                                            self._children_name_map["send_label"] = "send-label"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.translate_update = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate()
                                            self.translate_update.parent = self
                                            self._children_name_map["translate_update"] = "translate-update"

                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor, ['id', 'activate', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AdditionalPaths(Entity):
                                            """
                                            
                                            
                                            .. attribute:: disable
                                            
                                            	Disable additional paths for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to this neighbor
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self.receive = None

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to this neighbor
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                        class Advertise(Entity):
                                            """
                                            Advertise to this neighbor
                                            
                                            .. attribute:: additional_paths
                                            
                                            	Advertise additional paths
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Advertise best\-external (at RRs best\-internal) path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: diverse_path
                                            
                                            	Advertise diverse path
                                            	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise, self).__init__()

                                                self.yang_name = "advertise"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath))])
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.diverse_path = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath()
                                                self.diverse_path.parent = self
                                                self._children_name_map["diverse_path"] = "diverse-path"
                                                self._segment_path = lambda: "advertise"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                            class AdditionalPaths(Entity):
                                                """
                                                Advertise additional paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "best-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                            class DiversePath(Entity):
                                                """
                                                Advertise diverse path
                                                
                                                .. attribute:: backup
                                                
                                                	Diverse path can be backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                                    self.yang_name = "diverse-path"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"
                                                    self._segment_path = lambda: "diverse-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Diverse path can be backup path
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "diverse-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                        class AdvertiseMap(Entity):
                                            """
                                            specify route\-map for conditional advertisement
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap, self).__init__()

                                                self.yang_name = "advertise-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name))])
                                                self._leafs = OrderedDict()

                                                self.name = YList(self)
                                                self._segment_path = lambda: "advertise-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap, [], name, value)


                                            class Name(Entity):
                                                """
                                                
                                                
                                                .. attribute:: word  (key)
                                                
                                                	advertise route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: non_exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name, self).__init__()

                                                    self.yang_name = "name"
                                                    self.yang_parent_name = "advertise-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                        ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                        ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                    ])
                                                    self.word = None
                                                    self.exist_map = None
                                                    self.non_exist_map = None
                                                    self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                        class Aigp(Entity):
                                            """
                                            Enable a AIGP on neighbor
                                            
                                            .. attribute:: send
                                            
                                            	Cost community or MED carrying AIGP VALUE
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp, self).__init__()

                                                self.yang_name = "aigp"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.send = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send()
                                                self.send.parent = self
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "aigp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp, [], name, value)


                                            class Send(Entity):
                                                """
                                                Cost community or MED carrying AIGP VALUE
                                                
                                                .. attribute:: cost_community
                                                
                                                	Cost extended community carrying AIGP Value
                                                	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity>`
                                                
                                                .. attribute:: med
                                                
                                                	Med carrying AIGP Value
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "aigp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                    ])
                                                    self.med = None

                                                    self.cost_community = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity()
                                                    self.cost_community.parent = self
                                                    self._children_name_map["cost_community"] = "cost-community"
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send, ['med'], name, value)


                                                class CostCommunity(Entity):
                                                    """
                                                    Cost extended community carrying AIGP Value
                                                    
                                                    .. attribute:: cc_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                        self.yang_name = "cost-community"
                                                        self.yang_parent_name = "send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                        self._leafs = OrderedDict()

                                                        self.cc_range = YList(self)
                                                        self._segment_path = lambda: "cost-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                    class CcRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Community ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: poi
                                                        
                                                        	Point of insertion
                                                        	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                            self.yang_name = "cc-range"
                                                            self.yang_parent_name = "cost-community"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ])
                                                            self.range = None

                                                            self.poi = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                            self.poi.parent = self
                                                            self._children_name_map["poi"] = "poi"
                                                            self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                        class Poi(Entity):
                                                            """
                                                            Point of insertion
                                                            
                                                            .. attribute:: igp_cost
                                                            
                                                            	Point of insertion after IGP
                                                            	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            .. attribute:: pre_bestpath
                                                            
                                                            	Point of insertion at beginning
                                                            	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                self.yang_name = "poi"
                                                                self.yang_parent_name = "cc-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                self._leafs = OrderedDict()

                                                                self.igp_cost = None
                                                                self._children_name_map["igp_cost"] = "igp-cost"

                                                                self.pre_bestpath = None
                                                                self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                self._segment_path = lambda: "poi"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                            class IgpCost(Entity):
                                                                """
                                                                Point of insertion after IGP
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                    self.yang_name = "igp-cost"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "igp-cost"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                            class PreBestpath(Entity):
                                                                """
                                                                Point of insertion at beginning
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                    self.yang_name = "pre-bestpath"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "pre-bestpath"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Announce(Entity):
                                            """
                                            Announce RPKI state using an extended community
                                            
                                            .. attribute:: rpki
                                            
                                            	Announce RPKI information using an extended community
                                            	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce, self).__init__()

                                                self.yang_name = "announce"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki))])
                                                self._leafs = OrderedDict()

                                                self.rpki = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki()
                                                self.rpki.parent = self
                                                self._children_name_map["rpki"] = "rpki"
                                                self._segment_path = lambda: "announce"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce, [], name, value)


                                            class Rpki(Entity):
                                                """
                                                Announce RPKI information using an extended community
                                                
                                                .. attribute:: state
                                                
                                                	Announce RPKI state information using an extended community
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki, self).__init__()

                                                    self.yang_name = "rpki"
                                                    self.yang_parent_name = "announce"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                    ])
                                                    self.state = None
                                                    self._segment_path = lambda: "rpki"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki, ['state'], name, value)


                                        class AsOverride(Entity):
                                            """
                                            Override matching AS\-number while sending update
                                            
                                            .. attribute:: disable
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride, self).__init__()

                                                self.yang_name = "as-override"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "as-override"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride, ['disable'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SendLabel(Entity):
                                            """
                                            Send NLRI + MPLS Label to this peer
                                            
                                            .. attribute:: send_label_explicit
                                            
                                            	
                                            	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel.SendLabelExplicit>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel, self).__init__()

                                                self.yang_name = "send-label"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel.SendLabelExplicit')])),
                                                ])
                                                self.send_label_explicit = None
                                                self._segment_path = lambda: "send-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                            class SendLabelExplicit(Enum):
                                                """
                                                SendLabelExplicit (Enum Class)

                                                .. data:: explicit_null = 0

                                                """

                                                explicit_null = Enum.YLeaf(0, "explicit-null")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class TranslateUpdate(Entity):
                                            """
                                            Translate update to MBGP format
                                            
                                            .. attribute:: ipv4
                                            
                                            	Address Family
                                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate, self).__init__()

                                                self.yang_name = "translate-update"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4))])
                                                self._leafs = OrderedDict()

                                                self.ipv4 = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4()
                                                self.ipv4.parent = self
                                                self._children_name_map["ipv4"] = "ipv4"
                                                self._segment_path = lambda: "translate-update"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate, [], name, value)


                                            class Ipv4(Entity):
                                                """
                                                Address Family
                                                
                                                .. attribute:: multicast
                                                
                                                	Address Family modifier
                                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4, self).__init__()

                                                    self.yang_name = "ipv4"
                                                    self.yang_parent_name = "translate-update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast))])
                                                    self._leafs = OrderedDict()

                                                    self.multicast = None
                                                    self._children_name_map["multicast"] = "multicast"
                                                    self._segment_path = lambda: "ipv4"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4, [], name, value)


                                                class Multicast(Entity):
                                                    """
                                                    Address Family modifier
                                                    
                                                    .. attribute:: unicast
                                                    
                                                    	Address Family modifier
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast, self).__init__()

                                                        self.yang_name = "multicast"
                                                        self.yang_parent_name = "ipv4"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                        ])
                                                        self.unicast = None
                                                        self._segment_path = lambda: "multicast"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast, ['unicast'], name, value)


                                    class Network(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: number  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to modify the attributes
                                        	**type**\: str
                                        
                                        .. attribute:: backdoor
                                        
                                        	Specify a BGP backdoor route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['number']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.route_map = None
                                            self.backdoor = None
                                            self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network, ['number', 'route_map', 'backdoor'], name, value)


                                    class Redistribute(Entity):
                                        """
                                        Redistribute information from another routing protocol
                                        
                                        .. attribute:: application
                                        
                                        	Application
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dvmrp
                                        
                                        	Redistribution of DVMRP into BGP IPv4 Multicast
                                        	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator/ID Separation Protocol
                                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: iso_igrp
                                        
                                        	IGRP for OSI networks
                                        	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile routes
                                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: odr
                                        
                                        	On Demand stub Routes
                                        	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf>`
                                        
                                        .. attribute:: ospfv3
                                        
                                        	OSPFv3
                                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute, self).__init__()

                                            self.yang_name = "redistribute"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.dvmrp = None
                                            self._children_name_map["dvmrp"] = "dvmrp"

                                            self.eigrp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"

                                            self.isis = None
                                            self._children_name_map["isis"] = "isis"

                                            self.lisp = None
                                            self._children_name_map["lisp"] = "lisp"

                                            self.iso_igrp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp()
                                            self.iso_igrp.parent = self
                                            self._children_name_map["iso_igrp"] = "iso-igrp"

                                            self.mobile = None
                                            self._children_name_map["mobile"] = "mobile"

                                            self.odr = None
                                            self._children_name_map["odr"] = "odr"

                                            self.rip = None
                                            self._children_name_map["rip"] = "rip"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.ospf = YList(self)
                                            self.ospfv3 = YList(self)
                                            self._segment_path = lambda: "redistribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.name = YList(self)
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application, [], name, value)


                                            class Name(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	WORD \:\: Route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name, self).__init__()

                                                    self.yang_name = "name"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                        class Bgp_(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.as_no = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                        class Dvmrp(Entity):
                                            """
                                            Redistribution of DVMRP into BGP IPv4 Multicast
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp, self).__init__()

                                                self.yang_name = "dvmrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "dvmrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.as_no = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: isis_area
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea>`
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.default = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default()
                                                self.default.parent = self
                                                self._children_name_map["default"] = "default"

                                                self.isis_area = YList(self)
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis, [], name, value)


                                            class IsisArea(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of IP dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: clns
                                                
                                                	Redistribution of OSI dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: routes
                                                
                                                	
                                                	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea.Routes>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea, self).__init__()

                                                    self.yang_name = "isis-area"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                        ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                        ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea.Routes')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.ip = None
                                                    self.clns = None
                                                    self.routes = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                                class Routes(Enum):
                                                    """
                                                    Routes (Enum Class)

                                                    .. data:: level_1 = 0

                                                    .. data:: level_2 = 1

                                                    .. data:: level_1_2 = 2

                                                    """

                                                    level_1 = Enum.YLeaf(0, "level-1")

                                                    level_2 = Enum.YLeaf(1, "level-2")

                                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class Default(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of IP dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: clns
                                                
                                                	Redistribution of OSI dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: routes
                                                
                                                	
                                                	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default.Routes>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default, self).__init__()

                                                    self.yang_name = "default"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                        ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                        ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default.Routes')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.ip = None
                                                    self.clns = None
                                                    self.routes = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                                class Routes(Enum):
                                                    """
                                                    Routes (Enum Class)

                                                    .. data:: level_1 = 0

                                                    .. data:: level_2 = 1

                                                    .. data:: level_1_2 = 2

                                                    """

                                                    level_1 = Enum.YLeaf(0, "level-1")

                                                    level_2 = Enum.YLeaf(1, "level-2")

                                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class Lisp(Entity):
                                            """
                                            Locator/ID Separation Protocol
                                            
                                            .. attribute:: include_connected
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp, self).__init__()

                                                self.yang_name = "lisp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.include_connected = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "lisp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                        class IsoIgrp(Entity):
                                            """
                                            IGRP for OSI networks
                                            
                                            .. attribute:: iso_igrp_area
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp, self).__init__()

                                                self.yang_name = "iso-igrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default))])
                                                self._leafs = OrderedDict()

                                                self.default = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default()
                                                self.default.parent = self
                                                self._children_name_map["default"] = "default"

                                                self.iso_igrp_area = YList(self)
                                                self._segment_path = lambda: "iso-igrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp, [], name, value)


                                            class IsoIgrpArea(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                                    self.yang_name = "iso-igrp-area"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.name = None
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                            class Default(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default, self).__init__()

                                                    self.yang_name = "default"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "default"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                        class Mobile(Entity):
                                            """
                                            Mobile routes
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "mobile"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                        class Odr(Entity):
                                            """
                                            On Demand stub Routes
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr, self).__init__()

                                                self.yang_name = "odr"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "odr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: vrf
                                            
                                            	VPN Routing/Forwarding Instance
                                            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf>`
                                            
                                            .. attribute:: non_vrf
                                            
                                            	
                                            	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf)), ("non-vrf", ("non_vrf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.non_vrf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf()
                                                self.non_vrf.parent = self
                                                self._children_name_map["non_vrf"] = "non-vrf"

                                                self.vrf = YList(self)
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf, ['id'], name, value)


                                            class Vrf(Entity):
                                                """
                                                VPN Routing/Forwarding Instance
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: match
                                                
                                                	
                                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf.Match>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf.Match))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.metric = None
                                                    self.route_map = None

                                                    self.match = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf.Match()
                                                    self.match.parent = self
                                                    self._children_name_map["match"] = "match"
                                                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf, ['name', 'metric', 'route_map'], name, value)


                                                class Match(Entity):
                                                    """
                                                    
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf.Match, self).__init__()

                                                        self.yang_name = "match"
                                                        self.yang_parent_name = "vrf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict()
                                                        self._segment_path = lambda: "match"
                                                        self._is_frozen = True


                                            class NonVrf(Entity):
                                                """
                                                
                                                
                                                .. attribute:: match
                                                
                                                	
                                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf, self).__init__()

                                                    self.yang_name = "non-vrf"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match))])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.metric = None
                                                    self.route_map = None

                                                    self.match = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match()
                                                    self.match.parent = self
                                                    self._children_name_map["match"] = "match"
                                                    self._segment_path = lambda: "non-vrf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                                class Match(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: internal
                                                    
                                                    	Redistribute OSPF internal routes
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: external
                                                    
                                                    	Redistribute OSPF external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: external2
                                                    
                                                    	Redistribute OSPF external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: nssa_external
                                                    
                                                    	Redistribute OSPF NSSA external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric for redistributed routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map reference
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                        self.yang_name = "match"
                                                        self.yang_parent_name = "non-vrf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                            ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.internal = None
                                                        self.external = None
                                                        self.external2 = None
                                                        self.nssa_external = None
                                                        self.metric = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "match"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                        class Ospfv3(Entity):
                                            """
                                            OSPFv3
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3, self).__init__()

                                                self.yang_name = "ospfv3"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.id = None
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                .. attribute:: internal
                                                
                                                	Redistribute OSPF internal routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: external
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: external2
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: nssa_external
                                                
                                                	Redistribute OSPF NSSA external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "ospfv3"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                        ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.internal = None
                                                    self.external = None
                                                    self.external2 = None
                                                    self.nssa_external = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: name
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self.name = None
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ip
                                            
                                            	
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None

                                                self.clns = None
                                                self._children_name_map["clns"] = "clns"

                                                self.ip = None
                                                self._children_name_map["ip"] = "ip"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                            class Clns(Entity):
                                                """
                                                Redistribution of OSI dynamic routes
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns, self).__init__()

                                                    self.yang_name = "clns"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "clns"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                            class Ip(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                                    class TableMap(Entity):
                                        """
                                        Map external entry attributes into routing table
                                        
                                        .. attribute:: name
                                        
                                        	WORD \:\: Route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: filter
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap, self).__init__()

                                            self.yang_name = "table-map"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                                            ])
                                            self.name = None
                                            self.filter = None
                                            self._segment_path = lambda: "table-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap, ['name', 'filter'], name, value)


                            class Vpnv4(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.AfName>`
                                
                                .. attribute:: vpnv4_unicast
                                
                                	VPNv4 Unicast address family
                                	**type**\:  :py:class:`Vpnv4Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4, self).__init__()

                                    self.yang_name = "vpnv4"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("vpnv4-unicast", ("vpnv4_unicast", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.AfName')])),
                                    ])
                                    self.af_name = None

                                    self.vpnv4_unicast = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast()
                                    self.vpnv4_unicast.parent = self
                                    self._children_name_map["vpnv4_unicast"] = "vpnv4-unicast"
                                    self._segment_path = lambda: "vpnv4" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4, ['af_name'], name, value)

                                class AfName(Enum):
                                    """
                                    AfName (Enum Class)

                                    .. data:: unicast = 0

                                    .. data:: multicast = 1

                                    .. data:: flowspec = 2

                                    """

                                    unicast = Enum.YLeaf(0, "unicast")

                                    multicast = Enum.YLeaf(1, "multicast")

                                    flowspec = Enum.YLeaf(2, "flowspec")



                                class Vpnv4Unicast(Entity):
                                    """
                                    VPNv4 Unicast address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_>`
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor>`
                                    
                                    .. attribute:: network
                                    
                                    	
                                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast, self).__init__()

                                        self.yang_name = "vpnv4-unicast"
                                        self.yang_parent_name = "vpnv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor)), ("network", ("network", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.network = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network()
                                        self.network.parent = self
                                        self._children_name_map["network"] = "network"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "vpnv4-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Additional paths in the BGP table
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths>`
                                        
                                        .. attribute:: advertise_best_external
                                        
                                        	Advertise best external path to internal peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Configure aggregation timer
                                        	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer>`
                                        
                                        .. attribute:: bestpath
                                        
                                        	Change the default bestpath selection
                                        	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath>`
                                        
                                        .. attribute:: dampening
                                        
                                        	Enable route\-flap dampening
                                        	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: default
                                        
                                        	Configure BGP defaults
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Use DMZ Link Bandwidth as weight for BGP multipaths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop>`
                                        
                                        .. attribute:: recursion
                                        
                                        	recursion rule for the nexthops
                                        	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion>`
                                        
                                        .. attribute:: redistribute_internal
                                        
                                        	Allow redistribution of iBGP into IGPs (dangerous)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	bgp route\-map commands
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfig_backup
                                        
                                        	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: update_group
                                        
                                        	Manage peers in bgp update groups
                                        	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening)), ("default", ("default", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup))])
                                            self._leafs = OrderedDict([
                                                ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                                ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                            ])
                                            self.advertise_best_external = None
                                            self.dmzlink_bw = None
                                            self.redistribute_internal = None
                                            self.scan_time = None
                                            self.soft_reconfig_backup = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.aggregate_timer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer()
                                            self.aggregate_timer.parent = self
                                            self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                            self.bestpath = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath()
                                            self.bestpath.parent = self
                                            self._children_name_map["bestpath"] = "bestpath"

                                            self.dampening = None
                                            self._children_name_map["dampening"] = "dampening"

                                            self.default = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.nexthop = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.recursion = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion()
                                            self.recursion.parent = self
                                            self._children_name_map["recursion"] = "recursion"

                                            self.route_map = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap()
                                            self.route_map.parent = self
                                            self._children_name_map["route_map"] = "route-map"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup()
                                            self.update_group.parent = self
                                            self._children_name_map["update_group"] = "update-group"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Additional paths in the BGP table
                                            
                                            .. attribute:: install
                                            
                                            	Additional paths to install into RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: select
                                            
                                            	Selection criteria to pick the paths
                                            	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to neighbors
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.install = None
                                                self.receive = None

                                                self.select = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select()
                                                self.select.parent = self
                                                self._children_name_map["select"] = "select"

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                            class Select(Entity):
                                                """
                                                Selection criteria to pick the paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                    self.yang_name = "select"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"

                                                    self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.best_external = None
                                                    self._children_name_map["best_external"] = "best-external"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "select"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                            self._leafs = OrderedDict()

                                                            self.range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                        class Range(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best path
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                                self.yang_name = "range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Select backup path
                                                    
                                                    .. attribute:: best_external
                                                    
                                                    	Select best\-external path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                        ])
                                                        self.best_external = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best path
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                                class BestExternal(Entity):
                                                    """
                                                    Select best\-external path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Select backup path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                        self.yang_name = "best-external"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                        ])
                                                        self.backup = None
                                                        self._segment_path = lambda: "best-external"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to neighbors
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                        class AggregateTimer(Entity):
                                            """
                                            Configure aggregation timer
                                            
                                            .. attribute:: aggregate_timer
                                            
                                            	Timer interval
                                            	**type**\: int
                                            
                                            	**range:** 6..60
                                            
                                            .. attribute:: disable_timer
                                            
                                            	Timer interval
                                            	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer, self).__init__()

                                                self.yang_name = "aggregate-timer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                    ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                                ])
                                                self.aggregate_timer = None
                                                self.disable_timer = None
                                                self._segment_path = lambda: "aggregate-timer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                            class DisableTimer(Enum):
                                                """
                                                DisableTimer (Enum Class)

                                                Timer interval

                                                .. data:: Y_0 = 0

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")



                                        class Bestpath(Entity):
                                            """
                                            Change the default bestpath selection
                                            
                                            .. attribute:: igp_metric
                                            
                                            	igp metric
                                            	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric>`
                                            
                                            .. attribute:: prefix_validate
                                            
                                            	Prefix origin validation
                                            	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath, self).__init__()

                                                self.yang_name = "bestpath"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate))])
                                                self._leafs = OrderedDict()

                                                self.igp_metric = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric()
                                                self.igp_metric.parent = self
                                                self._children_name_map["igp_metric"] = "igp-metric"

                                                self.prefix_validate = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate()
                                                self.prefix_validate.parent = self
                                                self._children_name_map["prefix_validate"] = "prefix-validate"
                                                self._segment_path = lambda: "bestpath"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath, [], name, value)


                                            class IgpMetric(Entity):
                                                """
                                                igp metric
                                                
                                                .. attribute:: ignore
                                                
                                                	Ignore igp metric in bestpath selection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                                    self.yang_name = "igp-metric"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ])
                                                    self.ignore = None
                                                    self._segment_path = lambda: "igp-metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                            class PrefixValidate(Entity):
                                                """
                                                Prefix origin validation
                                                
                                                .. attribute:: allow_invalid
                                                
                                                	Allow invalid routes to be considered for bestpath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: disable
                                                
                                                	Disable prefix validation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                                    self.yang_name = "prefix-validate"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.allow_invalid = None
                                                    self.disable = None
                                                    self._segment_path = lambda: "prefix-validate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                        class Dampening(Entity):
                                            """
                                            Enable route\-flap dampening
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria for dampening
                                            	**type**\: str
                                            
                                            .. attribute:: dampen
                                            
                                            	
                                            	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening, self).__init__()

                                                self.yang_name = "dampening"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.dampen = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen()
                                                self.dampen.parent = self
                                                self._children_name_map["dampen"] = "dampen"
                                                self._segment_path = lambda: "dampening"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                            class Dampen(Entity):
                                                """
                                                
                                                
                                                .. attribute:: half_life_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..45
                                                
                                                .. attribute:: reuse_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: max_suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                                    self.yang_name = "dampen"
                                                    self.yang_parent_name = "dampening"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                        ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                        ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                        ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                    ])
                                                    self.half_life_time = None
                                                    self.reuse_time = None
                                                    self.suppress_time = None
                                                    self.max_suppress_time = None
                                                    self._segment_path = lambda: "dampen"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                        class Default(Entity):
                                            """
                                            Configure BGP defaults
                                            
                                            .. attribute:: route_target
                                            
                                            	Control behavior based on Route\-Target attributes
                                            	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default.RouteTarget>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default.RouteTarget')])),
                                                ])
                                                self.route_target = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default, ['route_target'], name, value)

                                            class RouteTarget(Enum):
                                                """
                                                RouteTarget (Enum Class)

                                                Control behavior based on Route\-Target attributes

                                                .. data:: filter = 0

                                                """

                                                filter = Enum.YLeaf(0, "filter")



                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class Recursion(Entity):
                                            """
                                            recursion rule for the nexthops
                                            
                                            .. attribute:: host
                                            
                                            	recursion via host for the nexthops
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion, self).__init__()

                                                self.yang_name = "recursion"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                                ])
                                                self.host = None
                                                self._segment_path = lambda: "recursion"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion, ['host'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            bgp route\-map commands
                                            
                                            .. attribute:: priority
                                            
                                            	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class UpdateGroup(Entity):
                                            """
                                            Manage peers in bgp update groups
                                            
                                            .. attribute:: split
                                            
                                            	Split update groups based on Policy
                                            	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup, self).__init__()

                                                self.yang_name = "update-group"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split))])
                                                self._leafs = OrderedDict()

                                                self.split = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split()
                                                self.split.parent = self
                                                self._children_name_map["split"] = "split"
                                                self._segment_path = lambda: "update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup, [], name, value)


                                            class Split(Entity):
                                                """
                                                Split update groups based on Policy
                                                
                                                .. attribute:: as_override
                                                
                                                	Keep peers with as\-override in different update groups
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                                    self.yang_name = "split"
                                                    self.yang_parent_name = "update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                    ])
                                                    self.as_override = None
                                                    self._segment_path = lambda: "split"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: advertise
                                            
                                            	Advertise to this neighbor
                                            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: distribute_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList>`
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: send_label
                                            
                                            	Send NLRI + MPLS Label to this peer
                                            	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.advertise = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise()
                                                self.advertise.parent = self
                                                self._children_name_map["advertise"] = "advertise"

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.send_label = None
                                                self._children_name_map["send_label"] = "send-label"

                                                self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.distribute_list = YList(self)
                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class Advertise(Entity):
                                                """
                                                Advertise to this neighbor
                                                
                                                .. attribute:: additional_paths
                                                
                                                	Advertise additional paths
                                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Advertise best\-external (at RRs best\-internal) path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: diverse_path
                                                
                                                	Advertise diverse path
                                                	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                                    self.yang_name = "advertise"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None

                                                    self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                                    self.additional_paths.parent = self
                                                    self._children_name_map["additional_paths"] = "additional-paths"

                                                    self.diverse_path = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                                    self.diverse_path.parent = self
                                                    self._children_name_map["diverse_path"] = "diverse-path"
                                                    self._segment_path = lambda: "advertise"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                                class AdditionalPaths(Entity):
                                                    """
                                                    Advertise additional paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                        self.yang_name = "additional-paths"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                        self._leafs = OrderedDict()

                                                        self.all = None
                                                        self._children_name_map["all"] = "all"

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "additional-paths"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                    class All(Entity):
                                                        """
                                                        Select all available paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Select best N paths
                                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                            self.yang_name = "all"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict()

                                                            self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                            self.best.parent = self
                                                            self._children_name_map["best"] = "best"

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "all"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                        class Best(Entity):
                                                            """
                                                            Select best N paths
                                                            
                                                            .. attribute:: best_range
                                                            
                                                            	
                                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                                self.yang_name = "best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                                self._leafs = OrderedDict()

                                                                self.best_range = YList(self)
                                                                self._segment_path = lambda: "best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                            class BestRange(Entity):
                                                                """
                                                                
                                                                
                                                                .. attribute:: range  (key)
                                                                
                                                                	Number of best paths in additional paths to be selected
                                                                	**type**\: int
                                                                
                                                                	**range:** 2..3
                                                                
                                                                .. attribute:: group_best
                                                                
                                                                	Select group\-best paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                    self.yang_name = "best-range"
                                                                    self.yang_parent_name = "best"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['range']
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                    ])
                                                                    self.range = None
                                                                    self.group_best = None
                                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: best
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                                ])
                                                                self.best = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.all = None

                                                                self.group_best = None
                                                                self._children_name_map["group_best"] = "group-best"
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                            class GroupBest(Entity):
                                                                """
                                                                Select group\-best paths
                                                                
                                                                .. attribute:: all
                                                                
                                                                	Select all available paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                    self.yang_name = "group-best"
                                                                    self.yang_parent_name = "best-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                    ])
                                                                    self.all = None
                                                                    self._segment_path = lambda: "group-best"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.all = None
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                                class DiversePath(Entity):
                                                    """
                                                    Advertise diverse path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Diverse path can be backup path
                                                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                        self.yang_name = "diverse-path"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None

                                                        self.backup = None
                                                        self._children_name_map["backup"] = "backup"
                                                        self._segment_path = lambda: "diverse-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                    class Backup(Entity):
                                                        """
                                                        Diverse path can be backup path
                                                        
                                                        .. attribute:: mpath
                                                        
                                                        	Diverse path can be multipath
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                            self.yang_name = "backup"
                                                            self.yang_parent_name = "diverse-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                            ])
                                                            self.mpath = None
                                                            self._segment_path = lambda: "backup"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class DistributeList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                                
                                                .. attribute:: accesslist
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..199
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1300..2699
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** [a\-zA\-Z].\*
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                                    self.yang_name = "distribute-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                        ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                    ])
                                                    self.inout = None
                                                    self.accesslist = None
                                                    self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SendLabel(Entity):
                                                """
                                                Send NLRI + MPLS Label to this peer
                                                
                                                .. attribute:: send_label_explicit
                                                
                                                	
                                                	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel, self).__init__()

                                                    self.yang_name = "send-label"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit')])),
                                                    ])
                                                    self.send_label_explicit = None
                                                    self._segment_path = lambda: "send-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                                class SendLabelExplicit(Enum):
                                                    """
                                                    SendLabelExplicit (Enum Class)

                                                    .. data:: explicit_null = 0

                                                    """

                                                    explicit_null = Enum.YLeaf(0, "explicit-null")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise
                                        
                                        	Advertise to this neighbor
                                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability>`
                                        
                                        .. attribute:: distribute_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: send_label
                                        
                                        	Send NLRI + MPLS Label to this peer
                                        	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.advertise = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise()
                                            self.advertise.parent = self
                                            self._children_name_map["advertise"] = "advertise"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.send_label = None
                                            self._children_name_map["send_label"] = "send-label"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.distribute_list = YList(self)
                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class Advertise(Entity):
                                            """
                                            Advertise to this neighbor
                                            
                                            .. attribute:: additional_paths
                                            
                                            	Advertise additional paths
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Advertise best\-external (at RRs best\-internal) path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: diverse_path
                                            
                                            	Advertise diverse path
                                            	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise, self).__init__()

                                                self.yang_name = "advertise"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath))])
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.diverse_path = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath()
                                                self.diverse_path.parent = self
                                                self._children_name_map["diverse_path"] = "diverse-path"
                                                self._segment_path = lambda: "advertise"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                            class AdditionalPaths(Entity):
                                                """
                                                Advertise additional paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "best-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                            class DiversePath(Entity):
                                                """
                                                Advertise diverse path
                                                
                                                .. attribute:: backup
                                                
                                                	Diverse path can be backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                                    self.yang_name = "diverse-path"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"
                                                    self._segment_path = lambda: "diverse-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Diverse path can be backup path
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "diverse-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DistributeList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList.Inout>`
                                            
                                            .. attribute:: accesslist
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..199
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..2699
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList, self).__init__()

                                                self.yang_name = "distribute-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList.Inout')])),
                                                    ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                ])
                                                self.inout = None
                                                self.accesslist = None
                                                self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SendLabel(Entity):
                                            """
                                            Send NLRI + MPLS Label to this peer
                                            
                                            .. attribute:: send_label_explicit
                                            
                                            	
                                            	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel.SendLabelExplicit>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel, self).__init__()

                                                self.yang_name = "send-label"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel.SendLabelExplicit')])),
                                                ])
                                                self.send_label_explicit = None
                                                self._segment_path = lambda: "send-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                            class SendLabelExplicit(Enum):
                                                """
                                                SendLabelExplicit (Enum Class)

                                                .. data:: explicit_null = 0

                                                """

                                                explicit_null = Enum.YLeaf(0, "explicit-null")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Network(Entity):
                                        """
                                        
                                        
                                        .. attribute:: with_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask>`
                                        
                                        .. attribute:: no_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask))])
                                            self._leafs = OrderedDict()

                                            self.with_mask = YList(self)
                                            self.no_mask = YList(self)
                                            self._segment_path = lambda: "network"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network, [], name, value)


                                        class WithMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mask  (key)
                                            
                                            	Network mask
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask, self).__init__()

                                                self.yang_name = "with-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number','mask']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.mask = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor'], name, value)


                                        class NoMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask, self).__init__()

                                                self.yang_name = "no-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask, ['number', 'route_map', 'backdoor'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class Vpnv6(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.AfName>`
                                
                                .. attribute:: vpnv6_unicast
                                
                                	VPNv6 Unicast address family
                                	**type**\:  :py:class:`Vpnv6Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6, self).__init__()

                                    self.yang_name = "vpnv6"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("vpnv6-unicast", ("vpnv6_unicast", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.AfName')])),
                                    ])
                                    self.af_name = None

                                    self.vpnv6_unicast = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast()
                                    self.vpnv6_unicast.parent = self
                                    self._children_name_map["vpnv6_unicast"] = "vpnv6-unicast"
                                    self._segment_path = lambda: "vpnv6" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6, ['af_name'], name, value)

                                class AfName(Enum):
                                    """
                                    AfName (Enum Class)

                                    .. data:: unicast = 0

                                    .. data:: multicast = 1

                                    .. data:: flowspec = 2

                                    """

                                    unicast = Enum.YLeaf(0, "unicast")

                                    multicast = Enum.YLeaf(1, "multicast")

                                    flowspec = Enum.YLeaf(2, "flowspec")



                                class Vpnv6Unicast(Entity):
                                    """
                                    VPNv6 Unicast address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast, self).__init__()

                                        self.yang_name = "vpnv6-unicast"
                                        self.yang_parent_name = "vpnv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.peer_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "vpnv6-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Additional paths in the BGP table
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths>`
                                        
                                        .. attribute:: advertise_best_external
                                        
                                        	Advertise best external path to internal peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Configure aggregation timer
                                        	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer>`
                                        
                                        .. attribute:: bestpath
                                        
                                        	Change the default bestpath selection
                                        	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath>`
                                        
                                        .. attribute:: dampening
                                        
                                        	Enable route\-flap dampening
                                        	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: default
                                        
                                        	Configure BGP defaults
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Use DMZ Link Bandwidth as weight for BGP multipaths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop>`
                                        
                                        .. attribute:: recursion
                                        
                                        	recursion rule for the nexthops
                                        	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion>`
                                        
                                        .. attribute:: redistribute_internal
                                        
                                        	Allow redistribution of iBGP into IGPs (dangerous)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	bgp route\-map commands
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfig_backup
                                        
                                        	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: update_group
                                        
                                        	Manage peers in bgp update groups
                                        	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "vpnv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening)), ("default", ("default", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup))])
                                            self._leafs = OrderedDict([
                                                ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                                ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                            ])
                                            self.advertise_best_external = None
                                            self.dmzlink_bw = None
                                            self.redistribute_internal = None
                                            self.scan_time = None
                                            self.soft_reconfig_backup = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.aggregate_timer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer()
                                            self.aggregate_timer.parent = self
                                            self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                            self.bestpath = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath()
                                            self.bestpath.parent = self
                                            self._children_name_map["bestpath"] = "bestpath"

                                            self.dampening = None
                                            self._children_name_map["dampening"] = "dampening"

                                            self.default = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.nexthop = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.recursion = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion()
                                            self.recursion.parent = self
                                            self._children_name_map["recursion"] = "recursion"

                                            self.route_map = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap()
                                            self.route_map.parent = self
                                            self._children_name_map["route_map"] = "route-map"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup()
                                            self.update_group.parent = self
                                            self._children_name_map["update_group"] = "update-group"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Additional paths in the BGP table
                                            
                                            .. attribute:: install
                                            
                                            	Additional paths to install into RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: select
                                            
                                            	Selection criteria to pick the paths
                                            	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to neighbors
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.install = None
                                                self.receive = None

                                                self.select = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select()
                                                self.select.parent = self
                                                self._children_name_map["select"] = "select"

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                            class Select(Entity):
                                                """
                                                Selection criteria to pick the paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                    self.yang_name = "select"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"

                                                    self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.best_external = None
                                                    self._children_name_map["best_external"] = "best-external"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "select"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                            self._leafs = OrderedDict()

                                                            self.range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                        class Range(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best path
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                                self.yang_name = "range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Select backup path
                                                    
                                                    .. attribute:: best_external
                                                    
                                                    	Select best\-external path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                        ])
                                                        self.best_external = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best path
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                                class BestExternal(Entity):
                                                    """
                                                    Select best\-external path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Select backup path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                        self.yang_name = "best-external"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                        ])
                                                        self.backup = None
                                                        self._segment_path = lambda: "best-external"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to neighbors
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                        class AggregateTimer(Entity):
                                            """
                                            Configure aggregation timer
                                            
                                            .. attribute:: aggregate_timer
                                            
                                            	Timer interval
                                            	**type**\: int
                                            
                                            	**range:** 6..60
                                            
                                            .. attribute:: disable_timer
                                            
                                            	Timer interval
                                            	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer, self).__init__()

                                                self.yang_name = "aggregate-timer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                    ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                                ])
                                                self.aggregate_timer = None
                                                self.disable_timer = None
                                                self._segment_path = lambda: "aggregate-timer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                            class DisableTimer(Enum):
                                                """
                                                DisableTimer (Enum Class)

                                                Timer interval

                                                .. data:: Y_0 = 0

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")



                                        class Bestpath(Entity):
                                            """
                                            Change the default bestpath selection
                                            
                                            .. attribute:: igp_metric
                                            
                                            	igp metric
                                            	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric>`
                                            
                                            .. attribute:: prefix_validate
                                            
                                            	Prefix origin validation
                                            	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath, self).__init__()

                                                self.yang_name = "bestpath"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate))])
                                                self._leafs = OrderedDict()

                                                self.igp_metric = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric()
                                                self.igp_metric.parent = self
                                                self._children_name_map["igp_metric"] = "igp-metric"

                                                self.prefix_validate = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate()
                                                self.prefix_validate.parent = self
                                                self._children_name_map["prefix_validate"] = "prefix-validate"
                                                self._segment_path = lambda: "bestpath"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath, [], name, value)


                                            class IgpMetric(Entity):
                                                """
                                                igp metric
                                                
                                                .. attribute:: ignore
                                                
                                                	Ignore igp metric in bestpath selection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                                    self.yang_name = "igp-metric"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ])
                                                    self.ignore = None
                                                    self._segment_path = lambda: "igp-metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                            class PrefixValidate(Entity):
                                                """
                                                Prefix origin validation
                                                
                                                .. attribute:: allow_invalid
                                                
                                                	Allow invalid routes to be considered for bestpath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: disable
                                                
                                                	Disable prefix validation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                                    self.yang_name = "prefix-validate"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.allow_invalid = None
                                                    self.disable = None
                                                    self._segment_path = lambda: "prefix-validate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                        class Dampening(Entity):
                                            """
                                            Enable route\-flap dampening
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria for dampening
                                            	**type**\: str
                                            
                                            .. attribute:: dampen
                                            
                                            	
                                            	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening, self).__init__()

                                                self.yang_name = "dampening"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.dampen = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen()
                                                self.dampen.parent = self
                                                self._children_name_map["dampen"] = "dampen"
                                                self._segment_path = lambda: "dampening"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                            class Dampen(Entity):
                                                """
                                                
                                                
                                                .. attribute:: half_life_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..45
                                                
                                                .. attribute:: reuse_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: max_suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                                    self.yang_name = "dampen"
                                                    self.yang_parent_name = "dampening"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                        ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                        ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                        ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                    ])
                                                    self.half_life_time = None
                                                    self.reuse_time = None
                                                    self.suppress_time = None
                                                    self.max_suppress_time = None
                                                    self._segment_path = lambda: "dampen"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                        class Default(Entity):
                                            """
                                            Configure BGP defaults
                                            
                                            .. attribute:: route_target
                                            
                                            	Control behavior based on Route\-Target attributes
                                            	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default.RouteTarget>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default.RouteTarget')])),
                                                ])
                                                self.route_target = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default, ['route_target'], name, value)

                                            class RouteTarget(Enum):
                                                """
                                                RouteTarget (Enum Class)

                                                Control behavior based on Route\-Target attributes

                                                .. data:: filter = 0

                                                """

                                                filter = Enum.YLeaf(0, "filter")



                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class Recursion(Entity):
                                            """
                                            recursion rule for the nexthops
                                            
                                            .. attribute:: host
                                            
                                            	recursion via host for the nexthops
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion, self).__init__()

                                                self.yang_name = "recursion"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                                ])
                                                self.host = None
                                                self._segment_path = lambda: "recursion"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion, ['host'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            bgp route\-map commands
                                            
                                            .. attribute:: priority
                                            
                                            	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class UpdateGroup(Entity):
                                            """
                                            Manage peers in bgp update groups
                                            
                                            .. attribute:: split
                                            
                                            	Split update groups based on Policy
                                            	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup, self).__init__()

                                                self.yang_name = "update-group"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split))])
                                                self._leafs = OrderedDict()

                                                self.split = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split()
                                                self.split.parent = self
                                                self._children_name_map["split"] = "split"
                                                self._segment_path = lambda: "update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup, [], name, value)


                                            class Split(Entity):
                                                """
                                                Split update groups based on Policy
                                                
                                                .. attribute:: as_override
                                                
                                                	Keep peers with as\-override in different update groups
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                                    self.yang_name = "split"
                                                    self.yang_parent_name = "update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                    ])
                                                    self.as_override = None
                                                    self._segment_path = lambda: "split"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "vpnv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: advertise
                                            
                                            	Advertise to this neighbor
                                            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: distribute_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList>`
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.advertise = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise()
                                                self.advertise.parent = self
                                                self._children_name_map["advertise"] = "advertise"

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.distribute_list = YList(self)
                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class Advertise(Entity):
                                                """
                                                Advertise to this neighbor
                                                
                                                .. attribute:: additional_paths
                                                
                                                	Advertise additional paths
                                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Advertise best\-external (at RRs best\-internal) path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: diverse_path
                                                
                                                	Advertise diverse path
                                                	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                                    self.yang_name = "advertise"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None

                                                    self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                                    self.additional_paths.parent = self
                                                    self._children_name_map["additional_paths"] = "additional-paths"

                                                    self.diverse_path = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                                    self.diverse_path.parent = self
                                                    self._children_name_map["diverse_path"] = "diverse-path"
                                                    self._segment_path = lambda: "advertise"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                                class AdditionalPaths(Entity):
                                                    """
                                                    Advertise additional paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                        self.yang_name = "additional-paths"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                        self._leafs = OrderedDict()

                                                        self.all = None
                                                        self._children_name_map["all"] = "all"

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "additional-paths"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                    class All(Entity):
                                                        """
                                                        Select all available paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Select best N paths
                                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                            self.yang_name = "all"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict()

                                                            self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                            self.best.parent = self
                                                            self._children_name_map["best"] = "best"

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "all"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                        class Best(Entity):
                                                            """
                                                            Select best N paths
                                                            
                                                            .. attribute:: best_range
                                                            
                                                            	
                                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                                self.yang_name = "best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                                self._leafs = OrderedDict()

                                                                self.best_range = YList(self)
                                                                self._segment_path = lambda: "best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                            class BestRange(Entity):
                                                                """
                                                                
                                                                
                                                                .. attribute:: range  (key)
                                                                
                                                                	Number of best paths in additional paths to be selected
                                                                	**type**\: int
                                                                
                                                                	**range:** 2..3
                                                                
                                                                .. attribute:: group_best
                                                                
                                                                	Select group\-best paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                    self.yang_name = "best-range"
                                                                    self.yang_parent_name = "best"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['range']
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                    ])
                                                                    self.range = None
                                                                    self.group_best = None
                                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: best
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                                ])
                                                                self.best = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.all = None

                                                                self.group_best = None
                                                                self._children_name_map["group_best"] = "group-best"
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                            class GroupBest(Entity):
                                                                """
                                                                Select group\-best paths
                                                                
                                                                .. attribute:: all
                                                                
                                                                	Select all available paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                    self.yang_name = "group-best"
                                                                    self.yang_parent_name = "best-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                    ])
                                                                    self.all = None
                                                                    self._segment_path = lambda: "group-best"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.all = None
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                                class DiversePath(Entity):
                                                    """
                                                    Advertise diverse path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Diverse path can be backup path
                                                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                        self.yang_name = "diverse-path"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None

                                                        self.backup = None
                                                        self._children_name_map["backup"] = "backup"
                                                        self._segment_path = lambda: "diverse-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                    class Backup(Entity):
                                                        """
                                                        Diverse path can be backup path
                                                        
                                                        .. attribute:: mpath
                                                        
                                                        	Diverse path can be multipath
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                            self.yang_name = "backup"
                                                            self.yang_parent_name = "diverse-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                            ])
                                                            self.mpath = None
                                                            self._segment_path = lambda: "backup"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class DistributeList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                                
                                                .. attribute:: accesslist
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..199
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1300..2699
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** [a\-zA\-Z].\*
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                                    self.yang_name = "distribute-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                        ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                    ])
                                                    self.inout = None
                                                    self.accesslist = None
                                                    self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise
                                        
                                        	Advertise to this neighbor
                                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: distribute_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "vpnv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.advertise = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise()
                                            self.advertise.parent = self
                                            self._children_name_map["advertise"] = "advertise"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.distribute_list = YList(self)
                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class Advertise(Entity):
                                            """
                                            Advertise to this neighbor
                                            
                                            .. attribute:: additional_paths
                                            
                                            	Advertise additional paths
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Advertise best\-external (at RRs best\-internal) path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: diverse_path
                                            
                                            	Advertise diverse path
                                            	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise, self).__init__()

                                                self.yang_name = "advertise"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath))])
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.diverse_path = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath()
                                                self.diverse_path.parent = self
                                                self._children_name_map["diverse_path"] = "diverse-path"
                                                self._segment_path = lambda: "advertise"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                            class AdditionalPaths(Entity):
                                                """
                                                Advertise additional paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "best-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                            class DiversePath(Entity):
                                                """
                                                Advertise diverse path
                                                
                                                .. attribute:: backup
                                                
                                                	Diverse path can be backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                                    self.yang_name = "diverse-path"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"
                                                    self._segment_path = lambda: "diverse-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Diverse path can be backup path
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "diverse-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class DistributeList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList.Inout>`
                                            
                                            .. attribute:: accesslist
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..199
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..2699
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList, self).__init__()

                                                self.yang_name = "distribute-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList.Inout')])),
                                                    ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                ])
                                                self.inout = None
                                                self.accesslist = None
                                                self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "vpnv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class Nsap(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.AfName>`
                                
                                .. attribute:: nsap
                                
                                	NSAP address family
                                	**type**\:  :py:class:`Nsap_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap, self).__init__()

                                    self.yang_name = "nsap"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("nsap", ("nsap", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.AfName')])),
                                    ])
                                    self.af_name = None

                                    self.nsap = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_()
                                    self.nsap.parent = self
                                    self._children_name_map["nsap"] = "nsap"
                                    self._segment_path = lambda: "nsap" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap, ['af_name'], name, value)

                                class AfName(Enum):
                                    """
                                    AfName (Enum Class)

                                    .. data:: unicast = 0

                                    """

                                    unicast = Enum.YLeaf(0, "unicast")



                                class Nsap_(Entity):
                                    """
                                    NSAP address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_>`
                                    
                                    .. attribute:: default_information
                                    
                                    	Control distribution of default information
                                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation>`
                                    
                                    .. attribute:: default_metric
                                    
                                    	Set metric of redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor>`
                                    
                                    .. attribute:: network
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Network>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_, self).__init__()

                                        self.yang_name = "nsap"
                                        self.yang_parent_name = "nsap"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor)), ("network", ("network", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Network)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp))])
                                        self._leafs = OrderedDict([
                                            ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                        ])
                                        self.default_metric = None

                                        self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.default_information = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation()
                                        self.default_information.parent = self
                                        self._children_name_map["default_information"] = "default-information"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self.network = YList(self)
                                        self._segment_path = lambda: "nsap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_, ['default_metric'], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Configure aggregation timer
                                        	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer>`
                                        
                                        .. attribute:: dampening
                                        
                                        	Enable route\-flap dampening
                                        	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Use DMZ Link Bandwidth as weight for BGP multipaths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop>`
                                        
                                        .. attribute:: redistribute_internal
                                        
                                        	Allow redistribution of iBGP into IGPs (dangerous)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	bgp route\-map commands
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfig_backup
                                        
                                        	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer)), ("dampening", ("dampening", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                                ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                            ])
                                            self.dmzlink_bw = None
                                            self.redistribute_internal = None
                                            self.scan_time = None
                                            self.soft_reconfig_backup = None

                                            self.aggregate_timer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer()
                                            self.aggregate_timer.parent = self
                                            self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                            self.dampening = None
                                            self._children_name_map["dampening"] = "dampening"

                                            self.nexthop = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.route_map = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap()
                                            self.route_map.parent = self
                                            self._children_name_map["route_map"] = "route-map"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_, ['dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                        class AggregateTimer(Entity):
                                            """
                                            Configure aggregation timer
                                            
                                            .. attribute:: aggregate_timer
                                            
                                            	Timer interval
                                            	**type**\: int
                                            
                                            	**range:** 6..60
                                            
                                            .. attribute:: disable_timer
                                            
                                            	Timer interval
                                            	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer.DisableTimer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer, self).__init__()

                                                self.yang_name = "aggregate-timer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                    ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer.DisableTimer')])),
                                                ])
                                                self.aggregate_timer = None
                                                self.disable_timer = None
                                                self._segment_path = lambda: "aggregate-timer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                            class DisableTimer(Enum):
                                                """
                                                DisableTimer (Enum Class)

                                                Timer interval

                                                .. data:: Y_0 = 0

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")



                                        class Dampening(Entity):
                                            """
                                            Enable route\-flap dampening
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria for dampening
                                            	**type**\: str
                                            
                                            .. attribute:: dampen
                                            
                                            	
                                            	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening, self).__init__()

                                                self.yang_name = "dampening"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.dampen = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen()
                                                self.dampen.parent = self
                                                self._children_name_map["dampen"] = "dampen"
                                                self._segment_path = lambda: "dampening"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening, ['route_map'], name, value)


                                            class Dampen(Entity):
                                                """
                                                
                                                
                                                .. attribute:: half_life_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..45
                                                
                                                .. attribute:: reuse_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: max_suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen, self).__init__()

                                                    self.yang_name = "dampen"
                                                    self.yang_parent_name = "dampening"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                        ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                        ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                        ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                    ])
                                                    self.half_life_time = None
                                                    self.reuse_time = None
                                                    self.suppress_time = None
                                                    self.max_suppress_time = None
                                                    self._segment_path = lambda: "dampen"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            bgp route\-map commands
                                            
                                            .. attribute:: priority
                                            
                                            	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap, ['priority'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class DefaultInformation(Entity):
                                        """
                                        Control distribution of default information
                                        
                                        .. attribute:: originate
                                        
                                        	Distribute a default route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation, self).__init__()

                                            self.yang_name = "default-information"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                            ])
                                            self.originate = None
                                            self._segment_path = lambda: "default-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation, ['originate'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: default_originate
                                            
                                            	Originate default route to this neighbor
                                            	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soo = None
                                                self.weight = None

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.default_originate = None
                                                self._children_name_map["default_originate"] = "default-originate"

                                                self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soo', 'weight'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class DefaultOriginate(Entity):
                                                """
                                                Originate default route to this neighbor
                                                
                                                .. attribute:: route_map
                                                
                                                	Route\-map to specify criteria to originate default
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                    self.yang_name = "default-originate"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default-originate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability>`
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soo = None
                                            self.weight = None

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soo', 'weight'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Network(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: number  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to modify the attributes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['number']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.number = None
                                            self.route_map = None
                                            self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Network, ['number', 'route_map'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class L2vpn(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.AfName>`
                                
                                .. attribute:: l2vpn_evpn
                                
                                	L2VPN EVPN address family
                                	**type**\:  :py:class:`L2vpnEvpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn>`
                                
                                .. attribute:: l2vpn_vpls
                                
                                	L2VPN VPLS address family
                                	**type**\:  :py:class:`L2vpnVpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn, self).__init__()

                                    self.yang_name = "l2vpn"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("l2vpn-evpn", ("l2vpn_evpn", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn)), ("l2vpn-vpls", ("l2vpn_vpls", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.AfName')])),
                                    ])
                                    self.af_name = None

                                    self.l2vpn_evpn = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn()
                                    self.l2vpn_evpn.parent = self
                                    self._children_name_map["l2vpn_evpn"] = "l2vpn-evpn"

                                    self.l2vpn_vpls = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls()
                                    self.l2vpn_vpls.parent = self
                                    self._children_name_map["l2vpn_vpls"] = "l2vpn-vpls"
                                    self._segment_path = lambda: "l2vpn" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn, ['af_name'], name, value)

                                class AfName(Enum):
                                    """
                                    AfName (Enum Class)

                                    .. data:: evpn = 0

                                    .. data:: vpls = 1

                                    """

                                    evpn = Enum.YLeaf(0, "evpn")

                                    vpls = Enum.YLeaf(1, "vpls")



                                class L2vpnEvpn(Entity):
                                    """
                                    L2VPN EVPN address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_>`
                                    
                                    .. attribute:: default_information
                                    
                                    	Control distribution of default information
                                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation>`
                                    
                                    .. attribute:: default_metric
                                    
                                    	Set metric of redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor>`
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: network
                                    
                                    	
                                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn, self).__init__()

                                        self.yang_name = "l2vpn-evpn"
                                        self.yang_parent_name = "l2vpn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer)), ("network", ("network", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp))])
                                        self._leafs = OrderedDict([
                                            ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.default_metric = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.default_information = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation()
                                        self.default_information.parent = self
                                        self._children_name_map["default_information"] = "default-information"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.network = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network()
                                        self.network.parent = self
                                        self._children_name_map["network"] = "network"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "l2vpn-evpn"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn, ['default_metric', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Additional paths in the BGP table
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths>`
                                        
                                        .. attribute:: default
                                        
                                        	Configure BGP defaults
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths)), ("default", ("default", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default))])
                                            self._leafs = OrderedDict()

                                            self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.default = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_, [], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Additional paths in the BGP table
                                            
                                            .. attribute:: install
                                            
                                            	Additional paths to install into RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: select
                                            
                                            	Selection criteria to pick the paths
                                            	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to neighbors
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.install = None
                                                self.receive = None

                                                self.select = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select()
                                                self.select.parent = self
                                                self._children_name_map["select"] = "select"

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                            class Select(Entity):
                                                """
                                                Selection criteria to pick the paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select, self).__init__()

                                                    self.yang_name = "select"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"

                                                    self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.best_external = None
                                                    self._children_name_map["best_external"] = "best-external"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "select"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                            self._leafs = OrderedDict()

                                                            self.range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                        class Range(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best path
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                                self.yang_name = "range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Select backup path
                                                    
                                                    .. attribute:: best_external
                                                    
                                                    	Select best\-external path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                        ])
                                                        self.best_external = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best path
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                                class BestExternal(Entity):
                                                    """
                                                    Select best\-external path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Select backup path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                        self.yang_name = "best-external"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                        ])
                                                        self.backup = None
                                                        self._segment_path = lambda: "best-external"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to neighbors
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                        class Default(Entity):
                                            """
                                            Configure BGP defaults
                                            
                                            .. attribute:: route_target
                                            
                                            	Control behavior based on Route\-Target attributes
                                            	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default.RouteTarget>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default.RouteTarget')])),
                                                ])
                                                self.route_target = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default, ['route_target'], name, value)

                                            class RouteTarget(Enum):
                                                """
                                                RouteTarget (Enum Class)

                                                Control behavior based on Route\-Target attributes

                                                .. data:: filter = 0

                                                """

                                                filter = Enum.YLeaf(0, "filter")



                                    class DefaultInformation(Entity):
                                        """
                                        Control distribution of default information
                                        
                                        .. attribute:: originate
                                        
                                        	Distribute a default route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation, self).__init__()

                                            self.yang_name = "default-information"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                            ])
                                            self.originate = None
                                            self._segment_path = lambda: "default-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation, ['originate'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: additional_paths
                                            
                                            	
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths>`
                                            
                                            .. attribute:: advertise
                                            
                                            	Advertise to this neighbor
                                            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: distribute_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList>`
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: encap
                                            
                                            	Preferred encapsulation for neighbor
                                            	**type**\:  :py:class:`Encap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: peer_group
                                            
                                            	Member of the peer\-group
                                            	**type**\:  :py:class:`PeerGroup_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList)), ("encap", ("encap", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.advertise = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise()
                                                self.advertise.parent = self
                                                self._children_name_map["advertise"] = "advertise"

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.encap = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap()
                                                self.encap.parent = self
                                                self._children_name_map["encap"] = "encap"

                                                self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.peer_group = None
                                                self._children_name_map["peer_group"] = "peer-group"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.distribute_list = YList(self)
                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class AdditionalPaths(Entity):
                                                """
                                                
                                                
                                                .. attribute:: disable
                                                
                                                	Disable additional paths for this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: send
                                                
                                                	Send additional paths to this neighbor
                                                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send))])
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self.receive = None

                                                    self.send = None
                                                    self._children_name_map["send"] = "send"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                                class Send(Entity):
                                                    """
                                                    Send additional paths to this neighbor
                                                    
                                                    .. attribute:: receive
                                                    
                                                    	Receive additional paths from this neighbor
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send, self).__init__()

                                                        self.yang_name = "send"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                        ])
                                                        self.receive = None
                                                        self._segment_path = lambda: "send"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                            class Advertise(Entity):
                                                """
                                                Advertise to this neighbor
                                                
                                                .. attribute:: additional_paths
                                                
                                                	Advertise additional paths
                                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Advertise best\-external (at RRs best\-internal) path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: diverse_path
                                                
                                                	Advertise diverse path
                                                	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise, self).__init__()

                                                    self.yang_name = "advertise"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath))])
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None

                                                    self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                                    self.additional_paths.parent = self
                                                    self._children_name_map["additional_paths"] = "additional-paths"

                                                    self.diverse_path = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath()
                                                    self.diverse_path.parent = self
                                                    self._children_name_map["diverse_path"] = "diverse-path"
                                                    self._segment_path = lambda: "advertise"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                                class AdditionalPaths(Entity):
                                                    """
                                                    Advertise additional paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                        self.yang_name = "additional-paths"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                        self._leafs = OrderedDict()

                                                        self.all = None
                                                        self._children_name_map["all"] = "all"

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "additional-paths"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                    class All(Entity):
                                                        """
                                                        Select all available paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Select best N paths
                                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                            self.yang_name = "all"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict()

                                                            self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                            self.best.parent = self
                                                            self._children_name_map["best"] = "best"

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "all"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                        class Best(Entity):
                                                            """
                                                            Select best N paths
                                                            
                                                            .. attribute:: best_range
                                                            
                                                            	
                                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                                self.yang_name = "best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                                self._leafs = OrderedDict()

                                                                self.best_range = YList(self)
                                                                self._segment_path = lambda: "best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                            class BestRange(Entity):
                                                                """
                                                                
                                                                
                                                                .. attribute:: range  (key)
                                                                
                                                                	Number of best paths in additional paths to be selected
                                                                	**type**\: int
                                                                
                                                                	**range:** 2..3
                                                                
                                                                .. attribute:: group_best
                                                                
                                                                	Select group\-best paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                    self.yang_name = "best-range"
                                                                    self.yang_parent_name = "best"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['range']
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                    ])
                                                                    self.range = None
                                                                    self.group_best = None
                                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: best
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                                ])
                                                                self.best = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.all = None

                                                                self.group_best = None
                                                                self._children_name_map["group_best"] = "group-best"
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                            class GroupBest(Entity):
                                                                """
                                                                Select group\-best paths
                                                                
                                                                .. attribute:: all
                                                                
                                                                	Select all available paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                    self.yang_name = "group-best"
                                                                    self.yang_parent_name = "best-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                    ])
                                                                    self.all = None
                                                                    self._segment_path = lambda: "group-best"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.all = None
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                                class DiversePath(Entity):
                                                    """
                                                    Advertise diverse path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Diverse path can be backup path
                                                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                        self.yang_name = "diverse-path"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None

                                                        self.backup = None
                                                        self._children_name_map["backup"] = "backup"
                                                        self._segment_path = lambda: "diverse-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                    class Backup(Entity):
                                                        """
                                                        Diverse path can be backup path
                                                        
                                                        .. attribute:: mpath
                                                        
                                                        	Diverse path can be multipath
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                            self.yang_name = "backup"
                                                            self.yang_parent_name = "diverse-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                            ])
                                                            self.mpath = None
                                                            self._segment_path = lambda: "backup"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class DistributeList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList.Inout>`
                                                
                                                .. attribute:: accesslist
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..199
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1300..2699
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** [a\-zA\-Z].\*
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList, self).__init__()

                                                    self.yang_name = "distribute-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                        ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                    ])
                                                    self.inout = None
                                                    self.accesslist = None
                                                    self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Encap(Entity):
                                                """
                                                Preferred encapsulation for neighbor
                                                
                                                .. attribute:: mpls
                                                
                                                	Neighbor prefers MPLS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: vxlan
                                                
                                                	Neighbor prefers VxLAN
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap, self).__init__()

                                                    self.yang_name = "encap"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                                        ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                                    ])
                                                    self.mpls = None
                                                    self.vxlan = None
                                                    self._segment_path = lambda: "encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap, ['mpls', 'vxlan'], name, value)


                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PeerGroup_(Entity):
                                                """
                                                Member of the peer\-group
                                                
                                                .. attribute:: peer_group_name
                                                
                                                	peer\-group name
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_, self).__init__()

                                                    self.yang_name = "peer-group"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                                    ])
                                                    self.peer_group_name = None
                                                    self._segment_path = lambda: "peer-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_, ['peer_group_name'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: additional_paths
                                        
                                        	
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths>`
                                        
                                        .. attribute:: advertise
                                        
                                        	Advertise to this neighbor
                                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: distribute_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: encap
                                        
                                        	Preferred encapsulation for neighbor
                                        	**type**\:  :py:class:`Encap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: peer_group
                                        
                                        	Member of the peer\-group
                                        	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList)), ("encap", ("encap", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.advertise = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise()
                                            self.advertise.parent = self
                                            self._children_name_map["advertise"] = "advertise"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.encap = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap()
                                            self.encap.parent = self
                                            self._children_name_map["encap"] = "encap"

                                            self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.peer_group = None
                                            self._children_name_map["peer_group"] = "peer-group"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.distribute_list = YList(self)
                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AdditionalPaths(Entity):
                                            """
                                            
                                            
                                            .. attribute:: disable
                                            
                                            	Disable additional paths for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to this neighbor
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self.receive = None

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to this neighbor
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                        class Advertise(Entity):
                                            """
                                            Advertise to this neighbor
                                            
                                            .. attribute:: additional_paths
                                            
                                            	Advertise additional paths
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Advertise best\-external (at RRs best\-internal) path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: diverse_path
                                            
                                            	Advertise diverse path
                                            	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise, self).__init__()

                                                self.yang_name = "advertise"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath))])
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.diverse_path = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath()
                                                self.diverse_path.parent = self
                                                self._children_name_map["diverse_path"] = "diverse-path"
                                                self._segment_path = lambda: "advertise"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise, ['best_external'], name, value)


                                            class AdditionalPaths(Entity):
                                                """
                                                Advertise additional paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "best-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                            class DiversePath(Entity):
                                                """
                                                Advertise diverse path
                                                
                                                .. attribute:: backup
                                                
                                                	Diverse path can be backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath, self).__init__()

                                                    self.yang_name = "diverse-path"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup))])
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"
                                                    self._segment_path = lambda: "diverse-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Diverse path can be backup path
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "diverse-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class DistributeList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList.Inout>`
                                            
                                            .. attribute:: accesslist
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..199
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..2699
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList, self).__init__()

                                                self.yang_name = "distribute-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList.Inout')])),
                                                    ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                ])
                                                self.inout = None
                                                self.accesslist = None
                                                self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Encap(Entity):
                                            """
                                            Preferred encapsulation for neighbor
                                            
                                            .. attribute:: mpls
                                            
                                            	Neighbor prefers MPLS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: vxlan
                                            
                                            	Neighbor prefers VxLAN
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap, self).__init__()

                                                self.yang_name = "encap"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                                    ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                                ])
                                                self.mpls = None
                                                self.vxlan = None
                                                self._segment_path = lambda: "encap"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap, ['mpls', 'vxlan'], name, value)


                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PeerGroup(Entity):
                                            """
                                            Member of the peer\-group
                                            
                                            .. attribute:: peer_group_name
                                            
                                            	peer\-group name
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup, self).__init__()

                                                self.yang_name = "peer-group"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                                ])
                                                self.peer_group_name = None
                                                self._segment_path = lambda: "peer-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn, ['as_number'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf, ['all'], name, value)


                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Network(Entity):
                                        """
                                        
                                        
                                        .. attribute:: with_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask>`
                                        
                                        .. attribute:: no_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask))])
                                            self._leafs = OrderedDict()

                                            self.with_mask = YList(self)
                                            self.no_mask = YList(self)
                                            self._segment_path = lambda: "network"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network, [], name, value)


                                        class WithMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mask  (key)
                                            
                                            	Network mask
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask, self).__init__()

                                                self.yang_name = "with-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number','mask']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.mask = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor'], name, value)


                                        class NoMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask, self).__init__()

                                                self.yang_name = "no-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask, ['number', 'route_map', 'backdoor'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord, ['context_word'], name, value)


                                class L2vpnVpls(Entity):
                                    """
                                    L2VPN VPLS address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_>`
                                    
                                    .. attribute:: default_information
                                    
                                    	Control distribution of default information
                                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls, self).__init__()

                                        self.yang_name = "l2vpn-vpls"
                                        self.yang_parent_name = "l2vpn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.default_information = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation()
                                        self.default_information.parent = self
                                        self._children_name_map["default_information"] = "default-information"

                                        self.peer_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "l2vpn-vpls"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: default
                                        
                                        	Configure BGP defaults
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("default", ("default", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                            ])
                                            self.scan_time = None

                                            self.default = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.nexthop = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_, ['scan_time'], name, value)


                                        class Default(Entity):
                                            """
                                            Configure BGP defaults
                                            
                                            .. attribute:: route_target
                                            
                                            	Control behavior based on Route\-Target attributes
                                            	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default.RouteTarget>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default.RouteTarget')])),
                                                ])
                                                self.route_target = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default, ['route_target'], name, value)

                                            class RouteTarget(Enum):
                                                """
                                                RouteTarget (Enum Class)

                                                Control behavior based on Route\-Target attributes

                                                .. data:: filter = 0

                                                """

                                                filter = Enum.YLeaf(0, "filter")



                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class DefaultInformation(Entity):
                                        """
                                        Control distribution of default information
                                        
                                        .. attribute:: originate
                                        
                                        	Distribute a default route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation, self).__init__()

                                            self.yang_name = "default-information"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                            ])
                                            self.originate = None
                                            self._segment_path = lambda: "default-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation, ['originate'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf, ['all'], name, value)


                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class Rtfilter(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.AfName>`
                                
                                .. attribute:: rtfilter
                                
                                	RT\-Filter address family
                                	**type**\:  :py:class:`Rtfilter_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter, self).__init__()

                                    self.yang_name = "rtfilter"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("rtfilter", ("rtfilter", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.AfName')])),
                                    ])
                                    self.af_name = None

                                    self.rtfilter = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_()
                                    self.rtfilter.parent = self
                                    self._children_name_map["rtfilter"] = "rtfilter"
                                    self._segment_path = lambda: "rtfilter" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter, ['af_name'], name, value)

                                class AfName(Enum):
                                    """
                                    AfName (Enum Class)

                                    .. data:: unicast = 0

                                    """

                                    unicast = Enum.YLeaf(0, "unicast")



                                class Rtfilter_(Entity):
                                    """
                                    RT\-Filter address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_>`
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_, self).__init__()

                                        self.yang_name = "rtfilter"
                                        self.yang_parent_name = "rtfilter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop>`
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "rtfilter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("nexthop", ("nexthop", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer))])
                                            self._leafs = OrderedDict()

                                            self.nexthop = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_, [], name, value)


                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "rtfilter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "rtfilter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: default_originate
                                            
                                            	Originate default route to this neighbor
                                            	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.weight = None

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.default_originate = None
                                                self._children_name_map["default_originate"] = "default-originate"

                                                self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class DefaultOriginate(Entity):
                                                """
                                                Originate default route to this neighbor
                                                
                                                .. attribute:: route_map
                                                
                                                	Route\-map to specify criteria to originate default
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                    self.yang_name = "default-originate"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default-originate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability>`
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "rtfilter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.weight = None

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.capability = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.inherit = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf, ['all'], name, value)


                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "rtfilter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Global.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord, ['context_word'], name, value)


                class Vrf(Entity):
                    """
                    
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    .. attribute:: peer_group
                    
                    	
                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.PeerGroup>`
                    
                    .. attribute:: neighbor
                    
                    	Specify a neighbor router
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.Neighbor>`
                    
                    .. attribute:: address_family
                    
                    	Enter Address Family command mode
                    	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily>`
                    
                    

                    """

                    _prefix = 'ios-bgp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Bgp.Scope.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "scope"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.Neighbor)), ("address-family", ("address_family", Native.Router.Bgp.Scope.Vrf.AddressFamily))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str','str','str'])),
                        ])
                        self.id = None

                        self.peer_group = Native.Router.Bgp.Scope.Vrf.PeerGroup()
                        self.peer_group.parent = self
                        self._children_name_map["peer_group"] = "peer-group"

                        self.address_family = Native.Router.Bgp.Scope.Vrf.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "vrf" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf, ['id'], name, value)


                    class PeerGroup(Entity):
                        """
                        
                        
                        .. attribute:: neighbor
                        
                        	Specify a neighbor router
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.PeerGroup.Neighbor>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Scope.Vrf.PeerGroup, self).__init__()

                            self.yang_name = "peer-group"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.PeerGroup.Neighbor))])
                            self._leafs = OrderedDict()

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "peer-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.PeerGroup, [], name, value)


                        class Neighbor(Entity):
                            """
                            Specify a neighbor router
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: peer_group
                            
                            	Member of the peer\-group
                            	**type**\:  :py:class:`PeerGroup_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.PeerGroup.Neighbor.PeerGroup_>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: remote_as
                            
                            	Specify a BGP neighbor
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Scope.Vrf.PeerGroup.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "peer-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.PeerGroup.Neighbor.PeerGroup_))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                                ])
                                self.id = None
                                self.remote_as = None

                                self.peer_group = None
                                self._children_name_map["peer_group"] = "peer-group"
                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.PeerGroup.Neighbor, ['id', 'remote_as'], name, value)


                            class PeerGroup_(Entity):
                                """
                                Member of the peer\-group
                                
                                .. attribute:: peer_group_name
                                
                                	peer\-group name
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Vrf.PeerGroup.Neighbor.PeerGroup_, self).__init__()

                                    self.yang_name = "peer-group"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                    ])
                                    self.peer_group_name = None
                                    self._segment_path = lambda: "peer-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.PeerGroup.Neighbor.PeerGroup_, ['peer_group_name'], name, value)


                    class Neighbor(Entity):
                        """
                        Specify a neighbor router
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: peer_group
                        
                        	Member of the peer\-group
                        	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.Neighbor.PeerGroup>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: remote_as
                        
                        	Specify a BGP neighbor
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4294967295
                        
                        		**type**\: str
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Scope.Vrf.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.Neighbor.PeerGroup))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                ('remote_as', (YLeaf(YType.str, 'remote-as'), ['int','str'])),
                            ])
                            self.id = None
                            self.remote_as = None

                            self.peer_group = None
                            self._children_name_map["peer_group"] = "peer-group"
                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.Neighbor, ['id', 'remote_as'], name, value)


                        class PeerGroup(Entity):
                            """
                            Member of the peer\-group
                            
                            .. attribute:: peer_group_name
                            
                            	peer\-group name
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Scope.Vrf.Neighbor.PeerGroup, self).__init__()

                                self.yang_name = "peer-group"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                ])
                                self.peer_group_name = None
                                self._segment_path = lambda: "peer-group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                    class AddressFamily(Entity):
                        """
                        Enter Address Family command mode
                        
                        .. attribute:: no_vrf
                        
                        	
                        	**type**\:  :py:class:`NoVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf>`
                        
                        

                        """

                        _prefix = 'ios-bgp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily, self).__init__()

                            self.yang_name = "address-family"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("no-vrf", ("no_vrf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf))])
                            self._leafs = OrderedDict()

                            self.no_vrf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf()
                            self.no_vrf.parent = self
                            self._children_name_map["no_vrf"] = "no-vrf"
                            self._segment_path = lambda: "address-family"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily, [], name, value)


                        class NoVrf(Entity):
                            """
                            
                            
                            .. attribute:: ipv4
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4>`
                            
                            .. attribute:: ipv6
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6>`
                            
                            .. attribute:: vpnv4
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Vpnv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4>`
                            
                            .. attribute:: vpnv6
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Vpnv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6>`
                            
                            .. attribute:: nsap
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Nsap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap>`
                            
                            .. attribute:: l2vpn
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`L2vpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn>`
                            
                            .. attribute:: rtfilter
                            
                            	Address family
                            	**type**\: list of  		 :py:class:`Rtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter>`
                            
                            

                            """

                            _prefix = 'ios-bgp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf, self).__init__()

                                self.yang_name = "no-vrf"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4)), ("ipv6", ("ipv6", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6)), ("vpnv4", ("vpnv4", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4)), ("vpnv6", ("vpnv6", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6)), ("nsap", ("nsap", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap)), ("l2vpn", ("l2vpn", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn)), ("rtfilter", ("rtfilter", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter))])
                                self._leafs = OrderedDict()

                                self.ipv4 = YList(self)
                                self.ipv6 = YList(self)
                                self.vpnv4 = YList(self)
                                self.vpnv6 = YList(self)
                                self.nsap = YList(self)
                                self.l2vpn = YList(self)
                                self.rtfilter = YList(self)
                                self._segment_path = lambda: "no-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf, [], name, value)


                            class Ipv4(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`BgpIpv4AfType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.BgpIpv4AfType>`
                                
                                .. attribute:: ipv4_unicast
                                
                                	IPv4 Unicast address family
                                	**type**\:  :py:class:`Ipv4Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("ipv4-unicast", ("ipv4_unicast", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'BgpIpv4AfType', '')])),
                                    ])
                                    self.af_name = None

                                    self.ipv4_unicast = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast()
                                    self.ipv4_unicast.parent = self
                                    self._children_name_map["ipv4_unicast"] = "ipv4-unicast"
                                    self._segment_path = lambda: "ipv4" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4, ['af_name'], name, value)


                                class Ipv4Unicast(Entity):
                                    """
                                    IPv4 Unicast address family
                                    
                                    .. attribute:: aggregate_address
                                    
                                    	Configure BGP aggregate entries
                                    	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress>`
                                    
                                    .. attribute:: auto_summary
                                    
                                    	Enable automatic network number summarization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_>`
                                    
                                    .. attribute:: default_information
                                    
                                    	Control distribution of default information
                                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation>`
                                    
                                    .. attribute:: default_metric
                                    
                                    	Set metric of redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: distance
                                    
                                    	Define an administrative distance
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter networks in routing updates
                                    	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList>`
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor>`
                                    
                                    .. attribute:: network
                                    
                                    	
                                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network>`
                                    
                                    .. attribute:: redistribute
                                    
                                    	Redistribute information from another routing protocol
                                    	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute>`
                                    
                                    .. attribute:: segment_routing
                                    
                                    	segment\-routing
                                    	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: synchronization
                                    
                                    	Perform IGP synchronization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: table_map
                                    
                                    	Map external entry attributes into routing table
                                    	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast, self).__init__()

                                        self.yang_name = "ipv4-unicast"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor)), ("network", ("network", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute)), ("segment-routing", ("segment_routing", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp)), ("table-map", ("table_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap))])
                                        self._leafs = OrderedDict([
                                            ('auto_summary', (YLeaf(YType.empty, 'auto-summary'), ['Empty'])),
                                            ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                            ('synchronization', (YLeaf(YType.empty, 'synchronization'), ['Empty'])),
                                        ])
                                        self.auto_summary = None
                                        self.default_metric = None
                                        self.synchronization = None

                                        self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.default_information = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation()
                                        self.default_information.parent = self
                                        self._children_name_map["default_information"] = "default-information"

                                        self.distance = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.network = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network()
                                        self.network.parent = self
                                        self._children_name_map["network"] = "network"

                                        self.redistribute = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute()
                                        self.redistribute.parent = self
                                        self._children_name_map["redistribute"] = "redistribute"

                                        self.segment_routing = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting()
                                        self.segment_routing.parent = self
                                        self._children_name_map["segment_routing"] = "segment-routing"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.table_map = None
                                        self._children_name_map["table_map"] = "table-map"

                                        self.aggregate_address = YList(self)
                                        self.distribute_list = YList(self)
                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "ipv4-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast, ['auto_summary', 'default_metric', 'synchronization'], name, value)


                                    class AggregateAddress(Entity):
                                        """
                                        Configure BGP aggregate entries
                                        
                                        .. attribute:: ipv4_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mask  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: advertise_map
                                        
                                        	Set condition to advertise attribute
                                        	**type**\: str
                                        
                                        .. attribute:: as_set
                                        
                                        	Generate AS set path information
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: attribute_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: summary_only
                                        
                                        	Filter more specific routes from updates
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_map
                                        
                                        	Conditionally filter more specific routes from updates
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress, self).__init__()

                                            self.yang_name = "aggregate-address"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ipv4_address','ipv4_mask']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mask', (YLeaf(YType.str, 'ipv4-mask'), ['str'])),
                                                ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                                ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                                ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                                ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                            ])
                                            self.ipv4_address = None
                                            self.ipv4_mask = None
                                            self.advertise_map = None
                                            self.as_set = None
                                            self.attribute_map = None
                                            self.as_override = None
                                            self.route_map = None
                                            self.summary_only = None
                                            self.suppress_map = None
                                            self._segment_path = lambda: "aggregate-address" + "[ipv4-address='" + str(self.ipv4_address) + "']" + "[ipv4-mask='" + str(self.ipv4_mask) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.AggregateAddress, ['ipv4_address', 'ipv4_mask', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Additional paths in the BGP table
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths>`
                                        
                                        .. attribute:: advertise_best_external
                                        
                                        	Advertise best external path to internal peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Configure aggregation timer
                                        	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer>`
                                        
                                        .. attribute:: bestpath
                                        
                                        	Change the default bestpath selection
                                        	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath>`
                                        
                                        .. attribute:: dampening
                                        
                                        	Enable route\-flap dampening
                                        	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Use DMZ Link Bandwidth as weight for BGP multipaths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: inject_map
                                        
                                        	Route map which specifies prefixes to inject
                                        	**type**\: list of  		 :py:class:`InjectMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop>`
                                        
                                        .. attribute:: recursion
                                        
                                        	recursion rule for the nexthops
                                        	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion>`
                                        
                                        .. attribute:: redistribute_internal
                                        
                                        	Allow redistribution of iBGP into IGPs (dangerous)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	bgp route\-map commands
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfig_backup
                                        
                                        	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_inactive
                                        
                                        	Suppress routes that are not in the routing table
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: update_group
                                        
                                        	Manage peers in bgp update groups
                                        	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening)), ("inject-map", ("inject_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup))])
                                            self._leafs = OrderedDict([
                                                ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                                ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                                ('suppress_inactive', (YLeaf(YType.empty, 'suppress-inactive'), ['Empty'])),
                                            ])
                                            self.advertise_best_external = None
                                            self.dmzlink_bw = None
                                            self.redistribute_internal = None
                                            self.scan_time = None
                                            self.soft_reconfig_backup = None
                                            self.suppress_inactive = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.aggregate_timer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer()
                                            self.aggregate_timer.parent = self
                                            self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                            self.bestpath = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath()
                                            self.bestpath.parent = self
                                            self._children_name_map["bestpath"] = "bestpath"

                                            self.dampening = None
                                            self._children_name_map["dampening"] = "dampening"

                                            self.nexthop = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.recursion = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion()
                                            self.recursion.parent = self
                                            self._children_name_map["recursion"] = "recursion"

                                            self.route_map = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap()
                                            self.route_map.parent = self
                                            self._children_name_map["route_map"] = "route-map"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup()
                                            self.update_group.parent = self
                                            self._children_name_map["update_group"] = "update-group"

                                            self.inject_map = YList(self)
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup', 'suppress_inactive'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Additional paths in the BGP table
                                            
                                            .. attribute:: install
                                            
                                            	Additional paths to install into RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: select
                                            
                                            	Selection criteria to pick the paths
                                            	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to neighbors
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.install = None
                                                self.receive = None

                                                self.select = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select()
                                                self.select.parent = self
                                                self._children_name_map["select"] = "select"

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                            class Select(Entity):
                                                """
                                                Selection criteria to pick the paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                    self.yang_name = "select"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"

                                                    self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.best_external = None
                                                    self._children_name_map["best_external"] = "best-external"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "select"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                            self._leafs = OrderedDict()

                                                            self.range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                        class Range(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best path
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                                self.yang_name = "range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Select backup path
                                                    
                                                    .. attribute:: best_external
                                                    
                                                    	Select best\-external path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                        ])
                                                        self.best_external = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best path
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                                class BestExternal(Entity):
                                                    """
                                                    Select best\-external path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Select backup path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                        self.yang_name = "best-external"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                        ])
                                                        self.backup = None
                                                        self._segment_path = lambda: "best-external"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to neighbors
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                        class AggregateTimer(Entity):
                                            """
                                            Configure aggregation timer
                                            
                                            .. attribute:: aggregate_timer
                                            
                                            	Timer interval
                                            	**type**\: int
                                            
                                            	**range:** 6..60
                                            
                                            .. attribute:: disable_timer
                                            
                                            	Timer interval
                                            	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer, self).__init__()

                                                self.yang_name = "aggregate-timer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                    ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                                ])
                                                self.aggregate_timer = None
                                                self.disable_timer = None
                                                self._segment_path = lambda: "aggregate-timer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                            class DisableTimer(Enum):
                                                """
                                                DisableTimer (Enum Class)

                                                Timer interval

                                                .. data:: Y_0 = 0

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")



                                        class Bestpath(Entity):
                                            """
                                            Change the default bestpath selection
                                            
                                            .. attribute:: igp_metric
                                            
                                            	igp metric
                                            	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric>`
                                            
                                            .. attribute:: prefix_validate
                                            
                                            	Prefix origin validation
                                            	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath, self).__init__()

                                                self.yang_name = "bestpath"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate))])
                                                self._leafs = OrderedDict()

                                                self.igp_metric = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric()
                                                self.igp_metric.parent = self
                                                self._children_name_map["igp_metric"] = "igp-metric"

                                                self.prefix_validate = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate()
                                                self.prefix_validate.parent = self
                                                self._children_name_map["prefix_validate"] = "prefix-validate"
                                                self._segment_path = lambda: "bestpath"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath, [], name, value)


                                            class IgpMetric(Entity):
                                                """
                                                igp metric
                                                
                                                .. attribute:: ignore
                                                
                                                	Ignore igp metric in bestpath selection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                                    self.yang_name = "igp-metric"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ])
                                                    self.ignore = None
                                                    self._segment_path = lambda: "igp-metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                            class PrefixValidate(Entity):
                                                """
                                                Prefix origin validation
                                                
                                                .. attribute:: allow_invalid
                                                
                                                	Allow invalid routes to be considered for bestpath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: disable
                                                
                                                	Disable prefix validation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                                    self.yang_name = "prefix-validate"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.allow_invalid = None
                                                    self.disable = None
                                                    self._segment_path = lambda: "prefix-validate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                        class Dampening(Entity):
                                            """
                                            Enable route\-flap dampening
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria for dampening
                                            	**type**\: str
                                            
                                            .. attribute:: dampen
                                            
                                            	
                                            	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening, self).__init__()

                                                self.yang_name = "dampening"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.dampen = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen()
                                                self.dampen.parent = self
                                                self._children_name_map["dampen"] = "dampen"
                                                self._segment_path = lambda: "dampening"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                            class Dampen(Entity):
                                                """
                                                
                                                
                                                .. attribute:: half_life_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..45
                                                
                                                .. attribute:: reuse_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: max_suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                                    self.yang_name = "dampen"
                                                    self.yang_parent_name = "dampening"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                        ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                        ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                        ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                    ])
                                                    self.half_life_time = None
                                                    self.reuse_time = None
                                                    self.suppress_time = None
                                                    self.max_suppress_time = None
                                                    self._segment_path = lambda: "dampen"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                        class InjectMap(Entity):
                                            """
                                            Route map which specifies prefixes to inject
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: exist_map
                                            
                                            	Route map which specifies exist condition
                                            	**type**\: str
                                            
                                            .. attribute:: copy_attributes
                                            
                                            	Copy attributes from aggregate
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap, self).__init__()

                                                self.yang_name = "inject-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                    ('copy_attributes', (YLeaf(YType.empty, 'copy-attributes'), ['Empty'])),
                                                ])
                                                self.name = None
                                                self.exist_map = None
                                                self.copy_attributes = None
                                                self._segment_path = lambda: "inject-map" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.InjectMap, ['name', 'exist_map', 'copy_attributes'], name, value)


                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class Recursion(Entity):
                                            """
                                            recursion rule for the nexthops
                                            
                                            .. attribute:: host
                                            
                                            	recursion via host for the nexthops
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion, self).__init__()

                                                self.yang_name = "recursion"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                                ])
                                                self.host = None
                                                self._segment_path = lambda: "recursion"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.Recursion, ['host'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            bgp route\-map commands
                                            
                                            .. attribute:: priority
                                            
                                            	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class UpdateGroup(Entity):
                                            """
                                            Manage peers in bgp update groups
                                            
                                            .. attribute:: split
                                            
                                            	Split update groups based on Policy
                                            	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup, self).__init__()

                                                self.yang_name = "update-group"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split))])
                                                self._leafs = OrderedDict()

                                                self.split = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split()
                                                self.split.parent = self
                                                self._children_name_map["split"] = "split"
                                                self._segment_path = lambda: "update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup, [], name, value)


                                            class Split(Entity):
                                                """
                                                Split update groups based on Policy
                                                
                                                .. attribute:: as_override
                                                
                                                	Keep peers with as\-override in different update groups
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                                    self.yang_name = "split"
                                                    self.yang_parent_name = "update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                    ])
                                                    self.as_override = None
                                                    self._segment_path = lambda: "split"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                                    class DefaultInformation(Entity):
                                        """
                                        Control distribution of default information
                                        
                                        .. attribute:: originate
                                        
                                        	Distribute a default route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation, self).__init__()

                                            self.yang_name = "default-information"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                            ])
                                            self.originate = None
                                            self._segment_path = lambda: "default-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DefaultInformation, ['originate'], name, value)


                                    class Distance(Entity):
                                        """
                                        Define an administrative distance
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP distance
                                        	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_>`
                                        
                                        .. attribute:: adm_distance
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance))])
                                            self._leafs = OrderedDict()

                                            self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.adm_distance = YList(self)
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance, [], name, value)


                                        class Bgp_(Entity):
                                            """
                                            BGP distance
                                            
                                            .. attribute:: extern_as
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: internal_as
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: local
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "distance"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                                    ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                                    ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                                ])
                                                self.extern_as = None
                                                self.internal_as = None
                                                self.local = None
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                        class AdmDistance(Entity):
                                            """
                                            
                                            
                                            .. attribute:: distance  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: srcip  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: wildbits  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: acl
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..99
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..1999
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance, self).__init__()

                                                self.yang_name = "adm-distance"
                                                self.yang_parent_name = "distance"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['distance','srcip','wildbits']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                                    ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                                    ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                                    ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                                ])
                                                self.distance = None
                                                self.srcip = None
                                                self.wildbits = None
                                                self.acl = None
                                                self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter networks in routing updates
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: int
                                        
                                        			**range:** 100..199
                                        
                                        		**type**\: int
                                        
                                        			**range:** 2000..2699
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** [a\-zA\-Z].\*
                                        
                                        .. attribute:: in_
                                        
                                        	Filter incoming routing updates
                                        	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: out
                                        
                                        	Filter outgoing routing updates
                                        	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("in", ("in_", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In)), ("out", ("out", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['int','int','str'])),
                                            ])
                                            self.id = None

                                            self.in_ = None
                                            self._children_name_map["in_"] = "in"

                                            self.out = None
                                            self._children_name_map["out"] = "out"
                                            self._segment_path = lambda: "distribute-list" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList, ['id'], name, value)


                                        class In(Entity):
                                            """
                                            Filter incoming routing updates
                                            
                                            .. attribute:: interface
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In, self).__init__()

                                                self.yang_name = "in"
                                                self.yang_parent_name = "distribute-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ])
                                                self.interface = None
                                                self._segment_path = lambda: "in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.In, ['interface'], name, value)


                                        class Out(Entity):
                                            """
                                            Filter outgoing routing updates
                                            
                                            .. attribute:: interface
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out, self).__init__()

                                                self.yang_name = "out"
                                                self.yang_parent_name = "distribute-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ])
                                                self.interface = None
                                                self._segment_path = lambda: "out"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.DistributeList.Out, ['interface'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: additional_paths
                                            
                                            	
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths>`
                                            
                                            .. attribute:: advertise
                                            
                                            	Advertise to this neighbor
                                            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise>`
                                            
                                            .. attribute:: advertise_map
                                            
                                            	specify route\-map for conditional advertisement
                                            	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: aigp
                                            
                                            	Enable a AIGP on neighbor
                                            	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: announce
                                            
                                            	Announce RPKI state using an extended community
                                            	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce>`
                                            
                                            .. attribute:: as_override
                                            
                                            	Override matching AS\-number while sending update
                                            	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: default_originate
                                            
                                            	Originate default route to this neighbor
                                            	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: distribute_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList>`
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: peer_group
                                            
                                            	Member of the peer\-group
                                            	**type**\:  :py:class:`PeerGroup_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: send_label
                                            
                                            	Send NLRI + MPLS Label to this peer
                                            	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: translate_update
                                            
                                            	Translate update to MBGP format
                                            	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate>`
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.advertise = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise()
                                                self.advertise.parent = self
                                                self._children_name_map["advertise"] = "advertise"

                                                self.advertise_map = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap()
                                                self.advertise_map.parent = self
                                                self._children_name_map["advertise_map"] = "advertise-map"

                                                self.aigp = None
                                                self._children_name_map["aigp"] = "aigp"

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.announce = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce()
                                                self.announce.parent = self
                                                self._children_name_map["announce"] = "announce"

                                                self.as_override = None
                                                self._children_name_map["as_override"] = "as-override"

                                                self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.default_originate = None
                                                self._children_name_map["default_originate"] = "default-originate"

                                                self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.peer_group = None
                                                self._children_name_map["peer_group"] = "peer-group"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.send_label = None
                                                self._children_name_map["send_label"] = "send-label"

                                                self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.translate_update = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate()
                                                self.translate_update.parent = self
                                                self._children_name_map["translate_update"] = "translate-update"

                                                self.distribute_list = YList(self)
                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class AdditionalPaths(Entity):
                                                """
                                                
                                                
                                                .. attribute:: disable
                                                
                                                	Disable additional paths for this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: send
                                                
                                                	Send additional paths to this neighbor
                                                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send))])
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self.receive = None

                                                    self.send = None
                                                    self._children_name_map["send"] = "send"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                                class Send(Entity):
                                                    """
                                                    Send additional paths to this neighbor
                                                    
                                                    .. attribute:: receive
                                                    
                                                    	Receive additional paths from this neighbor
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, self).__init__()

                                                        self.yang_name = "send"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                        ])
                                                        self.receive = None
                                                        self._segment_path = lambda: "send"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                            class Advertise(Entity):
                                                """
                                                Advertise to this neighbor
                                                
                                                .. attribute:: additional_paths
                                                
                                                	Advertise additional paths
                                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Advertise best\-external (at RRs best\-internal) path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: diverse_path
                                                
                                                	Advertise diverse path
                                                	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                                    self.yang_name = "advertise"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None

                                                    self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                                    self.additional_paths.parent = self
                                                    self._children_name_map["additional_paths"] = "additional-paths"

                                                    self.diverse_path = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                                    self.diverse_path.parent = self
                                                    self._children_name_map["diverse_path"] = "diverse-path"
                                                    self._segment_path = lambda: "advertise"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                                class AdditionalPaths(Entity):
                                                    """
                                                    Advertise additional paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                        self.yang_name = "additional-paths"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                        self._leafs = OrderedDict()

                                                        self.all = None
                                                        self._children_name_map["all"] = "all"

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "additional-paths"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                    class All(Entity):
                                                        """
                                                        Select all available paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Select best N paths
                                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                            self.yang_name = "all"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict()

                                                            self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                            self.best.parent = self
                                                            self._children_name_map["best"] = "best"

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "all"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                        class Best(Entity):
                                                            """
                                                            Select best N paths
                                                            
                                                            .. attribute:: best_range
                                                            
                                                            	
                                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                                self.yang_name = "best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                                self._leafs = OrderedDict()

                                                                self.best_range = YList(self)
                                                                self._segment_path = lambda: "best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                            class BestRange(Entity):
                                                                """
                                                                
                                                                
                                                                .. attribute:: range  (key)
                                                                
                                                                	Number of best paths in additional paths to be selected
                                                                	**type**\: int
                                                                
                                                                	**range:** 2..3
                                                                
                                                                .. attribute:: group_best
                                                                
                                                                	Select group\-best paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                    self.yang_name = "best-range"
                                                                    self.yang_parent_name = "best"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['range']
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                    ])
                                                                    self.range = None
                                                                    self.group_best = None
                                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: best
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                                ])
                                                                self.best = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.all = None

                                                                self.group_best = None
                                                                self._children_name_map["group_best"] = "group-best"
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                            class GroupBest(Entity):
                                                                """
                                                                Select group\-best paths
                                                                
                                                                .. attribute:: all
                                                                
                                                                	Select all available paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                    self.yang_name = "group-best"
                                                                    self.yang_parent_name = "best-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                    ])
                                                                    self.all = None
                                                                    self._segment_path = lambda: "group-best"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.all = None
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                                class DiversePath(Entity):
                                                    """
                                                    Advertise diverse path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Diverse path can be backup path
                                                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                        self.yang_name = "diverse-path"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None

                                                        self.backup = None
                                                        self._children_name_map["backup"] = "backup"
                                                        self._segment_path = lambda: "diverse-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                    class Backup(Entity):
                                                        """
                                                        Diverse path can be backup path
                                                        
                                                        .. attribute:: mpath
                                                        
                                                        	Diverse path can be multipath
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                            self.yang_name = "backup"
                                                            self.yang_parent_name = "diverse-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                            ])
                                                            self.mpath = None
                                                            self._segment_path = lambda: "backup"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                            class AdvertiseMap(Entity):
                                                """
                                                specify route\-map for conditional advertisement
                                                
                                                .. attribute:: name
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap, self).__init__()

                                                    self.yang_name = "advertise-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name))])
                                                    self._leafs = OrderedDict()

                                                    self.name = YList(self)
                                                    self._segment_path = lambda: "advertise-map"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap, [], name, value)


                                                class Name(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: word  (key)
                                                    
                                                    	advertise route\-map name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: exist_map
                                                    
                                                    	condition route\-map name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: non_exist_map
                                                    
                                                    	condition route\-map name
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, self).__init__()

                                                        self.yang_name = "name"
                                                        self.yang_parent_name = "advertise-map"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['word']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                            ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                            ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                        ])
                                                        self.word = None
                                                        self.exist_map = None
                                                        self.non_exist_map = None
                                                        self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                            class Aigp(Entity):
                                                """
                                                Enable a AIGP on neighbor
                                                
                                                .. attribute:: send
                                                
                                                	Cost community or MED carrying AIGP VALUE
                                                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                                    self.yang_name = "aigp"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.send = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send()
                                                    self.send.parent = self
                                                    self._children_name_map["send"] = "send"
                                                    self._segment_path = lambda: "aigp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                                class Send(Entity):
                                                    """
                                                    Cost community or MED carrying AIGP VALUE
                                                    
                                                    .. attribute:: cost_community
                                                    
                                                    	Cost extended community carrying AIGP Value
                                                    	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                                    
                                                    .. attribute:: med
                                                    
                                                    	Med carrying AIGP Value
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                        self.yang_name = "send"
                                                        self.yang_parent_name = "aigp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                        ])
                                                        self.med = None

                                                        self.cost_community = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                        self.cost_community.parent = self
                                                        self._children_name_map["cost_community"] = "cost-community"
                                                        self._segment_path = lambda: "send"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                                    class CostCommunity(Entity):
                                                        """
                                                        Cost extended community carrying AIGP Value
                                                        
                                                        .. attribute:: cc_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                            self.yang_name = "cost-community"
                                                            self.yang_parent_name = "send"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                            self._leafs = OrderedDict()

                                                            self.cc_range = YList(self)
                                                            self._segment_path = lambda: "cost-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                        class CcRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Community ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: poi
                                                            
                                                            	Point of insertion
                                                            	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                                self.yang_name = "cc-range"
                                                                self.yang_parent_name = "cost-community"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ])
                                                                self.range = None

                                                                self.poi = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                                self.poi.parent = self
                                                                self._children_name_map["poi"] = "poi"
                                                                self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                            class Poi(Entity):
                                                                """
                                                                Point of insertion
                                                                
                                                                .. attribute:: igp_cost
                                                                
                                                                	Point of insertion after IGP
                                                                	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                                
                                                                	**presence node**\: True
                                                                
                                                                .. attribute:: pre_bestpath
                                                                
                                                                	Point of insertion at beginning
                                                                	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                                
                                                                	**presence node**\: True
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                    self.yang_name = "poi"
                                                                    self.yang_parent_name = "cc-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                    self._leafs = OrderedDict()

                                                                    self.igp_cost = None
                                                                    self._children_name_map["igp_cost"] = "igp-cost"

                                                                    self.pre_bestpath = None
                                                                    self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                    self._segment_path = lambda: "poi"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                                class IgpCost(Entity):
                                                                    """
                                                                    Point of insertion after IGP
                                                                    
                                                                    .. attribute:: transitive
                                                                    
                                                                    	Cost community is transitive
                                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                    
                                                                    

                                                                    This class is a :ref:`presence class<presence-class>`

                                                                    """

                                                                    _prefix = 'ios-bgp'
                                                                    _revision = '2018-06-28'

                                                                    def __init__(self):
                                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                        self.yang_name = "igp-cost"
                                                                        self.yang_parent_name = "poi"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self.is_presence_container = True
                                                                        self._leafs = OrderedDict([
                                                                            ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                        ])
                                                                        self.transitive = None
                                                                        self._segment_path = lambda: "igp-cost"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                                class PreBestpath(Entity):
                                                                    """
                                                                    Point of insertion at beginning
                                                                    
                                                                    .. attribute:: transitive
                                                                    
                                                                    	Cost community is transitive
                                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                    
                                                                    

                                                                    This class is a :ref:`presence class<presence-class>`

                                                                    """

                                                                    _prefix = 'ios-bgp'
                                                                    _revision = '2018-06-28'

                                                                    def __init__(self):
                                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                        self.yang_name = "pre-bestpath"
                                                                        self.yang_parent_name = "poi"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self.is_presence_container = True
                                                                        self._leafs = OrderedDict([
                                                                            ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                        ])
                                                                        self.transitive = None
                                                                        self._segment_path = lambda: "pre-bestpath"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Announce(Entity):
                                                """
                                                Announce RPKI state using an extended community
                                                
                                                .. attribute:: rpki
                                                
                                                	Announce RPKI information using an extended community
                                                	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce, self).__init__()

                                                    self.yang_name = "announce"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki))])
                                                    self._leafs = OrderedDict()

                                                    self.rpki = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki()
                                                    self.rpki.parent = self
                                                    self._children_name_map["rpki"] = "rpki"
                                                    self._segment_path = lambda: "announce"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce, [], name, value)


                                                class Rpki(Entity):
                                                    """
                                                    Announce RPKI information using an extended community
                                                    
                                                    .. attribute:: state
                                                    
                                                    	Announce RPKI state information using an extended community
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki, self).__init__()

                                                        self.yang_name = "rpki"
                                                        self.yang_parent_name = "announce"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                        ])
                                                        self.state = None
                                                        self._segment_path = lambda: "rpki"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Announce.Rpki, ['state'], name, value)


                                            class AsOverride(Entity):
                                                """
                                                Override matching AS\-number while sending update
                                                
                                                .. attribute:: disable
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride, self).__init__()

                                                    self.yang_name = "as-override"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "as-override"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.AsOverride, ['disable'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class DefaultOriginate(Entity):
                                                """
                                                Originate default route to this neighbor
                                                
                                                .. attribute:: route_map
                                                
                                                	Route\-map to specify criteria to originate default
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                    self.yang_name = "default-originate"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default-originate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                            class DistributeList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                                
                                                .. attribute:: accesslist
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..199
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1300..2699
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** [a\-zA\-Z].\*
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                                    self.yang_name = "distribute-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                        ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                    ])
                                                    self.inout = None
                                                    self.accesslist = None
                                                    self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PeerGroup_(Entity):
                                                """
                                                Member of the peer\-group
                                                
                                                .. attribute:: peer_group_name
                                                
                                                	peer\-group name
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_, self).__init__()

                                                    self.yang_name = "peer-group"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                                    ])
                                                    self.peer_group_name = None
                                                    self._segment_path = lambda: "peer-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PeerGroup_, ['peer_group_name'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SendLabel(Entity):
                                                """
                                                Send NLRI + MPLS Label to this peer
                                                
                                                .. attribute:: send_label_explicit
                                                
                                                	
                                                	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel, self).__init__()

                                                    self.yang_name = "send-label"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit')])),
                                                    ])
                                                    self.send_label_explicit = None
                                                    self._segment_path = lambda: "send-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                                class SendLabelExplicit(Enum):
                                                    """
                                                    SendLabelExplicit (Enum Class)

                                                    .. data:: explicit_null = 0

                                                    """

                                                    explicit_null = Enum.YLeaf(0, "explicit-null")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                            class TranslateUpdate(Entity):
                                                """
                                                Translate update to MBGP format
                                                
                                                .. attribute:: ipv4
                                                
                                                	Address Family
                                                	**type**\:  :py:class:`Ipv4_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate, self).__init__()

                                                    self.yang_name = "translate-update"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv4 = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_()
                                                    self.ipv4.parent = self
                                                    self._children_name_map["ipv4"] = "ipv4"
                                                    self._segment_path = lambda: "translate-update"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate, [], name, value)


                                                class Ipv4_(Entity):
                                                    """
                                                    Address Family
                                                    
                                                    .. attribute:: multicast
                                                    
                                                    	Address Family modifier
                                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_, self).__init__()

                                                        self.yang_name = "ipv4"
                                                        self.yang_parent_name = "translate-update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast))])
                                                        self._leafs = OrderedDict()

                                                        self.multicast = None
                                                        self._children_name_map["multicast"] = "multicast"
                                                        self._segment_path = lambda: "ipv4"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_, [], name, value)


                                                    class Multicast(Entity):
                                                        """
                                                        Address Family modifier
                                                        
                                                        .. attribute:: unicast
                                                        
                                                        	Address Family modifier
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast, self).__init__()

                                                            self.yang_name = "multicast"
                                                            self.yang_parent_name = "ipv4"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                            ])
                                                            self.unicast = None
                                                            self._segment_path = lambda: "multicast"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4_.Multicast, ['unicast'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: additional_paths
                                        
                                        	
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths>`
                                        
                                        .. attribute:: advertise
                                        
                                        	Advertise to this neighbor
                                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise>`
                                        
                                        .. attribute:: advertise_map
                                        
                                        	specify route\-map for conditional advertisement
                                        	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable a AIGP on neighbor
                                        	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: announce
                                        
                                        	Announce RPKI state using an extended community
                                        	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce>`
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability>`
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: distribute_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: peer_group
                                        
                                        	Member of the peer\-group
                                        	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: send_label
                                        
                                        	Send NLRI + MPLS Label to this peer
                                        	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: translate_update
                                        
                                        	Translate update to MBGP format
                                        	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate>`
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.advertise = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise()
                                            self.advertise.parent = self
                                            self._children_name_map["advertise"] = "advertise"

                                            self.advertise_map = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap()
                                            self.advertise_map.parent = self
                                            self._children_name_map["advertise_map"] = "advertise-map"

                                            self.aigp = None
                                            self._children_name_map["aigp"] = "aigp"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.announce = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce()
                                            self.announce.parent = self
                                            self._children_name_map["announce"] = "announce"

                                            self.as_override = None
                                            self._children_name_map["as_override"] = "as-override"

                                            self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.peer_group = None
                                            self._children_name_map["peer_group"] = "peer-group"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.send_label = None
                                            self._children_name_map["send_label"] = "send-label"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.translate_update = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate()
                                            self.translate_update.parent = self
                                            self._children_name_map["translate_update"] = "translate-update"

                                            self.distribute_list = YList(self)
                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AdditionalPaths(Entity):
                                            """
                                            
                                            
                                            .. attribute:: disable
                                            
                                            	Disable additional paths for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to this neighbor
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self.receive = None

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to this neighbor
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                        class Advertise(Entity):
                                            """
                                            Advertise to this neighbor
                                            
                                            .. attribute:: additional_paths
                                            
                                            	Advertise additional paths
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Advertise best\-external (at RRs best\-internal) path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: diverse_path
                                            
                                            	Advertise diverse path
                                            	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise, self).__init__()

                                                self.yang_name = "advertise"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath))])
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.diverse_path = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath()
                                                self.diverse_path.parent = self
                                                self._children_name_map["diverse_path"] = "diverse-path"
                                                self._segment_path = lambda: "advertise"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                            class AdditionalPaths(Entity):
                                                """
                                                Advertise additional paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "best-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                            class DiversePath(Entity):
                                                """
                                                Advertise diverse path
                                                
                                                .. attribute:: backup
                                                
                                                	Diverse path can be backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                                    self.yang_name = "diverse-path"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"
                                                    self._segment_path = lambda: "diverse-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Diverse path can be backup path
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "diverse-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                        class AdvertiseMap(Entity):
                                            """
                                            specify route\-map for conditional advertisement
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap, self).__init__()

                                                self.yang_name = "advertise-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name))])
                                                self._leafs = OrderedDict()

                                                self.name = YList(self)
                                                self._segment_path = lambda: "advertise-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap, [], name, value)


                                            class Name(Entity):
                                                """
                                                
                                                
                                                .. attribute:: word  (key)
                                                
                                                	advertise route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: non_exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name, self).__init__()

                                                    self.yang_name = "name"
                                                    self.yang_parent_name = "advertise-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                        ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                        ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                    ])
                                                    self.word = None
                                                    self.exist_map = None
                                                    self.non_exist_map = None
                                                    self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                        class Aigp(Entity):
                                            """
                                            Enable a AIGP on neighbor
                                            
                                            .. attribute:: send
                                            
                                            	Cost community or MED carrying AIGP VALUE
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp, self).__init__()

                                                self.yang_name = "aigp"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.send = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send()
                                                self.send.parent = self
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "aigp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp, [], name, value)


                                            class Send(Entity):
                                                """
                                                Cost community or MED carrying AIGP VALUE
                                                
                                                .. attribute:: cost_community
                                                
                                                	Cost extended community carrying AIGP Value
                                                	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity>`
                                                
                                                .. attribute:: med
                                                
                                                	Med carrying AIGP Value
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "aigp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                    ])
                                                    self.med = None

                                                    self.cost_community = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity()
                                                    self.cost_community.parent = self
                                                    self._children_name_map["cost_community"] = "cost-community"
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send, ['med'], name, value)


                                                class CostCommunity(Entity):
                                                    """
                                                    Cost extended community carrying AIGP Value
                                                    
                                                    .. attribute:: cc_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                        self.yang_name = "cost-community"
                                                        self.yang_parent_name = "send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                        self._leafs = OrderedDict()

                                                        self.cc_range = YList(self)
                                                        self._segment_path = lambda: "cost-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                    class CcRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Community ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: poi
                                                        
                                                        	Point of insertion
                                                        	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                            self.yang_name = "cc-range"
                                                            self.yang_parent_name = "cost-community"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ])
                                                            self.range = None

                                                            self.poi = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                            self.poi.parent = self
                                                            self._children_name_map["poi"] = "poi"
                                                            self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                        class Poi(Entity):
                                                            """
                                                            Point of insertion
                                                            
                                                            .. attribute:: igp_cost
                                                            
                                                            	Point of insertion after IGP
                                                            	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            .. attribute:: pre_bestpath
                                                            
                                                            	Point of insertion at beginning
                                                            	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                self.yang_name = "poi"
                                                                self.yang_parent_name = "cc-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                self._leafs = OrderedDict()

                                                                self.igp_cost = None
                                                                self._children_name_map["igp_cost"] = "igp-cost"

                                                                self.pre_bestpath = None
                                                                self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                self._segment_path = lambda: "poi"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                            class IgpCost(Entity):
                                                                """
                                                                Point of insertion after IGP
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                    self.yang_name = "igp-cost"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "igp-cost"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                            class PreBestpath(Entity):
                                                                """
                                                                Point of insertion at beginning
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                    self.yang_name = "pre-bestpath"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "pre-bestpath"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Announce(Entity):
                                            """
                                            Announce RPKI state using an extended community
                                            
                                            .. attribute:: rpki
                                            
                                            	Announce RPKI information using an extended community
                                            	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce, self).__init__()

                                                self.yang_name = "announce"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki))])
                                                self._leafs = OrderedDict()

                                                self.rpki = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki()
                                                self.rpki.parent = self
                                                self._children_name_map["rpki"] = "rpki"
                                                self._segment_path = lambda: "announce"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce, [], name, value)


                                            class Rpki(Entity):
                                                """
                                                Announce RPKI information using an extended community
                                                
                                                .. attribute:: state
                                                
                                                	Announce RPKI state information using an extended community
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki, self).__init__()

                                                    self.yang_name = "rpki"
                                                    self.yang_parent_name = "announce"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                    ])
                                                    self.state = None
                                                    self._segment_path = lambda: "rpki"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Announce.Rpki, ['state'], name, value)


                                        class AsOverride(Entity):
                                            """
                                            Override matching AS\-number while sending update
                                            
                                            .. attribute:: disable
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride, self).__init__()

                                                self.yang_name = "as-override"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "as-override"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.AsOverride, ['disable'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class DistributeList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList.Inout>`
                                            
                                            .. attribute:: accesslist
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..199
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..2699
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList, self).__init__()

                                                self.yang_name = "distribute-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList.Inout')])),
                                                    ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                ])
                                                self.inout = None
                                                self.accesslist = None
                                                self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PeerGroup(Entity):
                                            """
                                            Member of the peer\-group
                                            
                                            .. attribute:: peer_group_name
                                            
                                            	peer\-group name
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup, self).__init__()

                                                self.yang_name = "peer-group"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                                ])
                                                self.peer_group_name = None
                                                self._segment_path = lambda: "peer-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SendLabel(Entity):
                                            """
                                            Send NLRI + MPLS Label to this peer
                                            
                                            .. attribute:: send_label_explicit
                                            
                                            	
                                            	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel.SendLabelExplicit>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel, self).__init__()

                                                self.yang_name = "send-label"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel.SendLabelExplicit')])),
                                                ])
                                                self.send_label_explicit = None
                                                self._segment_path = lambda: "send-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                            class SendLabelExplicit(Enum):
                                                """
                                                SendLabelExplicit (Enum Class)

                                                .. data:: explicit_null = 0

                                                """

                                                explicit_null = Enum.YLeaf(0, "explicit-null")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class TranslateUpdate(Entity):
                                            """
                                            Translate update to MBGP format
                                            
                                            .. attribute:: ipv4
                                            
                                            	Address Family
                                            	**type**\:  :py:class:`Ipv4_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate, self).__init__()

                                                self.yang_name = "translate-update"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_))])
                                                self._leafs = OrderedDict()

                                                self.ipv4 = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_()
                                                self.ipv4.parent = self
                                                self._children_name_map["ipv4"] = "ipv4"
                                                self._segment_path = lambda: "translate-update"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate, [], name, value)


                                            class Ipv4_(Entity):
                                                """
                                                Address Family
                                                
                                                .. attribute:: multicast
                                                
                                                	Address Family modifier
                                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_, self).__init__()

                                                    self.yang_name = "ipv4"
                                                    self.yang_parent_name = "translate-update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast))])
                                                    self._leafs = OrderedDict()

                                                    self.multicast = None
                                                    self._children_name_map["multicast"] = "multicast"
                                                    self._segment_path = lambda: "ipv4"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_, [], name, value)


                                                class Multicast(Entity):
                                                    """
                                                    Address Family modifier
                                                    
                                                    .. attribute:: unicast
                                                    
                                                    	Address Family modifier
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast, self).__init__()

                                                        self.yang_name = "multicast"
                                                        self.yang_parent_name = "ipv4"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                        ])
                                                        self.unicast = None
                                                        self._segment_path = lambda: "multicast"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Neighbor.TranslateUpdate.Ipv4_.Multicast, ['unicast'], name, value)


                                    class Network(Entity):
                                        """
                                        
                                        
                                        .. attribute:: with_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask>`
                                        
                                        .. attribute:: no_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask))])
                                            self._leafs = OrderedDict()

                                            self.with_mask = YList(self)
                                            self.no_mask = YList(self)
                                            self._segment_path = lambda: "network"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network, [], name, value)


                                        class WithMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mask  (key)
                                            
                                            	Network mask
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask, self).__init__()

                                                self.yang_name = "with-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number','mask']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.mask = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor'], name, value)


                                        class NoMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask, self).__init__()

                                                self.yang_name = "no-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Network.NoMask, ['number', 'route_map', 'backdoor'], name, value)


                                    class Redistribute(Entity):
                                        """
                                        Redistribute information from another routing protocol
                                        
                                        .. attribute:: application
                                        
                                        	Application
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dvmrp
                                        
                                        	Redistribution of DVMRP into BGP IPv4 Multicast
                                        	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator/ID Separation Protocol
                                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: iso_igrp
                                        
                                        	IGRP for OSI networks
                                        	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile routes
                                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: odr
                                        
                                        	On Demand stub Routes
                                        	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf>`
                                        
                                        .. attribute:: ospfv3
                                        
                                        	OSPFv3
                                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute, self).__init__()

                                            self.yang_name = "redistribute"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.dvmrp = None
                                            self._children_name_map["dvmrp"] = "dvmrp"

                                            self.eigrp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"

                                            self.isis = None
                                            self._children_name_map["isis"] = "isis"

                                            self.lisp = None
                                            self._children_name_map["lisp"] = "lisp"

                                            self.iso_igrp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp()
                                            self.iso_igrp.parent = self
                                            self._children_name_map["iso_igrp"] = "iso-igrp"

                                            self.mobile = None
                                            self._children_name_map["mobile"] = "mobile"

                                            self.odr = None
                                            self._children_name_map["odr"] = "odr"

                                            self.rip = None
                                            self._children_name_map["rip"] = "rip"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.ospf = YList(self)
                                            self.ospfv3 = YList(self)
                                            self._segment_path = lambda: "redistribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.name = YList(self)
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application, [], name, value)


                                            class Name(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	WORD \:\: Route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name, self).__init__()

                                                    self.yang_name = "name"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                        class Bgp_(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.as_no = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                        class Dvmrp(Entity):
                                            """
                                            Redistribution of DVMRP into BGP IPv4 Multicast
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp, self).__init__()

                                                self.yang_name = "dvmrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "dvmrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.as_no = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: isis_area
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea>`
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.default = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default()
                                                self.default.parent = self
                                                self._children_name_map["default"] = "default"

                                                self.isis_area = YList(self)
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis, [], name, value)


                                            class IsisArea(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of IP dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: clns
                                                
                                                	Redistribution of OSI dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: routes
                                                
                                                	
                                                	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea.Routes>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea, self).__init__()

                                                    self.yang_name = "isis-area"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                        ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                        ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea.Routes')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.ip = None
                                                    self.clns = None
                                                    self.routes = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                                class Routes(Enum):
                                                    """
                                                    Routes (Enum Class)

                                                    .. data:: level_1 = 0

                                                    .. data:: level_2 = 1

                                                    .. data:: level_1_2 = 2

                                                    """

                                                    level_1 = Enum.YLeaf(0, "level-1")

                                                    level_2 = Enum.YLeaf(1, "level-2")

                                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class Default(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of IP dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: clns
                                                
                                                	Redistribution of OSI dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: routes
                                                
                                                	
                                                	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default.Routes>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default, self).__init__()

                                                    self.yang_name = "default"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                        ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                        ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default.Routes')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.ip = None
                                                    self.clns = None
                                                    self.routes = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                                class Routes(Enum):
                                                    """
                                                    Routes (Enum Class)

                                                    .. data:: level_1 = 0

                                                    .. data:: level_2 = 1

                                                    .. data:: level_1_2 = 2

                                                    """

                                                    level_1 = Enum.YLeaf(0, "level-1")

                                                    level_2 = Enum.YLeaf(1, "level-2")

                                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class Lisp(Entity):
                                            """
                                            Locator/ID Separation Protocol
                                            
                                            .. attribute:: include_connected
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp, self).__init__()

                                                self.yang_name = "lisp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.include_connected = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "lisp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                        class IsoIgrp(Entity):
                                            """
                                            IGRP for OSI networks
                                            
                                            .. attribute:: iso_igrp_area
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp, self).__init__()

                                                self.yang_name = "iso-igrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default))])
                                                self._leafs = OrderedDict()

                                                self.default = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default()
                                                self.default.parent = self
                                                self._children_name_map["default"] = "default"

                                                self.iso_igrp_area = YList(self)
                                                self._segment_path = lambda: "iso-igrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp, [], name, value)


                                            class IsoIgrpArea(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                                    self.yang_name = "iso-igrp-area"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.name = None
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                            class Default(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default, self).__init__()

                                                    self.yang_name = "default"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "default"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                        class Mobile(Entity):
                                            """
                                            Mobile routes
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "mobile"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                        class Odr(Entity):
                                            """
                                            On Demand stub Routes
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr, self).__init__()

                                                self.yang_name = "odr"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "odr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: vrf
                                            
                                            	VPN Routing/Forwarding Instance
                                            	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf_>`
                                            
                                            .. attribute:: non_vrf
                                            
                                            	
                                            	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf_)), ("non-vrf", ("non_vrf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.non_vrf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf()
                                                self.non_vrf.parent = self
                                                self._children_name_map["non_vrf"] = "non-vrf"

                                                self.vrf = YList(self)
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf, ['id'], name, value)


                                            class Vrf_(Entity):
                                                """
                                                VPN Routing/Forwarding Instance
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: match
                                                
                                                	
                                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf_.Match>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf_, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf_.Match))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.metric = None
                                                    self.route_map = None

                                                    self.match = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf_.Match()
                                                    self.match.parent = self
                                                    self._children_name_map["match"] = "match"
                                                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf_, ['name', 'metric', 'route_map'], name, value)


                                                class Match(Entity):
                                                    """
                                                    
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.Vrf_.Match, self).__init__()

                                                        self.yang_name = "match"
                                                        self.yang_parent_name = "vrf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict()
                                                        self._segment_path = lambda: "match"
                                                        self._is_frozen = True


                                            class NonVrf(Entity):
                                                """
                                                
                                                
                                                .. attribute:: match
                                                
                                                	
                                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf, self).__init__()

                                                    self.yang_name = "non-vrf"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match))])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.metric = None
                                                    self.route_map = None

                                                    self.match = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match()
                                                    self.match.parent = self
                                                    self._children_name_map["match"] = "match"
                                                    self._segment_path = lambda: "non-vrf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                                class Match(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: internal
                                                    
                                                    	Redistribute OSPF internal routes
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: external
                                                    
                                                    	Redistribute OSPF external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: external2
                                                    
                                                    	Redistribute OSPF external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: nssa_external
                                                    
                                                    	Redistribute OSPF NSSA external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric for redistributed routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map reference
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                        self.yang_name = "match"
                                                        self.yang_parent_name = "non-vrf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                            ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.internal = None
                                                        self.external = None
                                                        self.external2 = None
                                                        self.nssa_external = None
                                                        self.metric = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "match"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                        class Ospfv3(Entity):
                                            """
                                            OSPFv3
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3, self).__init__()

                                                self.yang_name = "ospfv3"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.id = None
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                .. attribute:: internal
                                                
                                                	Redistribute OSPF internal routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: external
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: external2
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: nssa_external
                                                
                                                	Redistribute OSPF NSSA external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "ospfv3"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                        ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.internal = None
                                                    self.external = None
                                                    self.external2 = None
                                                    self.nssa_external = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: name
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self.name = None
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ip
                                            
                                            	
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None

                                                self.clns = None
                                                self._children_name_map["clns"] = "clns"

                                                self.ip = None
                                                self._children_name_map["ip"] = "ip"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                            class Clns(Entity):
                                                """
                                                Redistribution of OSI dynamic routes
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns, self).__init__()

                                                    self.yang_name = "clns"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "clns"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                            class Ip(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                                    class SegmentRouting(Entity):
                                        """
                                        segment\-routing
                                        
                                        .. attribute:: mpls
                                        
                                        	mpls
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting, self).__init__()

                                            self.yang_name = "segment-routing"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                            ])
                                            self.mpls = None
                                            self._segment_path = lambda: "segment-routing"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.SegmentRouting, ['mpls'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                                    class TableMap(Entity):
                                        """
                                        Map external entry attributes into routing table
                                        
                                        .. attribute:: name
                                        
                                        	WORD \:\: Route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: filter
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap, self).__init__()

                                            self.yang_name = "table-map"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                                            ])
                                            self.name = None
                                            self.filter = None
                                            self._segment_path = lambda: "table-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv4.Ipv4Unicast.TableMap, ['name', 'filter'], name, value)


                            class Ipv6(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`BgpIpv6AfType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.BgpIpv6AfType>`
                                
                                .. attribute:: ipv6_unicast
                                
                                	IPv6 Unicast address family
                                	**type**\:  :py:class:`Ipv6Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6, self).__init__()

                                    self.yang_name = "ipv6"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("ipv6-unicast", ("ipv6_unicast", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'BgpIpv6AfType', '')])),
                                    ])
                                    self.af_name = None

                                    self.ipv6_unicast = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast()
                                    self.ipv6_unicast.parent = self
                                    self._children_name_map["ipv6_unicast"] = "ipv6-unicast"
                                    self._segment_path = lambda: "ipv6" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6, ['af_name'], name, value)


                                class Ipv6Unicast(Entity):
                                    """
                                    IPv6 Unicast address family
                                    
                                    .. attribute:: aggregate_address
                                    
                                    	Configure BGP aggregate entries
                                    	**type**\: list of  		 :py:class:`AggregateAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress>`
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_>`
                                    
                                    .. attribute:: default_information
                                    
                                    	Control distribution of default information
                                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation>`
                                    
                                    .. attribute:: default_metric
                                    
                                    	Set metric of redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: distance
                                    
                                    	Define an administrative distance
                                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance>`
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor>`
                                    
                                    .. attribute:: network
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network>`
                                    
                                    .. attribute:: redistribute
                                    
                                    	Redistribute information from another routing protocol
                                    	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: synchronization
                                    
                                    	Perform IGP synchronization
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: table_map
                                    
                                    	Map external entry attributes into routing table
                                    	**type**\:  :py:class:`TableMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast, self).__init__()

                                        self.yang_name = "ipv6-unicast"
                                        self.yang_parent_name = "ipv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("aggregate-address", ("aggregate_address", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress)), ("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation)), ("distance", ("distance", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor)), ("network", ("network", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network)), ("redistribute", ("redistribute", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp)), ("table-map", ("table_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap))])
                                        self._leafs = OrderedDict([
                                            ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                            ('synchronization', (YLeaf(YType.empty, 'synchronization'), ['Empty'])),
                                        ])
                                        self.default_metric = None
                                        self.synchronization = None

                                        self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.default_information = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation()
                                        self.default_information.parent = self
                                        self._children_name_map["default_information"] = "default-information"

                                        self.distance = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.redistribute = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute()
                                        self.redistribute.parent = self
                                        self._children_name_map["redistribute"] = "redistribute"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.table_map = None
                                        self._children_name_map["table_map"] = "table-map"

                                        self.aggregate_address = YList(self)
                                        self.neighbor = YList(self)
                                        self.network = YList(self)
                                        self._segment_path = lambda: "ipv6-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast, ['default_metric', 'synchronization'], name, value)


                                    class AggregateAddress(Entity):
                                        """
                                        Configure BGP aggregate entries
                                        
                                        .. attribute:: ipv6_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: advertise_map
                                        
                                        	Set condition to advertise attribute
                                        	**type**\: str
                                        
                                        .. attribute:: as_set
                                        
                                        	Generate AS set path information
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: attribute_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: summary_only
                                        
                                        	Filter more specific routes from updates
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_map
                                        
                                        	Conditionally filter more specific routes from updates
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress, self).__init__()

                                            self.yang_name = "aggregate-address"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['ipv6_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('advertise_map', (YLeaf(YType.str, 'advertise-map'), ['str'])),
                                                ('as_set', (YLeaf(YType.empty, 'as-set'), ['Empty'])),
                                                ('attribute_map', (YLeaf(YType.str, 'attribute-map'), ['str'])),
                                                ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('summary_only', (YLeaf(YType.empty, 'summary-only'), ['Empty'])),
                                                ('suppress_map', (YLeaf(YType.str, 'suppress-map'), ['str'])),
                                            ])
                                            self.ipv6_address = None
                                            self.advertise_map = None
                                            self.as_set = None
                                            self.attribute_map = None
                                            self.as_override = None
                                            self.route_map = None
                                            self.summary_only = None
                                            self.suppress_map = None
                                            self._segment_path = lambda: "aggregate-address" + "[ipv6-address='" + str(self.ipv6_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.AggregateAddress, ['ipv6_address', 'advertise_map', 'as_set', 'attribute_map', 'as_override', 'route_map', 'summary_only', 'suppress_map'], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Additional paths in the BGP table
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths>`
                                        
                                        .. attribute:: advertise_best_external
                                        
                                        	Advertise best external path to internal peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Configure aggregation timer
                                        	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer>`
                                        
                                        .. attribute:: bestpath
                                        
                                        	Change the default bestpath selection
                                        	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath>`
                                        
                                        .. attribute:: dampening
                                        
                                        	Enable route\-flap dampening
                                        	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Use DMZ Link Bandwidth as weight for BGP multipaths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: inject_map
                                        
                                        	Route map which specifies prefixes to inject
                                        	**type**\: list of  		 :py:class:`InjectMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop>`
                                        
                                        .. attribute:: recursion
                                        
                                        	recursion rule for the nexthops
                                        	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion>`
                                        
                                        .. attribute:: redistribute_internal
                                        
                                        	Allow redistribution of iBGP into IGPs (dangerous)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	bgp route\-map commands
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfig_backup
                                        
                                        	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: suppress_inactive
                                        
                                        	Suppress routes that are not in the routing table
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: update_group
                                        
                                        	Manage peers in bgp update groups
                                        	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening)), ("inject-map", ("inject_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup))])
                                            self._leafs = OrderedDict([
                                                ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                                ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                                ('suppress_inactive', (YLeaf(YType.empty, 'suppress-inactive'), ['Empty'])),
                                            ])
                                            self.advertise_best_external = None
                                            self.dmzlink_bw = None
                                            self.redistribute_internal = None
                                            self.scan_time = None
                                            self.soft_reconfig_backup = None
                                            self.suppress_inactive = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.aggregate_timer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer()
                                            self.aggregate_timer.parent = self
                                            self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                            self.bestpath = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath()
                                            self.bestpath.parent = self
                                            self._children_name_map["bestpath"] = "bestpath"

                                            self.dampening = None
                                            self._children_name_map["dampening"] = "dampening"

                                            self.nexthop = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.recursion = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion()
                                            self.recursion.parent = self
                                            self._children_name_map["recursion"] = "recursion"

                                            self.route_map = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap()
                                            self.route_map.parent = self
                                            self._children_name_map["route_map"] = "route-map"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup()
                                            self.update_group.parent = self
                                            self._children_name_map["update_group"] = "update-group"

                                            self.inject_map = YList(self)
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup', 'suppress_inactive'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Additional paths in the BGP table
                                            
                                            .. attribute:: install
                                            
                                            	Additional paths to install into RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: select
                                            
                                            	Selection criteria to pick the paths
                                            	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to neighbors
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.install = None
                                                self.receive = None

                                                self.select = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select()
                                                self.select.parent = self
                                                self._children_name_map["select"] = "select"

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                            class Select(Entity):
                                                """
                                                Selection criteria to pick the paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                    self.yang_name = "select"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"

                                                    self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.best_external = None
                                                    self._children_name_map["best_external"] = "best-external"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "select"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                            self._leafs = OrderedDict()

                                                            self.range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                        class Range(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best path
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                                self.yang_name = "range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Select backup path
                                                    
                                                    .. attribute:: best_external
                                                    
                                                    	Select best\-external path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                        ])
                                                        self.best_external = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best path
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                                class BestExternal(Entity):
                                                    """
                                                    Select best\-external path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Select backup path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                        self.yang_name = "best-external"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                        ])
                                                        self.backup = None
                                                        self._segment_path = lambda: "best-external"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to neighbors
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                        class AggregateTimer(Entity):
                                            """
                                            Configure aggregation timer
                                            
                                            .. attribute:: aggregate_timer
                                            
                                            	Timer interval
                                            	**type**\: int
                                            
                                            	**range:** 6..60
                                            
                                            .. attribute:: disable_timer
                                            
                                            	Timer interval
                                            	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer, self).__init__()

                                                self.yang_name = "aggregate-timer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                    ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                                ])
                                                self.aggregate_timer = None
                                                self.disable_timer = None
                                                self._segment_path = lambda: "aggregate-timer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                            class DisableTimer(Enum):
                                                """
                                                DisableTimer (Enum Class)

                                                Timer interval

                                                .. data:: Y_0 = 0

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")



                                        class Bestpath(Entity):
                                            """
                                            Change the default bestpath selection
                                            
                                            .. attribute:: igp_metric
                                            
                                            	igp metric
                                            	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric>`
                                            
                                            .. attribute:: prefix_validate
                                            
                                            	Prefix origin validation
                                            	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath, self).__init__()

                                                self.yang_name = "bestpath"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate))])
                                                self._leafs = OrderedDict()

                                                self.igp_metric = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric()
                                                self.igp_metric.parent = self
                                                self._children_name_map["igp_metric"] = "igp-metric"

                                                self.prefix_validate = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate()
                                                self.prefix_validate.parent = self
                                                self._children_name_map["prefix_validate"] = "prefix-validate"
                                                self._segment_path = lambda: "bestpath"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath, [], name, value)


                                            class IgpMetric(Entity):
                                                """
                                                igp metric
                                                
                                                .. attribute:: ignore
                                                
                                                	Ignore igp metric in bestpath selection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                                    self.yang_name = "igp-metric"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ])
                                                    self.ignore = None
                                                    self._segment_path = lambda: "igp-metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                            class PrefixValidate(Entity):
                                                """
                                                Prefix origin validation
                                                
                                                .. attribute:: allow_invalid
                                                
                                                	Allow invalid routes to be considered for bestpath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: disable
                                                
                                                	Disable prefix validation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                                    self.yang_name = "prefix-validate"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.allow_invalid = None
                                                    self.disable = None
                                                    self._segment_path = lambda: "prefix-validate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                        class Dampening(Entity):
                                            """
                                            Enable route\-flap dampening
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria for dampening
                                            	**type**\: str
                                            
                                            .. attribute:: dampen
                                            
                                            	
                                            	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening, self).__init__()

                                                self.yang_name = "dampening"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.dampen = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen()
                                                self.dampen.parent = self
                                                self._children_name_map["dampen"] = "dampen"
                                                self._segment_path = lambda: "dampening"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                            class Dampen(Entity):
                                                """
                                                
                                                
                                                .. attribute:: half_life_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..45
                                                
                                                .. attribute:: reuse_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: max_suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                                    self.yang_name = "dampen"
                                                    self.yang_parent_name = "dampening"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                        ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                        ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                        ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                    ])
                                                    self.half_life_time = None
                                                    self.reuse_time = None
                                                    self.suppress_time = None
                                                    self.max_suppress_time = None
                                                    self._segment_path = lambda: "dampen"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                        class InjectMap(Entity):
                                            """
                                            Route map which specifies prefixes to inject
                                            
                                            .. attribute:: name  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: exist_map
                                            
                                            	Route map which specifies exist condition
                                            	**type**\: str
                                            
                                            .. attribute:: copy_attributes
                                            
                                            	Copy attributes from aggregate
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap, self).__init__()

                                                self.yang_name = "inject-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['name']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                    ('copy_attributes', (YLeaf(YType.empty, 'copy-attributes'), ['Empty'])),
                                                ])
                                                self.name = None
                                                self.exist_map = None
                                                self.copy_attributes = None
                                                self._segment_path = lambda: "inject-map" + "[name='" + str(self.name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.InjectMap, ['name', 'exist_map', 'copy_attributes'], name, value)


                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class Recursion(Entity):
                                            """
                                            recursion rule for the nexthops
                                            
                                            .. attribute:: host
                                            
                                            	recursion via host for the nexthops
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion, self).__init__()

                                                self.yang_name = "recursion"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                                ])
                                                self.host = None
                                                self._segment_path = lambda: "recursion"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.Recursion, ['host'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            bgp route\-map commands
                                            
                                            .. attribute:: priority
                                            
                                            	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class UpdateGroup(Entity):
                                            """
                                            Manage peers in bgp update groups
                                            
                                            .. attribute:: split
                                            
                                            	Split update groups based on Policy
                                            	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup, self).__init__()

                                                self.yang_name = "update-group"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split))])
                                                self._leafs = OrderedDict()

                                                self.split = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split()
                                                self.split.parent = self
                                                self._children_name_map["split"] = "split"
                                                self._segment_path = lambda: "update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup, [], name, value)


                                            class Split(Entity):
                                                """
                                                Split update groups based on Policy
                                                
                                                .. attribute:: as_override
                                                
                                                	Keep peers with as\-override in different update groups
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                                    self.yang_name = "split"
                                                    self.yang_parent_name = "update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                    ])
                                                    self.as_override = None
                                                    self._segment_path = lambda: "split"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                                    class DefaultInformation(Entity):
                                        """
                                        Control distribution of default information
                                        
                                        .. attribute:: originate
                                        
                                        	Distribute a default route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation, self).__init__()

                                            self.yang_name = "default-information"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                            ])
                                            self.originate = None
                                            self._segment_path = lambda: "default-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.DefaultInformation, ['originate'], name, value)


                                    class Distance(Entity):
                                        """
                                        Define an administrative distance
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP distance
                                        	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_>`
                                        
                                        .. attribute:: adm_distance
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`AdmDistance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_)), ("adm-distance", ("adm_distance", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance))])
                                            self._leafs = OrderedDict()

                                            self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.adm_distance = YList(self)
                                            self._segment_path = lambda: "distance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance, [], name, value)


                                        class Bgp_(Entity):
                                            """
                                            BGP distance
                                            
                                            .. attribute:: extern_as
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: internal_as
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: local
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "distance"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('extern_as', (YLeaf(YType.uint16, 'extern-as'), ['int'])),
                                                    ('internal_as', (YLeaf(YType.uint16, 'internal-as'), ['int'])),
                                                    ('local', (YLeaf(YType.uint16, 'local'), ['int'])),
                                                ])
                                                self.extern_as = None
                                                self.internal_as = None
                                                self.local = None
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.Bgp_, ['extern_as', 'internal_as', 'local'], name, value)


                                        class AdmDistance(Entity):
                                            """
                                            
                                            
                                            .. attribute:: distance  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: srcip  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: wildbits  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: acl
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..99
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..1999
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance, self).__init__()

                                                self.yang_name = "adm-distance"
                                                self.yang_parent_name = "distance"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['distance','srcip','wildbits']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('distance', (YLeaf(YType.uint16, 'distance'), ['int'])),
                                                    ('srcip', (YLeaf(YType.str, 'srcip'), ['str'])),
                                                    ('wildbits', (YLeaf(YType.str, 'wildbits'), ['str'])),
                                                    ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                                                ])
                                                self.distance = None
                                                self.srcip = None
                                                self.wildbits = None
                                                self.acl = None
                                                self._segment_path = lambda: "adm-distance" + "[distance='" + str(self.distance) + "']" + "[srcip='" + str(self.srcip) + "']" + "[wildbits='" + str(self.wildbits) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Distance.AdmDistance, ['distance', 'srcip', 'wildbits', 'acl'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: additional_paths
                                            
                                            	
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths>`
                                            
                                            .. attribute:: advertise
                                            
                                            	Advertise to this neighbor
                                            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise>`
                                            
                                            .. attribute:: advertise_map
                                            
                                            	specify route\-map for conditional advertisement
                                            	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap>`
                                            
                                            .. attribute:: aigp
                                            
                                            	Enable a AIGP on neighbor
                                            	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: announce
                                            
                                            	Announce RPKI state using an extended community
                                            	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce>`
                                            
                                            .. attribute:: as_override
                                            
                                            	Override matching AS\-number while sending update
                                            	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: default_originate
                                            
                                            	Originate default route to this neighbor
                                            	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: send_label
                                            
                                            	Send NLRI + MPLS Label to this peer
                                            	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: translate_update
                                            
                                            	Translate update to MBGP format
                                            	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate>`
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.advertise = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise()
                                                self.advertise.parent = self
                                                self._children_name_map["advertise"] = "advertise"

                                                self.advertise_map = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap()
                                                self.advertise_map.parent = self
                                                self._children_name_map["advertise_map"] = "advertise-map"

                                                self.aigp = None
                                                self._children_name_map["aigp"] = "aigp"

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.announce = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce()
                                                self.announce.parent = self
                                                self._children_name_map["announce"] = "announce"

                                                self.as_override = None
                                                self._children_name_map["as_override"] = "as-override"

                                                self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.default_originate = None
                                                self._children_name_map["default_originate"] = "default-originate"

                                                self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.send_label = None
                                                self._children_name_map["send_label"] = "send-label"

                                                self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.translate_update = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate()
                                                self.translate_update.parent = self
                                                self._children_name_map["translate_update"] = "translate-update"

                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor, ['id', 'activate', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class AdditionalPaths(Entity):
                                                """
                                                
                                                
                                                .. attribute:: disable
                                                
                                                	Disable additional paths for this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: send
                                                
                                                	Send additional paths to this neighbor
                                                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send))])
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self.receive = None

                                                    self.send = None
                                                    self._children_name_map["send"] = "send"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                                class Send(Entity):
                                                    """
                                                    Send additional paths to this neighbor
                                                    
                                                    .. attribute:: receive
                                                    
                                                    	Receive additional paths from this neighbor
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, self).__init__()

                                                        self.yang_name = "send"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                        ])
                                                        self.receive = None
                                                        self._segment_path = lambda: "send"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                            class Advertise(Entity):
                                                """
                                                Advertise to this neighbor
                                                
                                                .. attribute:: additional_paths
                                                
                                                	Advertise additional paths
                                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Advertise best\-external (at RRs best\-internal) path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: diverse_path
                                                
                                                	Advertise diverse path
                                                	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                                    self.yang_name = "advertise"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None

                                                    self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                                    self.additional_paths.parent = self
                                                    self._children_name_map["additional_paths"] = "additional-paths"

                                                    self.diverse_path = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                                    self.diverse_path.parent = self
                                                    self._children_name_map["diverse_path"] = "diverse-path"
                                                    self._segment_path = lambda: "advertise"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                                class AdditionalPaths(Entity):
                                                    """
                                                    Advertise additional paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                        self.yang_name = "additional-paths"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                        self._leafs = OrderedDict()

                                                        self.all = None
                                                        self._children_name_map["all"] = "all"

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "additional-paths"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                    class All(Entity):
                                                        """
                                                        Select all available paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Select best N paths
                                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                            self.yang_name = "all"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict()

                                                            self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                            self.best.parent = self
                                                            self._children_name_map["best"] = "best"

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "all"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                        class Best(Entity):
                                                            """
                                                            Select best N paths
                                                            
                                                            .. attribute:: best_range
                                                            
                                                            	
                                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                                self.yang_name = "best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                                self._leafs = OrderedDict()

                                                                self.best_range = YList(self)
                                                                self._segment_path = lambda: "best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                            class BestRange(Entity):
                                                                """
                                                                
                                                                
                                                                .. attribute:: range  (key)
                                                                
                                                                	Number of best paths in additional paths to be selected
                                                                	**type**\: int
                                                                
                                                                	**range:** 2..3
                                                                
                                                                .. attribute:: group_best
                                                                
                                                                	Select group\-best paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                    self.yang_name = "best-range"
                                                                    self.yang_parent_name = "best"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['range']
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                    ])
                                                                    self.range = None
                                                                    self.group_best = None
                                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: best
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                                ])
                                                                self.best = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.all = None

                                                                self.group_best = None
                                                                self._children_name_map["group_best"] = "group-best"
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                            class GroupBest(Entity):
                                                                """
                                                                Select group\-best paths
                                                                
                                                                .. attribute:: all
                                                                
                                                                	Select all available paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                    self.yang_name = "group-best"
                                                                    self.yang_parent_name = "best-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                    ])
                                                                    self.all = None
                                                                    self._segment_path = lambda: "group-best"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.all = None
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                                class DiversePath(Entity):
                                                    """
                                                    Advertise diverse path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Diverse path can be backup path
                                                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                        self.yang_name = "diverse-path"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None

                                                        self.backup = None
                                                        self._children_name_map["backup"] = "backup"
                                                        self._segment_path = lambda: "diverse-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                    class Backup(Entity):
                                                        """
                                                        Diverse path can be backup path
                                                        
                                                        .. attribute:: mpath
                                                        
                                                        	Diverse path can be multipath
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                            self.yang_name = "backup"
                                                            self.yang_parent_name = "diverse-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                            ])
                                                            self.mpath = None
                                                            self._segment_path = lambda: "backup"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                            class AdvertiseMap(Entity):
                                                """
                                                specify route\-map for conditional advertisement
                                                
                                                .. attribute:: name
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap, self).__init__()

                                                    self.yang_name = "advertise-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name))])
                                                    self._leafs = OrderedDict()

                                                    self.name = YList(self)
                                                    self._segment_path = lambda: "advertise-map"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap, [], name, value)


                                                class Name(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: word  (key)
                                                    
                                                    	advertise route\-map name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: exist_map
                                                    
                                                    	condition route\-map name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: non_exist_map
                                                    
                                                    	condition route\-map name
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, self).__init__()

                                                        self.yang_name = "name"
                                                        self.yang_parent_name = "advertise-map"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['word']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                            ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                            ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                        ])
                                                        self.word = None
                                                        self.exist_map = None
                                                        self.non_exist_map = None
                                                        self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                            class Aigp(Entity):
                                                """
                                                Enable a AIGP on neighbor
                                                
                                                .. attribute:: send
                                                
                                                	Cost community or MED carrying AIGP VALUE
                                                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp, self).__init__()

                                                    self.yang_name = "aigp"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.send = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send()
                                                    self.send.parent = self
                                                    self._children_name_map["send"] = "send"
                                                    self._segment_path = lambda: "aigp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp, [], name, value)


                                                class Send(Entity):
                                                    """
                                                    Cost community or MED carrying AIGP VALUE
                                                    
                                                    .. attribute:: cost_community
                                                    
                                                    	Cost extended community carrying AIGP Value
                                                    	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity>`
                                                    
                                                    .. attribute:: med
                                                    
                                                    	Med carrying AIGP Value
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send, self).__init__()

                                                        self.yang_name = "send"
                                                        self.yang_parent_name = "aigp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                        ])
                                                        self.med = None

                                                        self.cost_community = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity()
                                                        self.cost_community.parent = self
                                                        self._children_name_map["cost_community"] = "cost-community"
                                                        self._segment_path = lambda: "send"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send, ['med'], name, value)


                                                    class CostCommunity(Entity):
                                                        """
                                                        Cost extended community carrying AIGP Value
                                                        
                                                        .. attribute:: cc_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                            self.yang_name = "cost-community"
                                                            self.yang_parent_name = "send"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                            self._leafs = OrderedDict()

                                                            self.cc_range = YList(self)
                                                            self._segment_path = lambda: "cost-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                        class CcRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Community ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: poi
                                                            
                                                            	Point of insertion
                                                            	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                                self.yang_name = "cc-range"
                                                                self.yang_parent_name = "cost-community"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ])
                                                                self.range = None

                                                                self.poi = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                                self.poi.parent = self
                                                                self._children_name_map["poi"] = "poi"
                                                                self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                            class Poi(Entity):
                                                                """
                                                                Point of insertion
                                                                
                                                                .. attribute:: igp_cost
                                                                
                                                                	Point of insertion after IGP
                                                                	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                                
                                                                	**presence node**\: True
                                                                
                                                                .. attribute:: pre_bestpath
                                                                
                                                                	Point of insertion at beginning
                                                                	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                                
                                                                	**presence node**\: True
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                    self.yang_name = "poi"
                                                                    self.yang_parent_name = "cc-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                    self._leafs = OrderedDict()

                                                                    self.igp_cost = None
                                                                    self._children_name_map["igp_cost"] = "igp-cost"

                                                                    self.pre_bestpath = None
                                                                    self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                    self._segment_path = lambda: "poi"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                                class IgpCost(Entity):
                                                                    """
                                                                    Point of insertion after IGP
                                                                    
                                                                    .. attribute:: transitive
                                                                    
                                                                    	Cost community is transitive
                                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                    
                                                                    

                                                                    This class is a :ref:`presence class<presence-class>`

                                                                    """

                                                                    _prefix = 'ios-bgp'
                                                                    _revision = '2018-06-28'

                                                                    def __init__(self):
                                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                        self.yang_name = "igp-cost"
                                                                        self.yang_parent_name = "poi"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self.is_presence_container = True
                                                                        self._leafs = OrderedDict([
                                                                            ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                        ])
                                                                        self.transitive = None
                                                                        self._segment_path = lambda: "igp-cost"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                                class PreBestpath(Entity):
                                                                    """
                                                                    Point of insertion at beginning
                                                                    
                                                                    .. attribute:: transitive
                                                                    
                                                                    	Cost community is transitive
                                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                    
                                                                    

                                                                    This class is a :ref:`presence class<presence-class>`

                                                                    """

                                                                    _prefix = 'ios-bgp'
                                                                    _revision = '2018-06-28'

                                                                    def __init__(self):
                                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                        self.yang_name = "pre-bestpath"
                                                                        self.yang_parent_name = "poi"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self.is_presence_container = True
                                                                        self._leafs = OrderedDict([
                                                                            ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                        ])
                                                                        self.transitive = None
                                                                        self._segment_path = lambda: "pre-bestpath"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Announce(Entity):
                                                """
                                                Announce RPKI state using an extended community
                                                
                                                .. attribute:: rpki
                                                
                                                	Announce RPKI information using an extended community
                                                	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce, self).__init__()

                                                    self.yang_name = "announce"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki))])
                                                    self._leafs = OrderedDict()

                                                    self.rpki = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki()
                                                    self.rpki.parent = self
                                                    self._children_name_map["rpki"] = "rpki"
                                                    self._segment_path = lambda: "announce"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce, [], name, value)


                                                class Rpki(Entity):
                                                    """
                                                    Announce RPKI information using an extended community
                                                    
                                                    .. attribute:: state
                                                    
                                                    	Announce RPKI state information using an extended community
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki, self).__init__()

                                                        self.yang_name = "rpki"
                                                        self.yang_parent_name = "announce"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                        ])
                                                        self.state = None
                                                        self._segment_path = lambda: "rpki"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Announce.Rpki, ['state'], name, value)


                                            class AsOverride(Entity):
                                                """
                                                Override matching AS\-number while sending update
                                                
                                                .. attribute:: disable
                                                
                                                	
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride, self).__init__()

                                                    self.yang_name = "as-override"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self._segment_path = lambda: "as-override"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.AsOverride, ['disable'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class DefaultOriginate(Entity):
                                                """
                                                Originate default route to this neighbor
                                                
                                                .. attribute:: route_map
                                                
                                                	Route\-map to specify criteria to originate default
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                    self.yang_name = "default-originate"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default-originate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SendLabel(Entity):
                                                """
                                                Send NLRI + MPLS Label to this peer
                                                
                                                .. attribute:: send_label_explicit
                                                
                                                	
                                                	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel, self).__init__()

                                                    self.yang_name = "send-label"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit')])),
                                                    ])
                                                    self.send_label_explicit = None
                                                    self._segment_path = lambda: "send-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                                class SendLabelExplicit(Enum):
                                                    """
                                                    SendLabelExplicit (Enum Class)

                                                    .. data:: explicit_null = 0

                                                    """

                                                    explicit_null = Enum.YLeaf(0, "explicit-null")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                            class TranslateUpdate(Entity):
                                                """
                                                Translate update to MBGP format
                                                
                                                .. attribute:: ipv4
                                                
                                                	Address Family
                                                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate, self).__init__()

                                                    self.yang_name = "translate-update"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv4 = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4()
                                                    self.ipv4.parent = self
                                                    self._children_name_map["ipv4"] = "ipv4"
                                                    self._segment_path = lambda: "translate-update"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate, [], name, value)


                                                class Ipv4(Entity):
                                                    """
                                                    Address Family
                                                    
                                                    .. attribute:: multicast
                                                    
                                                    	Address Family modifier
                                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4, self).__init__()

                                                        self.yang_name = "ipv4"
                                                        self.yang_parent_name = "translate-update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast))])
                                                        self._leafs = OrderedDict()

                                                        self.multicast = None
                                                        self._children_name_map["multicast"] = "multicast"
                                                        self._segment_path = lambda: "ipv4"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4, [], name, value)


                                                    class Multicast(Entity):
                                                        """
                                                        Address Family modifier
                                                        
                                                        .. attribute:: unicast
                                                        
                                                        	Address Family modifier
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast, self).__init__()

                                                            self.yang_name = "multicast"
                                                            self.yang_parent_name = "ipv4"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                            ])
                                                            self.unicast = None
                                                            self._segment_path = lambda: "multicast"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.PeerGroup.Neighbor.TranslateUpdate.Ipv4.Multicast, ['unicast'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: additional_paths
                                        
                                        	
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths>`
                                        
                                        .. attribute:: advertise
                                        
                                        	Advertise to this neighbor
                                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise>`
                                        
                                        .. attribute:: advertise_map
                                        
                                        	specify route\-map for conditional advertisement
                                        	**type**\:  :py:class:`AdvertiseMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap>`
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable a AIGP on neighbor
                                        	**type**\:  :py:class:`Aigp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: announce
                                        
                                        	Announce RPKI state using an extended community
                                        	**type**\:  :py:class:`Announce <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce>`
                                        
                                        .. attribute:: as_override
                                        
                                        	Override matching AS\-number while sending update
                                        	**type**\:  :py:class:`AsOverride <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability>`
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: send_label
                                        
                                        	Send NLRI + MPLS Label to this peer
                                        	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: translate_update
                                        
                                        	Translate update to MBGP format
                                        	**type**\:  :py:class:`TranslateUpdate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate>`
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise)), ("advertise-map", ("advertise_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap)), ("aigp", ("aigp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn)), ("announce", ("announce", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce)), ("as-override", ("as_override", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer)), ("translate-update", ("translate_update", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.advertise = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise()
                                            self.advertise.parent = self
                                            self._children_name_map["advertise"] = "advertise"

                                            self.advertise_map = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap()
                                            self.advertise_map.parent = self
                                            self._children_name_map["advertise_map"] = "advertise-map"

                                            self.aigp = None
                                            self._children_name_map["aigp"] = "aigp"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.announce = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce()
                                            self.announce.parent = self
                                            self._children_name_map["announce"] = "announce"

                                            self.as_override = None
                                            self._children_name_map["as_override"] = "as-override"

                                            self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.send_label = None
                                            self._children_name_map["send_label"] = "send-label"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.translate_update = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate()
                                            self.translate_update.parent = self
                                            self._children_name_map["translate_update"] = "translate-update"

                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor, ['id', 'activate', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AdditionalPaths(Entity):
                                            """
                                            
                                            
                                            .. attribute:: disable
                                            
                                            	Disable additional paths for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to this neighbor
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self.receive = None

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to this neighbor
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                        class Advertise(Entity):
                                            """
                                            Advertise to this neighbor
                                            
                                            .. attribute:: additional_paths
                                            
                                            	Advertise additional paths
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Advertise best\-external (at RRs best\-internal) path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: diverse_path
                                            
                                            	Advertise diverse path
                                            	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise, self).__init__()

                                                self.yang_name = "advertise"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath))])
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.diverse_path = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath()
                                                self.diverse_path.parent = self
                                                self._children_name_map["diverse_path"] = "diverse-path"
                                                self._segment_path = lambda: "advertise"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                            class AdditionalPaths(Entity):
                                                """
                                                Advertise additional paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "best-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                            class DiversePath(Entity):
                                                """
                                                Advertise diverse path
                                                
                                                .. attribute:: backup
                                                
                                                	Diverse path can be backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                                    self.yang_name = "diverse-path"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"
                                                    self._segment_path = lambda: "diverse-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Diverse path can be backup path
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "diverse-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                        class AdvertiseMap(Entity):
                                            """
                                            specify route\-map for conditional advertisement
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap, self).__init__()

                                                self.yang_name = "advertise-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name))])
                                                self._leafs = OrderedDict()

                                                self.name = YList(self)
                                                self._segment_path = lambda: "advertise-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap, [], name, value)


                                            class Name(Entity):
                                                """
                                                
                                                
                                                .. attribute:: word  (key)
                                                
                                                	advertise route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: non_exist_map
                                                
                                                	condition route\-map name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name, self).__init__()

                                                    self.yang_name = "name"
                                                    self.yang_parent_name = "advertise-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                        ('exist_map', (YLeaf(YType.str, 'exist-map'), ['str'])),
                                                        ('non_exist_map', (YLeaf(YType.str, 'non-exist-map'), ['str'])),
                                                    ])
                                                    self.word = None
                                                    self.exist_map = None
                                                    self.non_exist_map = None
                                                    self._segment_path = lambda: "name" + "[word='" + str(self.word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AdvertiseMap.Name, ['word', 'exist_map', 'non_exist_map'], name, value)


                                        class Aigp(Entity):
                                            """
                                            Enable a AIGP on neighbor
                                            
                                            .. attribute:: send
                                            
                                            	Cost community or MED carrying AIGP VALUE
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp, self).__init__()

                                                self.yang_name = "aigp"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.send = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send()
                                                self.send.parent = self
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "aigp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp, [], name, value)


                                            class Send(Entity):
                                                """
                                                Cost community or MED carrying AIGP VALUE
                                                
                                                .. attribute:: cost_community
                                                
                                                	Cost extended community carrying AIGP Value
                                                	**type**\:  :py:class:`CostCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity>`
                                                
                                                .. attribute:: med
                                                
                                                	Med carrying AIGP Value
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "aigp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cost-community", ("cost_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('med', (YLeaf(YType.empty, 'med'), ['Empty'])),
                                                    ])
                                                    self.med = None

                                                    self.cost_community = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity()
                                                    self.cost_community.parent = self
                                                    self._children_name_map["cost_community"] = "cost-community"
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send, ['med'], name, value)


                                                class CostCommunity(Entity):
                                                    """
                                                    Cost extended community carrying AIGP Value
                                                    
                                                    .. attribute:: cc_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`CcRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity, self).__init__()

                                                        self.yang_name = "cost-community"
                                                        self.yang_parent_name = "send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("cc-range", ("cc_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange))])
                                                        self._leafs = OrderedDict()

                                                        self.cc_range = YList(self)
                                                        self._segment_path = lambda: "cost-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity, [], name, value)


                                                    class CcRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Community ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: poi
                                                        
                                                        	Point of insertion
                                                        	**type**\:  :py:class:`Poi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, self).__init__()

                                                            self.yang_name = "cc-range"
                                                            self.yang_parent_name = "cost-community"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("poi", ("poi", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                            ])
                                                            self.range = None

                                                            self.poi = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi()
                                                            self.poi.parent = self
                                                            self._children_name_map["poi"] = "poi"
                                                            self._segment_path = lambda: "cc-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange, ['range'], name, value)


                                                        class Poi(Entity):
                                                            """
                                                            Point of insertion
                                                            
                                                            .. attribute:: igp_cost
                                                            
                                                            	Point of insertion after IGP
                                                            	**type**\:  :py:class:`IgpCost <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            .. attribute:: pre_bestpath
                                                            
                                                            	Point of insertion at beginning
                                                            	**type**\:  :py:class:`PreBestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, self).__init__()

                                                                self.yang_name = "poi"
                                                                self.yang_parent_name = "cc-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("igp-cost", ("igp_cost", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost)), ("pre-bestpath", ("pre_bestpath", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath))])
                                                                self._leafs = OrderedDict()

                                                                self.igp_cost = None
                                                                self._children_name_map["igp_cost"] = "igp-cost"

                                                                self.pre_bestpath = None
                                                                self._children_name_map["pre_bestpath"] = "pre-bestpath"
                                                                self._segment_path = lambda: "poi"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi, [], name, value)


                                                            class IgpCost(Entity):
                                                                """
                                                                Point of insertion after IGP
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, self).__init__()

                                                                    self.yang_name = "igp-cost"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "igp-cost"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.IgpCost, ['transitive'], name, value)


                                                            class PreBestpath(Entity):
                                                                """
                                                                Point of insertion at beginning
                                                                
                                                                .. attribute:: transitive
                                                                
                                                                	Cost community is transitive
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, self).__init__()

                                                                    self.yang_name = "pre-bestpath"
                                                                    self.yang_parent_name = "poi"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('transitive', (YLeaf(YType.empty, 'transitive'), ['Empty'])),
                                                                    ])
                                                                    self.transitive = None
                                                                    self._segment_path = lambda: "pre-bestpath"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Aigp.Send.CostCommunity.CcRange.Poi.PreBestpath, ['transitive'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Announce(Entity):
                                            """
                                            Announce RPKI state using an extended community
                                            
                                            .. attribute:: rpki
                                            
                                            	Announce RPKI information using an extended community
                                            	**type**\:  :py:class:`Rpki <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce, self).__init__()

                                                self.yang_name = "announce"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rpki", ("rpki", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki))])
                                                self._leafs = OrderedDict()

                                                self.rpki = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki()
                                                self.rpki.parent = self
                                                self._children_name_map["rpki"] = "rpki"
                                                self._segment_path = lambda: "announce"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce, [], name, value)


                                            class Rpki(Entity):
                                                """
                                                Announce RPKI information using an extended community
                                                
                                                .. attribute:: state
                                                
                                                	Announce RPKI state information using an extended community
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki, self).__init__()

                                                    self.yang_name = "rpki"
                                                    self.yang_parent_name = "announce"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('state', (YLeaf(YType.empty, 'state'), ['Empty'])),
                                                    ])
                                                    self.state = None
                                                    self._segment_path = lambda: "rpki"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Announce.Rpki, ['state'], name, value)


                                        class AsOverride(Entity):
                                            """
                                            Override matching AS\-number while sending update
                                            
                                            .. attribute:: disable
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride, self).__init__()

                                                self.yang_name = "as-override"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self._segment_path = lambda: "as-override"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.AsOverride, ['disable'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SendLabel(Entity):
                                            """
                                            Send NLRI + MPLS Label to this peer
                                            
                                            .. attribute:: send_label_explicit
                                            
                                            	
                                            	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel.SendLabelExplicit>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel, self).__init__()

                                                self.yang_name = "send-label"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel.SendLabelExplicit')])),
                                                ])
                                                self.send_label_explicit = None
                                                self._segment_path = lambda: "send-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                            class SendLabelExplicit(Enum):
                                                """
                                                SendLabelExplicit (Enum Class)

                                                .. data:: explicit_null = 0

                                                """

                                                explicit_null = Enum.YLeaf(0, "explicit-null")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class TranslateUpdate(Entity):
                                            """
                                            Translate update to MBGP format
                                            
                                            .. attribute:: ipv4
                                            
                                            	Address Family
                                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate, self).__init__()

                                                self.yang_name = "translate-update"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4))])
                                                self._leafs = OrderedDict()

                                                self.ipv4 = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4()
                                                self.ipv4.parent = self
                                                self._children_name_map["ipv4"] = "ipv4"
                                                self._segment_path = lambda: "translate-update"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate, [], name, value)


                                            class Ipv4(Entity):
                                                """
                                                Address Family
                                                
                                                .. attribute:: multicast
                                                
                                                	Address Family modifier
                                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4, self).__init__()

                                                    self.yang_name = "ipv4"
                                                    self.yang_parent_name = "translate-update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("multicast", ("multicast", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast))])
                                                    self._leafs = OrderedDict()

                                                    self.multicast = None
                                                    self._children_name_map["multicast"] = "multicast"
                                                    self._segment_path = lambda: "ipv4"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4, [], name, value)


                                                class Multicast(Entity):
                                                    """
                                                    Address Family modifier
                                                    
                                                    .. attribute:: unicast
                                                    
                                                    	Address Family modifier
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast, self).__init__()

                                                        self.yang_name = "multicast"
                                                        self.yang_parent_name = "ipv4"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                                                        ])
                                                        self.unicast = None
                                                        self._segment_path = lambda: "multicast"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Neighbor.TranslateUpdate.Ipv4.Multicast, ['unicast'], name, value)


                                    class Network(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: number  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to modify the attributes
                                        	**type**\: str
                                        
                                        .. attribute:: backdoor
                                        
                                        	Specify a BGP backdoor route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['number']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                            ])
                                            self.number = None
                                            self.route_map = None
                                            self.backdoor = None
                                            self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Network, ['number', 'route_map', 'backdoor'], name, value)


                                    class Redistribute(Entity):
                                        """
                                        Redistribute information from another routing protocol
                                        
                                        .. attribute:: application
                                        
                                        	Application
                                        	**type**\:  :py:class:`Application <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: bgp
                                        
                                        	Border Gateway Protocol (BGP)
                                        	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dvmrp
                                        
                                        	Redistribution of DVMRP into BGP IPv4 Multicast
                                        	**type**\:  :py:class:`Dvmrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: eigrp
                                        
                                        	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                        	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISO IS\-IS
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: lisp
                                        
                                        	Locator/ID Separation Protocol
                                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: iso_igrp
                                        
                                        	IGRP for OSI networks
                                        	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile routes
                                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: odr
                                        
                                        	On Demand stub Routes
                                        	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: ospf
                                        
                                        	Open Shortest Path First (OSPF)
                                        	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf>`
                                        
                                        .. attribute:: ospfv3
                                        
                                        	OSPFv3
                                        	**type**\: list of  		 :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3>`
                                        
                                        .. attribute:: rip
                                        
                                        	Routing Information Protocol (RIP)
                                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: static
                                        
                                        	Static routes
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute, self).__init__()

                                            self.yang_name = "redistribute"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("application", ("application", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application)), ("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_)), ("connected", ("connected", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected)), ("dvmrp", ("dvmrp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp)), ("eigrp", ("eigrp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp)), ("iso-igrp", ("iso_igrp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf)), ("ospfv3", ("ospfv3", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3)), ("rip", ("rip", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip)), ("static", ("static", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static))])
                                            self._leafs = OrderedDict()

                                            self.application = None
                                            self._children_name_map["application"] = "application"

                                            self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.connected = None
                                            self._children_name_map["connected"] = "connected"

                                            self.dvmrp = None
                                            self._children_name_map["dvmrp"] = "dvmrp"

                                            self.eigrp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"

                                            self.isis = None
                                            self._children_name_map["isis"] = "isis"

                                            self.lisp = None
                                            self._children_name_map["lisp"] = "lisp"

                                            self.iso_igrp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp()
                                            self.iso_igrp.parent = self
                                            self._children_name_map["iso_igrp"] = "iso-igrp"

                                            self.mobile = None
                                            self._children_name_map["mobile"] = "mobile"

                                            self.odr = None
                                            self._children_name_map["odr"] = "odr"

                                            self.rip = None
                                            self._children_name_map["rip"] = "rip"

                                            self.static = None
                                            self._children_name_map["static"] = "static"

                                            self.ospf = YList(self)
                                            self.ospfv3 = YList(self)
                                            self._segment_path = lambda: "redistribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute, [], name, value)


                                        class Application(Entity):
                                            """
                                            Application
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("name", ("name", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.name = YList(self)
                                                self._segment_path = lambda: "application"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application, [], name, value)


                                            class Name(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	WORD \:\: Route\-map name
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name, self).__init__()

                                                    self.yang_name = "name"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "name" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Application.Name, ['name', 'metric', 'route_map'], name, value)


                                        class Bgp_(Entity):
                                            """
                                            Border Gateway Protocol (BGP)
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..4294967295
                                            
                                            		**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.str, 'as-no'), ['int','str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.as_no = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Bgp_, ['as_no', 'metric', 'route_map'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Connected, ['metric', 'route_map'], name, value)


                                        class Dvmrp(Entity):
                                            """
                                            Redistribution of DVMRP into BGP IPv4 Multicast
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp, self).__init__()

                                                self.yang_name = "dvmrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ])
                                                self.route_map = None
                                                self.metric = None
                                                self._segment_path = lambda: "dvmrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Dvmrp, ['route_map', 'metric'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            Enhanced Interior Gateway Routing Protocol (EIGRP)
                                            
                                            .. attribute:: as_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('as_no', (YLeaf(YType.uint16, 'as-no'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.as_no = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "eigrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Eigrp, ['as_no', 'metric', 'route_map'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISO IS\-IS
                                            
                                            .. attribute:: isis_area
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea>`
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea)), ("default", ("default", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.default = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default()
                                                self.default.parent = self
                                                self._children_name_map["default"] = "default"

                                                self.isis_area = YList(self)
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis, [], name, value)


                                            class IsisArea(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of IP dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: clns
                                                
                                                	Redistribution of OSI dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: routes
                                                
                                                	
                                                	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea.Routes>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea, self).__init__()

                                                    self.yang_name = "isis-area"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                        ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                        ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea.Routes')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.ip = None
                                                    self.clns = None
                                                    self.routes = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.IsisArea, ['name', 'ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                                class Routes(Enum):
                                                    """
                                                    Routes (Enum Class)

                                                    .. data:: level_1 = 0

                                                    .. data:: level_2 = 1

                                                    .. data:: level_1_2 = 2

                                                    """

                                                    level_1 = Enum.YLeaf(0, "level-1")

                                                    level_2 = Enum.YLeaf(1, "level-2")

                                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                            class Default(Entity):
                                                """
                                                
                                                
                                                .. attribute:: ip
                                                
                                                	Redistribution of IP dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: clns
                                                
                                                	Redistribution of OSI dynamic routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: routes
                                                
                                                	
                                                	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default.Routes>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default, self).__init__()

                                                    self.yang_name = "default"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ip', (YLeaf(YType.empty, 'ip'), ['Empty'])),
                                                        ('clns', (YLeaf(YType.empty, 'clns'), ['Empty'])),
                                                        ('routes', (YLeaf(YType.enumeration, 'routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default.Routes')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.ip = None
                                                    self.clns = None
                                                    self.routes = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Isis.Default, ['ip', 'clns', 'routes', 'metric', 'route_map'], name, value)

                                                class Routes(Enum):
                                                    """
                                                    Routes (Enum Class)

                                                    .. data:: level_1 = 0

                                                    .. data:: level_2 = 1

                                                    .. data:: level_1_2 = 2

                                                    """

                                                    level_1 = Enum.YLeaf(0, "level-1")

                                                    level_2 = Enum.YLeaf(1, "level-2")

                                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class Lisp(Entity):
                                            """
                                            Locator/ID Separation Protocol
                                            
                                            .. attribute:: include_connected
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp, self).__init__()

                                                self.yang_name = "lisp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('include_connected', (YLeaf(YType.empty, 'include-connected'), ['Empty'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.include_connected = None
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "lisp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Lisp, ['include_connected', 'metric', 'route_map'], name, value)


                                        class IsoIgrp(Entity):
                                            """
                                            IGRP for OSI networks
                                            
                                            .. attribute:: iso_igrp_area
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`IsoIgrpArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea>`
                                            
                                            .. attribute:: default
                                            
                                            	
                                            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp, self).__init__()

                                                self.yang_name = "iso-igrp"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("iso-igrp-area", ("iso_igrp_area", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea)), ("default", ("default", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default))])
                                                self._leafs = OrderedDict()

                                                self.default = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default()
                                                self.default.parent = self
                                                self._children_name_map["default"] = "default"

                                                self.iso_igrp_area = YList(self)
                                                self._segment_path = lambda: "iso-igrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp, [], name, value)


                                            class IsoIgrpArea(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea, self).__init__()

                                                    self.yang_name = "iso-igrp-area"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.name = None
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "iso-igrp-area" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.IsoIgrpArea, ['name', 'route_map', 'metric'], name, value)


                                            class Default(Entity):
                                                """
                                                
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default, self).__init__()

                                                    self.yang_name = "default"
                                                    self.yang_parent_name = "iso-igrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "default"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.IsoIgrp.Default, ['route_map', 'metric'], name, value)


                                        class Mobile(Entity):
                                            """
                                            Mobile routes
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "mobile"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                                        class Odr(Entity):
                                            """
                                            On Demand stub Routes
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr, self).__init__()

                                                self.yang_name = "odr"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self._segment_path = lambda: "odr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Odr, ['metric', 'route_map'], name, value)


                                        class Ospf(Entity):
                                            """
                                            Open Shortest Path First (OSPF)
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: vrf
                                            
                                            	VPN Routing/Forwarding Instance
                                            	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf_>`
                                            
                                            .. attribute:: non_vrf
                                            
                                            	
                                            	**type**\:  :py:class:`NonVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf_)), ("non-vrf", ("non_vrf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                ])
                                                self.id = None

                                                self.non_vrf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf()
                                                self.non_vrf.parent = self
                                                self._children_name_map["non_vrf"] = "non-vrf"

                                                self.vrf = YList(self)
                                                self._segment_path = lambda: "ospf" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf, ['id'], name, value)


                                            class Vrf_(Entity):
                                                """
                                                VPN Routing/Forwarding Instance
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: match
                                                
                                                	
                                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf_.Match>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf_, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf_.Match))])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.name = None
                                                    self.metric = None
                                                    self.route_map = None

                                                    self.match = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf_.Match()
                                                    self.match.parent = self
                                                    self._children_name_map["match"] = "match"
                                                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf_, ['name', 'metric', 'route_map'], name, value)


                                                class Match(Entity):
                                                    """
                                                    
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.Vrf_.Match, self).__init__()

                                                        self.yang_name = "match"
                                                        self.yang_parent_name = "vrf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict()
                                                        self._segment_path = lambda: "match"
                                                        self._is_frozen = True


                                            class NonVrf(Entity):
                                                """
                                                
                                                
                                                .. attribute:: match
                                                
                                                	
                                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf, self).__init__()

                                                    self.yang_name = "non-vrf"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match))])
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.metric = None
                                                    self.route_map = None

                                                    self.match = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match()
                                                    self.match.parent = self
                                                    self._children_name_map["match"] = "match"
                                                    self._segment_path = lambda: "non-vrf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf, ['metric', 'route_map'], name, value)


                                                class Match(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: internal
                                                    
                                                    	Redistribute OSPF internal routes
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: external
                                                    
                                                    	Redistribute OSPF external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: external2
                                                    
                                                    	Redistribute OSPF external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: nssa_external
                                                    
                                                    	Redistribute OSPF NSSA external routes
                                                    	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric for redistributed routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_map
                                                    
                                                    	Route map reference
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match, self).__init__()

                                                        self.yang_name = "match"
                                                        self.yang_parent_name = "non-vrf"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                            ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ])
                                                        self.internal = None
                                                        self.external = None
                                                        self.external2 = None
                                                        self.nssa_external = None
                                                        self.metric = None
                                                        self.route_map = None
                                                        self._segment_path = lambda: "match"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospf.NonVrf.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                        class Ospfv3(Entity):
                                            """
                                            OSPFv3
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: match
                                            
                                            	
                                            	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3, self).__init__()

                                                self.yang_name = "ospfv3"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("match", ("match", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint16, 'id'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.id = None
                                                self.metric = None
                                                self.route_map = None

                                                self.match = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match()
                                                self.match.parent = self
                                                self._children_name_map["match"] = "match"
                                                self._segment_path = lambda: "ospfv3" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3, ['id', 'metric', 'route_map'], name, value)


                                            class Match(Entity):
                                                """
                                                
                                                
                                                .. attribute:: internal
                                                
                                                	Redistribute OSPF internal routes
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: external
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: external2
                                                
                                                	Redistribute OSPF external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: nssa_external
                                                
                                                	Redistribute OSPF NSSA external routes
                                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match, self).__init__()

                                                    self.yang_name = "match"
                                                    self.yang_parent_name = "ospfv3"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('internal', (YLeaf(YType.empty, 'internal'), ['Empty'])),
                                                        ('external', (YLeaf(YType.enumeration, 'external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('external2', (YLeaf(YType.enumeration, 'external2'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('nssa_external', (YLeaf(YType.enumeration, 'nssa-external'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.internal = None
                                                    self.external = None
                                                    self.external2 = None
                                                    self.nssa_external = None
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "match"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Ospfv3.Match, ['internal', 'external', 'external2', 'nssa_external', 'metric', 'route_map'], name, value)


                                        class Rip(Entity):
                                            """
                                            Routing Information Protocol (RIP)
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            .. attribute:: name
                                            
                                            	User selected string identifying this process
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None
                                                self.name = None
                                                self._segment_path = lambda: "rip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Rip, ['metric', 'route_map', 'name'], name, value)


                                        class Static(Entity):
                                            """
                                            Static routes
                                            
                                            .. attribute:: clns
                                            
                                            	Redistribution of OSI dynamic routes
                                            	**type**\:  :py:class:`Clns <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: ip
                                            
                                            	
                                            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "redistribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("clns", ("clns", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns)), ("ip", ("ip", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.metric = None
                                                self.route_map = None

                                                self.clns = None
                                                self._children_name_map["clns"] = "clns"

                                                self.ip = None
                                                self._children_name_map["ip"] = "ip"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static, ['metric', 'route_map'], name, value)


                                            class Clns(Entity):
                                                """
                                                Redistribution of OSI dynamic routes
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns, self).__init__()

                                                    self.yang_name = "clns"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ])
                                                    self.route_map = None
                                                    self.metric = None
                                                    self._segment_path = lambda: "clns"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Clns, ['route_map', 'metric'], name, value)


                                            class Ip(Entity):
                                                """
                                                
                                                
                                                .. attribute:: metric
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_map
                                                
                                                	Route map reference
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip, self).__init__()

                                                    self.yang_name = "ip"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.metric = None
                                                    self.route_map = None
                                                    self._segment_path = lambda: "ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Redistribute.Static.Ip, ['metric', 'route_map'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                                    class TableMap(Entity):
                                        """
                                        Map external entry attributes into routing table
                                        
                                        .. attribute:: name
                                        
                                        	WORD \:\: Route\-map name
                                        	**type**\: str
                                        
                                        .. attribute:: filter
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap, self).__init__()

                                            self.yang_name = "table-map"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('filter', (YLeaf(YType.empty, 'filter'), ['Empty'])),
                                            ])
                                            self.name = None
                                            self.filter = None
                                            self._segment_path = lambda: "table-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Ipv6.Ipv6Unicast.TableMap, ['name', 'filter'], name, value)


                            class Vpnv4(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.AfName>`
                                
                                .. attribute:: vpnv4_unicast
                                
                                	VPNv4 Unicast address family
                                	**type**\:  :py:class:`Vpnv4Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4, self).__init__()

                                    self.yang_name = "vpnv4"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("vpnv4-unicast", ("vpnv4_unicast", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.AfName')])),
                                    ])
                                    self.af_name = None

                                    self.vpnv4_unicast = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast()
                                    self.vpnv4_unicast.parent = self
                                    self._children_name_map["vpnv4_unicast"] = "vpnv4-unicast"
                                    self._segment_path = lambda: "vpnv4" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4, ['af_name'], name, value)

                                class AfName(Enum):
                                    """
                                    AfName (Enum Class)

                                    .. data:: unicast = 0

                                    .. data:: multicast = 1

                                    .. data:: flowspec = 2

                                    """

                                    unicast = Enum.YLeaf(0, "unicast")

                                    multicast = Enum.YLeaf(1, "multicast")

                                    flowspec = Enum.YLeaf(2, "flowspec")



                                class Vpnv4Unicast(Entity):
                                    """
                                    VPNv4 Unicast address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_>`
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor>`
                                    
                                    .. attribute:: network
                                    
                                    	
                                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast, self).__init__()

                                        self.yang_name = "vpnv4-unicast"
                                        self.yang_parent_name = "vpnv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor)), ("network", ("network", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.network = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network()
                                        self.network.parent = self
                                        self._children_name_map["network"] = "network"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "vpnv4-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Additional paths in the BGP table
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths>`
                                        
                                        .. attribute:: advertise_best_external
                                        
                                        	Advertise best external path to internal peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Configure aggregation timer
                                        	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer>`
                                        
                                        .. attribute:: bestpath
                                        
                                        	Change the default bestpath selection
                                        	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath>`
                                        
                                        .. attribute:: dampening
                                        
                                        	Enable route\-flap dampening
                                        	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: default
                                        
                                        	Configure BGP defaults
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Use DMZ Link Bandwidth as weight for BGP multipaths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop>`
                                        
                                        .. attribute:: recursion
                                        
                                        	recursion rule for the nexthops
                                        	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion>`
                                        
                                        .. attribute:: redistribute_internal
                                        
                                        	Allow redistribution of iBGP into IGPs (dangerous)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	bgp route\-map commands
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfig_backup
                                        
                                        	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: update_group
                                        
                                        	Manage peers in bgp update groups
                                        	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening)), ("default", ("default", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup))])
                                            self._leafs = OrderedDict([
                                                ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                                ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                            ])
                                            self.advertise_best_external = None
                                            self.dmzlink_bw = None
                                            self.redistribute_internal = None
                                            self.scan_time = None
                                            self.soft_reconfig_backup = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.aggregate_timer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer()
                                            self.aggregate_timer.parent = self
                                            self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                            self.bestpath = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath()
                                            self.bestpath.parent = self
                                            self._children_name_map["bestpath"] = "bestpath"

                                            self.dampening = None
                                            self._children_name_map["dampening"] = "dampening"

                                            self.default = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.nexthop = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.recursion = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion()
                                            self.recursion.parent = self
                                            self._children_name_map["recursion"] = "recursion"

                                            self.route_map = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap()
                                            self.route_map.parent = self
                                            self._children_name_map["route_map"] = "route-map"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup()
                                            self.update_group.parent = self
                                            self._children_name_map["update_group"] = "update-group"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Additional paths in the BGP table
                                            
                                            .. attribute:: install
                                            
                                            	Additional paths to install into RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: select
                                            
                                            	Selection criteria to pick the paths
                                            	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to neighbors
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.install = None
                                                self.receive = None

                                                self.select = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select()
                                                self.select.parent = self
                                                self._children_name_map["select"] = "select"

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                            class Select(Entity):
                                                """
                                                Selection criteria to pick the paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                    self.yang_name = "select"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"

                                                    self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.best_external = None
                                                    self._children_name_map["best_external"] = "best-external"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "select"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                            self._leafs = OrderedDict()

                                                            self.range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                        class Range(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best path
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                                self.yang_name = "range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Select backup path
                                                    
                                                    .. attribute:: best_external
                                                    
                                                    	Select best\-external path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                        ])
                                                        self.best_external = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best path
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                                class BestExternal(Entity):
                                                    """
                                                    Select best\-external path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Select backup path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                        self.yang_name = "best-external"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                        ])
                                                        self.backup = None
                                                        self._segment_path = lambda: "best-external"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to neighbors
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                        class AggregateTimer(Entity):
                                            """
                                            Configure aggregation timer
                                            
                                            .. attribute:: aggregate_timer
                                            
                                            	Timer interval
                                            	**type**\: int
                                            
                                            	**range:** 6..60
                                            
                                            .. attribute:: disable_timer
                                            
                                            	Timer interval
                                            	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer, self).__init__()

                                                self.yang_name = "aggregate-timer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                    ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                                ])
                                                self.aggregate_timer = None
                                                self.disable_timer = None
                                                self._segment_path = lambda: "aggregate-timer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                            class DisableTimer(Enum):
                                                """
                                                DisableTimer (Enum Class)

                                                Timer interval

                                                .. data:: Y_0 = 0

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")



                                        class Bestpath(Entity):
                                            """
                                            Change the default bestpath selection
                                            
                                            .. attribute:: igp_metric
                                            
                                            	igp metric
                                            	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric>`
                                            
                                            .. attribute:: prefix_validate
                                            
                                            	Prefix origin validation
                                            	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath, self).__init__()

                                                self.yang_name = "bestpath"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate))])
                                                self._leafs = OrderedDict()

                                                self.igp_metric = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric()
                                                self.igp_metric.parent = self
                                                self._children_name_map["igp_metric"] = "igp-metric"

                                                self.prefix_validate = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate()
                                                self.prefix_validate.parent = self
                                                self._children_name_map["prefix_validate"] = "prefix-validate"
                                                self._segment_path = lambda: "bestpath"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath, [], name, value)


                                            class IgpMetric(Entity):
                                                """
                                                igp metric
                                                
                                                .. attribute:: ignore
                                                
                                                	Ignore igp metric in bestpath selection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                                    self.yang_name = "igp-metric"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ])
                                                    self.ignore = None
                                                    self._segment_path = lambda: "igp-metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                            class PrefixValidate(Entity):
                                                """
                                                Prefix origin validation
                                                
                                                .. attribute:: allow_invalid
                                                
                                                	Allow invalid routes to be considered for bestpath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: disable
                                                
                                                	Disable prefix validation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                                    self.yang_name = "prefix-validate"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.allow_invalid = None
                                                    self.disable = None
                                                    self._segment_path = lambda: "prefix-validate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                        class Dampening(Entity):
                                            """
                                            Enable route\-flap dampening
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria for dampening
                                            	**type**\: str
                                            
                                            .. attribute:: dampen
                                            
                                            	
                                            	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening, self).__init__()

                                                self.yang_name = "dampening"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.dampen = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen()
                                                self.dampen.parent = self
                                                self._children_name_map["dampen"] = "dampen"
                                                self._segment_path = lambda: "dampening"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                            class Dampen(Entity):
                                                """
                                                
                                                
                                                .. attribute:: half_life_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..45
                                                
                                                .. attribute:: reuse_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: max_suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                                    self.yang_name = "dampen"
                                                    self.yang_parent_name = "dampening"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                        ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                        ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                        ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                    ])
                                                    self.half_life_time = None
                                                    self.reuse_time = None
                                                    self.suppress_time = None
                                                    self.max_suppress_time = None
                                                    self._segment_path = lambda: "dampen"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                        class Default(Entity):
                                            """
                                            Configure BGP defaults
                                            
                                            .. attribute:: route_target
                                            
                                            	Control behavior based on Route\-Target attributes
                                            	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default.RouteTarget>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default.RouteTarget')])),
                                                ])
                                                self.route_target = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Default, ['route_target'], name, value)

                                            class RouteTarget(Enum):
                                                """
                                                RouteTarget (Enum Class)

                                                Control behavior based on Route\-Target attributes

                                                .. data:: filter = 0

                                                """

                                                filter = Enum.YLeaf(0, "filter")



                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class Recursion(Entity):
                                            """
                                            recursion rule for the nexthops
                                            
                                            .. attribute:: host
                                            
                                            	recursion via host for the nexthops
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion, self).__init__()

                                                self.yang_name = "recursion"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                                ])
                                                self.host = None
                                                self._segment_path = lambda: "recursion"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.Recursion, ['host'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            bgp route\-map commands
                                            
                                            .. attribute:: priority
                                            
                                            	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class UpdateGroup(Entity):
                                            """
                                            Manage peers in bgp update groups
                                            
                                            .. attribute:: split
                                            
                                            	Split update groups based on Policy
                                            	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup, self).__init__()

                                                self.yang_name = "update-group"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split))])
                                                self._leafs = OrderedDict()

                                                self.split = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split()
                                                self.split.parent = self
                                                self._children_name_map["split"] = "split"
                                                self._segment_path = lambda: "update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup, [], name, value)


                                            class Split(Entity):
                                                """
                                                Split update groups based on Policy
                                                
                                                .. attribute:: as_override
                                                
                                                	Keep peers with as\-override in different update groups
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                                    self.yang_name = "split"
                                                    self.yang_parent_name = "update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                    ])
                                                    self.as_override = None
                                                    self._segment_path = lambda: "split"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: advertise
                                            
                                            	Advertise to this neighbor
                                            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: distribute_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList>`
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: send_label
                                            
                                            	Send NLRI + MPLS Label to this peer
                                            	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.advertise = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise()
                                                self.advertise.parent = self
                                                self._children_name_map["advertise"] = "advertise"

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.send_label = None
                                                self._children_name_map["send_label"] = "send-label"

                                                self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.distribute_list = YList(self)
                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class Advertise(Entity):
                                                """
                                                Advertise to this neighbor
                                                
                                                .. attribute:: additional_paths
                                                
                                                	Advertise additional paths
                                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Advertise best\-external (at RRs best\-internal) path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: diverse_path
                                                
                                                	Advertise diverse path
                                                	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                                    self.yang_name = "advertise"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None

                                                    self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                                    self.additional_paths.parent = self
                                                    self._children_name_map["additional_paths"] = "additional-paths"

                                                    self.diverse_path = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                                    self.diverse_path.parent = self
                                                    self._children_name_map["diverse_path"] = "diverse-path"
                                                    self._segment_path = lambda: "advertise"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                                class AdditionalPaths(Entity):
                                                    """
                                                    Advertise additional paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                        self.yang_name = "additional-paths"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                        self._leafs = OrderedDict()

                                                        self.all = None
                                                        self._children_name_map["all"] = "all"

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "additional-paths"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                    class All(Entity):
                                                        """
                                                        Select all available paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Select best N paths
                                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                            self.yang_name = "all"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict()

                                                            self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                            self.best.parent = self
                                                            self._children_name_map["best"] = "best"

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "all"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                        class Best(Entity):
                                                            """
                                                            Select best N paths
                                                            
                                                            .. attribute:: best_range
                                                            
                                                            	
                                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                                self.yang_name = "best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                                self._leafs = OrderedDict()

                                                                self.best_range = YList(self)
                                                                self._segment_path = lambda: "best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                            class BestRange(Entity):
                                                                """
                                                                
                                                                
                                                                .. attribute:: range  (key)
                                                                
                                                                	Number of best paths in additional paths to be selected
                                                                	**type**\: int
                                                                
                                                                	**range:** 2..3
                                                                
                                                                .. attribute:: group_best
                                                                
                                                                	Select group\-best paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                    self.yang_name = "best-range"
                                                                    self.yang_parent_name = "best"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['range']
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                    ])
                                                                    self.range = None
                                                                    self.group_best = None
                                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: best
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                                ])
                                                                self.best = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.all = None

                                                                self.group_best = None
                                                                self._children_name_map["group_best"] = "group-best"
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                            class GroupBest(Entity):
                                                                """
                                                                Select group\-best paths
                                                                
                                                                .. attribute:: all
                                                                
                                                                	Select all available paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                    self.yang_name = "group-best"
                                                                    self.yang_parent_name = "best-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                    ])
                                                                    self.all = None
                                                                    self._segment_path = lambda: "group-best"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.all = None
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                                class DiversePath(Entity):
                                                    """
                                                    Advertise diverse path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Diverse path can be backup path
                                                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                        self.yang_name = "diverse-path"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None

                                                        self.backup = None
                                                        self._children_name_map["backup"] = "backup"
                                                        self._segment_path = lambda: "diverse-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                    class Backup(Entity):
                                                        """
                                                        Diverse path can be backup path
                                                        
                                                        .. attribute:: mpath
                                                        
                                                        	Diverse path can be multipath
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                            self.yang_name = "backup"
                                                            self.yang_parent_name = "diverse-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                            ])
                                                            self.mpath = None
                                                            self._segment_path = lambda: "backup"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class DistributeList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                                
                                                .. attribute:: accesslist
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..199
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1300..2699
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** [a\-zA\-Z].\*
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                                    self.yang_name = "distribute-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                        ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                    ])
                                                    self.inout = None
                                                    self.accesslist = None
                                                    self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SendLabel(Entity):
                                                """
                                                Send NLRI + MPLS Label to this peer
                                                
                                                .. attribute:: send_label_explicit
                                                
                                                	
                                                	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel, self).__init__()

                                                    self.yang_name = "send-label"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel.SendLabelExplicit')])),
                                                    ])
                                                    self.send_label_explicit = None
                                                    self._segment_path = lambda: "send-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                                class SendLabelExplicit(Enum):
                                                    """
                                                    SendLabelExplicit (Enum Class)

                                                    .. data:: explicit_null = 0

                                                    """

                                                    explicit_null = Enum.YLeaf(0, "explicit-null")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise
                                        
                                        	Advertise to this neighbor
                                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability>`
                                        
                                        .. attribute:: distribute_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: send_label
                                        
                                        	Send NLRI + MPLS Label to this peer
                                        	**type**\:  :py:class:`SendLabel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity)), ("send-label", ("send_label", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.advertise = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise()
                                            self.advertise.parent = self
                                            self._children_name_map["advertise"] = "advertise"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.send_label = None
                                            self._children_name_map["send_label"] = "send-label"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.distribute_list = YList(self)
                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class Advertise(Entity):
                                            """
                                            Advertise to this neighbor
                                            
                                            .. attribute:: additional_paths
                                            
                                            	Advertise additional paths
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Advertise best\-external (at RRs best\-internal) path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: diverse_path
                                            
                                            	Advertise diverse path
                                            	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise, self).__init__()

                                                self.yang_name = "advertise"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath))])
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.diverse_path = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath()
                                                self.diverse_path.parent = self
                                                self._children_name_map["diverse_path"] = "diverse-path"
                                                self._segment_path = lambda: "advertise"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                            class AdditionalPaths(Entity):
                                                """
                                                Advertise additional paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "best-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                            class DiversePath(Entity):
                                                """
                                                Advertise diverse path
                                                
                                                .. attribute:: backup
                                                
                                                	Diverse path can be backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                                    self.yang_name = "diverse-path"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"
                                                    self._segment_path = lambda: "diverse-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Diverse path can be backup path
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "diverse-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DistributeList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList.Inout>`
                                            
                                            .. attribute:: accesslist
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..199
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..2699
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList, self).__init__()

                                                self.yang_name = "distribute-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList.Inout')])),
                                                    ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                ])
                                                self.inout = None
                                                self.accesslist = None
                                                self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SendLabel(Entity):
                                            """
                                            Send NLRI + MPLS Label to this peer
                                            
                                            .. attribute:: send_label_explicit
                                            
                                            	
                                            	**type**\:  :py:class:`SendLabelExplicit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel.SendLabelExplicit>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel, self).__init__()

                                                self.yang_name = "send-label"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_label_explicit', (YLeaf(YType.enumeration, 'send-label-explicit'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel.SendLabelExplicit')])),
                                                ])
                                                self.send_label_explicit = None
                                                self._segment_path = lambda: "send-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SendLabel, ['send_label_explicit'], name, value)

                                            class SendLabelExplicit(Enum):
                                                """
                                                SendLabelExplicit (Enum Class)

                                                .. data:: explicit_null = 0

                                                """

                                                explicit_null = Enum.YLeaf(0, "explicit-null")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Network(Entity):
                                        """
                                        
                                        
                                        .. attribute:: with_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask>`
                                        
                                        .. attribute:: no_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask))])
                                            self._leafs = OrderedDict()

                                            self.with_mask = YList(self)
                                            self.no_mask = YList(self)
                                            self._segment_path = lambda: "network"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network, [], name, value)


                                        class WithMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mask  (key)
                                            
                                            	Network mask
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask, self).__init__()

                                                self.yang_name = "with-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number','mask']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.mask = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor'], name, value)


                                        class NoMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask, self).__init__()

                                                self.yang_name = "no-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Network.NoMask, ['number', 'route_map', 'backdoor'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "vpnv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv4.Vpnv4Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class Vpnv6(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.AfName>`
                                
                                .. attribute:: vpnv6_unicast
                                
                                	VPNv6 Unicast address family
                                	**type**\:  :py:class:`Vpnv6Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6, self).__init__()

                                    self.yang_name = "vpnv6"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("vpnv6-unicast", ("vpnv6_unicast", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.AfName')])),
                                    ])
                                    self.af_name = None

                                    self.vpnv6_unicast = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast()
                                    self.vpnv6_unicast.parent = self
                                    self._children_name_map["vpnv6_unicast"] = "vpnv6-unicast"
                                    self._segment_path = lambda: "vpnv6" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6, ['af_name'], name, value)

                                class AfName(Enum):
                                    """
                                    AfName (Enum Class)

                                    .. data:: unicast = 0

                                    .. data:: multicast = 1

                                    .. data:: flowspec = 2

                                    """

                                    unicast = Enum.YLeaf(0, "unicast")

                                    multicast = Enum.YLeaf(1, "multicast")

                                    flowspec = Enum.YLeaf(2, "flowspec")



                                class Vpnv6Unicast(Entity):
                                    """
                                    VPNv6 Unicast address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast, self).__init__()

                                        self.yang_name = "vpnv6-unicast"
                                        self.yang_parent_name = "vpnv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.peer_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "vpnv6-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Additional paths in the BGP table
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths>`
                                        
                                        .. attribute:: advertise_best_external
                                        
                                        	Advertise best external path to internal peers
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Configure aggregation timer
                                        	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer>`
                                        
                                        .. attribute:: bestpath
                                        
                                        	Change the default bestpath selection
                                        	**type**\:  :py:class:`Bestpath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath>`
                                        
                                        .. attribute:: dampening
                                        
                                        	Enable route\-flap dampening
                                        	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: default
                                        
                                        	Configure BGP defaults
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Use DMZ Link Bandwidth as weight for BGP multipaths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop>`
                                        
                                        .. attribute:: recursion
                                        
                                        	recursion rule for the nexthops
                                        	**type**\:  :py:class:`Recursion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion>`
                                        
                                        .. attribute:: redistribute_internal
                                        
                                        	Allow redistribution of iBGP into IGPs (dangerous)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	bgp route\-map commands
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfig_backup
                                        
                                        	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: update_group
                                        
                                        	Manage peers in bgp update groups
                                        	**type**\:  :py:class:`UpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "vpnv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths)), ("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer)), ("bestpath", ("bestpath", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath)), ("dampening", ("dampening", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening)), ("default", ("default", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop)), ("recursion", ("recursion", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer)), ("update-group", ("update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup))])
                                            self._leafs = OrderedDict([
                                                ('advertise_best_external', (YLeaf(YType.empty, 'advertise-best-external'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                                ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                            ])
                                            self.advertise_best_external = None
                                            self.dmzlink_bw = None
                                            self.redistribute_internal = None
                                            self.scan_time = None
                                            self.soft_reconfig_backup = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.aggregate_timer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer()
                                            self.aggregate_timer.parent = self
                                            self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                            self.bestpath = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath()
                                            self.bestpath.parent = self
                                            self._children_name_map["bestpath"] = "bestpath"

                                            self.dampening = None
                                            self._children_name_map["dampening"] = "dampening"

                                            self.default = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.nexthop = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.recursion = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion()
                                            self.recursion.parent = self
                                            self._children_name_map["recursion"] = "recursion"

                                            self.route_map = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap()
                                            self.route_map.parent = self
                                            self._children_name_map["route_map"] = "route-map"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup()
                                            self.update_group.parent = self
                                            self._children_name_map["update_group"] = "update-group"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_, ['advertise_best_external', 'dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Additional paths in the BGP table
                                            
                                            .. attribute:: install
                                            
                                            	Additional paths to install into RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: select
                                            
                                            	Selection criteria to pick the paths
                                            	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to neighbors
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.install = None
                                                self.receive = None

                                                self.select = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select()
                                                self.select.parent = self
                                                self._children_name_map["select"] = "select"

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                            class Select(Entity):
                                                """
                                                Selection criteria to pick the paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select, self).__init__()

                                                    self.yang_name = "select"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"

                                                    self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.best_external = None
                                                    self._children_name_map["best_external"] = "best-external"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "select"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                            self._leafs = OrderedDict()

                                                            self.range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                        class Range(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best path
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                                self.yang_name = "range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Select backup path
                                                    
                                                    .. attribute:: best_external
                                                    
                                                    	Select best\-external path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                        ])
                                                        self.best_external = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best path
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                                class BestExternal(Entity):
                                                    """
                                                    Select best\-external path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Select backup path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                        self.yang_name = "best-external"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                        ])
                                                        self.backup = None
                                                        self._segment_path = lambda: "best-external"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to neighbors
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                        class AggregateTimer(Entity):
                                            """
                                            Configure aggregation timer
                                            
                                            .. attribute:: aggregate_timer
                                            
                                            	Timer interval
                                            	**type**\: int
                                            
                                            	**range:** 6..60
                                            
                                            .. attribute:: disable_timer
                                            
                                            	Timer interval
                                            	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer.DisableTimer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer, self).__init__()

                                                self.yang_name = "aggregate-timer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                    ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer.DisableTimer')])),
                                                ])
                                                self.aggregate_timer = None
                                                self.disable_timer = None
                                                self._segment_path = lambda: "aggregate-timer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                            class DisableTimer(Enum):
                                                """
                                                DisableTimer (Enum Class)

                                                Timer interval

                                                .. data:: Y_0 = 0

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")



                                        class Bestpath(Entity):
                                            """
                                            Change the default bestpath selection
                                            
                                            .. attribute:: igp_metric
                                            
                                            	igp metric
                                            	**type**\:  :py:class:`IgpMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric>`
                                            
                                            .. attribute:: prefix_validate
                                            
                                            	Prefix origin validation
                                            	**type**\:  :py:class:`PrefixValidate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath, self).__init__()

                                                self.yang_name = "bestpath"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("igp-metric", ("igp_metric", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric)), ("prefix-validate", ("prefix_validate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate))])
                                                self._leafs = OrderedDict()

                                                self.igp_metric = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric()
                                                self.igp_metric.parent = self
                                                self._children_name_map["igp_metric"] = "igp-metric"

                                                self.prefix_validate = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate()
                                                self.prefix_validate.parent = self
                                                self._children_name_map["prefix_validate"] = "prefix-validate"
                                                self._segment_path = lambda: "bestpath"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath, [], name, value)


                                            class IgpMetric(Entity):
                                                """
                                                igp metric
                                                
                                                .. attribute:: ignore
                                                
                                                	Ignore igp metric in bestpath selection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric, self).__init__()

                                                    self.yang_name = "igp-metric"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                                                    ])
                                                    self.ignore = None
                                                    self._segment_path = lambda: "igp-metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.IgpMetric, ['ignore'], name, value)


                                            class PrefixValidate(Entity):
                                                """
                                                Prefix origin validation
                                                
                                                .. attribute:: allow_invalid
                                                
                                                	Allow invalid routes to be considered for bestpath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: disable
                                                
                                                	Disable prefix validation
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate, self).__init__()

                                                    self.yang_name = "prefix-validate"
                                                    self.yang_parent_name = "bestpath"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_invalid', (YLeaf(YType.empty, 'allow-invalid'), ['Empty'])),
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ])
                                                    self.allow_invalid = None
                                                    self.disable = None
                                                    self._segment_path = lambda: "prefix-validate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Bestpath.PrefixValidate, ['allow_invalid', 'disable'], name, value)


                                        class Dampening(Entity):
                                            """
                                            Enable route\-flap dampening
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria for dampening
                                            	**type**\: str
                                            
                                            .. attribute:: dampen
                                            
                                            	
                                            	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening, self).__init__()

                                                self.yang_name = "dampening"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.dampen = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen()
                                                self.dampen.parent = self
                                                self._children_name_map["dampen"] = "dampen"
                                                self._segment_path = lambda: "dampening"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening, ['route_map'], name, value)


                                            class Dampen(Entity):
                                                """
                                                
                                                
                                                .. attribute:: half_life_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..45
                                                
                                                .. attribute:: reuse_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: max_suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen, self).__init__()

                                                    self.yang_name = "dampen"
                                                    self.yang_parent_name = "dampening"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                        ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                        ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                        ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                    ])
                                                    self.half_life_time = None
                                                    self.reuse_time = None
                                                    self.suppress_time = None
                                                    self.max_suppress_time = None
                                                    self._segment_path = lambda: "dampen"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                        class Default(Entity):
                                            """
                                            Configure BGP defaults
                                            
                                            .. attribute:: route_target
                                            
                                            	Control behavior based on Route\-Target attributes
                                            	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default.RouteTarget>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default.RouteTarget')])),
                                                ])
                                                self.route_target = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Default, ['route_target'], name, value)

                                            class RouteTarget(Enum):
                                                """
                                                RouteTarget (Enum Class)

                                                Control behavior based on Route\-Target attributes

                                                .. data:: filter = 0

                                                """

                                                filter = Enum.YLeaf(0, "filter")



                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class Recursion(Entity):
                                            """
                                            recursion rule for the nexthops
                                            
                                            .. attribute:: host
                                            
                                            	recursion via host for the nexthops
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion, self).__init__()

                                                self.yang_name = "recursion"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('host', (YLeaf(YType.empty, 'host'), ['Empty'])),
                                                ])
                                                self.host = None
                                                self._segment_path = lambda: "recursion"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.Recursion, ['host'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            bgp route\-map commands
                                            
                                            .. attribute:: priority
                                            
                                            	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.RouteMap, ['priority'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                        class UpdateGroup(Entity):
                                            """
                                            Manage peers in bgp update groups
                                            
                                            .. attribute:: split
                                            
                                            	Split update groups based on Policy
                                            	**type**\:  :py:class:`Split <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup, self).__init__()

                                                self.yang_name = "update-group"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("split", ("split", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split))])
                                                self._leafs = OrderedDict()

                                                self.split = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split()
                                                self.split.parent = self
                                                self._children_name_map["split"] = "split"
                                                self._segment_path = lambda: "update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup, [], name, value)


                                            class Split(Entity):
                                                """
                                                Split update groups based on Policy
                                                
                                                .. attribute:: as_override
                                                
                                                	Keep peers with as\-override in different update groups
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split, self).__init__()

                                                    self.yang_name = "split"
                                                    self.yang_parent_name = "update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('as_override', (YLeaf(YType.empty, 'as-override'), ['Empty'])),
                                                    ])
                                                    self.as_override = None
                                                    self._segment_path = lambda: "split"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Bgp_.UpdateGroup.Split, ['as_override'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "vpnv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: advertise
                                            
                                            	Advertise to this neighbor
                                            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: distribute_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList>`
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.advertise = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise()
                                                self.advertise.parent = self
                                                self._children_name_map["advertise"] = "advertise"

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.distribute_list = YList(self)
                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class Advertise(Entity):
                                                """
                                                Advertise to this neighbor
                                                
                                                .. attribute:: additional_paths
                                                
                                                	Advertise additional paths
                                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Advertise best\-external (at RRs best\-internal) path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: diverse_path
                                                
                                                	Advertise diverse path
                                                	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise, self).__init__()

                                                    self.yang_name = "advertise"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath))])
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None

                                                    self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                                    self.additional_paths.parent = self
                                                    self._children_name_map["additional_paths"] = "additional-paths"

                                                    self.diverse_path = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath()
                                                    self.diverse_path.parent = self
                                                    self._children_name_map["diverse_path"] = "diverse-path"
                                                    self._segment_path = lambda: "advertise"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                                class AdditionalPaths(Entity):
                                                    """
                                                    Advertise additional paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                        self.yang_name = "additional-paths"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                        self._leafs = OrderedDict()

                                                        self.all = None
                                                        self._children_name_map["all"] = "all"

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "additional-paths"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                    class All(Entity):
                                                        """
                                                        Select all available paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Select best N paths
                                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                            self.yang_name = "all"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict()

                                                            self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                            self.best.parent = self
                                                            self._children_name_map["best"] = "best"

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "all"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                        class Best(Entity):
                                                            """
                                                            Select best N paths
                                                            
                                                            .. attribute:: best_range
                                                            
                                                            	
                                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                                self.yang_name = "best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                                self._leafs = OrderedDict()

                                                                self.best_range = YList(self)
                                                                self._segment_path = lambda: "best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                            class BestRange(Entity):
                                                                """
                                                                
                                                                
                                                                .. attribute:: range  (key)
                                                                
                                                                	Number of best paths in additional paths to be selected
                                                                	**type**\: int
                                                                
                                                                	**range:** 2..3
                                                                
                                                                .. attribute:: group_best
                                                                
                                                                	Select group\-best paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                    self.yang_name = "best-range"
                                                                    self.yang_parent_name = "best"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['range']
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                    ])
                                                                    self.range = None
                                                                    self.group_best = None
                                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: best
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                                ])
                                                                self.best = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.all = None

                                                                self.group_best = None
                                                                self._children_name_map["group_best"] = "group-best"
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                            class GroupBest(Entity):
                                                                """
                                                                Select group\-best paths
                                                                
                                                                .. attribute:: all
                                                                
                                                                	Select all available paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                    self.yang_name = "group-best"
                                                                    self.yang_parent_name = "best-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                    ])
                                                                    self.all = None
                                                                    self._segment_path = lambda: "group-best"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.all = None
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                                class DiversePath(Entity):
                                                    """
                                                    Advertise diverse path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Diverse path can be backup path
                                                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                        self.yang_name = "diverse-path"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None

                                                        self.backup = None
                                                        self._children_name_map["backup"] = "backup"
                                                        self._segment_path = lambda: "diverse-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                    class Backup(Entity):
                                                        """
                                                        Diverse path can be backup path
                                                        
                                                        .. attribute:: mpath
                                                        
                                                        	Diverse path can be multipath
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                            self.yang_name = "backup"
                                                            self.yang_parent_name = "diverse-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                            ])
                                                            self.mpath = None
                                                            self._segment_path = lambda: "backup"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class DistributeList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList.Inout>`
                                                
                                                .. attribute:: accesslist
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..199
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1300..2699
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** [a\-zA\-Z].\*
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList, self).__init__()

                                                    self.yang_name = "distribute-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                        ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                    ])
                                                    self.inout = None
                                                    self.accesslist = None
                                                    self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise
                                        
                                        	Advertise to this neighbor
                                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: distribute_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "vpnv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("advertise", ("advertise", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.advertise = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise()
                                            self.advertise.parent = self
                                            self._children_name_map["advertise"] = "advertise"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.distribute_list = YList(self)
                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class Advertise(Entity):
                                            """
                                            Advertise to this neighbor
                                            
                                            .. attribute:: additional_paths
                                            
                                            	Advertise additional paths
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Advertise best\-external (at RRs best\-internal) path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: diverse_path
                                            
                                            	Advertise diverse path
                                            	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise, self).__init__()

                                                self.yang_name = "advertise"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath))])
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.diverse_path = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath()
                                                self.diverse_path.parent = self
                                                self._children_name_map["diverse_path"] = "diverse-path"
                                                self._segment_path = lambda: "advertise"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise, ['best_external'], name, value)


                                            class AdditionalPaths(Entity):
                                                """
                                                Advertise additional paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "best-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                            class DiversePath(Entity):
                                                """
                                                Advertise diverse path
                                                
                                                .. attribute:: backup
                                                
                                                	Diverse path can be backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath, self).__init__()

                                                    self.yang_name = "diverse-path"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup))])
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"
                                                    self._segment_path = lambda: "diverse-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Diverse path can be backup path
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "diverse-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class DistributeList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList.Inout>`
                                            
                                            .. attribute:: accesslist
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..199
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..2699
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList, self).__init__()

                                                self.yang_name = "distribute-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList.Inout')])),
                                                    ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                ])
                                                self.inout = None
                                                self.accesslist = None
                                                self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "vpnv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Vpnv6.Vpnv6Unicast.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class Nsap(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.AfName>`
                                
                                .. attribute:: nsap
                                
                                	NSAP address family
                                	**type**\:  :py:class:`Nsap_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap, self).__init__()

                                    self.yang_name = "nsap"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("nsap", ("nsap", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.AfName')])),
                                    ])
                                    self.af_name = None

                                    self.nsap = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_()
                                    self.nsap.parent = self
                                    self._children_name_map["nsap"] = "nsap"
                                    self._segment_path = lambda: "nsap" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap, ['af_name'], name, value)

                                class AfName(Enum):
                                    """
                                    AfName (Enum Class)

                                    .. data:: unicast = 0

                                    """

                                    unicast = Enum.YLeaf(0, "unicast")



                                class Nsap_(Entity):
                                    """
                                    NSAP address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_>`
                                    
                                    .. attribute:: default_information
                                    
                                    	Control distribution of default information
                                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation>`
                                    
                                    .. attribute:: default_metric
                                    
                                    	Set metric of redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor>`
                                    
                                    .. attribute:: network
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Network>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_, self).__init__()

                                        self.yang_name = "nsap"
                                        self.yang_parent_name = "nsap"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor)), ("network", ("network", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Network)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp))])
                                        self._leafs = OrderedDict([
                                            ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                        ])
                                        self.default_metric = None

                                        self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.default_information = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation()
                                        self.default_information.parent = self
                                        self._children_name_map["default_information"] = "default-information"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self.network = YList(self)
                                        self._segment_path = lambda: "nsap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_, ['default_metric'], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: aggregate_timer
                                        
                                        	Configure aggregation timer
                                        	**type**\:  :py:class:`AggregateTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer>`
                                        
                                        .. attribute:: dampening
                                        
                                        	Enable route\-flap dampening
                                        	**type**\:  :py:class:`Dampening <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Use DMZ Link Bandwidth as weight for BGP multipaths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop>`
                                        
                                        .. attribute:: redistribute_internal
                                        
                                        	Allow redistribution of iBGP into IGPs (dangerous)
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: route_map
                                        
                                        	bgp route\-map commands
                                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfig_backup
                                        
                                        	Use soft\-reconfiguration inbound only when route\-refresh is not negotiated
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("aggregate-timer", ("aggregate_timer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer)), ("dampening", ("dampening", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('redistribute_internal', (YLeaf(YType.empty, 'redistribute-internal'), ['Empty'])),
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                                ('soft_reconfig_backup', (YLeaf(YType.empty, 'soft-reconfig-backup'), ['Empty'])),
                                            ])
                                            self.dmzlink_bw = None
                                            self.redistribute_internal = None
                                            self.scan_time = None
                                            self.soft_reconfig_backup = None

                                            self.aggregate_timer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer()
                                            self.aggregate_timer.parent = self
                                            self._children_name_map["aggregate_timer"] = "aggregate-timer"

                                            self.dampening = None
                                            self._children_name_map["dampening"] = "dampening"

                                            self.nexthop = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.route_map = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap()
                                            self.route_map.parent = self
                                            self._children_name_map["route_map"] = "route-map"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_, ['dmzlink_bw', 'redistribute_internal', 'scan_time', 'soft_reconfig_backup'], name, value)


                                        class AggregateTimer(Entity):
                                            """
                                            Configure aggregation timer
                                            
                                            .. attribute:: aggregate_timer
                                            
                                            	Timer interval
                                            	**type**\: int
                                            
                                            	**range:** 6..60
                                            
                                            .. attribute:: disable_timer
                                            
                                            	Timer interval
                                            	**type**\:  :py:class:`DisableTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer.DisableTimer>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer, self).__init__()

                                                self.yang_name = "aggregate-timer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('aggregate_timer', (YLeaf(YType.uint8, 'aggregate-timer'), ['int'])),
                                                    ('disable_timer', (YLeaf(YType.enumeration, 'disable-timer'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer.DisableTimer')])),
                                                ])
                                                self.aggregate_timer = None
                                                self.disable_timer = None
                                                self._segment_path = lambda: "aggregate-timer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.AggregateTimer, ['aggregate_timer', 'disable_timer'], name, value)

                                            class DisableTimer(Enum):
                                                """
                                                DisableTimer (Enum Class)

                                                Timer interval

                                                .. data:: Y_0 = 0

                                                """

                                                Y_0 = Enum.YLeaf(0, "0")



                                        class Dampening(Entity):
                                            """
                                            Enable route\-flap dampening
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria for dampening
                                            	**type**\: str
                                            
                                            .. attribute:: dampen
                                            
                                            	
                                            	**type**\:  :py:class:`Dampen <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening, self).__init__()

                                                self.yang_name = "dampening"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dampen", ("dampen", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.dampen = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen()
                                                self.dampen.parent = self
                                                self._children_name_map["dampen"] = "dampen"
                                                self._segment_path = lambda: "dampening"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening, ['route_map'], name, value)


                                            class Dampen(Entity):
                                                """
                                                
                                                
                                                .. attribute:: half_life_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..45
                                                
                                                .. attribute:: reuse_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..20000
                                                
                                                .. attribute:: max_suppress_time
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..255
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen, self).__init__()

                                                    self.yang_name = "dampen"
                                                    self.yang_parent_name = "dampening"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('half_life_time', (YLeaf(YType.uint8, 'half-life-time'), ['int'])),
                                                        ('reuse_time', (YLeaf(YType.uint16, 'reuse-time'), ['int'])),
                                                        ('suppress_time', (YLeaf(YType.uint16, 'suppress-time'), ['int'])),
                                                        ('max_suppress_time', (YLeaf(YType.uint8, 'max-suppress-time'), ['int'])),
                                                    ])
                                                    self.half_life_time = None
                                                    self.reuse_time = None
                                                    self.suppress_time = None
                                                    self.max_suppress_time = None
                                                    self._segment_path = lambda: "dampen"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Dampening.Dampen, ['half_life_time', 'reuse_time', 'suppress_time', 'max_suppress_time'], name, value)


                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            bgp route\-map commands
                                            
                                            .. attribute:: priority
                                            
                                            	Have route\-map set commands take priority over BGP commands such as next\-hop\-unchanged
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('priority', (YLeaf(YType.empty, 'priority'), ['Empty'])),
                                                ])
                                                self.priority = None
                                                self._segment_path = lambda: "route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.RouteMap, ['priority'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class DefaultInformation(Entity):
                                        """
                                        Control distribution of default information
                                        
                                        .. attribute:: originate
                                        
                                        	Distribute a default route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation, self).__init__()

                                            self.yang_name = "default-information"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                            ])
                                            self.originate = None
                                            self._segment_path = lambda: "default-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.DefaultInformation, ['originate'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: default_originate
                                            
                                            	Originate default route to this neighbor
                                            	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soo = None
                                                self.weight = None

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.default_originate = None
                                                self._children_name_map["default_originate"] = "default-originate"

                                                self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soo', 'weight'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class DefaultOriginate(Entity):
                                                """
                                                Originate default route to this neighbor
                                                
                                                .. attribute:: route_map
                                                
                                                	Route\-map to specify criteria to originate default
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                    self.yang_name = "default-originate"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default-originate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability>`
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soo = None
                                            self.weight = None

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soo', 'weight'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Network(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: number  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_map
                                        
                                        	Route\-map to modify the attributes
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['number']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.number = None
                                            self.route_map = None
                                            self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Network, ['number', 'route_map'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "nsap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Nsap.Nsap_.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class L2vpn(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.AfName>`
                                
                                .. attribute:: l2vpn_evpn
                                
                                	L2VPN EVPN address family
                                	**type**\:  :py:class:`L2vpnEvpn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn>`
                                
                                .. attribute:: l2vpn_vpls
                                
                                	L2VPN VPLS address family
                                	**type**\:  :py:class:`L2vpnVpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn, self).__init__()

                                    self.yang_name = "l2vpn"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("l2vpn-evpn", ("l2vpn_evpn", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn)), ("l2vpn-vpls", ("l2vpn_vpls", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.AfName')])),
                                    ])
                                    self.af_name = None

                                    self.l2vpn_evpn = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn()
                                    self.l2vpn_evpn.parent = self
                                    self._children_name_map["l2vpn_evpn"] = "l2vpn-evpn"

                                    self.l2vpn_vpls = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls()
                                    self.l2vpn_vpls.parent = self
                                    self._children_name_map["l2vpn_vpls"] = "l2vpn-vpls"
                                    self._segment_path = lambda: "l2vpn" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn, ['af_name'], name, value)

                                class AfName(Enum):
                                    """
                                    AfName (Enum Class)

                                    .. data:: evpn = 0

                                    .. data:: vpls = 1

                                    """

                                    evpn = Enum.YLeaf(0, "evpn")

                                    vpls = Enum.YLeaf(1, "vpls")



                                class L2vpnEvpn(Entity):
                                    """
                                    L2VPN EVPN address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_>`
                                    
                                    .. attribute:: default_information
                                    
                                    	Control distribution of default information
                                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation>`
                                    
                                    .. attribute:: default_metric
                                    
                                    	Set metric of redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor>`
                                    
                                    .. attribute:: activate
                                    
                                    	Enable the address family for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: advertisement_interval
                                    
                                    	Minimum interval between sending BGP routing updates
                                    	**type**\: int
                                    
                                    	**range:** 0..600
                                    
                                    .. attribute:: allow_policy
                                    
                                    	Enable the policy support for this IBGP Neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: allowas_in
                                    
                                    	Accept as\-path with my AS present in it
                                    	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: capability
                                    
                                    	Advertise capability to the peer
                                    	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability>`
                                    
                                    .. attribute:: inherit
                                    
                                    	Inherit a template
                                    	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit>`
                                    
                                    .. attribute:: maximum_prefix
                                    
                                    	Maximum number of prefixes accepted from this peer
                                    	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix>`
                                    
                                    .. attribute:: next_hop_self
                                    
                                    	Disable the next hop calculation for this neighbor
                                    	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	Propagate the iBGP paths' next hop unchanged for this neighbor
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: remove_private_as
                                    
                                    	Remove private AS number from outbound updates
                                    	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: route_map
                                    
                                    	Apply route map to neighbor
                                    	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap>`
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure a neighbor as Route Reflector client
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: send_community
                                    
                                    	Send Community attribute to this neighbor
                                    	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: slow_peer
                                    
                                    	Configure slow\-peer
                                    	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer>`
                                    
                                    .. attribute:: soft_reconfiguration
                                    
                                    	Per neighbor soft reconfiguration
                                    	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SoftReconfiguration>`
                                    
                                    .. attribute:: soo
                                    
                                    	ASN\:nn or IP\-address\:nn VPN extended community
                                    	**type**\: str
                                    
                                    .. attribute:: unsuppress_map
                                    
                                    	Route\-map to selectively unsuppress suppressed routes
                                    	**type**\: str
                                    
                                    .. attribute:: weight
                                    
                                    	Set default weight for routes from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: network
                                    
                                    	
                                    	**type**\:  :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn, self).__init__()

                                        self.yang_name = "l2vpn-evpn"
                                        self.yang_parent_name = "l2vpn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer)), ("network", ("network", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp))])
                                        self._leafs = OrderedDict([
                                            ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                            ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                            ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                            ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                            ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                            ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                            ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SoftReconfiguration')])),
                                            ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                            ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                            ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                        ])
                                        self.default_metric = None
                                        self.activate = None
                                        self.advertisement_interval = None
                                        self.allow_policy = None
                                        self.next_hop_unchanged = None
                                        self.route_reflector_client = None
                                        self.soft_reconfiguration = None
                                        self.soo = None
                                        self.unsuppress_map = None
                                        self.weight = None

                                        self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.default_information = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation()
                                        self.default_information.parent = self
                                        self._children_name_map["default_information"] = "default-information"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.allowas_in = None
                                        self._children_name_map["allowas_in"] = "allowas-in"

                                        self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability()
                                        self.capability.parent = self
                                        self._children_name_map["capability"] = "capability"

                                        self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit()
                                        self.inherit.parent = self
                                        self._children_name_map["inherit"] = "inherit"

                                        self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix()
                                        self.maximum_prefix.parent = self
                                        self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                        self.next_hop_self = None
                                        self._children_name_map["next_hop_self"] = "next-hop-self"

                                        self.remove_private_as = None
                                        self._children_name_map["remove_private_as"] = "remove-private-as"

                                        self.send_community = None
                                        self._children_name_map["send_community"] = "send-community"

                                        self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer()
                                        self.slow_peer.parent = self
                                        self._children_name_map["slow_peer"] = "slow-peer"

                                        self.network = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network()
                                        self.network.parent = self
                                        self._children_name_map["network"] = "network"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self.route_map = YList(self)
                                        self._segment_path = lambda: "l2vpn-evpn"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn, ['default_metric', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                    class SoftReconfiguration(Enum):
                                        """
                                        SoftReconfiguration (Enum Class)

                                        Per neighbor soft reconfiguration

                                        .. data:: inbound = 0

                                        """

                                        inbound = Enum.YLeaf(0, "inbound")



                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: additional_paths
                                        
                                        	Additional paths in the BGP table
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths>`
                                        
                                        .. attribute:: default
                                        
                                        	Configure BGP defaults
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths)), ("default", ("default", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default))])
                                            self._leafs = OrderedDict()

                                            self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.default = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_, [], name, value)


                                        class AdditionalPaths(Entity):
                                            """
                                            Additional paths in the BGP table
                                            
                                            .. attribute:: install
                                            
                                            	Additional paths to install into RIB
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: select
                                            
                                            	Selection criteria to pick the paths
                                            	**type**\:  :py:class:`Select <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to neighbors
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("select", ("select", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select)), ("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('install', (YLeaf(YType.empty, 'install'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.install = None
                                                self.receive = None

                                                self.select = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select()
                                                self.select.parent = self
                                                self._children_name_map["select"] = "select"

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths, ['install', 'receive'], name, value)


                                            class Select(Entity):
                                                """
                                                Selection criteria to pick the paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: backup
                                                
                                                	Select backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Select best\-external path
                                                	**type**\:  :py:class:`BestExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best path
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select, self).__init__()

                                                    self.yang_name = "select"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All)), ("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best)), ("best-external", ("best_external", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"

                                                    self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.best_external = None
                                                    self._children_name_map["best_external"] = "best-external"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "select"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best path
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range))])
                                                            self._leafs = OrderedDict()

                                                            self.range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best, [], name, value)


                                                        class Range(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best path
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range, self).__init__()

                                                                self.yang_name = "range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.Best.Range, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best path
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.All.GroupBest, ['best'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Select backup path
                                                    
                                                    .. attribute:: best_external
                                                    
                                                    	Select best\-external path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                        ])
                                                        self.best_external = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Backup, ['best_external'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("range", ("range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range))])
                                                        self._leafs = OrderedDict()

                                                        self.range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best, [], name, value)


                                                    class Range(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best path
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range, self).__init__()

                                                            self.yang_name = "range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best path
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.Best.Range.GroupBest, ['all'], name, value)


                                                class BestExternal(Entity):
                                                    """
                                                    Select best\-external path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Select backup path
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal, self).__init__()

                                                        self.yang_name = "best-external"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                                        ])
                                                        self.backup = None
                                                        self._segment_path = lambda: "best-external"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.BestExternal, ['backup'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best path
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "select"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Select.GroupBest, ['all', 'best'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to neighbors
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.AdditionalPaths.Send, ['receive'], name, value)


                                        class Default(Entity):
                                            """
                                            Configure BGP defaults
                                            
                                            .. attribute:: route_target
                                            
                                            	Control behavior based on Route\-Target attributes
                                            	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default.RouteTarget>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default.RouteTarget')])),
                                                ])
                                                self.route_target = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Bgp_.Default, ['route_target'], name, value)

                                            class RouteTarget(Enum):
                                                """
                                                RouteTarget (Enum Class)

                                                Control behavior based on Route\-Target attributes

                                                .. data:: filter = 0

                                                """

                                                filter = Enum.YLeaf(0, "filter")



                                    class DefaultInformation(Entity):
                                        """
                                        Control distribution of default information
                                        
                                        .. attribute:: originate
                                        
                                        	Distribute a default route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation, self).__init__()

                                            self.yang_name = "default-information"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                            ])
                                            self.originate = None
                                            self._segment_path = lambda: "default-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.DefaultInformation, ['originate'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: additional_paths
                                            
                                            	
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths>`
                                            
                                            .. attribute:: advertise
                                            
                                            	Advertise to this neighbor
                                            	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: distribute_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList>`
                                            
                                            .. attribute:: dmzlink_bw
                                            
                                            	Propagate the DMZ link bandwidth
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: encap
                                            
                                            	Preferred encapsulation for neighbor
                                            	**type**\:  :py:class:`Encap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap>`
                                            
                                            .. attribute:: filter_list
                                            
                                            	Establish BGP filters
                                            	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: peer_group
                                            
                                            	Member of the peer\-group
                                            	**type**\:  :py:class:`PeerGroup_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Filter updates to/from this neighbor
                                            	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList)), ("encap", ("encap", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.dmzlink_bw = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.advertise = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise()
                                                self.advertise.parent = self
                                                self._children_name_map["advertise"] = "advertise"

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.encap = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap()
                                                self.encap.parent = self
                                                self._children_name_map["encap"] = "encap"

                                                self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.peer_group = None
                                                self._children_name_map["peer_group"] = "peer-group"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.distribute_list = YList(self)
                                                self.filter_list = YList(self)
                                                self.prefix_list = YList(self)
                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class AdditionalPaths(Entity):
                                                """
                                                
                                                
                                                .. attribute:: disable
                                                
                                                	Disable additional paths for this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from neighbors
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: send
                                                
                                                	Send additional paths to this neighbor
                                                	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send))])
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.disable = None
                                                    self.receive = None

                                                    self.send = None
                                                    self._children_name_map["send"] = "send"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                                class Send(Entity):
                                                    """
                                                    Send additional paths to this neighbor
                                                    
                                                    .. attribute:: receive
                                                    
                                                    	Receive additional paths from this neighbor
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send, self).__init__()

                                                        self.yang_name = "send"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                        ])
                                                        self.receive = None
                                                        self._segment_path = lambda: "send"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                            class Advertise(Entity):
                                                """
                                                Advertise to this neighbor
                                                
                                                .. attribute:: additional_paths
                                                
                                                	Advertise additional paths
                                                	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths>`
                                                
                                                .. attribute:: best_external
                                                
                                                	Advertise best\-external (at RRs best\-internal) path
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: diverse_path
                                                
                                                	Advertise diverse path
                                                	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise, self).__init__()

                                                    self.yang_name = "advertise"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath))])
                                                    self._leafs = OrderedDict([
                                                        ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                    ])
                                                    self.best_external = None

                                                    self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths()
                                                    self.additional_paths.parent = self
                                                    self._children_name_map["additional_paths"] = "additional-paths"

                                                    self.diverse_path = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath()
                                                    self.diverse_path.parent = self
                                                    self._children_name_map["diverse_path"] = "diverse-path"
                                                    self._segment_path = lambda: "advertise"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise, ['best_external'], name, value)


                                                class AdditionalPaths(Entity):
                                                    """
                                                    Advertise additional paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                        self.yang_name = "additional-paths"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                        self._leafs = OrderedDict()

                                                        self.all = None
                                                        self._children_name_map["all"] = "all"

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "additional-paths"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                    class All(Entity):
                                                        """
                                                        Select all available paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Select best N paths
                                                        	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                            self.yang_name = "all"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict()

                                                            self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                            self.best.parent = self
                                                            self._children_name_map["best"] = "best"

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "all"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                        class Best(Entity):
                                                            """
                                                            Select best N paths
                                                            
                                                            .. attribute:: best_range
                                                            
                                                            	
                                                            	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                                self.yang_name = "best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                                self._leafs = OrderedDict()

                                                                self.best_range = YList(self)
                                                                self._segment_path = lambda: "best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                            class BestRange(Entity):
                                                                """
                                                                
                                                                
                                                                .. attribute:: range  (key)
                                                                
                                                                	Number of best paths in additional paths to be selected
                                                                	**type**\: int
                                                                
                                                                	**range:** 2..3
                                                                
                                                                .. attribute:: group_best
                                                                
                                                                	Select group\-best paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                    self.yang_name = "best-range"
                                                                    self.yang_parent_name = "best"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['range']
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                        ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                    ])
                                                                    self.range = None
                                                                    self.group_best = None
                                                                    self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: best
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "all"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                                ])
                                                                self.best = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                            
                                                            	**presence node**\: True
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.all = None

                                                                self.group_best = None
                                                                self._children_name_map["group_best"] = "group-best"
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                            class GroupBest(Entity):
                                                                """
                                                                Select group\-best paths
                                                                
                                                                .. attribute:: all
                                                                
                                                                	Select all available paths
                                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                                
                                                                

                                                                This class is a :ref:`presence class<presence-class>`

                                                                """

                                                                _prefix = 'ios-bgp'
                                                                _revision = '2018-06-28'

                                                                def __init__(self):
                                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                    self.yang_name = "group-best"
                                                                    self.yang_parent_name = "best-range"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self.is_presence_container = True
                                                                    self._leafs = OrderedDict([
                                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                    ])
                                                                    self.all = None
                                                                    self._segment_path = lambda: "group-best"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "additional-paths"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.all = None
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                                class DiversePath(Entity):
                                                    """
                                                    Advertise diverse path
                                                    
                                                    .. attribute:: backup
                                                    
                                                    	Diverse path can be backup path
                                                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath, self).__init__()

                                                        self.yang_name = "diverse-path"
                                                        self.yang_parent_name = "advertise"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup))])
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None

                                                        self.backup = None
                                                        self._children_name_map["backup"] = "backup"
                                                        self._segment_path = lambda: "diverse-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                    class Backup(Entity):
                                                        """
                                                        Diverse path can be backup path
                                                        
                                                        .. attribute:: mpath
                                                        
                                                        	Diverse path can be multipath
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                            self.yang_name = "backup"
                                                            self.yang_parent_name = "diverse-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                            ])
                                                            self.mpath = None
                                                            self._segment_path = lambda: "backup"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class DistributeList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList.Inout>`
                                                
                                                .. attribute:: accesslist
                                                
                                                	
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1..199
                                                
                                                		**type**\: int
                                                
                                                			**range:** 1300..2699
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** [a\-zA\-Z].\*
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList, self).__init__()

                                                    self.yang_name = "distribute-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList.Inout')])),
                                                        ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                    ])
                                                    self.inout = None
                                                    self.accesslist = None
                                                    self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Encap(Entity):
                                                """
                                                Preferred encapsulation for neighbor
                                                
                                                .. attribute:: mpls
                                                
                                                	Neighbor prefers MPLS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: vxlan
                                                
                                                	Neighbor prefers VxLAN
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap, self).__init__()

                                                    self.yang_name = "encap"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                                        ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                                    ])
                                                    self.mpls = None
                                                    self.vxlan = None
                                                    self._segment_path = lambda: "encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Encap, ['mpls', 'vxlan'], name, value)


                                            class FilterList(Entity):
                                                """
                                                Establish BGP filters
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList.Inout>`
                                                
                                                .. attribute:: as_path_list
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..500
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList, self).__init__()

                                                    self.yang_name = "filter-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList.Inout')])),
                                                        ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                    ])
                                                    self.inout = None
                                                    self.as_path_list = None
                                                    self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class PeerGroup_(Entity):
                                                """
                                                Member of the peer\-group
                                                
                                                .. attribute:: peer_group_name
                                                
                                                	peer\-group name
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_, self).__init__()

                                                    self.yang_name = "peer-group"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                                    ])
                                                    self.peer_group_name = None
                                                    self._segment_path = lambda: "peer-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PeerGroup_, ['peer_group_name'], name, value)


                                            class PrefixList(Entity):
                                                """
                                                Filter updates to/from this neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList.Inout>`
                                                
                                                .. attribute:: prefix_list_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList, self).__init__()

                                                    self.yang_name = "prefix-list"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList.Inout')])),
                                                        ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.prefix_list_name = None
                                                    self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: additional_paths
                                        
                                        	
                                        	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths>`
                                        
                                        .. attribute:: advertise
                                        
                                        	Advertise to this neighbor
                                        	**type**\:  :py:class:`Advertise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: distribute_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList>`
                                        
                                        .. attribute:: dmzlink_bw
                                        
                                        	Propagate the DMZ link bandwidth
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: encap
                                        
                                        	Preferred encapsulation for neighbor
                                        	**type**\:  :py:class:`Encap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap>`
                                        
                                        .. attribute:: filter_list
                                        
                                        	Establish BGP filters
                                        	**type**\: list of  		 :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: peer_group
                                        
                                        	Member of the peer\-group
                                        	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: prefix_list
                                        
                                        	Filter updates to/from this neighbor
                                        	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths)), ("advertise", ("advertise", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise)), ("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn)), ("distribute-list", ("distribute_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList)), ("encap", ("encap", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap)), ("filter-list", ("filter_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup)), ("prefix-list", ("prefix_list", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('dmzlink_bw', (YLeaf(YType.empty, 'dmzlink-bw'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.dmzlink_bw = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths()
                                            self.additional_paths.parent = self
                                            self._children_name_map["additional_paths"] = "additional-paths"

                                            self.advertise = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise()
                                            self.advertise.parent = self
                                            self._children_name_map["advertise"] = "advertise"

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.encap = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap()
                                            self.encap.parent = self
                                            self._children_name_map["encap"] = "encap"

                                            self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.peer_group = None
                                            self._children_name_map["peer_group"] = "peer-group"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.distribute_list = YList(self)
                                            self.filter_list = YList(self)
                                            self.prefix_list = YList(self)
                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'dmzlink_bw', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AdditionalPaths(Entity):
                                            """
                                            
                                            
                                            .. attribute:: disable
                                            
                                            	Disable additional paths for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: receive
                                            
                                            	Receive additional paths from neighbors
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send
                                            
                                            	Send additional paths to this neighbor
                                            	**type**\:  :py:class:`Send <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths, self).__init__()

                                                self.yang_name = "additional-paths"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("send", ("send", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send))])
                                                self._leafs = OrderedDict([
                                                    ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                    ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                ])
                                                self.disable = None
                                                self.receive = None

                                                self.send = None
                                                self._children_name_map["send"] = "send"
                                                self._segment_path = lambda: "additional-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths, ['disable', 'receive'], name, value)


                                            class Send(Entity):
                                                """
                                                Send additional paths to this neighbor
                                                
                                                .. attribute:: receive
                                                
                                                	Receive additional paths from this neighbor
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send, self).__init__()

                                                    self.yang_name = "send"
                                                    self.yang_parent_name = "additional-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('receive', (YLeaf(YType.empty, 'receive'), ['Empty'])),
                                                    ])
                                                    self.receive = None
                                                    self._segment_path = lambda: "send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AdditionalPaths.Send, ['receive'], name, value)


                                        class Advertise(Entity):
                                            """
                                            Advertise to this neighbor
                                            
                                            .. attribute:: additional_paths
                                            
                                            	Advertise additional paths
                                            	**type**\:  :py:class:`AdditionalPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths>`
                                            
                                            .. attribute:: best_external
                                            
                                            	Advertise best\-external (at RRs best\-internal) path
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: diverse_path
                                            
                                            	Advertise diverse path
                                            	**type**\:  :py:class:`DiversePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise, self).__init__()

                                                self.yang_name = "advertise"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("additional-paths", ("additional_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths)), ("diverse-path", ("diverse_path", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath))])
                                                self._leafs = OrderedDict([
                                                    ('best_external', (YLeaf(YType.empty, 'best-external'), ['Empty'])),
                                                ])
                                                self.best_external = None

                                                self.additional_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths()
                                                self.additional_paths.parent = self
                                                self._children_name_map["additional_paths"] = "additional-paths"

                                                self.diverse_path = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath()
                                                self.diverse_path.parent = self
                                                self._children_name_map["diverse_path"] = "diverse-path"
                                                self._segment_path = lambda: "advertise"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise, ['best_external'], name, value)


                                            class AdditionalPaths(Entity):
                                                """
                                                Advertise additional paths
                                                
                                                .. attribute:: all
                                                
                                                	Select all available paths
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: best
                                                
                                                	Select best N paths
                                                	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best>`
                                                
                                                .. attribute:: group_best
                                                
                                                	Select group\-best paths
                                                	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths, self).__init__()

                                                    self.yang_name = "additional-paths"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All)), ("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest))])
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"

                                                    self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best()
                                                    self.best.parent = self
                                                    self._children_name_map["best"] = "best"

                                                    self.group_best = None
                                                    self._children_name_map["group_best"] = "group-best"
                                                    self._segment_path = lambda: "additional-paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Select all available paths
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Select best N paths
                                                    	**type**\:  :py:class:`Best <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best>`
                                                    
                                                    .. attribute:: group_best
                                                    
                                                    	Select group\-best paths
                                                    	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best", ("best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best)), ("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest))])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict()

                                                        self.best = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best()
                                                        self.best.parent = self
                                                        self._children_name_map["best"] = "best"

                                                        self.group_best = None
                                                        self._children_name_map["group_best"] = "group-best"
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All, [], name, value)


                                                    class Best(Entity):
                                                        """
                                                        Select best N paths
                                                        
                                                        .. attribute:: best_range
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best, self).__init__()

                                                            self.yang_name = "best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange))])
                                                            self._leafs = OrderedDict()

                                                            self.best_range = YList(self)
                                                            self._segment_path = lambda: "best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best, [], name, value)


                                                        class BestRange(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: range  (key)
                                                            
                                                            	Number of best paths in additional paths to be selected
                                                            	**type**\: int
                                                            
                                                            	**range:** 2..3
                                                            
                                                            .. attribute:: group_best
                                                            
                                                            	Select group\-best paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, self).__init__()

                                                                self.yang_name = "best-range"
                                                                self.yang_parent_name = "best"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['range']
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                    ('group_best', (YLeaf(YType.empty, 'group-best'), ['Empty'])),
                                                                ])
                                                                self.range = None
                                                                self.group_best = None
                                                                self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.Best.BestRange, ['range', 'group_best'], name, value)


                                                    class GroupBest(Entity):
                                                        """
                                                        Select group\-best paths
                                                        
                                                        .. attribute:: best
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest, self).__init__()

                                                            self.yang_name = "group-best"
                                                            self.yang_parent_name = "all"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                            ])
                                                            self.best = None
                                                            self._segment_path = lambda: "group-best"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.All.GroupBest, ['best'], name, value)


                                                class Best(Entity):
                                                    """
                                                    Select best N paths
                                                    
                                                    .. attribute:: best_range
                                                    
                                                    	
                                                    	**type**\: list of  		 :py:class:`BestRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best, self).__init__()

                                                        self.yang_name = "best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("best-range", ("best_range", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange))])
                                                        self._leafs = OrderedDict()

                                                        self.best_range = YList(self)
                                                        self._segment_path = lambda: "best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best, [], name, value)


                                                    class BestRange(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: range  (key)
                                                        
                                                        	Number of best paths in additional paths to be selected
                                                        	**type**\: int
                                                        
                                                        	**range:** 2..3
                                                        
                                                        .. attribute:: all
                                                        
                                                        	Select all available paths
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        .. attribute:: group_best
                                                        
                                                        	Select group\-best paths
                                                        	**type**\:  :py:class:`GroupBest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest>`
                                                        
                                                        	**presence node**\: True
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange, self).__init__()

                                                            self.yang_name = "best-range"
                                                            self.yang_parent_name = "best"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['range']
                                                            self._child_classes = OrderedDict([("group-best", ("group_best", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest))])
                                                            self._leafs = OrderedDict([
                                                                ('range', (YLeaf(YType.uint8, 'range'), ['int'])),
                                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ])
                                                            self.range = None
                                                            self.all = None

                                                            self.group_best = None
                                                            self._children_name_map["group_best"] = "group-best"
                                                            self._segment_path = lambda: "best-range" + "[range='" + str(self.range) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange, ['range', 'all'], name, value)


                                                        class GroupBest(Entity):
                                                            """
                                                            Select group\-best paths
                                                            
                                                            .. attribute:: all
                                                            
                                                            	Select all available paths
                                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                            
                                                            

                                                            This class is a :ref:`presence class<presence-class>`

                                                            """

                                                            _prefix = 'ios-bgp'
                                                            _revision = '2018-06-28'

                                                            def __init__(self):
                                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, self).__init__()

                                                                self.yang_name = "group-best"
                                                                self.yang_parent_name = "best-range"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self.is_presence_container = True
                                                                self._leafs = OrderedDict([
                                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                                ])
                                                                self.all = None
                                                                self._segment_path = lambda: "group-best"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.Best.BestRange.GroupBest, ['all'], name, value)


                                                class GroupBest(Entity):
                                                    """
                                                    Select group\-best paths
                                                    
                                                    .. attribute:: all
                                                    
                                                    	Select all available paths
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    .. attribute:: best
                                                    
                                                    	Number of best paths in additional paths to be selected
                                                    	**type**\: int
                                                    
                                                    	**range:** 2..3
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest, self).__init__()

                                                        self.yang_name = "group-best"
                                                        self.yang_parent_name = "additional-paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                            ('best', (YLeaf(YType.uint8, 'best'), ['int'])),
                                                        ])
                                                        self.all = None
                                                        self.best = None
                                                        self._segment_path = lambda: "group-best"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.AdditionalPaths.GroupBest, ['all', 'best'], name, value)


                                            class DiversePath(Entity):
                                                """
                                                Advertise diverse path
                                                
                                                .. attribute:: backup
                                                
                                                	Diverse path can be backup path
                                                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: mpath
                                                
                                                	Diverse path can be multipath
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath, self).__init__()

                                                    self.yang_name = "diverse-path"
                                                    self.yang_parent_name = "advertise"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("backup", ("backup", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup))])
                                                    self._leafs = OrderedDict([
                                                        ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                    ])
                                                    self.mpath = None

                                                    self.backup = None
                                                    self._children_name_map["backup"] = "backup"
                                                    self._segment_path = lambda: "diverse-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath, ['mpath'], name, value)


                                                class Backup(Entity):
                                                    """
                                                    Diverse path can be backup path
                                                    
                                                    .. attribute:: mpath
                                                    
                                                    	Diverse path can be multipath
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup, self).__init__()

                                                        self.yang_name = "backup"
                                                        self.yang_parent_name = "diverse-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('mpath', (YLeaf(YType.empty, 'mpath'), ['Empty'])),
                                                        ])
                                                        self.mpath = None
                                                        self._segment_path = lambda: "backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Advertise.DiversePath.Backup, ['mpath'], name, value)


                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class DistributeList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList.Inout>`
                                            
                                            .. attribute:: accesslist
                                            
                                            	
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1..199
                                            
                                            		**type**\: int
                                            
                                            			**range:** 1300..2699
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** [a\-zA\-Z].\*
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList, self).__init__()

                                                self.yang_name = "distribute-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList.Inout')])),
                                                    ('accesslist', (YLeaf(YType.str, 'accesslist'), ['int','int','str'])),
                                                ])
                                                self.inout = None
                                                self.accesslist = None
                                                self._segment_path = lambda: "distribute-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.DistributeList, ['inout', 'accesslist'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Encap(Entity):
                                            """
                                            Preferred encapsulation for neighbor
                                            
                                            .. attribute:: mpls
                                            
                                            	Neighbor prefers MPLS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: vxlan
                                            
                                            	Neighbor prefers VxLAN
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap, self).__init__()

                                                self.yang_name = "encap"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mpls', (YLeaf(YType.empty, 'mpls'), ['Empty'])),
                                                    ('vxlan', (YLeaf(YType.empty, 'vxlan'), ['Empty'])),
                                                ])
                                                self.mpls = None
                                                self.vxlan = None
                                                self._segment_path = lambda: "encap"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Encap, ['mpls', 'vxlan'], name, value)


                                        class FilterList(Entity):
                                            """
                                            Establish BGP filters
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList.Inout>`
                                            
                                            .. attribute:: as_path_list
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..500
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList, self).__init__()

                                                self.yang_name = "filter-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList.Inout')])),
                                                    ('as_path_list', (YLeaf(YType.uint16, 'as-path-list'), ['int'])),
                                                ])
                                                self.inout = None
                                                self.as_path_list = None
                                                self._segment_path = lambda: "filter-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.FilterList, ['inout', 'as_path_list'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.NextHopSelf, ['all'], name, value)


                                        class PeerGroup(Entity):
                                            """
                                            Member of the peer\-group
                                            
                                            .. attribute:: peer_group_name
                                            
                                            	peer\-group name
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup, self).__init__()

                                                self.yang_name = "peer-group"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                                ])
                                                self.peer_group_name = None
                                                self._segment_path = lambda: "peer-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PeerGroup, ['peer_group_name'], name, value)


                                        class PrefixList(Entity):
                                            """
                                            Filter updates to/from this neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList.Inout>`
                                            
                                            .. attribute:: prefix_list_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList, self).__init__()

                                                self.yang_name = "prefix-list"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList.Inout')])),
                                                    ('prefix_list_name', (YLeaf(YType.str, 'prefix-list-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.prefix_list_name = None
                                                self._segment_path = lambda: "prefix-list" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.PrefixList, ['inout', 'prefix_list_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class AllowasIn(Entity):
                                        """
                                        Accept as\-path with my AS present in it
                                        
                                        .. attribute:: as_number
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..10
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn, self).__init__()

                                            self.yang_name = "allowas-in"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                            ])
                                            self.as_number = None
                                            self._segment_path = lambda: "allowas-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.AllowasIn, ['as_number'], name, value)


                                    class Capability(Entity):
                                        """
                                        Advertise capability to the peer
                                        
                                        .. attribute:: orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability, self).__init__()

                                            self.yang_name = "capability"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf))])
                                            self._leafs = OrderedDict()

                                            self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf()
                                            self.orf.parent = self
                                            self._children_name_map["orf"] = "orf"
                                            self._segment_path = lambda: "capability"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability, [], name, value)


                                        class Orf(Entity):
                                            """
                                            Advertise ORF capability to the peer
                                            
                                            .. attribute:: prefix_list
                                            
                                            	Advertise prefix list ORF capability to this neighbor
                                            	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf.PrefixList>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf, self).__init__()

                                                self.yang_name = "orf"
                                                self.yang_parent_name = "capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf.PrefixList')])),
                                                ])
                                                self.prefix_list = []
                                                self._segment_path = lambda: "orf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Capability.Orf, ['prefix_list'], name, value)

                                            class PrefixList(Enum):
                                                """
                                                PrefixList (Enum Class)

                                                Advertise prefix list ORF capability to this neighbor

                                                .. data:: both = 0

                                                .. data:: receive = 1

                                                .. data:: send = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                receive = Enum.YLeaf(1, "receive")

                                                send = Enum.YLeaf(2, "send")



                                    class Inherit(Entity):
                                        """
                                        Inherit a template
                                        
                                        .. attribute:: peer_policy
                                        
                                        	Inherit a peer\-policy template
                                        	**type**\: str
                                        
                                        .. attribute:: peer_session
                                        
                                        	Inherit a peer\-session template
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit, self).__init__()

                                            self.yang_name = "inherit"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                            ])
                                            self.peer_policy = None
                                            self.peer_session = None
                                            self._segment_path = lambda: "inherit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Inherit, ['peer_policy', 'peer_session'], name, value)


                                    class MaximumPrefix(Entity):
                                        """
                                        Maximum number of prefixes accepted from this peer
                                        
                                        .. attribute:: max_prefix_no
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..2147483647
                                        
                                        .. attribute:: threshold
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..100
                                        
                                        .. attribute:: restart
                                        
                                        	Restart bgp connection after limit is exceeded
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: warning_only
                                        
                                        	Only give warning message when limit is exceeded
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix, self).__init__()

                                            self.yang_name = "maximum-prefix"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                            ])
                                            self.max_prefix_no = None
                                            self.threshold = None
                                            self.restart = None
                                            self.warning_only = None
                                            self._segment_path = lambda: "maximum-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                    class NextHopSelf(Entity):
                                        """
                                        Disable the next hop calculation for this neighbor
                                        
                                        .. attribute:: all
                                        
                                        	Enable next\-hop\-self for both eBGP and iBGP received paths
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf, self).__init__()

                                            self.yang_name = "next-hop-self"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                            ])
                                            self.all = None
                                            self._segment_path = lambda: "next-hop-self"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.NextHopSelf, ['all'], name, value)


                                    class RemovePrivateAs(Entity):
                                        """
                                        Remove private AS number from outbound updates
                                        
                                        .. attribute:: all
                                        
                                        	Remove all private AS numbers
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs, self).__init__()

                                            self.yang_name = "remove-private-as"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.all = None
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "remove-private-as"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs, [], name, value)


                                        class All(Entity):
                                            """
                                            Remove all private AS numbers
                                            
                                            .. attribute:: replace_as
                                            
                                            	Replace all private AS numbers with local AS
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "remove-private-as"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                ])
                                                self.replace_as = None
                                                self._segment_path = lambda: "all"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RemovePrivateAs.All, ['replace_as'], name, value)


                                    class RouteMap(Entity):
                                        """
                                        Apply route map to neighbor
                                        
                                        .. attribute:: inout  (key)
                                        
                                        	
                                        	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap.Inout>`
                                        
                                        .. attribute:: route_map_name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap, self).__init__()

                                            self.yang_name = "route-map"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['inout']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap.Inout')])),
                                                ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                            ])
                                            self.inout = None
                                            self.route_map_name = None
                                            self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.RouteMap, ['inout', 'route_map_name'], name, value)

                                        class Inout(Enum):
                                            """
                                            Inout (Enum Class)

                                            .. data:: in_ = 0

                                            .. data:: out = 1

                                            """

                                            in_ = Enum.YLeaf(0, "in")

                                            out = Enum.YLeaf(1, "out")



                                    class SendCommunity(Entity):
                                        """
                                        Send Community attribute to this neighbor
                                        
                                        .. attribute:: send_community_where
                                        
                                        	
                                        	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity.SendCommunityWhere>`
                                        
                                        	**default value**\: standard
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity, self).__init__()

                                            self.yang_name = "send-community"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity.SendCommunityWhere')])),
                                            ])
                                            self.send_community_where = None
                                            self._segment_path = lambda: "send-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SendCommunity, ['send_community_where'], name, value)

                                        class SendCommunityWhere(Enum):
                                            """
                                            SendCommunityWhere (Enum Class)

                                            .. data:: both = 0

                                            .. data:: extended = 1

                                            .. data:: standard = 2

                                            """

                                            both = Enum.YLeaf(0, "both")

                                            extended = Enum.YLeaf(1, "extended")

                                            standard = Enum.YLeaf(2, "standard")



                                    class SlowPeer(Entity):
                                        """
                                        Configure slow\-peer
                                        
                                        .. attribute:: detection
                                        
                                        	Slow\-peer detection
                                        	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: split_update_group
                                        
                                        	Configure slow\-peer split\-update\-group
                                        	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer, self).__init__()

                                            self.yang_name = "slow-peer"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup))])
                                            self._leafs = OrderedDict()

                                            self.detection = None
                                            self._children_name_map["detection"] = "detection"

                                            self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup()
                                            self.split_update_group.parent = self
                                            self._children_name_map["split_update_group"] = "split-update-group"
                                            self._segment_path = lambda: "slow-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer, [], name, value)


                                        class Detection(Entity):
                                            """
                                            Slow\-peer detection
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 120..3600
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection, self).__init__()

                                                self.yang_name = "detection"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                ])
                                                self.threshold = None
                                                self._segment_path = lambda: "detection"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.Detection, ['threshold'], name, value)


                                        class SplitUpdateGroup(Entity):
                                            """
                                            Configure slow\-peer split\-update\-group
                                            
                                            .. attribute:: dynamic
                                            
                                            	Dynamically split the slow peer to slow\-update group
                                            	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup, self).__init__()

                                                self.yang_name = "split-update-group"
                                                self.yang_parent_name = "slow-peer"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                self._leafs = OrderedDict()

                                                self.dynamic = None
                                                self._children_name_map["dynamic"] = "dynamic"
                                                self._segment_path = lambda: "split-update-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup, [], name, value)


                                            class Dynamic(Entity):
                                                """
                                                Dynamically split the slow peer to slow\-update group
                                                
                                                .. attribute:: permanent
                                                
                                                	Keep the slow\-peer permanently in slow\-update group
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                    self.yang_name = "dynamic"
                                                    self.yang_parent_name = "split-update-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                    ])
                                                    self.permanent = None
                                                    self._segment_path = lambda: "dynamic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Network(Entity):
                                        """
                                        
                                        
                                        .. attribute:: with_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`WithMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask>`
                                        
                                        .. attribute:: no_mask
                                        
                                        	Specify a network to announce via BGP
                                        	**type**\: list of  		 :py:class:`NoMask <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("with-mask", ("with_mask", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask)), ("no-mask", ("no_mask", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask))])
                                            self._leafs = OrderedDict()

                                            self.with_mask = YList(self)
                                            self.no_mask = YList(self)
                                            self._segment_path = lambda: "network"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network, [], name, value)


                                        class WithMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mask  (key)
                                            
                                            	Network mask
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask, self).__init__()

                                                self.yang_name = "with-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number','mask']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.mask = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "with-mask" + "[number='" + str(self.number) + "']" + "[mask='" + str(self.mask) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.WithMask, ['number', 'mask', 'route_map', 'backdoor'], name, value)


                                        class NoMask(Entity):
                                            """
                                            Specify a network to announce via BGP
                                            
                                            .. attribute:: number  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to modify the attributes
                                            	**type**\: str
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask, self).__init__()

                                                self.yang_name = "no-mask"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ('backdoor', (YLeaf(YType.empty, 'backdoor'), ['Empty'])),
                                                ])
                                                self.number = None
                                                self.route_map = None
                                                self.backdoor = None
                                                self._segment_path = lambda: "no-mask" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Network.NoMask, ['number', 'route_map', 'backdoor'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnEvpn.Snmp.Context.ContextWord, ['context_word'], name, value)


                                class L2vpnVpls(Entity):
                                    """
                                    L2VPN VPLS address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_>`
                                    
                                    .. attribute:: default_information
                                    
                                    	Control distribution of default information
                                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls, self).__init__()

                                        self.yang_name = "l2vpn-vpls"
                                        self.yang_parent_name = "l2vpn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_)), ("default-information", ("default_information", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.default_information = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation()
                                        self.default_information.parent = self
                                        self._children_name_map["default_information"] = "default-information"

                                        self.peer_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "l2vpn-vpls"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: default
                                        
                                        	Configure BGP defaults
                                        	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default>`
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop>`
                                        
                                        .. attribute:: scan_time
                                        
                                        	Configure background scanner interval
                                        	**type**\: int
                                        
                                        	**range:** 5..60
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("default", ("default", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default)), ("nexthop", ("nexthop", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('scan_time', (YLeaf(YType.uint8, 'scan-time'), ['int'])),
                                            ])
                                            self.scan_time = None

                                            self.default = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default()
                                            self.default.parent = self
                                            self._children_name_map["default"] = "default"

                                            self.nexthop = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_, ['scan_time'], name, value)


                                        class Default(Entity):
                                            """
                                            Configure BGP defaults
                                            
                                            .. attribute:: route_target
                                            
                                            	Control behavior based on Route\-Target attributes
                                            	**type**\:  :py:class:`RouteTarget <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default.RouteTarget>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default, self).__init__()

                                                self.yang_name = "default"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('route_target', (YLeaf(YType.enumeration, 'route-target'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default.RouteTarget')])),
                                                ])
                                                self.route_target = None
                                                self._segment_path = lambda: "default"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Default, ['route_target'], name, value)

                                            class RouteTarget(Enum):
                                                """
                                                RouteTarget (Enum Class)

                                                Control behavior based on Route\-Target attributes

                                                .. data:: filter = 0

                                                """

                                                filter = Enum.YLeaf(0, "filter")



                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class DefaultInformation(Entity):
                                        """
                                        Control distribution of default information
                                        
                                        .. attribute:: originate
                                        
                                        	Distribute a default route
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation, self).__init__()

                                            self.yang_name = "default-information"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                                            ])
                                            self.originate = None
                                            self._segment_path = lambda: "default-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.DefaultInformation, ['originate'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: unsuppress_map
                                            
                                            	Route\-map to selectively unsuppress suppressed routes
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.unsuppress_map = None
                                                self.weight = None

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability>`
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: unsuppress_map
                                        
                                        	Route\-map to selectively unsuppress suppressed routes
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('unsuppress_map', (YLeaf(YType.str, 'unsuppress-map'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.unsuppress_map = None
                                            self.weight = None

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'unsuppress_map', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.NextHopSelf, ['all'], name, value)


                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.L2vpn.L2vpnVpls.Snmp.Context.ContextWord, ['context_word'], name, value)


                            class Rtfilter(Entity):
                                """
                                Address family
                                
                                .. attribute:: af_name  (key)
                                
                                	
                                	**type**\:  :py:class:`AfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.AfName>`
                                
                                .. attribute:: rtfilter
                                
                                	RT\-Filter address family
                                	**type**\:  :py:class:`Rtfilter_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_>`
                                
                                

                                """

                                _prefix = 'ios-bgp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter, self).__init__()

                                    self.yang_name = "rtfilter"
                                    self.yang_parent_name = "no-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("rtfilter", ("rtfilter", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.AfName')])),
                                    ])
                                    self.af_name = None

                                    self.rtfilter = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_()
                                    self.rtfilter.parent = self
                                    self._children_name_map["rtfilter"] = "rtfilter"
                                    self._segment_path = lambda: "rtfilter" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter, ['af_name'], name, value)

                                class AfName(Enum):
                                    """
                                    AfName (Enum Class)

                                    .. data:: unicast = 0

                                    """

                                    unicast = Enum.YLeaf(0, "unicast")



                                class Rtfilter_(Entity):
                                    """
                                    RT\-Filter address family
                                    
                                    .. attribute:: bgp
                                    
                                    	
                                    	**type**\:  :py:class:`Bgp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_>`
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Forward packets over multiple paths
                                    	**type**\:  :py:class:`MaximumPaths <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths>`
                                    
                                    .. attribute:: peer_group
                                    
                                    	
                                    	**type**\:  :py:class:`PeerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Specify a neighbor router
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor>`
                                    
                                    .. attribute:: snmp
                                    
                                    	Modify snmp parameters
                                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-bgp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_, self).__init__()

                                        self.yang_name = "rtfilter"
                                        self.yang_parent_name = "rtfilter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_)), ("maximum-paths", ("maximum_paths", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths)), ("peer-group", ("peer_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup)), ("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor)), ("snmp", ("snmp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp))])
                                        self._leafs = OrderedDict()

                                        self.bgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_()
                                        self.bgp.parent = self
                                        self._children_name_map["bgp"] = "bgp"

                                        self.maximum_paths = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths()
                                        self.maximum_paths.parent = self
                                        self._children_name_map["maximum_paths"] = "maximum-paths"

                                        self.peer_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup()
                                        self.peer_group.parent = self
                                        self._children_name_map["peer_group"] = "peer-group"

                                        self.snmp = None
                                        self._children_name_map["snmp"] = "snmp"

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "rtfilter"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_, [], name, value)


                                    class Bgp_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: nexthop
                                        
                                        	Nexthop tracking commands
                                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop>`
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_, self).__init__()

                                            self.yang_name = "bgp"
                                            self.yang_parent_name = "rtfilter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("nexthop", ("nexthop", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer))])
                                            self._leafs = OrderedDict()

                                            self.nexthop = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop()
                                            self.nexthop.parent = self
                                            self._children_name_map["nexthop"] = "nexthop"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"
                                            self._segment_path = lambda: "bgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_, [], name, value)


                                        class Nexthop(Entity):
                                            """
                                            Nexthop tracking commands
                                            
                                            .. attribute:: trigger
                                            
                                            	Nexthop triggering
                                            	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map for valid nexthops
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop, self).__init__()

                                                self.yang_name = "nexthop"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger", ("trigger", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.trigger = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger()
                                                self.trigger.parent = self
                                                self._children_name_map["trigger"] = "trigger"
                                                self._segment_path = lambda: "nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop, ['route_map'], name, value)


                                            class Trigger(Entity):
                                                """
                                                Nexthop triggering
                                                
                                                .. attribute:: delay
                                                
                                                	Set the delay to trigger nexthop tracking
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: enable
                                                
                                                	Enable nexthop tracking
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger, self).__init__()

                                                    self.yang_name = "trigger"
                                                    self.yang_parent_name = "nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                                    ])
                                                    self.delay = None
                                                    self.enable = None
                                                    self._segment_path = lambda: "trigger"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.Nexthop.Trigger, ['delay', 'enable'], name, value)


                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "bgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: disable
                                                
                                                	Disable slow\-peer detection
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.disable = None
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.Detection, ['disable', 'threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Bgp_.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class MaximumPaths(Entity):
                                        """
                                        Forward packets over multiple paths
                                        
                                        .. attribute:: ebgp
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: eibgp
                                        
                                        	Both eBGP and iBGP paths as multipath
                                        	**type**\: int
                                        
                                        	**range:** 1..32
                                        
                                        .. attribute:: ibgp
                                        
                                        	iBGP\-multipath
                                        	**type**\:  :py:class:`Ibgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp>`
                                        
                                        .. attribute:: external_rtfilter
                                        
                                        	VPN prefix multipath on external RT\-Filter peers
                                        	**type**\:  :py:class:`ExternalRtfilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths, self).__init__()

                                            self.yang_name = "maximum-paths"
                                            self.yang_parent_name = "rtfilter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ibgp", ("ibgp", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp)), ("external-rtfilter", ("external_rtfilter", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter))])
                                            self._leafs = OrderedDict([
                                                ('ebgp', (YLeaf(YType.uint16, 'ebgp'), ['int'])),
                                                ('eibgp', (YLeaf(YType.uint16, 'eibgp'), ['int'])),
                                            ])
                                            self.ebgp = None
                                            self.eibgp = None

                                            self.ibgp = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"

                                            self.external_rtfilter = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter()
                                            self.external_rtfilter.parent = self
                                            self._children_name_map["external_rtfilter"] = "external-rtfilter"
                                            self._segment_path = lambda: "maximum-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths, ['ebgp', 'eibgp'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            iBGP\-multipath
                                            
                                            .. attribute:: unequal_cost
                                            
                                            	Perform un\-equal cost multipath selection
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unequal_cost', (YLeaf(YType.uint16, 'unequal-cost'), ['int'])),
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.unequal_cost = None
                                                self.max = None
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.Ibgp, ['unequal_cost', 'max'], name, value)


                                        class ExternalRtfilter(Entity):
                                            """
                                            VPN prefix multipath on external RT\-Filter peers
                                            
                                            .. attribute:: max
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..32
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter, self).__init__()

                                                self.yang_name = "external-rtfilter"
                                                self.yang_parent_name = "maximum-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max', (YLeaf(YType.uint16, 'max'), ['int'])),
                                                ])
                                                self.max = None
                                                self._segment_path = lambda: "external-rtfilter"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.MaximumPaths.ExternalRtfilter, ['max'], name, value)


                                    class PeerGroup(Entity):
                                        """
                                        
                                        
                                        .. attribute:: neighbor
                                        
                                        	Specify a neighbor router
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup, self).__init__()

                                            self.yang_name = "peer-group"
                                            self.yang_parent_name = "rtfilter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor))])
                                            self._leafs = OrderedDict()

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "peer-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Specify a neighbor router
                                            
                                            .. attribute:: id  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: activate
                                            
                                            	Enable the address family for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: advertisement_interval
                                            
                                            	Minimum interval between sending BGP routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..600
                                            
                                            .. attribute:: allow_policy
                                            
                                            	Enable the policy support for this IBGP Neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: allowas_in
                                            
                                            	Accept as\-path with my AS present in it
                                            	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: capability
                                            
                                            	Advertise capability to the peer
                                            	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability>`
                                            
                                            .. attribute:: default_originate
                                            
                                            	Originate default route to this neighbor
                                            	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: inherit
                                            
                                            	Inherit a template
                                            	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit>`
                                            
                                            .. attribute:: maximum_prefix
                                            
                                            	Maximum number of prefixes accepted from this peer
                                            	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix>`
                                            
                                            .. attribute:: next_hop_self
                                            
                                            	Disable the next hop calculation for this neighbor
                                            	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: next_hop_unchanged
                                            
                                            	Propagate the iBGP paths' next hop unchanged for this neighbor
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: remove_private_as
                                            
                                            	Remove private AS number from outbound updates
                                            	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: route_map
                                            
                                            	Apply route map to neighbor
                                            	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap>`
                                            
                                            .. attribute:: route_reflector_client
                                            
                                            	Configure a neighbor as Route Reflector client
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            .. attribute:: send_community
                                            
                                            	Send Community attribute to this neighbor
                                            	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: slow_peer
                                            
                                            	Configure slow\-peer
                                            	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer>`
                                            
                                            .. attribute:: soft_reconfiguration
                                            
                                            	Per neighbor soft reconfiguration
                                            	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SoftReconfiguration>`
                                            
                                            .. attribute:: soo
                                            
                                            	ASN\:nn or IP\-address\:nn VPN extended community
                                            	**type**\: str
                                            
                                            .. attribute:: weight
                                            
                                            	Set default weight for routes from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "peer-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer))])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                    ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                    ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                    ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                    ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                    ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                    ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SoftReconfiguration')])),
                                                    ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                    ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                                ])
                                                self.id = None
                                                self.activate = None
                                                self.advertisement_interval = None
                                                self.allow_policy = None
                                                self.next_hop_unchanged = None
                                                self.route_reflector_client = None
                                                self.soft_reconfiguration = None
                                                self.soo = None
                                                self.weight = None

                                                self.allowas_in = None
                                                self._children_name_map["allowas_in"] = "allowas-in"

                                                self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability()
                                                self.capability.parent = self
                                                self._children_name_map["capability"] = "capability"

                                                self.default_originate = None
                                                self._children_name_map["default_originate"] = "default-originate"

                                                self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit()
                                                self.inherit.parent = self
                                                self._children_name_map["inherit"] = "inherit"

                                                self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix()
                                                self.maximum_prefix.parent = self
                                                self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                                self.next_hop_self = None
                                                self._children_name_map["next_hop_self"] = "next-hop-self"

                                                self.remove_private_as = None
                                                self._children_name_map["remove_private_as"] = "remove-private-as"

                                                self.send_community = None
                                                self._children_name_map["send_community"] = "send-community"

                                                self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer()
                                                self.slow_peer.parent = self
                                                self._children_name_map["slow_peer"] = "slow-peer"

                                                self.route_map = YList(self)
                                                self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'weight'], name, value)

                                            class SoftReconfiguration(Enum):
                                                """
                                                SoftReconfiguration (Enum Class)

                                                Per neighbor soft reconfiguration

                                                .. data:: inbound = 0

                                                """

                                                inbound = Enum.YLeaf(0, "inbound")



                                            class AllowasIn(Entity):
                                                """
                                                Accept as\-path with my AS present in it
                                                
                                                .. attribute:: as_number
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..10
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn, self).__init__()

                                                    self.yang_name = "allowas-in"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                    ])
                                                    self.as_number = None
                                                    self._segment_path = lambda: "allowas-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.AllowasIn, ['as_number'], name, value)


                                            class Capability(Entity):
                                                """
                                                Advertise capability to the peer
                                                
                                                .. attribute:: orf
                                                
                                                	Advertise ORF capability to the peer
                                                	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability, self).__init__()

                                                    self.yang_name = "capability"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf))])
                                                    self._leafs = OrderedDict()

                                                    self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf()
                                                    self.orf.parent = self
                                                    self._children_name_map["orf"] = "orf"
                                                    self._segment_path = lambda: "capability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability, [], name, value)


                                                class Orf(Entity):
                                                    """
                                                    Advertise ORF capability to the peer
                                                    
                                                    .. attribute:: prefix_list
                                                    
                                                    	Advertise prefix list ORF capability to this neighbor
                                                    	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf.PrefixList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf, self).__init__()

                                                        self.yang_name = "orf"
                                                        self.yang_parent_name = "capability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf.PrefixList')])),
                                                        ])
                                                        self.prefix_list = []
                                                        self._segment_path = lambda: "orf"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                    class PrefixList(Enum):
                                                        """
                                                        PrefixList (Enum Class)

                                                        Advertise prefix list ORF capability to this neighbor

                                                        .. data:: both = 0

                                                        .. data:: receive = 1

                                                        .. data:: send = 2

                                                        """

                                                        both = Enum.YLeaf(0, "both")

                                                        receive = Enum.YLeaf(1, "receive")

                                                        send = Enum.YLeaf(2, "send")



                                            class DefaultOriginate(Entity):
                                                """
                                                Originate default route to this neighbor
                                                
                                                .. attribute:: route_map
                                                
                                                	Route\-map to specify criteria to originate default
                                                	**type**\: str
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate, self).__init__()

                                                    self.yang_name = "default-originate"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                    ])
                                                    self.route_map = None
                                                    self._segment_path = lambda: "default-originate"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                            class Inherit(Entity):
                                                """
                                                Inherit a template
                                                
                                                .. attribute:: peer_policy
                                                
                                                	Inherit a peer\-policy template
                                                	**type**\: str
                                                
                                                .. attribute:: peer_session
                                                
                                                	Inherit a peer\-session template
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit, self).__init__()

                                                    self.yang_name = "inherit"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                        ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                    ])
                                                    self.peer_policy = None
                                                    self.peer_session = None
                                                    self._segment_path = lambda: "inherit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                            class MaximumPrefix(Entity):
                                                """
                                                Maximum number of prefixes accepted from this peer
                                                
                                                .. attribute:: max_prefix_no
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..2147483647
                                                
                                                .. attribute:: threshold
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: restart
                                                
                                                	Restart bgp connection after limit is exceeded
                                                	**type**\: int
                                                
                                                	**range:** 1..65535
                                                
                                                .. attribute:: warning_only
                                                
                                                	Only give warning message when limit is exceeded
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix, self).__init__()

                                                    self.yang_name = "maximum-prefix"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                        ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                        ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                    ])
                                                    self.max_prefix_no = None
                                                    self.threshold = None
                                                    self.restart = None
                                                    self.warning_only = None
                                                    self._segment_path = lambda: "maximum-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                            class NextHopSelf(Entity):
                                                """
                                                Disable the next hop calculation for this neighbor
                                                
                                                .. attribute:: all
                                                
                                                	Enable next\-hop\-self for both eBGP and iBGP received paths
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf, self).__init__()

                                                    self.yang_name = "next-hop-self"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                    ])
                                                    self.all = None
                                                    self._segment_path = lambda: "next-hop-self"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.NextHopSelf, ['all'], name, value)


                                            class RemovePrivateAs(Entity):
                                                """
                                                Remove private AS number from outbound updates
                                                
                                                .. attribute:: all
                                                
                                                	Remove all private AS numbers
                                                	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs, self).__init__()

                                                    self.yang_name = "remove-private-as"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All))])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict()

                                                    self.all = None
                                                    self._children_name_map["all"] = "all"
                                                    self._segment_path = lambda: "remove-private-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs, [], name, value)


                                                class All(Entity):
                                                    """
                                                    Remove all private AS numbers
                                                    
                                                    .. attribute:: replace_as
                                                    
                                                    	Replace all private AS numbers with local AS
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All, self).__init__()

                                                        self.yang_name = "all"
                                                        self.yang_parent_name = "remove-private-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                        ])
                                                        self.replace_as = None
                                                        self._segment_path = lambda: "all"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                            class RouteMap(Entity):
                                                """
                                                Apply route map to neighbor
                                                
                                                .. attribute:: inout  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap.Inout>`
                                                
                                                .. attribute:: route_map_name
                                                
                                                	
                                                	**type**\: str
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap, self).__init__()

                                                    self.yang_name = "route-map"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['inout']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap.Inout')])),
                                                        ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                    ])
                                                    self.inout = None
                                                    self.route_map_name = None
                                                    self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                                class Inout(Enum):
                                                    """
                                                    Inout (Enum Class)

                                                    .. data:: in_ = 0

                                                    .. data:: out = 1

                                                    """

                                                    in_ = Enum.YLeaf(0, "in")

                                                    out = Enum.YLeaf(1, "out")



                                            class SendCommunity(Entity):
                                                """
                                                Send Community attribute to this neighbor
                                                
                                                .. attribute:: send_community_where
                                                
                                                	
                                                	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere>`
                                                
                                                	**default value**\: standard
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity, self).__init__()

                                                    self.yang_name = "send-community"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                    ])
                                                    self.send_community_where = None
                                                    self._segment_path = lambda: "send-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                                class SendCommunityWhere(Enum):
                                                    """
                                                    SendCommunityWhere (Enum Class)

                                                    .. data:: both = 0

                                                    .. data:: extended = 1

                                                    .. data:: standard = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    extended = Enum.YLeaf(1, "extended")

                                                    standard = Enum.YLeaf(2, "standard")



                                            class SlowPeer(Entity):
                                                """
                                                Configure slow\-peer
                                                
                                                .. attribute:: detection
                                                
                                                	Slow\-peer detection
                                                	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection>`
                                                
                                                	**presence node**\: True
                                                
                                                .. attribute:: split_update_group
                                                
                                                	Configure slow\-peer split\-update\-group
                                                	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer, self).__init__()

                                                    self.yang_name = "slow-peer"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                    self._leafs = OrderedDict()

                                                    self.detection = None
                                                    self._children_name_map["detection"] = "detection"

                                                    self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup()
                                                    self.split_update_group.parent = self
                                                    self._children_name_map["split_update_group"] = "split-update-group"
                                                    self._segment_path = lambda: "slow-peer"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer, [], name, value)


                                                class Detection(Entity):
                                                    """
                                                    Slow\-peer detection
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold value (seconds)
                                                    	**type**\: int
                                                    
                                                    	**range:** 120..3600
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection, self).__init__()

                                                        self.yang_name = "detection"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                        ])
                                                        self.threshold = None
                                                        self._segment_path = lambda: "detection"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                                class SplitUpdateGroup(Entity):
                                                    """
                                                    Configure slow\-peer split\-update\-group
                                                    
                                                    .. attribute:: dynamic
                                                    
                                                    	Dynamically split the slow peer to slow\-update group
                                                    	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                    
                                                    	**presence node**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                        self.yang_name = "split-update-group"
                                                        self.yang_parent_name = "slow-peer"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                        self._leafs = OrderedDict()

                                                        self.dynamic = None
                                                        self._children_name_map["dynamic"] = "dynamic"
                                                        self._segment_path = lambda: "split-update-group"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                    class Dynamic(Entity):
                                                        """
                                                        Dynamically split the slow peer to slow\-update group
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	Keep the slow\-peer permanently in slow\-update group
                                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                        
                                                        

                                                        This class is a :ref:`presence class<presence-class>`

                                                        """

                                                        _prefix = 'ios-bgp'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                            self.yang_name = "dynamic"
                                                            self.yang_parent_name = "split-update-group"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self.is_presence_container = True
                                                            self._leafs = OrderedDict([
                                                                ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                            ])
                                                            self.permanent = None
                                                            self._segment_path = lambda: "dynamic"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.PeerGroup.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Specify a neighbor router
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: activate
                                        
                                        	Enable the address family for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertisement_interval
                                        
                                        	Minimum interval between sending BGP routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..600
                                        
                                        .. attribute:: allow_policy
                                        
                                        	Enable the policy support for this IBGP Neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: allowas_in
                                        
                                        	Accept as\-path with my AS present in it
                                        	**type**\:  :py:class:`AllowasIn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: capability
                                        
                                        	Advertise capability to the peer
                                        	**type**\:  :py:class:`Capability <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability>`
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:  :py:class:`DefaultOriginate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: inherit
                                        
                                        	Inherit a template
                                        	**type**\:  :py:class:`Inherit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit>`
                                        
                                        .. attribute:: maximum_prefix
                                        
                                        	Maximum number of prefixes accepted from this peer
                                        	**type**\:  :py:class:`MaximumPrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation for this neighbor
                                        	**type**\:  :py:class:`NextHopSelf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	Propagate the iBGP paths' next hop unchanged for this neighbor
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: remove_private_as
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:  :py:class:`RemovePrivateAs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_map
                                        
                                        	Apply route map to neighbor
                                        	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap>`
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	Configure a neighbor as Route Reflector client
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community
                                        
                                        	Send Community attribute to this neighbor
                                        	**type**\:  :py:class:`SendCommunity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: slow_peer
                                        
                                        	Configure slow\-peer
                                        	**type**\:  :py:class:`SlowPeer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Per neighbor soft reconfiguration
                                        	**type**\:  :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SoftReconfiguration>`
                                        
                                        .. attribute:: soo
                                        
                                        	ASN\:nn or IP\-address\:nn VPN extended community
                                        	**type**\: str
                                        
                                        .. attribute:: weight
                                        
                                        	Set default weight for routes from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "rtfilter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("allowas-in", ("allowas_in", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn)), ("capability", ("capability", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability)), ("default-originate", ("default_originate", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate)), ("inherit", ("inherit", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit)), ("maximum-prefix", ("maximum_prefix", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix)), ("next-hop-self", ("next_hop_self", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf)), ("remove-private-as", ("remove_private_as", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs)), ("route-map", ("route_map", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap)), ("send-community", ("send_community", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity)), ("slow-peer", ("slow_peer", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str','str'])),
                                                ('activate', (YLeaf(YType.empty, 'activate'), ['Empty'])),
                                                ('advertisement_interval', (YLeaf(YType.uint16, 'advertisement-interval'), ['int'])),
                                                ('allow_policy', (YLeaf(YType.empty, 'allow-policy'), ['Empty'])),
                                                ('next_hop_unchanged', (YLeaf(YType.empty, 'next-hop-unchanged'), ['Empty'])),
                                                ('route_reflector_client', (YLeaf(YType.empty, 'route-reflector-client'), ['Empty'])),
                                                ('soft_reconfiguration', (YLeaf(YType.enumeration, 'soft-reconfiguration'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SoftReconfiguration')])),
                                                ('soo', (YLeaf(YType.str, 'soo'), ['str'])),
                                                ('weight', (YLeaf(YType.uint16, 'weight'), ['int'])),
                                            ])
                                            self.id = None
                                            self.activate = None
                                            self.advertisement_interval = None
                                            self.allow_policy = None
                                            self.next_hop_unchanged = None
                                            self.route_reflector_client = None
                                            self.soft_reconfiguration = None
                                            self.soo = None
                                            self.weight = None

                                            self.allowas_in = None
                                            self._children_name_map["allowas_in"] = "allowas-in"

                                            self.capability = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability()
                                            self.capability.parent = self
                                            self._children_name_map["capability"] = "capability"

                                            self.default_originate = None
                                            self._children_name_map["default_originate"] = "default-originate"

                                            self.inherit = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit()
                                            self.inherit.parent = self
                                            self._children_name_map["inherit"] = "inherit"

                                            self.maximum_prefix = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix()
                                            self.maximum_prefix.parent = self
                                            self._children_name_map["maximum_prefix"] = "maximum-prefix"

                                            self.next_hop_self = None
                                            self._children_name_map["next_hop_self"] = "next-hop-self"

                                            self.remove_private_as = None
                                            self._children_name_map["remove_private_as"] = "remove-private-as"

                                            self.send_community = None
                                            self._children_name_map["send_community"] = "send-community"

                                            self.slow_peer = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer()
                                            self.slow_peer.parent = self
                                            self._children_name_map["slow_peer"] = "slow-peer"

                                            self.route_map = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor, ['id', 'activate', 'advertisement_interval', 'allow_policy', 'next_hop_unchanged', 'route_reflector_client', 'soft_reconfiguration', 'soo', 'weight'], name, value)

                                        class SoftReconfiguration(Enum):
                                            """
                                            SoftReconfiguration (Enum Class)

                                            Per neighbor soft reconfiguration

                                            .. data:: inbound = 0

                                            """

                                            inbound = Enum.YLeaf(0, "inbound")



                                        class AllowasIn(Entity):
                                            """
                                            Accept as\-path with my AS present in it
                                            
                                            .. attribute:: as_number
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..10
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn, self).__init__()

                                                self.yang_name = "allowas-in"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('as_number', (YLeaf(YType.uint8, 'as-number'), ['int'])),
                                                ])
                                                self.as_number = None
                                                self._segment_path = lambda: "allowas-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.AllowasIn, ['as_number'], name, value)


                                        class Capability(Entity):
                                            """
                                            Advertise capability to the peer
                                            
                                            .. attribute:: orf
                                            
                                            	Advertise ORF capability to the peer
                                            	**type**\:  :py:class:`Orf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability, self).__init__()

                                                self.yang_name = "capability"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("orf", ("orf", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf))])
                                                self._leafs = OrderedDict()

                                                self.orf = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf()
                                                self.orf.parent = self
                                                self._children_name_map["orf"] = "orf"
                                                self._segment_path = lambda: "capability"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability, [], name, value)


                                            class Orf(Entity):
                                                """
                                                Advertise ORF capability to the peer
                                                
                                                .. attribute:: prefix_list
                                                
                                                	Advertise prefix list ORF capability to this neighbor
                                                	**type**\: list of   :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf.PrefixList>`
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf, self).__init__()

                                                    self.yang_name = "orf"
                                                    self.yang_parent_name = "capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_list', (YLeafList(YType.enumeration, 'prefix-list'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf.PrefixList')])),
                                                    ])
                                                    self.prefix_list = []
                                                    self._segment_path = lambda: "orf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Capability.Orf, ['prefix_list'], name, value)

                                                class PrefixList(Enum):
                                                    """
                                                    PrefixList (Enum Class)

                                                    Advertise prefix list ORF capability to this neighbor

                                                    .. data:: both = 0

                                                    .. data:: receive = 1

                                                    .. data:: send = 2

                                                    """

                                                    both = Enum.YLeaf(0, "both")

                                                    receive = Enum.YLeaf(1, "receive")

                                                    send = Enum.YLeaf(2, "send")



                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: route_map
                                            
                                            	Route\-map to specify criteria to originate default
                                            	**type**\: str
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None
                                                self._segment_path = lambda: "default-originate"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.DefaultOriginate, ['route_map'], name, value)


                                        class Inherit(Entity):
                                            """
                                            Inherit a template
                                            
                                            .. attribute:: peer_policy
                                            
                                            	Inherit a peer\-policy template
                                            	**type**\: str
                                            
                                            .. attribute:: peer_session
                                            
                                            	Inherit a peer\-session template
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit, self).__init__()

                                                self.yang_name = "inherit"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_policy', (YLeaf(YType.str, 'peer-policy'), ['str'])),
                                                    ('peer_session', (YLeaf(YType.str, 'peer-session'), ['str'])),
                                                ])
                                                self.peer_policy = None
                                                self.peer_session = None
                                                self._segment_path = lambda: "inherit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.Inherit, ['peer_policy', 'peer_session'], name, value)


                                        class MaximumPrefix(Entity):
                                            """
                                            Maximum number of prefixes accepted from this peer
                                            
                                            .. attribute:: max_prefix_no
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..2147483647
                                            
                                            .. attribute:: threshold
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 1..100
                                            
                                            .. attribute:: restart
                                            
                                            	Restart bgp connection after limit is exceeded
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: warning_only
                                            
                                            	Only give warning message when limit is exceeded
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix, self).__init__()

                                                self.yang_name = "maximum-prefix"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefix_no', (YLeaf(YType.uint32, 'max-prefix-no'), ['int'])),
                                                    ('threshold', (YLeaf(YType.uint8, 'threshold'), ['int'])),
                                                    ('restart', (YLeaf(YType.uint16, 'restart'), ['int'])),
                                                    ('warning_only', (YLeaf(YType.empty, 'warning-only'), ['Empty'])),
                                                ])
                                                self.max_prefix_no = None
                                                self.threshold = None
                                                self.restart = None
                                                self.warning_only = None
                                                self._segment_path = lambda: "maximum-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.MaximumPrefix, ['max_prefix_no', 'threshold', 'restart', 'warning_only'], name, value)


                                        class NextHopSelf(Entity):
                                            """
                                            Disable the next hop calculation for this neighbor
                                            
                                            .. attribute:: all
                                            
                                            	Enable next\-hop\-self for both eBGP and iBGP received paths
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf, self).__init__()

                                                self.yang_name = "next-hop-self"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                                                ])
                                                self.all = None
                                                self._segment_path = lambda: "next-hop-self"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.NextHopSelf, ['all'], name, value)


                                        class RemovePrivateAs(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: all
                                            
                                            	Remove all private AS numbers
                                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All>`
                                            
                                            	**presence node**\: True
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs, self).__init__()

                                                self.yang_name = "remove-private-as"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("all", ("all", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.all = None
                                                self._children_name_map["all"] = "all"
                                                self._segment_path = lambda: "remove-private-as"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs, [], name, value)


                                            class All(Entity):
                                                """
                                                Remove all private AS numbers
                                                
                                                .. attribute:: replace_as
                                                
                                                	Replace all private AS numbers with local AS
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All, self).__init__()

                                                    self.yang_name = "all"
                                                    self.yang_parent_name = "remove-private-as"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('replace_as', (YLeaf(YType.empty, 'replace-as'), ['Empty'])),
                                                    ])
                                                    self.replace_as = None
                                                    self._segment_path = lambda: "all"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RemovePrivateAs.All, ['replace_as'], name, value)


                                        class RouteMap(Entity):
                                            """
                                            Apply route map to neighbor
                                            
                                            .. attribute:: inout  (key)
                                            
                                            	
                                            	**type**\:  :py:class:`Inout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap.Inout>`
                                            
                                            .. attribute:: route_map_name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap, self).__init__()

                                                self.yang_name = "route-map"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['inout']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('inout', (YLeaf(YType.enumeration, 'inout'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap.Inout')])),
                                                    ('route_map_name', (YLeaf(YType.str, 'route-map-name'), ['str'])),
                                                ])
                                                self.inout = None
                                                self.route_map_name = None
                                                self._segment_path = lambda: "route-map" + "[inout='" + str(self.inout) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.RouteMap, ['inout', 'route_map_name'], name, value)

                                            class Inout(Enum):
                                                """
                                                Inout (Enum Class)

                                                .. data:: in_ = 0

                                                .. data:: out = 1

                                                """

                                                in_ = Enum.YLeaf(0, "in")

                                                out = Enum.YLeaf(1, "out")



                                        class SendCommunity(Entity):
                                            """
                                            Send Community attribute to this neighbor
                                            
                                            .. attribute:: send_community_where
                                            
                                            	
                                            	**type**\:  :py:class:`SendCommunityWhere <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity.SendCommunityWhere>`
                                            
                                            	**default value**\: standard
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity, self).__init__()

                                                self.yang_name = "send-community"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('send_community_where', (YLeaf(YType.enumeration, 'send-community-where'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity.SendCommunityWhere')])),
                                                ])
                                                self.send_community_where = None
                                                self._segment_path = lambda: "send-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SendCommunity, ['send_community_where'], name, value)

                                            class SendCommunityWhere(Enum):
                                                """
                                                SendCommunityWhere (Enum Class)

                                                .. data:: both = 0

                                                .. data:: extended = 1

                                                .. data:: standard = 2

                                                """

                                                both = Enum.YLeaf(0, "both")

                                                extended = Enum.YLeaf(1, "extended")

                                                standard = Enum.YLeaf(2, "standard")



                                        class SlowPeer(Entity):
                                            """
                                            Configure slow\-peer
                                            
                                            .. attribute:: detection
                                            
                                            	Slow\-peer detection
                                            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection>`
                                            
                                            	**presence node**\: True
                                            
                                            .. attribute:: split_update_group
                                            
                                            	Configure slow\-peer split\-update\-group
                                            	**type**\:  :py:class:`SplitUpdateGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer, self).__init__()

                                                self.yang_name = "slow-peer"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("detection", ("detection", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection)), ("split-update-group", ("split_update_group", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup))])
                                                self._leafs = OrderedDict()

                                                self.detection = None
                                                self._children_name_map["detection"] = "detection"

                                                self.split_update_group = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup()
                                                self.split_update_group.parent = self
                                                self._children_name_map["split_update_group"] = "split-update-group"
                                                self._segment_path = lambda: "slow-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer, [], name, value)


                                            class Detection(Entity):
                                                """
                                                Slow\-peer detection
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold value (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 120..3600
                                                
                                                

                                                This class is a :ref:`presence class<presence-class>`

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection, self).__init__()

                                                    self.yang_name = "detection"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self.is_presence_container = True
                                                    self._leafs = OrderedDict([
                                                        ('threshold', (YLeaf(YType.uint16, 'threshold'), ['int'])),
                                                    ])
                                                    self.threshold = None
                                                    self._segment_path = lambda: "detection"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.Detection, ['threshold'], name, value)


                                            class SplitUpdateGroup(Entity):
                                                """
                                                Configure slow\-peer split\-update\-group
                                                
                                                .. attribute:: dynamic
                                                
                                                	Dynamically split the slow peer to slow\-update group
                                                	**type**\:  :py:class:`Dynamic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic>`
                                                
                                                	**presence node**\: True
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup, self).__init__()

                                                    self.yang_name = "split-update-group"
                                                    self.yang_parent_name = "slow-peer"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dynamic", ("dynamic", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic))])
                                                    self._leafs = OrderedDict()

                                                    self.dynamic = None
                                                    self._children_name_map["dynamic"] = "dynamic"
                                                    self._segment_path = lambda: "split-update-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup, [], name, value)


                                                class Dynamic(Entity):
                                                    """
                                                    Dynamically split the slow peer to slow\-update group
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	Keep the slow\-peer permanently in slow\-update group
                                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                    
                                                    

                                                    This class is a :ref:`presence class<presence-class>`

                                                    """

                                                    _prefix = 'ios-bgp'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, self).__init__()

                                                        self.yang_name = "dynamic"
                                                        self.yang_parent_name = "split-update-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self.is_presence_container = True
                                                        self._leafs = OrderedDict([
                                                            ('permanent', (YLeaf(YType.empty, 'permanent'), ['Empty'])),
                                                        ])
                                                        self.permanent = None
                                                        self._segment_path = lambda: "dynamic"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Neighbor.SlowPeer.SplitUpdateGroup.Dynamic, ['permanent'], name, value)


                                    class Snmp(Entity):
                                        """
                                        Modify snmp parameters
                                        
                                        .. attribute:: context
                                        
                                        	Configure a SNMP context
                                        	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-bgp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp, self).__init__()

                                            self.yang_name = "snmp"
                                            self.yang_parent_name = "rtfilter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("context", ("context", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.context = Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context()
                                            self.context.parent = self
                                            self._children_name_map["context"] = "context"
                                            self._segment_path = lambda: "snmp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp, [], name, value)


                                        class Context(Entity):
                                            """
                                            Configure a SNMP context
                                            
                                            .. attribute:: context_word
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`ContextWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord>`
                                            
                                            

                                            """

                                            _prefix = 'ios-bgp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context, self).__init__()

                                                self.yang_name = "context"
                                                self.yang_parent_name = "snmp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("context_word", ("context_word", Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord))])
                                                self._leafs = OrderedDict()

                                                self.context_word = YList(self)
                                                self._segment_path = lambda: "context"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context, [], name, value)


                                            class ContextWord(Entity):
                                                """
                                                
                                                
                                                .. attribute:: context_word  (key)
                                                
                                                	Context Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-bgp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord, self).__init__()

                                                    self.yang_name = "context_word"
                                                    self.yang_parent_name = "context"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['context_word']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('context_word', (YLeaf(YType.str, 'context_word'), ['str'])),
                                                    ])
                                                    self.context_word = None
                                                    self._segment_path = lambda: "context_word" + "[context_word='" + str(self.context_word) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Bgp.Scope.Vrf.AddressFamily.NoVrf.Rtfilter.Rtfilter_.Snmp.Context.ContextWord, ['context_word'], name, value)


        class Eigrp(Entity):
            """
            Enhanced Interior Gateway Routing Protocol (EIGRP)
            
            .. attribute:: id  (key)
            
            	Autonomous System ID
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 1..65535
            
            		**type**\: str
            
            .. attribute:: passive_interface
            
            	Suppress routing updates on an interface
            	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.PassiveInterface>`
            
            .. attribute:: address_family
            
            	Enter Address Family command mode
            	**type**\: list of  		 :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily>`
            
            .. attribute:: af_interface
            
            	Enter Address Family interface configuration
            	**type**\: list of  		 :py:class:`AfInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AfInterface>`
            
            .. attribute:: set_as_in_submode
            
            	
            	**type**\:  :py:class:`SetAsInSubmode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.SetAsInSubmode>`
            
            .. attribute:: auto_summary
            
            	Enable automatic network number summarization
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: bfd
            
            	BFD configuration commands
            	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Bfd>`
            
            .. attribute:: default_information
            
            	Control distribution of default information
            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DefaultInformation>`
            
            .. attribute:: default_metric
            
            	Set metric of redistributed routes
            	**type**\:  :py:class:`DefaultMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DefaultMetric>`
            
            .. attribute:: distance
            
            	Define an administrative distance
            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Distance>`
            
            .. attribute:: distribute_list
            
            	Filter entries in eigrp updates
            	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DistributeList>`
            
            .. attribute:: eigrp
            
            	EIGRP Address Family specific commands
            	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Eigrp_>`
            
            .. attribute:: maximum_paths
            
            	Number of paths
            	**type**\: int
            
            	**range:** 1..32
            
            .. attribute:: metric
            
            	Modify metrics and parameters for advertisement
            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Metric>`
            
            .. attribute:: neighbor
            
            	Specify a neighbor router
            	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Neighbor>`
            
            .. attribute:: network
            
            	Enable routing on an IP network
            	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Network>`
            
            .. attribute:: nsf
            
            	Non\-stop forwarding
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: offset_list
            
            	Add or subtract offset from EIGRP metrics
            	**type**\:  :py:class:`OffsetList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.OffsetList>`
            
            .. attribute:: redistribute
            
            	Redistribute IPv4 routes from another routing protocol
            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Redistribute>`
            
            .. attribute:: shutdown
            
            	Shutdown this instance of EIGRP
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: summary_metric
            
            	Specify summary to apply metric/filtering
            	**type**\:  :py:class:`SummaryMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.SummaryMetric>`
            
            .. attribute:: timers
            
            	Adjust routing timers
            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Timers>`
            
            .. attribute:: traffic_share
            
            	How to compute traffic share over alternate paths
            	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.TrafficShare>`
            
            .. attribute:: variance
            
            	Metric variance multiplier
            	**type**\: int
            
            	**range:** 1..128
            
            

            """

            _prefix = 'ios-eigrp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Router.Eigrp, self).__init__()

                self.yang_name = "eigrp"
                self.yang_parent_name = "router"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.Eigrp.PassiveInterface)), ("address-family", ("address_family", Native.Router.Eigrp.AddressFamily)), ("af-interface", ("af_interface", Native.Router.Eigrp.AfInterface)), ("set-as-in-submode", ("set_as_in_submode", Native.Router.Eigrp.SetAsInSubmode)), ("bfd", ("bfd", Native.Router.Eigrp.Bfd)), ("default-information", ("default_information", Native.Router.Eigrp.DefaultInformation)), ("default-metric", ("default_metric", Native.Router.Eigrp.DefaultMetric)), ("distance", ("distance", Native.Router.Eigrp.Distance)), ("distribute-list", ("distribute_list", Native.Router.Eigrp.DistributeList)), ("eigrp", ("eigrp", Native.Router.Eigrp.Eigrp_)), ("metric", ("metric", Native.Router.Eigrp.Metric)), ("neighbor", ("neighbor", Native.Router.Eigrp.Neighbor)), ("network", ("network", Native.Router.Eigrp.Network)), ("offset-list", ("offset_list", Native.Router.Eigrp.OffsetList)), ("redistribute", ("redistribute", Native.Router.Eigrp.Redistribute)), ("summary-metric", ("summary_metric", Native.Router.Eigrp.SummaryMetric)), ("timers", ("timers", Native.Router.Eigrp.Timers)), ("traffic-share", ("traffic_share", Native.Router.Eigrp.TrafficShare))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['int','str'])),
                    ('auto_summary', (YLeaf(YType.empty, 'auto-summary'), ['Empty'])),
                    ('maximum_paths', (YLeaf(YType.uint8, 'maximum-paths'), ['int'])),
                    ('nsf', (YLeaf(YType.empty, 'nsf'), ['Empty'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('variance', (YLeaf(YType.uint8, 'variance'), ['int'])),
                ])
                self.id = None
                self.auto_summary = None
                self.maximum_paths = None
                self.nsf = None
                self.shutdown = None
                self.variance = None

                self.passive_interface = Native.Router.Eigrp.PassiveInterface()
                self.passive_interface.parent = self
                self._children_name_map["passive_interface"] = "passive-interface"

                self.set_as_in_submode = Native.Router.Eigrp.SetAsInSubmode()
                self.set_as_in_submode.parent = self
                self._children_name_map["set_as_in_submode"] = "set-as-in-submode"

                self.bfd = Native.Router.Eigrp.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"

                self.default_information = Native.Router.Eigrp.DefaultInformation()
                self.default_information.parent = self
                self._children_name_map["default_information"] = "default-information"

                self.default_metric = Native.Router.Eigrp.DefaultMetric()
                self.default_metric.parent = self
                self._children_name_map["default_metric"] = "default-metric"

                self.distance = Native.Router.Eigrp.Distance()
                self.distance.parent = self
                self._children_name_map["distance"] = "distance"

                self.distribute_list = Native.Router.Eigrp.DistributeList()
                self.distribute_list.parent = self
                self._children_name_map["distribute_list"] = "distribute-list"

                self.eigrp = Native.Router.Eigrp.Eigrp_()
                self.eigrp.parent = self
                self._children_name_map["eigrp"] = "eigrp"

                self.metric = Native.Router.Eigrp.Metric()
                self.metric.parent = self
                self._children_name_map["metric"] = "metric"

                self.neighbor = Native.Router.Eigrp.Neighbor()
                self.neighbor.parent = self
                self._children_name_map["neighbor"] = "neighbor"

                self.offset_list = Native.Router.Eigrp.OffsetList()
                self.offset_list.parent = self
                self._children_name_map["offset_list"] = "offset-list"

                self.redistribute = Native.Router.Eigrp.Redistribute()
                self.redistribute.parent = self
                self._children_name_map["redistribute"] = "redistribute"

                self.summary_metric = Native.Router.Eigrp.SummaryMetric()
                self.summary_metric.parent = self
                self._children_name_map["summary_metric"] = "summary-metric"

                self.timers = Native.Router.Eigrp.Timers()
                self.timers.parent = self
                self._children_name_map["timers"] = "timers"

                self.traffic_share = Native.Router.Eigrp.TrafficShare()
                self.traffic_share.parent = self
                self._children_name_map["traffic_share"] = "traffic-share"

                self.address_family = YList(self)
                self.af_interface = YList(self)
                self.network = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-eigrp:eigrp" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Router.Eigrp, ['id', 'auto_summary', 'maximum_paths', 'nsf', 'shutdown', 'variance'], name, value)


            class PassiveInterface(Entity):
                """
                Suppress routing updates on an interface
                
                .. attribute:: interface
                
                	interface name
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface number
                	**type**\: int
                
                	**range:** 0..2147483647
                
                .. attribute:: vlan
                
                	Vlan interface number
                	**type**\: int
                
                	**range:** 1..4094
                
                .. attribute:: default
                
                	Suppress routing updates on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.PassiveInterface, self).__init__()

                    self.yang_name = "passive-interface"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                    ])
                    self.interface = None
                    self.tunnel = None
                    self.vlan = None
                    self.default = None
                    self._segment_path = lambda: "passive-interface"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.PassiveInterface, ['interface', 'tunnel', 'vlan', 'default'], name, value)


            class AddressFamily(Entity):
                """
                Enter Address Family command mode
                
                .. attribute:: type  (key)
                
                	
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.Type>`
                
                .. attribute:: af_ip_list
                
                	Address family IPv4/IPv6
                	**type**\: list of  		 :py:class:`AfIpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList>`
                
                .. attribute:: af_ip_vrf_list
                
                	Address family IPv4/IPv6 VRF
                	**type**\: list of  		 :py:class:`AfIpVrfList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['type']
                    self._child_classes = OrderedDict([("af-ip-list", ("af_ip_list", Native.Router.Eigrp.AddressFamily.AfIpList)), ("af-ip-vrf-list", ("af_ip_vrf_list", Native.Router.Eigrp.AddressFamily.AfIpVrfList))])
                    self._leafs = OrderedDict([
                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Eigrp.AddressFamily.Type')])),
                    ])
                    self.type = None

                    self.af_ip_list = YList(self)
                    self.af_ip_vrf_list = YList(self)
                    self._segment_path = lambda: "address-family" + "[type='" + str(self.type) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.AddressFamily, ['type'], name, value)

                class Type(Enum):
                    """
                    Type (Enum Class)

                    .. data:: ipv4 = 0

                    .. data:: ipv6 = 1

                    """

                    ipv4 = Enum.YLeaf(0, "ipv4")

                    ipv6 = Enum.YLeaf(1, "ipv6")



                class AfIpList(Entity):
                    """
                    Address family IPv4/IPv6
                    
                    .. attribute:: unicast_multicast  (key)
                    
                    	
                    	**type**\:  :py:class:`UnicastMulticast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.UnicastMulticast>`
                    
                    .. attribute:: autonomous_system
                    
                    	Specify Address\-Family Autonomous System Number
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: af_interface
                    
                    	Enter Address Family interface configuration
                    	**type**\: list of  		 :py:class:`AfInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface>`
                    
                    .. attribute:: set_as_in_submode
                    
                    	
                    	**type**\:  :py:class:`SetAsInSubmode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.SetAsInSubmode>`
                    
                    .. attribute:: auto_summary
                    
                    	Enable automatic network number summarization
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bfd
                    
                    	BFD configuration commands
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Bfd>`
                    
                    .. attribute:: default_information
                    
                    	Control distribution of default information
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation>`
                    
                    .. attribute:: default_metric
                    
                    	Set metric of redistributed routes
                    	**type**\:  :py:class:`DefaultMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric>`
                    
                    .. attribute:: distance
                    
                    	Define an administrative distance
                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Distance>`
                    
                    .. attribute:: distribute_list
                    
                    	Filter entries in eigrp updates
                    	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList>`
                    
                    .. attribute:: eigrp
                    
                    	EIGRP Address Family specific commands
                    	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Eigrp_>`
                    
                    .. attribute:: maximum_paths
                    
                    	Number of paths
                    	**type**\: int
                    
                    	**range:** 1..32
                    
                    .. attribute:: metric
                    
                    	Modify metrics and parameters for advertisement
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Metric>`
                    
                    .. attribute:: neighbor
                    
                    	Specify a neighbor router
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Enable routing on an IP network
                    	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Network>`
                    
                    .. attribute:: nsf
                    
                    	Non\-stop forwarding
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: offset_list
                    
                    	Add or subtract offset from EIGRP metrics
                    	**type**\:  :py:class:`OffsetList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList>`
                    
                    .. attribute:: redistribute
                    
                    	Redistribute IPv4 routes from another routing protocol
                    	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this instance of EIGRP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: summary_metric
                    
                    	Specify summary to apply metric/filtering
                    	**type**\:  :py:class:`SummaryMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.SummaryMetric>`
                    
                    .. attribute:: timers
                    
                    	Adjust routing timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Timers>`
                    
                    .. attribute:: traffic_share
                    
                    	How to compute traffic share over alternate paths
                    	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.TrafficShare>`
                    
                    .. attribute:: variance
                    
                    	Metric variance multiplier
                    	**type**\: int
                    
                    	**range:** 1..128
                    
                    .. attribute:: topology
                    
                    	Topology configuration mode
                    	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.AddressFamily.AfIpList, self).__init__()

                        self.yang_name = "af-ip-list"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['unicast_multicast']
                        self._child_classes = OrderedDict([("af-interface", ("af_interface", Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface)), ("set-as-in-submode", ("set_as_in_submode", Native.Router.Eigrp.AddressFamily.AfIpList.SetAsInSubmode)), ("bfd", ("bfd", Native.Router.Eigrp.AddressFamily.AfIpList.Bfd)), ("default-information", ("default_information", Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation)), ("default-metric", ("default_metric", Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric)), ("distance", ("distance", Native.Router.Eigrp.AddressFamily.AfIpList.Distance)), ("distribute-list", ("distribute_list", Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList)), ("eigrp", ("eigrp", Native.Router.Eigrp.AddressFamily.AfIpList.Eigrp_)), ("metric", ("metric", Native.Router.Eigrp.AddressFamily.AfIpList.Metric)), ("neighbor", ("neighbor", Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor)), ("network", ("network", Native.Router.Eigrp.AddressFamily.AfIpList.Network)), ("offset-list", ("offset_list", Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList)), ("redistribute", ("redistribute", Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute)), ("summary-metric", ("summary_metric", Native.Router.Eigrp.AddressFamily.AfIpList.SummaryMetric)), ("timers", ("timers", Native.Router.Eigrp.AddressFamily.AfIpList.Timers)), ("traffic-share", ("traffic_share", Native.Router.Eigrp.AddressFamily.AfIpList.TrafficShare)), ("topology", ("topology", Native.Router.Eigrp.AddressFamily.AfIpList.Topology))])
                        self._leafs = OrderedDict([
                            ('unicast_multicast', (YLeaf(YType.enumeration, 'unicast-multicast'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Eigrp.AddressFamily.AfIpList.UnicastMulticast')])),
                            ('autonomous_system', (YLeaf(YType.uint16, 'autonomous-system'), ['int'])),
                            ('auto_summary', (YLeaf(YType.empty, 'auto-summary'), ['Empty'])),
                            ('maximum_paths', (YLeaf(YType.uint8, 'maximum-paths'), ['int'])),
                            ('nsf', (YLeaf(YType.empty, 'nsf'), ['Empty'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('variance', (YLeaf(YType.uint8, 'variance'), ['int'])),
                        ])
                        self.unicast_multicast = None
                        self.autonomous_system = None
                        self.auto_summary = None
                        self.maximum_paths = None
                        self.nsf = None
                        self.shutdown = None
                        self.variance = None

                        self.set_as_in_submode = Native.Router.Eigrp.AddressFamily.AfIpList.SetAsInSubmode()
                        self.set_as_in_submode.parent = self
                        self._children_name_map["set_as_in_submode"] = "set-as-in-submode"

                        self.bfd = Native.Router.Eigrp.AddressFamily.AfIpList.Bfd()
                        self.bfd.parent = self
                        self._children_name_map["bfd"] = "bfd"

                        self.default_information = Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"

                        self.default_metric = Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric()
                        self.default_metric.parent = self
                        self._children_name_map["default_metric"] = "default-metric"

                        self.distance = Native.Router.Eigrp.AddressFamily.AfIpList.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"

                        self.distribute_list = Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList()
                        self.distribute_list.parent = self
                        self._children_name_map["distribute_list"] = "distribute-list"

                        self.eigrp = Native.Router.Eigrp.AddressFamily.AfIpList.Eigrp_()
                        self.eigrp.parent = self
                        self._children_name_map["eigrp"] = "eigrp"

                        self.metric = Native.Router.Eigrp.AddressFamily.AfIpList.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.neighbor = Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor()
                        self.neighbor.parent = self
                        self._children_name_map["neighbor"] = "neighbor"

                        self.offset_list = Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList()
                        self.offset_list.parent = self
                        self._children_name_map["offset_list"] = "offset-list"

                        self.redistribute = Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute()
                        self.redistribute.parent = self
                        self._children_name_map["redistribute"] = "redistribute"

                        self.summary_metric = Native.Router.Eigrp.AddressFamily.AfIpList.SummaryMetric()
                        self.summary_metric.parent = self
                        self._children_name_map["summary_metric"] = "summary-metric"

                        self.timers = Native.Router.Eigrp.AddressFamily.AfIpList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.traffic_share = Native.Router.Eigrp.AddressFamily.AfIpList.TrafficShare()
                        self.traffic_share.parent = self
                        self._children_name_map["traffic_share"] = "traffic-share"

                        self.topology = Native.Router.Eigrp.AddressFamily.AfIpList.Topology()
                        self.topology.parent = self
                        self._children_name_map["topology"] = "topology"

                        self.af_interface = YList(self)
                        self.network = YList(self)
                        self._segment_path = lambda: "af-ip-list" + "[unicast-multicast='" + str(self.unicast_multicast) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList, ['unicast_multicast', 'autonomous_system', 'auto_summary', 'maximum_paths', 'nsf', 'shutdown', 'variance'], name, value)

                    class UnicastMulticast(Enum):
                        """
                        UnicastMulticast (Enum Class)

                        .. data:: unicast = 0

                        .. data:: multicast = 1

                        """

                        unicast = Enum.YLeaf(0, "unicast")

                        multicast = Enum.YLeaf(1, "multicast")



                    class AfInterface(Entity):
                        """
                        Enter Address Family interface configuration
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: bandwidth_percent
                        
                        	Set percentage of bandwidth percentage limit
                        	**type**\: int
                        
                        	**range:** 1..999999
                        
                        .. attribute:: hello_interval
                        
                        	Configures hello interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hold_time
                        
                        	Configures hold time
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Suppress address updates on an interface
                        	**type**\: bool
                        
                        .. attribute:: split_horizon
                        
                        	Perform split horizon
                        	**type**\: bool
                        
                        .. attribute:: stub_site
                        
                        	Stub\-Site
                        	**type**\:  :py:class:`StubSite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.StubSite>`
                        
                        .. attribute:: authentication
                        
                        	authentication subcommands
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication>`
                        
                        .. attribute:: summary_address
                        
                        	
                        	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.SummaryAddress>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface, self).__init__()

                            self.yang_name = "af-interface"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("stub-site", ("stub_site", Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.StubSite)), ("authentication", ("authentication", Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication)), ("summary-address", ("summary_address", Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.SummaryAddress))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('bandwidth_percent', (YLeaf(YType.uint32, 'bandwidth-percent'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('split_horizon', (YLeaf(YType.boolean, 'split-horizon'), ['bool'])),
                            ])
                            self.name = None
                            self.bandwidth_percent = None
                            self.hello_interval = None
                            self.hold_time = None
                            self.passive_interface = None
                            self.split_horizon = None

                            self.stub_site = Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.StubSite()
                            self.stub_site.parent = self
                            self._children_name_map["stub_site"] = "stub-site"

                            self.authentication = Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.summary_address = Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.SummaryAddress()
                            self.summary_address.parent = self
                            self._children_name_map["summary_address"] = "summary-address"
                            self._segment_path = lambda: "af-interface" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface, ['name', 'bandwidth_percent', 'hello_interval', 'hold_time', 'passive_interface', 'split_horizon'], name, value)


                        class StubSite(Entity):
                            """
                            Stub\-Site
                            
                            .. attribute:: wan_interface
                            
                            	Wan Interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.StubSite, self).__init__()

                                self.yang_name = "stub-site"
                                self.yang_parent_name = "af-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wan_interface', (YLeaf(YType.empty, 'wan-interface'), ['Empty'])),
                                ])
                                self.wan_interface = None
                                self._segment_path = lambda: "stub-site"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.StubSite, ['wan_interface'], name, value)


                        class Authentication(Entity):
                            """
                            authentication subcommands
                            
                            .. attribute:: mode
                            
                            	authentication mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication.Mode>`
                            
                            .. attribute:: key_chain
                            
                            	key\-chain
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "af-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mode", ("mode", Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication.Mode))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.mode = Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication.Mode()
                                self.mode.parent = self
                                self._children_name_map["mode"] = "mode"
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication, ['key_chain'], name, value)


                            class Mode(Entity):
                                """
                                authentication mode
                                
                                .. attribute:: md5
                                
                                	Keyed message digest
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: hmac_sha_256
                                
                                	HMAC\-SHA\-256 Authentication
                                	**type**\:  :py:class:`HmacSha256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication.Mode.HmacSha256>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication.Mode, self).__init__()

                                    self.yang_name = "mode"
                                    self.yang_parent_name = "authentication"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hmac-sha-256", ("hmac_sha_256", Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication.Mode.HmacSha256))])
                                    self._leafs = OrderedDict([
                                        ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ])
                                    self.md5 = None

                                    self.hmac_sha_256 = Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication.Mode.HmacSha256()
                                    self.hmac_sha_256.parent = self
                                    self._children_name_map["hmac_sha_256"] = "hmac-sha-256"
                                    self._segment_path = lambda: "mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication.Mode, ['md5'], name, value)


                                class HmacSha256(Entity):
                                    """
                                    HMAC\-SHA\-256 Authentication
                                    
                                    .. attribute:: auth_type
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: auth_key
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication.Mode.HmacSha256, self).__init__()

                                        self.yang_name = "hmac-sha-256"
                                        self.yang_parent_name = "mode"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                            ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                        ])
                                        self.auth_type = None
                                        self.auth_key = None
                                        self._segment_path = lambda: "hmac-sha-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.Authentication.Mode.HmacSha256, ['auth_type', 'auth_key'], name, value)


                        class SummaryAddress(Entity):
                            """
                            
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.SummaryAddress, self).__init__()

                                self.yang_name = "summary-address"
                                self.yang_parent_name = "af-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.address = None
                                self.mask = None
                                self._segment_path = lambda: "summary-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.AfInterface.SummaryAddress, ['address', 'mask'], name, value)


                    class SetAsInSubmode(Entity):
                        """
                        
                        
                        .. attribute:: autonomous_system
                        
                        	Specify Address\-Family Autonomous System Number?
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.SetAsInSubmode, self).__init__()

                            self.yang_name = "set-as-in-submode"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('autonomous_system', (YLeaf(YType.uint16, 'autonomous-system'), ['int'])),
                            ])
                            self.autonomous_system = None
                            self._segment_path = lambda: "set-as-in-submode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.SetAsInSubmode, ['autonomous_system'], name, value)


                    class Bfd(Entity):
                        """
                        BFD configuration commands
                        
                        .. attribute:: all_interfaces
                        
                        	Enable BFD on all interfaces
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: interface
                        
                        	Enable BFD on specific interface
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface))])
                            self._leafs = OrderedDict([
                                ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                            ])
                            self.all_interfaces = None

                            self.interface = Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd, ['all_interfaces'], name, value)


                        class Interface(Entity):
                            """
                            Enable BFD on specific interface
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "bfd"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Bfd.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Control distribution of default information
                        
                        .. attribute:: in_
                        
                        	Accept input default routing information
                        	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation.In>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: out
                        
                        	Accept output default routing information
                        	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation.Out>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("in", ("in_", Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation.In)), ("out", ("out", Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation.Out))])
                            self._leafs = OrderedDict()

                            self.in_ = None
                            self._children_name_map["in_"] = "in"

                            self.out = None
                            self._children_name_map["out"] = "out"
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation, [], name, value)


                        class In(Entity):
                            """
                            Accept input default routing information
                            
                            .. attribute:: sa_num
                            
                            	A standard expanded IP access list number
                            	**type**\: int
                            
                            	**range:** 1300..1999
                            
                            .. attribute:: sa_name
                            
                            	Standard Access\-list name
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation.In, self).__init__()

                                self.yang_name = "in"
                                self.yang_parent_name = "default-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('sa_num', (YLeaf(YType.uint16, 'sa-num'), ['int'])),
                                    ('sa_name', (YLeaf(YType.str, 'sa-name'), ['str'])),
                                ])
                                self.sa_num = None
                                self.sa_name = None
                                self._segment_path = lambda: "in"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation.In, ['sa_num', 'sa_name'], name, value)


                        class Out(Entity):
                            """
                            Accept output default routing information
                            
                            .. attribute:: sa_out_num
                            
                            	A standard expanded IP access list number
                            	**type**\: int
                            
                            	**range:** 1300..1999
                            
                            .. attribute:: sa_out_name
                            
                            	Standard Access\-list name
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation.Out, self).__init__()

                                self.yang_name = "out"
                                self.yang_parent_name = "default-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('sa_out_num', (YLeaf(YType.uint16, 'sa-out-num'), ['int'])),
                                    ('sa_out_name', (YLeaf(YType.str, 'sa-out-name'), ['str'])),
                                ])
                                self.sa_out_num = None
                                self.sa_out_name = None
                                self._segment_path = lambda: "out"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultInformation.Out, ['sa_out_num', 'sa_out_name'], name, value)


                    class DefaultMetric(Entity):
                        """
                        Set metric of redistributed routes
                        
                        .. attribute:: dm_rdr
                        
                        	
                        	**type**\: list of  		 :py:class:`DmRdr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric.DmRdr>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric, self).__init__()

                            self.yang_name = "default-metric"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dm-rdr", ("dm_rdr", Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric.DmRdr))])
                            self._leafs = OrderedDict()

                            self.dm_rdr = YList(self)
                            self._segment_path = lambda: "default-metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric, [], name, value)


                        class DmRdr(Entity):
                            """
                            
                            
                            .. attribute:: dm_rdr  (key)
                            
                            	Bandwidth in Kbits per second
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: dm_rdr0
                            
                            	
                            	**type**\: list of  		 :py:class:`DmRdr0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric.DmRdr.DmRdr0>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric.DmRdr, self).__init__()

                                self.yang_name = "dm-rdr"
                                self.yang_parent_name = "default-metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['dm_rdr']
                                self._child_classes = OrderedDict([("dm-rdr0", ("dm_rdr0", Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric.DmRdr.DmRdr0))])
                                self._leafs = OrderedDict([
                                    ('dm_rdr', (YLeaf(YType.uint32, 'dm-rdr'), ['int'])),
                                ])
                                self.dm_rdr = None

                                self.dm_rdr0 = YList(self)
                                self._segment_path = lambda: "dm-rdr" + "[dm-rdr='" + str(self.dm_rdr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric.DmRdr, ['dm_rdr'], name, value)


                            class DmRdr0(Entity):
                                """
                                
                                
                                .. attribute:: dm_rdr0  (key)
                                
                                	delay metric in 10 microsecond units
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dm_rdr_pct
                                
                                	Reliability metric where 255 is 100% reliable
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric.DmRdr.DmRdr0, self).__init__()

                                    self.yang_name = "dm-rdr0"
                                    self.yang_parent_name = "dm-rdr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['dm_rdr0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dm_rdr0', (YLeaf(YType.uint32, 'dm-rdr0'), ['int'])),
                                        ('dm_rdr_pct', (YLeaf(YType.uint8, 'dm-rdr-pct'), ['int'])),
                                    ])
                                    self.dm_rdr0 = None
                                    self.dm_rdr_pct = None
                                    self._segment_path = lambda: "dm-rdr0" + "[dm-rdr0='" + str(self.dm_rdr0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DefaultMetric.DmRdr.DmRdr0, ['dm_rdr0', 'dm_rdr_pct'], name, value)


                    class Distance(Entity):
                        """
                        Define an administrative distance
                        
                        .. attribute:: rad_dis
                        
                        	
                        	**type**\: list of  		 :py:class:`RadDis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Distance.RadDis>`
                        
                        .. attribute:: eigrp
                        
                        	Set distance for internal and external routes
                        	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Distance.Eigrp_>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rad-dis", ("rad_dis", Native.Router.Eigrp.AddressFamily.AfIpList.Distance.RadDis)), ("eigrp", ("eigrp", Native.Router.Eigrp.AddressFamily.AfIpList.Distance.Eigrp_))])
                            self._leafs = OrderedDict()

                            self.eigrp = Native.Router.Eigrp.AddressFamily.AfIpList.Distance.Eigrp_()
                            self.eigrp.parent = self
                            self._children_name_map["eigrp"] = "eigrp"

                            self.rad_dis = YList(self)
                            self._segment_path = lambda: "distance"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Distance, [], name, value)


                        class RadDis(Entity):
                            """
                            
                            
                            .. attribute:: rad_dis  (key)
                            
                            	Set route administrative distance
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Distance.RadDis.Ipv4>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Distance.RadDis, self).__init__()

                                self.yang_name = "rad-dis"
                                self.yang_parent_name = "distance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['rad_dis']
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Eigrp.AddressFamily.AfIpList.Distance.RadDis.Ipv4))])
                                self._leafs = OrderedDict([
                                    ('rad_dis', (YLeaf(YType.uint8, 'rad-dis'), ['int'])),
                                ])
                                self.rad_dis = None

                                self.ipv4 = YList(self)
                                self._segment_path = lambda: "rad-dis" + "[rad-dis='" + str(self.rad_dis) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Distance.RadDis, ['rad_dis'], name, value)


                            class Ipv4(Entity):
                                """
                                
                                
                                .. attribute:: ipv4  (key)
                                
                                	IP Source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv40
                                
                                	Wildcard bits
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Distance.RadDis.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "rad-dis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv4']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv40', (YLeaf(YType.str, 'ipv40'), ['str'])),
                                    ])
                                    self.ipv4 = None
                                    self.ipv40 = None
                                    self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Distance.RadDis.Ipv4, ['ipv4', 'ipv40'], name, value)


                        class Eigrp_(Entity):
                            """
                            Set distance for internal and external routes
                            
                            .. attribute:: di_rt
                            
                            	
                            	**type**\: list of  		 :py:class:`DiRt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Distance.Eigrp_.DiRt>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Distance.Eigrp_, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "distance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("di-rt", ("di_rt", Native.Router.Eigrp.AddressFamily.AfIpList.Distance.Eigrp_.DiRt))])
                                self._leafs = OrderedDict()

                                self.di_rt = YList(self)
                                self._segment_path = lambda: "eigrp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Distance.Eigrp_, [], name, value)


                            class DiRt(Entity):
                                """
                                
                                
                                .. attribute:: di_rt  (key)
                                
                                	Distance for internal routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: di_rt0
                                
                                	Distance for external routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Distance.Eigrp_.DiRt, self).__init__()

                                    self.yang_name = "di-rt"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['di_rt']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('di_rt', (YLeaf(YType.uint8, 'di-rt'), ['int'])),
                                        ('di_rt0', (YLeaf(YType.uint8, 'di-rt0'), ['int'])),
                                    ])
                                    self.di_rt = None
                                    self.di_rt0 = None
                                    self._segment_path = lambda: "di-rt" + "[di-rt='" + str(self.di_rt) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Distance.Eigrp_.DiRt, ['di_rt', 'di_rt0'], name, value)


                    class DistributeList(Entity):
                        """
                        Filter entries in eigrp updates
                        
                        .. attribute:: eig_filt
                        
                        	
                        	**type**\: list of  		 :py:class:`EigFilt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt>`
                        
                        .. attribute:: gateway
                        
                        	Filtering incoming address updates based on gateway
                        	**type**\:  :py:class:`Gateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Gateway>`
                        
                        .. attribute:: prefix
                        
                        	Filter prefixes in address updates
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Prefix>`
                        
                        .. attribute:: route_map
                        
                        	Filter prefixes based on the route\-map
                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.RouteMap>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList, self).__init__()

                            self.yang_name = "distribute-list"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("eig-filt", ("eig_filt", Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt)), ("gateway", ("gateway", Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Gateway)), ("prefix", ("prefix", Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Prefix)), ("route-map", ("route_map", Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.RouteMap))])
                            self._leafs = OrderedDict()

                            self.gateway = Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Gateway()
                            self.gateway.parent = self
                            self._children_name_map["gateway"] = "gateway"

                            self.prefix = Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.route_map = Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.RouteMap()
                            self.route_map.parent = self
                            self._children_name_map["route_map"] = "route-map"

                            self.eig_filt = YList(self)
                            self._segment_path = lambda: "distribute-list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList, [], name, value)


                        class EigFilt(Entity):
                            """
                            
                            
                            .. attribute:: eig_filt  (key)
                            
                            	IP expanded access list number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	Filter incoming service updates
                            	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt.In>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: out
                            
                            	Filter outgoing service updates
                            	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt.Out>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt, self).__init__()

                                self.yang_name = "eig-filt"
                                self.yang_parent_name = "distribute-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['eig_filt']
                                self._child_classes = OrderedDict([("in", ("in_", Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt.In)), ("out", ("out", Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt.Out))])
                                self._leafs = OrderedDict([
                                    ('eig_filt', (YLeaf(YType.str, 'eig-filt'), ['int','str'])),
                                ])
                                self.eig_filt = None

                                self.in_ = None
                                self._children_name_map["in_"] = "in"

                                self.out = None
                                self._children_name_map["out"] = "out"
                                self._segment_path = lambda: "eig-filt" + "[eig-filt='" + str(self.eig_filt) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt, ['eig_filt'], name, value)


                            class In(Entity):
                                """
                                Filter incoming service updates
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: list of str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt.In, self).__init__()

                                    self.yang_name = "in"
                                    self.yang_parent_name = "eig-filt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeafList(YType.str, 'interface_name'), ['str'])),
                                    ])
                                    self.interface_name = []
                                    self._segment_path = lambda: "in"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt.In, ['interface_name'], name, value)


                            class Out(Entity):
                                """
                                Filter outgoing service updates
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: list of str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt.Out, self).__init__()

                                    self.yang_name = "out"
                                    self.yang_parent_name = "eig-filt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeafList(YType.str, 'interface_name'), ['str'])),
                                    ])
                                    self.interface_name = []
                                    self._segment_path = lambda: "out"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.EigFilt.Out, ['interface_name'], name, value)


                        class Gateway(Entity):
                            """
                            Filtering incoming address updates based on gateway
                            
                            .. attribute:: gw_list
                            
                            	
                            	**type**\: list of  		 :py:class:`GwList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Gateway.GwList>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Gateway, self).__init__()

                                self.yang_name = "gateway"
                                self.yang_parent_name = "distribute-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("gw-list", ("gw_list", Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Gateway.GwList))])
                                self._leafs = OrderedDict()

                                self.gw_list = YList(self)
                                self._segment_path = lambda: "gateway"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Gateway, [], name, value)


                            class GwList(Entity):
                                """
                                
                                
                                .. attribute:: gw_list  (key)
                                
                                	Name of an IP prefix\-list
                                	**type**\: str
                                
                                .. attribute:: in_
                                
                                	Filter incoming service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Filter outgoing service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Gateway.GwList, self).__init__()

                                    self.yang_name = "gw-list"
                                    self.yang_parent_name = "gateway"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['gw_list']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('gw_list', (YLeaf(YType.str, 'gw-list'), ['str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.gw_list = None
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "gw-list" + "[gw-list='" + str(self.gw_list) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Gateway.GwList, ['gw_list', 'in_', 'out'], name, value)


                        class Prefix(Entity):
                            """
                            Filter prefixes in address updates
                            
                            .. attribute:: pl_name
                            
                            	
                            	**type**\: list of  		 :py:class:`PlName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Prefix.PlName>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "distribute-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pl-name", ("pl_name", Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Prefix.PlName))])
                                self._leafs = OrderedDict()

                                self.pl_name = YList(self)
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Prefix, [], name, value)


                            class PlName(Entity):
                                """
                                
                                
                                .. attribute:: pl_name  (key)
                                
                                	Name of an IP prefix\-list
                                	**type**\: str
                                
                                .. attribute:: gateway
                                
                                	Filtering incoming address updates based on gateway
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: in_
                                
                                	Filter incoming service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Filter outgoing service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Prefix.PlName, self).__init__()

                                    self.yang_name = "pl-name"
                                    self.yang_parent_name = "prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['pl_name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pl_name', (YLeaf(YType.str, 'pl-name'), ['str'])),
                                        ('gateway', (YLeaf(YType.empty, 'gateway'), ['Empty'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.pl_name = None
                                    self.gateway = None
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "pl-name" + "[pl-name='" + str(self.pl_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.Prefix.PlName, ['pl_name', 'gateway', 'in_', 'out'], name, value)


                        class RouteMap(Entity):
                            """
                            Filter prefixes based on the route\-map
                            
                            .. attribute:: rmap_name
                            
                            	
                            	**type**\: list of  		 :py:class:`RmapName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.RouteMap.RmapName>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.RouteMap, self).__init__()

                                self.yang_name = "route-map"
                                self.yang_parent_name = "distribute-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rmap-name", ("rmap_name", Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.RouteMap.RmapName))])
                                self._leafs = OrderedDict()

                                self.rmap_name = YList(self)
                                self._segment_path = lambda: "route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.RouteMap, [], name, value)


                            class RmapName(Entity):
                                """
                                
                                
                                .. attribute:: rmap_name  (key)
                                
                                	route\-map name
                                	**type**\: str
                                
                                .. attribute:: in_
                                
                                	Filter incoming service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Filter outgoing service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.RouteMap.RmapName, self).__init__()

                                    self.yang_name = "rmap-name"
                                    self.yang_parent_name = "route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['rmap_name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rmap_name', (YLeaf(YType.str, 'rmap-name'), ['str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.rmap_name = None
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "rmap-name" + "[rmap-name='" + str(self.rmap_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.DistributeList.RouteMap.RmapName, ['rmap_name', 'in_', 'out'], name, value)


                    class Eigrp_(Entity):
                        """
                        EIGRP Address Family specific commands
                        
                        .. attribute:: router_id
                        
                        	router id for this EIGRP process
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: stub
                        
                        	Set address\-family in stubbed mode
                        	**type**\:  :py:class:`Stub <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Eigrp_.Stub>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: stub_site
                        
                        	ASN\:nn, Dotted\-Decimal\:nn or 4BASN\:nn  Stub\-Site ID in aa\:nn format
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Eigrp_, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("stub", ("stub", Native.Router.Eigrp.AddressFamily.AfIpList.Eigrp_.Stub))])
                            self._leafs = OrderedDict([
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('stub_site', (YLeaf(YType.str, 'stub-site'), ['str'])),
                            ])
                            self.router_id = None
                            self.stub_site = None

                            self.stub = None
                            self._children_name_map["stub"] = "stub"
                            self._segment_path = lambda: "eigrp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Eigrp_, ['router_id', 'stub_site'], name, value)


                        class Stub(Entity):
                            """
                            Set address\-family in stubbed mode
                            
                            .. attribute:: connected
                            
                            	Do advertise connected routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: summary
                            
                            	Do advertise summary routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redistributed
                            
                            	Do advertise redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: leak_map
                            
                            	Allow dynamic prefixes based on the leak\-map
                            	**type**\: str
                            
                            .. attribute:: receive_only
                            
                            	Set receive only neighbor
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: static
                            
                            	Do advertise static routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Eigrp_.Stub, self).__init__()

                                self.yang_name = "stub"
                                self.yang_parent_name = "eigrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('connected', (YLeaf(YType.empty, 'connected'), ['Empty'])),
                                    ('summary', (YLeaf(YType.empty, 'summary'), ['Empty'])),
                                    ('redistributed', (YLeaf(YType.empty, 'redistributed'), ['Empty'])),
                                    ('leak_map', (YLeaf(YType.str, 'leak-map'), ['str'])),
                                    ('receive_only', (YLeaf(YType.empty, 'receive-only'), ['Empty'])),
                                    ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ])
                                self.connected = None
                                self.summary = None
                                self.redistributed = None
                                self.leak_map = None
                                self.receive_only = None
                                self.static = None
                                self._segment_path = lambda: "stub"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Eigrp_.Stub, ['connected', 'summary', 'redistributed', 'leak_map', 'receive_only', 'static'], name, value)


                    class Metric(Entity):
                        """
                        Modify metrics and parameters for advertisement
                        
                        .. attribute:: maximum_hops
                        
                        	Hop count
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weights
                        
                        	Type (Only TOS 0 supported)
                        	**type**\: int
                        
                        	**range:** 0..8
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('maximum_hops', (YLeaf(YType.uint8, 'maximum-hops'), ['int'])),
                                ('weights', (YLeaf(YType.uint8, 'weights'), ['int'])),
                            ])
                            self.maximum_hops = None
                            self.weights = None
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Metric, ['maximum_hops', 'weights'], name, value)


                    class Neighbor(Entity):
                        """
                        Specify a neighbor router
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4))])
                            self._leafs = OrderedDict()

                            self.ipv4 = YList(self)
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor, [], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	Neighbor address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface
                            
                            	Specify interface for global address
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([("interface", ("interface", Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface))])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ])
                                self.ipv4 = None

                                self.interface = Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4, ['ipv4'], name, value)


                            class Interface(Entity):
                                """
                                Specify interface for global address
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Neighbor.Ipv4.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                    class Network(Entity):
                        """
                        Enable routing on an IP network
                        
                        .. attribute:: number  (key)
                        
                        	Network number
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: wild_card
                        
                        	EIGRP wild card bits
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                ('wild_card', (YLeaf(YType.str, 'wild-card'), ['str'])),
                            ])
                            self.number = None
                            self.wild_card = None
                            self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Network, ['number', 'wild_card'], name, value)


                    class OffsetList(Entity):
                        """
                        Add or subtract offset from EIGRP metrics
                        
                        .. attribute:: nsr_list
                        
                        	
                        	**type**\: list of  		 :py:class:`NsrList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList.NsrList>`
                        
                        .. attribute:: ol_acl
                        
                        	
                        	**type**\: list of  		 :py:class:`OlAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList.OlAcl>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList, self).__init__()

                            self.yang_name = "offset-list"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nsr-list", ("nsr_list", Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList.NsrList)), ("ol-acl", ("ol_acl", Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList.OlAcl))])
                            self._leafs = OrderedDict()

                            self.nsr_list = YList(self)
                            self.ol_acl = YList(self)
                            self._segment_path = lambda: "offset-list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList, [], name, value)


                        class NsrList(Entity):
                            """
                            
                            
                            .. attribute:: nsr_list  (key)
                            
                            	Access list of networks to apply offset (extended range)
                            	**type**\: int
                            
                            	**range:** 1300..1999
                            
                            .. attribute:: in_
                            
                            	Perform offset on incoming updates
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Perform offset on outgoing updates
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList.NsrList, self).__init__()

                                self.yang_name = "nsr-list"
                                self.yang_parent_name = "offset-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['nsr_list']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nsr_list', (YLeaf(YType.uint16, 'nsr-list'), ['int'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.nsr_list = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "nsr-list" + "[nsr-list='" + str(self.nsr_list) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList.NsrList, ['nsr_list', 'in_', 'out'], name, value)


                        class OlAcl(Entity):
                            """
                            
                            
                            .. attribute:: ol_acl  (key)
                            
                            	Access\-list name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Perform offset on incoming updates
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Perform offset on outgoing updates
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList.OlAcl, self).__init__()

                                self.yang_name = "ol-acl"
                                self.yang_parent_name = "offset-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ol_acl']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ol_acl', (YLeaf(YType.str, 'ol-acl'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.ol_acl = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "ol-acl" + "[ol-acl='" + str(self.ol_acl) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.OffsetList.OlAcl, ['ol_acl', 'in_', 'out'], name, value)


                    class Redistribute(Entity):
                        """
                        Redistribute IPv4 routes from another routing protocol
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Connected>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	Autonomous system number
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Isis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: lisp
                        
                        	Locator ID Separation Protocol (LISP)
                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Lisp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: mobile
                        
                        	Mobile routes
                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Mobile>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: odr
                        
                        	On Demand stub Routes
                        	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Odr>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ospf
                        
                        	Process ID
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Rip>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Static>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: vrf
                        
                        	Specify a source virtual routing/forwarding instance
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute, self).__init__()

                            self.yang_name = "redistribute"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Bgp)), ("connected", ("connected", Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Connected)), ("isis", ("isis", Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Lisp)), ("mobile", ("mobile", Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Odr)), ("rip", ("rip", Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Rip)), ("static", ("static", Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Static)), ("vrf", ("vrf", Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Vrf))])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('ospf', (YLeaf(YType.uint16, 'ospf'), ['int'])),
                            ])
                            self.eigrp = None
                            self.ospf = None

                            self.connected = None
                            self._children_name_map["connected"] = "connected"

                            self.isis = None
                            self._children_name_map["isis"] = "isis"

                            self.lisp = None
                            self._children_name_map["lisp"] = "lisp"

                            self.mobile = None
                            self._children_name_map["mobile"] = "mobile"

                            self.odr = None
                            self._children_name_map["odr"] = "odr"

                            self.rip = None
                            self._children_name_map["rip"] = "rip"

                            self.static = None
                            self._children_name_map["static"] = "static"

                            self.vrf = Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.bgp = YList(self)
                            self._segment_path = lambda: "redistribute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute, ['eigrp', 'ospf'], name, value)


                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: rdr_as  (key)
                            
                            	Autonomous system number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Bgp.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: rd_lesser_1_period_0_xx_period_yy_greater_
                            
                            	Autonomous system number
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['rdr_as']
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Bgp.Metric))])
                                self._leafs = OrderedDict([
                                    ('rdr_as', (YLeaf(YType.str, 'rdr-as'), ['int','str'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('rd_lesser_1_period_0_xx_period_yy_greater_', (YLeaf(YType.empty, 'rd-LESSER_1_PERIOD_0-XX_PERIOD_YY_GREATER_'), ['Empty'])),
                                ])
                                self.rdr_as = None
                                self.route_map = None
                                self.rd_lesser_1_period_0_xx_period_yy_greater_ = None

                                self.metric = Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Bgp.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "bgp" + "[rdr-as='" + str(self.rdr_as) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Bgp, ['rdr_as', 'route_map', 'rd_lesser_1_period_0_xx_period_yy_greater_'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: bandwith
                                
                                	Bandwidth metric in Kbits per second
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: delay
                                
                                	EIGRP delay metric, in 10 microsecond units
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reliability
                                
                                	EIGRP reliability metric where 255 is 100% reliable
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: effective
                                
                                	EIGRP Effective bandwidth metric (Loading) where 255 is 100% loaded
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: mtu
                                
                                	EIGRP MTU of the path
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Bgp.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bandwith', (YLeaf(YType.uint32, 'bandwith'), ['int'])),
                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                        ('reliability', (YLeaf(YType.uint8, 'reliability'), ['int'])),
                                        ('effective', (YLeaf(YType.uint8, 'Effective'), ['int'])),
                                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                                    ])
                                    self.bandwith = None
                                    self.delay = None
                                    self.reliability = None
                                    self.effective = None
                                    self.mtu = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Bgp.Metric, ['bandwith', 'delay', 'reliability', 'effective', 'mtu'], name, value)


                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "connected"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Connected, ['metric', 'route_map'], name, value)


                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: is_tag
                            
                            	ISO routing area tag
                            	**type**\: str
                            
                            .. attribute:: level_1
                            
                            	IS\-IS level\-1 routes only
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: level_1_2
                            
                            	IS\-IS level\-1 and level\-2 routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: level_2
                            
                            	IS\-IS level\-2 routes only
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('is_tag', (YLeaf(YType.str, 'is-tag'), ['str'])),
                                    ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                                    ('level_1_2', (YLeaf(YType.empty, 'level-1-2'), ['Empty'])),
                                    ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.is_tag = None
                                self.level_1 = None
                                self.level_1_2 = None
                                self.level_2 = None
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "isis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Isis, ['is_tag', 'level_1', 'level_1_2', 'level_2', 'metric', 'route_map'], name, value)


                        class Lisp(Entity):
                            """
                            Locator ID Separation Protocol (LISP)
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Lisp, self).__init__()

                                self.yang_name = "lisp"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "lisp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Lisp, ['metric', 'route_map'], name, value)


                        class Mobile(Entity):
                            """
                            Mobile routes
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Mobile, self).__init__()

                                self.yang_name = "mobile"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "mobile"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                        class Odr(Entity):
                            """
                            On Demand stub Routes
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Odr, self).__init__()

                                self.yang_name = "odr"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "odr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Odr, ['metric', 'route_map'], name, value)


                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "rip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Rip, ['metric', 'route_map'], name, value)


                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Static, ['metric', 'route_map'], name, value)


                        class Vrf(Entity):
                            """
                            Specify a source virtual routing/forwarding instance
                            
                            .. attribute:: name
                            
                            	Virtual Routing/Forwarding instance name
                            	**type**\: str
                            
                            .. attribute:: global_
                            
                            	global VRF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                                ])
                                self.name = None
                                self.global_ = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Redistribute.Vrf, ['name', 'global_'], name, value)


                    class SummaryMetric(Entity):
                        """
                        Specify summary to apply metric/filtering
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.SummaryMetric.Ipv4>`
                        
                        .. attribute:: a_period_b_period_c_period_d_slash_nn
                        
                        	Summary <network>/<length>, e.g., 192.168.0.0/16
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.SummaryMetric, self).__init__()

                            self.yang_name = "summary-metric"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Eigrp.AddressFamily.AfIpList.SummaryMetric.Ipv4))])
                            self._leafs = OrderedDict([
                                ('a_period_b_period_c_period_d_slash_nn', (YLeaf(YType.empty, 'A_PERIOD_B_PERIOD_C_PERIOD_D_SLASH_nn'), ['Empty'])),
                            ])
                            self.a_period_b_period_c_period_d_slash_nn = None

                            self.ipv4 = YList(self)
                            self._segment_path = lambda: "summary-metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.SummaryMetric, ['a_period_b_period_c_period_d_slash_nn'], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	Summary to configure static metric
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	Network mask
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.SummaryMetric.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "summary-metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.mask = None
                                self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.SummaryMetric.Ipv4, ['ipv4', 'mask'], name, value)


                    class Timers(Entity):
                        """
                        Adjust routing timers
                        
                        .. attribute:: active_time
                        
                        	time limit for active state
                        	**type**\:  :py:class:`ActiveTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Timers.ActiveTime>`
                        
                        .. attribute:: graceful_restart
                        
                        	EIGRP Graceful Restart timer
                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Timers.GracefulRestart>`
                        
                        .. attribute:: nsf
                        
                        	EIGRP NSF timer
                        	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Timers.Nsf>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("active-time", ("active_time", Native.Router.Eigrp.AddressFamily.AfIpList.Timers.ActiveTime)), ("graceful-restart", ("graceful_restart", Native.Router.Eigrp.AddressFamily.AfIpList.Timers.GracefulRestart)), ("nsf", ("nsf", Native.Router.Eigrp.AddressFamily.AfIpList.Timers.Nsf))])
                            self._leafs = OrderedDict()

                            self.active_time = Native.Router.Eigrp.AddressFamily.AfIpList.Timers.ActiveTime()
                            self.active_time.parent = self
                            self._children_name_map["active_time"] = "active-time"

                            self.graceful_restart = Native.Router.Eigrp.AddressFamily.AfIpList.Timers.GracefulRestart()
                            self.graceful_restart.parent = self
                            self._children_name_map["graceful_restart"] = "graceful-restart"

                            self.nsf = Native.Router.Eigrp.AddressFamily.AfIpList.Timers.Nsf()
                            self.nsf.parent = self
                            self._children_name_map["nsf"] = "nsf"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Timers, [], name, value)


                        class ActiveTime(Entity):
                            """
                            time limit for active state
                            
                            .. attribute:: atimer
                            
                            	active state time limit in minutes
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disabled
                            
                            	disable time limit for active state
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Timers.ActiveTime, self).__init__()

                                self.yang_name = "active-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atimer', (YLeaf(YType.uint16, 'atimer'), ['int'])),
                                    ('disabled', (YLeaf(YType.empty, 'disabled'), ['Empty'])),
                                ])
                                self.atimer = None
                                self.disabled = None
                                self._segment_path = lambda: "active-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Timers.ActiveTime, ['atimer', 'disabled'], name, value)


                        class GracefulRestart(Entity):
                            """
                            EIGRP Graceful Restart timer
                            
                            .. attribute:: purge_time
                            
                            	EIGRP stale route purge time
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Timers.GracefulRestart, self).__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('purge_time', (YLeaf(YType.empty, 'purge-time'), ['Empty'])),
                                ])
                                self.purge_time = None
                                self._segment_path = lambda: "graceful-restart"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Timers.GracefulRestart, ['purge_time'], name, value)


                        class Nsf(Entity):
                            """
                            EIGRP NSF timer
                            
                            .. attribute:: converge
                            
                            	EIGRP time limit for convergence after switchover
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: signal
                            
                            	EIGRP time limit for signaling NSF restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Timers.Nsf, self).__init__()

                                self.yang_name = "nsf"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('converge', (YLeaf(YType.empty, 'converge'), ['Empty'])),
                                    ('signal', (YLeaf(YType.empty, 'signal'), ['Empty'])),
                                ])
                                self.converge = None
                                self.signal = None
                                self._segment_path = lambda: "nsf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Timers.Nsf, ['converge', 'signal'], name, value)


                    class TrafficShare(Entity):
                        """
                        How to compute traffic share over alternate paths
                        
                        .. attribute:: balanced
                        
                        	Share inversely proportional to metric
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: min
                        
                        	All traffic shared among min metric paths
                        	**type**\:  :py:class:`Min <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.TrafficShare.Min>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.TrafficShare, self).__init__()

                            self.yang_name = "traffic-share"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("min", ("min", Native.Router.Eigrp.AddressFamily.AfIpList.TrafficShare.Min))])
                            self._leafs = OrderedDict([
                                ('balanced', (YLeaf(YType.empty, 'balanced'), ['Empty'])),
                            ])
                            self.balanced = None

                            self.min = Native.Router.Eigrp.AddressFamily.AfIpList.TrafficShare.Min()
                            self.min.parent = self
                            self._children_name_map["min"] = "min"
                            self._segment_path = lambda: "traffic-share"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.TrafficShare, ['balanced'], name, value)


                        class Min(Entity):
                            """
                            All traffic shared among min metric paths
                            
                            .. attribute:: across_interfaces
                            
                            	Use different interfaces for equal\-cost paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.TrafficShare.Min, self).__init__()

                                self.yang_name = "min"
                                self.yang_parent_name = "traffic-share"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                                ])
                                self.across_interfaces = None
                                self._segment_path = lambda: "min"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.TrafficShare.Min, ['across_interfaces'], name, value)


                    class Topology(Entity):
                        """
                        Topology configuration mode
                        
                        .. attribute:: base
                        
                        	Base Topology
                        	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "af-ip-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("base", ("base", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base))])
                            self._leafs = OrderedDict()

                            self.base = None
                            self._children_name_map["base"] = "base"
                            self._segment_path = lambda: "topology"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology, [], name, value)


                        class Base(Entity):
                            """
                            Base Topology
                            
                            .. attribute:: distance
                            
                            	Define an administrative distance
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance>`
                            
                            .. attribute:: distribute_list
                            
                            	Filter entries in eigrp updates
                            	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList>`
                            
                            .. attribute:: redistribute
                            
                            	Redistribute IPv6 prefixes from another routing protocol
                            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute>`
                            
                            .. attribute:: summary_metric
                            
                            	Specify summary to apply metric/filtering
                            	**type**\: list of  		 :py:class:`SummaryMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.SummaryMetric>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("distance", ("distance", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance)), ("distribute-list", ("distribute_list", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList)), ("redistribute", ("redistribute", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute)), ("summary-metric", ("summary_metric", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.SummaryMetric))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.distance = Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.distribute_list = Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList()
                                self.distribute_list.parent = self
                                self._children_name_map["distribute_list"] = "distribute-list"

                                self.redistribute = Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute()
                                self.redistribute.parent = self
                                self._children_name_map["redistribute"] = "redistribute"

                                self.summary_metric = YList(self)
                                self._segment_path = lambda: "base"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base, [], name, value)


                            class Distance(Entity):
                                """
                                Define an administrative distance
                                
                                .. attribute:: eigrp
                                
                                	EIGRP\-IPV6 distance
                                	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance.Eigrp_>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "base"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance.Eigrp_))])
                                    self._leafs = OrderedDict()

                                    self.eigrp = Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance.Eigrp_()
                                    self.eigrp.parent = self
                                    self._children_name_map["eigrp"] = "eigrp"
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance, [], name, value)


                                class Eigrp_(Entity):
                                    """
                                    EIGRP\-IPV6 distance
                                    
                                    .. attribute:: distance_list
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`DistanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance.Eigrp_.DistanceList>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance.Eigrp_, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("distance-list", ("distance_list", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance.Eigrp_.DistanceList))])
                                        self._leafs = OrderedDict()

                                        self.distance_list = YList(self)
                                        self._segment_path = lambda: "eigrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance.Eigrp_, [], name, value)


                                    class DistanceList(Entity):
                                        """
                                        
                                        
                                        .. attribute:: internal_route  (key)
                                        
                                        	Distance for internal routes
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: external_route
                                        
                                        	Distance for external routes
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-eigrp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance.Eigrp_.DistanceList, self).__init__()

                                            self.yang_name = "distance-list"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['internal_route']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('internal_route', (YLeaf(YType.uint8, 'internal-route'), ['int'])),
                                                ('external_route', (YLeaf(YType.uint8, 'external-route'), ['int'])),
                                            ])
                                            self.internal_route = None
                                            self.external_route = None
                                            self._segment_path = lambda: "distance-list" + "[internal-route='" + str(self.internal_route) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Distance.Eigrp_.DistanceList, ['internal_route', 'external_route'], name, value)


                            class DistributeList(Entity):
                                """
                                Filter entries in eigrp updates
                                
                                .. attribute:: prefix_list
                                
                                	Filter prefixes in address updates
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList.PrefixList>`
                                
                                .. attribute:: route_map
                                
                                	Filter prefixes based on the route\-map
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList.RouteMap>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList, self).__init__()

                                    self.yang_name = "distribute-list"
                                    self.yang_parent_name = "base"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("prefix-list", ("prefix_list", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList.PrefixList)), ("route-map", ("route_map", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList.RouteMap))])
                                    self._leafs = OrderedDict()

                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "distribute-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList, [], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter prefixes in address updates
                                    
                                    .. attribute:: prefix_list  (key)
                                    
                                    	Name of an IP prefix\-list
                                    	**type**\: str
                                    
                                    .. attribute:: gateway
                                    
                                    	Filtering incoming address updates based on gateway
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: in_
                                    
                                    	Filter incoming service updates
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: out
                                    
                                    	Filter outgoing service updates
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "distribute-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix_list']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ('gateway', (YLeaf(YType.empty, 'gateway'), ['Empty'])),
                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                            ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                        ])
                                        self.prefix_list = None
                                        self.gateway = None
                                        self.in_ = None
                                        self.out = None
                                        self._segment_path = lambda: "prefix-list" + "[prefix-list='" + str(self.prefix_list) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList.PrefixList, ['prefix_list', 'gateway', 'in_', 'out'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Filter prefixes based on the route\-map
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: in_
                                    
                                    	Filter incoming service updates
                                    	**type**\: str
                                    
                                    .. attribute:: out
                                    
                                    	Filter outgoing service updates
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "distribute-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                                            ('out', (YLeaf(YType.str, 'out'), ['str'])),
                                        ])
                                        self.name = None
                                        self.in_ = None
                                        self.out = None
                                        self._segment_path = lambda: "route-map" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.DistributeList.RouteMap, ['name', 'in_', 'out'], name, value)


                            class Redistribute(Entity):
                                """
                                Redistribute IPv6 prefixes from another routing protocol
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Eigrp_>`
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPFv3)
                                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Ospf>`
                                
                                .. attribute:: connected
                                
                                	Connected Routes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: static
                                
                                	Static Routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Static>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute, self).__init__()

                                    self.yang_name = "redistribute"
                                    self.yang_parent_name = "base"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Eigrp_)), ("ospf", ("ospf", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Ospf)), ("static", ("static", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Static))])
                                    self._leafs = OrderedDict([
                                        ('connected', (YLeaf(YType.empty, 'connected'), ['Empty'])),
                                    ])
                                    self.connected = None

                                    self.eigrp = Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Eigrp_()
                                    self.eigrp.parent = self
                                    self._children_name_map["eigrp"] = "eigrp"

                                    self.ospf = Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Ospf()
                                    self.ospf.parent = self
                                    self._children_name_map["ospf"] = "ospf"

                                    self.static = None
                                    self._children_name_map["static"] = "static"
                                    self._segment_path = lambda: "redistribute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute, ['connected'], name, value)


                                class Eigrp_(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: as_list
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`AsList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Eigrp_.AsList>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Eigrp_, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("as-list", ("as_list", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Eigrp_.AsList))])
                                        self._leafs = OrderedDict()

                                        self.as_list = YList(self)
                                        self._segment_path = lambda: "eigrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Eigrp_, [], name, value)


                                    class AsList(Entity):
                                        """
                                        
                                        
                                        .. attribute:: autonomous_system  (key)
                                        
                                        	Autonomous system number
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-eigrp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Eigrp_.AsList, self).__init__()

                                            self.yang_name = "as-list"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['autonomous_system']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('autonomous_system', (YLeaf(YType.uint16, 'autonomous-system'), ['int'])),
                                            ])
                                            self.autonomous_system = None
                                            self._segment_path = lambda: "as-list" + "[autonomous-system='" + str(self.autonomous_system) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Eigrp_.AsList, ['autonomous_system'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPFv3)
                                    
                                    .. attribute:: pid_list
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PidList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Ospf.PidList>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("pid-list", ("pid_list", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Ospf.PidList))])
                                        self._leafs = OrderedDict()

                                        self.pid_list = YList(self)
                                        self._segment_path = lambda: "ospf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Ospf, [], name, value)


                                    class PidList(Entity):
                                        """
                                        
                                        
                                        .. attribute:: process_id  (key)
                                        
                                        	Process ID
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-eigrp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Ospf.PidList, self).__init__()

                                            self.yang_name = "pid-list"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['process_id']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('process_id', (YLeaf(YType.uint16, 'process-id'), ['int'])),
                                            ])
                                            self.process_id = None
                                            self._segment_path = lambda: "pid-list" + "[process-id='" + str(self.process_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Ospf.PidList, ['process_id'], name, value)


                                class Static(Entity):
                                    """
                                    Static Routes
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.Redistribute.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True


                            class SummaryMetric(Entity):
                                """
                                Specify summary to apply metric/filtering
                                
                                .. attribute:: ipv4_addr_slash_prefix_len  (key)
                                
                                	Summary <network>/<length>, e.g., 192.168.0.0/16
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                .. attribute:: metric
                                
                                	
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.SummaryMetric.Metric>`
                                
                                .. attribute:: distance
                                
                                	Set administrative distance for summary route
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.SummaryMetric, self).__init__()

                                    self.yang_name = "summary-metric"
                                    self.yang_parent_name = "base"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv4_addr_slash_prefix_len']
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.SummaryMetric.Metric))])
                                    self._leafs = OrderedDict([
                                        ('ipv4_addr_slash_prefix_len', (YLeaf(YType.str, 'ipv4-addr-slash-prefix-len'), ['str'])),
                                        ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ])
                                    self.ipv4_addr_slash_prefix_len = None
                                    self.distance = None

                                    self.metric = Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.SummaryMetric.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "summary-metric" + "[ipv4-addr-slash-prefix-len='" + str(self.ipv4_addr_slash_prefix_len) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.SummaryMetric, ['ipv4_addr_slash_prefix_len', 'distance'], name, value)


                                class Metric(Entity):
                                    """
                                    
                                    
                                    .. attribute:: bandwidth_metric
                                    
                                    	Bandwidth metric in Kbits per second
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: delay_metric
                                    
                                    	delay metric in 10 microsecond units
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: reliability_metric
                                    
                                    	reliability metric where 255 is 100% reliable
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: effective_bandwidth_metric
                                    
                                    	Effective bandwidth metric (Loading) where 255 is 100% loaded
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU of the path
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.SummaryMetric.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "summary-metric"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bandwidth_metric', (YLeaf(YType.uint32, 'bandwidth-metric'), ['int'])),
                                            ('delay_metric', (YLeaf(YType.uint32, 'delay-metric'), ['int'])),
                                            ('reliability_metric', (YLeaf(YType.uint8, 'reliability-metric'), ['int'])),
                                            ('effective_bandwidth_metric', (YLeaf(YType.uint8, 'effective-bandwidth-metric'), ['int'])),
                                            ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                                        ])
                                        self.bandwidth_metric = None
                                        self.delay_metric = None
                                        self.reliability_metric = None
                                        self.effective_bandwidth_metric = None
                                        self.mtu = None
                                        self._segment_path = lambda: "metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpList.Topology.Base.SummaryMetric.Metric, ['bandwidth_metric', 'delay_metric', 'reliability_metric', 'effective_bandwidth_metric', 'mtu'], name, value)


                class AfIpVrfList(Entity):
                    """
                    Address family IPv4/IPv6 VRF
                    
                    .. attribute:: vrf  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: unicast_multicast
                    
                    	
                    	**type**\:  :py:class:`UnicastMulticast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.UnicastMulticast>`
                    
                    .. attribute:: autonomous_system
                    
                    	Specify Address\-Family Autonomous System Number?
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: af_interface
                    
                    	Enter Address Family interface configuration
                    	**type**\: list of  		 :py:class:`AfInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface>`
                    
                    .. attribute:: set_as_in_submode
                    
                    	
                    	**type**\:  :py:class:`SetAsInSubmode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.SetAsInSubmode>`
                    
                    .. attribute:: auto_summary
                    
                    	Enable automatic network number summarization
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bfd
                    
                    	BFD configuration commands
                    	**type**\:  :py:class:`Bfd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd>`
                    
                    .. attribute:: default_information
                    
                    	Control distribution of default information
                    	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation>`
                    
                    .. attribute:: default_metric
                    
                    	Set metric of redistributed routes
                    	**type**\:  :py:class:`DefaultMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric>`
                    
                    .. attribute:: distance
                    
                    	Define an administrative distance
                    	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance>`
                    
                    .. attribute:: distribute_list
                    
                    	Filter entries in eigrp updates
                    	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList>`
                    
                    .. attribute:: eigrp
                    
                    	EIGRP Address Family specific commands
                    	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Eigrp_>`
                    
                    .. attribute:: maximum_paths
                    
                    	Number of paths
                    	**type**\: int
                    
                    	**range:** 1..32
                    
                    .. attribute:: metric
                    
                    	Modify metrics and parameters for advertisement
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Metric>`
                    
                    .. attribute:: neighbor
                    
                    	Specify a neighbor router
                    	**type**\:  :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor>`
                    
                    .. attribute:: network
                    
                    	Enable routing on an IP network
                    	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Network>`
                    
                    .. attribute:: nsf
                    
                    	Non\-stop forwarding
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: offset_list
                    
                    	Add or subtract offset from EIGRP metrics
                    	**type**\:  :py:class:`OffsetList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList>`
                    
                    .. attribute:: redistribute
                    
                    	Redistribute IPv4 routes from another routing protocol
                    	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this instance of EIGRP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: summary_metric
                    
                    	Specify summary to apply metric/filtering
                    	**type**\:  :py:class:`SummaryMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.SummaryMetric>`
                    
                    .. attribute:: timers
                    
                    	Adjust routing timers
                    	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers>`
                    
                    .. attribute:: traffic_share
                    
                    	How to compute traffic share over alternate paths
                    	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.TrafficShare>`
                    
                    .. attribute:: variance
                    
                    	Metric variance multiplier
                    	**type**\: int
                    
                    	**range:** 1..128
                    
                    .. attribute:: topology
                    
                    	Topology configuration mode
                    	**type**\:  :py:class:`Topology <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList, self).__init__()

                        self.yang_name = "af-ip-vrf-list"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vrf']
                        self._child_classes = OrderedDict([("af-interface", ("af_interface", Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface)), ("set-as-in-submode", ("set_as_in_submode", Native.Router.Eigrp.AddressFamily.AfIpVrfList.SetAsInSubmode)), ("bfd", ("bfd", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd)), ("default-information", ("default_information", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation)), ("default-metric", ("default_metric", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric)), ("distance", ("distance", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance)), ("distribute-list", ("distribute_list", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList)), ("eigrp", ("eigrp", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Eigrp_)), ("metric", ("metric", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Metric)), ("neighbor", ("neighbor", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor)), ("network", ("network", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Network)), ("offset-list", ("offset_list", Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList)), ("redistribute", ("redistribute", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute)), ("summary-metric", ("summary_metric", Native.Router.Eigrp.AddressFamily.AfIpVrfList.SummaryMetric)), ("timers", ("timers", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers)), ("traffic-share", ("traffic_share", Native.Router.Eigrp.AddressFamily.AfIpVrfList.TrafficShare)), ("topology", ("topology", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology))])
                        self._leafs = OrderedDict([
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ('unicast_multicast', (YLeaf(YType.enumeration, 'unicast-multicast'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Eigrp.AddressFamily.AfIpVrfList.UnicastMulticast')])),
                            ('autonomous_system', (YLeaf(YType.uint16, 'autonomous-system'), ['int'])),
                            ('auto_summary', (YLeaf(YType.empty, 'auto-summary'), ['Empty'])),
                            ('maximum_paths', (YLeaf(YType.uint8, 'maximum-paths'), ['int'])),
                            ('nsf', (YLeaf(YType.empty, 'nsf'), ['Empty'])),
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('variance', (YLeaf(YType.uint8, 'variance'), ['int'])),
                        ])
                        self.vrf = None
                        self.unicast_multicast = None
                        self.autonomous_system = None
                        self.auto_summary = None
                        self.maximum_paths = None
                        self.nsf = None
                        self.shutdown = None
                        self.variance = None

                        self.set_as_in_submode = Native.Router.Eigrp.AddressFamily.AfIpVrfList.SetAsInSubmode()
                        self.set_as_in_submode.parent = self
                        self._children_name_map["set_as_in_submode"] = "set-as-in-submode"

                        self.bfd = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd()
                        self.bfd.parent = self
                        self._children_name_map["bfd"] = "bfd"

                        self.default_information = Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"

                        self.default_metric = Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric()
                        self.default_metric.parent = self
                        self._children_name_map["default_metric"] = "default-metric"

                        self.distance = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"

                        self.distribute_list = Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList()
                        self.distribute_list.parent = self
                        self._children_name_map["distribute_list"] = "distribute-list"

                        self.eigrp = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Eigrp_()
                        self.eigrp.parent = self
                        self._children_name_map["eigrp"] = "eigrp"

                        self.metric = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"

                        self.neighbor = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor()
                        self.neighbor.parent = self
                        self._children_name_map["neighbor"] = "neighbor"

                        self.offset_list = Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList()
                        self.offset_list.parent = self
                        self._children_name_map["offset_list"] = "offset-list"

                        self.redistribute = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute()
                        self.redistribute.parent = self
                        self._children_name_map["redistribute"] = "redistribute"

                        self.summary_metric = Native.Router.Eigrp.AddressFamily.AfIpVrfList.SummaryMetric()
                        self.summary_metric.parent = self
                        self._children_name_map["summary_metric"] = "summary-metric"

                        self.timers = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"

                        self.traffic_share = Native.Router.Eigrp.AddressFamily.AfIpVrfList.TrafficShare()
                        self.traffic_share.parent = self
                        self._children_name_map["traffic_share"] = "traffic-share"

                        self.topology = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology()
                        self.topology.parent = self
                        self._children_name_map["topology"] = "topology"

                        self.af_interface = YList(self)
                        self.network = YList(self)
                        self._segment_path = lambda: "af-ip-vrf-list" + "[vrf='" + str(self.vrf) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList, ['vrf', 'unicast_multicast', 'autonomous_system', 'auto_summary', 'maximum_paths', 'nsf', 'shutdown', 'variance'], name, value)

                    class UnicastMulticast(Enum):
                        """
                        UnicastMulticast (Enum Class)

                        .. data:: unicast = 0

                        .. data:: multicast = 1

                        """

                        unicast = Enum.YLeaf(0, "unicast")

                        multicast = Enum.YLeaf(1, "multicast")



                    class AfInterface(Entity):
                        """
                        Enter Address Family interface configuration
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: bandwidth_percent
                        
                        	Set percentage of bandwidth percentage limit
                        	**type**\: int
                        
                        	**range:** 1..999999
                        
                        .. attribute:: hello_interval
                        
                        	Configures hello interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hold_time
                        
                        	Configures hold time
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Suppress address updates on an interface
                        	**type**\: bool
                        
                        .. attribute:: split_horizon
                        
                        	Perform split horizon
                        	**type**\: bool
                        
                        .. attribute:: stub_site
                        
                        	Stub\-Site
                        	**type**\:  :py:class:`StubSite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.StubSite>`
                        
                        .. attribute:: authentication
                        
                        	authentication subcommands
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication>`
                        
                        .. attribute:: summary_address
                        
                        	
                        	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.SummaryAddress>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface, self).__init__()

                            self.yang_name = "af-interface"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("stub-site", ("stub_site", Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.StubSite)), ("authentication", ("authentication", Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication)), ("summary-address", ("summary_address", Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.SummaryAddress))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('bandwidth_percent', (YLeaf(YType.uint32, 'bandwidth-percent'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('split_horizon', (YLeaf(YType.boolean, 'split-horizon'), ['bool'])),
                            ])
                            self.name = None
                            self.bandwidth_percent = None
                            self.hello_interval = None
                            self.hold_time = None
                            self.passive_interface = None
                            self.split_horizon = None

                            self.stub_site = Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.StubSite()
                            self.stub_site.parent = self
                            self._children_name_map["stub_site"] = "stub-site"

                            self.authentication = Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.summary_address = Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.SummaryAddress()
                            self.summary_address.parent = self
                            self._children_name_map["summary_address"] = "summary-address"
                            self._segment_path = lambda: "af-interface" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface, ['name', 'bandwidth_percent', 'hello_interval', 'hold_time', 'passive_interface', 'split_horizon'], name, value)


                        class StubSite(Entity):
                            """
                            Stub\-Site
                            
                            .. attribute:: wan_interface
                            
                            	Wan Interface
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.StubSite, self).__init__()

                                self.yang_name = "stub-site"
                                self.yang_parent_name = "af-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wan_interface', (YLeaf(YType.empty, 'wan-interface'), ['Empty'])),
                                ])
                                self.wan_interface = None
                                self._segment_path = lambda: "stub-site"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.StubSite, ['wan_interface'], name, value)


                        class Authentication(Entity):
                            """
                            authentication subcommands
                            
                            .. attribute:: mode
                            
                            	authentication mode
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication.Mode>`
                            
                            .. attribute:: key_chain
                            
                            	key\-chain
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "af-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mode", ("mode", Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication.Mode))])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ])
                                self.key_chain = None

                                self.mode = Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication.Mode()
                                self.mode.parent = self
                                self._children_name_map["mode"] = "mode"
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication, ['key_chain'], name, value)


                            class Mode(Entity):
                                """
                                authentication mode
                                
                                .. attribute:: md5
                                
                                	Keyed message digest
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: hmac_sha_256
                                
                                	HMAC\-SHA\-256 Authentication
                                	**type**\:  :py:class:`HmacSha256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication.Mode.HmacSha256>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication.Mode, self).__init__()

                                    self.yang_name = "mode"
                                    self.yang_parent_name = "authentication"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hmac-sha-256", ("hmac_sha_256", Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication.Mode.HmacSha256))])
                                    self._leafs = OrderedDict([
                                        ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                                    ])
                                    self.md5 = None

                                    self.hmac_sha_256 = Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication.Mode.HmacSha256()
                                    self.hmac_sha_256.parent = self
                                    self._children_name_map["hmac_sha_256"] = "hmac-sha-256"
                                    self._segment_path = lambda: "mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication.Mode, ['md5'], name, value)


                                class HmacSha256(Entity):
                                    """
                                    HMAC\-SHA\-256 Authentication
                                    
                                    .. attribute:: auth_type
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: auth_key
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication.Mode.HmacSha256, self).__init__()

                                        self.yang_name = "hmac-sha-256"
                                        self.yang_parent_name = "mode"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                            ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                        ])
                                        self.auth_type = None
                                        self.auth_key = None
                                        self._segment_path = lambda: "hmac-sha-256"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.Authentication.Mode.HmacSha256, ['auth_type', 'auth_key'], name, value)


                        class SummaryAddress(Entity):
                            """
                            
                            
                            .. attribute:: address
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.SummaryAddress, self).__init__()

                                self.yang_name = "summary-address"
                                self.yang_parent_name = "af-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.address = None
                                self.mask = None
                                self._segment_path = lambda: "summary-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.AfInterface.SummaryAddress, ['address', 'mask'], name, value)


                    class SetAsInSubmode(Entity):
                        """
                        
                        
                        .. attribute:: autonomous_system
                        
                        	Specify Address\-Family Autonomous System Number?
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.SetAsInSubmode, self).__init__()

                            self.yang_name = "set-as-in-submode"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('autonomous_system', (YLeaf(YType.uint16, 'autonomous-system'), ['int'])),
                            ])
                            self.autonomous_system = None
                            self._segment_path = lambda: "set-as-in-submode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.SetAsInSubmode, ['autonomous_system'], name, value)


                    class Bfd(Entity):
                        """
                        BFD configuration commands
                        
                        .. attribute:: all_interfaces
                        
                        	Enable BFD on all interfaces
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: interface
                        
                        	Enable BFD on specific interface
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface))])
                            self._leafs = OrderedDict([
                                ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                            ])
                            self.all_interfaces = None

                            self.interface = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._segment_path = lambda: "bfd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd, ['all_interfaces'], name, value)


                        class Interface(Entity):
                            """
                            Enable BFD on specific interface
                            
                            .. attribute:: appnav_compress
                            
                            	Service\-Context Virtual Interface Compress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: appnav_uncompress
                            
                            	Service\-Context Virtual Interface UnCompress
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: atm
                            
                            	ATM interface
                            	**type**\: str
                            
                            .. attribute:: atm_subinterface
                            
                            	
                            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.ATMSubinterface>`
                            
                            .. attribute:: atm_acr
                            
                            	ATM\-ACR interface
                            	**type**\: str
                            
                            	**pattern:** [0\-9]
                            
                            .. attribute:: atm_acrsubinterface
                            
                            	
                            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.ATMACRsubinterface>`
                            
                            .. attribute:: bdi
                            
                            	Bridge\-Domain interface
                            	**type**\: str
                            
                            .. attribute:: cem
                            
                            	CEM interface
                            	**type**\: str
                            
                            	**pattern:** ([0\-9]/){2}[0\-9]
                            
                            .. attribute:: cem_acr
                            
                            	CEM\-ACR interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: embedded_service_engine
                            
                            	cisco embedded service engine module
                            	**type**\: str
                            
                            .. attribute:: ethernet
                            
                            	IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: fastethernet
                            
                            	FastEthernet IEEE 802.3
                            	**type**\: str
                            
                            .. attribute:: gigabitethernet
                            
                            	GigabitEthernet IEEE 802.3z
                            	**type**\: str
                            
                            .. attribute:: fivegigabitethernet
                            
                            	Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twentyfivegige
                            
                            	Twenty Five GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: twogigabitethernet
                            
                            	Two GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: fortygigabitethernet
                            
                            	Forty GigabitEthernet 
                            	**type**\: str
                            
                            .. attribute:: hundredgige
                            
                            	Hundred GigabitEthernet
                            	**type**\: str
                            
                            .. attribute:: lisp
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\: str
                            
                            .. attribute:: lisp_subinterface
                            
                            	Locator/ID Separation Protocol Virtual Interface
                            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.LISPSubinterface>`
                            
                            .. attribute:: loopback
                            
                            	Loopback interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multilink
                            
                            	Multilink\-group interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nve
                            
                            	Network virtualization endpoint interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: overlay
                            
                            	Overlay interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_channel
                            
                            	Ethernet Channel of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: port_channel_subinterface
                            
                            	
                            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.PortChannelSubinterface>`
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire Interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sm
                            
                            	SM Interface
                            	**type**\: str
                            
                            .. attribute:: cellular
                            
                            	Cellular Interface
                            	**type**\: str
                            
                            .. attribute:: serial
                            
                            	Serial interface
                            	**type**\: str
                            
                            .. attribute:: tengigabitethernet
                            
                            	Ten Gigabit Ethernet
                            	**type**\: str
                            
                            .. attribute:: tunnel
                            
                            	Tunnel interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_template
                            
                            	Virtual Template interface
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan
                            
                            	Iosxr Vlans
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtualportgroup
                            
                            	Virtual Port Group
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasileft
                            
                            	vasileft
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vasiright
                            
                            	vasiright
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "bfd"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.PortChannelSubinterface))])
                                self._leafs = OrderedDict([
                                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                ])
                                self.appnav_compress = None
                                self.appnav_uncompress = None
                                self.atm = None
                                self.atm_acr = None
                                self.bdi = None
                                self.cem = None
                                self.cem_acr = None
                                self.embedded_service_engine = None
                                self.ethernet = None
                                self.fastethernet = None
                                self.gigabitethernet = None
                                self.fivegigabitethernet = None
                                self.twentyfivegige = None
                                self.twogigabitethernet = None
                                self.fortygigabitethernet = None
                                self.hundredgige = None
                                self.lisp = None
                                self.loopback = None
                                self.multilink = None
                                self.nve = None
                                self.overlay = None
                                self.port_channel = None
                                self.pseudowire = None
                                self.sm = None
                                self.cellular = None
                                self.serial = None
                                self.tengigabitethernet = None
                                self.tunnel = None
                                self.virtual_template = None
                                self.vlan = None
                                self.virtualportgroup = None
                                self.vasileft = None
                                self.vasiright = None

                                self.atm_subinterface = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.ATMSubinterface()
                                self.atm_subinterface.parent = self
                                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                self.atm_acrsubinterface = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.ATMACRsubinterface()
                                self.atm_acrsubinterface.parent = self
                                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                self.lisp_subinterface = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.LISPSubinterface()
                                self.lisp_subinterface.parent = self
                                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                self.port_channel_subinterface = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.PortChannelSubinterface()
                                self.port_channel_subinterface.parent = self
                                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                self._segment_path = lambda: "interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                            class ATMSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.ATMSubinterface, self).__init__()

                                    self.yang_name = "ATM-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                    ])
                                    self.atm = None
                                    self._segment_path = lambda: "ATM-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.ATMSubinterface, [u'atm'], name, value)


                            class ATMACRsubinterface(Entity):
                                """
                                
                                
                                .. attribute:: atm_acr
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.ATMACRsubinterface, self).__init__()

                                    self.yang_name = "ATM-ACRsubinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                    ])
                                    self.atm_acr = None
                                    self._segment_path = lambda: "ATM-ACRsubinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                            class LISPSubinterface(Entity):
                                """
                                Locator/ID Separation Protocol Virtual Interface
                                
                                .. attribute:: lisp
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.LISPSubinterface, self).__init__()

                                    self.yang_name = "LISP-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                    ])
                                    self.lisp = None
                                    self._segment_path = lambda: "LISP-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.LISPSubinterface, [u'lisp'], name, value)


                            class PortChannelSubinterface(Entity):
                                """
                                
                                
                                .. attribute:: port_channel
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.PortChannelSubinterface, self).__init__()

                                    self.yang_name = "Port-channel-subinterface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                    ])
                                    self.port_channel = None
                                    self._segment_path = lambda: "Port-channel-subinterface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Bfd.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Control distribution of default information
                        
                        .. attribute:: in_
                        
                        	Accept input default routing information
                        	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation.In>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: out
                        
                        	Accept output default routing information
                        	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation.Out>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("in", ("in_", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation.In)), ("out", ("out", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation.Out))])
                            self._leafs = OrderedDict()

                            self.in_ = None
                            self._children_name_map["in_"] = "in"

                            self.out = None
                            self._children_name_map["out"] = "out"
                            self._segment_path = lambda: "default-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation, [], name, value)


                        class In(Entity):
                            """
                            Accept input default routing information
                            
                            .. attribute:: sa_num
                            
                            	A standard expanded IP access list number
                            	**type**\: int
                            
                            	**range:** 1300..1999
                            
                            .. attribute:: sa_name
                            
                            	Standard Access\-list name
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation.In, self).__init__()

                                self.yang_name = "in"
                                self.yang_parent_name = "default-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('sa_num', (YLeaf(YType.uint16, 'sa-num'), ['int'])),
                                    ('sa_name', (YLeaf(YType.str, 'sa-name'), ['str'])),
                                ])
                                self.sa_num = None
                                self.sa_name = None
                                self._segment_path = lambda: "in"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation.In, ['sa_num', 'sa_name'], name, value)


                        class Out(Entity):
                            """
                            Accept output default routing information
                            
                            .. attribute:: sa_out_num
                            
                            	A standard expanded IP access list number
                            	**type**\: int
                            
                            	**range:** 1300..1999
                            
                            .. attribute:: sa_out_name
                            
                            	Standard Access\-list name
                            	**type**\: str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation.Out, self).__init__()

                                self.yang_name = "out"
                                self.yang_parent_name = "default-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('sa_out_num', (YLeaf(YType.uint16, 'sa-out-num'), ['int'])),
                                    ('sa_out_name', (YLeaf(YType.str, 'sa-out-name'), ['str'])),
                                ])
                                self.sa_out_num = None
                                self.sa_out_name = None
                                self._segment_path = lambda: "out"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultInformation.Out, ['sa_out_num', 'sa_out_name'], name, value)


                    class DefaultMetric(Entity):
                        """
                        Set metric of redistributed routes
                        
                        .. attribute:: dm_rdr
                        
                        	
                        	**type**\: list of  		 :py:class:`DmRdr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric.DmRdr>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric, self).__init__()

                            self.yang_name = "default-metric"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dm-rdr", ("dm_rdr", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric.DmRdr))])
                            self._leafs = OrderedDict()

                            self.dm_rdr = YList(self)
                            self._segment_path = lambda: "default-metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric, [], name, value)


                        class DmRdr(Entity):
                            """
                            
                            
                            .. attribute:: dm_rdr  (key)
                            
                            	Bandwidth in Kbits per second
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: dm_rdr0
                            
                            	
                            	**type**\: list of  		 :py:class:`DmRdr0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric.DmRdr.DmRdr0>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric.DmRdr, self).__init__()

                                self.yang_name = "dm-rdr"
                                self.yang_parent_name = "default-metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['dm_rdr']
                                self._child_classes = OrderedDict([("dm-rdr0", ("dm_rdr0", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric.DmRdr.DmRdr0))])
                                self._leafs = OrderedDict([
                                    ('dm_rdr', (YLeaf(YType.uint32, 'dm-rdr'), ['int'])),
                                ])
                                self.dm_rdr = None

                                self.dm_rdr0 = YList(self)
                                self._segment_path = lambda: "dm-rdr" + "[dm-rdr='" + str(self.dm_rdr) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric.DmRdr, ['dm_rdr'], name, value)


                            class DmRdr0(Entity):
                                """
                                
                                
                                .. attribute:: dm_rdr0  (key)
                                
                                	delay metric in 10 microsecond units
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dm_rdr_pct
                                
                                	Reliability metric where 255 is 100% reliable
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric.DmRdr.DmRdr0, self).__init__()

                                    self.yang_name = "dm-rdr0"
                                    self.yang_parent_name = "dm-rdr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['dm_rdr0']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dm_rdr0', (YLeaf(YType.uint32, 'dm-rdr0'), ['int'])),
                                        ('dm_rdr_pct', (YLeaf(YType.uint8, 'dm-rdr-pct'), ['int'])),
                                    ])
                                    self.dm_rdr0 = None
                                    self.dm_rdr_pct = None
                                    self._segment_path = lambda: "dm-rdr0" + "[dm-rdr0='" + str(self.dm_rdr0) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DefaultMetric.DmRdr.DmRdr0, ['dm_rdr0', 'dm_rdr_pct'], name, value)


                    class Distance(Entity):
                        """
                        Define an administrative distance
                        
                        .. attribute:: rad_dis
                        
                        	
                        	**type**\: list of  		 :py:class:`RadDis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.RadDis>`
                        
                        .. attribute:: eigrp
                        
                        	Set distance for internal and external routes
                        	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.Eigrp_>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rad-dis", ("rad_dis", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.RadDis)), ("eigrp", ("eigrp", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.Eigrp_))])
                            self._leafs = OrderedDict()

                            self.eigrp = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.Eigrp_()
                            self.eigrp.parent = self
                            self._children_name_map["eigrp"] = "eigrp"

                            self.rad_dis = YList(self)
                            self._segment_path = lambda: "distance"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance, [], name, value)


                        class RadDis(Entity):
                            """
                            
                            
                            .. attribute:: rad_dis  (key)
                            
                            	Set route administrative distance
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: ipv4
                            
                            	
                            	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.RadDis.Ipv4>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.RadDis, self).__init__()

                                self.yang_name = "rad-dis"
                                self.yang_parent_name = "distance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['rad_dis']
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.RadDis.Ipv4))])
                                self._leafs = OrderedDict([
                                    ('rad_dis', (YLeaf(YType.uint8, 'rad-dis'), ['int'])),
                                ])
                                self.rad_dis = None

                                self.ipv4 = YList(self)
                                self._segment_path = lambda: "rad-dis" + "[rad-dis='" + str(self.rad_dis) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.RadDis, ['rad_dis'], name, value)


                            class Ipv4(Entity):
                                """
                                
                                
                                .. attribute:: ipv4  (key)
                                
                                	IP Source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv40
                                
                                	Wildcard bits
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.RadDis.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "rad-dis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv4']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv40', (YLeaf(YType.str, 'ipv40'), ['str'])),
                                    ])
                                    self.ipv4 = None
                                    self.ipv40 = None
                                    self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.RadDis.Ipv4, ['ipv4', 'ipv40'], name, value)


                        class Eigrp_(Entity):
                            """
                            Set distance for internal and external routes
                            
                            .. attribute:: di_rt
                            
                            	
                            	**type**\: list of  		 :py:class:`DiRt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.Eigrp_.DiRt>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.Eigrp_, self).__init__()

                                self.yang_name = "eigrp"
                                self.yang_parent_name = "distance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("di-rt", ("di_rt", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.Eigrp_.DiRt))])
                                self._leafs = OrderedDict()

                                self.di_rt = YList(self)
                                self._segment_path = lambda: "eigrp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.Eigrp_, [], name, value)


                            class DiRt(Entity):
                                """
                                
                                
                                .. attribute:: di_rt  (key)
                                
                                	Distance for internal routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: di_rt0
                                
                                	Distance for external routes
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.Eigrp_.DiRt, self).__init__()

                                    self.yang_name = "di-rt"
                                    self.yang_parent_name = "eigrp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['di_rt']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('di_rt', (YLeaf(YType.uint8, 'di-rt'), ['int'])),
                                        ('di_rt0', (YLeaf(YType.uint8, 'di-rt0'), ['int'])),
                                    ])
                                    self.di_rt = None
                                    self.di_rt0 = None
                                    self._segment_path = lambda: "di-rt" + "[di-rt='" + str(self.di_rt) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Distance.Eigrp_.DiRt, ['di_rt', 'di_rt0'], name, value)


                    class DistributeList(Entity):
                        """
                        Filter entries in eigrp updates
                        
                        .. attribute:: eig_filt
                        
                        	
                        	**type**\: list of  		 :py:class:`EigFilt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt>`
                        
                        .. attribute:: gateway
                        
                        	Filtering incoming address updates based on gateway
                        	**type**\:  :py:class:`Gateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Gateway>`
                        
                        .. attribute:: prefix
                        
                        	Filter prefixes in address updates
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Prefix>`
                        
                        .. attribute:: route_map
                        
                        	Filter prefixes based on the route\-map
                        	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.RouteMap>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList, self).__init__()

                            self.yang_name = "distribute-list"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("eig-filt", ("eig_filt", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt)), ("gateway", ("gateway", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Gateway)), ("prefix", ("prefix", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Prefix)), ("route-map", ("route_map", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.RouteMap))])
                            self._leafs = OrderedDict()

                            self.gateway = Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Gateway()
                            self.gateway.parent = self
                            self._children_name_map["gateway"] = "gateway"

                            self.prefix = Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.route_map = Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.RouteMap()
                            self.route_map.parent = self
                            self._children_name_map["route_map"] = "route-map"

                            self.eig_filt = YList(self)
                            self._segment_path = lambda: "distribute-list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList, [], name, value)


                        class EigFilt(Entity):
                            """
                            
                            
                            .. attribute:: eig_filt  (key)
                            
                            	IP expanded access list number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..199 \| 1300..2699
                            
                            		**type**\: str
                            
                            			**pattern:** [a\-zA\-Z].\*
                            
                            .. attribute:: in_
                            
                            	Filter incoming service updates
                            	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt.In>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: out
                            
                            	Filter outgoing service updates
                            	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt.Out>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt, self).__init__()

                                self.yang_name = "eig-filt"
                                self.yang_parent_name = "distribute-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['eig_filt']
                                self._child_classes = OrderedDict([("in", ("in_", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt.In)), ("out", ("out", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt.Out))])
                                self._leafs = OrderedDict([
                                    ('eig_filt', (YLeaf(YType.str, 'eig-filt'), ['int','str'])),
                                ])
                                self.eig_filt = None

                                self.in_ = None
                                self._children_name_map["in_"] = "in"

                                self.out = None
                                self._children_name_map["out"] = "out"
                                self._segment_path = lambda: "eig-filt" + "[eig-filt='" + str(self.eig_filt) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt, ['eig_filt'], name, value)


                            class In(Entity):
                                """
                                Filter incoming service updates
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: list of str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt.In, self).__init__()

                                    self.yang_name = "in"
                                    self.yang_parent_name = "eig-filt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeafList(YType.str, 'interface_name'), ['str'])),
                                    ])
                                    self.interface_name = []
                                    self._segment_path = lambda: "in"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt.In, ['interface_name'], name, value)


                            class Out(Entity):
                                """
                                Filter outgoing service updates
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: list of str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt.Out, self).__init__()

                                    self.yang_name = "out"
                                    self.yang_parent_name = "eig-filt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeafList(YType.str, 'interface_name'), ['str'])),
                                    ])
                                    self.interface_name = []
                                    self._segment_path = lambda: "out"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.EigFilt.Out, ['interface_name'], name, value)


                        class Gateway(Entity):
                            """
                            Filtering incoming address updates based on gateway
                            
                            .. attribute:: gw_list
                            
                            	
                            	**type**\: list of  		 :py:class:`GwList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Gateway.GwList>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Gateway, self).__init__()

                                self.yang_name = "gateway"
                                self.yang_parent_name = "distribute-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("gw-list", ("gw_list", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Gateway.GwList))])
                                self._leafs = OrderedDict()

                                self.gw_list = YList(self)
                                self._segment_path = lambda: "gateway"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Gateway, [], name, value)


                            class GwList(Entity):
                                """
                                
                                
                                .. attribute:: gw_list  (key)
                                
                                	Name of an IP prefix\-list
                                	**type**\: str
                                
                                .. attribute:: in_
                                
                                	Filter incoming service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Filter outgoing service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Gateway.GwList, self).__init__()

                                    self.yang_name = "gw-list"
                                    self.yang_parent_name = "gateway"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['gw_list']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('gw_list', (YLeaf(YType.str, 'gw-list'), ['str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.gw_list = None
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "gw-list" + "[gw-list='" + str(self.gw_list) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Gateway.GwList, ['gw_list', 'in_', 'out'], name, value)


                        class Prefix(Entity):
                            """
                            Filter prefixes in address updates
                            
                            .. attribute:: pl_name
                            
                            	
                            	**type**\: list of  		 :py:class:`PlName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Prefix.PlName>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "distribute-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pl-name", ("pl_name", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Prefix.PlName))])
                                self._leafs = OrderedDict()

                                self.pl_name = YList(self)
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Prefix, [], name, value)


                            class PlName(Entity):
                                """
                                
                                
                                .. attribute:: pl_name  (key)
                                
                                	Name of an IP prefix\-list
                                	**type**\: str
                                
                                .. attribute:: gateway
                                
                                	Filtering incoming address updates based on gateway
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: in_
                                
                                	Filter incoming service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Filter outgoing service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Prefix.PlName, self).__init__()

                                    self.yang_name = "pl-name"
                                    self.yang_parent_name = "prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['pl_name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pl_name', (YLeaf(YType.str, 'pl-name'), ['str'])),
                                        ('gateway', (YLeaf(YType.empty, 'gateway'), ['Empty'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.pl_name = None
                                    self.gateway = None
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "pl-name" + "[pl-name='" + str(self.pl_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.Prefix.PlName, ['pl_name', 'gateway', 'in_', 'out'], name, value)


                        class RouteMap(Entity):
                            """
                            Filter prefixes based on the route\-map
                            
                            .. attribute:: rmap_name
                            
                            	
                            	**type**\: list of  		 :py:class:`RmapName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.RouteMap.RmapName>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.RouteMap, self).__init__()

                                self.yang_name = "route-map"
                                self.yang_parent_name = "distribute-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rmap-name", ("rmap_name", Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.RouteMap.RmapName))])
                                self._leafs = OrderedDict()

                                self.rmap_name = YList(self)
                                self._segment_path = lambda: "route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.RouteMap, [], name, value)


                            class RmapName(Entity):
                                """
                                
                                
                                .. attribute:: rmap_name  (key)
                                
                                	route\-map name
                                	**type**\: str
                                
                                .. attribute:: in_
                                
                                	Filter incoming service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: out
                                
                                	Filter outgoing service updates
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.RouteMap.RmapName, self).__init__()

                                    self.yang_name = "rmap-name"
                                    self.yang_parent_name = "route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['rmap_name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('rmap_name', (YLeaf(YType.str, 'rmap-name'), ['str'])),
                                        ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                        ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                    ])
                                    self.rmap_name = None
                                    self.in_ = None
                                    self.out = None
                                    self._segment_path = lambda: "rmap-name" + "[rmap-name='" + str(self.rmap_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.DistributeList.RouteMap.RmapName, ['rmap_name', 'in_', 'out'], name, value)


                    class Eigrp_(Entity):
                        """
                        EIGRP Address Family specific commands
                        
                        .. attribute:: router_id
                        
                        	router id for this EIGRP process
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: stub
                        
                        	Set address\-family in stubbed mode
                        	**type**\:  :py:class:`Stub <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Eigrp_.Stub>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: stub_site
                        
                        	ASN\:nn, Dotted\-Decimal\:nn or 4BASN\:nn  Stub\-Site ID in aa\:nn format
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Eigrp_, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("stub", ("stub", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Eigrp_.Stub))])
                            self._leafs = OrderedDict([
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('stub_site', (YLeaf(YType.str, 'stub-site'), ['str'])),
                            ])
                            self.router_id = None
                            self.stub_site = None

                            self.stub = None
                            self._children_name_map["stub"] = "stub"
                            self._segment_path = lambda: "eigrp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Eigrp_, ['router_id', 'stub_site'], name, value)


                        class Stub(Entity):
                            """
                            Set address\-family in stubbed mode
                            
                            .. attribute:: connected
                            
                            	Do advertise connected routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: summary
                            
                            	Do advertise summary routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: redistributed
                            
                            	Do advertise redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: leak_map
                            
                            	Allow dynamic prefixes based on the leak\-map
                            	**type**\: str
                            
                            .. attribute:: receive_only
                            
                            	Set receive only neighbor
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: static
                            
                            	Do advertise static routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Eigrp_.Stub, self).__init__()

                                self.yang_name = "stub"
                                self.yang_parent_name = "eigrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('connected', (YLeaf(YType.empty, 'connected'), ['Empty'])),
                                    ('summary', (YLeaf(YType.empty, 'summary'), ['Empty'])),
                                    ('redistributed', (YLeaf(YType.empty, 'redistributed'), ['Empty'])),
                                    ('leak_map', (YLeaf(YType.str, 'leak-map'), ['str'])),
                                    ('receive_only', (YLeaf(YType.empty, 'receive-only'), ['Empty'])),
                                    ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ])
                                self.connected = None
                                self.summary = None
                                self.redistributed = None
                                self.leak_map = None
                                self.receive_only = None
                                self.static = None
                                self._segment_path = lambda: "stub"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Eigrp_.Stub, ['connected', 'summary', 'redistributed', 'leak_map', 'receive_only', 'static'], name, value)


                    class Metric(Entity):
                        """
                        Modify metrics and parameters for advertisement
                        
                        .. attribute:: maximum_hops
                        
                        	Hop count
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: weights
                        
                        	Type (Only TOS 0 supported)
                        	**type**\: int
                        
                        	**range:** 0..8
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('maximum_hops', (YLeaf(YType.uint8, 'maximum-hops'), ['int'])),
                                ('weights', (YLeaf(YType.uint8, 'weights'), ['int'])),
                            ])
                            self.maximum_hops = None
                            self.weights = None
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Metric, ['maximum_hops', 'weights'], name, value)


                    class Neighbor(Entity):
                        """
                        Specify a neighbor router
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4))])
                            self._leafs = OrderedDict()

                            self.ipv4 = YList(self)
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor, [], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	Neighbor address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface
                            
                            	Specify interface for global address
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([("interface", ("interface", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface))])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ])
                                self.ipv4 = None

                                self.interface = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4, ['ipv4'], name, value)


                            class Interface(Entity):
                                """
                                Specify interface for global address
                                
                                .. attribute:: appnav_compress
                                
                                	Service\-Context Virtual Interface Compress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: appnav_uncompress
                                
                                	Service\-Context Virtual Interface UnCompress
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: atm
                                
                                	ATM interface
                                	**type**\: str
                                
                                .. attribute:: atm_subinterface
                                
                                	
                                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.ATMSubinterface>`
                                
                                .. attribute:: atm_acr
                                
                                	ATM\-ACR interface
                                	**type**\: str
                                
                                	**pattern:** [0\-9]
                                
                                .. attribute:: atm_acrsubinterface
                                
                                	
                                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.ATMACRsubinterface>`
                                
                                .. attribute:: bdi
                                
                                	Bridge\-Domain interface
                                	**type**\: str
                                
                                .. attribute:: cem
                                
                                	CEM interface
                                	**type**\: str
                                
                                	**pattern:** ([0\-9]/){2}[0\-9]
                                
                                .. attribute:: cem_acr
                                
                                	CEM\-ACR interface
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: embedded_service_engine
                                
                                	cisco embedded service engine module
                                	**type**\: str
                                
                                .. attribute:: ethernet
                                
                                	IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: fastethernet
                                
                                	FastEthernet IEEE 802.3
                                	**type**\: str
                                
                                .. attribute:: gigabitethernet
                                
                                	GigabitEthernet IEEE 802.3z
                                	**type**\: str
                                
                                .. attribute:: fivegigabitethernet
                                
                                	Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twentyfivegige
                                
                                	Twenty Five GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: twogigabitethernet
                                
                                	Two GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: fortygigabitethernet
                                
                                	Forty GigabitEthernet 
                                	**type**\: str
                                
                                .. attribute:: hundredgige
                                
                                	Hundred GigabitEthernet
                                	**type**\: str
                                
                                .. attribute:: lisp
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\: str
                                
                                .. attribute:: lisp_subinterface
                                
                                	Locator/ID Separation Protocol Virtual Interface
                                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.LISPSubinterface>`
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multilink
                                
                                	Multilink\-group interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nve
                                
                                	Network virtualization endpoint interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: overlay
                                
                                	Overlay interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_channel
                                
                                	Ethernet Channel of interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: port_channel_subinterface
                                
                                	
                                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.PortChannelSubinterface>`
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire Interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sm
                                
                                	SM Interface
                                	**type**\: str
                                
                                .. attribute:: cellular
                                
                                	Cellular Interface
                                	**type**\: str
                                
                                .. attribute:: serial
                                
                                	Serial interface
                                	**type**\: str
                                
                                .. attribute:: tengigabitethernet
                                
                                	Ten Gigabit Ethernet
                                	**type**\: str
                                
                                .. attribute:: tunnel
                                
                                	Tunnel interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_template
                                
                                	Virtual Template interface
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan
                                
                                	Iosxr Vlans
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtualportgroup
                                
                                	Virtual Port Group
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasileft
                                
                                	vasileft
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vasiright
                                
                                	vasiright
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.PortChannelSubinterface))])
                                    self._leafs = OrderedDict([
                                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                                    ])
                                    self.appnav_compress = None
                                    self.appnav_uncompress = None
                                    self.atm = None
                                    self.atm_acr = None
                                    self.bdi = None
                                    self.cem = None
                                    self.cem_acr = None
                                    self.embedded_service_engine = None
                                    self.ethernet = None
                                    self.fastethernet = None
                                    self.gigabitethernet = None
                                    self.fivegigabitethernet = None
                                    self.twentyfivegige = None
                                    self.twogigabitethernet = None
                                    self.fortygigabitethernet = None
                                    self.hundredgige = None
                                    self.lisp = None
                                    self.loopback = None
                                    self.multilink = None
                                    self.nve = None
                                    self.overlay = None
                                    self.port_channel = None
                                    self.pseudowire = None
                                    self.sm = None
                                    self.cellular = None
                                    self.serial = None
                                    self.tengigabitethernet = None
                                    self.tunnel = None
                                    self.virtual_template = None
                                    self.vlan = None
                                    self.virtualportgroup = None
                                    self.vasileft = None
                                    self.vasiright = None

                                    self.atm_subinterface = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.ATMSubinterface()
                                    self.atm_subinterface.parent = self
                                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                                    self.atm_acrsubinterface = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.ATMACRsubinterface()
                                    self.atm_acrsubinterface.parent = self
                                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                                    self.lisp_subinterface = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.LISPSubinterface()
                                    self.lisp_subinterface.parent = self
                                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                                    self.port_channel_subinterface = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.PortChannelSubinterface()
                                    self.port_channel_subinterface.parent = self
                                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                                    self._segment_path = lambda: "interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                                class ATMSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.ATMSubinterface, self).__init__()

                                        self.yang_name = "ATM-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                        ])
                                        self.atm = None
                                        self._segment_path = lambda: "ATM-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.ATMSubinterface, [u'atm'], name, value)


                                class ATMACRsubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: atm_acr
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.ATMACRsubinterface, self).__init__()

                                        self.yang_name = "ATM-ACRsubinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                        ])
                                        self.atm_acr = None
                                        self._segment_path = lambda: "ATM-ACRsubinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                                class LISPSubinterface(Entity):
                                    """
                                    Locator/ID Separation Protocol Virtual Interface
                                    
                                    .. attribute:: lisp
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.LISPSubinterface, self).__init__()

                                        self.yang_name = "LISP-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                        ])
                                        self.lisp = None
                                        self._segment_path = lambda: "LISP-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.LISPSubinterface, [u'lisp'], name, value)


                                class PortChannelSubinterface(Entity):
                                    """
                                    
                                    
                                    .. attribute:: port_channel
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.PortChannelSubinterface, self).__init__()

                                        self.yang_name = "Port-channel-subinterface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                        ])
                                        self.port_channel = None
                                        self._segment_path = lambda: "Port-channel-subinterface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Neighbor.Ipv4.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


                    class Network(Entity):
                        """
                        Enable routing on an IP network
                        
                        .. attribute:: number  (key)
                        
                        	Network number
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: wild_card
                        
                        	EIGRP wild card bits
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Network, self).__init__()

                            self.yang_name = "network"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.str, 'number'), ['str'])),
                                ('wild_card', (YLeaf(YType.str, 'wild-card'), ['str'])),
                            ])
                            self.number = None
                            self.wild_card = None
                            self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Network, ['number', 'wild_card'], name, value)


                    class OffsetList(Entity):
                        """
                        Add or subtract offset from EIGRP metrics
                        
                        .. attribute:: nsr_list
                        
                        	
                        	**type**\: list of  		 :py:class:`NsrList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList.NsrList>`
                        
                        .. attribute:: ol_acl
                        
                        	
                        	**type**\: list of  		 :py:class:`OlAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList.OlAcl>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList, self).__init__()

                            self.yang_name = "offset-list"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nsr-list", ("nsr_list", Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList.NsrList)), ("ol-acl", ("ol_acl", Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList.OlAcl))])
                            self._leafs = OrderedDict()

                            self.nsr_list = YList(self)
                            self.ol_acl = YList(self)
                            self._segment_path = lambda: "offset-list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList, [], name, value)


                        class NsrList(Entity):
                            """
                            
                            
                            .. attribute:: nsr_list  (key)
                            
                            	Access list of networks to apply offset (extended range)
                            	**type**\: int
                            
                            	**range:** 1300..1999
                            
                            .. attribute:: in_
                            
                            	Perform offset on incoming updates
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Perform offset on outgoing updates
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList.NsrList, self).__init__()

                                self.yang_name = "nsr-list"
                                self.yang_parent_name = "offset-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['nsr_list']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nsr_list', (YLeaf(YType.uint16, 'nsr-list'), ['int'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.nsr_list = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "nsr-list" + "[nsr-list='" + str(self.nsr_list) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList.NsrList, ['nsr_list', 'in_', 'out'], name, value)


                        class OlAcl(Entity):
                            """
                            
                            
                            .. attribute:: ol_acl  (key)
                            
                            	Access\-list name
                            	**type**\: str
                            
                            .. attribute:: in_
                            
                            	Perform offset on incoming updates
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: out
                            
                            	Perform offset on outgoing updates
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList.OlAcl, self).__init__()

                                self.yang_name = "ol-acl"
                                self.yang_parent_name = "offset-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ol_acl']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ol_acl', (YLeaf(YType.str, 'ol-acl'), ['str'])),
                                    ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                    ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                ])
                                self.ol_acl = None
                                self.in_ = None
                                self.out = None
                                self._segment_path = lambda: "ol-acl" + "[ol-acl='" + str(self.ol_acl) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.OffsetList.OlAcl, ['ol_acl', 'in_', 'out'], name, value)


                    class Redistribute(Entity):
                        """
                        Redistribute IPv4 routes from another routing protocol
                        
                        .. attribute:: bgp
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Bgp>`
                        
                        .. attribute:: connected
                        
                        	Connected
                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Connected>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: eigrp
                        
                        	Autonomous system number
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: isis
                        
                        	ISO IS\-IS
                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Isis>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: lisp
                        
                        	Locator ID Separation Protocol (LISP)
                        	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Lisp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: mobile
                        
                        	Mobile routes
                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Mobile>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: odr
                        
                        	On Demand stub Routes
                        	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Odr>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ospf
                        
                        	Process ID
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: rip
                        
                        	Routing Information Protocol (RIP)
                        	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Rip>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: static
                        
                        	Static routes
                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Static>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: vrf
                        
                        	Specify a source virtual routing/forwarding instance
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute, self).__init__()

                            self.yang_name = "redistribute"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Bgp)), ("connected", ("connected", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Connected)), ("isis", ("isis", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Lisp)), ("mobile", ("mobile", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Odr)), ("rip", ("rip", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Rip)), ("static", ("static", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Static)), ("vrf", ("vrf", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Vrf))])
                            self._leafs = OrderedDict([
                                ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                                ('ospf', (YLeaf(YType.uint16, 'ospf'), ['int'])),
                            ])
                            self.eigrp = None
                            self.ospf = None

                            self.connected = None
                            self._children_name_map["connected"] = "connected"

                            self.isis = None
                            self._children_name_map["isis"] = "isis"

                            self.lisp = None
                            self._children_name_map["lisp"] = "lisp"

                            self.mobile = None
                            self._children_name_map["mobile"] = "mobile"

                            self.odr = None
                            self._children_name_map["odr"] = "odr"

                            self.rip = None
                            self._children_name_map["rip"] = "rip"

                            self.static = None
                            self._children_name_map["static"] = "static"

                            self.vrf = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.bgp = YList(self)
                            self._segment_path = lambda: "redistribute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute, ['eigrp', 'ospf'], name, value)


                        class Bgp(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: rdr_as  (key)
                            
                            	Autonomous system number
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 1..4294967295
                            
                            		**type**\: str
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Bgp.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: rd_lesser_1_period_0_xx_period_yy_greater_
                            
                            	Autonomous system number
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Bgp, self).__init__()

                                self.yang_name = "bgp"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['rdr_as']
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Bgp.Metric))])
                                self._leafs = OrderedDict([
                                    ('rdr_as', (YLeaf(YType.str, 'rdr-as'), ['int','str'])),
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ('rd_lesser_1_period_0_xx_period_yy_greater_', (YLeaf(YType.empty, 'rd-LESSER_1_PERIOD_0-XX_PERIOD_YY_GREATER_'), ['Empty'])),
                                ])
                                self.rdr_as = None
                                self.route_map = None
                                self.rd_lesser_1_period_0_xx_period_yy_greater_ = None

                                self.metric = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Bgp.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "bgp" + "[rdr-as='" + str(self.rdr_as) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Bgp, ['rdr_as', 'route_map', 'rd_lesser_1_period_0_xx_period_yy_greater_'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: bandwith
                                
                                	Bandwidth metric in Kbits per second
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: delay
                                
                                	EIGRP delay metric, in 10 microsecond units
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reliability
                                
                                	EIGRP reliability metric where 255 is 100% reliable
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: effective
                                
                                	EIGRP Effective bandwidth metric (Loading) where 255 is 100% loaded
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: mtu
                                
                                	EIGRP MTU of the path
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Bgp.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "bgp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bandwith', (YLeaf(YType.uint32, 'bandwith'), ['int'])),
                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                        ('reliability', (YLeaf(YType.uint8, 'reliability'), ['int'])),
                                        ('effective', (YLeaf(YType.uint8, 'Effective'), ['int'])),
                                        ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                                    ])
                                    self.bandwith = None
                                    self.delay = None
                                    self.reliability = None
                                    self.effective = None
                                    self.mtu = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Bgp.Metric, ['bandwith', 'delay', 'reliability', 'effective', 'mtu'], name, value)


                        class Connected(Entity):
                            """
                            Connected
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Connected, self).__init__()

                                self.yang_name = "connected"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "connected"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Connected, ['metric', 'route_map'], name, value)


                        class Isis(Entity):
                            """
                            ISO IS\-IS
                            
                            .. attribute:: is_tag
                            
                            	ISO routing area tag
                            	**type**\: str
                            
                            .. attribute:: level_1
                            
                            	IS\-IS level\-1 routes only
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: level_1_2
                            
                            	IS\-IS level\-1 and level\-2 routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: level_2
                            
                            	IS\-IS level\-2 routes only
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Isis, self).__init__()

                                self.yang_name = "isis"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('is_tag', (YLeaf(YType.str, 'is-tag'), ['str'])),
                                    ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                                    ('level_1_2', (YLeaf(YType.empty, 'level-1-2'), ['Empty'])),
                                    ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.is_tag = None
                                self.level_1 = None
                                self.level_1_2 = None
                                self.level_2 = None
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "isis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Isis, ['is_tag', 'level_1', 'level_1_2', 'level_2', 'metric', 'route_map'], name, value)


                        class Lisp(Entity):
                            """
                            Locator ID Separation Protocol (LISP)
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Lisp, self).__init__()

                                self.yang_name = "lisp"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "lisp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Lisp, ['metric', 'route_map'], name, value)


                        class Mobile(Entity):
                            """
                            Mobile routes
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Mobile, self).__init__()

                                self.yang_name = "mobile"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "mobile"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                        class Odr(Entity):
                            """
                            On Demand stub Routes
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Odr, self).__init__()

                                self.yang_name = "odr"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "odr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Odr, ['metric', 'route_map'], name, value)


                        class Rip(Entity):
                            """
                            Routing Information Protocol (RIP)
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Rip, self).__init__()

                                self.yang_name = "rip"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "rip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Rip, ['metric', 'route_map'], name, value)


                        class Static(Entity):
                            """
                            Static routes
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Static, self).__init__()

                                self.yang_name = "static"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                                    ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                                ])
                                self.metric = None
                                self.route_map = None
                                self._segment_path = lambda: "static"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Static, ['metric', 'route_map'], name, value)


                        class Vrf(Entity):
                            """
                            Specify a source virtual routing/forwarding instance
                            
                            .. attribute:: name
                            
                            	Virtual Routing/Forwarding instance name
                            	**type**\: str
                            
                            .. attribute:: global_
                            
                            	global VRF
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "redistribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                                ])
                                self.name = None
                                self.global_ = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Redistribute.Vrf, ['name', 'global_'], name, value)


                    class SummaryMetric(Entity):
                        """
                        Specify summary to apply metric/filtering
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.SummaryMetric.Ipv4>`
                        
                        .. attribute:: a_period_b_period_c_period_d_slash_nn
                        
                        	Summary <network>/<length>, e.g., 192.168.0.0/16
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.SummaryMetric, self).__init__()

                            self.yang_name = "summary-metric"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Eigrp.AddressFamily.AfIpVrfList.SummaryMetric.Ipv4))])
                            self._leafs = OrderedDict([
                                ('a_period_b_period_c_period_d_slash_nn', (YLeaf(YType.empty, 'A_PERIOD_B_PERIOD_C_PERIOD_D_SLASH_nn'), ['Empty'])),
                            ])
                            self.a_period_b_period_c_period_d_slash_nn = None

                            self.ipv4 = YList(self)
                            self._segment_path = lambda: "summary-metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.SummaryMetric, ['a_period_b_period_c_period_d_slash_nn'], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: ipv4  (key)
                            
                            	Summary to configure static metric
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask
                            
                            	Network mask
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.SummaryMetric.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "summary-metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ipv4']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ])
                                self.ipv4 = None
                                self.mask = None
                                self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.SummaryMetric.Ipv4, ['ipv4', 'mask'], name, value)


                    class Timers(Entity):
                        """
                        Adjust routing timers
                        
                        .. attribute:: active_time
                        
                        	time limit for active state
                        	**type**\:  :py:class:`ActiveTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.ActiveTime>`
                        
                        .. attribute:: graceful_restart
                        
                        	EIGRP Graceful Restart timer
                        	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.GracefulRestart>`
                        
                        .. attribute:: nsf
                        
                        	EIGRP NSF timer
                        	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.Nsf>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("active-time", ("active_time", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.ActiveTime)), ("graceful-restart", ("graceful_restart", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.GracefulRestart)), ("nsf", ("nsf", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.Nsf))])
                            self._leafs = OrderedDict()

                            self.active_time = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.ActiveTime()
                            self.active_time.parent = self
                            self._children_name_map["active_time"] = "active-time"

                            self.graceful_restart = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.GracefulRestart()
                            self.graceful_restart.parent = self
                            self._children_name_map["graceful_restart"] = "graceful-restart"

                            self.nsf = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.Nsf()
                            self.nsf.parent = self
                            self._children_name_map["nsf"] = "nsf"
                            self._segment_path = lambda: "timers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers, [], name, value)


                        class ActiveTime(Entity):
                            """
                            time limit for active state
                            
                            .. attribute:: atimer
                            
                            	active state time limit in minutes
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: disabled
                            
                            	disable time limit for active state
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.ActiveTime, self).__init__()

                                self.yang_name = "active-time"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atimer', (YLeaf(YType.uint16, 'atimer'), ['int'])),
                                    ('disabled', (YLeaf(YType.empty, 'disabled'), ['Empty'])),
                                ])
                                self.atimer = None
                                self.disabled = None
                                self._segment_path = lambda: "active-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.ActiveTime, ['atimer', 'disabled'], name, value)


                        class GracefulRestart(Entity):
                            """
                            EIGRP Graceful Restart timer
                            
                            .. attribute:: purge_time
                            
                            	EIGRP stale route purge time
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.GracefulRestart, self).__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('purge_time', (YLeaf(YType.empty, 'purge-time'), ['Empty'])),
                                ])
                                self.purge_time = None
                                self._segment_path = lambda: "graceful-restart"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.GracefulRestart, ['purge_time'], name, value)


                        class Nsf(Entity):
                            """
                            EIGRP NSF timer
                            
                            .. attribute:: converge
                            
                            	EIGRP time limit for convergence after switchover
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: signal
                            
                            	EIGRP time limit for signaling NSF restart
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.Nsf, self).__init__()

                                self.yang_name = "nsf"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('converge', (YLeaf(YType.empty, 'converge'), ['Empty'])),
                                    ('signal', (YLeaf(YType.empty, 'signal'), ['Empty'])),
                                ])
                                self.converge = None
                                self.signal = None
                                self._segment_path = lambda: "nsf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Timers.Nsf, ['converge', 'signal'], name, value)


                    class TrafficShare(Entity):
                        """
                        How to compute traffic share over alternate paths
                        
                        .. attribute:: balanced
                        
                        	Share inversely proportional to metric
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: min
                        
                        	All traffic shared among min metric paths
                        	**type**\:  :py:class:`Min <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.TrafficShare.Min>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.TrafficShare, self).__init__()

                            self.yang_name = "traffic-share"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("min", ("min", Native.Router.Eigrp.AddressFamily.AfIpVrfList.TrafficShare.Min))])
                            self._leafs = OrderedDict([
                                ('balanced', (YLeaf(YType.empty, 'balanced'), ['Empty'])),
                            ])
                            self.balanced = None

                            self.min = Native.Router.Eigrp.AddressFamily.AfIpVrfList.TrafficShare.Min()
                            self.min.parent = self
                            self._children_name_map["min"] = "min"
                            self._segment_path = lambda: "traffic-share"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.TrafficShare, ['balanced'], name, value)


                        class Min(Entity):
                            """
                            All traffic shared among min metric paths
                            
                            .. attribute:: across_interfaces
                            
                            	Use different interfaces for equal\-cost paths
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.TrafficShare.Min, self).__init__()

                                self.yang_name = "min"
                                self.yang_parent_name = "traffic-share"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                                ])
                                self.across_interfaces = None
                                self._segment_path = lambda: "min"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.TrafficShare.Min, ['across_interfaces'], name, value)


                    class Topology(Entity):
                        """
                        Topology configuration mode
                        
                        .. attribute:: base
                        
                        	Base Topology
                        	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "af-ip-vrf-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("base", ("base", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base))])
                            self._leafs = OrderedDict()

                            self.base = None
                            self._children_name_map["base"] = "base"
                            self._segment_path = lambda: "topology"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology, [], name, value)


                        class Base(Entity):
                            """
                            Base Topology
                            
                            .. attribute:: distance
                            
                            	Define an administrative distance
                            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance>`
                            
                            .. attribute:: distribute_list
                            
                            	Filter entries in eigrp updates
                            	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList>`
                            
                            .. attribute:: redistribute
                            
                            	Redistribute IPv6 prefixes from another routing protocol
                            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute>`
                            
                            .. attribute:: summary_metric
                            
                            	Specify summary to apply metric/filtering
                            	**type**\: list of  		 :py:class:`SummaryMetric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.SummaryMetric>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("distance", ("distance", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance)), ("distribute-list", ("distribute_list", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList)), ("redistribute", ("redistribute", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute)), ("summary-metric", ("summary_metric", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.SummaryMetric))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.distance = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"

                                self.distribute_list = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList()
                                self.distribute_list.parent = self
                                self._children_name_map["distribute_list"] = "distribute-list"

                                self.redistribute = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute()
                                self.redistribute.parent = self
                                self._children_name_map["redistribute"] = "redistribute"

                                self.summary_metric = YList(self)
                                self._segment_path = lambda: "base"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base, [], name, value)


                            class Distance(Entity):
                                """
                                Define an administrative distance
                                
                                .. attribute:: eigrp
                                
                                	EIGRP\-IPV6 distance
                                	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance.Eigrp_>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance, self).__init__()

                                    self.yang_name = "distance"
                                    self.yang_parent_name = "base"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance.Eigrp_))])
                                    self._leafs = OrderedDict()

                                    self.eigrp = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance.Eigrp_()
                                    self.eigrp.parent = self
                                    self._children_name_map["eigrp"] = "eigrp"
                                    self._segment_path = lambda: "distance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance, [], name, value)


                                class Eigrp_(Entity):
                                    """
                                    EIGRP\-IPV6 distance
                                    
                                    .. attribute:: distance_list
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`DistanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance.Eigrp_.DistanceList>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance.Eigrp_, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "distance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("distance-list", ("distance_list", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance.Eigrp_.DistanceList))])
                                        self._leafs = OrderedDict()

                                        self.distance_list = YList(self)
                                        self._segment_path = lambda: "eigrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance.Eigrp_, [], name, value)


                                    class DistanceList(Entity):
                                        """
                                        
                                        
                                        .. attribute:: internal_route  (key)
                                        
                                        	Distance for internal routes
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: external_route
                                        
                                        	Distance for external routes
                                        	**type**\: int
                                        
                                        	**range:** 1..255
                                        
                                        

                                        """

                                        _prefix = 'ios-eigrp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance.Eigrp_.DistanceList, self).__init__()

                                            self.yang_name = "distance-list"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['internal_route']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('internal_route', (YLeaf(YType.uint8, 'internal-route'), ['int'])),
                                                ('external_route', (YLeaf(YType.uint8, 'external-route'), ['int'])),
                                            ])
                                            self.internal_route = None
                                            self.external_route = None
                                            self._segment_path = lambda: "distance-list" + "[internal-route='" + str(self.internal_route) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Distance.Eigrp_.DistanceList, ['internal_route', 'external_route'], name, value)


                            class DistributeList(Entity):
                                """
                                Filter entries in eigrp updates
                                
                                .. attribute:: prefix_list
                                
                                	Filter prefixes in address updates
                                	**type**\: list of  		 :py:class:`PrefixList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList.PrefixList>`
                                
                                .. attribute:: route_map
                                
                                	Filter prefixes based on the route\-map
                                	**type**\: list of  		 :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList.RouteMap>`
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList, self).__init__()

                                    self.yang_name = "distribute-list"
                                    self.yang_parent_name = "base"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("prefix-list", ("prefix_list", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList.PrefixList)), ("route-map", ("route_map", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList.RouteMap))])
                                    self._leafs = OrderedDict()

                                    self.prefix_list = YList(self)
                                    self.route_map = YList(self)
                                    self._segment_path = lambda: "distribute-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList, [], name, value)


                                class PrefixList(Entity):
                                    """
                                    Filter prefixes in address updates
                                    
                                    .. attribute:: prefix_list  (key)
                                    
                                    	Name of an IP prefix\-list
                                    	**type**\: str
                                    
                                    .. attribute:: gateway
                                    
                                    	Filtering incoming address updates based on gateway
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: in_
                                    
                                    	Filter incoming service updates
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: out
                                    
                                    	Filter outgoing service updates
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList.PrefixList, self).__init__()

                                        self.yang_name = "prefix-list"
                                        self.yang_parent_name = "distribute-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix_list']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                            ('gateway', (YLeaf(YType.empty, 'gateway'), ['Empty'])),
                                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                            ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                                        ])
                                        self.prefix_list = None
                                        self.gateway = None
                                        self.in_ = None
                                        self.out = None
                                        self._segment_path = lambda: "prefix-list" + "[prefix-list='" + str(self.prefix_list) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList.PrefixList, ['prefix_list', 'gateway', 'in_', 'out'], name, value)


                                class RouteMap(Entity):
                                    """
                                    Filter prefixes based on the route\-map
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: in_
                                    
                                    	Filter incoming service updates
                                    	**type**\: str
                                    
                                    .. attribute:: out
                                    
                                    	Filter outgoing service updates
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList.RouteMap, self).__init__()

                                        self.yang_name = "route-map"
                                        self.yang_parent_name = "distribute-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('in_', (YLeaf(YType.str, 'in'), ['str'])),
                                            ('out', (YLeaf(YType.str, 'out'), ['str'])),
                                        ])
                                        self.name = None
                                        self.in_ = None
                                        self.out = None
                                        self._segment_path = lambda: "route-map" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.DistributeList.RouteMap, ['name', 'in_', 'out'], name, value)


                            class Redistribute(Entity):
                                """
                                Redistribute IPv6 prefixes from another routing protocol
                                
                                .. attribute:: eigrp
                                
                                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                                	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Eigrp_>`
                                
                                .. attribute:: ospf
                                
                                	Open Shortest Path First (OSPFv3)
                                	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Ospf>`
                                
                                .. attribute:: connected
                                
                                	Connected Routes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: static
                                
                                	Static Routes
                                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Static>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute, self).__init__()

                                    self.yang_name = "redistribute"
                                    self.yang_parent_name = "base"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("eigrp", ("eigrp", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Eigrp_)), ("ospf", ("ospf", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Ospf)), ("static", ("static", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Static))])
                                    self._leafs = OrderedDict([
                                        ('connected', (YLeaf(YType.empty, 'connected'), ['Empty'])),
                                    ])
                                    self.connected = None

                                    self.eigrp = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Eigrp_()
                                    self.eigrp.parent = self
                                    self._children_name_map["eigrp"] = "eigrp"

                                    self.ospf = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Ospf()
                                    self.ospf.parent = self
                                    self._children_name_map["ospf"] = "ospf"

                                    self.static = None
                                    self._children_name_map["static"] = "static"
                                    self._segment_path = lambda: "redistribute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute, ['connected'], name, value)


                                class Eigrp_(Entity):
                                    """
                                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                                    
                                    .. attribute:: as_list
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`AsList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Eigrp_.AsList>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Eigrp_, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("as-list", ("as_list", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Eigrp_.AsList))])
                                        self._leafs = OrderedDict()

                                        self.as_list = YList(self)
                                        self._segment_path = lambda: "eigrp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Eigrp_, [], name, value)


                                    class AsList(Entity):
                                        """
                                        
                                        
                                        .. attribute:: autonomous_system  (key)
                                        
                                        	Autonomous system number
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-eigrp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Eigrp_.AsList, self).__init__()

                                            self.yang_name = "as-list"
                                            self.yang_parent_name = "eigrp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['autonomous_system']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('autonomous_system', (YLeaf(YType.uint16, 'autonomous-system'), ['int'])),
                                            ])
                                            self.autonomous_system = None
                                            self._segment_path = lambda: "as-list" + "[autonomous-system='" + str(self.autonomous_system) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Eigrp_.AsList, ['autonomous_system'], name, value)


                                class Ospf(Entity):
                                    """
                                    Open Shortest Path First (OSPFv3)
                                    
                                    .. attribute:: pid_list
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`PidList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Ospf.PidList>`
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Ospf, self).__init__()

                                        self.yang_name = "ospf"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("pid-list", ("pid_list", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Ospf.PidList))])
                                        self._leafs = OrderedDict()

                                        self.pid_list = YList(self)
                                        self._segment_path = lambda: "ospf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Ospf, [], name, value)


                                    class PidList(Entity):
                                        """
                                        
                                        
                                        .. attribute:: process_id  (key)
                                        
                                        	Process ID
                                        	**type**\: int
                                        
                                        	**range:** 1..65535
                                        
                                        

                                        """

                                        _prefix = 'ios-eigrp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Ospf.PidList, self).__init__()

                                            self.yang_name = "pid-list"
                                            self.yang_parent_name = "ospf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['process_id']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('process_id', (YLeaf(YType.uint16, 'process-id'), ['int'])),
                                            ])
                                            self.process_id = None
                                            self._segment_path = lambda: "pid-list" + "[process-id='" + str(self.process_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Ospf.PidList, ['process_id'], name, value)


                                class Static(Entity):
                                    """
                                    Static Routes
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.Redistribute.Static, self).__init__()

                                        self.yang_name = "static"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "static"
                                        self._is_frozen = True


                            class SummaryMetric(Entity):
                                """
                                Specify summary to apply metric/filtering
                                
                                .. attribute:: ipv4_addr_slash_prefix_len  (key)
                                
                                	Summary <network>/<length>, e.g., 192.168.0.0/16
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                .. attribute:: metric
                                
                                	
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.SummaryMetric.Metric>`
                                
                                .. attribute:: distance
                                
                                	Set administrative distance for summary route
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'ios-eigrp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.SummaryMetric, self).__init__()

                                    self.yang_name = "summary-metric"
                                    self.yang_parent_name = "base"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv4_addr_slash_prefix_len']
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.SummaryMetric.Metric))])
                                    self._leafs = OrderedDict([
                                        ('ipv4_addr_slash_prefix_len', (YLeaf(YType.str, 'ipv4-addr-slash-prefix-len'), ['str'])),
                                        ('distance', (YLeaf(YType.uint8, 'distance'), ['int'])),
                                    ])
                                    self.ipv4_addr_slash_prefix_len = None
                                    self.distance = None

                                    self.metric = Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.SummaryMetric.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "summary-metric" + "[ipv4-addr-slash-prefix-len='" + str(self.ipv4_addr_slash_prefix_len) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.SummaryMetric, ['ipv4_addr_slash_prefix_len', 'distance'], name, value)


                                class Metric(Entity):
                                    """
                                    
                                    
                                    .. attribute:: bandwidth_metric
                                    
                                    	Bandwidth metric in Kbits per second
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: delay_metric
                                    
                                    	delay metric in 10 microsecond units
                                    	**type**\: int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: reliability_metric
                                    
                                    	reliability metric where 255 is 100% reliable
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: effective_bandwidth_metric
                                    
                                    	Effective bandwidth metric (Loading) where 255 is 100% loaded
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU of the path
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    

                                    """

                                    _prefix = 'ios-eigrp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.SummaryMetric.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "summary-metric"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bandwidth_metric', (YLeaf(YType.uint32, 'bandwidth-metric'), ['int'])),
                                            ('delay_metric', (YLeaf(YType.uint32, 'delay-metric'), ['int'])),
                                            ('reliability_metric', (YLeaf(YType.uint8, 'reliability-metric'), ['int'])),
                                            ('effective_bandwidth_metric', (YLeaf(YType.uint8, 'effective-bandwidth-metric'), ['int'])),
                                            ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                                        ])
                                        self.bandwidth_metric = None
                                        self.delay_metric = None
                                        self.reliability_metric = None
                                        self.effective_bandwidth_metric = None
                                        self.mtu = None
                                        self._segment_path = lambda: "metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Eigrp.AddressFamily.AfIpVrfList.Topology.Base.SummaryMetric.Metric, ['bandwidth_metric', 'delay_metric', 'reliability_metric', 'effective_bandwidth_metric', 'mtu'], name, value)


            class AfInterface(Entity):
                """
                Enter Address Family interface configuration
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: bandwidth_percent
                
                	Set percentage of bandwidth percentage limit
                	**type**\: int
                
                	**range:** 1..999999
                
                .. attribute:: hello_interval
                
                	Configures hello interval
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: hold_time
                
                	Configures hold time
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: passive_interface
                
                	Suppress address updates on an interface
                	**type**\: bool
                
                .. attribute:: split_horizon
                
                	Perform split horizon
                	**type**\: bool
                
                .. attribute:: stub_site
                
                	Stub\-Site
                	**type**\:  :py:class:`StubSite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AfInterface.StubSite>`
                
                .. attribute:: authentication
                
                	authentication subcommands
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AfInterface.Authentication>`
                
                .. attribute:: summary_address
                
                	
                	**type**\:  :py:class:`SummaryAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AfInterface.SummaryAddress>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.AfInterface, self).__init__()

                    self.yang_name = "af-interface"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("stub-site", ("stub_site", Native.Router.Eigrp.AfInterface.StubSite)), ("authentication", ("authentication", Native.Router.Eigrp.AfInterface.Authentication)), ("summary-address", ("summary_address", Native.Router.Eigrp.AfInterface.SummaryAddress))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('bandwidth_percent', (YLeaf(YType.uint32, 'bandwidth-percent'), ['int'])),
                        ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                        ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                        ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                        ('split_horizon', (YLeaf(YType.boolean, 'split-horizon'), ['bool'])),
                    ])
                    self.name = None
                    self.bandwidth_percent = None
                    self.hello_interval = None
                    self.hold_time = None
                    self.passive_interface = None
                    self.split_horizon = None

                    self.stub_site = Native.Router.Eigrp.AfInterface.StubSite()
                    self.stub_site.parent = self
                    self._children_name_map["stub_site"] = "stub-site"

                    self.authentication = Native.Router.Eigrp.AfInterface.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.summary_address = Native.Router.Eigrp.AfInterface.SummaryAddress()
                    self.summary_address.parent = self
                    self._children_name_map["summary_address"] = "summary-address"
                    self._segment_path = lambda: "af-interface" + "[name='" + str(self.name) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.AfInterface, ['name', 'bandwidth_percent', 'hello_interval', 'hold_time', 'passive_interface', 'split_horizon'], name, value)


                class StubSite(Entity):
                    """
                    Stub\-Site
                    
                    .. attribute:: wan_interface
                    
                    	Wan Interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.AfInterface.StubSite, self).__init__()

                        self.yang_name = "stub-site"
                        self.yang_parent_name = "af-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('wan_interface', (YLeaf(YType.empty, 'wan-interface'), ['Empty'])),
                        ])
                        self.wan_interface = None
                        self._segment_path = lambda: "stub-site"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.AfInterface.StubSite, ['wan_interface'], name, value)


                class Authentication(Entity):
                    """
                    authentication subcommands
                    
                    .. attribute:: mode
                    
                    	authentication mode
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AfInterface.Authentication.Mode>`
                    
                    .. attribute:: key_chain
                    
                    	key\-chain
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.AfInterface.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "af-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mode", ("mode", Native.Router.Eigrp.AfInterface.Authentication.Mode))])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                        ])
                        self.key_chain = None

                        self.mode = Native.Router.Eigrp.AfInterface.Authentication.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.AfInterface.Authentication, ['key_chain'], name, value)


                    class Mode(Entity):
                        """
                        authentication mode
                        
                        .. attribute:: md5
                        
                        	Keyed message digest
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hmac_sha_256
                        
                        	HMAC\-SHA\-256 Authentication
                        	**type**\:  :py:class:`HmacSha256 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.AfInterface.Authentication.Mode.HmacSha256>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.AfInterface.Authentication.Mode, self).__init__()

                            self.yang_name = "mode"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("hmac-sha-256", ("hmac_sha_256", Native.Router.Eigrp.AfInterface.Authentication.Mode.HmacSha256))])
                            self._leafs = OrderedDict([
                                ('md5', (YLeaf(YType.empty, 'md5'), ['Empty'])),
                            ])
                            self.md5 = None

                            self.hmac_sha_256 = Native.Router.Eigrp.AfInterface.Authentication.Mode.HmacSha256()
                            self.hmac_sha_256.parent = self
                            self._children_name_map["hmac_sha_256"] = "hmac-sha-256"
                            self._segment_path = lambda: "mode"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.AfInterface.Authentication.Mode, ['md5'], name, value)


                        class HmacSha256(Entity):
                            """
                            HMAC\-SHA\-256 Authentication
                            
                            .. attribute:: auth_type
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: auth_key
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.AfInterface.Authentication.Mode.HmacSha256, self).__init__()

                                self.yang_name = "hmac-sha-256"
                                self.yang_parent_name = "mode"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('auth_type', (YLeaf(YType.uint8, 'auth-type'), ['int'])),
                                    ('auth_key', (YLeaf(YType.str, 'auth-key'), ['str'])),
                                ])
                                self.auth_type = None
                                self.auth_key = None
                                self._segment_path = lambda: "hmac-sha-256"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.AfInterface.Authentication.Mode.HmacSha256, ['auth_type', 'auth_key'], name, value)


                class SummaryAddress(Entity):
                    """
                    
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mask
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.AfInterface.SummaryAddress, self).__init__()

                        self.yang_name = "summary-address"
                        self.yang_parent_name = "af-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                        ])
                        self.address = None
                        self.mask = None
                        self._segment_path = lambda: "summary-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.AfInterface.SummaryAddress, ['address', 'mask'], name, value)


            class SetAsInSubmode(Entity):
                """
                
                
                .. attribute:: autonomous_system
                
                	Specify Address\-Family Autonomous System Number?
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.SetAsInSubmode, self).__init__()

                    self.yang_name = "set-as-in-submode"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('autonomous_system', (YLeaf(YType.uint16, 'autonomous-system'), ['int'])),
                    ])
                    self.autonomous_system = None
                    self._segment_path = lambda: "set-as-in-submode"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.SetAsInSubmode, ['autonomous_system'], name, value)


            class Bfd(Entity):
                """
                BFD configuration commands
                
                .. attribute:: all_interfaces
                
                	Enable BFD on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface
                
                	Enable BFD on specific interface
                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Bfd.Interface>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Native.Router.Eigrp.Bfd.Interface))])
                    self._leafs = OrderedDict([
                        ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                    ])
                    self.all_interfaces = None

                    self.interface = Native.Router.Eigrp.Bfd.Interface()
                    self.interface.parent = self
                    self._children_name_map["interface"] = "interface"
                    self._segment_path = lambda: "bfd"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.Bfd, ['all_interfaces'], name, value)


                class Interface(Entity):
                    """
                    Enable BFD on specific interface
                    
                    .. attribute:: appnav_compress
                    
                    	Service\-Context Virtual Interface Compress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: appnav_uncompress
                    
                    	Service\-Context Virtual Interface UnCompress
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: atm
                    
                    	ATM interface
                    	**type**\: str
                    
                    .. attribute:: atm_subinterface
                    
                    	
                    	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Bfd.Interface.ATMSubinterface>`
                    
                    .. attribute:: atm_acr
                    
                    	ATM\-ACR interface
                    	**type**\: str
                    
                    	**pattern:** [0\-9]
                    
                    .. attribute:: atm_acrsubinterface
                    
                    	
                    	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Bfd.Interface.ATMACRsubinterface>`
                    
                    .. attribute:: bdi
                    
                    	Bridge\-Domain interface
                    	**type**\: str
                    
                    .. attribute:: cem
                    
                    	CEM interface
                    	**type**\: str
                    
                    	**pattern:** ([0\-9]/){2}[0\-9]
                    
                    .. attribute:: cem_acr
                    
                    	CEM\-ACR interface
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: embedded_service_engine
                    
                    	cisco embedded service engine module
                    	**type**\: str
                    
                    .. attribute:: ethernet
                    
                    	IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: fortygigabitethernet
                    
                    	Forty GigabitEthernet 
                    	**type**\: str
                    
                    .. attribute:: hundredgige
                    
                    	Hundred GigabitEthernet
                    	**type**\: str
                    
                    .. attribute:: lisp
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\: str
                    
                    .. attribute:: lisp_subinterface
                    
                    	Locator/ID Separation Protocol Virtual Interface
                    	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Bfd.Interface.LISPSubinterface>`
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multilink
                    
                    	Multilink\-group interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: nve
                    
                    	Network virtualization endpoint interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: overlay
                    
                    	Overlay interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_channel
                    
                    	Ethernet Channel of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_channel_subinterface
                    
                    	
                    	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Bfd.Interface.PortChannelSubinterface>`
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sm
                    
                    	SM Interface
                    	**type**\: str
                    
                    .. attribute:: cellular
                    
                    	Cellular Interface
                    	**type**\: str
                    
                    .. attribute:: serial
                    
                    	Serial interface
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: tunnel
                    
                    	Tunnel interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_template
                    
                    	Virtual Template interface
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vlan
                    
                    	Iosxr Vlans
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtualportgroup
                    
                    	Virtual Port Group
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasileft
                    
                    	vasileft
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vasiright
                    
                    	vasiright
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Bfd.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Eigrp.Bfd.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Eigrp.Bfd.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Eigrp.Bfd.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Eigrp.Bfd.Interface.PortChannelSubinterface))])
                        self._leafs = OrderedDict([
                            ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                            ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                            ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                            ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                            ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                            ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                            ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                            ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                            ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                            ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                            ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                            ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                            ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                            ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                            ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                            ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                            ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                            ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                            ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                        ])
                        self.appnav_compress = None
                        self.appnav_uncompress = None
                        self.atm = None
                        self.atm_acr = None
                        self.bdi = None
                        self.cem = None
                        self.cem_acr = None
                        self.embedded_service_engine = None
                        self.ethernet = None
                        self.fastethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.fortygigabitethernet = None
                        self.hundredgige = None
                        self.lisp = None
                        self.loopback = None
                        self.multilink = None
                        self.nve = None
                        self.overlay = None
                        self.port_channel = None
                        self.pseudowire = None
                        self.sm = None
                        self.cellular = None
                        self.serial = None
                        self.tengigabitethernet = None
                        self.tunnel = None
                        self.virtual_template = None
                        self.vlan = None
                        self.virtualportgroup = None
                        self.vasileft = None
                        self.vasiright = None

                        self.atm_subinterface = Native.Router.Eigrp.Bfd.Interface.ATMSubinterface()
                        self.atm_subinterface.parent = self
                        self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                        self.atm_acrsubinterface = Native.Router.Eigrp.Bfd.Interface.ATMACRsubinterface()
                        self.atm_acrsubinterface.parent = self
                        self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                        self.lisp_subinterface = Native.Router.Eigrp.Bfd.Interface.LISPSubinterface()
                        self.lisp_subinterface.parent = self
                        self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                        self.port_channel_subinterface = Native.Router.Eigrp.Bfd.Interface.PortChannelSubinterface()
                        self.port_channel_subinterface.parent = self
                        self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                        self._segment_path = lambda: "interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Bfd.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                    class ATMSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.Bfd.Interface.ATMSubinterface, self).__init__()

                            self.yang_name = "ATM-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                            ])
                            self.atm = None
                            self._segment_path = lambda: "ATM-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.Bfd.Interface.ATMSubinterface, [u'atm'], name, value)


                    class ATMACRsubinterface(Entity):
                        """
                        
                        
                        .. attribute:: atm_acr
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.Bfd.Interface.ATMACRsubinterface, self).__init__()

                            self.yang_name = "ATM-ACRsubinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                            ])
                            self.atm_acr = None
                            self._segment_path = lambda: "ATM-ACRsubinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.Bfd.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                    class LISPSubinterface(Entity):
                        """
                        Locator/ID Separation Protocol Virtual Interface
                        
                        .. attribute:: lisp
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.Bfd.Interface.LISPSubinterface, self).__init__()

                            self.yang_name = "LISP-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                            ])
                            self.lisp = None
                            self._segment_path = lambda: "LISP-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.Bfd.Interface.LISPSubinterface, [u'lisp'], name, value)


                    class PortChannelSubinterface(Entity):
                        """
                        
                        
                        .. attribute:: port_channel
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.Bfd.Interface.PortChannelSubinterface, self).__init__()

                            self.yang_name = "Port-channel-subinterface"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                            ])
                            self.port_channel = None
                            self._segment_path = lambda: "Port-channel-subinterface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.Bfd.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


            class DefaultInformation(Entity):
                """
                Control distribution of default information
                
                .. attribute:: in_
                
                	Accept input default routing information
                	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DefaultInformation.In>`
                
                	**presence node**\: True
                
                .. attribute:: out
                
                	Accept output default routing information
                	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DefaultInformation.Out>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.DefaultInformation, self).__init__()

                    self.yang_name = "default-information"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("in", ("in_", Native.Router.Eigrp.DefaultInformation.In)), ("out", ("out", Native.Router.Eigrp.DefaultInformation.Out))])
                    self._leafs = OrderedDict()

                    self.in_ = None
                    self._children_name_map["in_"] = "in"

                    self.out = None
                    self._children_name_map["out"] = "out"
                    self._segment_path = lambda: "default-information"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.DefaultInformation, [], name, value)


                class In(Entity):
                    """
                    Accept input default routing information
                    
                    .. attribute:: sa_num
                    
                    	A standard expanded IP access list number
                    	**type**\: int
                    
                    	**range:** 1300..1999
                    
                    .. attribute:: sa_name
                    
                    	Standard Access\-list name
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.DefaultInformation.In, self).__init__()

                        self.yang_name = "in"
                        self.yang_parent_name = "default-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('sa_num', (YLeaf(YType.uint16, 'sa-num'), ['int'])),
                            ('sa_name', (YLeaf(YType.str, 'sa-name'), ['str'])),
                        ])
                        self.sa_num = None
                        self.sa_name = None
                        self._segment_path = lambda: "in"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.DefaultInformation.In, ['sa_num', 'sa_name'], name, value)


                class Out(Entity):
                    """
                    Accept output default routing information
                    
                    .. attribute:: sa_out_num
                    
                    	A standard expanded IP access list number
                    	**type**\: int
                    
                    	**range:** 1300..1999
                    
                    .. attribute:: sa_out_name
                    
                    	Standard Access\-list name
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.DefaultInformation.Out, self).__init__()

                        self.yang_name = "out"
                        self.yang_parent_name = "default-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('sa_out_num', (YLeaf(YType.uint16, 'sa-out-num'), ['int'])),
                            ('sa_out_name', (YLeaf(YType.str, 'sa-out-name'), ['str'])),
                        ])
                        self.sa_out_num = None
                        self.sa_out_name = None
                        self._segment_path = lambda: "out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.DefaultInformation.Out, ['sa_out_num', 'sa_out_name'], name, value)


            class DefaultMetric(Entity):
                """
                Set metric of redistributed routes
                
                .. attribute:: dm_rdr
                
                	
                	**type**\: list of  		 :py:class:`DmRdr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DefaultMetric.DmRdr>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.DefaultMetric, self).__init__()

                    self.yang_name = "default-metric"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dm-rdr", ("dm_rdr", Native.Router.Eigrp.DefaultMetric.DmRdr))])
                    self._leafs = OrderedDict()

                    self.dm_rdr = YList(self)
                    self._segment_path = lambda: "default-metric"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.DefaultMetric, [], name, value)


                class DmRdr(Entity):
                    """
                    
                    
                    .. attribute:: dm_rdr  (key)
                    
                    	Bandwidth in Kbits per second
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: dm_rdr0
                    
                    	
                    	**type**\: list of  		 :py:class:`DmRdr0 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DefaultMetric.DmRdr.DmRdr0>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.DefaultMetric.DmRdr, self).__init__()

                        self.yang_name = "dm-rdr"
                        self.yang_parent_name = "default-metric"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['dm_rdr']
                        self._child_classes = OrderedDict([("dm-rdr0", ("dm_rdr0", Native.Router.Eigrp.DefaultMetric.DmRdr.DmRdr0))])
                        self._leafs = OrderedDict([
                            ('dm_rdr', (YLeaf(YType.uint32, 'dm-rdr'), ['int'])),
                        ])
                        self.dm_rdr = None

                        self.dm_rdr0 = YList(self)
                        self._segment_path = lambda: "dm-rdr" + "[dm-rdr='" + str(self.dm_rdr) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.DefaultMetric.DmRdr, ['dm_rdr'], name, value)


                    class DmRdr0(Entity):
                        """
                        
                        
                        .. attribute:: dm_rdr0  (key)
                        
                        	delay metric in 10 microsecond units
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: dm_rdr_pct
                        
                        	Reliability metric where 255 is 100% reliable
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.DefaultMetric.DmRdr.DmRdr0, self).__init__()

                            self.yang_name = "dm-rdr0"
                            self.yang_parent_name = "dm-rdr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['dm_rdr0']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dm_rdr0', (YLeaf(YType.uint32, 'dm-rdr0'), ['int'])),
                                ('dm_rdr_pct', (YLeaf(YType.uint8, 'dm-rdr-pct'), ['int'])),
                            ])
                            self.dm_rdr0 = None
                            self.dm_rdr_pct = None
                            self._segment_path = lambda: "dm-rdr0" + "[dm-rdr0='" + str(self.dm_rdr0) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.DefaultMetric.DmRdr.DmRdr0, ['dm_rdr0', 'dm_rdr_pct'], name, value)


            class Distance(Entity):
                """
                Define an administrative distance
                
                .. attribute:: rad_dis
                
                	
                	**type**\: list of  		 :py:class:`RadDis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Distance.RadDis>`
                
                .. attribute:: eigrp
                
                	Set distance for internal and external routes
                	**type**\:  :py:class:`Eigrp_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Distance.Eigrp_>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.Distance, self).__init__()

                    self.yang_name = "distance"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rad-dis", ("rad_dis", Native.Router.Eigrp.Distance.RadDis)), ("eigrp", ("eigrp", Native.Router.Eigrp.Distance.Eigrp_))])
                    self._leafs = OrderedDict()

                    self.eigrp = Native.Router.Eigrp.Distance.Eigrp_()
                    self.eigrp.parent = self
                    self._children_name_map["eigrp"] = "eigrp"

                    self.rad_dis = YList(self)
                    self._segment_path = lambda: "distance"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.Distance, [], name, value)


                class RadDis(Entity):
                    """
                    
                    
                    .. attribute:: rad_dis  (key)
                    
                    	Set route administrative distance
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Distance.RadDis.Ipv4>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Distance.RadDis, self).__init__()

                        self.yang_name = "rad-dis"
                        self.yang_parent_name = "distance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['rad_dis']
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Eigrp.Distance.RadDis.Ipv4))])
                        self._leafs = OrderedDict([
                            ('rad_dis', (YLeaf(YType.uint8, 'rad-dis'), ['int'])),
                        ])
                        self.rad_dis = None

                        self.ipv4 = YList(self)
                        self._segment_path = lambda: "rad-dis" + "[rad-dis='" + str(self.rad_dis) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Distance.RadDis, ['rad_dis'], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: ipv4  (key)
                        
                        	IP Source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv40
                        
                        	Wildcard bits
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.Distance.RadDis.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rad-dis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ipv4']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('ipv40', (YLeaf(YType.str, 'ipv40'), ['str'])),
                            ])
                            self.ipv4 = None
                            self.ipv40 = None
                            self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.Distance.RadDis.Ipv4, ['ipv4', 'ipv40'], name, value)


                class Eigrp_(Entity):
                    """
                    Set distance for internal and external routes
                    
                    .. attribute:: di_rt
                    
                    	
                    	**type**\: list of  		 :py:class:`DiRt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Distance.Eigrp_.DiRt>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Distance.Eigrp_, self).__init__()

                        self.yang_name = "eigrp"
                        self.yang_parent_name = "distance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("di-rt", ("di_rt", Native.Router.Eigrp.Distance.Eigrp_.DiRt))])
                        self._leafs = OrderedDict()

                        self.di_rt = YList(self)
                        self._segment_path = lambda: "eigrp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Distance.Eigrp_, [], name, value)


                    class DiRt(Entity):
                        """
                        
                        
                        .. attribute:: di_rt  (key)
                        
                        	Distance for internal routes
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: di_rt0
                        
                        	Distance for external routes
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.Distance.Eigrp_.DiRt, self).__init__()

                            self.yang_name = "di-rt"
                            self.yang_parent_name = "eigrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['di_rt']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('di_rt', (YLeaf(YType.uint8, 'di-rt'), ['int'])),
                                ('di_rt0', (YLeaf(YType.uint8, 'di-rt0'), ['int'])),
                            ])
                            self.di_rt = None
                            self.di_rt0 = None
                            self._segment_path = lambda: "di-rt" + "[di-rt='" + str(self.di_rt) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.Distance.Eigrp_.DiRt, ['di_rt', 'di_rt0'], name, value)


            class DistributeList(Entity):
                """
                Filter entries in eigrp updates
                
                .. attribute:: eig_filt
                
                	
                	**type**\: list of  		 :py:class:`EigFilt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DistributeList.EigFilt>`
                
                .. attribute:: gateway
                
                	Filtering incoming address updates based on gateway
                	**type**\:  :py:class:`Gateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DistributeList.Gateway>`
                
                .. attribute:: prefix
                
                	Filter prefixes in address updates
                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DistributeList.Prefix>`
                
                .. attribute:: route_map
                
                	Filter prefixes based on the route\-map
                	**type**\:  :py:class:`RouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DistributeList.RouteMap>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.DistributeList, self).__init__()

                    self.yang_name = "distribute-list"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("eig-filt", ("eig_filt", Native.Router.Eigrp.DistributeList.EigFilt)), ("gateway", ("gateway", Native.Router.Eigrp.DistributeList.Gateway)), ("prefix", ("prefix", Native.Router.Eigrp.DistributeList.Prefix)), ("route-map", ("route_map", Native.Router.Eigrp.DistributeList.RouteMap))])
                    self._leafs = OrderedDict()

                    self.gateway = Native.Router.Eigrp.DistributeList.Gateway()
                    self.gateway.parent = self
                    self._children_name_map["gateway"] = "gateway"

                    self.prefix = Native.Router.Eigrp.DistributeList.Prefix()
                    self.prefix.parent = self
                    self._children_name_map["prefix"] = "prefix"

                    self.route_map = Native.Router.Eigrp.DistributeList.RouteMap()
                    self.route_map.parent = self
                    self._children_name_map["route_map"] = "route-map"

                    self.eig_filt = YList(self)
                    self._segment_path = lambda: "distribute-list"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.DistributeList, [], name, value)


                class EigFilt(Entity):
                    """
                    
                    
                    .. attribute:: eig_filt  (key)
                    
                    	IP expanded access list number
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: in_
                    
                    	Filter incoming service updates
                    	**type**\:  :py:class:`In <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DistributeList.EigFilt.In>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: out
                    
                    	Filter outgoing service updates
                    	**type**\:  :py:class:`Out <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DistributeList.EigFilt.Out>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.DistributeList.EigFilt, self).__init__()

                        self.yang_name = "eig-filt"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['eig_filt']
                        self._child_classes = OrderedDict([("in", ("in_", Native.Router.Eigrp.DistributeList.EigFilt.In)), ("out", ("out", Native.Router.Eigrp.DistributeList.EigFilt.Out))])
                        self._leafs = OrderedDict([
                            ('eig_filt', (YLeaf(YType.str, 'eig-filt'), ['int','str'])),
                        ])
                        self.eig_filt = None

                        self.in_ = None
                        self._children_name_map["in_"] = "in"

                        self.out = None
                        self._children_name_map["out"] = "out"
                        self._segment_path = lambda: "eig-filt" + "[eig-filt='" + str(self.eig_filt) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.DistributeList.EigFilt, ['eig_filt'], name, value)


                    class In(Entity):
                        """
                        Filter incoming service updates
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: list of str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.DistributeList.EigFilt.In, self).__init__()

                            self.yang_name = "in"
                            self.yang_parent_name = "eig-filt"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeafList(YType.str, 'interface_name'), ['str'])),
                            ])
                            self.interface_name = []
                            self._segment_path = lambda: "in"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.DistributeList.EigFilt.In, ['interface_name'], name, value)


                    class Out(Entity):
                        """
                        Filter outgoing service updates
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: list of str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.DistributeList.EigFilt.Out, self).__init__()

                            self.yang_name = "out"
                            self.yang_parent_name = "eig-filt"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeafList(YType.str, 'interface_name'), ['str'])),
                            ])
                            self.interface_name = []
                            self._segment_path = lambda: "out"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.DistributeList.EigFilt.Out, ['interface_name'], name, value)


                class Gateway(Entity):
                    """
                    Filtering incoming address updates based on gateway
                    
                    .. attribute:: gw_list
                    
                    	
                    	**type**\: list of  		 :py:class:`GwList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DistributeList.Gateway.GwList>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.DistributeList.Gateway, self).__init__()

                        self.yang_name = "gateway"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gw-list", ("gw_list", Native.Router.Eigrp.DistributeList.Gateway.GwList))])
                        self._leafs = OrderedDict()

                        self.gw_list = YList(self)
                        self._segment_path = lambda: "gateway"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.DistributeList.Gateway, [], name, value)


                    class GwList(Entity):
                        """
                        
                        
                        .. attribute:: gw_list  (key)
                        
                        	Name of an IP prefix\-list
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	Filter incoming service updates
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Filter outgoing service updates
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.DistributeList.Gateway.GwList, self).__init__()

                            self.yang_name = "gw-list"
                            self.yang_parent_name = "gateway"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['gw_list']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('gw_list', (YLeaf(YType.str, 'gw-list'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.gw_list = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "gw-list" + "[gw-list='" + str(self.gw_list) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.DistributeList.Gateway.GwList, ['gw_list', 'in_', 'out'], name, value)


                class Prefix(Entity):
                    """
                    Filter prefixes in address updates
                    
                    .. attribute:: pl_name
                    
                    	
                    	**type**\: list of  		 :py:class:`PlName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DistributeList.Prefix.PlName>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.DistributeList.Prefix, self).__init__()

                        self.yang_name = "prefix"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("pl-name", ("pl_name", Native.Router.Eigrp.DistributeList.Prefix.PlName))])
                        self._leafs = OrderedDict()

                        self.pl_name = YList(self)
                        self._segment_path = lambda: "prefix"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.DistributeList.Prefix, [], name, value)


                    class PlName(Entity):
                        """
                        
                        
                        .. attribute:: pl_name  (key)
                        
                        	Name of an IP prefix\-list
                        	**type**\: str
                        
                        .. attribute:: gateway
                        
                        	Filtering incoming address updates based on gateway
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: in_
                        
                        	Filter incoming service updates
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Filter outgoing service updates
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.DistributeList.Prefix.PlName, self).__init__()

                            self.yang_name = "pl-name"
                            self.yang_parent_name = "prefix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['pl_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('pl_name', (YLeaf(YType.str, 'pl-name'), ['str'])),
                                ('gateway', (YLeaf(YType.empty, 'gateway'), ['Empty'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.pl_name = None
                            self.gateway = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "pl-name" + "[pl-name='" + str(self.pl_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.DistributeList.Prefix.PlName, ['pl_name', 'gateway', 'in_', 'out'], name, value)


                class RouteMap(Entity):
                    """
                    Filter prefixes based on the route\-map
                    
                    .. attribute:: rmap_name
                    
                    	
                    	**type**\: list of  		 :py:class:`RmapName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.DistributeList.RouteMap.RmapName>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.DistributeList.RouteMap, self).__init__()

                        self.yang_name = "route-map"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rmap-name", ("rmap_name", Native.Router.Eigrp.DistributeList.RouteMap.RmapName))])
                        self._leafs = OrderedDict()

                        self.rmap_name = YList(self)
                        self._segment_path = lambda: "route-map"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.DistributeList.RouteMap, [], name, value)


                    class RmapName(Entity):
                        """
                        
                        
                        .. attribute:: rmap_name  (key)
                        
                        	route\-map name
                        	**type**\: str
                        
                        .. attribute:: in_
                        
                        	Filter incoming service updates
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: out
                        
                        	Filter outgoing service updates
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.DistributeList.RouteMap.RmapName, self).__init__()

                            self.yang_name = "rmap-name"
                            self.yang_parent_name = "route-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['rmap_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('rmap_name', (YLeaf(YType.str, 'rmap-name'), ['str'])),
                                ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                                ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                            ])
                            self.rmap_name = None
                            self.in_ = None
                            self.out = None
                            self._segment_path = lambda: "rmap-name" + "[rmap-name='" + str(self.rmap_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.DistributeList.RouteMap.RmapName, ['rmap_name', 'in_', 'out'], name, value)


            class Eigrp_(Entity):
                """
                EIGRP Address Family specific commands
                
                .. attribute:: router_id
                
                	router id for this EIGRP process
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: stub
                
                	Set address\-family in stubbed mode
                	**type**\:  :py:class:`Stub <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Eigrp_.Stub>`
                
                	**presence node**\: True
                
                .. attribute:: stub_site
                
                	ASN\:nn, Dotted\-Decimal\:nn or 4BASN\:nn  Stub\-Site ID in aa\:nn format
                	**type**\: str
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.Eigrp_, self).__init__()

                    self.yang_name = "eigrp"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("stub", ("stub", Native.Router.Eigrp.Eigrp_.Stub))])
                    self._leafs = OrderedDict([
                        ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                        ('stub_site', (YLeaf(YType.str, 'stub-site'), ['str'])),
                    ])
                    self.router_id = None
                    self.stub_site = None

                    self.stub = None
                    self._children_name_map["stub"] = "stub"
                    self._segment_path = lambda: "eigrp"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.Eigrp_, ['router_id', 'stub_site'], name, value)


                class Stub(Entity):
                    """
                    Set address\-family in stubbed mode
                    
                    .. attribute:: connected
                    
                    	Do advertise connected routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: summary
                    
                    	Do advertise summary routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: redistributed
                    
                    	Do advertise redistributed routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: leak_map
                    
                    	Allow dynamic prefixes based on the leak\-map
                    	**type**\: str
                    
                    .. attribute:: receive_only
                    
                    	Set receive only neighbor
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: static
                    
                    	Do advertise static routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Eigrp_.Stub, self).__init__()

                        self.yang_name = "stub"
                        self.yang_parent_name = "eigrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('connected', (YLeaf(YType.empty, 'connected'), ['Empty'])),
                            ('summary', (YLeaf(YType.empty, 'summary'), ['Empty'])),
                            ('redistributed', (YLeaf(YType.empty, 'redistributed'), ['Empty'])),
                            ('leak_map', (YLeaf(YType.str, 'leak-map'), ['str'])),
                            ('receive_only', (YLeaf(YType.empty, 'receive-only'), ['Empty'])),
                            ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                        ])
                        self.connected = None
                        self.summary = None
                        self.redistributed = None
                        self.leak_map = None
                        self.receive_only = None
                        self.static = None
                        self._segment_path = lambda: "stub"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Eigrp_.Stub, ['connected', 'summary', 'redistributed', 'leak_map', 'receive_only', 'static'], name, value)


            class Metric(Entity):
                """
                Modify metrics and parameters for advertisement
                
                .. attribute:: maximum_hops
                
                	Hop count
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: weights
                
                	Type (Only TOS 0 supported)
                	**type**\: int
                
                	**range:** 0..8
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.Metric, self).__init__()

                    self.yang_name = "metric"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('maximum_hops', (YLeaf(YType.uint8, 'maximum-hops'), ['int'])),
                        ('weights', (YLeaf(YType.uint8, 'weights'), ['int'])),
                    ])
                    self.maximum_hops = None
                    self.weights = None
                    self._segment_path = lambda: "metric"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.Metric, ['maximum_hops', 'weights'], name, value)


            class Neighbor(Entity):
                """
                Specify a neighbor router
                
                .. attribute:: ipv4
                
                	
                	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Neighbor.Ipv4>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.Neighbor, self).__init__()

                    self.yang_name = "neighbor"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Eigrp.Neighbor.Ipv4))])
                    self._leafs = OrderedDict()

                    self.ipv4 = YList(self)
                    self._segment_path = lambda: "neighbor"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.Neighbor, [], name, value)


                class Ipv4(Entity):
                    """
                    
                    
                    .. attribute:: ipv4  (key)
                    
                    	Neighbor address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface
                    
                    	Specify interface for global address
                    	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Neighbor.Ipv4.Interface>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Neighbor.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "neighbor"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['ipv4']
                        self._child_classes = OrderedDict([("interface", ("interface", Native.Router.Eigrp.Neighbor.Ipv4.Interface))])
                        self._leafs = OrderedDict([
                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                        ])
                        self.ipv4 = None

                        self.interface = Native.Router.Eigrp.Neighbor.Ipv4.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Neighbor.Ipv4, ['ipv4'], name, value)


                    class Interface(Entity):
                        """
                        Specify interface for global address
                        
                        .. attribute:: appnav_compress
                        
                        	Service\-Context Virtual Interface Compress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: appnav_uncompress
                        
                        	Service\-Context Virtual Interface UnCompress
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: atm
                        
                        	ATM interface
                        	**type**\: str
                        
                        .. attribute:: atm_subinterface
                        
                        	
                        	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Neighbor.Ipv4.Interface.ATMSubinterface>`
                        
                        .. attribute:: atm_acr
                        
                        	ATM\-ACR interface
                        	**type**\: str
                        
                        	**pattern:** [0\-9]
                        
                        .. attribute:: atm_acrsubinterface
                        
                        	
                        	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Neighbor.Ipv4.Interface.ATMACRsubinterface>`
                        
                        .. attribute:: bdi
                        
                        	Bridge\-Domain interface
                        	**type**\: str
                        
                        .. attribute:: cem
                        
                        	CEM interface
                        	**type**\: str
                        
                        	**pattern:** ([0\-9]/){2}[0\-9]
                        
                        .. attribute:: cem_acr
                        
                        	CEM\-ACR interface
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: embedded_service_engine
                        
                        	cisco embedded service engine module
                        	**type**\: str
                        
                        .. attribute:: ethernet
                        
                        	IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: fastethernet
                        
                        	FastEthernet IEEE 802.3
                        	**type**\: str
                        
                        .. attribute:: gigabitethernet
                        
                        	GigabitEthernet IEEE 802.3z
                        	**type**\: str
                        
                        .. attribute:: fivegigabitethernet
                        
                        	Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twentyfivegige
                        
                        	Twenty Five GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: twogigabitethernet
                        
                        	Two GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: fortygigabitethernet
                        
                        	Forty GigabitEthernet 
                        	**type**\: str
                        
                        .. attribute:: hundredgige
                        
                        	Hundred GigabitEthernet
                        	**type**\: str
                        
                        .. attribute:: lisp
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\: str
                        
                        .. attribute:: lisp_subinterface
                        
                        	Locator/ID Separation Protocol Virtual Interface
                        	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Neighbor.Ipv4.Interface.LISPSubinterface>`
                        
                        .. attribute:: loopback
                        
                        	Loopback interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multilink
                        
                        	Multilink\-group interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nve
                        
                        	Network virtualization endpoint interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: overlay
                        
                        	Overlay interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_channel
                        
                        	Ethernet Channel of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port_channel_subinterface
                        
                        	
                        	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Neighbor.Ipv4.Interface.PortChannelSubinterface>`
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire Interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sm
                        
                        	SM Interface
                        	**type**\: str
                        
                        .. attribute:: cellular
                        
                        	Cellular Interface
                        	**type**\: str
                        
                        .. attribute:: serial
                        
                        	Serial interface
                        	**type**\: str
                        
                        .. attribute:: tengigabitethernet
                        
                        	Ten Gigabit Ethernet
                        	**type**\: str
                        
                        .. attribute:: tunnel
                        
                        	Tunnel interface
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_template
                        
                        	Virtual Template interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan
                        
                        	Iosxr Vlans
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtualportgroup
                        
                        	Virtual Port Group
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasileft
                        
                        	vasileft
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vasiright
                        
                        	vasiright
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.Neighbor.Ipv4.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Router.Eigrp.Neighbor.Ipv4.Interface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Router.Eigrp.Neighbor.Ipv4.Interface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Router.Eigrp.Neighbor.Ipv4.Interface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Router.Eigrp.Neighbor.Ipv4.Interface.PortChannelSubinterface))])
                            self._leafs = OrderedDict([
                                ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                                ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                                ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                                ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                                ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                                ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                                ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                                ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                                ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                                ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                                ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                                ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                                ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                                ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                                ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                                ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                                ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                                ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                                ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                                ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                                ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                                ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                                ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                                ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                                ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                                ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                                ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                                ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                                ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                            ])
                            self.appnav_compress = None
                            self.appnav_uncompress = None
                            self.atm = None
                            self.atm_acr = None
                            self.bdi = None
                            self.cem = None
                            self.cem_acr = None
                            self.embedded_service_engine = None
                            self.ethernet = None
                            self.fastethernet = None
                            self.gigabitethernet = None
                            self.fivegigabitethernet = None
                            self.twentyfivegige = None
                            self.twogigabitethernet = None
                            self.fortygigabitethernet = None
                            self.hundredgige = None
                            self.lisp = None
                            self.loopback = None
                            self.multilink = None
                            self.nve = None
                            self.overlay = None
                            self.port_channel = None
                            self.pseudowire = None
                            self.sm = None
                            self.cellular = None
                            self.serial = None
                            self.tengigabitethernet = None
                            self.tunnel = None
                            self.virtual_template = None
                            self.vlan = None
                            self.virtualportgroup = None
                            self.vasileft = None
                            self.vasiright = None

                            self.atm_subinterface = Native.Router.Eigrp.Neighbor.Ipv4.Interface.ATMSubinterface()
                            self.atm_subinterface.parent = self
                            self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                            self.atm_acrsubinterface = Native.Router.Eigrp.Neighbor.Ipv4.Interface.ATMACRsubinterface()
                            self.atm_acrsubinterface.parent = self
                            self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                            self.lisp_subinterface = Native.Router.Eigrp.Neighbor.Ipv4.Interface.LISPSubinterface()
                            self.lisp_subinterface.parent = self
                            self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                            self.port_channel_subinterface = Native.Router.Eigrp.Neighbor.Ipv4.Interface.PortChannelSubinterface()
                            self.port_channel_subinterface.parent = self
                            self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                            self._segment_path = lambda: "interface"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.Neighbor.Ipv4.Interface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                        class ATMSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.Neighbor.Ipv4.Interface.ATMSubinterface, self).__init__()

                                self.yang_name = "ATM-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                                ])
                                self.atm = None
                                self._segment_path = lambda: "ATM-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.Neighbor.Ipv4.Interface.ATMSubinterface, [u'atm'], name, value)


                        class ATMACRsubinterface(Entity):
                            """
                            
                            
                            .. attribute:: atm_acr
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.Neighbor.Ipv4.Interface.ATMACRsubinterface, self).__init__()

                                self.yang_name = "ATM-ACRsubinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                                ])
                                self.atm_acr = None
                                self._segment_path = lambda: "ATM-ACRsubinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.Neighbor.Ipv4.Interface.ATMACRsubinterface, [u'atm_acr'], name, value)


                        class LISPSubinterface(Entity):
                            """
                            Locator/ID Separation Protocol Virtual Interface
                            
                            .. attribute:: lisp
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.Neighbor.Ipv4.Interface.LISPSubinterface, self).__init__()

                                self.yang_name = "LISP-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                                ])
                                self.lisp = None
                                self._segment_path = lambda: "LISP-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.Neighbor.Ipv4.Interface.LISPSubinterface, [u'lisp'], name, value)


                        class PortChannelSubinterface(Entity):
                            """
                            
                            
                            .. attribute:: port_channel
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eigrp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Eigrp.Neighbor.Ipv4.Interface.PortChannelSubinterface, self).__init__()

                                self.yang_name = "Port-channel-subinterface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                                ])
                                self.port_channel = None
                                self._segment_path = lambda: "Port-channel-subinterface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Eigrp.Neighbor.Ipv4.Interface.PortChannelSubinterface, [u'port_channel'], name, value)


            class Network(Entity):
                """
                Enable routing on an IP network
                
                .. attribute:: number  (key)
                
                	Network number
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: wild_card
                
                	EIGRP wild card bits
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.Network, self).__init__()

                    self.yang_name = "network"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.str, 'number'), ['str'])),
                        ('wild_card', (YLeaf(YType.str, 'wild-card'), ['str'])),
                    ])
                    self.number = None
                    self.wild_card = None
                    self._segment_path = lambda: "network" + "[number='" + str(self.number) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.Network, ['number', 'wild_card'], name, value)


            class OffsetList(Entity):
                """
                Add or subtract offset from EIGRP metrics
                
                .. attribute:: nsr_list
                
                	
                	**type**\: list of  		 :py:class:`NsrList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.OffsetList.NsrList>`
                
                .. attribute:: ol_acl
                
                	
                	**type**\: list of  		 :py:class:`OlAcl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.OffsetList.OlAcl>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.OffsetList, self).__init__()

                    self.yang_name = "offset-list"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("nsr-list", ("nsr_list", Native.Router.Eigrp.OffsetList.NsrList)), ("ol-acl", ("ol_acl", Native.Router.Eigrp.OffsetList.OlAcl))])
                    self._leafs = OrderedDict()

                    self.nsr_list = YList(self)
                    self.ol_acl = YList(self)
                    self._segment_path = lambda: "offset-list"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.OffsetList, [], name, value)


                class NsrList(Entity):
                    """
                    
                    
                    .. attribute:: nsr_list  (key)
                    
                    	Access list of networks to apply offset (extended range)
                    	**type**\: int
                    
                    	**range:** 1300..1999
                    
                    .. attribute:: in_
                    
                    	Perform offset on incoming updates
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: out
                    
                    	Perform offset on outgoing updates
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.OffsetList.NsrList, self).__init__()

                        self.yang_name = "nsr-list"
                        self.yang_parent_name = "offset-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['nsr_list']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('nsr_list', (YLeaf(YType.uint16, 'nsr-list'), ['int'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                            ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ])
                        self.nsr_list = None
                        self.in_ = None
                        self.out = None
                        self._segment_path = lambda: "nsr-list" + "[nsr-list='" + str(self.nsr_list) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.OffsetList.NsrList, ['nsr_list', 'in_', 'out'], name, value)


                class OlAcl(Entity):
                    """
                    
                    
                    .. attribute:: ol_acl  (key)
                    
                    	Access\-list name
                    	**type**\: str
                    
                    .. attribute:: in_
                    
                    	Perform offset on incoming updates
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: out
                    
                    	Perform offset on outgoing updates
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.OffsetList.OlAcl, self).__init__()

                        self.yang_name = "ol-acl"
                        self.yang_parent_name = "offset-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['ol_acl']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ol_acl', (YLeaf(YType.str, 'ol-acl'), ['str'])),
                            ('in_', (YLeaf(YType.empty, 'in'), ['Empty'])),
                            ('out', (YLeaf(YType.empty, 'out'), ['Empty'])),
                        ])
                        self.ol_acl = None
                        self.in_ = None
                        self.out = None
                        self._segment_path = lambda: "ol-acl" + "[ol-acl='" + str(self.ol_acl) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.OffsetList.OlAcl, ['ol_acl', 'in_', 'out'], name, value)


            class Redistribute(Entity):
                """
                Redistribute IPv4 routes from another routing protocol
                
                .. attribute:: bgp
                
                	Border Gateway Protocol (BGP)
                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Redistribute.Bgp>`
                
                .. attribute:: connected
                
                	Connected
                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Redistribute.Connected>`
                
                	**presence node**\: True
                
                .. attribute:: eigrp
                
                	Autonomous system number
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: isis
                
                	ISO IS\-IS
                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Redistribute.Isis>`
                
                	**presence node**\: True
                
                .. attribute:: lisp
                
                	Locator ID Separation Protocol (LISP)
                	**type**\:  :py:class:`Lisp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Redistribute.Lisp>`
                
                	**presence node**\: True
                
                .. attribute:: mobile
                
                	Mobile routes
                	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Redistribute.Mobile>`
                
                	**presence node**\: True
                
                .. attribute:: odr
                
                	On Demand stub Routes
                	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Redistribute.Odr>`
                
                	**presence node**\: True
                
                .. attribute:: ospf
                
                	Process ID
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: rip
                
                	Routing Information Protocol (RIP)
                	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Redistribute.Rip>`
                
                	**presence node**\: True
                
                .. attribute:: static
                
                	Static routes
                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Redistribute.Static>`
                
                	**presence node**\: True
                
                .. attribute:: vrf
                
                	Specify a source virtual routing/forwarding instance
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Redistribute.Vrf>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.Redistribute, self).__init__()

                    self.yang_name = "redistribute"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bgp", ("bgp", Native.Router.Eigrp.Redistribute.Bgp)), ("connected", ("connected", Native.Router.Eigrp.Redistribute.Connected)), ("isis", ("isis", Native.Router.Eigrp.Redistribute.Isis)), ("lisp", ("lisp", Native.Router.Eigrp.Redistribute.Lisp)), ("mobile", ("mobile", Native.Router.Eigrp.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Eigrp.Redistribute.Odr)), ("rip", ("rip", Native.Router.Eigrp.Redistribute.Rip)), ("static", ("static", Native.Router.Eigrp.Redistribute.Static)), ("vrf", ("vrf", Native.Router.Eigrp.Redistribute.Vrf))])
                    self._leafs = OrderedDict([
                        ('eigrp', (YLeaf(YType.uint16, 'eigrp'), ['int'])),
                        ('ospf', (YLeaf(YType.uint16, 'ospf'), ['int'])),
                    ])
                    self.eigrp = None
                    self.ospf = None

                    self.connected = None
                    self._children_name_map["connected"] = "connected"

                    self.isis = None
                    self._children_name_map["isis"] = "isis"

                    self.lisp = None
                    self._children_name_map["lisp"] = "lisp"

                    self.mobile = None
                    self._children_name_map["mobile"] = "mobile"

                    self.odr = None
                    self._children_name_map["odr"] = "odr"

                    self.rip = None
                    self._children_name_map["rip"] = "rip"

                    self.static = None
                    self._children_name_map["static"] = "static"

                    self.vrf = Native.Router.Eigrp.Redistribute.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.bgp = YList(self)
                    self._segment_path = lambda: "redistribute"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.Redistribute, ['eigrp', 'ospf'], name, value)


                class Bgp(Entity):
                    """
                    Border Gateway Protocol (BGP)
                    
                    .. attribute:: rdr_as  (key)
                    
                    	Autonomous system number
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: str
                    
                    .. attribute:: metric
                    
                    	Metric for redistributed routes
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Redistribute.Bgp.Metric>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    .. attribute:: rd_lesser_1_period_0_xx_period_yy_greater_
                    
                    	Autonomous system number
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Redistribute.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['rdr_as']
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Eigrp.Redistribute.Bgp.Metric))])
                        self._leafs = OrderedDict([
                            ('rdr_as', (YLeaf(YType.str, 'rdr-as'), ['int','str'])),
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ('rd_lesser_1_period_0_xx_period_yy_greater_', (YLeaf(YType.empty, 'rd-LESSER_1_PERIOD_0-XX_PERIOD_YY_GREATER_'), ['Empty'])),
                        ])
                        self.rdr_as = None
                        self.route_map = None
                        self.rd_lesser_1_period_0_xx_period_yy_greater_ = None

                        self.metric = Native.Router.Eigrp.Redistribute.Bgp.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"
                        self._segment_path = lambda: "bgp" + "[rdr-as='" + str(self.rdr_as) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Redistribute.Bgp, ['rdr_as', 'route_map', 'rd_lesser_1_period_0_xx_period_yy_greater_'], name, value)


                    class Metric(Entity):
                        """
                        Metric for redistributed routes
                        
                        .. attribute:: bandwith
                        
                        	Bandwidth metric in Kbits per second
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: delay
                        
                        	EIGRP delay metric, in 10 microsecond units
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reliability
                        
                        	EIGRP reliability metric where 255 is 100% reliable
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: effective
                        
                        	EIGRP Effective bandwidth metric (Loading) where 255 is 100% loaded
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: mtu
                        
                        	EIGRP MTU of the path
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        

                        """

                        _prefix = 'ios-eigrp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Eigrp.Redistribute.Bgp.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "bgp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bandwith', (YLeaf(YType.uint32, 'bandwith'), ['int'])),
                                ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                ('reliability', (YLeaf(YType.uint8, 'reliability'), ['int'])),
                                ('effective', (YLeaf(YType.uint8, 'Effective'), ['int'])),
                                ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                            ])
                            self.bandwith = None
                            self.delay = None
                            self.reliability = None
                            self.effective = None
                            self.mtu = None
                            self._segment_path = lambda: "metric"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Eigrp.Redistribute.Bgp.Metric, ['bandwith', 'delay', 'reliability', 'effective', 'mtu'], name, value)


                class Connected(Entity):
                    """
                    Connected
                    
                    .. attribute:: metric
                    
                    	Metric for redistributed routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Redistribute.Connected, self).__init__()

                        self.yang_name = "connected"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                            ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                        ])
                        self.metric = None
                        self.route_map = None
                        self._segment_path = lambda: "connected"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Redistribute.Connected, ['metric', 'route_map'], name, value)


                class Isis(Entity):
                    """
                    ISO IS\-IS
                    
                    .. attribute:: is_tag
                    
                    	ISO routing area tag
                    	**type**\: str
                    
                    .. attribute:: level_1
                    
                    	IS\-IS level\-1 routes only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level_1_2
                    
                    	IS\-IS level\-1 and level\-2 routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level_2
                    
                    	IS\-IS level\-2 routes only
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: metric
                    
                    	Metric for redistributed routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Redistribute.Isis, self).__init__()

                        self.yang_name = "isis"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('is_tag', (YLeaf(YType.str, 'is-tag'), ['str'])),
                            ('level_1', (YLeaf(YType.empty, 'level-1'), ['Empty'])),
                            ('level_1_2', (YLeaf(YType.empty, 'level-1-2'), ['Empty'])),
                            ('level_2', (YLeaf(YType.empty, 'level-2'), ['Empty'])),
                            ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                            ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                        ])
                        self.is_tag = None
                        self.level_1 = None
                        self.level_1_2 = None
                        self.level_2 = None
                        self.metric = None
                        self.route_map = None
                        self._segment_path = lambda: "isis"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Redistribute.Isis, ['is_tag', 'level_1', 'level_1_2', 'level_2', 'metric', 'route_map'], name, value)


                class Lisp(Entity):
                    """
                    Locator ID Separation Protocol (LISP)
                    
                    .. attribute:: metric
                    
                    	Metric for redistributed routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Redistribute.Lisp, self).__init__()

                        self.yang_name = "lisp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                            ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                        ])
                        self.metric = None
                        self.route_map = None
                        self._segment_path = lambda: "lisp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Redistribute.Lisp, ['metric', 'route_map'], name, value)


                class Mobile(Entity):
                    """
                    Mobile routes
                    
                    .. attribute:: metric
                    
                    	Metric for redistributed routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Redistribute.Mobile, self).__init__()

                        self.yang_name = "mobile"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                            ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                        ])
                        self.metric = None
                        self.route_map = None
                        self._segment_path = lambda: "mobile"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Redistribute.Mobile, ['metric', 'route_map'], name, value)


                class Odr(Entity):
                    """
                    On Demand stub Routes
                    
                    .. attribute:: metric
                    
                    	Metric for redistributed routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Redistribute.Odr, self).__init__()

                        self.yang_name = "odr"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                            ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                        ])
                        self.metric = None
                        self.route_map = None
                        self._segment_path = lambda: "odr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Redistribute.Odr, ['metric', 'route_map'], name, value)


                class Rip(Entity):
                    """
                    Routing Information Protocol (RIP)
                    
                    .. attribute:: metric
                    
                    	Metric for redistributed routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Redistribute.Rip, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                            ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                        ])
                        self.metric = None
                        self.route_map = None
                        self._segment_path = lambda: "rip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Redistribute.Rip, ['metric', 'route_map'], name, value)


                class Static(Entity):
                    """
                    Static routes
                    
                    .. attribute:: metric
                    
                    	Metric for redistributed routes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Redistribute.Static, self).__init__()

                        self.yang_name = "static"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('metric', (YLeaf(YType.empty, 'metric'), ['Empty'])),
                            ('route_map', (YLeaf(YType.empty, 'route-map'), ['Empty'])),
                        ])
                        self.metric = None
                        self.route_map = None
                        self._segment_path = lambda: "static"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Redistribute.Static, ['metric', 'route_map'], name, value)


                class Vrf(Entity):
                    """
                    Specify a source virtual routing/forwarding instance
                    
                    .. attribute:: name
                    
                    	Virtual Routing/Forwarding instance name
                    	**type**\: str
                    
                    .. attribute:: global_
                    
                    	global VRF
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Redistribute.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                        ])
                        self.name = None
                        self.global_ = None
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Redistribute.Vrf, ['name', 'global_'], name, value)


            class SummaryMetric(Entity):
                """
                Specify summary to apply metric/filtering
                
                .. attribute:: ipv4
                
                	
                	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.SummaryMetric.Ipv4>`
                
                .. attribute:: a_period_b_period_c_period_d_slash_nn
                
                	Summary <network>/<length>, e.g., 192.168.0.0/16
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.SummaryMetric, self).__init__()

                    self.yang_name = "summary-metric"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Eigrp.SummaryMetric.Ipv4))])
                    self._leafs = OrderedDict([
                        ('a_period_b_period_c_period_d_slash_nn', (YLeaf(YType.empty, 'A_PERIOD_B_PERIOD_C_PERIOD_D_SLASH_nn'), ['Empty'])),
                    ])
                    self.a_period_b_period_c_period_d_slash_nn = None

                    self.ipv4 = YList(self)
                    self._segment_path = lambda: "summary-metric"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.SummaryMetric, ['a_period_b_period_c_period_d_slash_nn'], name, value)


                class Ipv4(Entity):
                    """
                    
                    
                    .. attribute:: ipv4  (key)
                    
                    	Summary to configure static metric
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mask
                    
                    	Network mask
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.SummaryMetric.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "summary-metric"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['ipv4']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                        ])
                        self.ipv4 = None
                        self.mask = None
                        self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.SummaryMetric.Ipv4, ['ipv4', 'mask'], name, value)


            class Timers(Entity):
                """
                Adjust routing timers
                
                .. attribute:: active_time
                
                	time limit for active state
                	**type**\:  :py:class:`ActiveTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Timers.ActiveTime>`
                
                .. attribute:: graceful_restart
                
                	EIGRP Graceful Restart timer
                	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Timers.GracefulRestart>`
                
                .. attribute:: nsf
                
                	EIGRP NSF timer
                	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.Timers.Nsf>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.Timers, self).__init__()

                    self.yang_name = "timers"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("active-time", ("active_time", Native.Router.Eigrp.Timers.ActiveTime)), ("graceful-restart", ("graceful_restart", Native.Router.Eigrp.Timers.GracefulRestart)), ("nsf", ("nsf", Native.Router.Eigrp.Timers.Nsf))])
                    self._leafs = OrderedDict()

                    self.active_time = Native.Router.Eigrp.Timers.ActiveTime()
                    self.active_time.parent = self
                    self._children_name_map["active_time"] = "active-time"

                    self.graceful_restart = Native.Router.Eigrp.Timers.GracefulRestart()
                    self.graceful_restart.parent = self
                    self._children_name_map["graceful_restart"] = "graceful-restart"

                    self.nsf = Native.Router.Eigrp.Timers.Nsf()
                    self.nsf.parent = self
                    self._children_name_map["nsf"] = "nsf"
                    self._segment_path = lambda: "timers"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.Timers, [], name, value)


                class ActiveTime(Entity):
                    """
                    time limit for active state
                    
                    .. attribute:: atimer
                    
                    	active state time limit in minutes
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: disabled
                    
                    	disable time limit for active state
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Timers.ActiveTime, self).__init__()

                        self.yang_name = "active-time"
                        self.yang_parent_name = "timers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atimer', (YLeaf(YType.uint16, 'atimer'), ['int'])),
                            ('disabled', (YLeaf(YType.empty, 'disabled'), ['Empty'])),
                        ])
                        self.atimer = None
                        self.disabled = None
                        self._segment_path = lambda: "active-time"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Timers.ActiveTime, ['atimer', 'disabled'], name, value)


                class GracefulRestart(Entity):
                    """
                    EIGRP Graceful Restart timer
                    
                    .. attribute:: purge_time
                    
                    	EIGRP stale route purge time
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Timers.GracefulRestart, self).__init__()

                        self.yang_name = "graceful-restart"
                        self.yang_parent_name = "timers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('purge_time', (YLeaf(YType.empty, 'purge-time'), ['Empty'])),
                        ])
                        self.purge_time = None
                        self._segment_path = lambda: "graceful-restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Timers.GracefulRestart, ['purge_time'], name, value)


                class Nsf(Entity):
                    """
                    EIGRP NSF timer
                    
                    .. attribute:: converge
                    
                    	EIGRP time limit for convergence after switchover
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: signal
                    
                    	EIGRP time limit for signaling NSF restart
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.Timers.Nsf, self).__init__()

                        self.yang_name = "nsf"
                        self.yang_parent_name = "timers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('converge', (YLeaf(YType.empty, 'converge'), ['Empty'])),
                            ('signal', (YLeaf(YType.empty, 'signal'), ['Empty'])),
                        ])
                        self.converge = None
                        self.signal = None
                        self._segment_path = lambda: "nsf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.Timers.Nsf, ['converge', 'signal'], name, value)


            class TrafficShare(Entity):
                """
                How to compute traffic share over alternate paths
                
                .. attribute:: balanced
                
                	Share inversely proportional to metric
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: min
                
                	All traffic shared among min metric paths
                	**type**\:  :py:class:`Min <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Eigrp.TrafficShare.Min>`
                
                

                """

                _prefix = 'ios-eigrp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Eigrp.TrafficShare, self).__init__()

                    self.yang_name = "traffic-share"
                    self.yang_parent_name = "eigrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("min", ("min", Native.Router.Eigrp.TrafficShare.Min))])
                    self._leafs = OrderedDict([
                        ('balanced', (YLeaf(YType.empty, 'balanced'), ['Empty'])),
                    ])
                    self.balanced = None

                    self.min = Native.Router.Eigrp.TrafficShare.Min()
                    self.min.parent = self
                    self._children_name_map["min"] = "min"
                    self._segment_path = lambda: "traffic-share"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Eigrp.TrafficShare, ['balanced'], name, value)


                class Min(Entity):
                    """
                    All traffic shared among min metric paths
                    
                    .. attribute:: across_interfaces
                    
                    	Use different interfaces for equal\-cost paths
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eigrp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Eigrp.TrafficShare.Min, self).__init__()

                        self.yang_name = "min"
                        self.yang_parent_name = "traffic-share"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                        ])
                        self.across_interfaces = None
                        self._segment_path = lambda: "min"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Eigrp.TrafficShare.Min, ['across_interfaces'], name, value)


        class Rip(Entity):
            """
            Routing Information Protocol (RIP)
            
            .. attribute:: auto_summary
            
            	Enable automatic network number summarization
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: maximum_paths
            
            	Forward packets over multiple paths
            	**type**\: int
            
            	**range:** 1..32
            
            .. attribute:: neighbor
            
            	Specify a neighbor router
            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Neighbor>`
            
            .. attribute:: network
            
            	Enable routing on an IP network
            	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Network>`
            
            .. attribute:: validate_update_source
            
            	Perform sanity checks against source address of routing updates
            	**type**\: bool
            
            .. attribute:: default_information
            
            	Control distribution of default information
            	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.DefaultInformation>`
            
            .. attribute:: default_metric
            
            	Set metric of redistributed routes
            	**type**\: int
            
            	**range:** 1..4294967295
            
            .. attribute:: distance
            
            	Define an administrative distance
            	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Distance>`
            
            .. attribute:: distribute_list
            
            	Filter networks in routing updates
            	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.DistributeList>`
            
            .. attribute:: offset_list
            
            	Add or subtract offset from RIP metrics
            	**type**\: list of  		 :py:class:`OffsetList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.OffsetList>`
            
            .. attribute:: redistribute
            
            	Redistribute information from another routing protocol
            	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute>`
            
            .. attribute:: timers
            
            	Adjust routing timers
            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Timers>`
            
            .. attribute:: version
            
            	Set routing protocol version
            	**type**\: int
            
            	**range:** 1..2
            
            .. attribute:: flash_update_threshold
            
            	Specify flash update threshold in second
            	**type**\: int
            
            	**range:** 0..30
            
            .. attribute:: input_queue
            
            	Specify input queue depth
            	**type**\: int
            
            	**range:** 0..1024
            
            .. attribute:: output_delay
            
            	Interpacket delay for RIP updates
            	**type**\: int
            
            	**range:** 8..50
            
            .. attribute:: passive_interface
            
            	Suppress routing updates on an interface
            	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.PassiveInterface>`
            
            .. attribute:: disable
            
            	
            	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Disable>`
            
            .. attribute:: traffic_share
            
            	How to compute traffic share over alternate paths
            	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.TrafficShare>`
            
            .. attribute:: address_family
            
            	Enter Address Family command mode
            	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily>`
            
            .. attribute:: default
            
            	Set a command to its defaults
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-rip'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Router.Rip, self).__init__()

                self.yang_name = "rip"
                self.yang_parent_name = "router"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Rip.Neighbor)), ("network", ("network", Native.Router.Rip.Network)), ("default-information", ("default_information", Native.Router.Rip.DefaultInformation)), ("distance", ("distance", Native.Router.Rip.Distance)), ("distribute-list", ("distribute_list", Native.Router.Rip.DistributeList)), ("offset-list", ("offset_list", Native.Router.Rip.OffsetList)), ("redistribute", ("redistribute", Native.Router.Rip.Redistribute)), ("timers", ("timers", Native.Router.Rip.Timers)), ("passive-interface", ("passive_interface", Native.Router.Rip.PassiveInterface)), ("disable", ("disable", Native.Router.Rip.Disable)), ("traffic-share", ("traffic_share", Native.Router.Rip.TrafficShare)), ("address-family", ("address_family", Native.Router.Rip.AddressFamily)), ("default", ("default", Native.Router.Rip.Default))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('auto_summary', (YLeaf(YType.empty, 'auto-summary'), ['Empty'])),
                    ('maximum_paths', (YLeaf(YType.uint8, 'maximum-paths'), ['int'])),
                    ('validate_update_source', (YLeaf(YType.boolean, 'validate-update-source'), ['bool'])),
                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                    ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                    ('flash_update_threshold', (YLeaf(YType.uint8, 'flash-update-threshold'), ['int'])),
                    ('input_queue', (YLeaf(YType.uint16, 'input-queue'), ['int'])),
                    ('output_delay', (YLeaf(YType.uint8, 'output-delay'), ['int'])),
                ])
                self.auto_summary = None
                self.maximum_paths = None
                self.validate_update_source = None
                self.default_metric = None
                self.version = None
                self.flash_update_threshold = None
                self.input_queue = None
                self.output_delay = None

                self.default_information = Native.Router.Rip.DefaultInformation()
                self.default_information.parent = self
                self._children_name_map["default_information"] = "default-information"

                self.distance = Native.Router.Rip.Distance()
                self.distance.parent = self
                self._children_name_map["distance"] = "distance"

                self.distribute_list = Native.Router.Rip.DistributeList()
                self.distribute_list.parent = self
                self._children_name_map["distribute_list"] = "distribute-list"

                self.redistribute = Native.Router.Rip.Redistribute()
                self.redistribute.parent = self
                self._children_name_map["redistribute"] = "redistribute"

                self.timers = Native.Router.Rip.Timers()
                self.timers.parent = self
                self._children_name_map["timers"] = "timers"

                self.passive_interface = Native.Router.Rip.PassiveInterface()
                self.passive_interface.parent = self
                self._children_name_map["passive_interface"] = "passive-interface"

                self.disable = Native.Router.Rip.Disable()
                self.disable.parent = self
                self._children_name_map["disable"] = "disable"

                self.traffic_share = Native.Router.Rip.TrafficShare()
                self.traffic_share.parent = self
                self._children_name_map["traffic_share"] = "traffic-share"

                self.address_family = Native.Router.Rip.AddressFamily()
                self.address_family.parent = self
                self._children_name_map["address_family"] = "address-family"

                self.default = Native.Router.Rip.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.neighbor = YList(self)
                self.network = YList(self)
                self.offset_list = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-rip:rip"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Router.Rip, ['auto_summary', 'maximum_paths', 'validate_update_source', 'default_metric', 'version', 'flash_update_threshold', 'input_queue', 'output_delay'], name, value)


            class Neighbor(Entity):
                """
                Specify a neighbor router
                
                .. attribute:: ip  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.Neighbor, self).__init__()

                    self.yang_name = "neighbor"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['ip']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                    ])
                    self.ip = None
                    self._segment_path = lambda: "neighbor" + "[ip='" + str(self.ip) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.Neighbor, ['ip'], name, value)


            class Network(Entity):
                """
                Enable routing on an IP network
                
                .. attribute:: ip  (key)
                
                	
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.Network, self).__init__()

                    self.yang_name = "network"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['ip']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                    ])
                    self.ip = None
                    self._segment_path = lambda: "network" + "[ip='" + str(self.ip) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.Network, ['ip'], name, value)


            class DefaultInformation(Entity):
                """
                Control distribution of default information
                
                .. attribute:: originate
                
                	Distribute a default route
                	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.DefaultInformation.Originate>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.DefaultInformation, self).__init__()

                    self.yang_name = "default-information"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("originate", ("originate", Native.Router.Rip.DefaultInformation.Originate))])
                    self._leafs = OrderedDict()

                    self.originate = None
                    self._children_name_map["originate"] = "originate"
                    self._segment_path = lambda: "default-information"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.DefaultInformation, [], name, value)


                class Originate(Entity):
                    """
                    Distribute a default route
                    
                    .. attribute:: route_map
                    
                    	Route\-map reference
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.DefaultInformation.Originate, self).__init__()

                        self.yang_name = "originate"
                        self.yang_parent_name = "default-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None
                        self._segment_path = lambda: "originate"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default-information/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.DefaultInformation.Originate, ['route_map'], name, value)


            class Distance(Entity):
                """
                Define an administrative distance
                
                .. attribute:: distance_leaf
                
                	
                	**type**\: int
                
                	**range:** 1..255
                
                .. attribute:: distance_list
                
                	
                	**type**\: list of  		 :py:class:`DistanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Distance.DistanceList>`
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.Distance, self).__init__()

                    self.yang_name = "distance"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("distance-list", ("distance_list", Native.Router.Rip.Distance.DistanceList))])
                    self._leafs = OrderedDict([
                        ('distance_leaf', (YLeaf(YType.uint8, 'distance-leaf'), ['int'])),
                    ])
                    self.distance_leaf = None

                    self.distance_list = YList(self)
                    self._segment_path = lambda: "distance"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.Distance, ['distance_leaf'], name, value)


                class DistanceList(Entity):
                    """
                    
                    
                    .. attribute:: number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: ip  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mask  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Distance.DistanceList, self).__init__()

                        self.yang_name = "distance-list"
                        self.yang_parent_name = "distance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['number','ip','mask']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int','str'])),
                        ])
                        self.number = None
                        self.ip = None
                        self.mask = None
                        self.access_list = None
                        self._segment_path = lambda: "distance-list" + "[number='" + str(self.number) + "']" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/distance/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Distance.DistanceList, ['number', 'ip', 'mask', 'access_list'], name, value)


            class DistributeList(Entity):
                """
                Filter networks in routing updates
                
                .. attribute:: accesslist
                
                	
                	**type**\: list of  		 :py:class:`Accesslist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.DistributeList.Accesslist>`
                
                .. attribute:: accesslist_ifname
                
                	
                	**type**\: list of  		 :py:class:`AccesslistIfname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.DistributeList.AccesslistIfname>`
                
                .. attribute:: accesslist_prefix_gateway
                
                	
                	**type**\: list of  		 :py:class:`AccesslistPrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.DistributeList.AccesslistPrefixGateway>`
                
                .. attribute:: accesslist_prefix_gateway_ifname
                
                	
                	**type**\: list of  		 :py:class:`AccesslistPrefixGatewayIfname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.DistributeList.AccesslistPrefixGatewayIfname>`
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.DistributeList, self).__init__()

                    self.yang_name = "distribute-list"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("accesslist", ("accesslist", Native.Router.Rip.DistributeList.Accesslist)), ("accesslist-ifname", ("accesslist_ifname", Native.Router.Rip.DistributeList.AccesslistIfname)), ("accesslist-prefix-gateway", ("accesslist_prefix_gateway", Native.Router.Rip.DistributeList.AccesslistPrefixGateway)), ("accesslist-prefix-gateway-ifname", ("accesslist_prefix_gateway_ifname", Native.Router.Rip.DistributeList.AccesslistPrefixGatewayIfname))])
                    self._leafs = OrderedDict()

                    self.accesslist = YList(self)
                    self.accesslist_ifname = YList(self)
                    self.accesslist_prefix_gateway = YList(self)
                    self.accesslist_prefix_gateway_ifname = YList(self)
                    self._segment_path = lambda: "distribute-list"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.DistributeList, [], name, value)


                class Accesslist(Entity):
                    """
                    
                    
                    .. attribute:: in_out  (key)
                    
                    	
                    	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199
                    
                    		**type**\: int
                    
                    			**range:** 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.DistributeList.Accesslist, self).__init__()

                        self.yang_name = "accesslist"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['in_out']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                            ('id', (YLeaf(YType.str, 'id'), ['int','int','str'])),
                        ])
                        self.in_out = None
                        self.id = None
                        self._segment_path = lambda: "accesslist" + "[in-out='" + str(self.in_out) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/distribute-list/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.DistributeList.Accesslist, ['in_out', 'id'], name, value)


                class AccesslistIfname(Entity):
                    """
                    
                    
                    .. attribute:: in_out  (key)
                    
                    	
                    	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                    
                    .. attribute:: interface  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: interface_routing_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: isis_tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding Instance
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199
                    
                    		**type**\: int
                    
                    			**range:** 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.DistributeList.AccesslistIfname, self).__init__()

                        self.yang_name = "accesslist-ifname"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['in_out','interface']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ('interface_routing_id', (YLeaf(YType.uint8, 'interface-routing-id'), ['int'])),
                            ('isis_tag', (YLeaf(YType.str, 'isis-tag'), ['str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ('id', (YLeaf(YType.str, 'id'), ['int','int','str'])),
                        ])
                        self.in_out = None
                        self.interface = None
                        self.interface_routing_id = None
                        self.isis_tag = None
                        self.vrf = None
                        self.id = None
                        self._segment_path = lambda: "accesslist-ifname" + "[in-out='" + str(self.in_out) + "']" + "[interface='" + str(self.interface) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/distribute-list/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.DistributeList.AccesslistIfname, ['in_out', 'interface', 'interface_routing_id', 'isis_tag', 'vrf', 'id'], name, value)


                class AccesslistPrefixGateway(Entity):
                    """
                    
                    
                    .. attribute:: in_out  (key)
                    
                    	
                    	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                    
                    .. attribute:: prefix_gateway
                    
                    	
                    	**type**\:  :py:class:`PrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.DistributeList.AccesslistPrefixGateway.PrefixGateway>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.DistributeList.AccesslistPrefixGateway, self).__init__()

                        self.yang_name = "accesslist-prefix-gateway"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['in_out']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                            ('prefix_gateway', (YLeaf(YType.enumeration, 'prefix-gateway'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.DistributeList.AccesslistPrefixGateway.PrefixGateway')])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.in_out = None
                        self.prefix_gateway = None
                        self.name = None
                        self._segment_path = lambda: "accesslist-prefix-gateway" + "[in-out='" + str(self.in_out) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/distribute-list/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.DistributeList.AccesslistPrefixGateway, ['in_out', 'prefix_gateway', 'name'], name, value)

                    class PrefixGateway(Enum):
                        """
                        PrefixGateway (Enum Class)

                        .. data:: prefix = 0

                        .. data:: gateway = 1

                        .. data:: route_map = 2

                        """

                        prefix = Enum.YLeaf(0, "prefix")

                        gateway = Enum.YLeaf(1, "gateway")

                        route_map = Enum.YLeaf(2, "route-map")



                class AccesslistPrefixGatewayIfname(Entity):
                    """
                    
                    
                    .. attribute:: in_out  (key)
                    
                    	
                    	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                    
                    .. attribute:: interface  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: prefix_gateway
                    
                    	
                    	**type**\:  :py:class:`PrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.DistributeList.AccesslistPrefixGatewayIfname.PrefixGateway>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: name
                    
                    	
                    	**type**\: str
                    
                    	**mandatory**\: True
                    
                    .. attribute:: interface_routing_id
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: isis_tag
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding Instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.DistributeList.AccesslistPrefixGatewayIfname, self).__init__()

                        self.yang_name = "accesslist-prefix-gateway-ifname"
                        self.yang_parent_name = "distribute-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['in_out','interface']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ('prefix_gateway', (YLeaf(YType.enumeration, 'prefix-gateway'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.DistributeList.AccesslistPrefixGatewayIfname.PrefixGateway')])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('interface_routing_id', (YLeaf(YType.uint8, 'interface-routing-id'), ['int'])),
                            ('isis_tag', (YLeaf(YType.str, 'isis-tag'), ['str'])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.in_out = None
                        self.interface = None
                        self.prefix_gateway = None
                        self.name = None
                        self.interface_routing_id = None
                        self.isis_tag = None
                        self.vrf = None
                        self._segment_path = lambda: "accesslist-prefix-gateway-ifname" + "[in-out='" + str(self.in_out) + "']" + "[interface='" + str(self.interface) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/distribute-list/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.DistributeList.AccesslistPrefixGatewayIfname, ['in_out', 'interface', 'prefix_gateway', 'name', 'interface_routing_id', 'isis_tag', 'vrf'], name, value)

                    class PrefixGateway(Enum):
                        """
                        PrefixGateway (Enum Class)

                        .. data:: prefix = 0

                        .. data:: gateway = 1

                        .. data:: route_map = 2

                        """

                        prefix = Enum.YLeaf(0, "prefix")

                        gateway = Enum.YLeaf(1, "gateway")

                        route_map = Enum.YLeaf(2, "route-map")



            class OffsetList(Entity):
                """
                Add or subtract offset from RIP metrics
                
                .. attribute:: in_out  (key)
                
                	
                	**type**\:  :py:class:`OffsetListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_rip.OffsetListInOutType>`
                
                .. attribute:: offset
                
                	
                	**type**\: int
                
                	**range:** 0..16
                
                	**mandatory**\: True
                
                .. attribute:: id
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..99
                
                		**type**\: int
                
                			**range:** 1300..1999
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                	**mandatory**\: True
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.OffsetList, self).__init__()

                    self.yang_name = "offset-list"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['in_out']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_rip', 'OffsetListInOutType', '')])),
                        ('offset', (YLeaf(YType.uint8, 'offset'), ['int'])),
                        ('id', (YLeaf(YType.str, 'id'), ['int','int','str'])),
                    ])
                    self.in_out = None
                    self.offset = None
                    self.id = None
                    self._segment_path = lambda: "offset-list" + "[in-out='" + str(self.in_out) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.OffsetList, ['in_out', 'offset', 'id'], name, value)


            class Redistribute(Entity):
                """
                Redistribute information from another routing protocol
                
                .. attribute:: rip_metric_route_map
                
                	
                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.RipMetricRouteMap>`
                
                .. attribute:: connected
                
                	Connected
                	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Connected>`
                
                	**presence node**\: True
                
                .. attribute:: bgp
                
                	Border Gateway Protocol (BGP)
                	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Bgp>`
                
                .. attribute:: eigrp
                
                	Enhanced Interior Gateway Routing Protocol (EIGRP)
                	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Eigrp>`
                
                .. attribute:: isis
                
                	ISO IS\-IS
                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Isis>`
                
                	**presence node**\: True
                
                .. attribute:: iso_igrp
                
                	IGRP for OSI networks
                	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.IsoIgrp>`
                
                	**presence node**\: True
                
                .. attribute:: mobile
                
                	Mobile routes
                	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Mobile>`
                
                	**presence node**\: True
                
                .. attribute:: odr
                
                	On Demand stub Routes
                	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Odr>`
                
                	**presence node**\: True
                
                .. attribute:: ospf
                
                	Open Shortest Path First (OSPF)
                	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf>`
                
                .. attribute:: static
                
                	Static routes
                	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Static>`
                
                	**presence node**\: True
                
                .. attribute:: rip
                
                	Routing Information Protocol (RIP)
                	**type**\:  :py:class:`Rip_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Rip_>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.Redistribute, self).__init__()

                    self.yang_name = "redistribute"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.RipMetricRouteMap)), ("connected", ("connected", Native.Router.Rip.Redistribute.Connected)), ("bgp", ("bgp", Native.Router.Rip.Redistribute.Bgp)), ("eigrp", ("eigrp", Native.Router.Rip.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Rip.Redistribute.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Rip.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Rip.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Rip.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Rip.Redistribute.Ospf)), ("static", ("static", Native.Router.Rip.Redistribute.Static)), ("rip", ("rip", Native.Router.Rip.Redistribute.Rip_))])
                    self._leafs = OrderedDict()

                    self.rip_metric_route_map = Native.Router.Rip.Redistribute.RipMetricRouteMap()
                    self.rip_metric_route_map.parent = self
                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                    self.connected = None
                    self._children_name_map["connected"] = "connected"

                    self.isis = None
                    self._children_name_map["isis"] = "isis"

                    self.iso_igrp = None
                    self._children_name_map["iso_igrp"] = "iso-igrp"

                    self.mobile = None
                    self._children_name_map["mobile"] = "mobile"

                    self.odr = None
                    self._children_name_map["odr"] = "odr"

                    self.static = None
                    self._children_name_map["static"] = "static"

                    self.rip = None
                    self._children_name_map["rip"] = "rip"

                    self.bgp = YList(self)
                    self.eigrp = YList(self)
                    self.ospf = YList(self)
                    self._segment_path = lambda: "redistribute"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.Redistribute, [], name, value)


                class RipMetricRouteMap(Entity):
                    """
                    
                    
                    .. attribute:: metric
                    
                    	Metric for redistributed routes
                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.RipMetricRouteMap.Metric>`
                    
                    .. attribute:: route_map
                    
                    	Route map reference
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Redistribute.RipMetricRouteMap, self).__init__()

                        self.yang_name = "rip-metric-route-map"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.RipMetricRouteMap.Metric))])
                        self._leafs = OrderedDict([
                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                        ])
                        self.route_map = None

                        self.metric = Native.Router.Rip.Redistribute.RipMetricRouteMap.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"
                        self._segment_path = lambda: "rip-metric-route-map"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Redistribute.RipMetricRouteMap, ['route_map'], name, value)


                    class Metric(Entity):
                        """
                        Metric for redistributed routes
                        
                        .. attribute:: metric_value
                        
                        	Metric for redistributed routes
                        	**type**\: int
                        
                        	**range:** 0..16
                        
                        .. attribute:: transparent
                        
                        	Transparently redistribute metric
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.RipMetricRouteMap.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "rip-metric-route-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                            ])
                            self.metric_value = None
                            self.transparent = None
                            self._segment_path = lambda: "metric"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/rip-metric-route-map/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class Connected(Entity):
                    """
                    Connected
                    
                    .. attribute:: rip_metric_route_map
                    
                    	
                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Connected.RipMetricRouteMap>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Redistribute.Connected, self).__init__()

                        self.yang_name = "connected"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Connected.RipMetricRouteMap))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.rip_metric_route_map = Native.Router.Rip.Redistribute.Connected.RipMetricRouteMap()
                        self.rip_metric_route_map.parent = self
                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                        self._segment_path = lambda: "connected"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Redistribute.Connected, [], name, value)


                    class RipMetricRouteMap(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Connected.RipMetricRouteMap.Metric>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Connected.RipMetricRouteMap, self).__init__()

                            self.yang_name = "rip-metric-route-map"
                            self.yang_parent_name = "connected"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Connected.RipMetricRouteMap.Metric))])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None

                            self.metric = Native.Router.Rip.Redistribute.Connected.RipMetricRouteMap.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"
                            self._segment_path = lambda: "rip-metric-route-map"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/connected/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Connected.RipMetricRouteMap, ['route_map'], name, value)


                        class Metric(Entity):
                            """
                            Metric for redistributed routes
                            
                            .. attribute:: metric_value
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..16
                            
                            .. attribute:: transparent
                            
                            	Transparently redistribute metric
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Connected.RipMetricRouteMap.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "rip-metric-route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                ])
                                self.metric_value = None
                                self.transparent = None
                                self._segment_path = lambda: "metric"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/connected/rip-metric-route-map/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Connected.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class Bgp(Entity):
                    """
                    Border Gateway Protocol (BGP)
                    
                    .. attribute:: as_number  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..4294967295
                    
                    		**type**\: str
                    
                    .. attribute:: rip_metric_route_map
                    
                    	
                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Bgp.RipMetricRouteMap>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Redistribute.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['as_number']
                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Bgp.RipMetricRouteMap))])
                        self._leafs = OrderedDict([
                            ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                        ])
                        self.as_number = None

                        self.rip_metric_route_map = Native.Router.Rip.Redistribute.Bgp.RipMetricRouteMap()
                        self.rip_metric_route_map.parent = self
                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                        self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Redistribute.Bgp, ['as_number'], name, value)


                    class RipMetricRouteMap(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Bgp.RipMetricRouteMap.Metric>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Bgp.RipMetricRouteMap, self).__init__()

                            self.yang_name = "rip-metric-route-map"
                            self.yang_parent_name = "bgp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Bgp.RipMetricRouteMap.Metric))])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None

                            self.metric = Native.Router.Rip.Redistribute.Bgp.RipMetricRouteMap.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"
                            self._segment_path = lambda: "rip-metric-route-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Bgp.RipMetricRouteMap, ['route_map'], name, value)


                        class Metric(Entity):
                            """
                            Metric for redistributed routes
                            
                            .. attribute:: metric_value
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..16
                            
                            .. attribute:: transparent
                            
                            	Transparently redistribute metric
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Bgp.RipMetricRouteMap.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "rip-metric-route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                ])
                                self.metric_value = None
                                self.transparent = None
                                self._segment_path = lambda: "metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Bgp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class Eigrp(Entity):
                    """
                    Enhanced Interior Gateway Routing Protocol (EIGRP)
                    
                    .. attribute:: as_number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: rip_metric_route_map
                    
                    	
                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Redistribute.Eigrp, self).__init__()

                        self.yang_name = "eigrp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['as_number']
                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap))])
                        self._leafs = OrderedDict([
                            ('as_number', (YLeaf(YType.uint16, 'as-number'), ['int'])),
                        ])
                        self.as_number = None

                        self.rip_metric_route_map = Native.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap()
                        self.rip_metric_route_map.parent = self
                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                        self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Redistribute.Eigrp, ['as_number'], name, value)


                    class RipMetricRouteMap(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap.Metric>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap, self).__init__()

                            self.yang_name = "rip-metric-route-map"
                            self.yang_parent_name = "eigrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap.Metric))])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None

                            self.metric = Native.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"
                            self._segment_path = lambda: "rip-metric-route-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap, ['route_map'], name, value)


                        class Metric(Entity):
                            """
                            Metric for redistributed routes
                            
                            .. attribute:: metric_value
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..16
                            
                            .. attribute:: transparent
                            
                            	Transparently redistribute metric
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "rip-metric-route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                ])
                                self.metric_value = None
                                self.transparent = None
                                self._segment_path = lambda: "metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Eigrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class Isis(Entity):
                    """
                    ISO IS\-IS
                    
                    .. attribute:: isis_area
                    
                    	
                    	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Isis.IsisArea>`
                    
                    .. attribute:: rip_isis_redist
                    
                    	
                    	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Isis.RipIsisRedist>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Redistribute.Isis, self).__init__()

                        self.yang_name = "isis"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Rip.Redistribute.Isis.IsisArea)), ("rip-isis-redist", ("rip_isis_redist", Native.Router.Rip.Redistribute.Isis.RipIsisRedist))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.rip_isis_redist = Native.Router.Rip.Redistribute.Isis.RipIsisRedist()
                        self.rip_isis_redist.parent = self
                        self._children_name_map["rip_isis_redist"] = "rip-isis-redist"

                        self.isis_area = YList(self)
                        self._segment_path = lambda: "isis"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Redistribute.Isis, [], name, value)


                    class IsisArea(Entity):
                        """
                        
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: rip_isis_redist
                        
                        	
                        	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Isis.IsisArea, self).__init__()

                            self.yang_name = "isis-area"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("rip-isis-redist", ("rip_isis_redist", Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.rip_isis_redist = Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist()
                            self.rip_isis_redist.parent = self
                            self._children_name_map["rip_isis_redist"] = "rip-isis-redist"
                            self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/isis/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Isis.IsisArea, ['name'], name, value)


                        class RipIsisRedist(Entity):
                            """
                            
                            
                            .. attribute:: isis_level_routes
                            
                            	
                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes>`
                            
                            .. attribute:: rip_metric_route_map
                            
                            	
                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist, self).__init__()

                                self.yang_name = "rip-isis-redist"
                                self.yang_parent_name = "isis-area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap))])
                                self._leafs = OrderedDict([
                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes')])),
                                ])
                                self.isis_level_routes = None

                                self.rip_metric_route_map = Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap()
                                self.rip_metric_route_map.parent = self
                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                self._segment_path = lambda: "rip-isis-redist"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist, ['isis_level_routes'], name, value)

                            class IsisLevelRoutes(Enum):
                                """
                                IsisLevelRoutes (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                .. data:: level_1_2 = 2

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")

                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                            class RipMetricRouteMap(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                    self.yang_name = "rip-metric-route-map"
                                    self.yang_parent_name = "rip-isis-redist"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric))])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.metric = Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "rip-metric-route-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                                class Metric(Entity):
                                    """
                                    Metric for redistributed routes
                                    
                                    .. attribute:: metric_value
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..16
                                    
                                    .. attribute:: transparent
                                    
                                    	Transparently redistribute metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "rip-metric-route-map"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                        ])
                                        self.metric_value = None
                                        self.transparent = None
                                        self._segment_path = lambda: "metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class RipIsisRedist(Entity):
                        """
                        
                        
                        .. attribute:: isis_level_routes
                        
                        	
                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes>`
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Isis.RipIsisRedist, self).__init__()

                            self.yang_name = "rip-isis-redist"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap))])
                            self._leafs = OrderedDict([
                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes')])),
                            ])
                            self.isis_level_routes = None

                            self.rip_metric_route_map = Native.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "rip-isis-redist"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/isis/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Isis.RipIsisRedist, ['isis_level_routes'], name, value)

                        class IsisLevelRoutes(Enum):
                            """
                            IsisLevelRoutes (Enum Class)

                            .. data:: level_1 = 0

                            .. data:: level_2 = 1

                            .. data:: level_1_2 = 2

                            """

                            level_1 = Enum.YLeaf(0, "level-1")

                            level_2 = Enum.YLeaf(1, "level-2")

                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "rip-isis-redist"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/isis/rip-isis-redist/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/isis/rip-isis-redist/rip-metric-route-map/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class IsoIgrp(Entity):
                    """
                    IGRP for OSI networks
                    
                    .. attribute:: isoigrp_list
                    
                    	Border Gateway Protocol (BGP)
                    	**type**\: list of  		 :py:class:`IsoigrpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList>`
                    
                    .. attribute:: rip_metric_route_map
                    
                    	
                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Redistribute.IsoIgrp, self).__init__()

                        self.yang_name = "iso-igrp"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isoigrp-list", ("isoigrp_list", Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.rip_metric_route_map = Native.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap()
                        self.rip_metric_route_map.parent = self
                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                        self.isoigrp_list = YList(self)
                        self._segment_path = lambda: "iso-igrp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Redistribute.IsoIgrp, [], name, value)


                    class IsoigrpList(Entity):
                        """
                        Border Gateway Protocol (BGP)
                        
                        .. attribute:: iso_area_tag  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList, self).__init__()

                            self.yang_name = "isoigrp-list"
                            self.yang_parent_name = "iso-igrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['iso_area_tag']
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap))])
                            self._leafs = OrderedDict([
                                ('iso_area_tag', (YLeaf(YType.str, 'iso-area-tag'), ['str'])),
                            ])
                            self.iso_area_tag = None

                            self.rip_metric_route_map = Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "isoigrp-list" + "[iso-area-tag='" + str(self.iso_area_tag) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/iso-igrp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList, ['iso_area_tag'], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "isoigrp-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class RipMetricRouteMap(Entity):
                        """
                        
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap.Metric>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap, self).__init__()

                            self.yang_name = "rip-metric-route-map"
                            self.yang_parent_name = "iso-igrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap.Metric))])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None

                            self.metric = Native.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"
                            self._segment_path = lambda: "rip-metric-route-map"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/iso-igrp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap, ['route_map'], name, value)


                        class Metric(Entity):
                            """
                            Metric for redistributed routes
                            
                            .. attribute:: metric_value
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..16
                            
                            .. attribute:: transparent
                            
                            	Transparently redistribute metric
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "rip-metric-route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                ])
                                self.metric_value = None
                                self.transparent = None
                                self._segment_path = lambda: "metric"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/iso-igrp/rip-metric-route-map/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class Mobile(Entity):
                    """
                    Mobile routes
                    
                    .. attribute:: rip_metric_route_map
                    
                    	
                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Mobile.RipMetricRouteMap>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Redistribute.Mobile, self).__init__()

                        self.yang_name = "mobile"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Mobile.RipMetricRouteMap))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.rip_metric_route_map = Native.Router.Rip.Redistribute.Mobile.RipMetricRouteMap()
                        self.rip_metric_route_map.parent = self
                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                        self._segment_path = lambda: "mobile"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Redistribute.Mobile, [], name, value)


                    class RipMetricRouteMap(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Mobile.RipMetricRouteMap.Metric>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Mobile.RipMetricRouteMap, self).__init__()

                            self.yang_name = "rip-metric-route-map"
                            self.yang_parent_name = "mobile"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Mobile.RipMetricRouteMap.Metric))])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None

                            self.metric = Native.Router.Rip.Redistribute.Mobile.RipMetricRouteMap.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"
                            self._segment_path = lambda: "rip-metric-route-map"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/mobile/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Mobile.RipMetricRouteMap, ['route_map'], name, value)


                        class Metric(Entity):
                            """
                            Metric for redistributed routes
                            
                            .. attribute:: metric_value
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..16
                            
                            .. attribute:: transparent
                            
                            	Transparently redistribute metric
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Mobile.RipMetricRouteMap.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "rip-metric-route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                ])
                                self.metric_value = None
                                self.transparent = None
                                self._segment_path = lambda: "metric"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/mobile/rip-metric-route-map/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Mobile.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class Odr(Entity):
                    """
                    On Demand stub Routes
                    
                    .. attribute:: rip_metric_route_map
                    
                    	
                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Odr.RipMetricRouteMap>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Redistribute.Odr, self).__init__()

                        self.yang_name = "odr"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Odr.RipMetricRouteMap))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.rip_metric_route_map = Native.Router.Rip.Redistribute.Odr.RipMetricRouteMap()
                        self.rip_metric_route_map.parent = self
                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                        self._segment_path = lambda: "odr"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Redistribute.Odr, [], name, value)


                    class RipMetricRouteMap(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Odr.RipMetricRouteMap.Metric>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Odr.RipMetricRouteMap, self).__init__()

                            self.yang_name = "rip-metric-route-map"
                            self.yang_parent_name = "odr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Odr.RipMetricRouteMap.Metric))])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None

                            self.metric = Native.Router.Rip.Redistribute.Odr.RipMetricRouteMap.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"
                            self._segment_path = lambda: "rip-metric-route-map"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/odr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Odr.RipMetricRouteMap, ['route_map'], name, value)


                        class Metric(Entity):
                            """
                            Metric for redistributed routes
                            
                            .. attribute:: metric_value
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..16
                            
                            .. attribute:: transparent
                            
                            	Transparently redistribute metric
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Odr.RipMetricRouteMap.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "rip-metric-route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                ])
                                self.metric_value = None
                                self.transparent = None
                                self._segment_path = lambda: "metric"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/odr/rip-metric-route-map/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Odr.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class Ospf(Entity):
                    """
                    Open Shortest Path First (OSPF)
                    
                    .. attribute:: process_id  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: vrf
                    
                    	VPN Routing/Forwarding Instance
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.Vrf>`
                    
                    .. attribute:: match
                    
                    	Redistribution of OSPF routes
                    	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.Match>`
                    
                    .. attribute:: rip_metric_route_map
                    
                    	
                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.RipMetricRouteMap>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Redistribute.Ospf, self).__init__()

                        self.yang_name = "ospf"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['process_id']
                        self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Rip.Redistribute.Ospf.Vrf)), ("match", ("match", Native.Router.Rip.Redistribute.Ospf.Match)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Ospf.RipMetricRouteMap))])
                        self._leafs = OrderedDict([
                            ('process_id', (YLeaf(YType.uint16, 'process-id'), ['int'])),
                        ])
                        self.process_id = None

                        self.match = Native.Router.Rip.Redistribute.Ospf.Match()
                        self.match.parent = self
                        self._children_name_map["match"] = "match"

                        self.rip_metric_route_map = Native.Router.Rip.Redistribute.Ospf.RipMetricRouteMap()
                        self.rip_metric_route_map.parent = self
                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                        self.vrf = YList(self)
                        self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Redistribute.Ospf, ['process_id'], name, value)


                    class Vrf(Entity):
                        """
                        VPN Routing/Forwarding Instance
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Ospf.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.Vrf, ['name'], name, value)


                    class Match(Entity):
                        """
                        Redistribution of OSPF routes
                        
                        .. attribute:: internal
                        
                        	Redistribute OSPF internal routes
                        	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.Match.Internal>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: external
                        
                        	Redistribute OSPF external routes
                        	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.Match.External>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: nssa_external
                        
                        	Redistribute OSPF NSSA external routes
                        	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Ospf.Match, self).__init__()

                            self.yang_name = "match"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Rip.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.Rip.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal))])
                            self._leafs = OrderedDict()

                            self.internal = None
                            self._children_name_map["internal"] = "internal"

                            self.external = None
                            self._children_name_map["external"] = "external"

                            self.nssa_external = None
                            self._children_name_map["nssa_external"] = "nssa-external"
                            self._segment_path = lambda: "match"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.Match, [], name, value)


                        class Internal(Entity):
                            """
                            Redistribute OSPF internal routes
                            
                            .. attribute:: rip_metric_route_map
                            
                            	
                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Ospf.Match.Internal, self).__init__()

                                self.yang_name = "internal"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.rip_metric_route_map = Native.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap()
                                self.rip_metric_route_map.parent = self
                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                self._segment_path = lambda: "internal"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.Match.Internal, [], name, value)


                            class RipMetricRouteMap(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, self).__init__()

                                    self.yang_name = "rip-metric-route-map"
                                    self.yang_parent_name = "internal"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric))])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.metric = Native.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "rip-metric-route-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, ['route_map'], name, value)


                                class Metric(Entity):
                                    """
                                    Metric for redistributed routes
                                    
                                    .. attribute:: metric_value
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..16
                                    
                                    .. attribute:: transparent
                                    
                                    	Transparently redistribute metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "rip-metric-route-map"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                        ])
                                        self.metric_value = None
                                        self.transparent = None
                                        self._segment_path = lambda: "metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                        class External(Entity):
                            """
                            Redistribute OSPF external routes
                            
                            .. attribute:: external_routes
                            
                            	
                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                            
                            .. attribute:: rip_metric_route_map
                            
                            	
                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Ospf.Match.External, self).__init__()

                                self.yang_name = "external"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                ])
                                self.external_routes = None

                                self.rip_metric_route_map = Native.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap()
                                self.rip_metric_route_map.parent = self
                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                self._segment_path = lambda: "external"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.Match.External, ['external_routes'], name, value)


                            class RipMetricRouteMap(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap, self).__init__()

                                    self.yang_name = "rip-metric-route-map"
                                    self.yang_parent_name = "external"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric))])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.metric = Native.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "rip-metric-route-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap, ['route_map'], name, value)


                                class Metric(Entity):
                                    """
                                    Metric for redistributed routes
                                    
                                    .. attribute:: metric_value
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..16
                                    
                                    .. attribute:: transparent
                                    
                                    	Transparently redistribute metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "rip-metric-route-map"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                        ])
                                        self.metric_value = None
                                        self.transparent = None
                                        self._segment_path = lambda: "metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                        class NssaExternal(Entity):
                            """
                            Redistribute OSPF NSSA external routes
                            
                            .. attribute:: nssa_external_routes
                            
                            	
                            	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                            
                            .. attribute:: rip_metric_route_map
                            
                            	
                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                self.yang_name = "nssa-external"
                                self.yang_parent_name = "match"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                ])
                                self.nssa_external_routes = None

                                self.rip_metric_route_map = Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap()
                                self.rip_metric_route_map.parent = self
                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                self._segment_path = lambda: "nssa-external"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal, ['nssa_external_routes'], name, value)


                            class RipMetricRouteMap(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, self).__init__()

                                    self.yang_name = "rip-metric-route-map"
                                    self.yang_parent_name = "nssa-external"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric))])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.metric = Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "rip-metric-route-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, ['route_map'], name, value)


                                class Metric(Entity):
                                    """
                                    Metric for redistributed routes
                                    
                                    .. attribute:: metric_value
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..16
                                    
                                    .. attribute:: transparent
                                    
                                    	Transparently redistribute metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "rip-metric-route-map"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                        ])
                                        self.metric_value = None
                                        self.transparent = None
                                        self._segment_path = lambda: "metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class RipMetricRouteMap(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Ospf.RipMetricRouteMap.Metric>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Ospf.RipMetricRouteMap, self).__init__()

                            self.yang_name = "rip-metric-route-map"
                            self.yang_parent_name = "ospf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Ospf.RipMetricRouteMap.Metric))])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None

                            self.metric = Native.Router.Rip.Redistribute.Ospf.RipMetricRouteMap.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"
                            self._segment_path = lambda: "rip-metric-route-map"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.RipMetricRouteMap, ['route_map'], name, value)


                        class Metric(Entity):
                            """
                            Metric for redistributed routes
                            
                            .. attribute:: metric_value
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..16
                            
                            .. attribute:: transparent
                            
                            	Transparently redistribute metric
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Ospf.RipMetricRouteMap.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "rip-metric-route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                ])
                                self.metric_value = None
                                self.transparent = None
                                self._segment_path = lambda: "metric"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Ospf.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class Static(Entity):
                    """
                    Static routes
                    
                    .. attribute:: rip_metric_route_map
                    
                    	
                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Static.RipMetricRouteMap>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Redistribute.Static, self).__init__()

                        self.yang_name = "static"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Static.RipMetricRouteMap))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.rip_metric_route_map = Native.Router.Rip.Redistribute.Static.RipMetricRouteMap()
                        self.rip_metric_route_map.parent = self
                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                        self._segment_path = lambda: "static"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Redistribute.Static, [], name, value)


                    class RipMetricRouteMap(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Static.RipMetricRouteMap.Metric>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Static.RipMetricRouteMap, self).__init__()

                            self.yang_name = "rip-metric-route-map"
                            self.yang_parent_name = "static"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Static.RipMetricRouteMap.Metric))])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None

                            self.metric = Native.Router.Rip.Redistribute.Static.RipMetricRouteMap.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"
                            self._segment_path = lambda: "rip-metric-route-map"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/static/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Static.RipMetricRouteMap, ['route_map'], name, value)


                        class Metric(Entity):
                            """
                            Metric for redistributed routes
                            
                            .. attribute:: metric_value
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..16
                            
                            .. attribute:: transparent
                            
                            	Transparently redistribute metric
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Static.RipMetricRouteMap.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "rip-metric-route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                ])
                                self.metric_value = None
                                self.transparent = None
                                self._segment_path = lambda: "metric"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/static/rip-metric-route-map/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Static.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class Rip_(Entity):
                    """
                    Routing Information Protocol (RIP)
                    
                    .. attribute:: rip_metric_route_map
                    
                    	
                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Rip_.RipMetricRouteMap>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Redistribute.Rip_, self).__init__()

                        self.yang_name = "rip"
                        self.yang_parent_name = "redistribute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Redistribute.Rip_.RipMetricRouteMap))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.rip_metric_route_map = Native.Router.Rip.Redistribute.Rip_.RipMetricRouteMap()
                        self.rip_metric_route_map.parent = self
                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                        self._segment_path = lambda: "rip"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Redistribute.Rip_, [], name, value)


                    class RipMetricRouteMap(Entity):
                        """
                        
                        
                        .. attribute:: metric
                        
                        	Metric for redistributed routes
                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Redistribute.Rip_.RipMetricRouteMap.Metric>`
                        
                        .. attribute:: route_map
                        
                        	Route map reference
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Redistribute.Rip_.RipMetricRouteMap, self).__init__()

                            self.yang_name = "rip-metric-route-map"
                            self.yang_parent_name = "rip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Redistribute.Rip_.RipMetricRouteMap.Metric))])
                            self._leafs = OrderedDict([
                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                            ])
                            self.route_map = None

                            self.metric = Native.Router.Rip.Redistribute.Rip_.RipMetricRouteMap.Metric()
                            self.metric.parent = self
                            self._children_name_map["metric"] = "metric"
                            self._segment_path = lambda: "rip-metric-route-map"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/rip/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Redistribute.Rip_.RipMetricRouteMap, ['route_map'], name, value)


                        class Metric(Entity):
                            """
                            Metric for redistributed routes
                            
                            .. attribute:: metric_value
                            
                            	Metric for redistributed routes
                            	**type**\: int
                            
                            	**range:** 0..16
                            
                            .. attribute:: transparent
                            
                            	Transparently redistribute metric
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Redistribute.Rip_.RipMetricRouteMap.Metric, self).__init__()

                                self.yang_name = "metric"
                                self.yang_parent_name = "rip-metric-route-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                ])
                                self.metric_value = None
                                self.transparent = None
                                self._segment_path = lambda: "metric"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/redistribute/rip/rip-metric-route-map/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Redistribute.Rip_.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


            class Timers(Entity):
                """
                Adjust routing timers
                
                .. attribute:: basic
                
                	Basic routing protocol update timers
                	**type**\:  :py:class:`Basic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Timers.Basic>`
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.Timers, self).__init__()

                    self.yang_name = "timers"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("basic", ("basic", Native.Router.Rip.Timers.Basic))])
                    self._leafs = OrderedDict()

                    self.basic = Native.Router.Rip.Timers.Basic()
                    self.basic.parent = self
                    self._children_name_map["basic"] = "basic"
                    self._segment_path = lambda: "timers"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.Timers, [], name, value)


                class Basic(Entity):
                    """
                    Basic routing protocol update timers
                    
                    .. attribute:: updates
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: invalid
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: holddown
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: flush
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: sleep
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Timers.Basic, self).__init__()

                        self.yang_name = "basic"
                        self.yang_parent_name = "timers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('updates', (YLeaf(YType.uint32, 'updates'), ['int'])),
                            ('invalid', (YLeaf(YType.uint32, 'invalid'), ['int'])),
                            ('holddown', (YLeaf(YType.uint32, 'holddown'), ['int'])),
                            ('flush', (YLeaf(YType.uint32, 'flush'), ['int'])),
                            ('sleep', (YLeaf(YType.uint32, 'sleep'), ['int'])),
                        ])
                        self.updates = None
                        self.invalid = None
                        self.holddown = None
                        self.flush = None
                        self.sleep = None
                        self._segment_path = lambda: "basic"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/timers/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Timers.Basic, ['updates', 'invalid', 'holddown', 'flush', 'sleep'], name, value)


            class PassiveInterface(Entity):
                """
                Suppress routing updates on an interface
                
                .. attribute:: default
                
                	Suppress routing updates on all interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.PassiveInterface, self).__init__()

                    self.yang_name = "passive-interface"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                    ])
                    self.default = None
                    self.interface = None
                    self._segment_path = lambda: "passive-interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.PassiveInterface, [u'default', u'interface'], name, value)


            class Disable(Entity):
                """
                
                
                .. attribute:: passive_interface
                
                	
                	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Disable.PassiveInterface>`
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.Disable, self).__init__()

                    self.yang_name = "disable"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.Rip.Disable.PassiveInterface))])
                    self._leafs = OrderedDict()

                    self.passive_interface = YList(self)
                    self._segment_path = lambda: "disable"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.Disable, [], name, value)


                class PassiveInterface(Entity):
                    """
                    
                    
                    .. attribute:: interface  (key)
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Disable.PassiveInterface, self).__init__()

                        self.yang_name = "passive-interface"
                        self.yang_parent_name = "disable"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ])
                        self.interface = None
                        self._segment_path = lambda: "passive-interface" + "[interface='" + str(self.interface) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/disable/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Disable.PassiveInterface, [u'interface'], name, value)


            class TrafficShare(Entity):
                """
                How to compute traffic share over alternate paths
                
                .. attribute:: min
                
                	All traffic shared among min metric paths
                	**type**\:  :py:class:`Min <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.TrafficShare.Min>`
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.TrafficShare, self).__init__()

                    self.yang_name = "traffic-share"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("min", ("min", Native.Router.Rip.TrafficShare.Min))])
                    self._leafs = OrderedDict()

                    self.min = Native.Router.Rip.TrafficShare.Min()
                    self.min.parent = self
                    self._children_name_map["min"] = "min"
                    self._segment_path = lambda: "traffic-share"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.TrafficShare, [], name, value)


                class Min(Entity):
                    """
                    All traffic shared among min metric paths
                    
                    .. attribute:: across_interfaces
                    
                    	Use different interfaces for equal\-cost paths
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.TrafficShare.Min, self).__init__()

                        self.yang_name = "min"
                        self.yang_parent_name = "traffic-share"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                        ])
                        self.across_interfaces = None
                        self._segment_path = lambda: "min"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/traffic-share/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.TrafficShare.Min, ['across_interfaces'], name, value)


            class AddressFamily(Entity):
                """
                Enter Address Family command mode
                
                .. attribute:: ipv4
                
                	Address family
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4>`
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Rip.AddressFamily.Ipv4))])
                    self._leafs = OrderedDict()

                    self.ipv4 = Native.Router.Rip.AddressFamily.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._segment_path = lambda: "address-family"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.AddressFamily, [], name, value)


                class Ipv4(Entity):
                    """
                    Address family
                    
                    .. attribute:: unicast
                    
                    	
                    	**type**\:  :py:class:`Unicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast>`
                    
                    .. attribute:: vrf
                    
                    	Specify parameters for a VPN Routing/Forwarding instance
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.AddressFamily.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("unicast", ("unicast", Native.Router.Rip.AddressFamily.Ipv4.Unicast)), ("vrf", ("vrf", Native.Router.Rip.AddressFamily.Ipv4.Vrf))])
                        self._leafs = OrderedDict()

                        self.unicast = Native.Router.Rip.AddressFamily.Ipv4.Unicast()
                        self.unicast.parent = self
                        self._children_name_map["unicast"] = "unicast"

                        self.vrf = YList(self)
                        self._segment_path = lambda: "ipv4"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4, [], name, value)


                    class Unicast(Entity):
                        """
                        
                        
                        .. attribute:: auto_summary
                        
                        	Enable automatic network number summarization
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: maximum_paths
                        
                        	Forward packets over multiple paths
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: neighbor
                        
                        	Specify a neighbor router
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Enable routing on an IP network
                        	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Network>`
                        
                        .. attribute:: validate_update_source
                        
                        	Perform sanity checks against source address of routing updates
                        	**type**\: bool
                        
                        .. attribute:: default_information
                        
                        	Control distribution of default information
                        	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.DefaultInformation>`
                        
                        .. attribute:: default_metric
                        
                        	Set metric of redistributed routes
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: distance
                        
                        	Define an administrative distance
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Distance>`
                        
                        .. attribute:: distribute_list
                        
                        	Filter networks in routing updates
                        	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList>`
                        
                        .. attribute:: offset_list
                        
                        	Add or subtract offset from RIP metrics
                        	**type**\: list of  		 :py:class:`OffsetList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.OffsetList>`
                        
                        .. attribute:: redistribute
                        
                        	Redistribute information from another routing protocol
                        	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute>`
                        
                        .. attribute:: timers
                        
                        	Adjust routing timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Timers>`
                        
                        .. attribute:: version
                        
                        	Set routing protocol version
                        	**type**\: int
                        
                        	**range:** 1..2
                        
                        .. attribute:: flash_update_threshold
                        
                        	Specify flash update threshold in second
                        	**type**\: int
                        
                        	**range:** 0..30
                        
                        .. attribute:: input_queue
                        
                        	Specify input queue depth
                        	**type**\: int
                        
                        	**range:** 0..1024
                        
                        .. attribute:: output_delay
                        
                        	Interpacket delay for RIP updates
                        	**type**\: int
                        
                        	**range:** 8..50
                        
                        .. attribute:: passive_interface
                        
                        	Suppress routing updates on an interface
                        	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.PassiveInterface>`
                        
                        .. attribute:: disable
                        
                        	
                        	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Disable>`
                        
                        .. attribute:: traffic_share
                        
                        	How to compute traffic share over alternate paths
                        	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.TrafficShare>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast, self).__init__()

                            self.yang_name = "unicast"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Neighbor)), ("network", ("network", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Network)), ("default-information", ("default_information", Native.Router.Rip.AddressFamily.Ipv4.Unicast.DefaultInformation)), ("distance", ("distance", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Distance)), ("distribute-list", ("distribute_list", Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList)), ("offset-list", ("offset_list", Native.Router.Rip.AddressFamily.Ipv4.Unicast.OffsetList)), ("redistribute", ("redistribute", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute)), ("timers", ("timers", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Timers)), ("passive-interface", ("passive_interface", Native.Router.Rip.AddressFamily.Ipv4.Unicast.PassiveInterface)), ("disable", ("disable", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Disable)), ("traffic-share", ("traffic_share", Native.Router.Rip.AddressFamily.Ipv4.Unicast.TrafficShare))])
                            self._leafs = OrderedDict([
                                ('auto_summary', (YLeaf(YType.empty, 'auto-summary'), ['Empty'])),
                                ('maximum_paths', (YLeaf(YType.uint8, 'maximum-paths'), ['int'])),
                                ('validate_update_source', (YLeaf(YType.boolean, 'validate-update-source'), ['bool'])),
                                ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                                ('flash_update_threshold', (YLeaf(YType.uint8, 'flash-update-threshold'), ['int'])),
                                ('input_queue', (YLeaf(YType.uint16, 'input-queue'), ['int'])),
                                ('output_delay', (YLeaf(YType.uint8, 'output-delay'), ['int'])),
                            ])
                            self.auto_summary = None
                            self.maximum_paths = None
                            self.validate_update_source = None
                            self.default_metric = None
                            self.version = None
                            self.flash_update_threshold = None
                            self.input_queue = None
                            self.output_delay = None

                            self.default_information = Native.Router.Rip.AddressFamily.Ipv4.Unicast.DefaultInformation()
                            self.default_information.parent = self
                            self._children_name_map["default_information"] = "default-information"

                            self.distance = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.distribute_list = Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList()
                            self.distribute_list.parent = self
                            self._children_name_map["distribute_list"] = "distribute-list"

                            self.redistribute = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute()
                            self.redistribute.parent = self
                            self._children_name_map["redistribute"] = "redistribute"

                            self.timers = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"

                            self.passive_interface = Native.Router.Rip.AddressFamily.Ipv4.Unicast.PassiveInterface()
                            self.passive_interface.parent = self
                            self._children_name_map["passive_interface"] = "passive-interface"

                            self.disable = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Disable()
                            self.disable.parent = self
                            self._children_name_map["disable"] = "disable"

                            self.traffic_share = Native.Router.Rip.AddressFamily.Ipv4.Unicast.TrafficShare()
                            self.traffic_share.parent = self
                            self._children_name_map["traffic_share"] = "traffic-share"

                            self.neighbor = YList(self)
                            self.network = YList(self)
                            self.offset_list = YList(self)
                            self._segment_path = lambda: "unicast"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast, ['auto_summary', 'maximum_paths', 'validate_update_source', 'default_metric', 'version', 'flash_update_threshold', 'input_queue', 'output_delay'], name, value)


                        class Neighbor(Entity):
                            """
                            Specify a neighbor router
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ])
                                self.ip = None
                                self._segment_path = lambda: "neighbor" + "[ip='" + str(self.ip) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Neighbor, ['ip'], name, value)


                        class Network(Entity):
                            """
                            Enable routing on an IP network
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ip']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ])
                                self.ip = None
                                self._segment_path = lambda: "network" + "[ip='" + str(self.ip) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Network, ['ip'], name, value)


                        class DefaultInformation(Entity):
                            """
                            Control distribution of default information
                            
                            .. attribute:: originate
                            
                            	Distribute a default route
                            	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.DefaultInformation.Originate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DefaultInformation, self).__init__()

                                self.yang_name = "default-information"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("originate", ("originate", Native.Router.Rip.AddressFamily.Ipv4.Unicast.DefaultInformation.Originate))])
                                self._leafs = OrderedDict()

                                self.originate = None
                                self._children_name_map["originate"] = "originate"
                                self._segment_path = lambda: "default-information"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DefaultInformation, [], name, value)


                            class Originate(Entity):
                                """
                                Distribute a default route
                                
                                .. attribute:: route_map
                                
                                	Route\-map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DefaultInformation.Originate, self).__init__()

                                    self.yang_name = "originate"
                                    self.yang_parent_name = "default-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "originate"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/default-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DefaultInformation.Originate, ['route_map'], name, value)


                        class Distance(Entity):
                            """
                            Define an administrative distance
                            
                            .. attribute:: distance_leaf
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: distance_list
                            
                            	
                            	**type**\: list of  		 :py:class:`DistanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Distance.DistanceList>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("distance-list", ("distance_list", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Distance.DistanceList))])
                                self._leafs = OrderedDict([
                                    ('distance_leaf', (YLeaf(YType.uint8, 'distance-leaf'), ['int'])),
                                ])
                                self.distance_leaf = None

                                self.distance_list = YList(self)
                                self._segment_path = lambda: "distance"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Distance, ['distance_leaf'], name, value)


                            class DistanceList(Entity):
                                """
                                
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: ip  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Distance.DistanceList, self).__init__()

                                    self.yang_name = "distance-list"
                                    self.yang_parent_name = "distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['number','ip','mask']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                        ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ])
                                    self.number = None
                                    self.ip = None
                                    self.mask = None
                                    self._segment_path = lambda: "distance-list" + "[number='" + str(self.number) + "']" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/distance/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Distance.DistanceList, ['number', 'ip', 'mask'], name, value)


                        class DistributeList(Entity):
                            """
                            Filter networks in routing updates
                            
                            .. attribute:: accesslist
                            
                            	
                            	**type**\: list of  		 :py:class:`Accesslist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.Accesslist>`
                            
                            .. attribute:: accesslist_ifname
                            
                            	
                            	**type**\: list of  		 :py:class:`AccesslistIfname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistIfname>`
                            
                            .. attribute:: accesslist_prefix_gateway
                            
                            	
                            	**type**\: list of  		 :py:class:`AccesslistPrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGateway>`
                            
                            .. attribute:: accesslist_prefix_gateway_ifname
                            
                            	
                            	**type**\: list of  		 :py:class:`AccesslistPrefixGatewayIfname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGatewayIfname>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList, self).__init__()

                                self.yang_name = "distribute-list"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("accesslist", ("accesslist", Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.Accesslist)), ("accesslist-ifname", ("accesslist_ifname", Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistIfname)), ("accesslist-prefix-gateway", ("accesslist_prefix_gateway", Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGateway)), ("accesslist-prefix-gateway-ifname", ("accesslist_prefix_gateway_ifname", Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGatewayIfname))])
                                self._leafs = OrderedDict()

                                self.accesslist = YList(self)
                                self.accesslist_ifname = YList(self)
                                self.accesslist_prefix_gateway = YList(self)
                                self.accesslist_prefix_gateway_ifname = YList(self)
                                self._segment_path = lambda: "distribute-list"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList, [], name, value)


                            class Accesslist(Entity):
                                """
                                
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.Accesslist, self).__init__()

                                    self.yang_name = "accesslist"
                                    self.yang_parent_name = "distribute-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['in_out']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                    ])
                                    self.in_out = None
                                    self._segment_path = lambda: "accesslist" + "[in-out='" + str(self.in_out) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/distribute-list/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.Accesslist, ['in_out'], name, value)


                            class AccesslistIfname(Entity):
                                """
                                
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                                
                                .. attribute:: interface  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: interface_routing_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: isis_tag
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistIfname, self).__init__()

                                    self.yang_name = "accesslist-ifname"
                                    self.yang_parent_name = "distribute-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['in_out','interface']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('interface_routing_id', (YLeaf(YType.uint8, 'interface-routing-id'), ['int'])),
                                        ('isis_tag', (YLeaf(YType.str, 'isis-tag'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.in_out = None
                                    self.interface = None
                                    self.interface_routing_id = None
                                    self.isis_tag = None
                                    self.vrf = None
                                    self._segment_path = lambda: "accesslist-ifname" + "[in-out='" + str(self.in_out) + "']" + "[interface='" + str(self.interface) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/distribute-list/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistIfname, ['in_out', 'interface', 'interface_routing_id', 'isis_tag', 'vrf'], name, value)


                            class AccesslistPrefixGateway(Entity):
                                """
                                
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                                
                                .. attribute:: prefix_gateway
                                
                                	
                                	**type**\:  :py:class:`PrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGateway.PrefixGateway>`
                                
                                	**mandatory**\: True
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGateway, self).__init__()

                                    self.yang_name = "accesslist-prefix-gateway"
                                    self.yang_parent_name = "distribute-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['in_out']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                        ('prefix_gateway', (YLeaf(YType.enumeration, 'prefix-gateway'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGateway.PrefixGateway')])),
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.in_out = None
                                    self.prefix_gateway = None
                                    self.name = None
                                    self._segment_path = lambda: "accesslist-prefix-gateway" + "[in-out='" + str(self.in_out) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/distribute-list/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGateway, ['in_out', 'prefix_gateway', 'name'], name, value)

                                class PrefixGateway(Enum):
                                    """
                                    PrefixGateway (Enum Class)

                                    .. data:: prefix = 0

                                    .. data:: gateway = 1

                                    .. data:: route_map = 2

                                    """

                                    prefix = Enum.YLeaf(0, "prefix")

                                    gateway = Enum.YLeaf(1, "gateway")

                                    route_map = Enum.YLeaf(2, "route-map")



                            class AccesslistPrefixGatewayIfname(Entity):
                                """
                                
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                                
                                .. attribute:: interface  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: prefix_gateway
                                
                                	
                                	**type**\:  :py:class:`PrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGatewayIfname.PrefixGateway>`
                                
                                	**mandatory**\: True
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                	**mandatory**\: True
                                
                                .. attribute:: interface_routing_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: isis_tag
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGatewayIfname, self).__init__()

                                    self.yang_name = "accesslist-prefix-gateway-ifname"
                                    self.yang_parent_name = "distribute-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['in_out','interface']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('prefix_gateway', (YLeaf(YType.enumeration, 'prefix-gateway'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGatewayIfname.PrefixGateway')])),
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('interface_routing_id', (YLeaf(YType.uint8, 'interface-routing-id'), ['int'])),
                                        ('isis_tag', (YLeaf(YType.str, 'isis-tag'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.in_out = None
                                    self.interface = None
                                    self.prefix_gateway = None
                                    self.name = None
                                    self.interface_routing_id = None
                                    self.isis_tag = None
                                    self.vrf = None
                                    self._segment_path = lambda: "accesslist-prefix-gateway-ifname" + "[in-out='" + str(self.in_out) + "']" + "[interface='" + str(self.interface) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/distribute-list/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.DistributeList.AccesslistPrefixGatewayIfname, ['in_out', 'interface', 'prefix_gateway', 'name', 'interface_routing_id', 'isis_tag', 'vrf'], name, value)

                                class PrefixGateway(Enum):
                                    """
                                    PrefixGateway (Enum Class)

                                    .. data:: prefix = 0

                                    .. data:: gateway = 1

                                    .. data:: route_map = 2

                                    """

                                    prefix = Enum.YLeaf(0, "prefix")

                                    gateway = Enum.YLeaf(1, "gateway")

                                    route_map = Enum.YLeaf(2, "route-map")



                        class OffsetList(Entity):
                            """
                            Add or subtract offset from RIP metrics
                            
                            .. attribute:: in_out  (key)
                            
                            	
                            	**type**\:  :py:class:`OffsetListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_rip.OffsetListInOutType>`
                            
                            .. attribute:: offset
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..16
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.OffsetList, self).__init__()

                                self.yang_name = "offset-list"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['in_out']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_rip', 'OffsetListInOutType', '')])),
                                    ('offset', (YLeaf(YType.uint8, 'offset'), ['int'])),
                                ])
                                self.in_out = None
                                self.offset = None
                                self._segment_path = lambda: "offset-list" + "[in-out='" + str(self.in_out) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.OffsetList, ['in_out', 'offset'], name, value)


                        class Redistribute(Entity):
                            """
                            Redistribute information from another routing protocol
                            
                            .. attribute:: rip_metric_route_map
                            
                            	
                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.RipMetricRouteMap>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp>`
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: iso_igrp
                            
                            	IGRP for OSI networks
                            	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: mobile
                            
                            	Mobile routes
                            	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: odr
                            
                            	On Demand stub Routes
                            	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf>`
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute, self).__init__()

                                self.yang_name = "redistribute"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.RipMetricRouteMap)), ("connected", ("connected", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected)), ("bgp", ("bgp", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp)), ("eigrp", ("eigrp", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf)), ("static", ("static", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static)), ("rip", ("rip", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_))])
                                self._leafs = OrderedDict()

                                self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.RipMetricRouteMap()
                                self.rip_metric_route_map.parent = self
                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.isis = None
                                self._children_name_map["isis"] = "isis"

                                self.iso_igrp = None
                                self._children_name_map["iso_igrp"] = "iso-igrp"

                                self.mobile = None
                                self._children_name_map["mobile"] = "mobile"

                                self.odr = None
                                self._children_name_map["odr"] = "odr"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.rip = None
                                self._children_name_map["rip"] = "rip"

                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.ospf = YList(self)
                                self._segment_path = lambda: "redistribute"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute, [], name, value)


                            class RipMetricRouteMap(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.RipMetricRouteMap.Metric>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.RipMetricRouteMap, self).__init__()

                                    self.yang_name = "rip-metric-route-map"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.RipMetricRouteMap.Metric))])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.RipMetricRouteMap.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "rip-metric-route-map"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.RipMetricRouteMap, ['route_map'], name, value)


                                class Metric(Entity):
                                    """
                                    Metric for redistributed routes
                                    
                                    .. attribute:: metric_value
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..16
                                    
                                    .. attribute:: transparent
                                    
                                    	Transparently redistribute metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.RipMetricRouteMap.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "rip-metric-route-map"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                        ])
                                        self.metric_value = None
                                        self.transparent = None
                                        self._segment_path = lambda: "metric"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/rip-metric-route-map/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "connected"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/connected/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/connected/rip-metric-route-map/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Connected.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RipMetricRouteMap>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RipMetricRouteMap))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                    ])
                                    self.as_number = None

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp, ['as_number'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Bgp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RipMetricRouteMap>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RipMetricRouteMap))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.uint16, 'as-number'), ['int'])),
                                    ])
                                    self.as_number = None

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp, ['as_number'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Eigrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: isis_area
                                
                                	
                                	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea>`
                                
                                .. attribute:: rip_isis_redist
                                
                                	
                                	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea)), ("rip-isis-redist", ("rip_isis_redist", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_isis_redist = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist()
                                    self.rip_isis_redist.parent = self
                                    self._children_name_map["rip_isis_redist"] = "rip-isis-redist"

                                    self.isis_area = YList(self)
                                    self._segment_path = lambda: "isis"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis, [], name, value)


                                class IsisArea(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: rip_isis_redist
                                    
                                    	
                                    	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea, self).__init__()

                                        self.yang_name = "isis-area"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("rip-isis-redist", ("rip_isis_redist", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.rip_isis_redist = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist()
                                        self.rip_isis_redist.parent = self
                                        self._children_name_map["rip_isis_redist"] = "rip-isis-redist"
                                        self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/isis/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea, ['name'], name, value)


                                    class RipIsisRedist(Entity):
                                        """
                                        
                                        
                                        .. attribute:: isis_level_routes
                                        
                                        	
                                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes>`
                                        
                                        .. attribute:: rip_metric_route_map
                                        
                                        	
                                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist, self).__init__()

                                            self.yang_name = "rip-isis-redist"
                                            self.yang_parent_name = "isis-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap))])
                                            self._leafs = OrderedDict([
                                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes')])),
                                            ])
                                            self.isis_level_routes = None

                                            self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap()
                                            self.rip_metric_route_map.parent = self
                                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                            self._segment_path = lambda: "rip-isis-redist"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist, ['isis_level_routes'], name, value)

                                        class IsisLevelRoutes(Enum):
                                            """
                                            IsisLevelRoutes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class RipMetricRouteMap(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                                self.yang_name = "rip-metric-route-map"
                                                self.yang_parent_name = "rip-isis-redist"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric()
                                                self.metric.parent = self
                                                self._children_name_map["metric"] = "metric"
                                                self._segment_path = lambda: "rip-metric-route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                                            class Metric(Entity):
                                                """
                                                Metric for redistributed routes
                                                
                                                .. attribute:: metric_value
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..16
                                                
                                                .. attribute:: transparent
                                                
                                                	Transparently redistribute metric
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                                    self.yang_name = "metric"
                                                    self.yang_parent_name = "rip-metric-route-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                    ])
                                                    self.metric_value = None
                                                    self.transparent = None
                                                    self._segment_path = lambda: "metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class RipIsisRedist(Entity):
                                    """
                                    
                                    
                                    .. attribute:: isis_level_routes
                                    
                                    	
                                    	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes>`
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist, self).__init__()

                                        self.yang_name = "rip-isis-redist"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap))])
                                        self._leafs = OrderedDict([
                                            ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes')])),
                                        ])
                                        self.isis_level_routes = None

                                        self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                        self._segment_path = lambda: "rip-isis-redist"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/isis/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist, ['isis_level_routes'], name, value)

                                    class IsisLevelRoutes(Enum):
                                        """
                                        IsisLevelRoutes (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        .. data:: level_1_2 = 2

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")

                                        level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "rip-isis-redist"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/isis/rip-isis-redist/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/isis/rip-isis-redist/rip-metric-route-map/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class IsoIgrp(Entity):
                                """
                                IGRP for OSI networks
                                
                                .. attribute:: isoigrp_list
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\: list of  		 :py:class:`IsoigrpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList>`
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp, self).__init__()

                                    self.yang_name = "iso-igrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isoigrp-list", ("isoigrp_list", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                                    self.isoigrp_list = YList(self)
                                    self._segment_path = lambda: "iso-igrp"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp, [], name, value)


                                class IsoigrpList(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: iso_area_tag  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList, self).__init__()

                                        self.yang_name = "isoigrp-list"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['iso_area_tag']
                                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap))])
                                        self._leafs = OrderedDict([
                                            ('iso_area_tag', (YLeaf(YType.str, 'iso-area-tag'), ['str'])),
                                        ])
                                        self.iso_area_tag = None

                                        self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                        self._segment_path = lambda: "isoigrp-list" + "[iso-area-tag='" + str(self.iso_area_tag) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/iso-igrp/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList, ['iso_area_tag'], name, value)


                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "isoigrp-list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.RipMetricRouteMap.Metric>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/iso-igrp/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/iso-igrp/rip-metric-route-map/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Mobile(Entity):
                                """
                                Mobile routes
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile, self).__init__()

                                    self.yang_name = "mobile"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "mobile"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "mobile"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/mobile/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/mobile/rip-metric-route-map/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Mobile.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Odr(Entity):
                                """
                                On Demand stub Routes
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr, self).__init__()

                                    self.yang_name = "odr"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "odr"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "odr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/odr/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/odr/rip-metric-route-map/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Odr.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: process_id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Vrf>`
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match>`
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.RipMetricRouteMap>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['process_id']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Vrf)), ("match", ("match", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.RipMetricRouteMap))])
                                    self._leafs = OrderedDict([
                                        ('process_id', (YLeaf(YType.uint16, 'process-id'), ['int'])),
                                    ])
                                    self.process_id = None

                                    self.match = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                                    self.vrf = YList(self)
                                    self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf, ['process_id'], name, value)


                                class Vrf(Entity):
                                    """
                                    VPN Routing/Forwarding Instance
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None
                                        self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Vrf, ['name'], name, value)


                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: rip_metric_route_map
                                        
                                        	
                                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.RipMetricRouteMap>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.RipMetricRouteMap))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.RipMetricRouteMap()
                                            self.rip_metric_route_map.parent = self
                                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal, [], name, value)


                                        class RipMetricRouteMap(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, self).__init__()

                                                self.yang_name = "rip-metric-route-map"
                                                self.yang_parent_name = "internal"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric()
                                                self.metric.parent = self
                                                self._children_name_map["metric"] = "metric"
                                                self._segment_path = lambda: "rip-metric-route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, ['route_map'], name, value)


                                            class Metric(Entity):
                                                """
                                                Metric for redistributed routes
                                                
                                                .. attribute:: metric_value
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..16
                                                
                                                .. attribute:: transparent
                                                
                                                	Transparently redistribute metric
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, self).__init__()

                                                    self.yang_name = "metric"
                                                    self.yang_parent_name = "rip-metric-route-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                    ])
                                                    self.metric_value = None
                                                    self.transparent = None
                                                    self._segment_path = lambda: "metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: rip_metric_route_map
                                        
                                        	
                                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.RipMetricRouteMap>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.RipMetricRouteMap))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                            ])
                                            self.external_routes = None

                                            self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.RipMetricRouteMap()
                                            self.rip_metric_route_map.parent = self
                                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External, ['external_routes'], name, value)


                                        class RipMetricRouteMap(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.RipMetricRouteMap, self).__init__()

                                                self.yang_name = "rip-metric-route-map"
                                                self.yang_parent_name = "external"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric()
                                                self.metric.parent = self
                                                self._children_name_map["metric"] = "metric"
                                                self._segment_path = lambda: "rip-metric-route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.RipMetricRouteMap, ['route_map'], name, value)


                                            class Metric(Entity):
                                                """
                                                Metric for redistributed routes
                                                
                                                .. attribute:: metric_value
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..16
                                                
                                                .. attribute:: transparent
                                                
                                                	Transparently redistribute metric
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, self).__init__()

                                                    self.yang_name = "metric"
                                                    self.yang_parent_name = "rip-metric-route-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                    ])
                                                    self.metric_value = None
                                                    self.transparent = None
                                                    self._segment_path = lambda: "metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: rip_metric_route_map
                                        
                                        	
                                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                            ])
                                            self.nssa_external_routes = None

                                            self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap()
                                            self.rip_metric_route_map.parent = self
                                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal, ['nssa_external_routes'], name, value)


                                        class RipMetricRouteMap(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, self).__init__()

                                                self.yang_name = "rip-metric-route-map"
                                                self.yang_parent_name = "nssa-external"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric()
                                                self.metric.parent = self
                                                self._children_name_map["metric"] = "metric"
                                                self._segment_path = lambda: "rip-metric-route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, ['route_map'], name, value)


                                            class Metric(Entity):
                                                """
                                                Metric for redistributed routes
                                                
                                                .. attribute:: metric_value
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..16
                                                
                                                .. attribute:: transparent
                                                
                                                	Transparently redistribute metric
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, self).__init__()

                                                    self.yang_name = "metric"
                                                    self.yang_parent_name = "rip-metric-route-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                    ])
                                                    self.metric_value = None
                                                    self.transparent = None
                                                    self._segment_path = lambda: "metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Ospf.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "static"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/static/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/static/rip-metric-route-map/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Static.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Rip_(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "rip"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/rip/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/redistribute/rip/rip-metric-route-map/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Redistribute.Rip_.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                        class Timers(Entity):
                            """
                            Adjust routing timers
                            
                            .. attribute:: basic
                            
                            	Basic routing protocol update timers
                            	**type**\:  :py:class:`Basic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Timers.Basic>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("basic", ("basic", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Timers.Basic))])
                                self._leafs = OrderedDict()

                                self.basic = Native.Router.Rip.AddressFamily.Ipv4.Unicast.Timers.Basic()
                                self.basic.parent = self
                                self._children_name_map["basic"] = "basic"
                                self._segment_path = lambda: "timers"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Timers, [], name, value)


                            class Basic(Entity):
                                """
                                Basic routing protocol update timers
                                
                                .. attribute:: updates
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: invalid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: holddown
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: flush
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: sleep
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Timers.Basic, self).__init__()

                                    self.yang_name = "basic"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('updates', (YLeaf(YType.uint32, 'updates'), ['int'])),
                                        ('invalid', (YLeaf(YType.uint32, 'invalid'), ['int'])),
                                        ('holddown', (YLeaf(YType.uint32, 'holddown'), ['int'])),
                                        ('flush', (YLeaf(YType.uint32, 'flush'), ['int'])),
                                        ('sleep', (YLeaf(YType.uint32, 'sleep'), ['int'])),
                                    ])
                                    self.updates = None
                                    self.invalid = None
                                    self.holddown = None
                                    self.flush = None
                                    self.sleep = None
                                    self._segment_path = lambda: "basic"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/timers/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Timers.Basic, ['updates', 'invalid', 'holddown', 'flush', 'sleep'], name, value)


                        class PassiveInterface(Entity):
                            """
                            Suppress routing updates on an interface
                            
                            .. attribute:: default
                            
                            	Suppress routing updates on all interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: interface
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.PassiveInterface, self).__init__()

                                self.yang_name = "passive-interface"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ])
                                self.default = None
                                self.interface = None
                                self._segment_path = lambda: "passive-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.PassiveInterface, [u'default', u'interface'], name, value)


                        class Disable(Entity):
                            """
                            
                            
                            .. attribute:: passive_interface
                            
                            	
                            	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.Disable.PassiveInterface>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Disable, self).__init__()

                                self.yang_name = "disable"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.Rip.AddressFamily.Ipv4.Unicast.Disable.PassiveInterface))])
                                self._leafs = OrderedDict()

                                self.passive_interface = YList(self)
                                self._segment_path = lambda: "disable"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Disable, [], name, value)


                            class PassiveInterface(Entity):
                                """
                                
                                
                                .. attribute:: interface  (key)
                                
                                	
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Disable.PassiveInterface, self).__init__()

                                    self.yang_name = "passive-interface"
                                    self.yang_parent_name = "disable"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['interface']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ])
                                    self.interface = None
                                    self._segment_path = lambda: "passive-interface" + "[interface='" + str(self.interface) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/disable/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.Disable.PassiveInterface, [u'interface'], name, value)


                        class TrafficShare(Entity):
                            """
                            How to compute traffic share over alternate paths
                            
                            .. attribute:: min
                            
                            	All traffic shared among min metric paths
                            	**type**\:  :py:class:`Min <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Unicast.TrafficShare.Min>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.TrafficShare, self).__init__()

                                self.yang_name = "traffic-share"
                                self.yang_parent_name = "unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("min", ("min", Native.Router.Rip.AddressFamily.Ipv4.Unicast.TrafficShare.Min))])
                                self._leafs = OrderedDict()

                                self.min = Native.Router.Rip.AddressFamily.Ipv4.Unicast.TrafficShare.Min()
                                self.min.parent = self
                                self._children_name_map["min"] = "min"
                                self._segment_path = lambda: "traffic-share"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.TrafficShare, [], name, value)


                            class Min(Entity):
                                """
                                All traffic shared among min metric paths
                                
                                .. attribute:: across_interfaces
                                
                                	Use different interfaces for equal\-cost paths
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Unicast.TrafficShare.Min, self).__init__()

                                    self.yang_name = "min"
                                    self.yang_parent_name = "traffic-share"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                                    ])
                                    self.across_interfaces = None
                                    self._segment_path = lambda: "min"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/unicast/traffic-share/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Unicast.TrafficShare.Min, ['across_interfaces'], name, value)


                    class Vrf(Entity):
                        """
                        Specify parameters for a VPN Routing/Forwarding instance
                        
                        .. attribute:: name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: auto_summary
                        
                        	Enable automatic network number summarization
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: maximum_paths
                        
                        	Forward packets over multiple paths
                        	**type**\: int
                        
                        	**range:** 1..32
                        
                        .. attribute:: neighbor
                        
                        	Specify a neighbor router
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Neighbor>`
                        
                        .. attribute:: network
                        
                        	Enable routing on an IP network
                        	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Network>`
                        
                        .. attribute:: validate_update_source
                        
                        	Perform sanity checks against source address of routing updates
                        	**type**\: bool
                        
                        .. attribute:: default_information
                        
                        	Control distribution of default information
                        	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.DefaultInformation>`
                        
                        .. attribute:: default_metric
                        
                        	Set metric of redistributed routes
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: distance
                        
                        	Define an administrative distance
                        	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Distance>`
                        
                        .. attribute:: distribute_list
                        
                        	Filter networks in routing updates
                        	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList>`
                        
                        .. attribute:: offset_list
                        
                        	Add or subtract offset from RIP metrics
                        	**type**\: list of  		 :py:class:`OffsetList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.OffsetList>`
                        
                        .. attribute:: redistribute
                        
                        	Redistribute information from another routing protocol
                        	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute>`
                        
                        .. attribute:: timers
                        
                        	Adjust routing timers
                        	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Timers>`
                        
                        .. attribute:: version
                        
                        	Set routing protocol version
                        	**type**\: int
                        
                        	**range:** 1..2
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Neighbor)), ("network", ("network", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Network)), ("default-information", ("default_information", Native.Router.Rip.AddressFamily.Ipv4.Vrf.DefaultInformation)), ("distance", ("distance", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Distance)), ("distribute-list", ("distribute_list", Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList)), ("offset-list", ("offset_list", Native.Router.Rip.AddressFamily.Ipv4.Vrf.OffsetList)), ("redistribute", ("redistribute", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute)), ("timers", ("timers", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Timers))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('auto_summary', (YLeaf(YType.empty, 'auto-summary'), ['Empty'])),
                                ('maximum_paths', (YLeaf(YType.uint8, 'maximum-paths'), ['int'])),
                                ('validate_update_source', (YLeaf(YType.boolean, 'validate-update-source'), ['bool'])),
                                ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                            ])
                            self.name = None
                            self.auto_summary = None
                            self.maximum_paths = None
                            self.validate_update_source = None
                            self.default_metric = None
                            self.version = None

                            self.default_information = Native.Router.Rip.AddressFamily.Ipv4.Vrf.DefaultInformation()
                            self.default_information.parent = self
                            self._children_name_map["default_information"] = "default-information"

                            self.distance = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"

                            self.distribute_list = Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList()
                            self.distribute_list.parent = self
                            self._children_name_map["distribute_list"] = "distribute-list"

                            self.redistribute = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute()
                            self.redistribute.parent = self
                            self._children_name_map["redistribute"] = "redistribute"

                            self.timers = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"

                            self.neighbor = YList(self)
                            self.network = YList(self)
                            self.offset_list = YList(self)
                            self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/address-family/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf, ['name', 'auto_summary', 'maximum_paths', 'validate_update_source', 'default_metric', 'version'], name, value)


                        class Neighbor(Entity):
                            """
                            Specify a neighbor router
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ])
                                self.ip = None
                                self._segment_path = lambda: "neighbor" + "[ip='" + str(self.ip) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Neighbor, ['ip'], name, value)


                        class Network(Entity):
                            """
                            Enable routing on an IP network
                            
                            .. attribute:: ip  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Network, self).__init__()

                                self.yang_name = "network"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ])
                                self.ip = None
                                self._segment_path = lambda: "network" + "[ip='" + str(self.ip) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Network, ['ip'], name, value)


                        class DefaultInformation(Entity):
                            """
                            Control distribution of default information
                            
                            .. attribute:: originate
                            
                            	Distribute a default route
                            	**type**\:  :py:class:`Originate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.DefaultInformation.Originate>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DefaultInformation, self).__init__()

                                self.yang_name = "default-information"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("originate", ("originate", Native.Router.Rip.AddressFamily.Ipv4.Vrf.DefaultInformation.Originate))])
                                self._leafs = OrderedDict()

                                self.originate = None
                                self._children_name_map["originate"] = "originate"
                                self._segment_path = lambda: "default-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DefaultInformation, [], name, value)


                            class Originate(Entity):
                                """
                                Distribute a default route
                                
                                .. attribute:: route_map
                                
                                	Route\-map reference
                                	**type**\: str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DefaultInformation.Originate, self).__init__()

                                    self.yang_name = "originate"
                                    self.yang_parent_name = "default-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None
                                    self._segment_path = lambda: "originate"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DefaultInformation.Originate, ['route_map'], name, value)


                        class Distance(Entity):
                            """
                            Define an administrative distance
                            
                            .. attribute:: distance_leaf
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..255
                            
                            .. attribute:: distance_list
                            
                            	
                            	**type**\: list of  		 :py:class:`DistanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Distance.DistanceList>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Distance, self).__init__()

                                self.yang_name = "distance"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("distance-list", ("distance_list", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Distance.DistanceList))])
                                self._leafs = OrderedDict([
                                    ('distance_leaf', (YLeaf(YType.uint8, 'distance-leaf'), ['int'])),
                                ])
                                self.distance_leaf = None

                                self.distance_list = YList(self)
                                self._segment_path = lambda: "distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Distance, ['distance_leaf'], name, value)


                            class DistanceList(Entity):
                                """
                                
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: ip  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Distance.DistanceList, self).__init__()

                                    self.yang_name = "distance-list"
                                    self.yang_parent_name = "distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number','ip','mask']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                        ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                    ])
                                    self.number = None
                                    self.ip = None
                                    self.mask = None
                                    self._segment_path = lambda: "distance-list" + "[number='" + str(self.number) + "']" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Distance.DistanceList, ['number', 'ip', 'mask'], name, value)


                        class DistributeList(Entity):
                            """
                            Filter networks in routing updates
                            
                            .. attribute:: accesslist
                            
                            	
                            	**type**\: list of  		 :py:class:`Accesslist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.Accesslist>`
                            
                            .. attribute:: accesslist_ifname
                            
                            	
                            	**type**\: list of  		 :py:class:`AccesslistIfname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistIfname>`
                            
                            .. attribute:: accesslist_prefix_gateway
                            
                            	
                            	**type**\: list of  		 :py:class:`AccesslistPrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGateway>`
                            
                            .. attribute:: accesslist_prefix_gateway_ifname
                            
                            	
                            	**type**\: list of  		 :py:class:`AccesslistPrefixGatewayIfname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGatewayIfname>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList, self).__init__()

                                self.yang_name = "distribute-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("accesslist", ("accesslist", Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.Accesslist)), ("accesslist-ifname", ("accesslist_ifname", Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistIfname)), ("accesslist-prefix-gateway", ("accesslist_prefix_gateway", Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGateway)), ("accesslist-prefix-gateway-ifname", ("accesslist_prefix_gateway_ifname", Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGatewayIfname))])
                                self._leafs = OrderedDict()

                                self.accesslist = YList(self)
                                self.accesslist_ifname = YList(self)
                                self.accesslist_prefix_gateway = YList(self)
                                self.accesslist_prefix_gateway_ifname = YList(self)
                                self._segment_path = lambda: "distribute-list"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList, [], name, value)


                            class Accesslist(Entity):
                                """
                                
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.Accesslist, self).__init__()

                                    self.yang_name = "accesslist"
                                    self.yang_parent_name = "distribute-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['in_out']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                    ])
                                    self.in_out = None
                                    self._segment_path = lambda: "accesslist" + "[in-out='" + str(self.in_out) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.Accesslist, ['in_out'], name, value)


                            class AccesslistIfname(Entity):
                                """
                                
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                                
                                .. attribute:: interface  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: interface_routing_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: isis_tag
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistIfname, self).__init__()

                                    self.yang_name = "accesslist-ifname"
                                    self.yang_parent_name = "distribute-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['in_out','interface']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('interface_routing_id', (YLeaf(YType.uint8, 'interface-routing-id'), ['int'])),
                                        ('isis_tag', (YLeaf(YType.str, 'isis-tag'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.in_out = None
                                    self.interface = None
                                    self.interface_routing_id = None
                                    self.isis_tag = None
                                    self.vrf = None
                                    self._segment_path = lambda: "accesslist-ifname" + "[in-out='" + str(self.in_out) + "']" + "[interface='" + str(self.interface) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistIfname, ['in_out', 'interface', 'interface_routing_id', 'isis_tag', 'vrf'], name, value)


                            class AccesslistPrefixGateway(Entity):
                                """
                                
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                                
                                .. attribute:: prefix_gateway
                                
                                	
                                	**type**\:  :py:class:`PrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGateway.PrefixGateway>`
                                
                                	**mandatory**\: True
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGateway, self).__init__()

                                    self.yang_name = "accesslist-prefix-gateway"
                                    self.yang_parent_name = "distribute-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['in_out']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                        ('prefix_gateway', (YLeaf(YType.enumeration, 'prefix-gateway'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGateway.PrefixGateway')])),
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.in_out = None
                                    self.prefix_gateway = None
                                    self.name = None
                                    self._segment_path = lambda: "accesslist-prefix-gateway" + "[in-out='" + str(self.in_out) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGateway, ['in_out', 'prefix_gateway', 'name'], name, value)

                                class PrefixGateway(Enum):
                                    """
                                    PrefixGateway (Enum Class)

                                    .. data:: prefix = 0

                                    .. data:: gateway = 1

                                    .. data:: route_map = 2

                                    """

                                    prefix = Enum.YLeaf(0, "prefix")

                                    gateway = Enum.YLeaf(1, "gateway")

                                    route_map = Enum.YLeaf(2, "route-map")



                            class AccesslistPrefixGatewayIfname(Entity):
                                """
                                
                                
                                .. attribute:: in_out  (key)
                                
                                	
                                	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                                
                                .. attribute:: interface  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: prefix_gateway
                                
                                	
                                	**type**\:  :py:class:`PrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGatewayIfname.PrefixGateway>`
                                
                                	**mandatory**\: True
                                
                                .. attribute:: name
                                
                                	
                                	**type**\: str
                                
                                	**mandatory**\: True
                                
                                .. attribute:: interface_routing_id
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: isis_tag
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGatewayIfname, self).__init__()

                                    self.yang_name = "accesslist-prefix-gateway-ifname"
                                    self.yang_parent_name = "distribute-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['in_out','interface']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('prefix_gateway', (YLeaf(YType.enumeration, 'prefix-gateway'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGatewayIfname.PrefixGateway')])),
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('interface_routing_id', (YLeaf(YType.uint8, 'interface-routing-id'), ['int'])),
                                        ('isis_tag', (YLeaf(YType.str, 'isis-tag'), ['str'])),
                                        ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ])
                                    self.in_out = None
                                    self.interface = None
                                    self.prefix_gateway = None
                                    self.name = None
                                    self.interface_routing_id = None
                                    self.isis_tag = None
                                    self.vrf = None
                                    self._segment_path = lambda: "accesslist-prefix-gateway-ifname" + "[in-out='" + str(self.in_out) + "']" + "[interface='" + str(self.interface) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.DistributeList.AccesslistPrefixGatewayIfname, ['in_out', 'interface', 'prefix_gateway', 'name', 'interface_routing_id', 'isis_tag', 'vrf'], name, value)

                                class PrefixGateway(Enum):
                                    """
                                    PrefixGateway (Enum Class)

                                    .. data:: prefix = 0

                                    .. data:: gateway = 1

                                    .. data:: route_map = 2

                                    """

                                    prefix = Enum.YLeaf(0, "prefix")

                                    gateway = Enum.YLeaf(1, "gateway")

                                    route_map = Enum.YLeaf(2, "route-map")



                        class OffsetList(Entity):
                            """
                            Add or subtract offset from RIP metrics
                            
                            .. attribute:: in_out  (key)
                            
                            	
                            	**type**\:  :py:class:`OffsetListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_rip.OffsetListInOutType>`
                            
                            .. attribute:: offset
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..16
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.OffsetList, self).__init__()

                                self.yang_name = "offset-list"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['in_out']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_rip', 'OffsetListInOutType', '')])),
                                    ('offset', (YLeaf(YType.uint8, 'offset'), ['int'])),
                                ])
                                self.in_out = None
                                self.offset = None
                                self._segment_path = lambda: "offset-list" + "[in-out='" + str(self.in_out) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.OffsetList, ['in_out', 'offset'], name, value)


                        class Redistribute(Entity):
                            """
                            Redistribute information from another routing protocol
                            
                            .. attribute:: rip_metric_route_map
                            
                            	
                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.RipMetricRouteMap>`
                            
                            .. attribute:: connected
                            
                            	Connected
                            	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: bgp
                            
                            	Border Gateway Protocol (BGP)
                            	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp>`
                            
                            .. attribute:: eigrp
                            
                            	Enhanced Interior Gateway Routing Protocol (EIGRP)
                            	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp>`
                            
                            .. attribute:: isis
                            
                            	ISO IS\-IS
                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: iso_igrp
                            
                            	IGRP for OSI networks
                            	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: mobile
                            
                            	Mobile routes
                            	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: odr
                            
                            	On Demand stub Routes
                            	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: ospf
                            
                            	Open Shortest Path First (OSPF)
                            	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf>`
                            
                            .. attribute:: static
                            
                            	Static routes
                            	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: rip
                            
                            	Routing Information Protocol (RIP)
                            	**type**\:  :py:class:`Rip_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute, self).__init__()

                                self.yang_name = "redistribute"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.RipMetricRouteMap)), ("connected", ("connected", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected)), ("bgp", ("bgp", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp)), ("eigrp", ("eigrp", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf)), ("static", ("static", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static)), ("rip", ("rip", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_))])
                                self._leafs = OrderedDict()

                                self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.RipMetricRouteMap()
                                self.rip_metric_route_map.parent = self
                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                                self.connected = None
                                self._children_name_map["connected"] = "connected"

                                self.isis = None
                                self._children_name_map["isis"] = "isis"

                                self.iso_igrp = None
                                self._children_name_map["iso_igrp"] = "iso-igrp"

                                self.mobile = None
                                self._children_name_map["mobile"] = "mobile"

                                self.odr = None
                                self._children_name_map["odr"] = "odr"

                                self.static = None
                                self._children_name_map["static"] = "static"

                                self.rip = None
                                self._children_name_map["rip"] = "rip"

                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self.ospf = YList(self)
                                self._segment_path = lambda: "redistribute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute, [], name, value)


                            class RipMetricRouteMap(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.RipMetricRouteMap.Metric>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.RipMetricRouteMap, self).__init__()

                                    self.yang_name = "rip-metric-route-map"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.RipMetricRouteMap.Metric))])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.RipMetricRouteMap.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "rip-metric-route-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.RipMetricRouteMap, ['route_map'], name, value)


                                class Metric(Entity):
                                    """
                                    Metric for redistributed routes
                                    
                                    .. attribute:: metric_value
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..16
                                    
                                    .. attribute:: transparent
                                    
                                    	Transparently redistribute metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.RipMetricRouteMap.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "rip-metric-route-map"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                        ])
                                        self.metric_value = None
                                        self.transparent = None
                                        self._segment_path = lambda: "metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Connected(Entity):
                                """
                                Connected
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected, self).__init__()

                                    self.yang_name = "connected"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "connected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "connected"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Connected.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Bgp(Entity):
                                """
                                Border Gateway Protocol (BGP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 1..4294967295
                                
                                		**type**\: str
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RipMetricRouteMap>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RipMetricRouteMap))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                                    ])
                                    self.as_number = None

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp, ['as_number'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "bgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Bgp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Eigrp(Entity):
                                """
                                Enhanced Interior Gateway Routing Protocol (EIGRP)
                                
                                .. attribute:: as_number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RipMetricRouteMap>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['as_number']
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RipMetricRouteMap))])
                                    self._leafs = OrderedDict([
                                        ('as_number', (YLeaf(YType.uint16, 'as-number'), ['int'])),
                                    ])
                                    self.as_number = None

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp, ['as_number'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "eigrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Eigrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Isis(Entity):
                                """
                                ISO IS\-IS
                                
                                .. attribute:: isis_area
                                
                                	
                                	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea>`
                                
                                .. attribute:: rip_isis_redist
                                
                                	
                                	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis, self).__init__()

                                    self.yang_name = "isis"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea)), ("rip-isis-redist", ("rip_isis_redist", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_isis_redist = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist()
                                    self.rip_isis_redist.parent = self
                                    self._children_name_map["rip_isis_redist"] = "rip-isis-redist"

                                    self.isis_area = YList(self)
                                    self._segment_path = lambda: "isis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis, [], name, value)


                                class IsisArea(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: rip_isis_redist
                                    
                                    	
                                    	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea, self).__init__()

                                        self.yang_name = "isis-area"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("rip-isis-redist", ("rip_isis_redist", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.rip_isis_redist = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist()
                                        self.rip_isis_redist.parent = self
                                        self._children_name_map["rip_isis_redist"] = "rip-isis-redist"
                                        self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea, ['name'], name, value)


                                    class RipIsisRedist(Entity):
                                        """
                                        
                                        
                                        .. attribute:: isis_level_routes
                                        
                                        	
                                        	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes>`
                                        
                                        .. attribute:: rip_metric_route_map
                                        
                                        	
                                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist, self).__init__()

                                            self.yang_name = "rip-isis-redist"
                                            self.yang_parent_name = "isis-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap))])
                                            self._leafs = OrderedDict([
                                                ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes')])),
                                            ])
                                            self.isis_level_routes = None

                                            self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap()
                                            self.rip_metric_route_map.parent = self
                                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                            self._segment_path = lambda: "rip-isis-redist"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist, ['isis_level_routes'], name, value)

                                        class IsisLevelRoutes(Enum):
                                            """
                                            IsisLevelRoutes (Enum Class)

                                            .. data:: level_1 = 0

                                            .. data:: level_2 = 1

                                            .. data:: level_1_2 = 2

                                            """

                                            level_1 = Enum.YLeaf(0, "level-1")

                                            level_2 = Enum.YLeaf(1, "level-2")

                                            level_1_2 = Enum.YLeaf(2, "level-1-2")



                                        class RipMetricRouteMap(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                                self.yang_name = "rip-metric-route-map"
                                                self.yang_parent_name = "rip-isis-redist"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric()
                                                self.metric.parent = self
                                                self._children_name_map["metric"] = "metric"
                                                self._segment_path = lambda: "rip-metric-route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                                            class Metric(Entity):
                                                """
                                                Metric for redistributed routes
                                                
                                                .. attribute:: metric_value
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..16
                                                
                                                .. attribute:: transparent
                                                
                                                	Transparently redistribute metric
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                                    self.yang_name = "metric"
                                                    self.yang_parent_name = "rip-metric-route-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                    ])
                                                    self.metric_value = None
                                                    self.transparent = None
                                                    self._segment_path = lambda: "metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class RipIsisRedist(Entity):
                                    """
                                    
                                    
                                    .. attribute:: isis_level_routes
                                    
                                    	
                                    	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes>`
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist, self).__init__()

                                        self.yang_name = "rip-isis-redist"
                                        self.yang_parent_name = "isis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap))])
                                        self._leafs = OrderedDict([
                                            ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes')])),
                                        ])
                                        self.isis_level_routes = None

                                        self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                        self._segment_path = lambda: "rip-isis-redist"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist, ['isis_level_routes'], name, value)

                                    class IsisLevelRoutes(Enum):
                                        """
                                        IsisLevelRoutes (Enum Class)

                                        .. data:: level_1 = 0

                                        .. data:: level_2 = 1

                                        .. data:: level_1_2 = 2

                                        """

                                        level_1 = Enum.YLeaf(0, "level-1")

                                        level_2 = Enum.YLeaf(1, "level-2")

                                        level_1_2 = Enum.YLeaf(2, "level-1-2")



                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric>`
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "rip-isis-redist"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class IsoIgrp(Entity):
                                """
                                IGRP for OSI networks
                                
                                .. attribute:: isoigrp_list
                                
                                	Border Gateway Protocol (BGP)
                                	**type**\: list of  		 :py:class:`IsoigrpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList>`
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp, self).__init__()

                                    self.yang_name = "iso-igrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("isoigrp-list", ("isoigrp_list", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                                    self.isoigrp_list = YList(self)
                                    self._segment_path = lambda: "iso-igrp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp, [], name, value)


                                class IsoigrpList(Entity):
                                    """
                                    Border Gateway Protocol (BGP)
                                    
                                    .. attribute:: iso_area_tag  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: rip_metric_route_map
                                    
                                    	
                                    	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList, self).__init__()

                                        self.yang_name = "isoigrp-list"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['iso_area_tag']
                                        self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap))])
                                        self._leafs = OrderedDict([
                                            ('iso_area_tag', (YLeaf(YType.str, 'iso-area-tag'), ['str'])),
                                        ])
                                        self.iso_area_tag = None

                                        self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap()
                                        self.rip_metric_route_map.parent = self
                                        self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                        self._segment_path = lambda: "isoigrp-list" + "[iso-area-tag='" + str(self.iso_area_tag) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList, ['iso_area_tag'], name, value)


                                    class RipMetricRouteMap(Entity):
                                        """
                                        
                                        
                                        .. attribute:: route_map
                                        
                                        	Route map reference
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	Metric for redistributed routes
                                        	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, self).__init__()

                                            self.yang_name = "rip-metric-route-map"
                                            self.yang_parent_name = "isoigrp-list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric))])
                                            self._leafs = OrderedDict([
                                                ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                            ])
                                            self.route_map = None

                                            self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric()
                                            self.metric.parent = self
                                            self._children_name_map["metric"] = "metric"
                                            self._segment_path = lambda: "rip-metric-route-map"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, ['route_map'], name, value)


                                        class Metric(Entity):
                                            """
                                            Metric for redistributed routes
                                            
                                            .. attribute:: metric_value
                                            
                                            	Metric for redistributed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..16
                                            
                                            .. attribute:: transparent
                                            
                                            	Transparently redistribute metric
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, self).__init__()

                                                self.yang_name = "metric"
                                                self.yang_parent_name = "rip-metric-route-map"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                    ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                ])
                                                self.metric_value = None
                                                self.transparent = None
                                                self._segment_path = lambda: "metric"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap.Metric>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "iso-igrp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Mobile(Entity):
                                """
                                Mobile routes
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile, self).__init__()

                                    self.yang_name = "mobile"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "mobile"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "mobile"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Mobile.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Odr(Entity):
                                """
                                On Demand stub Routes
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr, self).__init__()

                                    self.yang_name = "odr"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "odr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "odr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Odr.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Ospf(Entity):
                                """
                                Open Shortest Path First (OSPF)
                                
                                .. attribute:: process_id  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: vrf
                                
                                	VPN Routing/Forwarding Instance
                                	**type**\: list of  		 :py:class:`Vrf_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Vrf_>`
                                
                                .. attribute:: match
                                
                                	Redistribution of OSPF routes
                                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match>`
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.RipMetricRouteMap>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf, self).__init__()

                                    self.yang_name = "ospf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['process_id']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Vrf_)), ("match", ("match", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.RipMetricRouteMap))])
                                    self._leafs = OrderedDict([
                                        ('process_id', (YLeaf(YType.uint16, 'process-id'), ['int'])),
                                    ])
                                    self.process_id = None

                                    self.match = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match()
                                    self.match.parent = self
                                    self._children_name_map["match"] = "match"

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                                    self.vrf = YList(self)
                                    self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf, ['process_id'], name, value)


                                class Vrf_(Entity):
                                    """
                                    VPN Routing/Forwarding Instance
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Vrf_, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None
                                        self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Vrf_, ['name'], name, value)


                                class Match(Entity):
                                    """
                                    Redistribution of OSPF routes
                                    
                                    .. attribute:: internal
                                    
                                    	Redistribute OSPF internal routes
                                    	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: external
                                    
                                    	Redistribute OSPF external routes
                                    	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: nssa_external
                                    
                                    	Redistribute OSPF NSSA external routes
                                    	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match, self).__init__()

                                        self.yang_name = "match"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal))])
                                        self._leafs = OrderedDict()

                                        self.internal = None
                                        self._children_name_map["internal"] = "internal"

                                        self.external = None
                                        self._children_name_map["external"] = "external"

                                        self.nssa_external = None
                                        self._children_name_map["nssa_external"] = "nssa-external"
                                        self._segment_path = lambda: "match"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match, [], name, value)


                                    class Internal(Entity):
                                        """
                                        Redistribute OSPF internal routes
                                        
                                        .. attribute:: rip_metric_route_map
                                        
                                        	
                                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal, self).__init__()

                                            self.yang_name = "internal"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap()
                                            self.rip_metric_route_map.parent = self
                                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                            self._segment_path = lambda: "internal"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal, [], name, value)


                                        class RipMetricRouteMap(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, self).__init__()

                                                self.yang_name = "rip-metric-route-map"
                                                self.yang_parent_name = "internal"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric()
                                                self.metric.parent = self
                                                self._children_name_map["metric"] = "metric"
                                                self._segment_path = lambda: "rip-metric-route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, ['route_map'], name, value)


                                            class Metric(Entity):
                                                """
                                                Metric for redistributed routes
                                                
                                                .. attribute:: metric_value
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..16
                                                
                                                .. attribute:: transparent
                                                
                                                	Transparently redistribute metric
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, self).__init__()

                                                    self.yang_name = "metric"
                                                    self.yang_parent_name = "rip-metric-route-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                    ])
                                                    self.metric_value = None
                                                    self.transparent = None
                                                    self._segment_path = lambda: "metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                    class External(Entity):
                                        """
                                        Redistribute OSPF external routes
                                        
                                        .. attribute:: external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: rip_metric_route_map
                                        
                                        	
                                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External, self).__init__()

                                            self.yang_name = "external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                            ])
                                            self.external_routes = None

                                            self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap()
                                            self.rip_metric_route_map.parent = self
                                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                            self._segment_path = lambda: "external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External, ['external_routes'], name, value)


                                        class RipMetricRouteMap(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap, self).__init__()

                                                self.yang_name = "rip-metric-route-map"
                                                self.yang_parent_name = "external"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric()
                                                self.metric.parent = self
                                                self._children_name_map["metric"] = "metric"
                                                self._segment_path = lambda: "rip-metric-route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap, ['route_map'], name, value)


                                            class Metric(Entity):
                                                """
                                                Metric for redistributed routes
                                                
                                                .. attribute:: metric_value
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..16
                                                
                                                .. attribute:: transparent
                                                
                                                	Transparently redistribute metric
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, self).__init__()

                                                    self.yang_name = "metric"
                                                    self.yang_parent_name = "rip-metric-route-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                    ])
                                                    self.metric_value = None
                                                    self.transparent = None
                                                    self._segment_path = lambda: "metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                    class NssaExternal(Entity):
                                        """
                                        Redistribute OSPF NSSA external routes
                                        
                                        .. attribute:: nssa_external_routes
                                        
                                        	
                                        	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                        
                                        .. attribute:: rip_metric_route_map
                                        
                                        	
                                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                            self.yang_name = "nssa-external"
                                            self.yang_parent_name = "match"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                            ])
                                            self.nssa_external_routes = None

                                            self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap()
                                            self.rip_metric_route_map.parent = self
                                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                            self._segment_path = lambda: "nssa-external"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal, ['nssa_external_routes'], name, value)


                                        class RipMetricRouteMap(Entity):
                                            """
                                            
                                            
                                            .. attribute:: metric
                                            
                                            	Metric for redistributed routes
                                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric>`
                                            
                                            .. attribute:: route_map
                                            
                                            	Route map reference
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-rip'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, self).__init__()

                                                self.yang_name = "rip-metric-route-map"
                                                self.yang_parent_name = "nssa-external"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric))])
                                                self._leafs = OrderedDict([
                                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                ])
                                                self.route_map = None

                                                self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric()
                                                self.metric.parent = self
                                                self._children_name_map["metric"] = "metric"
                                                self._segment_path = lambda: "rip-metric-route-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, ['route_map'], name, value)


                                            class Metric(Entity):
                                                """
                                                Metric for redistributed routes
                                                
                                                .. attribute:: metric_value
                                                
                                                	Metric for redistributed routes
                                                	**type**\: int
                                                
                                                	**range:** 0..16
                                                
                                                .. attribute:: transparent
                                                
                                                	Transparently redistribute metric
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-rip'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, self).__init__()

                                                    self.yang_name = "metric"
                                                    self.yang_parent_name = "rip-metric-route-map"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                                    ])
                                                    self.metric_value = None
                                                    self.transparent = None
                                                    self._segment_path = lambda: "metric"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "ospf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Ospf.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Static(Entity):
                                """
                                Static routes
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static, self).__init__()

                                    self.yang_name = "static"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "static"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "static"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Static.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class Rip_(Entity):
                                """
                                Routing Information Protocol (RIP)
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_, self).__init__()

                                    self.yang_name = "rip"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "rip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "rip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Redistribute.Rip_.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                        class Timers(Entity):
                            """
                            Adjust routing timers
                            
                            .. attribute:: basic
                            
                            	Basic routing protocol update timers
                            	**type**\:  :py:class:`Basic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.AddressFamily.Ipv4.Vrf.Timers.Basic>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("basic", ("basic", Native.Router.Rip.AddressFamily.Ipv4.Vrf.Timers.Basic))])
                                self._leafs = OrderedDict()

                                self.basic = Native.Router.Rip.AddressFamily.Ipv4.Vrf.Timers.Basic()
                                self.basic.parent = self
                                self._children_name_map["basic"] = "basic"
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Timers, [], name, value)


                            class Basic(Entity):
                                """
                                Basic routing protocol update timers
                                
                                .. attribute:: updates
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: invalid
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: holddown
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: flush
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: sleep
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Timers.Basic, self).__init__()

                                    self.yang_name = "basic"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('updates', (YLeaf(YType.uint32, 'updates'), ['int'])),
                                        ('invalid', (YLeaf(YType.uint32, 'invalid'), ['int'])),
                                        ('holddown', (YLeaf(YType.uint32, 'holddown'), ['int'])),
                                        ('flush', (YLeaf(YType.uint32, 'flush'), ['int'])),
                                        ('sleep', (YLeaf(YType.uint32, 'sleep'), ['int'])),
                                    ])
                                    self.updates = None
                                    self.invalid = None
                                    self.holddown = None
                                    self.flush = None
                                    self.sleep = None
                                    self._segment_path = lambda: "basic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.AddressFamily.Ipv4.Vrf.Timers.Basic, ['updates', 'invalid', 'holddown', 'flush', 'sleep'], name, value)


            class Default(Entity):
                """
                Set a command to its defaults
                
                .. attribute:: address_family
                
                	Enter Address Family command mode
                	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.AddressFamily>`
                
                .. attribute:: auto_summary
                
                	Enable automatic network number summarization
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: maximum_paths
                
                	Forward packets over multiple paths
                	**type**\: int
                
                	**range:** 1..32
                
                .. attribute:: neighbor
                
                	Specify a neighbor router
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Neighbor>`
                
                .. attribute:: network
                
                	Enable routing on an IP network
                	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Network>`
                
                .. attribute:: validate_update_source
                
                	Perform sanity checks against source address of routing updates
                	**type**\: bool
                
                .. attribute:: default_information
                
                	Control distribution of default information
                	**type**\:  :py:class:`DefaultInformation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.DefaultInformation>`
                
                .. attribute:: default_metric
                
                	Set metric of redistributed routes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: distance
                
                	Define an administrative distance
                	**type**\:  :py:class:`Distance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Distance>`
                
                .. attribute:: distribute_list
                
                	Filter networks in routing updates
                	**type**\:  :py:class:`DistributeList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.DistributeList>`
                
                .. attribute:: flash_update_threshold
                
                	Specify flash update threshold in second
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: input_queue
                
                	Specify input queue depth
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: offset_list
                
                	Add or subtract offset from RIP metrics
                	**type**\: list of  		 :py:class:`OffsetList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.OffsetList>`
                
                .. attribute:: output_delay
                
                	Interpacket delay for RIP updates
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: passive_interface
                
                	Suppress routing updates on an interface
                	**type**\:  :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.PassiveInterface>`
                
                .. attribute:: disable
                
                	
                	**type**\:  :py:class:`Disable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Disable>`
                
                .. attribute:: redistribute
                
                	Redistribute information from another routing protocol
                	**type**\:  :py:class:`Redistribute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute>`
                
                .. attribute:: timers
                
                	Adjust routing timers
                	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Timers>`
                
                .. attribute:: traffic_share
                
                	How to compute traffic share over alternate paths
                	**type**\:  :py:class:`TrafficShare <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.TrafficShare>`
                
                .. attribute:: version
                
                	Set routing protocol version
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-rip'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Router.Rip.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "rip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("address-family", ("address_family", Native.Router.Rip.Default.AddressFamily)), ("neighbor", ("neighbor", Native.Router.Rip.Default.Neighbor)), ("network", ("network", Native.Router.Rip.Default.Network)), ("default-information", ("default_information", Native.Router.Rip.Default.DefaultInformation)), ("distance", ("distance", Native.Router.Rip.Default.Distance)), ("distribute-list", ("distribute_list", Native.Router.Rip.Default.DistributeList)), ("offset-list", ("offset_list", Native.Router.Rip.Default.OffsetList)), ("passive-interface", ("passive_interface", Native.Router.Rip.Default.PassiveInterface)), ("disable", ("disable", Native.Router.Rip.Default.Disable)), ("redistribute", ("redistribute", Native.Router.Rip.Default.Redistribute)), ("timers", ("timers", Native.Router.Rip.Default.Timers)), ("traffic-share", ("traffic_share", Native.Router.Rip.Default.TrafficShare))])
                    self._leafs = OrderedDict([
                        ('auto_summary', (YLeaf(YType.empty, 'auto-summary'), ['Empty'])),
                        ('maximum_paths', (YLeaf(YType.uint8, 'maximum-paths'), ['int'])),
                        ('validate_update_source', (YLeaf(YType.boolean, 'validate-update-source'), ['bool'])),
                        ('default_metric', (YLeaf(YType.empty, 'default-metric'), ['Empty'])),
                        ('flash_update_threshold', (YLeaf(YType.empty, 'flash-update-threshold'), ['Empty'])),
                        ('input_queue', (YLeaf(YType.empty, 'input-queue'), ['Empty'])),
                        ('output_delay', (YLeaf(YType.empty, 'output-delay'), ['Empty'])),
                        ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                    ])
                    self.auto_summary = None
                    self.maximum_paths = None
                    self.validate_update_source = None
                    self.default_metric = None
                    self.flash_update_threshold = None
                    self.input_queue = None
                    self.output_delay = None
                    self.version = None

                    self.address_family = Native.Router.Rip.Default.AddressFamily()
                    self.address_family.parent = self
                    self._children_name_map["address_family"] = "address-family"

                    self.default_information = Native.Router.Rip.Default.DefaultInformation()
                    self.default_information.parent = self
                    self._children_name_map["default_information"] = "default-information"

                    self.distance = Native.Router.Rip.Default.Distance()
                    self.distance.parent = self
                    self._children_name_map["distance"] = "distance"

                    self.distribute_list = Native.Router.Rip.Default.DistributeList()
                    self.distribute_list.parent = self
                    self._children_name_map["distribute_list"] = "distribute-list"

                    self.passive_interface = Native.Router.Rip.Default.PassiveInterface()
                    self.passive_interface.parent = self
                    self._children_name_map["passive_interface"] = "passive-interface"

                    self.disable = Native.Router.Rip.Default.Disable()
                    self.disable.parent = self
                    self._children_name_map["disable"] = "disable"

                    self.redistribute = Native.Router.Rip.Default.Redistribute()
                    self.redistribute.parent = self
                    self._children_name_map["redistribute"] = "redistribute"

                    self.timers = Native.Router.Rip.Default.Timers()
                    self.timers.parent = self
                    self._children_name_map["timers"] = "timers"

                    self.traffic_share = Native.Router.Rip.Default.TrafficShare()
                    self.traffic_share.parent = self
                    self._children_name_map["traffic_share"] = "traffic-share"

                    self.neighbor = YList(self)
                    self.network = YList(self)
                    self.offset_list = YList(self)
                    self._segment_path = lambda: "default"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Router.Rip.Default, ['auto_summary', 'maximum_paths', 'validate_update_source', 'default_metric', 'flash_update_threshold', 'input_queue', 'output_delay', 'version'], name, value)


                class AddressFamily(Entity):
                    """
                    Enter Address Family command mode
                    
                    .. attribute:: ipv4
                    
                    	Address family
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.AddressFamily.Ipv4>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.AddressFamily, self).__init__()

                        self.yang_name = "address-family"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Router.Rip.Default.AddressFamily.Ipv4))])
                        self._leafs = OrderedDict()

                        self.ipv4 = None
                        self._children_name_map["ipv4"] = "ipv4"
                        self._segment_path = lambda: "address-family"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.AddressFamily, [], name, value)


                    class Ipv4(Entity):
                        """
                        Address family
                        
                        .. attribute:: unicast
                        
                        	Address Family Modifier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vrf
                        
                        	Specify parameters for a VPN Routing/Forwarding instance
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.AddressFamily.Ipv4.Vrf>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.AddressFamily.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "address-family"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Rip.Default.AddressFamily.Ipv4.Vrf))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                            ])
                            self.unicast = None

                            self.vrf = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/address-family/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.AddressFamily.Ipv4, ['unicast'], name, value)


                        class Vrf(Entity):
                            """
                            Specify parameters for a VPN Routing/Forwarding instance
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.AddressFamily.Ipv4.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/address-family/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.AddressFamily.Ipv4.Vrf, ['name'], name, value)


                class Neighbor(Entity):
                    """
                    Specify a neighbor router
                    
                    .. attribute:: ip  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['ip']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                        ])
                        self.ip = None
                        self._segment_path = lambda: "neighbor" + "[ip='" + str(self.ip) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.Neighbor, ['ip'], name, value)


                class Network(Entity):
                    """
                    Enable routing on an IP network
                    
                    .. attribute:: ip  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.Network, self).__init__()

                        self.yang_name = "network"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['ip']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                        ])
                        self.ip = None
                        self._segment_path = lambda: "network" + "[ip='" + str(self.ip) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.Network, ['ip'], name, value)


                class DefaultInformation(Entity):
                    """
                    Control distribution of default information
                    
                    .. attribute:: originate
                    
                    	Distribute a default route
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.DefaultInformation, self).__init__()

                        self.yang_name = "default-information"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('originate', (YLeaf(YType.empty, 'originate'), ['Empty'])),
                        ])
                        self.originate = None
                        self._segment_path = lambda: "default-information"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.DefaultInformation, ['originate'], name, value)


                class Distance(Entity):
                    """
                    Define an administrative distance
                    
                    .. attribute:: distance_leaf
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..255
                    
                    .. attribute:: distance_list
                    
                    	
                    	**type**\: list of  		 :py:class:`DistanceList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Distance.DistanceList>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.Distance, self).__init__()

                        self.yang_name = "distance"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("distance-list", ("distance_list", Native.Router.Rip.Default.Distance.DistanceList))])
                        self._leafs = OrderedDict([
                            ('distance_leaf', (YLeaf(YType.uint8, 'distance-leaf'), ['int'])),
                        ])
                        self.distance_leaf = None

                        self.distance_list = YList(self)
                        self._segment_path = lambda: "distance"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.Distance, ['distance_leaf'], name, value)


                    class DistanceList(Entity):
                        """
                        
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..255
                        
                        .. attribute:: ip  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: access_list
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..99
                        
                        		**type**\: int
                        
                        			**range:** 1300..1999
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Distance.DistanceList, self).__init__()

                            self.yang_name = "distance-list"
                            self.yang_parent_name = "distance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['number','ip','mask']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('access_list', (YLeaf(YType.str, 'access-list'), ['int','int'])),
                            ])
                            self.number = None
                            self.ip = None
                            self.mask = None
                            self.access_list = None
                            self._segment_path = lambda: "distance-list" + "[number='" + str(self.number) + "']" + "[ip='" + str(self.ip) + "']" + "[mask='" + str(self.mask) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/distance/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Distance.DistanceList, ['number', 'ip', 'mask', 'access_list'], name, value)


                class DistributeList(Entity):
                    """
                    Filter networks in routing updates
                    
                    .. attribute:: accesslist
                    
                    	
                    	**type**\: list of  		 :py:class:`Accesslist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.DistributeList.Accesslist>`
                    
                    .. attribute:: accesslist_ifname
                    
                    	
                    	**type**\: list of  		 :py:class:`AccesslistIfname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.DistributeList.AccesslistIfname>`
                    
                    .. attribute:: accesslist_prefix_gateway
                    
                    	
                    	**type**\: list of  		 :py:class:`AccesslistPrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.DistributeList.AccesslistPrefixGateway>`
                    
                    .. attribute:: accesslist_prefix_gateway_ifname
                    
                    	
                    	**type**\: list of  		 :py:class:`AccesslistPrefixGatewayIfname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.DistributeList.AccesslistPrefixGatewayIfname>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.DistributeList, self).__init__()

                        self.yang_name = "distribute-list"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("accesslist", ("accesslist", Native.Router.Rip.Default.DistributeList.Accesslist)), ("accesslist-ifname", ("accesslist_ifname", Native.Router.Rip.Default.DistributeList.AccesslistIfname)), ("accesslist-prefix-gateway", ("accesslist_prefix_gateway", Native.Router.Rip.Default.DistributeList.AccesslistPrefixGateway)), ("accesslist-prefix-gateway-ifname", ("accesslist_prefix_gateway_ifname", Native.Router.Rip.Default.DistributeList.AccesslistPrefixGatewayIfname))])
                        self._leafs = OrderedDict()

                        self.accesslist = YList(self)
                        self.accesslist_ifname = YList(self)
                        self.accesslist_prefix_gateway = YList(self)
                        self.accesslist_prefix_gateway_ifname = YList(self)
                        self._segment_path = lambda: "distribute-list"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.DistributeList, [], name, value)


                    class Accesslist(Entity):
                        """
                        
                        
                        .. attribute:: in_out  (key)
                        
                        	
                        	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199
                        
                        		**type**\: int
                        
                        			**range:** 1300..2699
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.DistributeList.Accesslist, self).__init__()

                            self.yang_name = "accesslist"
                            self.yang_parent_name = "distribute-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['in_out']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                ('id', (YLeaf(YType.str, 'id'), ['int','int'])),
                            ])
                            self.in_out = None
                            self.id = None
                            self._segment_path = lambda: "accesslist" + "[in-out='" + str(self.in_out) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/distribute-list/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.DistributeList.Accesslist, ['in_out', 'id'], name, value)


                    class AccesslistIfname(Entity):
                        """
                        
                        
                        .. attribute:: in_out  (key)
                        
                        	
                        	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                        
                        .. attribute:: interface  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: interface_routing_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: isis_tag
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: vrf
                        
                        	VPN Routing/Forwarding Instance
                        	**type**\: str
                        
                        .. attribute:: id
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..199
                        
                        		**type**\: int
                        
                        			**range:** 1300..2699
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.DistributeList.AccesslistIfname, self).__init__()

                            self.yang_name = "accesslist-ifname"
                            self.yang_parent_name = "distribute-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['in_out','interface']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ('interface_routing_id', (YLeaf(YType.uint8, 'interface-routing-id'), ['int'])),
                                ('isis_tag', (YLeaf(YType.str, 'isis-tag'), ['str'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                ('id', (YLeaf(YType.str, 'id'), ['int','int'])),
                            ])
                            self.in_out = None
                            self.interface = None
                            self.interface_routing_id = None
                            self.isis_tag = None
                            self.vrf = None
                            self.id = None
                            self._segment_path = lambda: "accesslist-ifname" + "[in-out='" + str(self.in_out) + "']" + "[interface='" + str(self.interface) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/distribute-list/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.DistributeList.AccesslistIfname, ['in_out', 'interface', 'interface_routing_id', 'isis_tag', 'vrf', 'id'], name, value)


                    class AccesslistPrefixGateway(Entity):
                        """
                        
                        
                        .. attribute:: in_out  (key)
                        
                        	
                        	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                        
                        .. attribute:: prefix_gateway
                        
                        	
                        	**type**\:  :py:class:`PrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.DistributeList.AccesslistPrefixGateway.PrefixGateway>`
                        
                        	**mandatory**\: True
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        	**mandatory**\: True
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.DistributeList.AccesslistPrefixGateway, self).__init__()

                            self.yang_name = "accesslist-prefix-gateway"
                            self.yang_parent_name = "distribute-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['in_out']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                ('prefix_gateway', (YLeaf(YType.enumeration, 'prefix-gateway'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.Default.DistributeList.AccesslistPrefixGateway.PrefixGateway')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.in_out = None
                            self.prefix_gateway = None
                            self.name = None
                            self._segment_path = lambda: "accesslist-prefix-gateway" + "[in-out='" + str(self.in_out) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/distribute-list/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.DistributeList.AccesslistPrefixGateway, ['in_out', 'prefix_gateway', 'name'], name, value)

                        class PrefixGateway(Enum):
                            """
                            PrefixGateway (Enum Class)

                            .. data:: prefix = 0

                            .. data:: gateway = 1

                            .. data:: route_map = 2

                            """

                            prefix = Enum.YLeaf(0, "prefix")

                            gateway = Enum.YLeaf(1, "gateway")

                            route_map = Enum.YLeaf(2, "route-map")



                    class AccesslistPrefixGatewayIfname(Entity):
                        """
                        
                        
                        .. attribute:: in_out  (key)
                        
                        	
                        	**type**\:  :py:class:`AccessListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.AccessListInOutType>`
                        
                        .. attribute:: interface  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: prefix_gateway
                        
                        	
                        	**type**\:  :py:class:`PrefixGateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.DistributeList.AccesslistPrefixGatewayIfname.PrefixGateway>`
                        
                        	**mandatory**\: True
                        
                        .. attribute:: name
                        
                        	
                        	**type**\: str
                        
                        	**mandatory**\: True
                        
                        .. attribute:: interface_routing_id
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: isis_tag
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: vrf
                        
                        	VPN Routing/Forwarding Instance
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.DistributeList.AccesslistPrefixGatewayIfname, self).__init__()

                            self.yang_name = "accesslist-prefix-gateway-ifname"
                            self.yang_parent_name = "distribute-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['in_out','interface']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'AccessListInOutType', '')])),
                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ('prefix_gateway', (YLeaf(YType.enumeration, 'prefix-gateway'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.Default.DistributeList.AccesslistPrefixGatewayIfname.PrefixGateway')])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('interface_routing_id', (YLeaf(YType.uint8, 'interface-routing-id'), ['int'])),
                                ('isis_tag', (YLeaf(YType.str, 'isis-tag'), ['str'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.in_out = None
                            self.interface = None
                            self.prefix_gateway = None
                            self.name = None
                            self.interface_routing_id = None
                            self.isis_tag = None
                            self.vrf = None
                            self._segment_path = lambda: "accesslist-prefix-gateway-ifname" + "[in-out='" + str(self.in_out) + "']" + "[interface='" + str(self.interface) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/distribute-list/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.DistributeList.AccesslistPrefixGatewayIfname, ['in_out', 'interface', 'prefix_gateway', 'name', 'interface_routing_id', 'isis_tag', 'vrf'], name, value)

                        class PrefixGateway(Enum):
                            """
                            PrefixGateway (Enum Class)

                            .. data:: prefix = 0

                            .. data:: gateway = 1

                            .. data:: route_map = 2

                            """

                            prefix = Enum.YLeaf(0, "prefix")

                            gateway = Enum.YLeaf(1, "gateway")

                            route_map = Enum.YLeaf(2, "route-map")



                class OffsetList(Entity):
                    """
                    Add or subtract offset from RIP metrics
                    
                    .. attribute:: in_out  (key)
                    
                    	
                    	**type**\:  :py:class:`OffsetListInOutType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_rip.OffsetListInOutType>`
                    
                    .. attribute:: offset
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..16
                    
                    	**mandatory**\: True
                    
                    .. attribute:: id
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.OffsetList, self).__init__()

                        self.yang_name = "offset-list"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['in_out']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('in_out', (YLeaf(YType.enumeration, 'in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_rip', 'OffsetListInOutType', '')])),
                            ('offset', (YLeaf(YType.uint8, 'offset'), ['int'])),
                            ('id', (YLeaf(YType.str, 'id'), ['int','int'])),
                        ])
                        self.in_out = None
                        self.offset = None
                        self.id = None
                        self._segment_path = lambda: "offset-list" + "[in-out='" + str(self.in_out) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.OffsetList, ['in_out', 'offset', 'id'], name, value)


                class PassiveInterface(Entity):
                    """
                    Suppress routing updates on an interface
                    
                    .. attribute:: default
                    
                    	Suppress routing updates on all interfaces
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: interface
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.PassiveInterface, self).__init__()

                        self.yang_name = "passive-interface"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ])
                        self.default = None
                        self.interface = None
                        self._segment_path = lambda: "passive-interface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.PassiveInterface, [u'default', u'interface'], name, value)


                class Disable(Entity):
                    """
                    
                    
                    .. attribute:: passive_interface
                    
                    	
                    	**type**\: list of  		 :py:class:`PassiveInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Disable.PassiveInterface>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.Disable, self).__init__()

                        self.yang_name = "disable"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("passive-interface", ("passive_interface", Native.Router.Rip.Default.Disable.PassiveInterface))])
                        self._leafs = OrderedDict()

                        self.passive_interface = YList(self)
                        self._segment_path = lambda: "disable"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.Disable, [], name, value)


                    class PassiveInterface(Entity):
                        """
                        
                        
                        .. attribute:: interface  (key)
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Disable.PassiveInterface, self).__init__()

                            self.yang_name = "passive-interface"
                            self.yang_parent_name = "disable"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['interface']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ])
                            self.interface = None
                            self._segment_path = lambda: "passive-interface" + "[interface='" + str(self.interface) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/disable/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Disable.PassiveInterface, [u'interface'], name, value)


                class Redistribute(Entity):
                    """
                    Redistribute information from another routing protocol
                    
                    .. attribute:: connected
                    
                    	Connected
                    	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Connected>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bgp
                    
                    	Border Gateway Protocol (BGP)
                    	**type**\: list of  		 :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Bgp>`
                    
                    .. attribute:: eigrp
                    
                    	Enhanced Interior Gateway Routing Protocol (EIGRP)
                    	**type**\: list of  		 :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Eigrp>`
                    
                    .. attribute:: isis
                    
                    	ISO IS\-IS
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Isis>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: iso_igrp
                    
                    	IGRP for OSI networks
                    	**type**\:  :py:class:`IsoIgrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.IsoIgrp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: mobile
                    
                    	Mobile routes
                    	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Mobile>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: odr
                    
                    	On Demand stub Routes
                    	**type**\:  :py:class:`Odr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Odr>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ospf
                    
                    	Open Shortest Path First (OSPF)
                    	**type**\: list of  		 :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf>`
                    
                    .. attribute:: static
                    
                    	Static routes
                    	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Static>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: rip
                    
                    	Routing Information Protocol (RIP)
                    	**type**\:  :py:class:`Rip_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Rip_>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.Redistribute, self).__init__()

                        self.yang_name = "redistribute"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("connected", ("connected", Native.Router.Rip.Default.Redistribute.Connected)), ("bgp", ("bgp", Native.Router.Rip.Default.Redistribute.Bgp)), ("eigrp", ("eigrp", Native.Router.Rip.Default.Redistribute.Eigrp)), ("isis", ("isis", Native.Router.Rip.Default.Redistribute.Isis)), ("iso-igrp", ("iso_igrp", Native.Router.Rip.Default.Redistribute.IsoIgrp)), ("mobile", ("mobile", Native.Router.Rip.Default.Redistribute.Mobile)), ("odr", ("odr", Native.Router.Rip.Default.Redistribute.Odr)), ("ospf", ("ospf", Native.Router.Rip.Default.Redistribute.Ospf)), ("static", ("static", Native.Router.Rip.Default.Redistribute.Static)), ("rip", ("rip", Native.Router.Rip.Default.Redistribute.Rip_))])
                        self._leafs = OrderedDict()

                        self.connected = None
                        self._children_name_map["connected"] = "connected"

                        self.isis = None
                        self._children_name_map["isis"] = "isis"

                        self.iso_igrp = None
                        self._children_name_map["iso_igrp"] = "iso-igrp"

                        self.mobile = None
                        self._children_name_map["mobile"] = "mobile"

                        self.odr = None
                        self._children_name_map["odr"] = "odr"

                        self.static = None
                        self._children_name_map["static"] = "static"

                        self.rip = None
                        self._children_name_map["rip"] = "rip"

                        self.bgp = YList(self)
                        self.eigrp = YList(self)
                        self.ospf = YList(self)
                        self._segment_path = lambda: "redistribute"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.Redistribute, [], name, value)


                    class Connected(Entity):
                        """
                        Connected
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Connected.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Redistribute.Connected, self).__init__()

                            self.yang_name = "connected"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Connected.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Connected.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "connected"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Connected, [], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Connected.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Connected.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "connected"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Connected.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Router.Rip.Default.Redistribute.Connected.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/connected/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Connected.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Connected.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/connected/rip-metric-route-map/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Connected.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Bgp(Entity):
                        """
                        Border Gateway Protocol (BGP)
                        
                        .. attribute:: as_number  (key)
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4294967295
                        
                        		**type**\: str
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Bgp.RipMetricRouteMap>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Redistribute.Bgp, self).__init__()

                            self.yang_name = "bgp"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['as_number']
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Bgp.RipMetricRouteMap))])
                            self._leafs = OrderedDict([
                                ('as_number', (YLeaf(YType.str, 'as-number'), ['int','str'])),
                            ])
                            self.as_number = None

                            self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Bgp.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "bgp" + "[as-number='" + str(self.as_number) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Bgp, ['as_number'], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Bgp.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Bgp.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "bgp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Bgp.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Router.Rip.Default.Redistribute.Bgp.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Bgp.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Bgp.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Bgp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Eigrp(Entity):
                        """
                        Enhanced Interior Gateway Routing Protocol (EIGRP)
                        
                        .. attribute:: as_number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Eigrp.RipMetricRouteMap>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Redistribute.Eigrp, self).__init__()

                            self.yang_name = "eigrp"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['as_number']
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Eigrp.RipMetricRouteMap))])
                            self._leafs = OrderedDict([
                                ('as_number', (YLeaf(YType.uint16, 'as-number'), ['int'])),
                            ])
                            self.as_number = None

                            self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Eigrp.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "eigrp" + "[as-number='" + str(self.as_number) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Eigrp, ['as_number'], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Eigrp.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Eigrp.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "eigrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Eigrp.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Router.Rip.Default.Redistribute.Eigrp.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Eigrp.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Eigrp.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Eigrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Isis(Entity):
                        """
                        ISO IS\-IS
                        
                        .. attribute:: isis_area
                        
                        	
                        	**type**\: list of  		 :py:class:`IsisArea <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Isis.IsisArea>`
                        
                        .. attribute:: rip_isis_redist
                        
                        	
                        	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Redistribute.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("isis-area", ("isis_area", Native.Router.Rip.Default.Redistribute.Isis.IsisArea)), ("rip-isis-redist", ("rip_isis_redist", Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_isis_redist = Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist()
                            self.rip_isis_redist.parent = self
                            self._children_name_map["rip_isis_redist"] = "rip-isis-redist"

                            self.isis_area = YList(self)
                            self._segment_path = lambda: "isis"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Isis, [], name, value)


                        class IsisArea(Entity):
                            """
                            
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: rip_isis_redist
                            
                            	
                            	**type**\:  :py:class:`RipIsisRedist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Isis.IsisArea, self).__init__()

                                self.yang_name = "isis-area"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("rip-isis-redist", ("rip_isis_redist", Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.rip_isis_redist = Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist()
                                self.rip_isis_redist.parent = self
                                self._children_name_map["rip_isis_redist"] = "rip-isis-redist"
                                self._segment_path = lambda: "isis-area" + "[name='" + str(self.name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/isis/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Isis.IsisArea, ['name'], name, value)


                            class RipIsisRedist(Entity):
                                """
                                
                                
                                .. attribute:: isis_level_routes
                                
                                	
                                	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes>`
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist, self).__init__()

                                    self.yang_name = "rip-isis-redist"
                                    self.yang_parent_name = "isis-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap))])
                                    self._leafs = OrderedDict([
                                        ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.IsisLevelRoutes')])),
                                    ])
                                    self.isis_level_routes = None

                                    self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "rip-isis-redist"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist, ['isis_level_routes'], name, value)

                                class IsisLevelRoutes(Enum):
                                    """
                                    IsisLevelRoutes (Enum Class)

                                    .. data:: level_1 = 0

                                    .. data:: level_2 = 1

                                    .. data:: level_1_2 = 2

                                    """

                                    level_1 = Enum.YLeaf(0, "level-1")

                                    level_2 = Enum.YLeaf(1, "level-2")

                                    level_1_2 = Enum.YLeaf(2, "level-1-2")



                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "rip-isis-redist"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Isis.IsisArea.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                        class RipIsisRedist(Entity):
                            """
                            
                            
                            .. attribute:: isis_level_routes
                            
                            	
                            	**type**\:  :py:class:`IsisLevelRoutes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes>`
                            
                            .. attribute:: rip_metric_route_map
                            
                            	
                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist, self).__init__()

                                self.yang_name = "rip-isis-redist"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap))])
                                self._leafs = OrderedDict([
                                    ('isis_level_routes', (YLeaf(YType.enumeration, 'isis-level-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Router.Rip.Default.Redistribute.Isis.RipIsisRedist.IsisLevelRoutes')])),
                                ])
                                self.isis_level_routes = None

                                self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap()
                                self.rip_metric_route_map.parent = self
                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                self._segment_path = lambda: "rip-isis-redist"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/isis/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist, ['isis_level_routes'], name, value)

                            class IsisLevelRoutes(Enum):
                                """
                                IsisLevelRoutes (Enum Class)

                                .. data:: level_1 = 0

                                .. data:: level_2 = 1

                                .. data:: level_1_2 = 2

                                """

                                level_1 = Enum.YLeaf(0, "level-1")

                                level_2 = Enum.YLeaf(1, "level-2")

                                level_1_2 = Enum.YLeaf(2, "level-1-2")



                            class RipMetricRouteMap(Entity):
                                """
                                
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric>`
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, self).__init__()

                                    self.yang_name = "rip-metric-route-map"
                                    self.yang_parent_name = "rip-isis-redist"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric))])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.metric = Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "rip-metric-route-map"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/isis/rip-isis-redist/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap, ['route_map'], name, value)


                                class Metric(Entity):
                                    """
                                    Metric for redistributed routes
                                    
                                    .. attribute:: metric_value
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..16
                                    
                                    .. attribute:: transparent
                                    
                                    	Transparently redistribute metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "rip-metric-route-map"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                        ])
                                        self.metric_value = None
                                        self.transparent = None
                                        self._segment_path = lambda: "metric"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/isis/rip-isis-redist/rip-metric-route-map/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.Default.Redistribute.Isis.RipIsisRedist.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class IsoIgrp(Entity):
                        """
                        IGRP for OSI networks
                        
                        .. attribute:: isoigrp_list
                        
                        	Border Gateway Protocol (BGP)
                        	**type**\: list of  		 :py:class:`IsoigrpList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList>`
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.IsoIgrp.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Redistribute.IsoIgrp, self).__init__()

                            self.yang_name = "iso-igrp"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("isoigrp-list", ("isoigrp_list", Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.IsoIgrp.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.IsoIgrp.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                            self.isoigrp_list = YList(self)
                            self._segment_path = lambda: "iso-igrp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.IsoIgrp, [], name, value)


                        class IsoigrpList(Entity):
                            """
                            Border Gateway Protocol (BGP)
                            
                            .. attribute:: iso_area_tag  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: rip_metric_route_map
                            
                            	
                            	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList, self).__init__()

                                self.yang_name = "isoigrp-list"
                                self.yang_parent_name = "iso-igrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['iso_area_tag']
                                self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap))])
                                self._leafs = OrderedDict([
                                    ('iso_area_tag', (YLeaf(YType.str, 'iso-area-tag'), ['str'])),
                                ])
                                self.iso_area_tag = None

                                self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap()
                                self.rip_metric_route_map.parent = self
                                self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                self._segment_path = lambda: "isoigrp-list" + "[iso-area-tag='" + str(self.iso_area_tag) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/iso-igrp/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList, ['iso_area_tag'], name, value)


                            class RipMetricRouteMap(Entity):
                                """
                                
                                
                                .. attribute:: route_map
                                
                                	Route map reference
                                	**type**\: str
                                
                                .. attribute:: metric
                                
                                	Metric for redistributed routes
                                	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, self).__init__()

                                    self.yang_name = "rip-metric-route-map"
                                    self.yang_parent_name = "isoigrp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric))])
                                    self._leafs = OrderedDict([
                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                    ])
                                    self.route_map = None

                                    self.metric = Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric()
                                    self.metric.parent = self
                                    self._children_name_map["metric"] = "metric"
                                    self._segment_path = lambda: "rip-metric-route-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap, ['route_map'], name, value)


                                class Metric(Entity):
                                    """
                                    Metric for redistributed routes
                                    
                                    .. attribute:: metric_value
                                    
                                    	Metric for redistributed routes
                                    	**type**\: int
                                    
                                    	**range:** 0..16
                                    
                                    .. attribute:: transparent
                                    
                                    	Transparently redistribute metric
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, self).__init__()

                                        self.yang_name = "metric"
                                        self.yang_parent_name = "rip-metric-route-map"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                            ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                        ])
                                        self.metric_value = None
                                        self.transparent = None
                                        self._segment_path = lambda: "metric"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.Default.Redistribute.IsoIgrp.IsoigrpList.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.IsoIgrp.RipMetricRouteMap.Metric>`
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.IsoIgrp.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "iso-igrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.IsoIgrp.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Router.Rip.Default.Redistribute.IsoIgrp.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/iso-igrp/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.IsoIgrp.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/iso-igrp/rip-metric-route-map/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.IsoIgrp.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Mobile(Entity):
                        """
                        Mobile routes
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Mobile.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Redistribute.Mobile, self).__init__()

                            self.yang_name = "mobile"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Mobile.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Mobile.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "mobile"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Mobile, [], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Mobile.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Mobile.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "mobile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Mobile.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Router.Rip.Default.Redistribute.Mobile.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/mobile/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Mobile.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Mobile.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/mobile/rip-metric-route-map/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Mobile.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Odr(Entity):
                        """
                        On Demand stub Routes
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Odr.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Redistribute.Odr, self).__init__()

                            self.yang_name = "odr"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Odr.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Odr.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "odr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Odr, [], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Odr.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Odr.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "odr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Odr.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Router.Rip.Default.Redistribute.Odr.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/odr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Odr.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Odr.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/odr/rip-metric-route-map/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Odr.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Ospf(Entity):
                        """
                        Open Shortest Path First (OSPF)
                        
                        .. attribute:: process_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: vrf
                        
                        	VPN Routing/Forwarding Instance
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.Vrf>`
                        
                        .. attribute:: match
                        
                        	Redistribution of OSPF routes
                        	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.Match>`
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.RipMetricRouteMap>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Redistribute.Ospf, self).__init__()

                            self.yang_name = "ospf"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['process_id']
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Router.Rip.Default.Redistribute.Ospf.Vrf)), ("match", ("match", Native.Router.Rip.Default.Redistribute.Ospf.Match)), ("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Ospf.RipMetricRouteMap))])
                            self._leafs = OrderedDict([
                                ('process_id', (YLeaf(YType.uint16, 'process-id'), ['int'])),
                            ])
                            self.process_id = None

                            self.match = Native.Router.Rip.Default.Redistribute.Ospf.Match()
                            self.match.parent = self
                            self._children_name_map["match"] = "match"

                            self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Ospf.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"

                            self.vrf = YList(self)
                            self._segment_path = lambda: "ospf" + "[process-id='" + str(self.process_id) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf, ['process_id'], name, value)


                        class Vrf(Entity):
                            """
                            VPN Routing/Forwarding Instance
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Ospf.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.Vrf, ['name'], name, value)


                        class Match(Entity):
                            """
                            Redistribution of OSPF routes
                            
                            .. attribute:: internal
                            
                            	Redistribute OSPF internal routes
                            	**type**\:  :py:class:`Internal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: external
                            
                            	Redistribute OSPF external routes
                            	**type**\:  :py:class:`External <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.Match.External>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: nssa_external
                            
                            	Redistribute OSPF NSSA external routes
                            	**type**\:  :py:class:`NssaExternal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Ospf.Match, self).__init__()

                                self.yang_name = "match"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("internal", ("internal", Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal)), ("external", ("external", Native.Router.Rip.Default.Redistribute.Ospf.Match.External)), ("nssa-external", ("nssa_external", Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal))])
                                self._leafs = OrderedDict()

                                self.internal = None
                                self._children_name_map["internal"] = "internal"

                                self.external = None
                                self._children_name_map["external"] = "external"

                                self.nssa_external = None
                                self._children_name_map["nssa_external"] = "nssa-external"
                                self._segment_path = lambda: "match"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.Match, [], name, value)


                            class Internal(Entity):
                                """
                                Redistribute OSPF internal routes
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal, self).__init__()

                                    self.yang_name = "internal"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "internal"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal, [], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "internal"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.Match.Internal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class External(Entity):
                                """
                                Redistribute OSPF external routes
                                
                                .. attribute:: external_routes
                                
                                	
                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.Match.External.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Ospf.Match.External, self).__init__()

                                    self.yang_name = "external"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Ospf.Match.External.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('external_routes', (YLeaf(YType.enumeration, 'external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                    ])
                                    self.external_routes = None

                                    self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Ospf.Match.External.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "external"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.Match.External, ['external_routes'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.Default.Redistribute.Ospf.Match.External.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "external"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.Default.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.Match.External.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.Default.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.Match.External.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                            class NssaExternal(Entity):
                                """
                                Redistribute OSPF NSSA external routes
                                
                                .. attribute:: nssa_external_routes
                                
                                	
                                	**type**\:  :py:class:`RedistOspfExternalType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.RedistOspfExternalType>`
                                
                                .. attribute:: rip_metric_route_map
                                
                                	
                                	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal, self).__init__()

                                    self.yang_name = "nssa-external"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('nssa_external_routes', (YLeaf(YType.enumeration, 'nssa-external-routes'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'RedistOspfExternalType', '')])),
                                    ])
                                    self.nssa_external_routes = None

                                    self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap()
                                    self.rip_metric_route_map.parent = self
                                    self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                                    self._segment_path = lambda: "nssa-external"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal, ['nssa_external_routes'], name, value)


                                class RipMetricRouteMap(Entity):
                                    """
                                    
                                    
                                    .. attribute:: metric
                                    
                                    	Metric for redistributed routes
                                    	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric>`
                                    
                                    .. attribute:: route_map
                                    
                                    	Route map reference
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-rip'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, self).__init__()

                                        self.yang_name = "rip-metric-route-map"
                                        self.yang_parent_name = "nssa-external"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric))])
                                        self._leafs = OrderedDict([
                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                        ])
                                        self.route_map = None

                                        self.metric = Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric()
                                        self.metric.parent = self
                                        self._children_name_map["metric"] = "metric"
                                        self._segment_path = lambda: "rip-metric-route-map"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap, ['route_map'], name, value)


                                    class Metric(Entity):
                                        """
                                        Metric for redistributed routes
                                        
                                        .. attribute:: metric_value
                                        
                                        	Metric for redistributed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..16
                                        
                                        .. attribute:: transparent
                                        
                                        	Transparently redistribute metric
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-rip'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, self).__init__()

                                            self.yang_name = "metric"
                                            self.yang_parent_name = "rip-metric-route-map"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                                ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                            ])
                                            self.metric_value = None
                                            self.transparent = None
                                            self._segment_path = lambda: "metric"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.Match.NssaExternal.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Ospf.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Ospf.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Ospf.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Router.Rip.Default.Redistribute.Ospf.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Ospf.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Ospf.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Static(Entity):
                        """
                        Static routes
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Static.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Redistribute.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Static.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Static.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "static"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Static, [], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Static.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Static.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Static.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Router.Rip.Default.Redistribute.Static.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/static/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Static.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Static.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/static/rip-metric-route-map/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Static.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                    class Rip_(Entity):
                        """
                        Routing Information Protocol (RIP)
                        
                        .. attribute:: rip_metric_route_map
                        
                        	
                        	**type**\:  :py:class:`RipMetricRouteMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Rip_.RipMetricRouteMap>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.Redistribute.Rip_, self).__init__()

                            self.yang_name = "rip"
                            self.yang_parent_name = "redistribute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rip-metric-route-map", ("rip_metric_route_map", Native.Router.Rip.Default.Redistribute.Rip_.RipMetricRouteMap))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rip_metric_route_map = Native.Router.Rip.Default.Redistribute.Rip_.RipMetricRouteMap()
                            self.rip_metric_route_map.parent = self
                            self._children_name_map["rip_metric_route_map"] = "rip-metric-route-map"
                            self._segment_path = lambda: "rip"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.Redistribute.Rip_, [], name, value)


                        class RipMetricRouteMap(Entity):
                            """
                            
                            
                            .. attribute:: metric
                            
                            	Metric for redistributed routes
                            	**type**\:  :py:class:`Metric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.Redistribute.Rip_.RipMetricRouteMap.Metric>`
                            
                            .. attribute:: route_map
                            
                            	Route map reference
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-rip'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.Router.Rip.Default.Redistribute.Rip_.RipMetricRouteMap, self).__init__()

                                self.yang_name = "rip-metric-route-map"
                                self.yang_parent_name = "rip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("metric", ("metric", Native.Router.Rip.Default.Redistribute.Rip_.RipMetricRouteMap.Metric))])
                                self._leafs = OrderedDict([
                                    ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                ])
                                self.route_map = None

                                self.metric = Native.Router.Rip.Default.Redistribute.Rip_.RipMetricRouteMap.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                                self._segment_path = lambda: "rip-metric-route-map"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/rip/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Router.Rip.Default.Redistribute.Rip_.RipMetricRouteMap, ['route_map'], name, value)


                            class Metric(Entity):
                                """
                                Metric for redistributed routes
                                
                                .. attribute:: metric_value
                                
                                	Metric for redistributed routes
                                	**type**\: int
                                
                                	**range:** 0..16
                                
                                .. attribute:: transparent
                                
                                	Transparently redistribute metric
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-rip'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.Router.Rip.Default.Redistribute.Rip_.RipMetricRouteMap.Metric, self).__init__()

                                    self.yang_name = "metric"
                                    self.yang_parent_name = "rip-metric-route-map"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('metric_value', (YLeaf(YType.uint32, 'metric-value'), ['int'])),
                                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                                    ])
                                    self.metric_value = None
                                    self.transparent = None
                                    self._segment_path = lambda: "metric"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/redistribute/rip/rip-metric-route-map/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Router.Rip.Default.Redistribute.Rip_.RipMetricRouteMap.Metric, ['metric_value', 'transparent'], name, value)


                class Timers(Entity):
                    """
                    Adjust routing timers
                    
                    .. attribute:: basic
                    
                    	Basic routing protocol update timers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.Timers, self).__init__()

                        self.yang_name = "timers"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('basic', (YLeaf(YType.empty, 'basic'), ['Empty'])),
                        ])
                        self.basic = None
                        self._segment_path = lambda: "timers"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.Timers, ['basic'], name, value)


                class TrafficShare(Entity):
                    """
                    How to compute traffic share over alternate paths
                    
                    .. attribute:: min
                    
                    	All traffic shared among min metric paths
                    	**type**\:  :py:class:`Min <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Router.Rip.Default.TrafficShare.Min>`
                    
                    

                    """

                    _prefix = 'ios-rip'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Router.Rip.Default.TrafficShare, self).__init__()

                        self.yang_name = "traffic-share"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("min", ("min", Native.Router.Rip.Default.TrafficShare.Min))])
                        self._leafs = OrderedDict()

                        self.min = Native.Router.Rip.Default.TrafficShare.Min()
                        self.min.parent = self
                        self._children_name_map["min"] = "min"
                        self._segment_path = lambda: "traffic-share"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Router.Rip.Default.TrafficShare, [], name, value)


                    class Min(Entity):
                        """
                        All traffic shared among min metric paths
                        
                        .. attribute:: across_interfaces
                        
                        	Use different interfaces for equal\-cost paths
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-rip'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.Router.Rip.Default.TrafficShare.Min, self).__init__()

                            self.yang_name = "min"
                            self.yang_parent_name = "traffic-share"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('across_interfaces', (YLeaf(YType.empty, 'across-interfaces'), ['Empty'])),
                            ])
                            self.across_interfaces = None
                            self._segment_path = lambda: "min"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-rip:rip/default/traffic-share/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Router.Rip.Default.TrafficShare.Min, ['across_interfaces'], name, value)


    class ServiceChain(Entity):
        """
        Service Chain mode
        
        .. attribute:: service_function
        
        	Service function details
        	**type**\: list of  		 :py:class:`ServiceFunction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServiceFunction>`
        
        .. attribute:: service_function_forwarder
        
        	Service function forwarder details
        	**type**\:  :py:class:`ServiceFunctionForwarder <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServiceFunctionForwarder>`
        
        .. attribute:: service_path
        
        	Service Path Entries
        	**type**\: list of  		 :py:class:`ServicePath <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServicePath>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.ServiceChain, self).__init__()

            self.yang_name = "service-chain"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-service-chain:service-function", ("service_function", Native.ServiceChain.ServiceFunction)), ("Cisco-IOS-XE-service-chain:service-function-forwarder", ("service_function_forwarder", Native.ServiceChain.ServiceFunctionForwarder)), ("Cisco-IOS-XE-service-chain:service-path", ("service_path", Native.ServiceChain.ServicePath))])
            self._leafs = OrderedDict()

            self.service_function_forwarder = Native.ServiceChain.ServiceFunctionForwarder()
            self.service_function_forwarder.parent = self
            self._children_name_map["service_function_forwarder"] = "Cisco-IOS-XE-service-chain:service-function-forwarder"

            self.service_function = YList(self)
            self.service_path = YList(self)
            self._segment_path = lambda: "service-chain"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.ServiceChain, [], name, value)


        class ServiceFunction(Entity):
            """
            Service function details
            
            .. attribute:: name  (key)
            
            	WORD;;Service function name
            	**type**\: str
            
            .. attribute:: config_service_chain_sf_mode
            
            	
            	**type**\:  :py:class:`ConfigServiceChainSfMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode>`
            
            

            """

            _prefix = 'ios-service-chain'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.ServiceChain.ServiceFunction, self).__init__()

                self.yang_name = "service-function"
                self.yang_parent_name = "service-chain"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("config-service-chain-sf-mode", ("config_service_chain_sf_mode", Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.config_service_chain_sf_mode = Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode()
                self.config_service_chain_sf_mode.parent = self
                self._children_name_map["config_service_chain_sf_mode"] = "config-service-chain-sf-mode"
                self._segment_path = lambda: "Cisco-IOS-XE-service-chain:service-function" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service-chain/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceChain.ServiceFunction, ['name'], name, value)


            class ConfigServiceChainSfMode(Entity):
                """
                
                
                .. attribute:: description
                
                	Service function description
                	**type**\: str
                
                	**length:** 1..256
                
                .. attribute:: encapsulation
                
                	Service node encapsulation
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Encapsulation>`
                
                .. attribute:: ip
                
                	Service node
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Ip>`
                
                

                """

                _prefix = 'ios-service-chain'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode, self).__init__()

                    self.yang_name = "config-service-chain-sf-mode"
                    self.yang_parent_name = "service-function"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Encapsulation)), ("ip", ("ip", Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Ip))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.encapsulation = Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"

                    self.ip = Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "config-service-chain-sf-mode"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode, ['description'], name, value)


                class Encapsulation(Entity):
                    """
                    Service node encapsulation
                    
                    .. attribute:: gre
                    
                    	Service node encapsulation type
                    	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Encapsulation.Gre>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: none
                    
                    	Service node encapsulation type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-service-chain'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Encapsulation, self).__init__()

                        self.yang_name = "encapsulation"
                        self.yang_parent_name = "config-service-chain-sf-mode"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre", ("gre", Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Encapsulation.Gre))])
                        self._leafs = OrderedDict([
                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ])
                        self.none = None

                        self.gre = None
                        self._children_name_map["gre"] = "gre"
                        self._segment_path = lambda: "encapsulation"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Encapsulation, ['none'], name, value)


                    class Gre(Entity):
                        """
                        Service node encapsulation type
                        
                        .. attribute:: enhanced
                        
                        	Add enhanced NSH TLV information
                        	**type**\:  :py:class:`Enhanced <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Encapsulation.Gre.Enhanced>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-service-chain'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Encapsulation.Gre, self).__init__()

                            self.yang_name = "gre"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('enhanced', (YLeaf(YType.enumeration, 'enhanced'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Encapsulation.Gre.Enhanced')])),
                            ])
                            self.enhanced = None
                            self._segment_path = lambda: "gre"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Encapsulation.Gre, ['enhanced'], name, value)

                        class Enhanced(Enum):
                            """
                            Enhanced (Enum Class)

                            Add enhanced NSH TLV information

                            .. data:: copy = 0

                            .. data:: divert = 1

                            """

                            copy = Enum.YLeaf(0, "copy")

                            divert = Enum.YLeaf(1, "divert")



                class Ip(Entity):
                    """
                    Service node
                    
                    .. attribute:: address
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-service-chain'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "config-service-chain-sf-mode"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ServiceChain.ServiceFunction.ConfigServiceChainSfMode.Ip, ['address'], name, value)


        class ServiceFunctionForwarder(Entity):
            """
            Service function forwarder details
            
            .. attribute:: service_ff_name
            
            	
            	**type**\: list of  		 :py:class:`ServiceFfName <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServiceFunctionForwarder.ServiceFfName>`
            
            .. attribute:: local
            
            	Local service function forwarder
            	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServiceFunctionForwarder.Local>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios-service-chain'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.ServiceChain.ServiceFunctionForwarder, self).__init__()

                self.yang_name = "service-function-forwarder"
                self.yang_parent_name = "service-chain"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-ff-name", ("service_ff_name", Native.ServiceChain.ServiceFunctionForwarder.ServiceFfName)), ("local", ("local", Native.ServiceChain.ServiceFunctionForwarder.Local))])
                self._leafs = OrderedDict()

                self.local = None
                self._children_name_map["local"] = "local"

                self.service_ff_name = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-service-chain:service-function-forwarder"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service-chain/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceChain.ServiceFunctionForwarder, [], name, value)


            class ServiceFfName(Entity):
                """
                
                
                .. attribute:: name  (key)
                
                	WORD;;Service function forwarder name
                	**type**\: str
                
                .. attribute:: description
                
                	Service function forwarder description
                	**type**\: str
                
                	**length:** 1..256
                
                .. attribute:: ip
                
                	IP address for Service Function Forwarder
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServiceFunctionForwarder.ServiceFfName.Ip>`
                
                

                """

                _prefix = 'ios-service-chain'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.ServiceChain.ServiceFunctionForwarder.ServiceFfName, self).__init__()

                    self.yang_name = "service-ff-name"
                    self.yang_parent_name = "service-function-forwarder"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("ip", ("ip", Native.ServiceChain.ServiceFunctionForwarder.ServiceFfName.Ip))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.name = None
                    self.description = None

                    self.ip = Native.ServiceChain.ServiceFunctionForwarder.ServiceFfName.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "service-ff-name" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service-chain/Cisco-IOS-XE-service-chain:service-function-forwarder/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ServiceChain.ServiceFunctionForwarder.ServiceFfName, ['name', 'description'], name, value)


                class Ip(Entity):
                    """
                    IP address for Service Function Forwarder
                    
                    .. attribute:: address
                    
                    	Set IPv4 address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-service-chain'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.ServiceChain.ServiceFunctionForwarder.ServiceFfName.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "service-ff-name"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ServiceChain.ServiceFunctionForwarder.ServiceFfName.Ip, ['address'], name, value)


            class Local(Entity):
                """
                Local service function forwarder
                
                .. attribute:: description
                
                	Service function forwarder description
                	**type**\: str
                
                	**length:** 1..256
                
                .. attribute:: ip
                
                	IP address for Service Function Forwarder
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServiceFunctionForwarder.Local.Ip>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-service-chain'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.ServiceChain.ServiceFunctionForwarder.Local, self).__init__()

                    self.yang_name = "local"
                    self.yang_parent_name = "service-function-forwarder"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.ServiceChain.ServiceFunctionForwarder.Local.Ip))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.ip = Native.ServiceChain.ServiceFunctionForwarder.Local.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "local"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service-chain/Cisco-IOS-XE-service-chain:service-function-forwarder/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ServiceChain.ServiceFunctionForwarder.Local, ['description'], name, value)


                class Ip(Entity):
                    """
                    IP address for Service Function Forwarder
                    
                    .. attribute:: address
                    
                    	Set IPv4 address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-service-chain'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.ServiceChain.ServiceFunctionForwarder.Local.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "local"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ])
                        self.address = None
                        self._segment_path = lambda: "ip"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service-chain/Cisco-IOS-XE-service-chain:service-function-forwarder/local/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ServiceChain.ServiceFunctionForwarder.Local.Ip, ['address'], name, value)


        class ServicePath(Entity):
            """
            Service Path Entries
            
            .. attribute:: service_path_id  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..16777215
            
            .. attribute:: config_service_chain_path_mode
            
            	
            	**type**\:  :py:class:`ConfigServiceChainPathMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServicePath.ConfigServiceChainPathMode>`
            
            

            """

            _prefix = 'ios-service-chain'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.ServiceChain.ServicePath, self).__init__()

                self.yang_name = "service-path"
                self.yang_parent_name = "service-chain"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['service_path_id']
                self._child_classes = OrderedDict([("config-service-chain-path-mode", ("config_service_chain_path_mode", Native.ServiceChain.ServicePath.ConfigServiceChainPathMode))])
                self._leafs = OrderedDict([
                    ('service_path_id', (YLeaf(YType.uint32, 'service-path-id'), ['int'])),
                ])
                self.service_path_id = None

                self.config_service_chain_path_mode = Native.ServiceChain.ServicePath.ConfigServiceChainPathMode()
                self.config_service_chain_path_mode.parent = self
                self._children_name_map["config_service_chain_path_mode"] = "config-service-chain-path-mode"
                self._segment_path = lambda: "Cisco-IOS-XE-service-chain:service-path" + "[service-path-id='" + str(self.service_path_id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service-chain/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceChain.ServicePath, ['service_path_id'], name, value)


            class ConfigServiceChainPathMode(Entity):
                """
                
                
                .. attribute:: description
                
                	Path Description
                	**type**\: str
                
                	**length:** 1..256
                
                .. attribute:: service_index
                
                	Service Index
                	**type**\:  :py:class:`ServiceIndex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServicePath.ConfigServiceChainPathMode.ServiceIndex>`
                
                

                """

                _prefix = 'ios-service-chain'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.ServiceChain.ServicePath.ConfigServiceChainPathMode, self).__init__()

                    self.yang_name = "config-service-chain-path-mode"
                    self.yang_parent_name = "service-path"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("service-index", ("service_index", Native.ServiceChain.ServicePath.ConfigServiceChainPathMode.ServiceIndex))])
                    self._leafs = OrderedDict([
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.description = None

                    self.service_index = Native.ServiceChain.ServicePath.ConfigServiceChainPathMode.ServiceIndex()
                    self.service_index.parent = self
                    self._children_name_map["service_index"] = "service-index"
                    self._segment_path = lambda: "config-service-chain-path-mode"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ServiceChain.ServicePath.ConfigServiceChainPathMode, ['description'], name, value)


                class ServiceIndex(Entity):
                    """
                    Service Index
                    
                    .. attribute:: services
                    
                    	
                    	**type**\: list of  		 :py:class:`Services <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceChain.ServicePath.ConfigServiceChainPathMode.ServiceIndex.Services>`
                    
                    

                    """

                    _prefix = 'ios-service-chain'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.ServiceChain.ServicePath.ConfigServiceChainPathMode.ServiceIndex, self).__init__()

                        self.yang_name = "service-index"
                        self.yang_parent_name = "config-service-chain-path-mode"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("services", ("services", Native.ServiceChain.ServicePath.ConfigServiceChainPathMode.ServiceIndex.Services))])
                        self._leafs = OrderedDict()

                        self.services = YList(self)
                        self._segment_path = lambda: "service-index"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ServiceChain.ServicePath.ConfigServiceChainPathMode.ServiceIndex, [], name, value)


                    class Services(Entity):
                        """
                        
                        
                        .. attribute:: service_index_id  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 2..255
                        
                        .. attribute:: service_function
                        
                        	Service Function name
                        	**type**\: str
                        
                        .. attribute:: service_function_forwarder
                        
                        	Service Function Forwarder name
                        	**type**\: str
                        
                        .. attribute:: terminate
                        
                        	Terminate(Proxy)
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-service-chain'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.ServiceChain.ServicePath.ConfigServiceChainPathMode.ServiceIndex.Services, self).__init__()

                            self.yang_name = "services"
                            self.yang_parent_name = "service-index"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['service_index_id']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('service_index_id', (YLeaf(YType.uint8, 'service-index-id'), ['int'])),
                                ('service_function', (YLeaf(YType.str, 'service-function'), ['str'])),
                                ('service_function_forwarder', (YLeaf(YType.str, 'service-function-forwarder'), ['str'])),
                                ('terminate', (YLeaf(YType.empty, 'terminate'), ['Empty'])),
                            ])
                            self.service_index_id = None
                            self.service_function = None
                            self.service_function_forwarder = None
                            self.terminate = None
                            self._segment_path = lambda: "services" + "[service-index-id='" + str(self.service_index_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ServiceChain.ServicePath.ConfigServiceChainPathMode.ServiceIndex.Services, ['service_index_id', 'service_function', 'service_function_forwarder', 'terminate'], name, value)


    class Performance(Entity):
        """
        Global Performance monitor configuration
        
        .. attribute:: monitor
        
        	monitor
        	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Performance, self).__init__()

            self.yang_name = "performance"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-ezpm:monitor", ("monitor", Native.Performance.Monitor))])
            self._leafs = OrderedDict()

            self.monitor = Native.Performance.Monitor()
            self.monitor.parent = self
            self._children_name_map["monitor"] = "Cisco-IOS-XE-ezpm:monitor"
            self._segment_path = lambda: "performance"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Performance, [], name, value)


        class Monitor(Entity):
            """
            monitor
            
            .. attribute:: context
            
            	Define ezPM context
            	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context>`
            
            .. attribute:: observation_point
            
            	Select observation point
            	**type**\:  :py:class:`ObservationPoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.ObservationPoint>`
            
            

            """

            _prefix = 'ios-ezpm'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Performance.Monitor, self).__init__()

                self.yang_name = "monitor"
                self.yang_parent_name = "performance"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("context", ("context", Native.Performance.Monitor.Context)), ("observation-point", ("observation_point", Native.Performance.Monitor.ObservationPoint))])
                self._leafs = OrderedDict()

                self.observation_point = Native.Performance.Monitor.ObservationPoint()
                self.observation_point.parent = self
                self._children_name_map["observation_point"] = "observation-point"

                self.context = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-ezpm:monitor"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/performance/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Performance.Monitor, [], name, value)


            class Context(Entity):
                """
                Define ezPM context
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: profile
                
                	Select ezPM profile
                	**type**\:  :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Profile>`
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default>`
                
                .. attribute:: description
                
                	Provide a description for ezPM context
                	**type**\: str
                
                .. attribute:: exporter
                
                	Create exporter
                	**type**\:  :py:class:`Exporter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Exporter>`
                
                .. attribute:: traffic_monitor
                
                	Select traffic monitor
                	**type**\:  :py:class:`TrafficMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Performance.Monitor.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("default", ("default", Native.Performance.Monitor.Context.Default)), ("exporter", ("exporter", Native.Performance.Monitor.Context.Exporter)), ("traffic-monitor", ("traffic_monitor", Native.Performance.Monitor.Context.TrafficMonitor))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('profile', (YLeaf(YType.enumeration, 'profile'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Performance.Monitor.Context.Profile')])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.name = None
                    self.profile = None
                    self.description = None

                    self.default = Native.Performance.Monitor.Context.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.exporter = Native.Performance.Monitor.Context.Exporter()
                    self.exporter.parent = self
                    self._children_name_map["exporter"] = "exporter"

                    self.traffic_monitor = Native.Performance.Monitor.Context.TrafficMonitor()
                    self.traffic_monitor.parent = self
                    self._children_name_map["traffic_monitor"] = "traffic-monitor"
                    self._segment_path = lambda: "context" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/performance/Cisco-IOS-XE-ezpm:monitor/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Performance.Monitor.Context, ['name', 'profile', 'description'], name, value)

                class Profile(Enum):
                    """
                    Profile (Enum Class)

                    Select ezPM profile

                    .. data:: application_experience = 0

                    .. data:: application_performance = 1

                    .. data:: application_statistics = 2

                    """

                    application_experience = Enum.YLeaf(0, "application-experience")

                    application_performance = Enum.YLeaf(1, "application-performance")

                    application_statistics = Enum.YLeaf(2, "application-statistics")



                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: description
                    
                    	Provide a description for ezPM context
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: exporter
                    
                    	Create exporter
                    	**type**\:  :py:class:`Exporter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.Exporter>`
                    
                    .. attribute:: traffic_monitor
                    
                    	Select traffic monitor
                    	**type**\:  :py:class:`TrafficMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor>`
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Performance.Monitor.Context.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("exporter", ("exporter", Native.Performance.Monitor.Context.Default.Exporter)), ("traffic-monitor", ("traffic_monitor", Native.Performance.Monitor.Context.Default.TrafficMonitor))])
                        self._leafs = OrderedDict([
                            ('description', (YLeaf(YType.empty, 'description'), ['Empty'])),
                        ])
                        self.description = None

                        self.exporter = Native.Performance.Monitor.Context.Default.Exporter()
                        self.exporter.parent = self
                        self._children_name_map["exporter"] = "exporter"

                        self.traffic_monitor = Native.Performance.Monitor.Context.Default.TrafficMonitor()
                        self.traffic_monitor.parent = self
                        self._children_name_map["traffic_monitor"] = "traffic-monitor"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Performance.Monitor.Context.Default, ['description'], name, value)


                    class Exporter(Entity):
                        """
                        Create exporter
                        
                        .. attribute:: destination
                        
                        	Export destination configuration
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	Originating interface
                        	**type**\: str
                        
                        .. attribute:: port
                        
                        	port
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transport
                        
                        	transport
                        	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.Exporter.Transport>`
                        
                        .. attribute:: vrf
                        
                        	vrf
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-ezpm'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Performance.Monitor.Context.Default.Exporter, self).__init__()

                            self.yang_name = "exporter"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('destination', (YLeaf(YType.str, 'destination'), ['str','str'])),
                                ('source', (YLeaf(YType.str, 'source'), ['str'])),
                                ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                ('transport', (YLeaf(YType.enumeration, 'transport'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Performance.Monitor.Context.Default.Exporter.Transport')])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.destination = None
                            self.source = None
                            self.port = None
                            self.transport = None
                            self.vrf = None
                            self._segment_path = lambda: "exporter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Performance.Monitor.Context.Default.Exporter, ['destination', 'source', 'port', 'transport', 'vrf'], name, value)

                        class Transport(Enum):
                            """
                            Transport (Enum Class)

                            transport

                            .. data:: udp = 0

                            """

                            udp = Enum.YLeaf(0, "udp")



                    class TrafficMonitor(Entity):
                        """
                        Select traffic monitor
                        
                        .. attribute:: all
                        
                        	All traffic monitors in this profile
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor.All>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: application_response_time
                        
                        	Application response time (ART) metrics and counters for TCP traffic
                        	**type**\:  :py:class:`ApplicationResponseTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationResponseTime>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: application_traffic_stats
                        
                        	Application level counters for dns and dht protocol
                        	**type**\:  :py:class:`ApplicationTrafficStats <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationTrafficStats>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: conversation_traffic_stats
                        
                        	Conversation level counters for IP traffic
                        	**type**\:  :py:class:`ConversationTrafficStats <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor.ConversationTrafficStats>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: media
                        
                        	Media metrics and counters for rtp and telepresence\-media traffic
                        	**type**\:  :py:class:`Media <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor.Media>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: url
                        
                        	URL information, application response time (ART) metrics and counters
                        	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor.Url>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: application_client_server_stats
                        
                        	Per interface, client, server and application statistics
                        	**type**\:  :py:class:`ApplicationClientServerStats <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationClientServerStats>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: application_stats
                        
                        	Per application and interface statistics
                        	**type**\:  :py:class:`ApplicationStats <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationStats>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-ezpm'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Performance.Monitor.Context.Default.TrafficMonitor, self).__init__()

                            self.yang_name = "traffic-monitor"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("all", ("all", Native.Performance.Monitor.Context.Default.TrafficMonitor.All)), ("application-response-time", ("application_response_time", Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationResponseTime)), ("application-traffic-stats", ("application_traffic_stats", Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationTrafficStats)), ("conversation-traffic-stats", ("conversation_traffic_stats", Native.Performance.Monitor.Context.Default.TrafficMonitor.ConversationTrafficStats)), ("media", ("media", Native.Performance.Monitor.Context.Default.TrafficMonitor.Media)), ("url", ("url", Native.Performance.Monitor.Context.Default.TrafficMonitor.Url)), ("application-client-server-stats", ("application_client_server_stats", Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationClientServerStats)), ("application-stats", ("application_stats", Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationStats))])
                            self._leafs = OrderedDict()

                            self.all = None
                            self._children_name_map["all"] = "all"

                            self.application_response_time = None
                            self._children_name_map["application_response_time"] = "application-response-time"

                            self.application_traffic_stats = None
                            self._children_name_map["application_traffic_stats"] = "application-traffic-stats"

                            self.conversation_traffic_stats = None
                            self._children_name_map["conversation_traffic_stats"] = "conversation-traffic-stats"

                            self.media = None
                            self._children_name_map["media"] = "media"

                            self.url = None
                            self._children_name_map["url"] = "url"

                            self.application_client_server_stats = None
                            self._children_name_map["application_client_server_stats"] = "application-client-server-stats"

                            self.application_stats = None
                            self._children_name_map["application_stats"] = "application-stats"
                            self._segment_path = lambda: "traffic-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Performance.Monitor.Context.Default.TrafficMonitor, [], name, value)


                        class All(Entity):
                            """
                            All traffic monitors in this profile
                            
                            .. attribute:: ipv4
                            
                            	Activate monitor for ipv4 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipv6
                            
                            	Activate monitor for ipv6 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ezpm'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Performance.Monitor.Context.Default.TrafficMonitor.All, self).__init__()

                                self.yang_name = "all"
                                self.yang_parent_name = "traffic-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                                ])
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "all"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Performance.Monitor.Context.Default.TrafficMonitor.All, ['ipv4', 'ipv6'], name, value)


                        class ApplicationResponseTime(Entity):
                            """
                            Application response time (ART) metrics and counters for TCP traffic
                            
                            .. attribute:: cache_size
                            
                            	Maximum flow entries in the Flow Cache
                            	**type**\: int
                            
                            	**range:** 64..2000000
                            
                            .. attribute:: class_replace
                            
                            	Replace traffic classification
                            	**type**\: str
                            
                            .. attribute:: interval_timeout
                            
                            	The exporting interval timeout
                            	**type**\: int
                            
                            	**range:** 1..604800
                            
                            .. attribute:: cache_type
                            
                            	The type of the Flow Cache
                            	**type**\:  :py:class:`CacheType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationResponseTime.CacheType>`
                            
                            .. attribute:: class_and
                            
                            	Narrow down default traffic classification
                            	**type**\: str
                            
                            .. attribute:: ipv4
                            
                            	Activate monitor for ipv4 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipv6
                            
                            	Activate monitor for ipv6 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ezpm'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationResponseTime, self).__init__()

                                self.yang_name = "application-response-time"
                                self.yang_parent_name = "traffic-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                    ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                    ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                                    ('cache_type', (YLeaf(YType.enumeration, 'cache-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Performance.Monitor.Context.Default.TrafficMonitor.ApplicationResponseTime.CacheType')])),
                                    ('class_and', (YLeaf(YType.str, 'class-and'), ['str'])),
                                    ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                                ])
                                self.cache_size = None
                                self.class_replace = None
                                self.interval_timeout = None
                                self.cache_type = None
                                self.class_and = None
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "application-response-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationResponseTime, ['cache_size', 'class_replace', 'interval_timeout', 'cache_type', 'class_and', 'ipv4', 'ipv6'], name, value)

                            class CacheType(Enum):
                                """
                                CacheType (Enum Class)

                                The type of the Flow Cache

                                .. data:: normal = 0

                                .. data:: synchronized = 1

                                """

                                normal = Enum.YLeaf(0, "normal")

                                synchronized = Enum.YLeaf(1, "synchronized")



                        class ApplicationTrafficStats(Entity):
                            """
                            Application level counters for dns and dht protocol
                            
                            .. attribute:: cache_size
                            
                            	Maximum flow entries in the Flow Cache
                            	**type**\: int
                            
                            	**range:** 64..2000000
                            
                            .. attribute:: class_replace
                            
                            	Replace traffic classification
                            	**type**\: str
                            
                            .. attribute:: interval_timeout
                            
                            	The exporting interval timeout
                            	**type**\: int
                            
                            	**range:** 1..604800
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ezpm'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationTrafficStats, self).__init__()

                                self.yang_name = "application-traffic-stats"
                                self.yang_parent_name = "traffic-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                    ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                    ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                                ])
                                self.cache_size = None
                                self.class_replace = None
                                self.interval_timeout = None
                                self._segment_path = lambda: "application-traffic-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationTrafficStats, ['cache_size', 'class_replace', 'interval_timeout'], name, value)


                        class ConversationTrafficStats(Entity):
                            """
                            Conversation level counters for IP traffic
                            
                            .. attribute:: cache_size
                            
                            	Maximum flow entries in the Flow Cache
                            	**type**\: int
                            
                            	**range:** 64..2000000
                            
                            .. attribute:: class_replace
                            
                            	Replace traffic classification
                            	**type**\: str
                            
                            .. attribute:: interval_timeout
                            
                            	The exporting interval timeout
                            	**type**\: int
                            
                            	**range:** 1..604800
                            
                            .. attribute:: cache_type
                            
                            	The type of the Flow Cache
                            	**type**\:  :py:class:`CacheType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor.ConversationTrafficStats.CacheType>`
                            
                            .. attribute:: ipv4
                            
                            	Activate monitor for ipv4 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipv6
                            
                            	Activate monitor for ipv6 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ezpm'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Performance.Monitor.Context.Default.TrafficMonitor.ConversationTrafficStats, self).__init__()

                                self.yang_name = "conversation-traffic-stats"
                                self.yang_parent_name = "traffic-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                    ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                    ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                                    ('cache_type', (YLeaf(YType.enumeration, 'cache-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Performance.Monitor.Context.Default.TrafficMonitor.ConversationTrafficStats.CacheType')])),
                                    ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                                ])
                                self.cache_size = None
                                self.class_replace = None
                                self.interval_timeout = None
                                self.cache_type = None
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "conversation-traffic-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Performance.Monitor.Context.Default.TrafficMonitor.ConversationTrafficStats, ['cache_size', 'class_replace', 'interval_timeout', 'cache_type', 'ipv4', 'ipv6'], name, value)

                            class CacheType(Enum):
                                """
                                CacheType (Enum Class)

                                The type of the Flow Cache

                                .. data:: normal = 0

                                .. data:: synchronized = 1

                                """

                                normal = Enum.YLeaf(0, "normal")

                                synchronized = Enum.YLeaf(1, "synchronized")



                        class Media(Entity):
                            """
                            Media metrics and counters for rtp and telepresence\-media traffic
                            
                            .. attribute:: cache_size
                            
                            	Maximum flow entries in the Flow Cache
                            	**type**\: int
                            
                            	**range:** 64..2000000
                            
                            .. attribute:: class_replace
                            
                            	Replace traffic classification
                            	**type**\: str
                            
                            .. attribute:: interval_timeout
                            
                            	The exporting interval timeout
                            	**type**\: int
                            
                            	**range:** 1..604800
                            
                            .. attribute:: class_and
                            
                            	Narrow down default traffic classification
                            	**type**\: str
                            
                            .. attribute:: egress
                            
                            	Activate monitor on egress direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ingress
                            
                            	Activate monitor on ingress direction
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipv4
                            
                            	Activate monitor for ipv4 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipv6
                            
                            	Activate monitor for ipv6 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ezpm'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Performance.Monitor.Context.Default.TrafficMonitor.Media, self).__init__()

                                self.yang_name = "media"
                                self.yang_parent_name = "traffic-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                    ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                    ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                                    ('class_and', (YLeaf(YType.str, 'class-and'), ['str'])),
                                    ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                                    ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                                    ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                                ])
                                self.cache_size = None
                                self.class_replace = None
                                self.interval_timeout = None
                                self.class_and = None
                                self.egress = None
                                self.ingress = None
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "media"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Performance.Monitor.Context.Default.TrafficMonitor.Media, ['cache_size', 'class_replace', 'interval_timeout', 'class_and', 'egress', 'ingress', 'ipv4', 'ipv6'], name, value)


                        class Url(Entity):
                            """
                            URL information, application response time (ART) metrics and counters
                            
                            .. attribute:: cache_size
                            
                            	Maximum flow entries in the Flow Cache
                            	**type**\: int
                            
                            	**range:** 64..2000000
                            
                            .. attribute:: class_and
                            
                            	Narrow down default traffic classification
                            	**type**\: str
                            
                            .. attribute:: class_replace
                            
                            	Replace traffic classification
                            	**type**\: str
                            
                            .. attribute:: ipv4
                            
                            	Activate monitor for ipv4 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipv6
                            
                            	Activate monitor for ipv6 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: sampling_rate
                            
                            	Sampling rate of flow sampler
                            	**type**\: int
                            
                            	**range:** 1..32768
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ezpm'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Performance.Monitor.Context.Default.TrafficMonitor.Url, self).__init__()

                                self.yang_name = "url"
                                self.yang_parent_name = "traffic-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                    ('class_and', (YLeaf(YType.str, 'class-and'), ['str'])),
                                    ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                    ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                                    ('sampling_rate', (YLeaf(YType.uint32, 'sampling-rate'), ['int'])),
                                ])
                                self.cache_size = None
                                self.class_and = None
                                self.class_replace = None
                                self.ipv4 = None
                                self.ipv6 = None
                                self.sampling_rate = None
                                self._segment_path = lambda: "url"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Performance.Monitor.Context.Default.TrafficMonitor.Url, ['cache_size', 'class_and', 'class_replace', 'ipv4', 'ipv6', 'sampling_rate'], name, value)


                        class ApplicationClientServerStats(Entity):
                            """
                            Per interface, client, server and application statistics
                            
                            .. attribute:: cache_size
                            
                            	Maximum flow entries in the Flow Cache
                            	**type**\: int
                            
                            	**range:** 64..2000000
                            
                            .. attribute:: class_replace
                            
                            	Replace traffic classification
                            	**type**\: str
                            
                            .. attribute:: interval_timeout
                            
                            	The exporting interval timeout
                            	**type**\: int
                            
                            	**range:** 1..604800
                            
                            .. attribute:: cache_type
                            
                            	The type of the Flow Cache
                            	**type**\:  :py:class:`CacheType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationClientServerStats.CacheType>`
                            
                            .. attribute:: ipv4
                            
                            	Activate monitor for ipv4 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ipv6
                            
                            	Activate monitor for ipv6 traffic
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ezpm'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationClientServerStats, self).__init__()

                                self.yang_name = "application-client-server-stats"
                                self.yang_parent_name = "traffic-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                    ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                    ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                                    ('cache_type', (YLeaf(YType.enumeration, 'cache-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Performance.Monitor.Context.Default.TrafficMonitor.ApplicationClientServerStats.CacheType')])),
                                    ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                    ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                                ])
                                self.cache_size = None
                                self.class_replace = None
                                self.interval_timeout = None
                                self.cache_type = None
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "application-client-server-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationClientServerStats, ['cache_size', 'class_replace', 'interval_timeout', 'cache_type', 'ipv4', 'ipv6'], name, value)

                            class CacheType(Enum):
                                """
                                CacheType (Enum Class)

                                The type of the Flow Cache

                                .. data:: normal = 0

                                .. data:: synchronized = 1

                                """

                                normal = Enum.YLeaf(0, "normal")

                                synchronized = Enum.YLeaf(1, "synchronized")



                        class ApplicationStats(Entity):
                            """
                            Per application and interface statistics
                            
                            .. attribute:: cache_size
                            
                            	Maximum flow entries in the Flow Cache
                            	**type**\: int
                            
                            	**range:** 64..2000000
                            
                            .. attribute:: class_replace
                            
                            	Replace traffic classification
                            	**type**\: str
                            
                            .. attribute:: interval_timeout
                            
                            	The exporting interval timeout
                            	**type**\: int
                            
                            	**range:** 1..604800
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-ezpm'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationStats, self).__init__()

                                self.yang_name = "application-stats"
                                self.yang_parent_name = "traffic-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                    ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                    ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                                ])
                                self.cache_size = None
                                self.class_replace = None
                                self.interval_timeout = None
                                self._segment_path = lambda: "application-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Performance.Monitor.Context.Default.TrafficMonitor.ApplicationStats, ['cache_size', 'class_replace', 'interval_timeout'], name, value)


                class Exporter(Entity):
                    """
                    Create exporter
                    
                    .. attribute:: destination
                    
                    	Export destination configuration
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source
                    
                    	Originating interface
                    	**type**\: str
                    
                    .. attribute:: port
                    
                    	port
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transport
                    
                    	transport
                    	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.Exporter.Transport>`
                    
                    .. attribute:: vrf
                    
                    	vrf
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Performance.Monitor.Context.Exporter, self).__init__()

                        self.yang_name = "exporter"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('destination', (YLeaf(YType.str, 'destination'), ['str','str'])),
                            ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                            ('transport', (YLeaf(YType.enumeration, 'transport'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Performance.Monitor.Context.Exporter.Transport')])),
                            ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                        ])
                        self.destination = None
                        self.source = None
                        self.port = None
                        self.transport = None
                        self.vrf = None
                        self._segment_path = lambda: "exporter"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Performance.Monitor.Context.Exporter, ['destination', 'source', 'port', 'transport', 'vrf'], name, value)

                    class Transport(Enum):
                        """
                        Transport (Enum Class)

                        transport

                        .. data:: udp = 0

                        """

                        udp = Enum.YLeaf(0, "udp")



                class TrafficMonitor(Entity):
                    """
                    Select traffic monitor
                    
                    .. attribute:: all
                    
                    	All traffic monitors in this profile
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor.All>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: application_response_time
                    
                    	Application response time (ART) metrics and counters for TCP traffic
                    	**type**\:  :py:class:`ApplicationResponseTime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor.ApplicationResponseTime>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: application_traffic_stats
                    
                    	Application level counters for dns and dht protocol
                    	**type**\:  :py:class:`ApplicationTrafficStats <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor.ApplicationTrafficStats>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: conversation_traffic_stats
                    
                    	Conversation level counters for IP traffic
                    	**type**\:  :py:class:`ConversationTrafficStats <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor.ConversationTrafficStats>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: media
                    
                    	Media metrics and counters for rtp and telepresence\-media traffic
                    	**type**\:  :py:class:`Media <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor.Media>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: url
                    
                    	URL information, application response time (ART) metrics and counters
                    	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor.Url>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: application_client_server_stats
                    
                    	Per interface, client, server and application statistics
                    	**type**\:  :py:class:`ApplicationClientServerStats <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor.ApplicationClientServerStats>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: application_stats
                    
                    	Per application and interface statistics
                    	**type**\:  :py:class:`ApplicationStats <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor.ApplicationStats>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-ezpm'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.Performance.Monitor.Context.TrafficMonitor, self).__init__()

                        self.yang_name = "traffic-monitor"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("all", ("all", Native.Performance.Monitor.Context.TrafficMonitor.All)), ("application-response-time", ("application_response_time", Native.Performance.Monitor.Context.TrafficMonitor.ApplicationResponseTime)), ("application-traffic-stats", ("application_traffic_stats", Native.Performance.Monitor.Context.TrafficMonitor.ApplicationTrafficStats)), ("conversation-traffic-stats", ("conversation_traffic_stats", Native.Performance.Monitor.Context.TrafficMonitor.ConversationTrafficStats)), ("media", ("media", Native.Performance.Monitor.Context.TrafficMonitor.Media)), ("url", ("url", Native.Performance.Monitor.Context.TrafficMonitor.Url)), ("application-client-server-stats", ("application_client_server_stats", Native.Performance.Monitor.Context.TrafficMonitor.ApplicationClientServerStats)), ("application-stats", ("application_stats", Native.Performance.Monitor.Context.TrafficMonitor.ApplicationStats))])
                        self._leafs = OrderedDict()

                        self.all = None
                        self._children_name_map["all"] = "all"

                        self.application_response_time = None
                        self._children_name_map["application_response_time"] = "application-response-time"

                        self.application_traffic_stats = None
                        self._children_name_map["application_traffic_stats"] = "application-traffic-stats"

                        self.conversation_traffic_stats = None
                        self._children_name_map["conversation_traffic_stats"] = "conversation-traffic-stats"

                        self.media = None
                        self._children_name_map["media"] = "media"

                        self.url = None
                        self._children_name_map["url"] = "url"

                        self.application_client_server_stats = None
                        self._children_name_map["application_client_server_stats"] = "application-client-server-stats"

                        self.application_stats = None
                        self._children_name_map["application_stats"] = "application-stats"
                        self._segment_path = lambda: "traffic-monitor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Performance.Monitor.Context.TrafficMonitor, [], name, value)


                    class All(Entity):
                        """
                        All traffic monitors in this profile
                        
                        .. attribute:: ipv4
                        
                        	Activate monitor for ipv4 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6
                        
                        	Activate monitor for ipv6 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ezpm'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Performance.Monitor.Context.TrafficMonitor.All, self).__init__()

                            self.yang_name = "all"
                            self.yang_parent_name = "traffic-monitor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                            ])
                            self.ipv4 = None
                            self.ipv6 = None
                            self._segment_path = lambda: "all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Performance.Monitor.Context.TrafficMonitor.All, ['ipv4', 'ipv6'], name, value)


                    class ApplicationResponseTime(Entity):
                        """
                        Application response time (ART) metrics and counters for TCP traffic
                        
                        .. attribute:: cache_size
                        
                        	Maximum flow entries in the Flow Cache
                        	**type**\: int
                        
                        	**range:** 64..2000000
                        
                        .. attribute:: class_replace
                        
                        	Replace traffic classification
                        	**type**\: str
                        
                        .. attribute:: interval_timeout
                        
                        	The exporting interval timeout
                        	**type**\: int
                        
                        	**range:** 1..604800
                        
                        .. attribute:: cache_type
                        
                        	The type of the Flow Cache
                        	**type**\:  :py:class:`CacheType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor.ApplicationResponseTime.CacheType>`
                        
                        .. attribute:: class_and
                        
                        	Narrow down default traffic classification
                        	**type**\: str
                        
                        .. attribute:: ipv4
                        
                        	Activate monitor for ipv4 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6
                        
                        	Activate monitor for ipv6 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ezpm'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Performance.Monitor.Context.TrafficMonitor.ApplicationResponseTime, self).__init__()

                            self.yang_name = "application-response-time"
                            self.yang_parent_name = "traffic-monitor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                                ('cache_type', (YLeaf(YType.enumeration, 'cache-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Performance.Monitor.Context.TrafficMonitor.ApplicationResponseTime.CacheType')])),
                                ('class_and', (YLeaf(YType.str, 'class-and'), ['str'])),
                                ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                            ])
                            self.cache_size = None
                            self.class_replace = None
                            self.interval_timeout = None
                            self.cache_type = None
                            self.class_and = None
                            self.ipv4 = None
                            self.ipv6 = None
                            self._segment_path = lambda: "application-response-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Performance.Monitor.Context.TrafficMonitor.ApplicationResponseTime, ['cache_size', 'class_replace', 'interval_timeout', 'cache_type', 'class_and', 'ipv4', 'ipv6'], name, value)

                        class CacheType(Enum):
                            """
                            CacheType (Enum Class)

                            The type of the Flow Cache

                            .. data:: normal = 0

                            .. data:: synchronized = 1

                            """

                            normal = Enum.YLeaf(0, "normal")

                            synchronized = Enum.YLeaf(1, "synchronized")



                    class ApplicationTrafficStats(Entity):
                        """
                        Application level counters for dns and dht protocol
                        
                        .. attribute:: cache_size
                        
                        	Maximum flow entries in the Flow Cache
                        	**type**\: int
                        
                        	**range:** 64..2000000
                        
                        .. attribute:: class_replace
                        
                        	Replace traffic classification
                        	**type**\: str
                        
                        .. attribute:: interval_timeout
                        
                        	The exporting interval timeout
                        	**type**\: int
                        
                        	**range:** 1..604800
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ezpm'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Performance.Monitor.Context.TrafficMonitor.ApplicationTrafficStats, self).__init__()

                            self.yang_name = "application-traffic-stats"
                            self.yang_parent_name = "traffic-monitor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                            ])
                            self.cache_size = None
                            self.class_replace = None
                            self.interval_timeout = None
                            self._segment_path = lambda: "application-traffic-stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Performance.Monitor.Context.TrafficMonitor.ApplicationTrafficStats, ['cache_size', 'class_replace', 'interval_timeout'], name, value)


                    class ConversationTrafficStats(Entity):
                        """
                        Conversation level counters for IP traffic
                        
                        .. attribute:: cache_size
                        
                        	Maximum flow entries in the Flow Cache
                        	**type**\: int
                        
                        	**range:** 64..2000000
                        
                        .. attribute:: class_replace
                        
                        	Replace traffic classification
                        	**type**\: str
                        
                        .. attribute:: interval_timeout
                        
                        	The exporting interval timeout
                        	**type**\: int
                        
                        	**range:** 1..604800
                        
                        .. attribute:: cache_type
                        
                        	The type of the Flow Cache
                        	**type**\:  :py:class:`CacheType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor.ConversationTrafficStats.CacheType>`
                        
                        .. attribute:: ipv4
                        
                        	Activate monitor for ipv4 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6
                        
                        	Activate monitor for ipv6 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ezpm'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Performance.Monitor.Context.TrafficMonitor.ConversationTrafficStats, self).__init__()

                            self.yang_name = "conversation-traffic-stats"
                            self.yang_parent_name = "traffic-monitor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                                ('cache_type', (YLeaf(YType.enumeration, 'cache-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Performance.Monitor.Context.TrafficMonitor.ConversationTrafficStats.CacheType')])),
                                ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                            ])
                            self.cache_size = None
                            self.class_replace = None
                            self.interval_timeout = None
                            self.cache_type = None
                            self.ipv4 = None
                            self.ipv6 = None
                            self._segment_path = lambda: "conversation-traffic-stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Performance.Monitor.Context.TrafficMonitor.ConversationTrafficStats, ['cache_size', 'class_replace', 'interval_timeout', 'cache_type', 'ipv4', 'ipv6'], name, value)

                        class CacheType(Enum):
                            """
                            CacheType (Enum Class)

                            The type of the Flow Cache

                            .. data:: normal = 0

                            .. data:: synchronized = 1

                            """

                            normal = Enum.YLeaf(0, "normal")

                            synchronized = Enum.YLeaf(1, "synchronized")



                    class Media(Entity):
                        """
                        Media metrics and counters for rtp and telepresence\-media traffic
                        
                        .. attribute:: cache_size
                        
                        	Maximum flow entries in the Flow Cache
                        	**type**\: int
                        
                        	**range:** 64..2000000
                        
                        .. attribute:: class_replace
                        
                        	Replace traffic classification
                        	**type**\: str
                        
                        .. attribute:: interval_timeout
                        
                        	The exporting interval timeout
                        	**type**\: int
                        
                        	**range:** 1..604800
                        
                        .. attribute:: class_and
                        
                        	Narrow down default traffic classification
                        	**type**\: str
                        
                        .. attribute:: egress
                        
                        	Activate monitor on egress direction
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ingress
                        
                        	Activate monitor on ingress direction
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv4
                        
                        	Activate monitor for ipv4 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6
                        
                        	Activate monitor for ipv6 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ezpm'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Performance.Monitor.Context.TrafficMonitor.Media, self).__init__()

                            self.yang_name = "media"
                            self.yang_parent_name = "traffic-monitor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                                ('class_and', (YLeaf(YType.str, 'class-and'), ['str'])),
                                ('egress', (YLeaf(YType.empty, 'egress'), ['Empty'])),
                                ('ingress', (YLeaf(YType.empty, 'ingress'), ['Empty'])),
                                ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                            ])
                            self.cache_size = None
                            self.class_replace = None
                            self.interval_timeout = None
                            self.class_and = None
                            self.egress = None
                            self.ingress = None
                            self.ipv4 = None
                            self.ipv6 = None
                            self._segment_path = lambda: "media"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Performance.Monitor.Context.TrafficMonitor.Media, ['cache_size', 'class_replace', 'interval_timeout', 'class_and', 'egress', 'ingress', 'ipv4', 'ipv6'], name, value)


                    class Url(Entity):
                        """
                        URL information, application response time (ART) metrics and counters
                        
                        .. attribute:: cache_size
                        
                        	Maximum flow entries in the Flow Cache
                        	**type**\: int
                        
                        	**range:** 64..2000000
                        
                        .. attribute:: class_and
                        
                        	Narrow down default traffic classification
                        	**type**\: str
                        
                        .. attribute:: class_replace
                        
                        	Replace traffic classification
                        	**type**\: str
                        
                        .. attribute:: ipv4
                        
                        	Activate monitor for ipv4 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6
                        
                        	Activate monitor for ipv6 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: sampling_rate
                        
                        	Sampling rate of flow sampler
                        	**type**\: int
                        
                        	**range:** 1..32768
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ezpm'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Performance.Monitor.Context.TrafficMonitor.Url, self).__init__()

                            self.yang_name = "url"
                            self.yang_parent_name = "traffic-monitor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                ('class_and', (YLeaf(YType.str, 'class-and'), ['str'])),
                                ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                                ('sampling_rate', (YLeaf(YType.uint32, 'sampling-rate'), ['int'])),
                            ])
                            self.cache_size = None
                            self.class_and = None
                            self.class_replace = None
                            self.ipv4 = None
                            self.ipv6 = None
                            self.sampling_rate = None
                            self._segment_path = lambda: "url"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Performance.Monitor.Context.TrafficMonitor.Url, ['cache_size', 'class_and', 'class_replace', 'ipv4', 'ipv6', 'sampling_rate'], name, value)


                    class ApplicationClientServerStats(Entity):
                        """
                        Per interface, client, server and application statistics
                        
                        .. attribute:: cache_size
                        
                        	Maximum flow entries in the Flow Cache
                        	**type**\: int
                        
                        	**range:** 64..2000000
                        
                        .. attribute:: class_replace
                        
                        	Replace traffic classification
                        	**type**\: str
                        
                        .. attribute:: interval_timeout
                        
                        	The exporting interval timeout
                        	**type**\: int
                        
                        	**range:** 1..604800
                        
                        .. attribute:: cache_type
                        
                        	The type of the Flow Cache
                        	**type**\:  :py:class:`CacheType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Performance.Monitor.Context.TrafficMonitor.ApplicationClientServerStats.CacheType>`
                        
                        .. attribute:: ipv4
                        
                        	Activate monitor for ipv4 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6
                        
                        	Activate monitor for ipv6 traffic
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ezpm'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Performance.Monitor.Context.TrafficMonitor.ApplicationClientServerStats, self).__init__()

                            self.yang_name = "application-client-server-stats"
                            self.yang_parent_name = "traffic-monitor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                                ('cache_type', (YLeaf(YType.enumeration, 'cache-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Performance.Monitor.Context.TrafficMonitor.ApplicationClientServerStats.CacheType')])),
                                ('ipv4', (YLeaf(YType.empty, 'ipv4'), ['Empty'])),
                                ('ipv6', (YLeaf(YType.empty, 'ipv6'), ['Empty'])),
                            ])
                            self.cache_size = None
                            self.class_replace = None
                            self.interval_timeout = None
                            self.cache_type = None
                            self.ipv4 = None
                            self.ipv6 = None
                            self._segment_path = lambda: "application-client-server-stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Performance.Monitor.Context.TrafficMonitor.ApplicationClientServerStats, ['cache_size', 'class_replace', 'interval_timeout', 'cache_type', 'ipv4', 'ipv6'], name, value)

                        class CacheType(Enum):
                            """
                            CacheType (Enum Class)

                            The type of the Flow Cache

                            .. data:: normal = 0

                            .. data:: synchronized = 1

                            """

                            normal = Enum.YLeaf(0, "normal")

                            synchronized = Enum.YLeaf(1, "synchronized")



                    class ApplicationStats(Entity):
                        """
                        Per application and interface statistics
                        
                        .. attribute:: cache_size
                        
                        	Maximum flow entries in the Flow Cache
                        	**type**\: int
                        
                        	**range:** 64..2000000
                        
                        .. attribute:: class_replace
                        
                        	Replace traffic classification
                        	**type**\: str
                        
                        .. attribute:: interval_timeout
                        
                        	The exporting interval timeout
                        	**type**\: int
                        
                        	**range:** 1..604800
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-ezpm'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.Performance.Monitor.Context.TrafficMonitor.ApplicationStats, self).__init__()

                            self.yang_name = "application-stats"
                            self.yang_parent_name = "traffic-monitor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('cache_size', (YLeaf(YType.uint32, 'cache-size'), ['int'])),
                                ('class_replace', (YLeaf(YType.str, 'class-replace'), ['str'])),
                                ('interval_timeout', (YLeaf(YType.uint32, 'interval-timeout'), ['int'])),
                            ])
                            self.cache_size = None
                            self.class_replace = None
                            self.interval_timeout = None
                            self._segment_path = lambda: "application-stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Performance.Monitor.Context.TrafficMonitor.ApplicationStats, ['cache_size', 'class_replace', 'interval_timeout'], name, value)


            class ObservationPoint(Entity):
                """
                Select observation point
                
                .. attribute:: encrypted_text
                
                	Select clear text for observation
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ezpm'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Performance.Monitor.ObservationPoint, self).__init__()

                    self.yang_name = "observation-point"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('encrypted_text', (YLeaf(YType.empty, 'encrypted-text'), ['Empty'])),
                    ])
                    self.encrypted_text = None
                    self._segment_path = lambda: "observation-point"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/performance/Cisco-IOS-XE-ezpm:monitor/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Performance.Monitor.ObservationPoint, ['encrypted_text'], name, value)


    class Otv(Entity):
        """
        Configure OTV information
        
        .. attribute:: fragmentation
        
        	Clear the DF (Don't Fragment) bit in the IP header
        	**type**\:  :py:class:`Fragmentation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Fragmentation>`
        
        .. attribute:: isis
        
        	OTV ISIS instance subcommands
        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis>`
        
        .. attribute:: site
        
        	OTV site network configuration
        	**type**\: list of  		 :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site>`
        
        .. attribute:: site_identifier
        
        	OTV site id
        	**type**\: union of the below types:
        
        		**type**\: int
        
        			**range:** 0..4294967295
        
        		**type**\: str
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Otv, self).__init__()

            self.yang_name = "otv"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-otv:fragmentation", ("fragmentation", Native.Otv.Fragmentation)), ("Cisco-IOS-XE-otv:isis", ("isis", Native.Otv.Isis)), ("Cisco-IOS-XE-otv:site", ("site", Native.Otv.Site))])
            self._leafs = OrderedDict([
                ('site_identifier', (YLeaf(YType.str, 'Cisco-IOS-XE-otv:site-identifier'), ['int','str'])),
            ])
            self.site_identifier = None

            self.fragmentation = Native.Otv.Fragmentation()
            self.fragmentation.parent = self
            self._children_name_map["fragmentation"] = "Cisco-IOS-XE-otv:fragmentation"

            self.isis = Native.Otv.Isis()
            self.isis.parent = self
            self._children_name_map["isis"] = "Cisco-IOS-XE-otv:isis"

            self.site = YList(self)
            self._segment_path = lambda: "otv"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Otv, ['site_identifier'], name, value)


        class Fragmentation(Entity):
            """
            Clear the DF (Don't Fragment) bit in the IP header
            
            .. attribute:: join_interface
            
            	Allow fragmentation for overlays using this join\-interface
            	**type**\:  :py:class:`JoinInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Fragmentation.JoinInterface>`
            
            

            """

            _prefix = 'ios-otv'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Otv.Fragmentation, self).__init__()

                self.yang_name = "fragmentation"
                self.yang_parent_name = "otv"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("join-interface", ("join_interface", Native.Otv.Fragmentation.JoinInterface))])
                self._leafs = OrderedDict()

                self.join_interface = Native.Otv.Fragmentation.JoinInterface()
                self.join_interface.parent = self
                self._children_name_map["join_interface"] = "join-interface"
                self._segment_path = lambda: "Cisco-IOS-XE-otv:fragmentation"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Otv.Fragmentation, [], name, value)


            class JoinInterface(Entity):
                """
                Allow fragmentation for overlays using this join\-interface
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Fragmentation.JoinInterface.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Fragmentation.JoinInterface.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Fragmentation.JoinInterface.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Fragmentation.JoinInterface.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Otv.Fragmentation.JoinInterface, self).__init__()

                    self.yang_name = "join-interface"
                    self.yang_parent_name = "fragmentation"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Otv.Fragmentation.JoinInterface.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Otv.Fragmentation.JoinInterface.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Otv.Fragmentation.JoinInterface.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Otv.Fragmentation.JoinInterface.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.Otv.Fragmentation.JoinInterface.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.Otv.Fragmentation.JoinInterface.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.Otv.Fragmentation.JoinInterface.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.Otv.Fragmentation.JoinInterface.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "join-interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/Cisco-IOS-XE-otv:fragmentation/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Otv.Fragmentation.JoinInterface, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Fragmentation.JoinInterface.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "join-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/Cisco-IOS-XE-otv:fragmentation/join-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Fragmentation.JoinInterface.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Fragmentation.JoinInterface.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "join-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/Cisco-IOS-XE-otv:fragmentation/join-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Fragmentation.JoinInterface.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Fragmentation.JoinInterface.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "join-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/Cisco-IOS-XE-otv:fragmentation/join-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Fragmentation.JoinInterface.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Fragmentation.JoinInterface.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "join-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/Cisco-IOS-XE-otv:fragmentation/join-interface/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Fragmentation.JoinInterface.PortChannelSubinterface, [u'port_channel'], name, value)


        class Isis(Entity):
            """
            OTV ISIS instance subcommands
            
            .. attribute:: overlay
            
            	Overlay interface
            	**type**\: list of  		 :py:class:`Overlay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay>`
            
            .. attribute:: site
            
            	Site Instance
            	**type**\:  :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Site>`
            
            

            """

            _prefix = 'ios-otv'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Otv.Isis, self).__init__()

                self.yang_name = "isis"
                self.yang_parent_name = "otv"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("Overlay", ("overlay", Native.Otv.Isis.Overlay)), ("site", ("site", Native.Otv.Isis.Site))])
                self._leafs = OrderedDict()

                self.site = Native.Otv.Isis.Site()
                self.site.parent = self
                self._children_name_map["site"] = "site"

                self.overlay = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-otv:isis"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Otv.Isis, [], name, value)


            class Overlay(Entity):
                """
                Overlay interface
                
                .. attribute:: number  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..512
                
                .. attribute:: authentication
                
                	ISIS authentication for interface related PDUs
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.Authentication>`
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.Default>`
                
                .. attribute:: delayed_deletion_interval
                
                	Set delayed deletion interval
                	**type**\: int
                
                	**range:** 1..86400
                
                .. attribute:: hostname
                
                	Dynamic hostname for IS\-IS
                	**type**\:  :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.Hostname>`
                
                .. attribute:: log_adjacency_changes
                
                	Log changes in adjacency state
                	**type**\:  :py:class:`LogAdjacencyChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.LogAdjacencyChanges>`
                
                	**presence node**\: True
                
                .. attribute:: lsp_gen_interval
                
                	Minimum interval between regenerating same LSP
                	**type**\:  :py:class:`LspGenInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.LspGenInterval>`
                
                .. attribute:: lsp_mtu
                
                	Set maximum LSP size
                	**type**\: int
                
                	**range:** 128..4352
                
                .. attribute:: lsp_refresh_interval
                
                	Set LSP refresh interval
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: max_lsp_lifetime
                
                	Set maximum LSP lifetime
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: nsf
                
                	Non\-stop forwarding
                	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.Nsf>`
                
                .. attribute:: prc_interval
                
                	Minimum interval between partial route calculations
                	**type**\:  :py:class:`PrcInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.PrcInterval>`
                
                .. attribute:: skeptical
                
                	Be a cautious NSF helper when refresh adjacency
                	**type**\:  :py:class:`Skeptical <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.Skeptical>`
                
                .. attribute:: spf_interval
                
                	Minimum interval between SPF calculations
                	**type**\:  :py:class:`SpfInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.SpfInterval>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Otv.Isis.Overlay, self).__init__()

                    self.yang_name = "Overlay"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("authentication", ("authentication", Native.Otv.Isis.Overlay.Authentication)), ("default", ("default", Native.Otv.Isis.Overlay.Default)), ("hostname", ("hostname", Native.Otv.Isis.Overlay.Hostname)), ("log-adjacency-changes", ("log_adjacency_changes", Native.Otv.Isis.Overlay.LogAdjacencyChanges)), ("lsp-gen-interval", ("lsp_gen_interval", Native.Otv.Isis.Overlay.LspGenInterval)), ("nsf", ("nsf", Native.Otv.Isis.Overlay.Nsf)), ("prc-interval", ("prc_interval", Native.Otv.Isis.Overlay.PrcInterval)), ("skeptical", ("skeptical", Native.Otv.Isis.Overlay.Skeptical)), ("spf-interval", ("spf_interval", Native.Otv.Isis.Overlay.SpfInterval))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ('delayed_deletion_interval', (YLeaf(YType.uint32, 'delayed-deletion-interval'), ['int'])),
                        ('lsp_mtu', (YLeaf(YType.uint32, 'lsp-mtu'), ['int'])),
                        ('lsp_refresh_interval', (YLeaf(YType.uint32, 'lsp-refresh-interval'), ['int'])),
                        ('max_lsp_lifetime', (YLeaf(YType.uint32, 'max-lsp-lifetime'), ['int'])),
                    ])
                    self.number = None
                    self.delayed_deletion_interval = None
                    self.lsp_mtu = None
                    self.lsp_refresh_interval = None
                    self.max_lsp_lifetime = None

                    self.authentication = Native.Otv.Isis.Overlay.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.default = Native.Otv.Isis.Overlay.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.hostname = Native.Otv.Isis.Overlay.Hostname()
                    self.hostname.parent = self
                    self._children_name_map["hostname"] = "hostname"

                    self.log_adjacency_changes = None
                    self._children_name_map["log_adjacency_changes"] = "log-adjacency-changes"

                    self.lsp_gen_interval = Native.Otv.Isis.Overlay.LspGenInterval()
                    self.lsp_gen_interval.parent = self
                    self._children_name_map["lsp_gen_interval"] = "lsp-gen-interval"

                    self.nsf = Native.Otv.Isis.Overlay.Nsf()
                    self.nsf.parent = self
                    self._children_name_map["nsf"] = "nsf"

                    self.prc_interval = Native.Otv.Isis.Overlay.PrcInterval()
                    self.prc_interval.parent = self
                    self._children_name_map["prc_interval"] = "prc-interval"

                    self.skeptical = Native.Otv.Isis.Overlay.Skeptical()
                    self.skeptical.parent = self
                    self._children_name_map["skeptical"] = "skeptical"

                    self.spf_interval = Native.Otv.Isis.Overlay.SpfInterval()
                    self.spf_interval.parent = self
                    self._children_name_map["spf_interval"] = "spf-interval"
                    self._segment_path = lambda: "Overlay" + "[number='" + str(self.number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/Cisco-IOS-XE-otv:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Otv.Isis.Overlay, ['number', 'delayed_deletion_interval', 'lsp_mtu', 'lsp_refresh_interval', 'max_lsp_lifetime'], name, value)


                class Authentication(Entity):
                    """
                    ISIS authentication for interface related PDUs
                    
                    .. attribute:: key_chain
                    
                    	Authentication key\-chain
                    	**type**\: str
                    
                    .. attribute:: mode
                    
                    	Authentication mode for PDUs
                    	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.Authentication.Mode>`
                    
                    .. attribute:: send_only
                    
                    	Authentication send only, receive ignore
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Overlay.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "Overlay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Otv.Isis.Overlay.Authentication.Mode')])),
                            ('send_only', (YLeaf(YType.empty, 'send-only'), ['Empty'])),
                        ])
                        self.key_chain = None
                        self.mode = None
                        self.send_only = None
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Overlay.Authentication, ['key_chain', 'mode', 'send_only'], name, value)

                    class Mode(Enum):
                        """
                        Mode (Enum Class)

                        Authentication mode for PDUs

                        .. data:: md5 = 0

                        .. data:: text = 1

                        """

                        md5 = Enum.YLeaf(0, "md5")

                        text = Enum.YLeaf(1, "text")



                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: authentication
                    
                    	ISIS authentication for interface related PDUs
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.Default.Authentication>`
                    
                    .. attribute:: hostname
                    
                    	Dynamic hostname for IS\-IS
                    	**type**\:  :py:class:`Hostname <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.Default.Hostname>`
                    
                    .. attribute:: delayed_deletion_interval
                    
                    	Set delayed deletion interval
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: log_adjacency_changes
                    
                    	Log changes in adjacency state
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: lsp_gen_interval
                    
                    	Minimum interval between regenerating same LSP
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: lsp_mtu
                    
                    	Set maximum LSP size
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: lsp_refresh_interval
                    
                    	Set LSP refresh interval
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: max_lsp_lifetime
                    
                    	Set maximum LSP lifetime
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: prc_interval
                    
                    	Minimum interval between partial route calculations
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: spf_interval
                    
                    	Minimum interval between SPF calculations
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nsf
                    
                    	Non\-stop forwarding
                    	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.Default.Nsf>`
                    
                    .. attribute:: skeptical
                    
                    	Be a cautious NSF helper when refresh adjacency
                    	**type**\:  :py:class:`Skeptical <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.Default.Skeptical>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Overlay.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "Overlay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Otv.Isis.Overlay.Default.Authentication)), ("hostname", ("hostname", Native.Otv.Isis.Overlay.Default.Hostname)), ("nsf", ("nsf", Native.Otv.Isis.Overlay.Default.Nsf)), ("skeptical", ("skeptical", Native.Otv.Isis.Overlay.Default.Skeptical))])
                        self._leafs = OrderedDict([
                            ('delayed_deletion_interval', (YLeaf(YType.empty, 'delayed-deletion-interval'), ['Empty'])),
                            ('log_adjacency_changes', (YLeaf(YType.empty, 'log-adjacency-changes'), ['Empty'])),
                            ('lsp_gen_interval', (YLeaf(YType.empty, 'lsp-gen-interval'), ['Empty'])),
                            ('lsp_mtu', (YLeaf(YType.empty, 'lsp-mtu'), ['Empty'])),
                            ('lsp_refresh_interval', (YLeaf(YType.empty, 'lsp-refresh-interval'), ['Empty'])),
                            ('max_lsp_lifetime', (YLeaf(YType.empty, 'max-lsp-lifetime'), ['Empty'])),
                            ('prc_interval', (YLeaf(YType.empty, 'prc-interval'), ['Empty'])),
                            ('spf_interval', (YLeaf(YType.empty, 'spf-interval'), ['Empty'])),
                        ])
                        self.delayed_deletion_interval = None
                        self.log_adjacency_changes = None
                        self.lsp_gen_interval = None
                        self.lsp_mtu = None
                        self.lsp_refresh_interval = None
                        self.max_lsp_lifetime = None
                        self.prc_interval = None
                        self.spf_interval = None

                        self.authentication = Native.Otv.Isis.Overlay.Default.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.hostname = Native.Otv.Isis.Overlay.Default.Hostname()
                        self.hostname.parent = self
                        self._children_name_map["hostname"] = "hostname"

                        self.nsf = Native.Otv.Isis.Overlay.Default.Nsf()
                        self.nsf.parent = self
                        self._children_name_map["nsf"] = "nsf"

                        self.skeptical = Native.Otv.Isis.Overlay.Default.Skeptical()
                        self.skeptical.parent = self
                        self._children_name_map["skeptical"] = "skeptical"
                        self._segment_path = lambda: "default"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Overlay.Default, ['delayed_deletion_interval', 'log_adjacency_changes', 'lsp_gen_interval', 'lsp_mtu', 'lsp_refresh_interval', 'max_lsp_lifetime', 'prc_interval', 'spf_interval'], name, value)


                    class Authentication(Entity):
                        """
                        ISIS authentication for interface related PDUs
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode for PDUs
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Overlay.Default.Authentication.Mode>`
                        
                        .. attribute:: send_only
                        
                        	Authentication send only, receive ignore
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Otv.Isis.Overlay.Default.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Otv.Isis.Overlay.Default.Authentication.Mode')])),
                                ('send_only', (YLeaf(YType.empty, 'send-only'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.mode = None
                            self.send_only = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Otv.Isis.Overlay.Default.Authentication, ['key_chain', 'mode', 'send_only'], name, value)

                        class Mode(Enum):
                            """
                            Mode (Enum Class)

                            Authentication mode for PDUs

                            .. data:: md5 = 0

                            .. data:: text = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            text = Enum.YLeaf(1, "text")



                    class Hostname(Entity):
                        """
                        Dynamic hostname for IS\-IS
                        
                        .. attribute:: dynamic
                        
                        	Dynamic hostname
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Otv.Isis.Overlay.Default.Hostname, self).__init__()

                            self.yang_name = "hostname"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                            ])
                            self.dynamic = None
                            self._segment_path = lambda: "hostname"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Otv.Isis.Overlay.Default.Hostname, ['dynamic'], name, value)


                    class Nsf(Entity):
                        """
                        Non\-stop forwarding
                        
                        .. attribute:: cisco
                        
                        	Checkpoint method
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: interval
                        
                        	Minimum required stable interval between restarts
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Otv.Isis.Overlay.Default.Nsf, self).__init__()

                            self.yang_name = "nsf"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('cisco', (YLeaf(YType.empty, 'cisco'), ['Empty'])),
                                ('interval', (YLeaf(YType.empty, 'interval'), ['Empty'])),
                            ])
                            self.cisco = None
                            self.interval = None
                            self._segment_path = lambda: "nsf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Otv.Isis.Overlay.Default.Nsf, ['cisco', 'interval'], name, value)


                    class Skeptical(Entity):
                        """
                        Be a cautious NSF helper when refresh adjacency
                        
                        .. attribute:: interval
                        
                        	Interval during which holdtime will NOT be refreshed
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Otv.Isis.Overlay.Default.Skeptical, self).__init__()

                            self.yang_name = "skeptical"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.empty, 'interval'), ['Empty'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "skeptical"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Otv.Isis.Overlay.Default.Skeptical, ['interval'], name, value)


                class Hostname(Entity):
                    """
                    Dynamic hostname for IS\-IS
                    
                    .. attribute:: dynamic
                    
                    	Dynamic hostname
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Overlay.Hostname, self).__init__()

                        self.yang_name = "hostname"
                        self.yang_parent_name = "Overlay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('dynamic', (YLeaf(YType.empty, 'dynamic'), ['Empty'])),
                        ])
                        self.dynamic = None
                        self._segment_path = lambda: "hostname"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Overlay.Hostname, ['dynamic'], name, value)


                class LogAdjacencyChanges(Entity):
                    """
                    Log changes in adjacency state
                    
                    .. attribute:: all
                    
                    	Include changes generated by non\-IIH event
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Overlay.LogAdjacencyChanges, self).__init__()

                        self.yang_name = "log-adjacency-changes"
                        self.yang_parent_name = "Overlay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "log-adjacency-changes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Overlay.LogAdjacencyChanges, ['all'], name, value)


                class LspGenInterval(Entity):
                    """
                    Minimum interval between regenerating same LSP
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    .. attribute:: milliseconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    .. attribute:: wait
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Overlay.LspGenInterval, self).__init__()

                        self.yang_name = "lsp-gen-interval"
                        self.yang_parent_name = "Overlay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('milliseconds', (YLeaf(YType.uint32, 'milliseconds'), ['int'])),
                            ('wait', (YLeaf(YType.uint32, 'wait'), ['int'])),
                        ])
                        self.seconds = None
                        self.milliseconds = None
                        self.wait = None
                        self._segment_path = lambda: "lsp-gen-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Overlay.LspGenInterval, ['seconds', 'milliseconds', 'wait'], name, value)


                class Nsf(Entity):
                    """
                    Non\-stop forwarding
                    
                    .. attribute:: cisco
                    
                    	Checkpoint method
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: interval
                    
                    	Minimum required stable interval between restarts
                    	**type**\: int
                    
                    	**range:** 0..1440
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Overlay.Nsf, self).__init__()

                        self.yang_name = "nsf"
                        self.yang_parent_name = "Overlay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('cisco', (YLeaf(YType.empty, 'cisco'), ['Empty'])),
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                        ])
                        self.cisco = None
                        self.interval = None
                        self._segment_path = lambda: "nsf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Overlay.Nsf, ['cisco', 'interval'], name, value)


                class PrcInterval(Entity):
                    """
                    Minimum interval between partial route calculations
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    .. attribute:: milliseconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    .. attribute:: wait
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Overlay.PrcInterval, self).__init__()

                        self.yang_name = "prc-interval"
                        self.yang_parent_name = "Overlay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('milliseconds', (YLeaf(YType.uint32, 'milliseconds'), ['int'])),
                            ('wait', (YLeaf(YType.uint32, 'wait'), ['int'])),
                        ])
                        self.seconds = None
                        self.milliseconds = None
                        self.wait = None
                        self._segment_path = lambda: "prc-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Overlay.PrcInterval, ['seconds', 'milliseconds', 'wait'], name, value)


                class Skeptical(Entity):
                    """
                    Be a cautious NSF helper when refresh adjacency
                    
                    .. attribute:: interval
                    
                    	Interval during which holdtime will NOT be refreshed
                    	**type**\: int
                    
                    	**range:** 0..1440
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Overlay.Skeptical, self).__init__()

                        self.yang_name = "skeptical"
                        self.yang_parent_name = "Overlay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                        ])
                        self.interval = None
                        self._segment_path = lambda: "skeptical"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Overlay.Skeptical, ['interval'], name, value)


                class SpfInterval(Entity):
                    """
                    Minimum interval between SPF calculations
                    
                    .. attribute:: seconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120
                    
                    .. attribute:: milliseconds
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    .. attribute:: wait
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..120000
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Overlay.SpfInterval, self).__init__()

                        self.yang_name = "spf-interval"
                        self.yang_parent_name = "Overlay"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('seconds', (YLeaf(YType.uint8, 'seconds'), ['int'])),
                            ('milliseconds', (YLeaf(YType.uint32, 'milliseconds'), ['int'])),
                            ('wait', (YLeaf(YType.uint32, 'wait'), ['int'])),
                        ])
                        self.seconds = None
                        self.milliseconds = None
                        self.wait = None
                        self._segment_path = lambda: "spf-interval"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Overlay.SpfInterval, ['seconds', 'milliseconds', 'wait'], name, value)


            class Site(Entity):
                """
                Site Instance
                
                .. attribute:: default
                
                	Set a command to its defaults
                	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Site.Default>`
                
                .. attribute:: log_adjacency_changes
                
                	Log changes in adjacency state
                	**type**\:  :py:class:`LogAdjacencyChanges <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Site.LogAdjacencyChanges>`
                
                	**presence node**\: True
                
                .. attribute:: net
                
                	A Network Entity Title for this process
                	**type**\: str
                
                .. attribute:: skeptical
                
                	Be a cautious NSF helper when refresh adjacency
                	**type**\:  :py:class:`Skeptical <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Site.Skeptical>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Otv.Isis.Site, self).__init__()

                    self.yang_name = "site"
                    self.yang_parent_name = "isis"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("default", ("default", Native.Otv.Isis.Site.Default)), ("log-adjacency-changes", ("log_adjacency_changes", Native.Otv.Isis.Site.LogAdjacencyChanges)), ("skeptical", ("skeptical", Native.Otv.Isis.Site.Skeptical))])
                    self._leafs = OrderedDict([
                        ('net', (YLeaf(YType.str, 'net'), ['str'])),
                    ])
                    self.net = None

                    self.default = Native.Otv.Isis.Site.Default()
                    self.default.parent = self
                    self._children_name_map["default"] = "default"

                    self.log_adjacency_changes = None
                    self._children_name_map["log_adjacency_changes"] = "log-adjacency-changes"

                    self.skeptical = Native.Otv.Isis.Site.Skeptical()
                    self.skeptical.parent = self
                    self._children_name_map["skeptical"] = "skeptical"
                    self._segment_path = lambda: "site"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/Cisco-IOS-XE-otv:isis/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Otv.Isis.Site, ['net'], name, value)


                class Default(Entity):
                    """
                    Set a command to its defaults
                    
                    .. attribute:: log_adjacency_changes
                    
                    	Log changes in adjacency state
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: net
                    
                    	A Network Entity Title for this process
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: skeptical
                    
                    	Be a cautious NSF helper when refresh adjacency
                    	**type**\:  :py:class:`Skeptical <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Isis.Site.Default.Skeptical>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Site.Default, self).__init__()

                        self.yang_name = "default"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("skeptical", ("skeptical", Native.Otv.Isis.Site.Default.Skeptical))])
                        self._leafs = OrderedDict([
                            ('log_adjacency_changes', (YLeaf(YType.empty, 'log-adjacency-changes'), ['Empty'])),
                            ('net', (YLeaf(YType.empty, 'net'), ['Empty'])),
                        ])
                        self.log_adjacency_changes = None
                        self.net = None

                        self.skeptical = Native.Otv.Isis.Site.Default.Skeptical()
                        self.skeptical.parent = self
                        self._children_name_map["skeptical"] = "skeptical"
                        self._segment_path = lambda: "default"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/Cisco-IOS-XE-otv:isis/site/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Site.Default, ['log_adjacency_changes', 'net'], name, value)


                    class Skeptical(Entity):
                        """
                        Be a cautious NSF helper when refresh adjacency
                        
                        .. attribute:: interval
                        
                        	Interval during which holdtime will NOT be refreshed
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Otv.Isis.Site.Default.Skeptical, self).__init__()

                            self.yang_name = "skeptical"
                            self.yang_parent_name = "default"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interval', (YLeaf(YType.empty, 'interval'), ['Empty'])),
                            ])
                            self.interval = None
                            self._segment_path = lambda: "skeptical"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/Cisco-IOS-XE-otv:isis/site/default/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Otv.Isis.Site.Default.Skeptical, ['interval'], name, value)


                class LogAdjacencyChanges(Entity):
                    """
                    Log changes in adjacency state
                    
                    .. attribute:: all
                    
                    	Include changes generated by non\-IIH event
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Site.LogAdjacencyChanges, self).__init__()

                        self.yang_name = "log-adjacency-changes"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                        ])
                        self.all = None
                        self._segment_path = lambda: "log-adjacency-changes"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/Cisco-IOS-XE-otv:isis/site/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Site.LogAdjacencyChanges, ['all'], name, value)


                class Skeptical(Entity):
                    """
                    Be a cautious NSF helper when refresh adjacency
                    
                    .. attribute:: interval
                    
                    	Interval during which holdtime will NOT be refreshed
                    	**type**\: int
                    
                    	**range:** 0..1440
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Isis.Site.Skeptical, self).__init__()

                        self.yang_name = "skeptical"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                        ])
                        self.interval = None
                        self._segment_path = lambda: "skeptical"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/Cisco-IOS-XE-otv:isis/site/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Isis.Site.Skeptical, ['interval'], name, value)


        class Site(Entity):
            """
            OTV site network configuration
            
            .. attribute:: bridge_domain  (key)
            
            	Bridge\-domain to discover local OTV enabled devices
            	**type**\: int
            
            	**range:** 1..8192
            
            .. attribute:: default
            
            	Set a command to its defaults
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Default>`
            
            .. attribute:: otv
            
            	OTV site configuration subcommands
            	**type**\:  :py:class:`Otv_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Otv_>`
            
            

            """

            _prefix = 'ios-otv'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Otv.Site, self).__init__()

                self.yang_name = "site"
                self.yang_parent_name = "otv"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['bridge_domain']
                self._child_classes = OrderedDict([("default", ("default", Native.Otv.Site.Default)), ("otv", ("otv", Native.Otv.Site.Otv_))])
                self._leafs = OrderedDict([
                    ('bridge_domain', (YLeaf(YType.uint16, 'bridge-domain'), ['int'])),
                ])
                self.bridge_domain = None

                self.default = Native.Otv.Site.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.otv = Native.Otv.Site.Otv_()
                self.otv.parent = self
                self._children_name_map["otv"] = "otv"
                self._segment_path = lambda: "Cisco-IOS-XE-otv:site" + "[bridge-domain='" + str(self.bridge_domain) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/otv/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Otv.Site, ['bridge_domain'], name, value)


            class Default(Entity):
                """
                Set a command to its defaults
                
                .. attribute:: otv
                
                	OTV site configuration subcommands
                	**type**\:  :py:class:`Otv_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Default.Otv_>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Otv.Site.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "site"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("otv", ("otv", Native.Otv.Site.Default.Otv_))])
                    self._leafs = OrderedDict()

                    self.otv = Native.Otv.Site.Default.Otv_()
                    self.otv.parent = self
                    self._children_name_map["otv"] = "otv"
                    self._segment_path = lambda: "default"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Otv.Site.Default, [], name, value)


                class Otv_(Entity):
                    """
                    OTV site configuration subcommands
                    
                    .. attribute:: isis
                    
                    	ISIS interface subcommands
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Default.Otv_.Isis>`
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Site.Default.Otv_, self).__init__()

                        self.yang_name = "otv"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis", ("isis", Native.Otv.Site.Default.Otv_.Isis))])
                        self._leafs = OrderedDict()

                        self.isis = Native.Otv.Site.Default.Otv_.Isis()
                        self.isis.parent = self
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "otv"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Site.Default.Otv_, [], name, value)


                    class Isis(Entity):
                        """
                        ISIS interface subcommands
                        
                        .. attribute:: authentication
                        
                        	ISIS authentication for interface related PDUs
                        	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Default.Otv_.Isis.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	Bidirectional Forwarding Protocol
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hello
                        
                        	Add padding to IS\-IS hello packets
                        	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Default.Otv_.Isis.Hello>`
                        
                        .. attribute:: hello_interval
                        
                        	Set Hello interval in seconds
                        	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Default.Otv_.Isis.HelloInterval>`
                        
                        .. attribute:: hello_multiplier
                        
                        	Set multiplier for Hello holding time
                        	**type**\: int
                        
                        	**range:** 3..1000
                        
                        .. attribute:: priority
                        
                        	Set priority for Designated Router election
                        	**type**\: int
                        
                        	**range:** 0..127
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Otv.Site.Default.Otv_.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "otv"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authentication", ("authentication", Native.Otv.Site.Default.Otv_.Isis.Authentication)), ("hello", ("hello", Native.Otv.Site.Default.Otv_.Isis.Hello)), ("hello-interval", ("hello_interval", Native.Otv.Site.Default.Otv_.Isis.HelloInterval))])
                            self._leafs = OrderedDict([
                                ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                                ('hello_multiplier', (YLeaf(YType.uint16, 'hello-multiplier'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                            ])
                            self.bfd = None
                            self.hello_multiplier = None
                            self.priority = None

                            self.authentication = Native.Otv.Site.Default.Otv_.Isis.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"

                            self.hello = Native.Otv.Site.Default.Otv_.Isis.Hello()
                            self.hello.parent = self
                            self._children_name_map["hello"] = "hello"

                            self.hello_interval = Native.Otv.Site.Default.Otv_.Isis.HelloInterval()
                            self.hello_interval.parent = self
                            self._children_name_map["hello_interval"] = "hello-interval"
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Otv.Site.Default.Otv_.Isis, ['bfd', 'hello_multiplier', 'priority'], name, value)


                        class Authentication(Entity):
                            """
                            ISIS authentication for interface related PDUs
                            
                            .. attribute:: key_chain
                            
                            	Authentication key\-chain
                            	**type**\: str
                            
                            .. attribute:: mode
                            
                            	Authentication mode for PDUs
                            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Default.Otv_.Isis.Authentication.Mode>`
                            
                            .. attribute:: send_only
                            
                            	Authentication send only, receive ignore
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Otv.Site.Default.Otv_.Isis.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Otv.Site.Default.Otv_.Isis.Authentication.Mode')])),
                                    ('send_only', (YLeaf(YType.empty, 'send-only'), ['Empty'])),
                                ])
                                self.key_chain = None
                                self.mode = None
                                self.send_only = None
                                self._segment_path = lambda: "authentication"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Otv.Site.Default.Otv_.Isis.Authentication, ['key_chain', 'mode', 'send_only'], name, value)

                            class Mode(Enum):
                                """
                                Mode (Enum Class)

                                Authentication mode for PDUs

                                .. data:: md5 = 0

                                .. data:: text = 1

                                """

                                md5 = Enum.YLeaf(0, "md5")

                                text = Enum.YLeaf(1, "text")



                        class Hello(Entity):
                            """
                            Add padding to IS\-IS hello packets
                            
                            .. attribute:: padding
                            
                            	Pad hello packets
                            	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Default.Otv_.Isis.Hello.Padding>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Otv.Site.Default.Otv_.Isis.Hello, self).__init__()

                                self.yang_name = "hello"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("padding", ("padding", Native.Otv.Site.Default.Otv_.Isis.Hello.Padding))])
                                self._leafs = OrderedDict()

                                self.padding = None
                                self._children_name_map["padding"] = "padding"
                                self._segment_path = lambda: "hello"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Otv.Site.Default.Otv_.Isis.Hello, [], name, value)


                            class Padding(Entity):
                                """
                                Pad hello packets
                                
                                .. attribute:: always
                                
                                	Never pad hello packets if no prefix present
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-otv'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Otv.Site.Default.Otv_.Isis.Hello.Padding, self).__init__()

                                    self.yang_name = "padding"
                                    self.yang_parent_name = "hello"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                    ])
                                    self.always = None
                                    self._segment_path = lambda: "padding"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Otv.Site.Default.Otv_.Isis.Hello.Padding, ['always'], name, value)


                        class HelloInterval(Entity):
                            """
                            Set Hello interval in seconds
                            
                            .. attribute:: value
                            
                            	
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: minimal
                            
                            	Holdtime 1 second, interval depends on multiplier
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Otv.Site.Default.Otv_.Isis.HelloInterval, self).__init__()

                                self.yang_name = "hello-interval"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                    ('minimal', (YLeaf(YType.empty, 'minimal'), ['Empty'])),
                                ])
                                self.value = None
                                self.minimal = None
                                self._segment_path = lambda: "hello-interval"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Otv.Site.Default.Otv_.Isis.HelloInterval, ['value', 'minimal'], name, value)


            class Otv_(Entity):
                """
                OTV site configuration subcommands
                
                .. attribute:: isis
                
                	ISIS interface subcommands
                	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Otv_.Isis>`
                
                

                """

                _prefix = 'ios-otv'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Otv.Site.Otv_, self).__init__()

                    self.yang_name = "otv"
                    self.yang_parent_name = "site"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("isis", ("isis", Native.Otv.Site.Otv_.Isis))])
                    self._leafs = OrderedDict()

                    self.isis = Native.Otv.Site.Otv_.Isis()
                    self.isis.parent = self
                    self._children_name_map["isis"] = "isis"
                    self._segment_path = lambda: "otv"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Otv.Site.Otv_, [], name, value)


                class Isis(Entity):
                    """
                    ISIS interface subcommands
                    
                    .. attribute:: authentication
                    
                    	ISIS authentication for interface related PDUs
                    	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Otv_.Isis.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	Bidirectional Forwarding Protocol
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hello
                    
                    	Add padding to IS\-IS hello packets
                    	**type**\:  :py:class:`Hello <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Otv_.Isis.Hello>`
                    
                    .. attribute:: hello_interval
                    
                    	Set Hello interval in seconds
                    	**type**\:  :py:class:`HelloInterval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Otv_.Isis.HelloInterval>`
                    
                    .. attribute:: hello_multiplier
                    
                    	Set multiplier for Hello holding time
                    	**type**\: int
                    
                    	**range:** 3..1000
                    
                    .. attribute:: priority
                    
                    	Set priority for Designated Router election
                    	**type**\: int
                    
                    	**range:** 0..127
                    
                    

                    """

                    _prefix = 'ios-otv'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Otv.Site.Otv_.Isis, self).__init__()

                        self.yang_name = "isis"
                        self.yang_parent_name = "otv"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("authentication", ("authentication", Native.Otv.Site.Otv_.Isis.Authentication)), ("hello", ("hello", Native.Otv.Site.Otv_.Isis.Hello)), ("hello-interval", ("hello_interval", Native.Otv.Site.Otv_.Isis.HelloInterval))])
                        self._leafs = OrderedDict([
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('hello_multiplier', (YLeaf(YType.uint16, 'hello-multiplier'), ['int'])),
                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                        ])
                        self.bfd = None
                        self.hello_multiplier = None
                        self.priority = None

                        self.authentication = Native.Otv.Site.Otv_.Isis.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"

                        self.hello = Native.Otv.Site.Otv_.Isis.Hello()
                        self.hello.parent = self
                        self._children_name_map["hello"] = "hello"

                        self.hello_interval = Native.Otv.Site.Otv_.Isis.HelloInterval()
                        self.hello_interval.parent = self
                        self._children_name_map["hello_interval"] = "hello-interval"
                        self._segment_path = lambda: "isis"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Otv.Site.Otv_.Isis, ['bfd', 'hello_multiplier', 'priority'], name, value)


                    class Authentication(Entity):
                        """
                        ISIS authentication for interface related PDUs
                        
                        .. attribute:: key_chain
                        
                        	Authentication key\-chain
                        	**type**\: str
                        
                        .. attribute:: mode
                        
                        	Authentication mode for PDUs
                        	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Otv_.Isis.Authentication.Mode>`
                        
                        .. attribute:: send_only
                        
                        	Authentication send only, receive ignore
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Otv.Site.Otv_.Isis.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('key_chain', (YLeaf(YType.str, 'key-chain'), ['str'])),
                                ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Otv.Site.Otv_.Isis.Authentication.Mode')])),
                                ('send_only', (YLeaf(YType.empty, 'send-only'), ['Empty'])),
                            ])
                            self.key_chain = None
                            self.mode = None
                            self.send_only = None
                            self._segment_path = lambda: "authentication"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Otv.Site.Otv_.Isis.Authentication, ['key_chain', 'mode', 'send_only'], name, value)

                        class Mode(Enum):
                            """
                            Mode (Enum Class)

                            Authentication mode for PDUs

                            .. data:: md5 = 0

                            .. data:: text = 1

                            """

                            md5 = Enum.YLeaf(0, "md5")

                            text = Enum.YLeaf(1, "text")



                    class Hello(Entity):
                        """
                        Add padding to IS\-IS hello packets
                        
                        .. attribute:: padding
                        
                        	Pad hello packets
                        	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Otv.Site.Otv_.Isis.Hello.Padding>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Otv.Site.Otv_.Isis.Hello, self).__init__()

                            self.yang_name = "hello"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("padding", ("padding", Native.Otv.Site.Otv_.Isis.Hello.Padding))])
                            self._leafs = OrderedDict()

                            self.padding = None
                            self._children_name_map["padding"] = "padding"
                            self._segment_path = lambda: "hello"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Otv.Site.Otv_.Isis.Hello, [], name, value)


                        class Padding(Entity):
                            """
                            Pad hello packets
                            
                            .. attribute:: always
                            
                            	Never pad hello packets if no prefix present
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-otv'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Otv.Site.Otv_.Isis.Hello.Padding, self).__init__()

                                self.yang_name = "padding"
                                self.yang_parent_name = "hello"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('always', (YLeaf(YType.empty, 'always'), ['Empty'])),
                                ])
                                self.always = None
                                self._segment_path = lambda: "padding"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Otv.Site.Otv_.Isis.Hello.Padding, ['always'], name, value)


                    class HelloInterval(Entity):
                        """
                        Set Hello interval in seconds
                        
                        .. attribute:: value
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: minimal
                        
                        	Holdtime 1 second, interval depends on multiplier
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-otv'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Otv.Site.Otv_.Isis.HelloInterval, self).__init__()

                            self.yang_name = "hello-interval"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                                ('minimal', (YLeaf(YType.empty, 'minimal'), ['Empty'])),
                            ])
                            self.value = None
                            self.minimal = None
                            self._segment_path = lambda: "hello-interval"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Otv.Site.Otv_.Isis.HelloInterval, ['value', 'minimal'], name, value)


    class RemoteManagement(Entity):
        """
        Enable the remote managment
        
        .. attribute:: dmi
        
        	data\-model\-interface
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: restful_api
        
        	RESTful API
        	**type**\: bool
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.RemoteManagement, self).__init__()

            self.yang_name = "remote-management"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('dmi', (YLeaf(YType.empty, 'dmi'), ['Empty'])),
                ('restful_api', (YLeaf(YType.boolean, 'restful-api'), ['bool'])),
            ])
            self.dmi = None
            self.restful_api = None
            self._segment_path = lambda: "remote-management"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.RemoteManagement, [u'dmi', u'restful_api'], name, value)


    class VirtualService(Entity):
        """
        Configure virtual service
        
        .. attribute:: name  (key)
        
        	
        	**type**\: str
        
        	**length:** 1..63
        
        .. attribute:: ip
        
        	ip configured virtual service
        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Ip>`
        
        .. attribute:: activate
        
        	Activate configured virtual service
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: profile
        
        	
        	**type**\: str
        
        .. attribute:: vnic
        
        	Guest vnic configuration
        	**type**\:  :py:class:`Vnic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Vnic>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.VirtualService, self).__init__()

            self.yang_name = "virtual-service"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['name']
            self._child_classes = OrderedDict([("Cisco-IOS-XE-vservice:ip", ("ip", Native.VirtualService.Ip)), ("Cisco-IOS-XE-vservice:vnic", ("vnic", Native.VirtualService.Vnic))])
            self._leafs = OrderedDict([
                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ('activate', (YLeaf(YType.empty, 'Cisco-IOS-XE-vservice:activate'), ['Empty'])),
                ('profile', (YLeaf(YType.str, 'Cisco-IOS-XE-vservice:profile'), ['str'])),
            ])
            self.name = None
            self.activate = None
            self.profile = None

            self.ip = Native.VirtualService.Ip()
            self.ip.parent = self
            self._children_name_map["ip"] = "Cisco-IOS-XE-vservice:ip"

            self.vnic = Native.VirtualService.Vnic()
            self.vnic.parent = self
            self._children_name_map["vnic"] = "Cisco-IOS-XE-vservice:vnic"
            self._segment_path = lambda: "virtual-service" + "[name='" + str(self.name) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.VirtualService, [u'name', 'activate', 'profile'], name, value)


        class Ip(Entity):
            """
            ip configured virtual service
            
            .. attribute:: shared
            
            	Ip shared host\-interface
            	**type**\:  :py:class:`Shared <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Ip.Shared>`
            
            

            """

            _prefix = 'ios-vservice'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.VirtualService.Ip, self).__init__()

                self.yang_name = "ip"
                self.yang_parent_name = "virtual-service"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("shared", ("shared", Native.VirtualService.Ip.Shared))])
                self._leafs = OrderedDict()

                self.shared = Native.VirtualService.Ip.Shared()
                self.shared.parent = self
                self._children_name_map["shared"] = "shared"
                self._segment_path = lambda: "Cisco-IOS-XE-vservice:ip"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.VirtualService.Ip, [], name, value)


            class Shared(Entity):
                """
                Ip shared host\-interface
                
                .. attribute:: host_interface
                
                	Ip shared host\-interface
                	**type**\:  :py:class:`HostInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Ip.Shared.HostInterface>`
                
                

                """

                _prefix = 'ios-vservice'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.VirtualService.Ip.Shared, self).__init__()

                    self.yang_name = "shared"
                    self.yang_parent_name = "ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("host-interface", ("host_interface", Native.VirtualService.Ip.Shared.HostInterface))])
                    self._leafs = OrderedDict()

                    self.host_interface = Native.VirtualService.Ip.Shared.HostInterface()
                    self.host_interface.parent = self
                    self._children_name_map["host_interface"] = "host-interface"
                    self._segment_path = lambda: "shared"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.VirtualService.Ip.Shared, [], name, value)


                class HostInterface(Entity):
                    """
                    Ip shared host\-interface
                    
                    .. attribute:: fastethernet
                    
                    	FastEthernet IEEE 802.3
                    	**type**\: str
                    
                    .. attribute:: tengigabitethernet
                    
                    	Ten Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: gigabitethernet
                    
                    	GigabitEthernet IEEE 802.3z
                    	**type**\: str
                    
                    .. attribute:: fivegigabitethernet
                    
                    	Five Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: twentyfivegige
                    
                    	Twenty Five Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: twogigabitethernet
                    
                    	Two Gigabit Ethernet
                    	**type**\: str
                    
                    .. attribute:: loopback
                    
                    	Loopback interface
                    	**type**\: int
                    
                    	**range:** 0..2147483647
                    
                    .. attribute:: vlan
                    
                    	Vlan interface number
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-vservice'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.VirtualService.Ip.Shared.HostInterface, self).__init__()

                        self.yang_name = "host-interface"
                        self.yang_parent_name = "shared"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                            ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                            ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                            ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                            ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                            ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                            ('loopback', (YLeaf(YType.uint64, 'Loopback'), ['int'])),
                            ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ])
                        self.fastethernet = None
                        self.tengigabitethernet = None
                        self.gigabitethernet = None
                        self.fivegigabitethernet = None
                        self.twentyfivegige = None
                        self.twogigabitethernet = None
                        self.loopback = None
                        self.vlan = None
                        self._segment_path = lambda: "host-interface"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.VirtualService.Ip.Shared.HostInterface, ['fastethernet', 'tengigabitethernet', 'gigabitethernet', 'fivegigabitethernet', 'twentyfivegige', 'twogigabitethernet', 'loopback', 'vlan'], name, value)


        class Vnic(Entity):
            """
            Guest vnic configuration
            
            .. attribute:: gateway
            
            	Gateway interface to connect to the guest vnic
            	**type**\:  :py:class:`Gateway <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Vnic.Gateway>`
            
            .. attribute:: management
            
            	Gateway interface to connect to the guest vnic
            	**type**\:  :py:class:`Management <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Vnic.Management>`
            
            

            """

            _prefix = 'ios-vservice'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.VirtualService.Vnic, self).__init__()

                self.yang_name = "vnic"
                self.yang_parent_name = "virtual-service"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("gateway", ("gateway", Native.VirtualService.Vnic.Gateway)), ("management", ("management", Native.VirtualService.Vnic.Management))])
                self._leafs = OrderedDict()

                self.gateway = Native.VirtualService.Vnic.Gateway()
                self.gateway.parent = self
                self._children_name_map["gateway"] = "gateway"

                self.management = Native.VirtualService.Vnic.Management()
                self.management.parent = self
                self._children_name_map["management"] = "management"
                self._segment_path = lambda: "Cisco-IOS-XE-vservice:vnic"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.VirtualService.Vnic, [], name, value)


            class Gateway(Entity):
                """
                Gateway interface to connect to the guest vnic
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: list of  		 :py:class:`VirtualPortGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Vnic.Gateway.VirtualPortGroup>`
                
                

                """

                _prefix = 'ios-vservice'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.VirtualService.Vnic.Gateway, self).__init__()

                    self.yang_name = "gateway"
                    self.yang_parent_name = "vnic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("VirtualPortGroup", ("virtualportgroup", Native.VirtualService.Vnic.Gateway.VirtualPortGroup))])
                    self._leafs = OrderedDict()

                    self.virtualportgroup = YList(self)
                    self._segment_path = lambda: "gateway"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.VirtualService.Vnic.Gateway, [], name, value)


                class VirtualPortGroup(Entity):
                    """
                    Virtual Port Group
                    
                    .. attribute:: number  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..31
                    
                    .. attribute:: guest
                    
                    	Configure guest vnic address
                    	**type**\:  :py:class:`Guest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest>`
                    
                    

                    """

                    _prefix = 'ios-vservice'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.VirtualService.Vnic.Gateway.VirtualPortGroup, self).__init__()

                        self.yang_name = "VirtualPortGroup"
                        self.yang_parent_name = "gateway"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['number']
                        self._child_classes = OrderedDict([("guest", ("guest", Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest))])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                        ])
                        self.number = None

                        self.guest = Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest()
                        self.guest.parent = self
                        self._children_name_map["guest"] = "guest"
                        self._segment_path = lambda: "VirtualPortGroup" + "[number='" + str(self.number) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.VirtualService.Vnic.Gateway.VirtualPortGroup, ['number'], name, value)


                    class Guest(Entity):
                        """
                        Configure guest vnic address
                        
                        .. attribute:: ip
                        
                        	Guest vnic IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest.Ip>`
                        
                        .. attribute:: ipv6
                        
                        	Guest vnic IPv6 address
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest.Ipv6>`
                        
                        

                        """

                        _prefix = 'ios-vservice'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest, self).__init__()

                            self.yang_name = "guest"
                            self.yang_parent_name = "VirtualPortGroup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest.Ip)), ("ipv6", ("ipv6", Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ip = Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"

                            self.ipv6 = Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "guest"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest, [], name, value)


                        class Ip(Entity):
                            """
                            Guest vnic IP address
                            
                            .. attribute:: address
                            
                            	Set the IP address of virtual interface on guest
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-vservice'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "guest"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest.Ip, ['address'], name, value)


                        class Ipv6(Entity):
                            """
                            Guest vnic IPv6 address
                            
                            .. attribute:: address
                            
                            	Set the IPv6 address of virtual interface on guest
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ios-vservice'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "guest"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ])
                                self.address = None
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.VirtualService.Vnic.Gateway.VirtualPortGroup.Guest.Ipv6, ['address'], name, value)


            class Management(Entity):
                """
                Gateway interface to connect to the guest vnic
                
                .. attribute:: gigabitethernet0
                
                	Management Ethernet Interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: guest
                
                	Configure guest vnic address
                	**type**\:  :py:class:`Guest <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Vnic.Management.Guest>`
                
                

                """

                _prefix = 'ios-vservice'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.VirtualService.Vnic.Management, self).__init__()

                    self.yang_name = "management"
                    self.yang_parent_name = "vnic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("guest", ("guest", Native.VirtualService.Vnic.Management.Guest))])
                    self._leafs = OrderedDict([
                        ('gigabitethernet0', (YLeaf(YType.empty, 'GigabitEthernet0'), ['Empty'])),
                    ])
                    self.gigabitethernet0 = None

                    self.guest = Native.VirtualService.Vnic.Management.Guest()
                    self.guest.parent = self
                    self._children_name_map["guest"] = "guest"
                    self._segment_path = lambda: "management"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.VirtualService.Vnic.Management, ['gigabitethernet0'], name, value)


                class Guest(Entity):
                    """
                    Configure guest vnic address
                    
                    .. attribute:: ip
                    
                    	Guest vnic IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Vnic.Management.Guest.Ip>`
                    
                    .. attribute:: ipv6
                    
                    	Guest vnic IPv6 address
                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.VirtualService.Vnic.Management.Guest.Ipv6>`
                    
                    

                    """

                    _prefix = 'ios-vservice'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.VirtualService.Vnic.Management.Guest, self).__init__()

                        self.yang_name = "guest"
                        self.yang_parent_name = "management"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.VirtualService.Vnic.Management.Guest.Ip)), ("ipv6", ("ipv6", Native.VirtualService.Vnic.Management.Guest.Ipv6))])
                        self._leafs = OrderedDict()

                        self.ip = Native.VirtualService.Vnic.Management.Guest.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.ipv6 = Native.VirtualService.Vnic.Management.Guest.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"
                        self._segment_path = lambda: "guest"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.VirtualService.Vnic.Management.Guest, [], name, value)


                    class Ip(Entity):
                        """
                        Guest vnic IP address
                        
                        .. attribute:: address
                        
                        	Set the IP address of virtual interface on guest
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-vservice'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.VirtualService.Vnic.Management.Guest.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "guest"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ])
                            self.address = None
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.VirtualService.Vnic.Management.Guest.Ip, ['address'], name, value)


                    class Ipv6(Entity):
                        """
                        Guest vnic IPv6 address
                        
                        .. attribute:: address
                        
                        	Set the IPv6 address of virtual interface on guest
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-vservice'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.VirtualService.Vnic.Management.Guest.Ipv6, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "guest"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ])
                            self.address = None
                            self._segment_path = lambda: "ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.VirtualService.Vnic.Management.Guest.Ipv6, ['address'], name, value)


    class Snmp(Entity):
        """
        Modify SNMP interface parameters
        
        .. attribute:: ifmib
        
        	IF\-MIB commands
        	**type**\:  :py:class:`Ifmib <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Snmp.Ifmib>`
        
        .. attribute:: mib
        
        	MIB commands
        	**type**\:  :py:class:`Mib <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Snmp.Mib>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Snmp, self).__init__()

            self.yang_name = "snmp"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-snmp:ifmib", ("ifmib", Native.Snmp.Ifmib)), ("Cisco-IOS-XE-snmp:mib", ("mib", Native.Snmp.Mib))])
            self._leafs = OrderedDict()

            self.ifmib = Native.Snmp.Ifmib()
            self.ifmib.parent = self
            self._children_name_map["ifmib"] = "Cisco-IOS-XE-snmp:ifmib"

            self.mib = Native.Snmp.Mib()
            self.mib.parent = self
            self._children_name_map["mib"] = "Cisco-IOS-XE-snmp:mib"
            self._segment_path = lambda: "snmp"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Snmp, [], name, value)


        class Ifmib(Entity):
            """
            IF\-MIB commands
            
            .. attribute:: ifindex
            
            	ifindex persistence
            	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Snmp.Ifmib.Ifindex>`
            
            .. attribute:: ifalias
            
            	ifAlias description option, by default it is limited to 64 character
            	**type**\:  :py:class:`Ifalias <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Snmp.Ifmib.Ifalias>`
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Snmp.Ifmib, self).__init__()

                self.yang_name = "ifmib"
                self.yang_parent_name = "snmp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ifindex", ("ifindex", Native.Snmp.Ifmib.Ifindex)), ("ifalias", ("ifalias", Native.Snmp.Ifmib.Ifalias))])
                self._leafs = OrderedDict()

                self.ifindex = Native.Snmp.Ifmib.Ifindex()
                self.ifindex.parent = self
                self._children_name_map["ifindex"] = "ifindex"

                self.ifalias = Native.Snmp.Ifmib.Ifalias()
                self.ifalias.parent = self
                self._children_name_map["ifalias"] = "ifalias"
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:ifmib"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Snmp.Ifmib, [], name, value)


            class Ifindex(Entity):
                """
                ifindex persistence
                
                .. attribute:: persist
                
                	Persist interface indices
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Snmp.Ifmib.Ifindex, self).__init__()

                    self.yang_name = "ifindex"
                    self.yang_parent_name = "ifmib"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                    ])
                    self.persist = None
                    self._segment_path = lambda: "ifindex"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp/Cisco-IOS-XE-snmp:ifmib/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Snmp.Ifmib.Ifindex, [u'persist'], name, value)


            class Ifalias(Entity):
                """
                ifAlias description option, by default it is limited to 64 character
                
                .. attribute:: long
                
                	ifAlias description can be up to 256 characters
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Snmp.Ifmib.Ifalias, self).__init__()

                    self.yang_name = "ifalias"
                    self.yang_parent_name = "ifmib"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('long', (YLeaf(YType.empty, 'long'), ['Empty'])),
                    ])
                    self.long = None
                    self._segment_path = lambda: "ifalias"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp/Cisco-IOS-XE-snmp:ifmib/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Snmp.Ifmib.Ifalias, [u'long'], name, value)


        class Mib(Entity):
            """
            MIB commands
            
            .. attribute:: community_map
            
            	Community Mapping as per RFC\-2576
            	**type**\:  :py:class:`CommunityMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Snmp.Mib.CommunityMap>`
            
            .. attribute:: bulkstat
            
            	Bulkstat Configuration commands
            	**type**\:  :py:class:`Bulkstat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Snmp.Mib.Bulkstat>`
            
            .. attribute:: persist
            
            	Persistence for MIBS
            	**type**\:  :py:class:`Persist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Snmp.Mib.Persist>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Snmp.Mib, self).__init__()

                self.yang_name = "mib"
                self.yang_parent_name = "snmp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("community-map", ("community_map", Native.Snmp.Mib.CommunityMap)), ("bulkstat", ("bulkstat", Native.Snmp.Mib.Bulkstat)), ("persist", ("persist", Native.Snmp.Mib.Persist))])
                self._leafs = OrderedDict()

                self.community_map = Native.Snmp.Mib.CommunityMap()
                self.community_map.parent = self
                self._children_name_map["community_map"] = "community-map"

                self.bulkstat = Native.Snmp.Mib.Bulkstat()
                self.bulkstat.parent = self
                self._children_name_map["bulkstat"] = "bulkstat"

                self.persist = None
                self._children_name_map["persist"] = "persist"
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:mib"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Snmp.Mib, [], name, value)


            class CommunityMap(Entity):
                """
                Community Mapping as per RFC\-2576
                
                .. attribute:: community_map_list
                
                	SNMP community string
                	**type**\: list of  		 :py:class:`CommunityMapList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Snmp.Mib.CommunityMap.CommunityMapList>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Snmp.Mib.CommunityMap, self).__init__()

                    self.yang_name = "community-map"
                    self.yang_parent_name = "mib"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("community-map-list", ("community_map_list", Native.Snmp.Mib.CommunityMap.CommunityMapList))])
                    self._leafs = OrderedDict()

                    self.community_map_list = YList(self)
                    self._segment_path = lambda: "community-map"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp/Cisco-IOS-XE-snmp:mib/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Snmp.Mib.CommunityMap, [], name, value)


                class CommunityMapList(Entity):
                    """
                    SNMP community string
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: engineid
                    
                    	Engine ID for the community mapping
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Snmp.Mib.CommunityMap.CommunityMapList, self).__init__()

                        self.yang_name = "community-map-list"
                        self.yang_parent_name = "community-map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('engineid', (YLeaf(YType.str, 'engineid'), ['str'])),
                        ])
                        self.name = None
                        self.engineid = None
                        self._segment_path = lambda: "community-map-list" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp/Cisco-IOS-XE-snmp:mib/community-map/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Snmp.Mib.CommunityMap.CommunityMapList, [u'name', u'engineid'], name, value)


            class Bulkstat(Entity):
                """
                Bulkstat Configuration commands
                
                .. attribute:: object_list
                
                	Configure an Object List
                	**type**\: list of  		 :py:class:`ObjectList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Snmp.Mib.Bulkstat.ObjectList>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Snmp.Mib.Bulkstat, self).__init__()

                    self.yang_name = "bulkstat"
                    self.yang_parent_name = "mib"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("object-list", ("object_list", Native.Snmp.Mib.Bulkstat.ObjectList))])
                    self._leafs = OrderedDict()

                    self.object_list = YList(self)
                    self._segment_path = lambda: "bulkstat"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp/Cisco-IOS-XE-snmp:mib/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Snmp.Mib.Bulkstat, [], name, value)


                class ObjectList(Entity):
                    """
                    Configure an Object List.
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Snmp.Mib.Bulkstat.ObjectList, self).__init__()

                        self.yang_name = "object-list"
                        self.yang_parent_name = "bulkstat"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "object-list" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp/Cisco-IOS-XE-snmp:mib/bulkstat/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Snmp.Mib.Bulkstat.ObjectList, [u'name'], name, value)


            class Persist(Entity):
                """
                Persistence for MIBS
                
                .. attribute:: persist_enum
                
                	
                	**type**\:  :py:class:`PersistEnum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Snmp.Mib.Persist.PersistEnum>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Snmp.Mib.Persist, self).__init__()

                    self.yang_name = "persist"
                    self.yang_parent_name = "mib"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('persist_enum', (YLeaf(YType.enumeration, 'persist-enum'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Snmp.Mib.Persist.PersistEnum')])),
                    ])
                    self.persist_enum = None
                    self._segment_path = lambda: "persist"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp/Cisco-IOS-XE-snmp:mib/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Snmp.Mib.Persist, [u'persist_enum'], name, value)

                class PersistEnum(Enum):
                    """
                    PersistEnum (Enum Class)

                    .. data:: cbqos = 0

                    .. data:: circuit = 1

                    .. data:: v3mibs = 2

                    """

                    cbqos = Enum.YLeaf(0, "cbqos")

                    circuit = Enum.YLeaf(1, "circuit")

                    v3mibs = Enum.YLeaf(2, "v3mibs")



    class SnmpServer(Entity):
        """
        Modify SNMP engine parameters
        
        .. attribute:: chassis_id
        
        	String to uniquely identify this chassis
        	**type**\: str
        
        .. attribute:: community
        
        	Enable SNMP; set community string and access privs
        	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Community>`
        
        .. attribute:: contact
        
        	Text for mib object sysContact
        	**type**\: str
        
        .. attribute:: context
        
        	Create/Delete a context apart from default
        	**type**\: list of  		 :py:class:`Context <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Context>`
        
        .. attribute:: enable
        
        	Enable SNMP Traps or Informs
        	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable>`
        
        .. attribute:: engineid
        
        	Configure a local or remote SNMPv3 engineID
        	**type**\:  :py:class:`EngineID <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.EngineID>`
        
        .. attribute:: group
        
        	Define a User Security Model group
        	**type**\: list of  		 :py:class:`Group <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Group>`
        
        .. attribute:: host
        
        	Specify hosts to receive SNMP notifications
        	**type**\: list of  		 :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Host>`
        
        .. attribute:: ip
        
        	IP ToS configuration for SNMP traffic
        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Ip>`
        
        .. attribute:: ifindex
        
        	Enable ifindex persistence
        	**type**\:  :py:class:`Ifindex <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Ifindex>`
        
        .. attribute:: location
        
        	Text for mib object sysLocation
        	**type**\: str
        
        .. attribute:: manager
        
        	Modify SNMP manager parameters
        	**type**\:  :py:class:`Manager <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Manager>`
        
        	**presence node**\: True
        
        .. attribute:: packetsize
        
        	Largest SNMP packet size
        	**type**\: int
        
        	**range:** 484..17924
        
        .. attribute:: queue_length
        
        	Message queue length for each TRAP host
        	**type**\: int
        
        	**range:** 1..5000
        
        .. attribute:: source_interface
        
        	Assign an source interface
        	**type**\:  :py:class:`SourceInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.SourceInterface>`
        
        .. attribute:: system_shutdown
        
        	Enable use of the SNMP reload command
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: tftp_server_list
        
        	Limit TFTP servers used via SNMP
        	**type**\: union of the below types:
        
        		**type**\: int
        
        			**range:** 1..99
        
        		**type**\: str
        
        .. attribute:: trap
        
        	SNMP trap options
        	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Trap>`
        
        .. attribute:: trap_source
        
        	Assign an interface for the source address of all traps
        	**type**\:  :py:class:`TrapSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.TrapSource>`
        
        .. attribute:: user
        
        	Define a user who can access the SNMP engine
        	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.User>`
        
        .. attribute:: view
        
        	Define an SNMPv2 MIB view
        	**type**\: list of  		 :py:class:`View <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.View>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.SnmpServer, self).__init__()

            self.yang_name = "snmp-server"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-snmp:community", ("community", Native.SnmpServer.Community)), ("Cisco-IOS-XE-snmp:context", ("context", Native.SnmpServer.Context)), ("Cisco-IOS-XE-snmp:enable", ("enable", Native.SnmpServer.Enable)), ("Cisco-IOS-XE-snmp:engineID", ("engineid", Native.SnmpServer.EngineID)), ("Cisco-IOS-XE-snmp:group", ("group", Native.SnmpServer.Group)), ("Cisco-IOS-XE-snmp:host", ("host", Native.SnmpServer.Host)), ("Cisco-IOS-XE-snmp:ip", ("ip", Native.SnmpServer.Ip)), ("Cisco-IOS-XE-snmp:ifindex", ("ifindex", Native.SnmpServer.Ifindex)), ("Cisco-IOS-XE-snmp:manager", ("manager", Native.SnmpServer.Manager)), ("Cisco-IOS-XE-snmp:source-interface", ("source_interface", Native.SnmpServer.SourceInterface)), ("Cisco-IOS-XE-snmp:trap", ("trap", Native.SnmpServer.Trap)), ("Cisco-IOS-XE-snmp:trap-source", ("trap_source", Native.SnmpServer.TrapSource)), ("Cisco-IOS-XE-snmp:user", ("user", Native.SnmpServer.User)), ("Cisco-IOS-XE-snmp:view", ("view", Native.SnmpServer.View))])
            self._leafs = OrderedDict([
                ('chassis_id', (YLeaf(YType.str, 'Cisco-IOS-XE-snmp:chassis-id'), ['str'])),
                ('contact', (YLeaf(YType.str, 'Cisco-IOS-XE-snmp:contact'), ['str'])),
                ('location', (YLeaf(YType.str, 'Cisco-IOS-XE-snmp:location'), ['str'])),
                ('packetsize', (YLeaf(YType.uint32, 'Cisco-IOS-XE-snmp:packetsize'), ['int'])),
                ('queue_length', (YLeaf(YType.uint16, 'Cisco-IOS-XE-snmp:queue-length'), ['int'])),
                ('system_shutdown', (YLeaf(YType.empty, 'Cisco-IOS-XE-snmp:system-shutdown'), ['Empty'])),
                ('tftp_server_list', (YLeaf(YType.str, 'Cisco-IOS-XE-snmp:tftp-server-list'), ['int','str'])),
            ])
            self.chassis_id = None
            self.contact = None
            self.location = None
            self.packetsize = None
            self.queue_length = None
            self.system_shutdown = None
            self.tftp_server_list = None

            self.enable = Native.SnmpServer.Enable()
            self.enable.parent = self
            self._children_name_map["enable"] = "Cisco-IOS-XE-snmp:enable"

            self.engineid = Native.SnmpServer.EngineID()
            self.engineid.parent = self
            self._children_name_map["engineid"] = "Cisco-IOS-XE-snmp:engineID"

            self.ip = Native.SnmpServer.Ip()
            self.ip.parent = self
            self._children_name_map["ip"] = "Cisco-IOS-XE-snmp:ip"

            self.ifindex = Native.SnmpServer.Ifindex()
            self.ifindex.parent = self
            self._children_name_map["ifindex"] = "Cisco-IOS-XE-snmp:ifindex"

            self.manager = None
            self._children_name_map["manager"] = "Cisco-IOS-XE-snmp:manager"

            self.source_interface = Native.SnmpServer.SourceInterface()
            self.source_interface.parent = self
            self._children_name_map["source_interface"] = "Cisco-IOS-XE-snmp:source-interface"

            self.trap = Native.SnmpServer.Trap()
            self.trap.parent = self
            self._children_name_map["trap"] = "Cisco-IOS-XE-snmp:trap"

            self.trap_source = Native.SnmpServer.TrapSource()
            self.trap_source.parent = self
            self._children_name_map["trap_source"] = "Cisco-IOS-XE-snmp:trap-source"

            self.user = Native.SnmpServer.User()
            self.user.parent = self
            self._children_name_map["user"] = "Cisco-IOS-XE-snmp:user"

            self.community = YList(self)
            self.context = YList(self)
            self.group = YList(self)
            self.host = YList(self)
            self.view = YList(self)
            self._segment_path = lambda: "snmp-server"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.SnmpServer, [u'chassis_id', u'contact', u'location', u'packetsize', u'queue_length', u'system_shutdown', u'tftp_server_list'], name, value)


        class Community(Entity):
            """
            Enable SNMP; set community string and access privs
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: view
            
            	Restrict this community to a named MIB view
            	**type**\: str
            
            .. attribute:: ro
            
            	Read\-only access with this community string
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: rw
            
            	Read\-write access with this community string
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ipv6
            
            	Specify IPv6 Named Access\-List
            	**type**\: str
            
            .. attribute:: access_list_name
            
            	Access\-list name
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 1..99
            
            		**type**\: int
            
            			**range:** 1300..1999
            
            		**type**\: str
            
            			**pattern:** [a\-zA\-Z].\*
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.Community, self).__init__()

                self.yang_name = "community"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('view', (YLeaf(YType.str, 'view'), ['str'])),
                    ('ro', (YLeaf(YType.empty, 'RO'), ['Empty'])),
                    ('rw', (YLeaf(YType.empty, 'RW'), ['Empty'])),
                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                    ('access_list_name', (YLeaf(YType.str, 'access-list-name'), ['int','int','str'])),
                ])
                self.name = None
                self.view = None
                self.ro = None
                self.rw = None
                self.ipv6 = None
                self.access_list_name = None
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:community" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.Community, [u'name', u'view', u'ro', u'rw', u'ipv6', u'access_list_name'], name, value)


        class Context(Entity):
            """
            Create/Delete a context apart from default
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.Context, self).__init__()

                self.yang_name = "context"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:context" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.Context, [u'name'], name, value)


        class Enable(Entity):
            """
            Enable SNMP Traps or Informs
            
            .. attribute:: enable_choice
            
            	
            	**type**\:  :py:class:`EnableChoice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice>`
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.Enable, self).__init__()

                self.yang_name = "enable"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("enable-choice", ("enable_choice", Native.SnmpServer.Enable.EnableChoice))])
                self._leafs = OrderedDict()

                self.enable_choice = Native.SnmpServer.Enable.EnableChoice()
                self.enable_choice.parent = self
                self._children_name_map["enable_choice"] = "enable-choice"
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:enable"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.Enable, [], name, value)


            class EnableChoice(Entity):
                """
                
                
                .. attribute:: informs
                
                	Enable SNMP Informs
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: traps
                
                	Enable SNMP Traps
                	**type**\:  :py:class:`Traps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.Enable.EnableChoice, self).__init__()

                    self.yang_name = "enable-choice"
                    self.yang_parent_name = "enable"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("traps", ("traps", Native.SnmpServer.Enable.EnableChoice.Traps))])
                    self._leafs = OrderedDict([
                        ('informs', (YLeaf(YType.empty, 'informs'), ['Empty'])),
                    ])
                    self.informs = None

                    self.traps = None
                    self._children_name_map["traps"] = "traps"
                    self._segment_path = lambda: "enable-choice"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SnmpServer.Enable.EnableChoice, [u'informs'], name, value)


                class Traps(Entity):
                    """
                    Enable SNMP Traps
                    
                    .. attribute:: aaa_server
                    
                    	Enable SNMP AAA Server traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trustsec_sxp
                    
                    	Enable SNMP CISCO\-TRUSTSEC\-SXP\-MIB traps
                    	**type**\:  :py:class:`TrustsecSxp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecSxp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: vswitch
                    
                    	Enable SNMP Virtual Switch notifications
                    	**type**\:  :py:class:`Vswitch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Vswitch>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trustsec_server
                    
                    	Enable SNMP CISCO\-TRUSTSEC\-SERVER\-MIB traps
                    	**type**\:  :py:class:`TrustsecServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecServer>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trustsec
                    
                    	Enable SNMP CISCO\-TRUSTSEC\-MIB traps
                    	**type**\:  :py:class:`Trustsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trustsec_interface
                    
                    	Enable SNMP CISCO\-TRUSTSEC\-INTERFACE\-MIB traps
                    	**type**\:  :py:class:`TrustsecInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: trustsec_policy
                    
                    	Enable SNMP CISCO\-TRUSTSEC\-POLICY\-MIB traps
                    	**type**\:  :py:class:`TrustsecPolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecPolicy>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ospfv3
                    
                    	Enable OSPFv3 traps
                    	**type**\:  :py:class:`Ospfv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospfv3>`
                    
                    .. attribute:: ike
                    
                    	Enable IKE traps
                    	**type**\:  :py:class:`Ike <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ike>`
                    
                    .. attribute:: local_auth
                    
                    	Enable SNMP local auth traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: alarms
                    
                    	Enable SNMP alarms traps
                    	**type**\:  :py:class:`Alarms <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Alarms>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: atm
                    
                    	Enable SNMP atm traps
                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Atm>`
                    
                    .. attribute:: authenticate_fail
                    
                    	Enable SNMP 802.11 Authentication Fail Trap
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: auth_framework
                    
                    	
                    	**type**\:  :py:class:`AuthFramework <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.AuthFramework>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bfd
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bgp_conf
                    
                    	
                    	**type**\:  :py:class:`BgpConf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.BgpConf>`
                    
                    .. attribute:: bgp
                    
                    	Enable BGP traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bridge
                    
                    	
                    	**type**\:  :py:class:`Bridge <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Bridge>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: bstun
                    
                    	Enable SNMP BSTUN traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: bulkstat
                    
                    	Enable Data\-Collection\-MIB Collection notifications
                    	**type**\:  :py:class:`Bulkstat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Bulkstat>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: call_home
                    
                    	Enable CISCO\-CALLHOME\-MIB traps
                    	**type**\:  :py:class:`CallHome <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.CallHome>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: c2900
                    
                    	Enable SNMP c2900 traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: c6kxbar
                    
                    	Enable SNMP CISCO\-CAT6K\-CROSSBAR\-MIB traps
                    	**type**\:  :py:class:`C6kxbar <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.C6kxbar>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: casa
                    
                    	Enable SNMP casa traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ccme
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cef
                    
                    	
                    	**type**\:  :py:class:`Cef <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Cef>`
                    
                    .. attribute:: cluster
                    
                    	Enable Cluster traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: channel
                    
                    	Enable SNMP channel traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: chassis
                    
                    	Enable SNMP chassis traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cnpd
                    
                    	Enable NBAR Protocol Discovery traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: config
                    
                    	Enable SNMP config traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: copy_config
                    
                    	Enable SNMP copy\-config traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: config_copy
                    
                    	Enable SNMP config\-copy traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: config_ctid
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: cpu
                    
                    	Allow cpu related traps
                    	**type**\:  :py:class:`Cpu <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Cpu>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: cpu_threshold
                    
                    	Enables CPU threshold notifications
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: csg
                    
                    	Enable SNMP CSG traps
                    	**type**\:  :py:class:`Csg <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Csg>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dial
                    
                    	Enable SNMP dial control traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: director
                    
                    	Enable SNMP Distributed Director traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dlsw
                    
                    	Enable SNMP dlsw traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: deauthenticate
                    
                    	Enable SNMP 802.11 Deauthentication Trap
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: disassociate
                    
                    	Enable SNMP 802.11 Disassociation Trap
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dnis
                    
                    	Enable SNMP DNIS traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dot11_qos
                    
                    	Enable SNMP 802.11 QoS Change Trap
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dot1x
                    
                    	
                    	**type**\:  :py:class:`Dot1x <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Dot1x>`
                    
                    .. attribute:: ds0_busyout
                    
                    	Enable ds0\-busyout traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ds1
                    
                    	Enable SNMP DS1 traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ds1_loopback
                    
                    	Enable ds1\-loopback traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ds3
                    
                    	Enable SNMP DS3 traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dsp
                    
                    	Enable SNMP dsp traps
                    	**type**\:  :py:class:`Dsp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Dsp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: dhcp
                    
                    	Enable SNMP dhcp traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: eigrp
                    
                    	Enable SNMP EIGRP traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: energywise
                    
                    	
                    	**type**\:  :py:class:`Energywise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Energywise>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: entity_
                    
                    	Enable SNMP entity traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: entity_diag
                    
                    	Enable SNMP CISCO\-ENTITY\-DIAG\-MIB traps
                    	**type**\:  :py:class:`EntityDiag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.EntityDiag>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: envmon
                    
                    	Enable SNMP environmental monitor traps
                    	**type**\:  :py:class:`Envmon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Envmon>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: errdisable
                    
                    	Enable SNMP errdisable notifications
                    	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Errdisable>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ether_oam
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ethernet
                    
                    	
                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet>`
                    
                    .. attribute:: event_manager
                    
                    	Enable SNMP Embedded Event Manager traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: firewall
                    
                    	
                    	**type**\:  :py:class:`Firewall <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Firewall>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flash
                    
                    	Enable SNMP FLASH notifications
                    	**type**\:  :py:class:`Flash <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Flash>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: flowmon
                    
                    	Enabel SNMP flowmon notifications
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: flex_links
                    
                    	Enable SNMP FLEX Links traps
                    	**type**\:  :py:class:`FlexLinks <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.FlexLinks>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: frame_relay
                    
                    	Enable SNMP frame\-relay traps
                    	**type**\:  :py:class:`FrameRelay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: fru_ctrl
                    
                    	Enable SNMP entity FRU control traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: gatekeeper
                    
                    	Enable SNMP gatekeeper traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: hsrp
                    
                    	Enable SNMP HSRP traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: icsudsu
                    
                    	Enable SNMP ICSUDSU traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ima
                    
                    	Enable SNMP ATM IMA traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipmobile
                    
                    	Enable SNMP ipmobile traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipmulticast
                    
                    	Enable SNMP ipmulticast traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipsec
                    
                    	Enable IPsec traps
                    	**type**\:  :py:class:`Ipsec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec>`
                    
                    .. attribute:: isakmp
                    
                    	Enable ISAKMP traps traps
                    	**type**\:  :py:class:`Isakmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp>`
                    
                    .. attribute:: isdn
                    
                    	Enable SNMP isdn traps
                    	**type**\:  :py:class:`Isdn <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Isdn>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipsla
                    
                    	Enable IPSLA traps traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: isis
                    
                    	Enable ISIS traps traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: l2tc
                    
                    	Enable SNMP L2 Tunnel Config traps
                    	**type**\:  :py:class:`L2tc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.L2tc>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: l2tun
                    
                    	Enable SNMP L2 tunnel protocol traps
                    	**type**\:  :py:class:`L2tun <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.L2tun>`
                    
                    .. attribute:: license
                    
                    	Enable license traps
                    	**type**\:  :py:class:`License <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.License>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: mac_notification
                    
                    	Enable SNMP MAC Notification traps
                    	**type**\:  :py:class:`MacNotification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.MacNotification>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: mac_notification2
                    
                    	Enable SNMP MAC Notification traps
                    	**type**\:  :py:class:`MacNotification2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.MacNotification2>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: memory
                    
                    	Enable SNMP Memory traps
                    	**type**\:  :py:class:`Memory <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Memory>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: module
                    
                    	Enable SNMP module traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mpls
                    
                    	Enable SNMP MPLS traps
                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Mpls>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: msdp
                    
                    	Enable SNMP MSDP traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mvpn
                    
                    	Enable Multicast Virtual Private Networks traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nhrp
                    
                    	
                    	**type**\:  :py:class:`Nhrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ospf
                    
                    	Enable OSPF traps
                    	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf>`
                    
                    .. attribute:: pim
                    
                    	Enable SNMP PIM traps
                    	**type**\:  :py:class:`Pim <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Pim>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: plogd
                    
                    	Enable SNMP plogd traps
                    	**type**\:  :py:class:`Plogd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Plogd>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: port_security
                    
                    	Enable SNMP port security traps
                    	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.PortSecurity>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: power_ethernet
                    
                    	Enable SNMP power ethernet traps
                    	**type**\:  :py:class:`PowerEthernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.PowerEthernet>`
                    
                    .. attribute:: pppoe
                    
                    	Enable SNMP pppoe traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: pw
                    
                    	
                    	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Pw>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: rep
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: resource_policy
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: rf
                    
                    	Enable all SNMP traps defined in CISCO\-RF\-MIB
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: rogue_ap
                    
                    	Enable SNMP 802.11 Rogue AP Trap
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: rsvp
                    
                    	Enable RSVP flow change traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: rtr
                    
                    	Enable SNMP Response Time Reporter traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: slb
                    
                    	Enable SNMP SLB traps
                    	**type**\:  :py:class:`Slb <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Slb>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: snmp
                    
                    	Enable SNMP traps
                    	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Snmp>`
                    
                    .. attribute:: sonet
                    
                    	Enable SNMP SONET traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: srst
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: srp
                    
                    	Enable SRP protocol traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: stackwise
                    
                    	Enable SNMP stackwise traps
                    	**type**\:  :py:class:`Stackwise <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Stackwise>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: stpx
                    
                    	
                    	**type**\:  :py:class:`Stpx <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Stpx>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: stun
                    
                    	Enable SNMP STUN traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: switch_over
                    
                    	Enable SNMP 802.11 Standby Switch\-over Trap
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: syslog
                    
                    	Enable SNMP syslog traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: transceiver
                    
                    	
                    	**type**\:  :py:class:`Transceiver <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Transceiver>`
                    
                    .. attribute:: tty
                    
                    	Enable TCP connection traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: udld
                    
                    	Enable SNMP CISCO\-UDLDP\-MIB traps
                    	**type**\:  :py:class:`Udld <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Udld>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: vlancreate
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vlandelete
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vlan_mac_limit
                    
                    	Enable SNMP L2 Control VLAN MAC Limit notifications
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vlan_membership
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: voice
                    
                    	Enable SNMP voice traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrfmib
                    
                    	
                    	**type**\:  :py:class:`Vrfmib <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Vrfmib>`
                    
                    .. attribute:: vrrp
                    
                    	Enable SNMP vrrp traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vsimaster
                    
                    	Allow SNMP vsimaster traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vstack
                    
                    	Enable SNMP Smart Install traps
                    	**type**\:  :py:class:`Vstack <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Vstack>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: vtp
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: wlan_wep
                    
                    	Enable SNMP 802.11 WLAN WEP Trap
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: xgcp
                    
                    	Enable XGCP protocol traps
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: wireless
                    
                    	wireless
                    	**type**\:  :py:class:`Wireless <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Wireless>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.SnmpServer.Enable.EnableChoice.Traps, self).__init__()

                        self.yang_name = "traps"
                        self.yang_parent_name = "enable-choice"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("trustsec-sxp", ("trustsec_sxp", Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecSxp)), ("vswitch", ("vswitch", Native.SnmpServer.Enable.EnableChoice.Traps.Vswitch)), ("trustsec-server", ("trustsec_server", Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecServer)), ("trustsec", ("trustsec", Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec)), ("trustsec-interface", ("trustsec_interface", Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface)), ("trustsec-policy", ("trustsec_policy", Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecPolicy)), ("ospfv3", ("ospfv3", Native.SnmpServer.Enable.EnableChoice.Traps.Ospfv3)), ("ike", ("ike", Native.SnmpServer.Enable.EnableChoice.Traps.Ike)), ("alarms", ("alarms", Native.SnmpServer.Enable.EnableChoice.Traps.Alarms)), ("atm", ("atm", Native.SnmpServer.Enable.EnableChoice.Traps.Atm)), ("auth-framework", ("auth_framework", Native.SnmpServer.Enable.EnableChoice.Traps.AuthFramework)), ("bgp-conf", ("bgp_conf", Native.SnmpServer.Enable.EnableChoice.Traps.BgpConf)), ("bridge", ("bridge", Native.SnmpServer.Enable.EnableChoice.Traps.Bridge)), ("bulkstat", ("bulkstat", Native.SnmpServer.Enable.EnableChoice.Traps.Bulkstat)), ("call-home", ("call_home", Native.SnmpServer.Enable.EnableChoice.Traps.CallHome)), ("c6kxbar", ("c6kxbar", Native.SnmpServer.Enable.EnableChoice.Traps.C6kxbar)), ("cef", ("cef", Native.SnmpServer.Enable.EnableChoice.Traps.Cef)), ("cpu", ("cpu", Native.SnmpServer.Enable.EnableChoice.Traps.Cpu)), ("csg", ("csg", Native.SnmpServer.Enable.EnableChoice.Traps.Csg)), ("dot1x", ("dot1x", Native.SnmpServer.Enable.EnableChoice.Traps.Dot1x)), ("dsp", ("dsp", Native.SnmpServer.Enable.EnableChoice.Traps.Dsp)), ("energywise", ("energywise", Native.SnmpServer.Enable.EnableChoice.Traps.Energywise)), ("entity-diag", ("entity_diag", Native.SnmpServer.Enable.EnableChoice.Traps.EntityDiag)), ("envmon", ("envmon", Native.SnmpServer.Enable.EnableChoice.Traps.Envmon)), ("errdisable", ("errdisable", Native.SnmpServer.Enable.EnableChoice.Traps.Errdisable)), ("ethernet", ("ethernet", Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet)), ("firewall", ("firewall", Native.SnmpServer.Enable.EnableChoice.Traps.Firewall)), ("flash", ("flash", Native.SnmpServer.Enable.EnableChoice.Traps.Flash)), ("flex-links", ("flex_links", Native.SnmpServer.Enable.EnableChoice.Traps.FlexLinks)), ("frame-relay", ("frame_relay", Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay)), ("ipsec", ("ipsec", Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec)), ("isakmp", ("isakmp", Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp)), ("isdn", ("isdn", Native.SnmpServer.Enable.EnableChoice.Traps.Isdn)), ("l2tc", ("l2tc", Native.SnmpServer.Enable.EnableChoice.Traps.L2tc)), ("l2tun", ("l2tun", Native.SnmpServer.Enable.EnableChoice.Traps.L2tun)), ("license", ("license", Native.SnmpServer.Enable.EnableChoice.Traps.License)), ("mac-notification", ("mac_notification", Native.SnmpServer.Enable.EnableChoice.Traps.MacNotification)), ("mac-notification2", ("mac_notification2", Native.SnmpServer.Enable.EnableChoice.Traps.MacNotification2)), ("memory", ("memory", Native.SnmpServer.Enable.EnableChoice.Traps.Memory)), ("mpls", ("mpls", Native.SnmpServer.Enable.EnableChoice.Traps.Mpls)), ("nhrp", ("nhrp", Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp)), ("ospf", ("ospf", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf)), ("pim", ("pim", Native.SnmpServer.Enable.EnableChoice.Traps.Pim)), ("plogd", ("plogd", Native.SnmpServer.Enable.EnableChoice.Traps.Plogd)), ("port-security", ("port_security", Native.SnmpServer.Enable.EnableChoice.Traps.PortSecurity)), ("power-ethernet", ("power_ethernet", Native.SnmpServer.Enable.EnableChoice.Traps.PowerEthernet)), ("pw", ("pw", Native.SnmpServer.Enable.EnableChoice.Traps.Pw)), ("slb", ("slb", Native.SnmpServer.Enable.EnableChoice.Traps.Slb)), ("snmp", ("snmp", Native.SnmpServer.Enable.EnableChoice.Traps.Snmp)), ("stackwise", ("stackwise", Native.SnmpServer.Enable.EnableChoice.Traps.Stackwise)), ("stpx", ("stpx", Native.SnmpServer.Enable.EnableChoice.Traps.Stpx)), ("transceiver", ("transceiver", Native.SnmpServer.Enable.EnableChoice.Traps.Transceiver)), ("udld", ("udld", Native.SnmpServer.Enable.EnableChoice.Traps.Udld)), ("vrfmib", ("vrfmib", Native.SnmpServer.Enable.EnableChoice.Traps.Vrfmib)), ("vstack", ("vstack", Native.SnmpServer.Enable.EnableChoice.Traps.Vstack)), ("wireless", ("wireless", Native.SnmpServer.Enable.EnableChoice.Traps.Wireless))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('aaa_server', (YLeaf(YType.empty, 'aaa_server'), ['Empty'])),
                            ('local_auth', (YLeaf(YType.empty, 'local-auth'), ['Empty'])),
                            ('authenticate_fail', (YLeaf(YType.empty, 'authenticate-fail'), ['Empty'])),
                            ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                            ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                            ('bstun', (YLeaf(YType.empty, 'bstun'), ['Empty'])),
                            ('c2900', (YLeaf(YType.empty, 'c2900'), ['Empty'])),
                            ('casa', (YLeaf(YType.empty, 'casa'), ['Empty'])),
                            ('ccme', (YLeaf(YType.empty, 'ccme'), ['Empty'])),
                            ('cluster', (YLeaf(YType.empty, 'cluster'), ['Empty'])),
                            ('channel', (YLeaf(YType.empty, 'channel'), ['Empty'])),
                            ('chassis', (YLeaf(YType.empty, 'chassis'), ['Empty'])),
                            ('cnpd', (YLeaf(YType.empty, 'cnpd'), ['Empty'])),
                            ('config', (YLeaf(YType.empty, 'config'), ['Empty'])),
                            ('copy_config', (YLeaf(YType.empty, 'copy-config'), ['Empty'])),
                            ('config_copy', (YLeaf(YType.empty, 'config-copy'), ['Empty'])),
                            ('config_ctid', (YLeaf(YType.empty, 'config-ctid'), ['Empty'])),
                            ('cpu_threshold', (YLeaf(YType.empty, 'cpu_threshold'), ['Empty'])),
                            ('dial', (YLeaf(YType.empty, 'dial'), ['Empty'])),
                            ('director', (YLeaf(YType.empty, 'director'), ['Empty'])),
                            ('dlsw', (YLeaf(YType.empty, 'dlsw'), ['Empty'])),
                            ('deauthenticate', (YLeaf(YType.empty, 'deauthenticate'), ['Empty'])),
                            ('disassociate', (YLeaf(YType.empty, 'disassociate'), ['Empty'])),
                            ('dnis', (YLeaf(YType.empty, 'dnis'), ['Empty'])),
                            ('dot11_qos', (YLeaf(YType.empty, 'dot11-qos'), ['Empty'])),
                            ('ds0_busyout', (YLeaf(YType.empty, 'ds0-busyout'), ['Empty'])),
                            ('ds1', (YLeaf(YType.empty, 'ds1'), ['Empty'])),
                            ('ds1_loopback', (YLeaf(YType.empty, 'ds1-loopback'), ['Empty'])),
                            ('ds3', (YLeaf(YType.empty, 'ds3'), ['Empty'])),
                            ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                            ('eigrp', (YLeaf(YType.empty, 'eigrp'), ['Empty'])),
                            ('entity_', (YLeaf(YType.empty, 'entity'), ['Empty'])),
                            ('ether_oam', (YLeaf(YType.empty, 'ether-oam'), ['Empty'])),
                            ('event_manager', (YLeaf(YType.empty, 'event-manager'), ['Empty'])),
                            ('flowmon', (YLeaf(YType.empty, 'flowmon'), ['Empty'])),
                            ('fru_ctrl', (YLeaf(YType.empty, 'fru-ctrl'), ['Empty'])),
                            ('gatekeeper', (YLeaf(YType.empty, 'gatekeeper'), ['Empty'])),
                            ('hsrp', (YLeaf(YType.empty, 'hsrp'), ['Empty'])),
                            ('icsudsu', (YLeaf(YType.empty, 'icsudsu'), ['Empty'])),
                            ('ima', (YLeaf(YType.empty, 'ima'), ['Empty'])),
                            ('ipmobile', (YLeaf(YType.empty, 'ipmobile'), ['Empty'])),
                            ('ipmulticast', (YLeaf(YType.empty, 'ipmulticast'), ['Empty'])),
                            ('ipsla', (YLeaf(YType.empty, 'ipsla'), ['Empty'])),
                            ('isis', (YLeaf(YType.empty, 'isis'), ['Empty'])),
                            ('module', (YLeaf(YType.empty, 'module'), ['Empty'])),
                            ('msdp', (YLeaf(YType.empty, 'msdp'), ['Empty'])),
                            ('mvpn', (YLeaf(YType.empty, 'mvpn'), ['Empty'])),
                            ('pppoe', (YLeaf(YType.empty, 'pppoe'), ['Empty'])),
                            ('rep', (YLeaf(YType.empty, 'rep'), ['Empty'])),
                            ('resource_policy', (YLeaf(YType.empty, 'resource-policy'), ['Empty'])),
                            ('rf', (YLeaf(YType.empty, 'rf'), ['Empty'])),
                            ('rogue_ap', (YLeaf(YType.empty, 'rogue-ap'), ['Empty'])),
                            ('rsvp', (YLeaf(YType.empty, 'rsvp'), ['Empty'])),
                            ('rtr', (YLeaf(YType.empty, 'rtr'), ['Empty'])),
                            ('sonet', (YLeaf(YType.empty, 'sonet'), ['Empty'])),
                            ('srst', (YLeaf(YType.empty, 'srst'), ['Empty'])),
                            ('srp', (YLeaf(YType.empty, 'srp'), ['Empty'])),
                            ('stun', (YLeaf(YType.empty, 'stun'), ['Empty'])),
                            ('switch_over', (YLeaf(YType.empty, 'switch-over'), ['Empty'])),
                            ('syslog', (YLeaf(YType.empty, 'syslog'), ['Empty'])),
                            ('tty', (YLeaf(YType.empty, 'tty'), ['Empty'])),
                            ('vlancreate', (YLeaf(YType.empty, 'vlancreate'), ['Empty'])),
                            ('vlandelete', (YLeaf(YType.empty, 'vlandelete'), ['Empty'])),
                            ('vlan_mac_limit', (YLeaf(YType.empty, 'vlan-mac-limit'), ['Empty'])),
                            ('vlan_membership', (YLeaf(YType.empty, 'vlan-membership'), ['Empty'])),
                            ('voice', (YLeaf(YType.empty, 'voice'), ['Empty'])),
                            ('vrrp', (YLeaf(YType.empty, 'vrrp'), ['Empty'])),
                            ('vsimaster', (YLeaf(YType.empty, 'vsimaster'), ['Empty'])),
                            ('vtp', (YLeaf(YType.empty, 'vtp'), ['Empty'])),
                            ('wlan_wep', (YLeaf(YType.empty, 'wlan-wep'), ['Empty'])),
                            ('xgcp', (YLeaf(YType.empty, 'xgcp'), ['Empty'])),
                        ])
                        self.aaa_server = None
                        self.local_auth = None
                        self.authenticate_fail = None
                        self.bfd = None
                        self.bgp = None
                        self.bstun = None
                        self.c2900 = None
                        self.casa = None
                        self.ccme = None
                        self.cluster = None
                        self.channel = None
                        self.chassis = None
                        self.cnpd = None
                        self.config = None
                        self.copy_config = None
                        self.config_copy = None
                        self.config_ctid = None
                        self.cpu_threshold = None
                        self.dial = None
                        self.director = None
                        self.dlsw = None
                        self.deauthenticate = None
                        self.disassociate = None
                        self.dnis = None
                        self.dot11_qos = None
                        self.ds0_busyout = None
                        self.ds1 = None
                        self.ds1_loopback = None
                        self.ds3 = None
                        self.dhcp = None
                        self.eigrp = None
                        self.entity_ = None
                        self.ether_oam = None
                        self.event_manager = None
                        self.flowmon = None
                        self.fru_ctrl = None
                        self.gatekeeper = None
                        self.hsrp = None
                        self.icsudsu = None
                        self.ima = None
                        self.ipmobile = None
                        self.ipmulticast = None
                        self.ipsla = None
                        self.isis = None
                        self.module = None
                        self.msdp = None
                        self.mvpn = None
                        self.pppoe = None
                        self.rep = None
                        self.resource_policy = None
                        self.rf = None
                        self.rogue_ap = None
                        self.rsvp = None
                        self.rtr = None
                        self.sonet = None
                        self.srst = None
                        self.srp = None
                        self.stun = None
                        self.switch_over = None
                        self.syslog = None
                        self.tty = None
                        self.vlancreate = None
                        self.vlandelete = None
                        self.vlan_mac_limit = None
                        self.vlan_membership = None
                        self.voice = None
                        self.vrrp = None
                        self.vsimaster = None
                        self.vtp = None
                        self.wlan_wep = None
                        self.xgcp = None

                        self.trustsec_sxp = None
                        self._children_name_map["trustsec_sxp"] = "trustsec-sxp"

                        self.vswitch = None
                        self._children_name_map["vswitch"] = "vswitch"

                        self.trustsec_server = None
                        self._children_name_map["trustsec_server"] = "trustsec-server"

                        self.trustsec = None
                        self._children_name_map["trustsec"] = "trustsec"

                        self.trustsec_interface = None
                        self._children_name_map["trustsec_interface"] = "trustsec-interface"

                        self.trustsec_policy = None
                        self._children_name_map["trustsec_policy"] = "trustsec-policy"

                        self.ospfv3 = Native.SnmpServer.Enable.EnableChoice.Traps.Ospfv3()
                        self.ospfv3.parent = self
                        self._children_name_map["ospfv3"] = "ospfv3"

                        self.ike = Native.SnmpServer.Enable.EnableChoice.Traps.Ike()
                        self.ike.parent = self
                        self._children_name_map["ike"] = "ike"

                        self.alarms = None
                        self._children_name_map["alarms"] = "alarms"

                        self.atm = Native.SnmpServer.Enable.EnableChoice.Traps.Atm()
                        self.atm.parent = self
                        self._children_name_map["atm"] = "atm"

                        self.auth_framework = None
                        self._children_name_map["auth_framework"] = "auth-framework"

                        self.bgp_conf = Native.SnmpServer.Enable.EnableChoice.Traps.BgpConf()
                        self.bgp_conf.parent = self
                        self._children_name_map["bgp_conf"] = "bgp-conf"

                        self.bridge = None
                        self._children_name_map["bridge"] = "bridge"

                        self.bulkstat = None
                        self._children_name_map["bulkstat"] = "bulkstat"

                        self.call_home = None
                        self._children_name_map["call_home"] = "call-home"

                        self.c6kxbar = None
                        self._children_name_map["c6kxbar"] = "c6kxbar"

                        self.cef = Native.SnmpServer.Enable.EnableChoice.Traps.Cef()
                        self.cef.parent = self
                        self._children_name_map["cef"] = "cef"

                        self.cpu = None
                        self._children_name_map["cpu"] = "cpu"

                        self.csg = None
                        self._children_name_map["csg"] = "csg"

                        self.dot1x = Native.SnmpServer.Enable.EnableChoice.Traps.Dot1x()
                        self.dot1x.parent = self
                        self._children_name_map["dot1x"] = "dot1x"

                        self.dsp = None
                        self._children_name_map["dsp"] = "dsp"

                        self.energywise = None
                        self._children_name_map["energywise"] = "energywise"

                        self.entity_diag = None
                        self._children_name_map["entity_diag"] = "entity-diag"

                        self.envmon = None
                        self._children_name_map["envmon"] = "envmon"

                        self.errdisable = None
                        self._children_name_map["errdisable"] = "errdisable"

                        self.ethernet = Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet()
                        self.ethernet.parent = self
                        self._children_name_map["ethernet"] = "ethernet"

                        self.firewall = None
                        self._children_name_map["firewall"] = "firewall"

                        self.flash = None
                        self._children_name_map["flash"] = "flash"

                        self.flex_links = None
                        self._children_name_map["flex_links"] = "flex-links"

                        self.frame_relay = None
                        self._children_name_map["frame_relay"] = "frame-relay"

                        self.ipsec = Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec()
                        self.ipsec.parent = self
                        self._children_name_map["ipsec"] = "ipsec"

                        self.isakmp = Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp()
                        self.isakmp.parent = self
                        self._children_name_map["isakmp"] = "isakmp"

                        self.isdn = None
                        self._children_name_map["isdn"] = "isdn"

                        self.l2tc = None
                        self._children_name_map["l2tc"] = "l2tc"

                        self.l2tun = Native.SnmpServer.Enable.EnableChoice.Traps.L2tun()
                        self.l2tun.parent = self
                        self._children_name_map["l2tun"] = "l2tun"

                        self.license = None
                        self._children_name_map["license"] = "license"

                        self.mac_notification = None
                        self._children_name_map["mac_notification"] = "mac-notification"

                        self.mac_notification2 = None
                        self._children_name_map["mac_notification2"] = "mac-notification2"

                        self.memory = None
                        self._children_name_map["memory"] = "memory"

                        self.mpls = None
                        self._children_name_map["mpls"] = "mpls"

                        self.nhrp = None
                        self._children_name_map["nhrp"] = "nhrp"

                        self.ospf = Native.SnmpServer.Enable.EnableChoice.Traps.Ospf()
                        self.ospf.parent = self
                        self._children_name_map["ospf"] = "ospf"

                        self.pim = None
                        self._children_name_map["pim"] = "pim"

                        self.plogd = None
                        self._children_name_map["plogd"] = "plogd"

                        self.port_security = None
                        self._children_name_map["port_security"] = "port-security"

                        self.power_ethernet = Native.SnmpServer.Enable.EnableChoice.Traps.PowerEthernet()
                        self.power_ethernet.parent = self
                        self._children_name_map["power_ethernet"] = "power-ethernet"

                        self.pw = None
                        self._children_name_map["pw"] = "pw"

                        self.slb = None
                        self._children_name_map["slb"] = "slb"

                        self.snmp = Native.SnmpServer.Enable.EnableChoice.Traps.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"

                        self.stackwise = None
                        self._children_name_map["stackwise"] = "stackwise"

                        self.stpx = None
                        self._children_name_map["stpx"] = "stpx"

                        self.transceiver = Native.SnmpServer.Enable.EnableChoice.Traps.Transceiver()
                        self.transceiver.parent = self
                        self._children_name_map["transceiver"] = "transceiver"

                        self.udld = None
                        self._children_name_map["udld"] = "udld"

                        self.vrfmib = Native.SnmpServer.Enable.EnableChoice.Traps.Vrfmib()
                        self.vrfmib.parent = self
                        self._children_name_map["vrfmib"] = "vrfmib"

                        self.vstack = None
                        self._children_name_map["vstack"] = "vstack"

                        self.wireless = None
                        self._children_name_map["wireless"] = "wireless"
                        self._segment_path = lambda: "traps"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps, [u'aaa_server', u'local_auth', u'authenticate_fail', u'bfd', u'bgp', u'bstun', u'c2900', u'casa', u'ccme', u'cluster', u'channel', u'chassis', u'cnpd', u'config', u'copy_config', u'config_copy', u'config_ctid', u'cpu_threshold', u'dial', u'director', u'dlsw', u'deauthenticate', u'disassociate', u'dnis', u'dot11_qos', u'ds0_busyout', u'ds1', u'ds1_loopback', u'ds3', u'dhcp', u'eigrp', u'entity_', u'ether_oam', u'event_manager', u'flowmon', u'fru_ctrl', u'gatekeeper', u'hsrp', u'icsudsu', u'ima', u'ipmobile', u'ipmulticast', u'ipsla', u'isis', u'module', u'msdp', u'mvpn', u'pppoe', u'rep', u'resource_policy', u'rf', u'rogue_ap', u'rsvp', u'rtr', u'sonet', u'srst', u'srp', u'stun', u'switch_over', u'syslog', u'tty', u'vlancreate', u'vlandelete', u'vlan_mac_limit', u'vlan_membership', u'voice', u'vrrp', u'vsimaster', u'vtp', u'wlan_wep', u'xgcp'], name, value)


                    class TrustsecSxp(Entity):
                        """
                        Enable SNMP CISCO\-TRUSTSEC\-SXP\-MIB traps
                        
                        .. attribute:: binding_conflict
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: binding_err
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: binding_expn_fail
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: conn_config_err
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: conn_down
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: conn_srcaddr_err
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: conn_up
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: msg_parse_err
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: oper_nodeid_change
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecSxp, self).__init__()

                            self.yang_name = "trustsec-sxp"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('binding_conflict', (YLeaf(YType.empty, 'binding-conflict'), ['Empty'])),
                                ('binding_err', (YLeaf(YType.empty, 'binding-err'), ['Empty'])),
                                ('binding_expn_fail', (YLeaf(YType.empty, 'binding-expn-fail'), ['Empty'])),
                                ('conn_config_err', (YLeaf(YType.empty, 'conn-config-err'), ['Empty'])),
                                ('conn_down', (YLeaf(YType.empty, 'conn-down'), ['Empty'])),
                                ('conn_srcaddr_err', (YLeaf(YType.empty, 'conn-srcaddr-err'), ['Empty'])),
                                ('conn_up', (YLeaf(YType.empty, 'conn-up'), ['Empty'])),
                                ('msg_parse_err', (YLeaf(YType.empty, 'msg-parse-err'), ['Empty'])),
                                ('oper_nodeid_change', (YLeaf(YType.empty, 'oper-nodeid-change'), ['Empty'])),
                            ])
                            self.binding_conflict = None
                            self.binding_err = None
                            self.binding_expn_fail = None
                            self.conn_config_err = None
                            self.conn_down = None
                            self.conn_srcaddr_err = None
                            self.conn_up = None
                            self.msg_parse_err = None
                            self.oper_nodeid_change = None
                            self._segment_path = lambda: "trustsec-sxp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecSxp, [u'binding_conflict', u'binding_err', u'binding_expn_fail', u'conn_config_err', u'conn_down', u'conn_srcaddr_err', u'conn_up', u'msg_parse_err', u'oper_nodeid_change'], name, value)


                    class Vswitch(Entity):
                        """
                        Enable SNMP Virtual Switch notifications
                        
                        .. attribute:: dual_active
                        
                        	Enable SNMP Virtual Switch (Dual Active) notification
                        	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Vswitch.DualActive>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Vswitch, self).__init__()

                            self.yang_name = "vswitch"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dual-active", ("dual_active", Native.SnmpServer.Enable.EnableChoice.Traps.Vswitch.DualActive))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.dual_active = None
                            self._children_name_map["dual_active"] = "dual-active"
                            self._segment_path = lambda: "vswitch"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Vswitch, [], name, value)


                        class DualActive(Entity):
                            """
                            Enable SNMP Virtual Switch (Dual Active) notification
                            
                            .. attribute:: vsl
                            
                            	Enable SNMP Virtual Switch Link (VSL) notification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Vswitch.DualActive, self).__init__()

                                self.yang_name = "dual-active"
                                self.yang_parent_name = "vswitch"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('vsl', (YLeaf(YType.empty, 'vsl'), ['Empty'])),
                                ])
                                self.vsl = None
                                self._segment_path = lambda: "dual-active"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/vswitch/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Vswitch.DualActive, [u'vsl'], name, value)


                    class TrustsecServer(Entity):
                        """
                        Enable SNMP CISCO\-TRUSTSEC\-SERVER\-MIB traps
                        
                        .. attribute:: radius_server
                        
                        	Enable ctsvNoRadiusServerNotif notification
                        	**type**\:  :py:class:`RadiusServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecServer.RadiusServer>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecServer, self).__init__()

                            self.yang_name = "trustsec-server"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("radius-server", ("radius_server", Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecServer.RadiusServer))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.radius_server = None
                            self._children_name_map["radius_server"] = "radius-server"
                            self._segment_path = lambda: "trustsec-server"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecServer, [], name, value)


                        class RadiusServer(Entity):
                            """
                            Enable ctsvNoRadiusServerNotif notification
                            
                            .. attribute:: provision_secret
                            
                            	Enable ctsvNoProvisionSecretNotif notification
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecServer.RadiusServer, self).__init__()

                                self.yang_name = "radius-server"
                                self.yang_parent_name = "trustsec-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('provision_secret', (YLeaf(YType.empty, 'provision-secret'), ['Empty'])),
                                ])
                                self.provision_secret = None
                                self._segment_path = lambda: "radius-server"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/trustsec-server/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecServer.RadiusServer, [u'provision_secret'], name, value)


                    class Trustsec(Entity):
                        """
                        Enable SNMP CISCO\-TRUSTSEC\-MIB traps
                        
                        .. attribute:: authz_file_error
                        
                        	Enable ctsAuthzCacheFileErrNotif notifications
                        	**type**\:  :py:class:`AuthzFileError <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec, self).__init__()

                            self.yang_name = "trustsec"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("authz-file-error", ("authz_file_error", Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.authz_file_error = None
                            self._children_name_map["authz_file_error"] = "authz-file-error"
                            self._segment_path = lambda: "trustsec"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec, [], name, value)


                        class AuthzFileError(Entity):
                            """
                            Enable ctsAuthzCacheFileErrNotif notifications
                            
                            .. attribute:: cache_file_error
                            
                            	Enable ctsCacheFileAccessErrNotif notifications
                            	**type**\:  :py:class:`CacheFileError <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError, self).__init__()

                                self.yang_name = "authz-file-error"
                                self.yang_parent_name = "trustsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cache-file-error", ("cache_file_error", Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.cache_file_error = None
                                self._children_name_map["cache_file_error"] = "cache-file-error"
                                self._segment_path = lambda: "authz-file-error"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/trustsec/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError, [], name, value)


                            class CacheFileError(Entity):
                                """
                                Enable ctsCacheFileAccessErrNotif notifications
                                
                                .. attribute:: keystore_file_error
                                
                                	Enable ctsSwKeystoreFileErrNotif notifications
                                	**type**\:  :py:class:`KeystoreFileError <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError, self).__init__()

                                    self.yang_name = "cache-file-error"
                                    self.yang_parent_name = "authz-file-error"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("keystore-file-error", ("keystore_file_error", Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.keystore_file_error = None
                                    self._children_name_map["keystore_file_error"] = "keystore-file-error"
                                    self._segment_path = lambda: "cache-file-error"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/trustsec/authz-file-error/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError, [], name, value)


                                class KeystoreFileError(Entity):
                                    """
                                    Enable ctsSwKeystoreFileErrNotif notifications
                                    
                                    .. attribute:: keystore_sync_fail
                                    
                                    	Enable ctsSwKeystoreSyncFailNotif notifications
                                    	**type**\:  :py:class:`KeystoreSyncFail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError.KeystoreSyncFail>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-snmp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError, self).__init__()

                                        self.yang_name = "keystore-file-error"
                                        self.yang_parent_name = "cache-file-error"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("keystore-sync-fail", ("keystore_sync_fail", Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError.KeystoreSyncFail))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.keystore_sync_fail = None
                                        self._children_name_map["keystore_sync_fail"] = "keystore-sync-fail"
                                        self._segment_path = lambda: "keystore-file-error"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/trustsec/authz-file-error/cache-file-error/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError, [], name, value)


                                    class KeystoreSyncFail(Entity):
                                        """
                                        Enable ctsSwKeystoreSyncFailNotif notifications
                                        
                                        .. attribute:: random_number_fail
                                        
                                        	Enable ctsSapRandonNumberFailNotif notifications
                                        	**type**\:  :py:class:`RandomNumberFail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError.KeystoreSyncFail.RandomNumberFail>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-snmp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError.KeystoreSyncFail, self).__init__()

                                            self.yang_name = "keystore-sync-fail"
                                            self.yang_parent_name = "keystore-file-error"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("random-number-fail", ("random_number_fail", Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError.KeystoreSyncFail.RandomNumberFail))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.random_number_fail = None
                                            self._children_name_map["random_number_fail"] = "random-number-fail"
                                            self._segment_path = lambda: "keystore-sync-fail"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/trustsec/authz-file-error/cache-file-error/keystore-file-error/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError.KeystoreSyncFail, [], name, value)


                                        class RandomNumberFail(Entity):
                                            """
                                            Enable ctsSapRandonNumberFailNotif notifications
                                            
                                            .. attribute:: src_entropy_fail
                                            
                                            	Enable ctsSrcEntropyFailNotif notifications
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-snmp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError.KeystoreSyncFail.RandomNumberFail, self).__init__()

                                                self.yang_name = "random-number-fail"
                                                self.yang_parent_name = "keystore-sync-fail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('src_entropy_fail', (YLeaf(YType.empty, 'src-entropy-fail'), ['Empty'])),
                                                ])
                                                self.src_entropy_fail = None
                                                self._segment_path = lambda: "random-number-fail"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/trustsec/authz-file-error/cache-file-error/keystore-file-error/keystore-sync-fail/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Trustsec.AuthzFileError.CacheFileError.KeystoreFileError.KeystoreSyncFail.RandomNumberFail, [u'src_entropy_fail'], name, value)


                    class TrustsecInterface(Entity):
                        """
                        Enable SNMP CISCO\-TRUSTSEC\-INTERFACE\-MIB traps
                        
                        .. attribute:: unauthorized
                        
                        	Enable ctsiIfUnauthorizedNotifEnable trap
                        	**type**\:  :py:class:`Unauthorized <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface, self).__init__()

                            self.yang_name = "trustsec-interface"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("unauthorized", ("unauthorized", Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.unauthorized = None
                            self._children_name_map["unauthorized"] = "unauthorized"
                            self._segment_path = lambda: "trustsec-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface, [], name, value)


                        class Unauthorized(Entity):
                            """
                            Enable ctsiIfUnauthorizedNotifEnable trap
                            
                            .. attribute:: sap_fail
                            
                            	Enable ctsiIfSapNegotiationFailNotif trap
                            	**type**\:  :py:class:`SapFail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized, self).__init__()

                                self.yang_name = "unauthorized"
                                self.yang_parent_name = "trustsec-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sap-fail", ("sap_fail", Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.sap_fail = None
                                self._children_name_map["sap_fail"] = "sap-fail"
                                self._segment_path = lambda: "unauthorized"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/trustsec-interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized, [], name, value)


                            class SapFail(Entity):
                                """
                                Enable ctsiIfSapNegotiationFailNotif trap
                                
                                .. attribute:: authc_fail
                                
                                	Enable ctsiIfAuthenticationFailNotif trap
                                	**type**\:  :py:class:`AuthcFail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail.AuthcFail>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail, self).__init__()

                                    self.yang_name = "sap-fail"
                                    self.yang_parent_name = "unauthorized"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("authc-fail", ("authc_fail", Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail.AuthcFail))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.authc_fail = None
                                    self._children_name_map["authc_fail"] = "authc-fail"
                                    self._segment_path = lambda: "sap-fail"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/trustsec-interface/unauthorized/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail, [], name, value)


                                class AuthcFail(Entity):
                                    """
                                    Enable ctsiIfAuthenticationFailNotif trap
                                    
                                    .. attribute:: supplicant_fail
                                    
                                    	Enable ctsiIfAddSupplicantFailNotif trap
                                    	**type**\:  :py:class:`SupplicantFail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail.AuthcFail.SupplicantFail>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-snmp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail.AuthcFail, self).__init__()

                                        self.yang_name = "authc-fail"
                                        self.yang_parent_name = "sap-fail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("supplicant-fail", ("supplicant_fail", Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail.AuthcFail.SupplicantFail))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.supplicant_fail = None
                                        self._children_name_map["supplicant_fail"] = "supplicant-fail"
                                        self._segment_path = lambda: "authc-fail"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/trustsec-interface/unauthorized/sap-fail/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail.AuthcFail, [], name, value)


                                    class SupplicantFail(Entity):
                                        """
                                        Enable ctsiIfAddSupplicantFailNotif trap
                                        
                                        .. attribute:: authz_fail
                                        
                                        	Enable ctsiAuthorizationFailNotif trap
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-snmp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail.AuthcFail.SupplicantFail, self).__init__()

                                            self.yang_name = "supplicant-fail"
                                            self.yang_parent_name = "authc-fail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('authz_fail', (YLeaf(YType.empty, 'authz-fail'), ['Empty'])),
                                            ])
                                            self.authz_fail = None
                                            self._segment_path = lambda: "supplicant-fail"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/trustsec-interface/unauthorized/sap-fail/authc-fail/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecInterface.Unauthorized.SapFail.AuthcFail.SupplicantFail, [u'authz_fail'], name, value)


                    class TrustsecPolicy(Entity):
                        """
                        Enable SNMP CISCO\-TRUSTSEC\-POLICY\-MIB traps
                        
                        .. attribute:: peer_policy_updated
                        
                        	Enable ctspPeerPolicyUpdatedNotif notifications
                        	**type**\:  :py:class:`PeerPolicyUpdated <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecPolicy.PeerPolicyUpdated>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecPolicy, self).__init__()

                            self.yang_name = "trustsec-policy"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-policy-updated", ("peer_policy_updated", Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecPolicy.PeerPolicyUpdated))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.peer_policy_updated = None
                            self._children_name_map["peer_policy_updated"] = "peer-policy-updated"
                            self._segment_path = lambda: "trustsec-policy"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecPolicy, [], name, value)


                        class PeerPolicyUpdated(Entity):
                            """
                            Enable ctspPeerPolicyUpdatedNotif notifications
                            
                            .. attribute:: authz_sgacl_fail
                            
                            	Enable ctspAuthorizationSgaclFailNotif notifications
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecPolicy.PeerPolicyUpdated, self).__init__()

                                self.yang_name = "peer-policy-updated"
                                self.yang_parent_name = "trustsec-policy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('authz_sgacl_fail', (YLeaf(YType.empty, 'authz-sgacl-fail'), ['Empty'])),
                                ])
                                self.authz_sgacl_fail = None
                                self._segment_path = lambda: "peer-policy-updated"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/trustsec-policy/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.TrustsecPolicy.PeerPolicyUpdated, [u'authz_sgacl_fail'], name, value)


                    class Ospfv3(Entity):
                        """
                        Enable OSPFv3 traps
                        
                        .. attribute:: state_change
                        
                        	State change traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: errors
                        
                        	Error traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospfv3, self).__init__()

                            self.yang_name = "ospfv3"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('state_change', (YLeaf(YType.empty, 'state-change'), ['Empty'])),
                                ('errors', (YLeaf(YType.empty, 'errors'), ['Empty'])),
                            ])
                            self.state_change = None
                            self.errors = None
                            self._segment_path = lambda: "ospfv3"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ospfv3, [u'state_change', u'errors'], name, value)


                    class Ike(Entity):
                        """
                        Enable IKE traps
                        
                        .. attribute:: policy
                        
                        	Enable IKE Policy traps
                        	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ike.Policy>`
                        
                        .. attribute:: tunnel
                        
                        	Enable IKE Tunnel traps
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ike.Tunnel>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Ike, self).__init__()

                            self.yang_name = "ike"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("policy", ("policy", Native.SnmpServer.Enable.EnableChoice.Traps.Ike.Policy)), ("tunnel", ("tunnel", Native.SnmpServer.Enable.EnableChoice.Traps.Ike.Tunnel))])
                            self._leafs = OrderedDict()

                            self.policy = Native.SnmpServer.Enable.EnableChoice.Traps.Ike.Policy()
                            self.policy.parent = self
                            self._children_name_map["policy"] = "policy"

                            self.tunnel = Native.SnmpServer.Enable.EnableChoice.Traps.Ike.Tunnel()
                            self.tunnel.parent = self
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "ike"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ike, [], name, value)


                        class Policy(Entity):
                            """
                            Enable IKE Policy traps
                            
                            .. attribute:: add
                            
                            	Enable IKE Policy add trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: delete
                            
                            	Enable IKE Policy delete trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Ike.Policy, self).__init__()

                                self.yang_name = "policy"
                                self.yang_parent_name = "ike"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('add', (YLeaf(YType.empty, 'add'), ['Empty'])),
                                    ('delete', (YLeaf(YType.empty, 'delete'), ['Empty'])),
                                ])
                                self.add = None
                                self.delete = None
                                self._segment_path = lambda: "policy"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ike/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ike.Policy, [u'add', u'delete'], name, value)


                        class Tunnel(Entity):
                            """
                            Enable IKE Tunnel traps
                            
                            .. attribute:: start
                            
                            	Enable IKE Tunnel start trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: stop
                            
                            	Enable IKE Tunnel stop trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Ike.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "ike"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('start', (YLeaf(YType.empty, 'start'), ['Empty'])),
                                    ('stop', (YLeaf(YType.empty, 'stop'), ['Empty'])),
                                ])
                                self.start = None
                                self.stop = None
                                self._segment_path = lambda: "tunnel"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ike/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ike.Tunnel, [u'start', u'stop'], name, value)


                    class Alarms(Entity):
                        """
                        Enable SNMP alarms traps
                        
                        .. attribute:: alarm_type
                        
                        	
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 1..4
                        
                        		**type**\:  :py:class:`AlarmType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Alarms.AlarmType>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Alarms, self).__init__()

                            self.yang_name = "alarms"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('alarm_type', (YLeaf(YType.str, 'alarm-type'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'SnmpServer.Enable.EnableChoice.Traps.Alarms.AlarmType')])),
                            ])
                            self.alarm_type = None
                            self._segment_path = lambda: "alarms"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Alarms, [u'alarm_type'], name, value)

                        class AlarmType(Enum):
                            """
                            AlarmType (Enum Class)

                            .. data:: critical = 0

                            .. data:: informational = 1

                            .. data:: major = 2

                            .. data:: minor = 3

                            """

                            critical = Enum.YLeaf(0, "critical")

                            informational = Enum.YLeaf(1, "informational")

                            major = Enum.YLeaf(2, "major")

                            minor = Enum.YLeaf(3, "minor")



                    class Atm(Entity):
                        """
                        Enable SNMP atm traps
                        
                        .. attribute:: pvc
                        
                        	Enable SNMP atm pvc traps
                        	**type**\:  :py:class:`Pvc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: subif
                        
                        	Enable SNMP atm subinterface traps
                        	**type**\:  :py:class:`Subif <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Subif>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Atm, self).__init__()

                            self.yang_name = "atm"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pvc", ("pvc", Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc)), ("subif", ("subif", Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Subif))])
                            self._leafs = OrderedDict()

                            self.pvc = None
                            self._children_name_map["pvc"] = "pvc"

                            self.subif = None
                            self._children_name_map["subif"] = "subif"
                            self._segment_path = lambda: "atm"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Atm, [], name, value)


                        class Pvc(Entity):
                            """
                            Enable SNMP atm pvc traps
                            
                            .. attribute:: extension
                            
                            	Enable SNMP atm pvc extension traps
                            	**type**\:  :py:class:`Extension <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension>`
                            
                            .. attribute:: interval
                            
                            	minimum period between successive traps
                            	**type**\: int
                            
                            	**range:** 1..3600
                            
                            .. attribute:: fail_interval
                            
                            	minimum period for storing the failed timestamp
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc, self).__init__()

                                self.yang_name = "pvc"
                                self.yang_parent_name = "atm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("extension", ("extension", Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ('fail_interval', (YLeaf(YType.uint16, 'fail-interval'), ['int'])),
                                ])
                                self.interval = None
                                self.fail_interval = None

                                self.extension = Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension()
                                self.extension.parent = self
                                self._children_name_map["extension"] = "extension"
                                self._segment_path = lambda: "pvc"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/atm/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc, [u'interval', u'fail_interval'], name, value)


                            class Extension(Entity):
                                """
                                Enable SNMP atm pvc extension traps
                                
                                .. attribute:: down
                                
                                	Enable SNMP atm pvc extended down trap
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: up
                                
                                	Enable SNMP atm pvc extended up traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: mibversion
                                
                                	Extension MIB version to be used
                                	**type**\:  :py:class:`Mibversion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Mibversion>`
                                
                                .. attribute:: oam
                                
                                	Enable SNMP atm pvc extended oam trap
                                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Oam>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension, self).__init__()

                                    self.yang_name = "extension"
                                    self.yang_parent_name = "pvc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("oam", ("oam", Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Oam))])
                                    self._leafs = OrderedDict([
                                        ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                        ('up', (YLeaf(YType.empty, 'up'), ['Empty'])),
                                        ('mibversion', (YLeaf(YType.enumeration, 'mibversion'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Mibversion')])),
                                    ])
                                    self.down = None
                                    self.up = None
                                    self.mibversion = None

                                    self.oam = Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Oam()
                                    self.oam.parent = self
                                    self._children_name_map["oam"] = "oam"
                                    self._segment_path = lambda: "extension"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/atm/pvc/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension, [u'down', u'up', u'mibversion'], name, value)

                                class Mibversion(Enum):
                                    """
                                    Mibversion (Enum Class)

                                    Extension MIB version to be used

                                    .. data:: Y_1 = 0

                                    .. data:: Y_2 = 1

                                    """

                                    Y_1 = Enum.YLeaf(0, "1")

                                    Y_2 = Enum.YLeaf(1, "2")



                                class Oam(Entity):
                                    """
                                    Enable SNMP atm pvc extended oam trap
                                    
                                    .. attribute:: failure
                                    
                                    	Enable SNMP atm pvc extended any oam failure trap
                                    	**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Oam.Failure>`
                                    
                                    

                                    """

                                    _prefix = 'ios-snmp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Oam, self).__init__()

                                        self.yang_name = "oam"
                                        self.yang_parent_name = "extension"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("failure", ("failure", Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Oam.Failure))])
                                        self._leafs = OrderedDict()

                                        self.failure = Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Oam.Failure()
                                        self.failure.parent = self
                                        self._children_name_map["failure"] = "failure"
                                        self._segment_path = lambda: "oam"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/atm/pvc/extension/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Oam, [], name, value)


                                    class Failure(Entity):
                                        """
                                        Enable SNMP atm pvc extended any oam failure trap
                                        
                                        .. attribute:: loopback
                                        
                                        	Enable SNMP atm pvc extended oam loopback failure trap
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-snmp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Oam.Failure, self).__init__()

                                            self.yang_name = "failure"
                                            self.yang_parent_name = "oam"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('loopback', (YLeaf(YType.empty, 'loopback'), ['Empty'])),
                                            ])
                                            self.loopback = None
                                            self._segment_path = lambda: "failure"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/atm/pvc/extension/oam/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Pvc.Extension.Oam.Failure, [u'loopback'], name, value)


                        class Subif(Entity):
                            """
                            Enable SNMP atm subinterface traps
                            
                            .. attribute:: interval
                            
                            	Interval duration in which to limit the number of traps sent
                            	**type**\: int
                            
                            	**range:** 0..3600
                            
                            .. attribute:: count
                            
                            	Maximum number of traps sent per interval
                            	**type**\: int
                            
                            	**range:** 1..1000
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Subif, self).__init__()

                                self.yang_name = "subif"
                                self.yang_parent_name = "atm"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                                    ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                ])
                                self.interval = None
                                self.count = None
                                self._segment_path = lambda: "subif"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/atm/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Atm.Subif, [u'interval', u'count'], name, value)


                    class AuthFramework(Entity):
                        """
                        
                        
                        .. attribute:: sec_violation
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.AuthFramework, self).__init__()

                            self.yang_name = "auth-framework"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('sec_violation', (YLeaf(YType.empty, 'sec-violation'), ['Empty'])),
                            ])
                            self.sec_violation = None
                            self._segment_path = lambda: "auth-framework"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.AuthFramework, [u'sec_violation'], name, value)


                    class BgpConf(Entity):
                        """
                        
                        
                        .. attribute:: cbgp2
                        
                        	Enable BGP MIBv2 traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.BgpConf, self).__init__()

                            self.yang_name = "bgp-conf"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('cbgp2', (YLeaf(YType.empty, 'cbgp2'), ['Empty'])),
                            ])
                            self.cbgp2 = None
                            self._segment_path = lambda: "bgp-conf"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.BgpConf, [u'cbgp2'], name, value)


                    class Bridge(Entity):
                        """
                        
                        
                        .. attribute:: newroot
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: topologychange
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Bridge, self).__init__()

                            self.yang_name = "bridge"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('newroot', (YLeaf(YType.empty, 'newroot'), ['Empty'])),
                                ('topologychange', (YLeaf(YType.empty, 'topologychange'), ['Empty'])),
                            ])
                            self.newroot = None
                            self.topologychange = None
                            self._segment_path = lambda: "bridge"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Bridge, [u'newroot', u'topologychange'], name, value)


                    class Bulkstat(Entity):
                        """
                        Enable Data\-Collection\-MIB Collection notifications
                        
                        .. attribute:: collection
                        
                        	Enable Data\-Collection\-MIB Collection notifications
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: transfer
                        
                        	Enable Data\-Collection\-MIB Transfer notifications
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Bulkstat, self).__init__()

                            self.yang_name = "bulkstat"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('collection', (YLeaf(YType.empty, 'collection'), ['Empty'])),
                                ('transfer', (YLeaf(YType.empty, 'transfer'), ['Empty'])),
                            ])
                            self.collection = None
                            self.transfer = None
                            self._segment_path = lambda: "bulkstat"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Bulkstat, [u'collection', u'transfer'], name, value)


                    class CallHome(Entity):
                        """
                        Enable CISCO\-CALLHOME\-MIB traps
                        
                        .. attribute:: message_send_fail
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: server_fail
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.CallHome, self).__init__()

                            self.yang_name = "call-home"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('message_send_fail', (YLeaf(YType.empty, 'message-send-fail'), ['Empty'])),
                                ('server_fail', (YLeaf(YType.empty, 'server-fail'), ['Empty'])),
                            ])
                            self.message_send_fail = None
                            self.server_fail = None
                            self._segment_path = lambda: "call-home"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.CallHome, [u'message_send_fail', u'server_fail'], name, value)


                    class C6kxbar(Entity):
                        """
                        Enable SNMP CISCO\-CAT6K\-CROSSBAR\-MIB traps
                        
                        .. attribute:: intbus_crcexcd
                        
                        	Enable SNMP cc6kxbarIntBusCRCErrExcdNotif notification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: intbus_crcrcvrd
                        
                        	Enable SNMP cc6kxbarIntBusCRCErrRcvrdNotif notification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: swbus
                        
                        	Enable SNMP cc6kxbarSwBusStatusChangeNotif notification
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.C6kxbar, self).__init__()

                            self.yang_name = "c6kxbar"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('intbus_crcexcd', (YLeaf(YType.empty, 'intbus-crcexcd'), ['Empty'])),
                                ('intbus_crcrcvrd', (YLeaf(YType.empty, 'intbus-crcrcvrd'), ['Empty'])),
                                ('swbus', (YLeaf(YType.empty, 'swbus'), ['Empty'])),
                            ])
                            self.intbus_crcexcd = None
                            self.intbus_crcrcvrd = None
                            self.swbus = None
                            self._segment_path = lambda: "c6kxbar"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.C6kxbar, [u'intbus_crcexcd', u'intbus_crcrcvrd', u'swbus'], name, value)


                    class Cef(Entity):
                        """
                        
                        
                        .. attribute:: resource_failure
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: peer_state_change
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: peer_fib_state_change
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: inconsistency
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Cef, self).__init__()

                            self.yang_name = "cef"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('resource_failure', (YLeaf(YType.empty, 'resource-failure'), ['Empty'])),
                                ('peer_state_change', (YLeaf(YType.empty, 'peer-state-change'), ['Empty'])),
                                ('peer_fib_state_change', (YLeaf(YType.empty, 'peer-fib-state-change'), ['Empty'])),
                                ('inconsistency', (YLeaf(YType.empty, 'inconsistency'), ['Empty'])),
                            ])
                            self.resource_failure = None
                            self.peer_state_change = None
                            self.peer_fib_state_change = None
                            self.inconsistency = None
                            self._segment_path = lambda: "cef"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Cef, [u'resource_failure', u'peer_state_change', u'peer_fib_state_change', u'inconsistency'], name, value)


                    class Cpu(Entity):
                        """
                        Allow cpu related traps
                        
                        .. attribute:: threshold
                        
                        	Allow CPU utilization threshold violation traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Cpu, self).__init__()

                            self.yang_name = "cpu"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.empty, 'threshold'), ['Empty'])),
                            ])
                            self.threshold = None
                            self._segment_path = lambda: "cpu"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Cpu, [u'threshold'], name, value)


                    class Csg(Entity):
                        """
                        Enable SNMP CSG traps
                        
                        .. attribute:: agent
                        
                        	Enable SNMP Agent Server traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: database
                        
                        	Enable SNMP CSG database traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: quota_server
                        
                        	Enable SNMP Quota Server traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Csg, self).__init__()

                            self.yang_name = "csg"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('agent', (YLeaf(YType.empty, 'agent'), ['Empty'])),
                                ('database', (YLeaf(YType.empty, 'database'), ['Empty'])),
                                ('quota_server', (YLeaf(YType.empty, 'quota-server'), ['Empty'])),
                            ])
                            self.agent = None
                            self.database = None
                            self.quota_server = None
                            self._segment_path = lambda: "csg"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Csg, [u'agent', u'database', u'quota_server'], name, value)


                    class Dot1x(Entity):
                        """
                        
                        
                        .. attribute:: auth_fail_vlan
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: guest_vlan
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: no_auth_fail_vlan
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: no_guest_vlan
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Dot1x, self).__init__()

                            self.yang_name = "dot1x"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('auth_fail_vlan', (YLeaf(YType.empty, 'auth-fail-vlan'), ['Empty'])),
                                ('guest_vlan', (YLeaf(YType.empty, 'guest-vlan'), ['Empty'])),
                                ('no_auth_fail_vlan', (YLeaf(YType.empty, 'no-auth-fail-vlan'), ['Empty'])),
                                ('no_guest_vlan', (YLeaf(YType.empty, 'no-guest-vlan'), ['Empty'])),
                            ])
                            self.auth_fail_vlan = None
                            self.guest_vlan = None
                            self.no_auth_fail_vlan = None
                            self.no_guest_vlan = None
                            self._segment_path = lambda: "dot1x"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Dot1x, [u'auth_fail_vlan', u'guest_vlan', u'no_auth_fail_vlan', u'no_guest_vlan'], name, value)


                    class Dsp(Entity):
                        """
                        Enable SNMP dsp traps
                        
                        .. attribute:: card_status
                        
                        	Enable SNMP card status of dsp traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: oper_state
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Dsp, self).__init__()

                            self.yang_name = "dsp"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('card_status', (YLeaf(YType.empty, 'card-status'), ['Empty'])),
                                ('oper_state', (YLeaf(YType.empty, 'oper-state'), ['Empty'])),
                            ])
                            self.card_status = None
                            self.oper_state = None
                            self._segment_path = lambda: "dsp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Dsp, [u'card_status', u'oper_state'], name, value)


                    class Energywise(Entity):
                        """
                        
                        
                        .. attribute:: event_occured
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: level_change
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: neighbor_added
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: neighbor_deleted
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Energywise, self).__init__()

                            self.yang_name = "energywise"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('event_occured', (YLeaf(YType.empty, 'event-occured'), ['Empty'])),
                                ('level_change', (YLeaf(YType.empty, 'level-change'), ['Empty'])),
                                ('neighbor_added', (YLeaf(YType.empty, 'neighbor-added'), ['Empty'])),
                                ('neighbor_deleted', (YLeaf(YType.empty, 'neighbor-deleted'), ['Empty'])),
                            ])
                            self.event_occured = None
                            self.level_change = None
                            self.neighbor_added = None
                            self.neighbor_deleted = None
                            self._segment_path = lambda: "energywise"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Energywise, [u'event_occured', u'level_change', u'neighbor_added', u'neighbor_deleted'], name, value)


                    class EntityDiag(Entity):
                        """
                        Enable SNMP CISCO\-ENTITY\-DIAG\-MIB traps
                        
                        .. attribute:: boot_up_fail
                        
                        	Enable SNMP ceDiagBootUpFailedNotif traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hm_test_recover
                        
                        	Enable SNMP ceDiagHMTestRecoverNotif traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: hm_thresh_reached
                        
                        	Enable SNMP ceDiagHMThresholdReachedNotif traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: scheduled_test_fail
                        
                        	Enable SNMP ceDiagScheduledTestFailedNotif traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.EntityDiag, self).__init__()

                            self.yang_name = "entity-diag"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('boot_up_fail', (YLeaf(YType.empty, 'boot-up-fail'), ['Empty'])),
                                ('hm_test_recover', (YLeaf(YType.empty, 'hm-test-recover'), ['Empty'])),
                                ('hm_thresh_reached', (YLeaf(YType.empty, 'hm-thresh-reached'), ['Empty'])),
                                ('scheduled_test_fail', (YLeaf(YType.empty, 'scheduled-test-fail'), ['Empty'])),
                            ])
                            self.boot_up_fail = None
                            self.hm_test_recover = None
                            self.hm_thresh_reached = None
                            self.scheduled_test_fail = None
                            self._segment_path = lambda: "entity-diag"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.EntityDiag, [u'boot_up_fail', u'hm_test_recover', u'hm_thresh_reached', u'scheduled_test_fail'], name, value)


                    class Envmon(Entity):
                        """
                        Enable SNMP environmental monitor traps
                        
                        .. attribute:: fan
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: supply
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: temperature
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: status
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Envmon, self).__init__()

                            self.yang_name = "envmon"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('fan', (YLeaf(YType.empty, 'fan'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                ('supply', (YLeaf(YType.empty, 'supply'), ['Empty'])),
                                ('temperature', (YLeaf(YType.empty, 'temperature'), ['Empty'])),
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.fan = None
                            self.shutdown = None
                            self.supply = None
                            self.temperature = None
                            self.status = None
                            self._segment_path = lambda: "envmon"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Envmon, [u'fan', u'shutdown', u'supply', u'temperature', u'status'], name, value)


                    class Errdisable(Entity):
                        """
                        Enable SNMP errdisable notifications
                        
                        .. attribute:: notification_rate
                        
                        	Number of notifications per minute
                        	**type**\: int
                        
                        	**range:** 0..10000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Errdisable, self).__init__()

                            self.yang_name = "errdisable"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('notification_rate', (YLeaf(YType.uint16, 'notification-rate'), ['int'])),
                            ])
                            self.notification_rate = None
                            self._segment_path = lambda: "errdisable"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Errdisable, [u'notification_rate'], name, value)


                    class Ethernet(Entity):
                        """
                        
                        
                        .. attribute:: cfm
                        
                        	
                        	**type**\:  :py:class:`Cfm <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm>`
                        
                        .. attribute:: evc
                        
                        	Enable SNMP Ethernet EVC traps
                        	**type**\:  :py:class:`Evc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Evc>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet, self).__init__()

                            self.yang_name = "ethernet"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cfm", ("cfm", Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm)), ("evc", ("evc", Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Evc))])
                            self._leafs = OrderedDict()

                            self.cfm = Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm()
                            self.cfm.parent = self
                            self._children_name_map["cfm"] = "cfm"

                            self.evc = None
                            self._children_name_map["evc"] = "evc"
                            self._segment_path = lambda: "ethernet"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet, [], name, value)


                        class Cfm(Entity):
                            """
                            
                            
                            .. attribute:: alarm
                            
                            	Enable SNMP Ethernet CFM fault alarm trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: cc
                            
                            	
                            	**type**\:  :py:class:`Cc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm.Cc>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: crosscheck
                            
                            	
                            	**type**\:  :py:class:`Crosscheck <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm.Crosscheck>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm, self).__init__()

                                self.yang_name = "cfm"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cc", ("cc", Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm.Cc)), ("crosscheck", ("crosscheck", Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm.Crosscheck))])
                                self._leafs = OrderedDict([
                                    ('alarm', (YLeaf(YType.empty, 'alarm'), ['Empty'])),
                                ])
                                self.alarm = None

                                self.cc = None
                                self._children_name_map["cc"] = "cc"

                                self.crosscheck = None
                                self._children_name_map["crosscheck"] = "crosscheck"
                                self._segment_path = lambda: "cfm"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm, [u'alarm'], name, value)


                            class Cc(Entity):
                                """
                                
                                
                                .. attribute:: config
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: cross_connect
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: loop
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: mep_down
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: mep_up
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm.Cc, self).__init__()

                                    self.yang_name = "cc"
                                    self.yang_parent_name = "cfm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('config', (YLeaf(YType.empty, 'config'), ['Empty'])),
                                        ('cross_connect', (YLeaf(YType.empty, 'cross-connect'), ['Empty'])),
                                        ('loop', (YLeaf(YType.empty, 'loop'), ['Empty'])),
                                        ('mep_down', (YLeaf(YType.empty, 'mep-down'), ['Empty'])),
                                        ('mep_up', (YLeaf(YType.empty, 'mep-up'), ['Empty'])),
                                    ])
                                    self.config = None
                                    self.cross_connect = None
                                    self.loop = None
                                    self.mep_down = None
                                    self.mep_up = None
                                    self._segment_path = lambda: "cc"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ethernet/cfm/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm.Cc, [u'config', u'cross_connect', u'loop', u'mep_down', u'mep_up'], name, value)


                            class Crosscheck(Entity):
                                """
                                
                                
                                .. attribute:: mep_missing
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: mep_unknown
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: service_up
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm.Crosscheck, self).__init__()

                                    self.yang_name = "crosscheck"
                                    self.yang_parent_name = "cfm"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('mep_missing', (YLeaf(YType.empty, 'mep-missing'), ['Empty'])),
                                        ('mep_unknown', (YLeaf(YType.empty, 'mep-unknown'), ['Empty'])),
                                        ('service_up', (YLeaf(YType.empty, 'service-up'), ['Empty'])),
                                    ])
                                    self.mep_missing = None
                                    self.mep_unknown = None
                                    self.service_up = None
                                    self._segment_path = lambda: "crosscheck"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ethernet/cfm/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Cfm.Crosscheck, [u'mep_missing', u'mep_unknown', u'service_up'], name, value)


                        class Evc(Entity):
                            """
                            Enable SNMP Ethernet EVC traps
                            
                            .. attribute:: create
                            
                            	Enable SNMP Ethernet EVC create traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: delete
                            
                            	Enable SNMP Ethernet EVC delete traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: status
                            
                            	Enable SNMP Ethernet EVC status traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Evc, self).__init__()

                                self.yang_name = "evc"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('create', (YLeaf(YType.empty, 'create'), ['Empty'])),
                                    ('delete', (YLeaf(YType.empty, 'delete'), ['Empty'])),
                                    ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                                ])
                                self.create = None
                                self.delete = None
                                self.status = None
                                self._segment_path = lambda: "evc"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ethernet/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ethernet.Evc, [u'create', u'delete', u'status'], name, value)


                    class Firewall(Entity):
                        """
                        
                        
                        .. attribute:: serverstatus
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Firewall, self).__init__()

                            self.yang_name = "firewall"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('serverstatus', (YLeaf(YType.empty, 'serverstatus'), ['Empty'])),
                            ])
                            self.serverstatus = None
                            self._segment_path = lambda: "firewall"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Firewall, [u'serverstatus'], name, value)


                    class Flash(Entity):
                        """
                        Enable SNMP FLASH notifications
                        
                        .. attribute:: insertion
                        
                        	Enable SNMP Flash Insertion notifications
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: removal
                        
                        	Enable SNMP Flash Removal notifications
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Flash, self).__init__()

                            self.yang_name = "flash"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('insertion', (YLeaf(YType.empty, 'insertion'), ['Empty'])),
                                ('removal', (YLeaf(YType.empty, 'removal'), ['Empty'])),
                            ])
                            self.insertion = None
                            self.removal = None
                            self._segment_path = lambda: "flash"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Flash, [u'insertion', u'removal'], name, value)


                    class FlexLinks(Entity):
                        """
                        Enable SNMP FLEX Links traps
                        
                        .. attribute:: status
                        
                        	Enable SNMP FLEX Links status change traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.FlexLinks, self).__init__()

                            self.yang_name = "flex-links"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                            ])
                            self.status = None
                            self._segment_path = lambda: "flex-links"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.FlexLinks, [u'status'], name, value)


                    class FrameRelay(Entity):
                        """
                        Enable SNMP frame\-relay traps
                        
                        .. attribute:: multilink
                        
                        	Enable MFR traps
                        	**type**\:  :py:class:`Multilink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay.Multilink>`
                        
                        .. attribute:: subif
                        
                        	Enable SNMP frame\-relay subinterface traps
                        	**type**\:  :py:class:`Subif <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay.Subif>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay, self).__init__()

                            self.yang_name = "frame-relay"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("multilink", ("multilink", Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay.Multilink)), ("subif", ("subif", Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay.Subif))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.multilink = Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay.Multilink()
                            self.multilink.parent = self
                            self._children_name_map["multilink"] = "multilink"

                            self.subif = None
                            self._children_name_map["subif"] = "subif"
                            self._segment_path = lambda: "frame-relay"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay, [], name, value)


                        class Multilink(Entity):
                            """
                            Enable MFR traps
                            
                            .. attribute:: bundle_mismatch
                            
                            	Enable MFR trap for inconsistent bundle event
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay.Multilink, self).__init__()

                                self.yang_name = "multilink"
                                self.yang_parent_name = "frame-relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bundle_mismatch', (YLeaf(YType.empty, 'bundle-mismatch'), ['Empty'])),
                                ])
                                self.bundle_mismatch = None
                                self._segment_path = lambda: "multilink"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/frame-relay/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay.Multilink, [u'bundle_mismatch'], name, value)


                        class Subif(Entity):
                            """
                            Enable SNMP frame\-relay subinterface traps
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.FrameRelay.Subif, self).__init__()

                                self.yang_name = "subif"
                                self.yang_parent_name = "frame-relay"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "subif"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/frame-relay/%s" % self._segment_path()
                                self._is_frozen = True


                    class Ipsec(Entity):
                        """
                        Enable IPsec traps
                        
                        .. attribute:: cryptomap
                        
                        	
                        	**type**\:  :py:class:`Cryptomap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec.Cryptomap>`
                        
                        .. attribute:: tunnel
                        
                        	Enable IPsec Tunnel traps
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec.Tunnel>`
                        
                        .. attribute:: too_many_sas
                        
                        	Enable IPsec Tunnel Start trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec, self).__init__()

                            self.yang_name = "ipsec"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("cryptomap", ("cryptomap", Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec.Cryptomap)), ("tunnel", ("tunnel", Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec.Tunnel))])
                            self._leafs = OrderedDict([
                                ('too_many_sas', (YLeaf(YType.empty, 'too-many-sas'), ['Empty'])),
                            ])
                            self.too_many_sas = None

                            self.cryptomap = Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec.Cryptomap()
                            self.cryptomap.parent = self
                            self._children_name_map["cryptomap"] = "cryptomap"

                            self.tunnel = Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec.Tunnel()
                            self.tunnel.parent = self
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "ipsec"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec, [u'too_many_sas'], name, value)


                        class Cryptomap(Entity):
                            """
                            
                            
                            .. attribute:: add
                            
                            	Enable IPsec Cryptomap add trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: attach
                            
                            	Enable IPsec Cryptomap Attach trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: delete
                            
                            	Enable IPsec Cryptomap delete trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: detach
                            
                            	Enable IPsec Cryptomap Detach trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec.Cryptomap, self).__init__()

                                self.yang_name = "cryptomap"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('add', (YLeaf(YType.empty, 'add'), ['Empty'])),
                                    ('attach', (YLeaf(YType.empty, 'attach'), ['Empty'])),
                                    ('delete', (YLeaf(YType.empty, 'delete'), ['Empty'])),
                                    ('detach', (YLeaf(YType.empty, 'detach'), ['Empty'])),
                                ])
                                self.add = None
                                self.attach = None
                                self.delete = None
                                self.detach = None
                                self._segment_path = lambda: "cryptomap"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ipsec/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec.Cryptomap, [u'add', u'attach', u'delete', u'detach'], name, value)


                        class Tunnel(Entity):
                            """
                            Enable IPsec Tunnel traps
                            
                            .. attribute:: start
                            
                            	Enable IPsec Tunnel Start trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: stop
                            
                            	Enable IPsec Tunnel Stop trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "ipsec"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('start', (YLeaf(YType.empty, 'start'), ['Empty'])),
                                    ('stop', (YLeaf(YType.empty, 'stop'), ['Empty'])),
                                ])
                                self.start = None
                                self.stop = None
                                self._segment_path = lambda: "tunnel"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ipsec/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ipsec.Tunnel, [u'start', u'stop'], name, value)


                    class Isakmp(Entity):
                        """
                        Enable ISAKMP traps traps
                        
                        .. attribute:: policy
                        
                        	Enable ISAKMP traps
                        	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp.Policy>`
                        
                        .. attribute:: tunnel
                        
                        	Enable ISAKMP Tunnel traps
                        	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp.Tunnel>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp, self).__init__()

                            self.yang_name = "isakmp"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("policy", ("policy", Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp.Policy)), ("tunnel", ("tunnel", Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp.Tunnel))])
                            self._leafs = OrderedDict()

                            self.policy = Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp.Policy()
                            self.policy.parent = self
                            self._children_name_map["policy"] = "policy"

                            self.tunnel = Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp.Tunnel()
                            self.tunnel.parent = self
                            self._children_name_map["tunnel"] = "tunnel"
                            self._segment_path = lambda: "isakmp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp, [], name, value)


                        class Policy(Entity):
                            """
                            Enable ISAKMP traps
                            
                            .. attribute:: add
                            
                            	Enable ISAKMP Policy add trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: delete
                            
                            	Enable ISAKMP Policy delete trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp.Policy, self).__init__()

                                self.yang_name = "policy"
                                self.yang_parent_name = "isakmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('add', (YLeaf(YType.empty, 'add'), ['Empty'])),
                                    ('delete', (YLeaf(YType.empty, 'delete'), ['Empty'])),
                                ])
                                self.add = None
                                self.delete = None
                                self._segment_path = lambda: "policy"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/isakmp/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp.Policy, [u'add', u'delete'], name, value)


                        class Tunnel(Entity):
                            """
                            Enable ISAKMP Tunnel traps
                            
                            .. attribute:: start
                            
                            	Enable ISAKMP Tunnel start trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: stop
                            
                            	Enable ISAKMP Tunnel stop trap
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp.Tunnel, self).__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "isakmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('start', (YLeaf(YType.empty, 'start'), ['Empty'])),
                                    ('stop', (YLeaf(YType.empty, 'stop'), ['Empty'])),
                                ])
                                self.start = None
                                self.stop = None
                                self._segment_path = lambda: "tunnel"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/isakmp/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Isakmp.Tunnel, [u'start', u'stop'], name, value)


                    class Isdn(Entity):
                        """
                        Enable SNMP isdn traps
                        
                        .. attribute:: call_information
                        
                        	Enable SNMP isdn call information traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: chan_not_avail
                        
                        	Enable SNMP isdn channel not avail traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ietf
                        
                        	Enable SNMP isdn ietf traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: layer2
                        
                        	Enable SNMP isdn layer2 transition traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Isdn, self).__init__()

                            self.yang_name = "isdn"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('call_information', (YLeaf(YType.empty, 'call-information'), ['Empty'])),
                                ('chan_not_avail', (YLeaf(YType.empty, 'chan-not-avail'), ['Empty'])),
                                ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                                ('layer2', (YLeaf(YType.empty, 'layer2'), ['Empty'])),
                            ])
                            self.call_information = None
                            self.chan_not_avail = None
                            self.ietf = None
                            self.layer2 = None
                            self._segment_path = lambda: "isdn"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Isdn, [u'call_information', u'chan_not_avail', u'ietf', u'layer2'], name, value)


                    class L2tc(Entity):
                        """
                        Enable SNMP L2 Tunnel Config traps
                        
                        .. attribute:: sys_threshold
                        
                        	Enable SNMP L2TC System threshold traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: threshold
                        
                        	Enable SNMP L2 Tunnel Config threshold traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.L2tc, self).__init__()

                            self.yang_name = "l2tc"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('sys_threshold', (YLeaf(YType.empty, 'sys-threshold'), ['Empty'])),
                                ('threshold', (YLeaf(YType.empty, 'threshold'), ['Empty'])),
                            ])
                            self.sys_threshold = None
                            self.threshold = None
                            self._segment_path = lambda: "l2tc"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.L2tc, [u'sys_threshold', u'threshold'], name, value)


                    class L2tun(Entity):
                        """
                        Enable SNMP L2 tunnel protocol traps
                        
                        .. attribute:: session
                        
                        	Enable SNMP l2tun session traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: pseudowire
                        
                        	
                        	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.L2tun.Pseudowire>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.L2tun, self).__init__()

                            self.yang_name = "l2tun"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pseudowire", ("pseudowire", Native.SnmpServer.Enable.EnableChoice.Traps.L2tun.Pseudowire))])
                            self._leafs = OrderedDict([
                                ('session', (YLeaf(YType.empty, 'session'), ['Empty'])),
                            ])
                            self.session = None

                            self.pseudowire = Native.SnmpServer.Enable.EnableChoice.Traps.L2tun.Pseudowire()
                            self.pseudowire.parent = self
                            self._children_name_map["pseudowire"] = "pseudowire"
                            self._segment_path = lambda: "l2tun"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.L2tun, [u'session'], name, value)


                        class Pseudowire(Entity):
                            """
                            
                            
                            .. attribute:: status
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.L2tun.Pseudowire, self).__init__()

                                self.yang_name = "pseudowire"
                                self.yang_parent_name = "l2tun"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('status', (YLeaf(YType.empty, 'status'), ['Empty'])),
                                ])
                                self.status = None
                                self._segment_path = lambda: "pseudowire"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/l2tun/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.L2tun.Pseudowire, [u'status'], name, value)


                    class License(Entity):
                        """
                        Enable license traps
                        
                        .. attribute:: deploy
                        
                        	Enable license deployment traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: error
                        
                        	Enable license error traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: usage
                        
                        	Enable license usage traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.License, self).__init__()

                            self.yang_name = "license"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('deploy', (YLeaf(YType.empty, 'deploy'), ['Empty'])),
                                ('error', (YLeaf(YType.empty, 'error'), ['Empty'])),
                                ('usage', (YLeaf(YType.empty, 'usage'), ['Empty'])),
                            ])
                            self.deploy = None
                            self.error = None
                            self.usage = None
                            self._segment_path = lambda: "license"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.License, [u'deploy', u'error', u'usage'], name, value)


                    class MacNotification(Entity):
                        """
                        Enable SNMP MAC Notification traps
                        
                        .. attribute:: change
                        
                        	Enable SNMP Change traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: move
                        
                        	Enable SNMP Move traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: threshold
                        
                        	Enable SNMP Threshold traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.MacNotification, self).__init__()

                            self.yang_name = "mac-notification"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('change', (YLeaf(YType.empty, 'change'), ['Empty'])),
                                ('move', (YLeaf(YType.empty, 'move'), ['Empty'])),
                                ('threshold', (YLeaf(YType.empty, 'threshold'), ['Empty'])),
                            ])
                            self.change = None
                            self.move = None
                            self.threshold = None
                            self._segment_path = lambda: "mac-notification"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.MacNotification, [u'change', u'move', u'threshold'], name, value)


                    class MacNotification2(Entity):
                        """
                        Enable SNMP MAC Notification traps
                        
                        .. attribute:: change
                        
                        	Enable SNMP Change traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: move
                        
                        	Enable SNMP Move traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: threshold
                        
                        	Enable SNMP Threshold traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.MacNotification2, self).__init__()

                            self.yang_name = "mac-notification2"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('change', (YLeaf(YType.empty, 'change'), ['Empty'])),
                                ('move', (YLeaf(YType.empty, 'move'), ['Empty'])),
                                ('threshold', (YLeaf(YType.empty, 'threshold'), ['Empty'])),
                            ])
                            self.change = None
                            self.move = None
                            self.threshold = None
                            self._segment_path = lambda: "mac-notification2"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.MacNotification2, [u'change', u'move', u'threshold'], name, value)


                    class Memory(Entity):
                        """
                        Enable SNMP Memory traps
                        
                        .. attribute:: bufferpeak
                        
                        	Enable SNMP Memory Bufferpeak traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Memory, self).__init__()

                            self.yang_name = "memory"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('bufferpeak', (YLeaf(YType.empty, 'bufferpeak'), ['Empty'])),
                            ])
                            self.bufferpeak = None
                            self._segment_path = lambda: "memory"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Memory, [u'bufferpeak'], name, value)


                    class Mpls(Entity):
                        """
                        Enable SNMP MPLS traps
                        
                        .. attribute:: traffic_eng
                        
                        	
                        	**type**\:  :py:class:`TrafficEng <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.TrafficEng>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: fast_reroute
                        
                        	
                        	**type**\:  :py:class:`FastReroute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.FastReroute>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: rfc
                        
                        	
                        	**type**\:  :py:class:`Rfc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.Rfc>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ldp
                        
                        	SNMP MPLS label distribution protocol traps
                        	**type**\:  :py:class:`Ldp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.Ldp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: vpn
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Mpls, self).__init__()

                            self.yang_name = "mpls"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("traffic-eng", ("traffic_eng", Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.TrafficEng)), ("fast-reroute", ("fast_reroute", Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.FastReroute)), ("rfc", ("rfc", Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.Rfc)), ("ldp", ("ldp", Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.Ldp))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('vpn', (YLeaf(YType.empty, 'vpn'), ['Empty'])),
                            ])
                            self.vpn = None

                            self.traffic_eng = None
                            self._children_name_map["traffic_eng"] = "traffic-eng"

                            self.fast_reroute = None
                            self._children_name_map["fast_reroute"] = "fast-reroute"

                            self.rfc = None
                            self._children_name_map["rfc"] = "rfc"

                            self.ldp = None
                            self._children_name_map["ldp"] = "ldp"
                            self._segment_path = lambda: "mpls"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Mpls, [u'vpn'], name, value)


                        class TrafficEng(Entity):
                            """
                            
                            
                            .. attribute:: up
                            
                            	Enable MPLS TE tunnel up traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: down
                            
                            	Enable MPLS TE tunnel down traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: reroute
                            
                            	Enable MPLS TE tunnel reroute traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.TrafficEng, self).__init__()

                                self.yang_name = "traffic-eng"
                                self.yang_parent_name = "mpls"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('up', (YLeaf(YType.empty, 'up'), ['Empty'])),
                                    ('down', (YLeaf(YType.empty, 'down'), ['Empty'])),
                                    ('reroute', (YLeaf(YType.empty, 'reroute'), ['Empty'])),
                                ])
                                self.up = None
                                self.down = None
                                self.reroute = None
                                self._segment_path = lambda: "traffic-eng"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/mpls/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.TrafficEng, [u'up', u'down', u'reroute'], name, value)


                        class FastReroute(Entity):
                            """
                            
                            
                            .. attribute:: protected
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.FastReroute, self).__init__()

                                self.yang_name = "fast-reroute"
                                self.yang_parent_name = "mpls"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('protected', (YLeaf(YType.empty, 'protected'), ['Empty'])),
                                ])
                                self.protected = None
                                self._segment_path = lambda: "fast-reroute"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/mpls/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.FastReroute, [u'protected'], name, value)


                        class Rfc(Entity):
                            """
                            
                            
                            .. attribute:: ldp
                            
                            	
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.Rfc, self).__init__()

                                self.yang_name = "rfc"
                                self.yang_parent_name = "mpls"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('ldp', (YLeaf(YType.empty, 'ldp'), ['Empty'])),
                                ])
                                self.ldp = None
                                self._segment_path = lambda: "rfc"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/mpls/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.Rfc, [u'ldp'], name, value)


                        class Ldp(Entity):
                            """
                            SNMP MPLS label distribution protocol traps
                            
                            .. attribute:: pv_limit
                            
                            	Enable MPLS LDP path vector limit mismatch traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: session_down
                            
                            	Enable MPLS LDP session down traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: session_up
                            
                            	Enable MPLS LDP session up traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: threshold
                            
                            	Enable MPLS LDP threshold exceeded traps
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.Ldp, self).__init__()

                                self.yang_name = "ldp"
                                self.yang_parent_name = "mpls"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('pv_limit', (YLeaf(YType.empty, 'pv-limit'), ['Empty'])),
                                    ('session_down', (YLeaf(YType.empty, 'session-down'), ['Empty'])),
                                    ('session_up', (YLeaf(YType.empty, 'session-up'), ['Empty'])),
                                    ('threshold', (YLeaf(YType.empty, 'threshold'), ['Empty'])),
                                ])
                                self.pv_limit = None
                                self.session_down = None
                                self.session_up = None
                                self.threshold = None
                                self._segment_path = lambda: "ldp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/mpls/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Mpls.Ldp, [u'pv_limit', u'session_down', u'session_up', u'threshold'], name, value)


                    class Nhrp(Entity):
                        """
                        
                        
                        .. attribute:: nhs
                        
                        	
                        	**type**\:  :py:class:`Nhs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.Nhs>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: nhc
                        
                        	
                        	**type**\:  :py:class:`Nhc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.Nhc>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: nhp
                        
                        	
                        	**type**\:  :py:class:`Nhp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.Nhp>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: quota_exceeded
                        
                        	
                        	**type**\:  :py:class:`QuotaExceeded <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.QuotaExceeded>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp, self).__init__()

                            self.yang_name = "nhrp"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nhs", ("nhs", Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.Nhs)), ("nhc", ("nhc", Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.Nhc)), ("nhp", ("nhp", Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.Nhp)), ("quota-exceeded", ("quota_exceeded", Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.QuotaExceeded))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.nhs = None
                            self._children_name_map["nhs"] = "nhs"

                            self.nhc = None
                            self._children_name_map["nhc"] = "nhc"

                            self.nhp = None
                            self._children_name_map["nhp"] = "nhp"

                            self.quota_exceeded = None
                            self._children_name_map["quota_exceeded"] = "quota-exceeded"
                            self._segment_path = lambda: "nhrp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp, [], name, value)


                        class Nhs(Entity):
                            """
                            
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.Nhs, self).__init__()

                                self.yang_name = "nhs"
                                self.yang_parent_name = "nhrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "nhs"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/nhrp/%s" % self._segment_path()
                                self._is_frozen = True


                        class Nhc(Entity):
                            """
                            
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.Nhc, self).__init__()

                                self.yang_name = "nhc"
                                self.yang_parent_name = "nhrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "nhc"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/nhrp/%s" % self._segment_path()
                                self._is_frozen = True


                        class Nhp(Entity):
                            """
                            
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.Nhp, self).__init__()

                                self.yang_name = "nhp"
                                self.yang_parent_name = "nhrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "nhp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/nhrp/%s" % self._segment_path()
                                self._is_frozen = True


                        class QuotaExceeded(Entity):
                            """
                            
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Nhrp.QuotaExceeded, self).__init__()

                                self.yang_name = "quota-exceeded"
                                self.yang_parent_name = "nhrp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "quota-exceeded"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/nhrp/%s" % self._segment_path()
                                self._is_frozen = True


                    class Ospf(Entity):
                        """
                        Enable OSPF traps
                        
                        .. attribute:: state_change
                        
                        	State change traps
                        	**type**\:  :py:class:`StateChange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.StateChange>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: errors
                        
                        	Error traps
                        	**type**\:  :py:class:`Errors <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.Errors>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: retransmit
                        
                        	Packet retransmit traps
                        	**type**\:  :py:class:`Retransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.Retransmit>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: lsa
                        
                        	Lsa related traps
                        	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.Lsa>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: cisco_specific
                        
                        	Cisco specific traps
                        	**type**\:  :py:class:`CiscoSpecific <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf, self).__init__()

                            self.yang_name = "ospf"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("state-change", ("state_change", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.StateChange)), ("errors", ("errors", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.Errors)), ("retransmit", ("retransmit", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.Retransmit)), ("lsa", ("lsa", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.Lsa)), ("cisco-specific", ("cisco_specific", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific))])
                            self._leafs = OrderedDict()

                            self.state_change = None
                            self._children_name_map["state_change"] = "state-change"

                            self.errors = None
                            self._children_name_map["errors"] = "errors"

                            self.retransmit = None
                            self._children_name_map["retransmit"] = "retransmit"

                            self.lsa = None
                            self._children_name_map["lsa"] = "lsa"

                            self.cisco_specific = None
                            self._children_name_map["cisco_specific"] = "cisco-specific"
                            self._segment_path = lambda: "ospf"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf, [], name, value)


                        class StateChange(Entity):
                            """
                            State change traps
                            
                            .. attribute:: if_state_change
                            
                            	Non\-virtual interface state changes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: neighbor_state_change
                            
                            	Non\-virtual neighbor state changes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: virtif_state_change
                            
                            	Virtual interface state changes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: virtneighbor_state_change
                            
                            	Non\-virtual neighbor state changes
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.StateChange, self).__init__()

                                self.yang_name = "state-change"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('if_state_change', (YLeaf(YType.empty, 'if-state-change'), ['Empty'])),
                                    ('neighbor_state_change', (YLeaf(YType.empty, 'neighbor-state-change'), ['Empty'])),
                                    ('virtif_state_change', (YLeaf(YType.empty, 'virtif-state-change'), ['Empty'])),
                                    ('virtneighbor_state_change', (YLeaf(YType.empty, 'virtneighbor-state-change'), ['Empty'])),
                                ])
                                self.if_state_change = None
                                self.neighbor_state_change = None
                                self.virtif_state_change = None
                                self.virtneighbor_state_change = None
                                self._segment_path = lambda: "state-change"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ospf/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.StateChange, [u'if_state_change', u'neighbor_state_change', u'virtif_state_change', u'virtneighbor_state_change'], name, value)


                        class Errors(Entity):
                            """
                            Error traps
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.Errors, self).__init__()

                                self.yang_name = "errors"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "errors"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ospf/%s" % self._segment_path()
                                self._is_frozen = True


                        class Retransmit(Entity):
                            """
                            Packet retransmit traps
                            
                            .. attribute:: packets
                            
                            	Packet retransmission on non\-virtual interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: virt_packets
                            
                            	Packet retransmission on virtual interfaces
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.Retransmit, self).__init__()

                                self.yang_name = "retransmit"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('packets', (YLeaf(YType.empty, 'packets'), ['Empty'])),
                                    ('virt_packets', (YLeaf(YType.empty, 'virt-packets'), ['Empty'])),
                                ])
                                self.packets = None
                                self.virt_packets = None
                                self._segment_path = lambda: "retransmit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ospf/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.Retransmit, [u'packets', u'virt_packets'], name, value)


                        class Lsa(Entity):
                            """
                            Lsa related traps
                            
                            .. attribute:: lsa_maxage
                            
                            	Lsa aged to maxage
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: lsa_originate
                            
                            	New lsa originated
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.Lsa, self).__init__()

                                self.yang_name = "lsa"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('lsa_maxage', (YLeaf(YType.empty, 'lsa-maxage'), ['Empty'])),
                                    ('lsa_originate', (YLeaf(YType.empty, 'lsa-originate'), ['Empty'])),
                                ])
                                self.lsa_maxage = None
                                self.lsa_originate = None
                                self._segment_path = lambda: "lsa"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ospf/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.Lsa, [u'lsa_maxage', u'lsa_originate'], name, value)


                        class CiscoSpecific(Entity):
                            """
                            Cisco specific traps
                            
                            .. attribute:: state_change
                            
                            	State change traps
                            	**type**\:  :py:class:`StateChange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.StateChange>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: errors
                            
                            	Error traps
                            	**type**\:  :py:class:`Errors <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Errors>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: errdisable
                            
                            	Enable SNMP errdisable notifications
                            	**type**\:  :py:class:`Errdisable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Errdisable>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: retransmit
                            
                            	Packet retransmit traps
                            	**type**\:  :py:class:`Retransmit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Retransmit>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: lsa
                            
                            	Lsa related traps
                            	**type**\:  :py:class:`Lsa <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Lsa>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific, self).__init__()

                                self.yang_name = "cisco-specific"
                                self.yang_parent_name = "ospf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("state-change", ("state_change", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.StateChange)), ("errors", ("errors", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Errors)), ("errdisable", ("errdisable", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Errdisable)), ("retransmit", ("retransmit", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Retransmit)), ("lsa", ("lsa", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Lsa))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.state_change = None
                                self._children_name_map["state_change"] = "state-change"

                                self.errors = None
                                self._children_name_map["errors"] = "errors"

                                self.errdisable = None
                                self._children_name_map["errdisable"] = "errdisable"

                                self.retransmit = None
                                self._children_name_map["retransmit"] = "retransmit"

                                self.lsa = None
                                self._children_name_map["lsa"] = "lsa"
                                self._segment_path = lambda: "cisco-specific"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ospf/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific, [], name, value)


                            class StateChange(Entity):
                                """
                                State change traps
                                
                                .. attribute:: nssa_trans_change
                                
                                	Nssa translator state changes
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: shamlink
                                
                                	Sham link state change traps
                                	**type**\:  :py:class:`Shamlink <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.StateChange.Shamlink>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.StateChange, self).__init__()

                                    self.yang_name = "state-change"
                                    self.yang_parent_name = "cisco-specific"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("shamlink", ("shamlink", Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.StateChange.Shamlink))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('nssa_trans_change', (YLeaf(YType.empty, 'nssa-trans-change'), ['Empty'])),
                                    ])
                                    self.nssa_trans_change = None

                                    self.shamlink = None
                                    self._children_name_map["shamlink"] = "shamlink"
                                    self._segment_path = lambda: "state-change"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ospf/cisco-specific/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.StateChange, [u'nssa_trans_change'], name, value)


                                class Shamlink(Entity):
                                    """
                                    Sham link state change traps
                                    
                                    .. attribute:: interface
                                    
                                    	Sham link interface state changes
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: interface_old
                                    
                                    	Sham link interface state changes (deprecated)
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: neighbor
                                    
                                    	Sham link neighbor state changes
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-snmp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.StateChange.Shamlink, self).__init__()

                                        self.yang_name = "shamlink"
                                        self.yang_parent_name = "state-change"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.empty, 'interface'), ['Empty'])),
                                            ('interface_old', (YLeaf(YType.empty, 'interface-old'), ['Empty'])),
                                            ('neighbor', (YLeaf(YType.empty, 'neighbor'), ['Empty'])),
                                        ])
                                        self.interface = None
                                        self.interface_old = None
                                        self.neighbor = None
                                        self._segment_path = lambda: "shamlink"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ospf/cisco-specific/state-change/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.StateChange.Shamlink, [u'interface', u'interface_old', u'neighbor'], name, value)


                            class Errors(Entity):
                                """
                                Error traps
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Errors, self).__init__()

                                    self.yang_name = "errors"
                                    self.yang_parent_name = "cisco-specific"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "errors"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ospf/cisco-specific/%s" % self._segment_path()
                                    self._is_frozen = True


                            class Errdisable(Entity):
                                """
                                Enable SNMP errdisable notifications
                                
                                .. attribute:: notification_rate
                                
                                	Number of notifications per minute
                                	**type**\: int
                                
                                	**range:** 0..10000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Errdisable, self).__init__()

                                    self.yang_name = "errdisable"
                                    self.yang_parent_name = "cisco-specific"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('notification_rate', (YLeaf(YType.uint16, 'notification-rate'), ['int'])),
                                    ])
                                    self.notification_rate = None
                                    self._segment_path = lambda: "errdisable"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ospf/cisco-specific/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Errdisable, [u'notification_rate'], name, value)


                            class Retransmit(Entity):
                                """
                                Packet retransmit traps
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Retransmit, self).__init__()

                                    self.yang_name = "retransmit"
                                    self.yang_parent_name = "cisco-specific"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "retransmit"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ospf/cisco-specific/%s" % self._segment_path()
                                    self._is_frozen = True


                            class Lsa(Entity):
                                """
                                Lsa related traps
                                
                                .. attribute:: lsa_maxage
                                
                                	Lsa aged to maxage
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: lsa_originate
                                
                                	New lsa originated
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "cisco-specific"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('lsa_maxage', (YLeaf(YType.empty, 'lsa-maxage'), ['Empty'])),
                                        ('lsa_originate', (YLeaf(YType.empty, 'lsa-originate'), ['Empty'])),
                                    ])
                                    self.lsa_maxage = None
                                    self.lsa_originate = None
                                    self._segment_path = lambda: "lsa"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/ospf/cisco-specific/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Ospf.CiscoSpecific.Lsa, [u'lsa_maxage', u'lsa_originate'], name, value)


                    class Pim(Entity):
                        """
                        Enable SNMP PIM traps
                        
                        .. attribute:: invalid_pim_message
                        
                        	Enable invalid pim message trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: neighbor_change
                        
                        	Enable neighbor change trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rp_mapping_change
                        
                        	Enable rp mapping change trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Pim, self).__init__()

                            self.yang_name = "pim"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('invalid_pim_message', (YLeaf(YType.empty, 'invalid-pim-message'), ['Empty'])),
                                ('neighbor_change', (YLeaf(YType.empty, 'neighbor-change'), ['Empty'])),
                                ('rp_mapping_change', (YLeaf(YType.empty, 'rp-mapping-change'), ['Empty'])),
                            ])
                            self.invalid_pim_message = None
                            self.neighbor_change = None
                            self.rp_mapping_change = None
                            self._segment_path = lambda: "pim"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Pim, [u'invalid_pim_message', u'neighbor_change', u'rp_mapping_change'], name, value)


                    class Plogd(Entity):
                        """
                        Enable SNMP plogd traps
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Plogd, self).__init__()

                            self.yang_name = "plogd"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "plogd"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True


                    class PortSecurity(Entity):
                        """
                        Enable SNMP port security traps
                        
                        .. attribute:: trap_rate
                        
                        	Number of traps per second
                        	**type**\: int
                        
                        	**range:** 0..1000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.PortSecurity, self).__init__()

                            self.yang_name = "port-security"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('trap_rate', (YLeaf(YType.uint16, 'trap-rate'), ['int'])),
                            ])
                            self.trap_rate = None
                            self._segment_path = lambda: "port-security"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.PortSecurity, [u'trap_rate'], name, value)


                    class PowerEthernet(Entity):
                        """
                        Enable SNMP power ethernet traps
                        
                        .. attribute:: group
                        
                        	Enable SNMP inline power group based traps
                        	**type**\: str
                        
                        .. attribute:: police
                        
                        	Enable Policing Trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.PowerEthernet, self).__init__()

                            self.yang_name = "power-ethernet"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('group', (YLeaf(YType.str, 'group'), ['str'])),
                                ('police', (YLeaf(YType.empty, 'police'), ['Empty'])),
                            ])
                            self.group = None
                            self.police = None
                            self._segment_path = lambda: "power-ethernet"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.PowerEthernet, [u'group', u'police'], name, value)


                    class Pw(Entity):
                        """
                        
                        
                        .. attribute:: vc
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Pw, self).__init__()

                            self.yang_name = "pw"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('vc', (YLeaf(YType.empty, 'vc'), ['Empty'])),
                            ])
                            self.vc = None
                            self._segment_path = lambda: "pw"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Pw, [u'vc'], name, value)


                    class Slb(Entity):
                        """
                        Enable SNMP SLB traps
                        
                        .. attribute:: csrp
                        
                        	Enable SNMP SLB Fault Tolerance Replication Protocol traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: real
                        
                        	Enable SNMP SLB Real Server traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: virtual
                        
                        	Enable SNMP SLB Virtual Server traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Slb, self).__init__()

                            self.yang_name = "slb"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('csrp', (YLeaf(YType.empty, 'csrp'), ['Empty'])),
                                ('real', (YLeaf(YType.empty, 'real'), ['Empty'])),
                                ('virtual', (YLeaf(YType.empty, 'virtual'), ['Empty'])),
                            ])
                            self.csrp = None
                            self.real = None
                            self.virtual = None
                            self._segment_path = lambda: "slb"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Slb, [u'csrp', u'real', u'virtual'], name, value)


                    class Snmp(Entity):
                        """
                        Enable SNMP traps
                        
                        .. attribute:: authentication
                        
                        	Enable authentication trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: coldstart
                        
                        	Enable coldStart trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: linkdown
                        
                        	Enable linkDown trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: linkup
                        
                        	Enable linkUp trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: warmstart
                        
                        	Enable warmStart trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Snmp, self).__init__()

                            self.yang_name = "snmp"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('authentication', (YLeaf(YType.empty, 'authentication'), ['Empty'])),
                                ('coldstart', (YLeaf(YType.empty, 'coldstart'), ['Empty'])),
                                ('linkdown', (YLeaf(YType.empty, 'linkdown'), ['Empty'])),
                                ('linkup', (YLeaf(YType.empty, 'linkup'), ['Empty'])),
                                ('warmstart', (YLeaf(YType.empty, 'warmstart'), ['Empty'])),
                            ])
                            self.authentication = None
                            self.coldstart = None
                            self.linkdown = None
                            self.linkup = None
                            self.warmstart = None
                            self._segment_path = lambda: "snmp"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Snmp, [u'authentication', u'coldstart', u'linkdown', u'linkup', u'warmstart'], name, value)


                    class Stackwise(Entity):
                        """
                        Enable SNMP stackwise traps
                        
                        .. attribute:: gls
                        
                        	Enable STACKWISE stack power GLS trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ils
                        
                        	Enable STACKWISE stack power ILS trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: srls
                        
                        	Enable STACKWISE stack power SRLS trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: insufficient_power
                        
                        	Enable STACKWISE stack power unbalanced power supplies trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: invalid_input_current
                        
                        	Enable STACKWISE stack power invalid input current trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: invalid_output_current
                        
                        	Enable STACKWISE stack power invalid output current trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: member_removed
                        
                        	Enable STACKWISE stack member removed trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: member_upgrade_notification
                        
                        	Enable STACKWISE member to be reloaded for upgrade trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: new_master
                        
                        	Enable STACKWISE new master trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: new_member
                        
                        	Enable STACKWISE stack new member trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: port_change
                        
                        	Enable STACKWISE port change trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: power_budget_warning
                        
                        	Enable STACKWISE stack power budget warning trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: power_invalid_topology
                        
                        	Enable STACKWISE stack power invalid topology trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: power_link_status_changed
                        
                        	Enable STACKWISE stack power link status changed trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: power_oper_status_changed
                        
                        	Enable STACKWISE stack power port oper status changed trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: power_priority_conflict
                        
                        	Enable STACKWISE stack power priority conflict trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: power_version_mismatch
                        
                        	Enable STACKWISE stack power version mismatch discovered trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ring_redundant
                        
                        	Enable STACKWISE stack ring redundant trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: stack_mismatch
                        
                        	Enable STACKWISE stack mismatch trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: unbalanced_power_supplies
                        
                        	Enable STACKWISE stack power unbalanced power supplies trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: under_budget
                        
                        	Enable STACKWISE stack power under budget trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: under_voltage
                        
                        	Enable STACKWISE stack power under voltage trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Stackwise, self).__init__()

                            self.yang_name = "stackwise"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('gls', (YLeaf(YType.empty, 'GLS'), ['Empty'])),
                                ('ils', (YLeaf(YType.empty, 'ILS'), ['Empty'])),
                                ('srls', (YLeaf(YType.empty, 'SRLS'), ['Empty'])),
                                ('insufficient_power', (YLeaf(YType.empty, 'insufficient-power'), ['Empty'])),
                                ('invalid_input_current', (YLeaf(YType.empty, 'invalid-input-current'), ['Empty'])),
                                ('invalid_output_current', (YLeaf(YType.empty, 'invalid-output-current'), ['Empty'])),
                                ('member_removed', (YLeaf(YType.empty, 'member-removed'), ['Empty'])),
                                ('member_upgrade_notification', (YLeaf(YType.empty, 'member-upgrade-notification'), ['Empty'])),
                                ('new_master', (YLeaf(YType.empty, 'new-master'), ['Empty'])),
                                ('new_member', (YLeaf(YType.empty, 'new-member'), ['Empty'])),
                                ('port_change', (YLeaf(YType.empty, 'port-change'), ['Empty'])),
                                ('power_budget_warning', (YLeaf(YType.empty, 'power-budget-warning'), ['Empty'])),
                                ('power_invalid_topology', (YLeaf(YType.empty, 'power-invalid-topology'), ['Empty'])),
                                ('power_link_status_changed', (YLeaf(YType.empty, 'power-link-status-changed'), ['Empty'])),
                                ('power_oper_status_changed', (YLeaf(YType.empty, 'power-oper-status-changed'), ['Empty'])),
                                ('power_priority_conflict', (YLeaf(YType.empty, 'power-priority-conflict'), ['Empty'])),
                                ('power_version_mismatch', (YLeaf(YType.empty, 'power-version-mismatch'), ['Empty'])),
                                ('ring_redundant', (YLeaf(YType.empty, 'ring-redundant'), ['Empty'])),
                                ('stack_mismatch', (YLeaf(YType.empty, 'stack-mismatch'), ['Empty'])),
                                ('unbalanced_power_supplies', (YLeaf(YType.empty, 'unbalanced-power-supplies'), ['Empty'])),
                                ('under_budget', (YLeaf(YType.empty, 'under-budget'), ['Empty'])),
                                ('under_voltage', (YLeaf(YType.empty, 'under-voltage'), ['Empty'])),
                            ])
                            self.gls = None
                            self.ils = None
                            self.srls = None
                            self.insufficient_power = None
                            self.invalid_input_current = None
                            self.invalid_output_current = None
                            self.member_removed = None
                            self.member_upgrade_notification = None
                            self.new_master = None
                            self.new_member = None
                            self.port_change = None
                            self.power_budget_warning = None
                            self.power_invalid_topology = None
                            self.power_link_status_changed = None
                            self.power_oper_status_changed = None
                            self.power_priority_conflict = None
                            self.power_version_mismatch = None
                            self.ring_redundant = None
                            self.stack_mismatch = None
                            self.unbalanced_power_supplies = None
                            self.under_budget = None
                            self.under_voltage = None
                            self._segment_path = lambda: "stackwise"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Stackwise, [u'gls', u'ils', u'srls', u'insufficient_power', u'invalid_input_current', u'invalid_output_current', u'member_removed', u'member_upgrade_notification', u'new_master', u'new_member', u'port_change', u'power_budget_warning', u'power_invalid_topology', u'power_link_status_changed', u'power_oper_status_changed', u'power_priority_conflict', u'power_version_mismatch', u'ring_redundant', u'stack_mismatch', u'unbalanced_power_supplies', u'under_budget', u'under_voltage'], name, value)


                    class Stpx(Entity):
                        """
                        
                        
                        .. attribute:: inconsistency
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: root_inconsistency
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: loop_inconsistency
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Stpx, self).__init__()

                            self.yang_name = "stpx"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('inconsistency', (YLeaf(YType.empty, 'inconsistency'), ['Empty'])),
                                ('root_inconsistency', (YLeaf(YType.empty, 'root-inconsistency'), ['Empty'])),
                                ('loop_inconsistency', (YLeaf(YType.empty, 'loop-inconsistency'), ['Empty'])),
                            ])
                            self.inconsistency = None
                            self.root_inconsistency = None
                            self.loop_inconsistency = None
                            self._segment_path = lambda: "stpx"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Stpx, [u'inconsistency', u'root_inconsistency', u'loop_inconsistency'], name, value)


                    class Transceiver(Entity):
                        """
                        
                        
                        .. attribute:: all
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Transceiver, self).__init__()

                            self.yang_name = "transceiver"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                            ])
                            self.all = None
                            self._segment_path = lambda: "transceiver"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Transceiver, [u'all'], name, value)


                    class Udld(Entity):
                        """
                        Enable SNMP CISCO\-UDLDP\-MIB traps
                        
                        .. attribute:: link_fail_rpt
                        
                        	Enable SNMP cudldpFastHelloLinkFailRptNotification traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: status_change
                        
                        	Enable SNMP cudldpFastHelloStatusChangeNotification traps
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Udld, self).__init__()

                            self.yang_name = "udld"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('link_fail_rpt', (YLeaf(YType.empty, 'link-fail-rpt'), ['Empty'])),
                                ('status_change', (YLeaf(YType.empty, 'status-change'), ['Empty'])),
                            ])
                            self.link_fail_rpt = None
                            self.status_change = None
                            self._segment_path = lambda: "udld"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Udld, [u'link_fail_rpt', u'status_change'], name, value)


                    class Vrfmib(Entity):
                        """
                        
                        
                        .. attribute:: vrf_up
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vrf_down
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vnet_trunk_up
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: vnet_trunk_down
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Vrfmib, self).__init__()

                            self.yang_name = "vrfmib"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vrf_up', (YLeaf(YType.empty, 'vrf-up'), ['Empty'])),
                                ('vrf_down', (YLeaf(YType.empty, 'vrf-down'), ['Empty'])),
                                ('vnet_trunk_up', (YLeaf(YType.empty, 'vnet-trunk-up'), ['Empty'])),
                                ('vnet_trunk_down', (YLeaf(YType.empty, 'vnet-trunk-down'), ['Empty'])),
                            ])
                            self.vrf_up = None
                            self.vrf_down = None
                            self.vnet_trunk_up = None
                            self.vnet_trunk_down = None
                            self._segment_path = lambda: "vrfmib"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Vrfmib, [u'vrf_up', u'vrf_down', u'vnet_trunk_up', u'vnet_trunk_down'], name, value)


                    class Vstack(Entity):
                        """
                        Enable SNMP Smart Install traps
                        
                        .. attribute:: addition
                        
                        	Enable client added trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: failure
                        
                        	Enable file upload/download failure trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: lost
                        
                        	Enable client lost trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: operation_
                        
                        	Enable operation mode change trap
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Vstack, self).__init__()

                            self.yang_name = "vstack"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('addition', (YLeaf(YType.empty, 'addition'), ['Empty'])),
                                ('failure', (YLeaf(YType.empty, 'failure'), ['Empty'])),
                                ('lost', (YLeaf(YType.empty, 'lost'), ['Empty'])),
                                ('operation_', (YLeaf(YType.empty, 'operation'), ['Empty'])),
                            ])
                            self.addition = None
                            self.failure = None
                            self.lost = None
                            self.operation_ = None
                            self._segment_path = lambda: "vstack"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Vstack, [u'addition', u'failure', u'lost', u'operation_'], name, value)


                    class Wireless(Entity):
                        """
                        wireless
                        
                        .. attribute:: bsnmobilestation
                        
                        	Controls wireless client traps
                        	**type**\:  :py:class:`BsnMobileStation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Wireless.BsnMobileStation>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.Enable.EnableChoice.Traps.Wireless, self).__init__()

                            self.yang_name = "wireless"
                            self.yang_parent_name = "traps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bsnMobileStation", ("bsnmobilestation", Native.SnmpServer.Enable.EnableChoice.Traps.Wireless.BsnMobileStation))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.bsnmobilestation = None
                            self._children_name_map["bsnmobilestation"] = "bsnMobileStation"
                            self._segment_path = lambda: "wireless"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Wireless, [], name, value)


                        class BsnMobileStation(Entity):
                            """
                            Controls wireless client traps
                            
                            .. attribute:: bsnaccesspoint
                            
                            	Access Point traps
                            	**type**\:  :py:class:`BsnAccessPoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Enable.EnableChoice.Traps.Wireless.BsnMobileStation.BsnAccessPoint>`
                            
                            	**presence node**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.Enable.EnableChoice.Traps.Wireless.BsnMobileStation, self).__init__()

                                self.yang_name = "bsnMobileStation"
                                self.yang_parent_name = "wireless"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bsnAccessPoint", ("bsnaccesspoint", Native.SnmpServer.Enable.EnableChoice.Traps.Wireless.BsnMobileStation.BsnAccessPoint))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.bsnaccesspoint = None
                                self._children_name_map["bsnaccesspoint"] = "bsnAccessPoint"
                                self._segment_path = lambda: "bsnMobileStation"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/wireless/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Wireless.BsnMobileStation, [], name, value)


                            class BsnAccessPoint(Entity):
                                """
                                Access Point traps
                                
                                .. attribute:: bsnrogue
                                
                                	Rogue related traps
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.Enable.EnableChoice.Traps.Wireless.BsnMobileStation.BsnAccessPoint, self).__init__()

                                    self.yang_name = "bsnAccessPoint"
                                    self.yang_parent_name = "bsnMobileStation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('bsnrogue', (YLeaf(YType.empty, 'bsnRogue'), ['Empty'])),
                                    ])
                                    self.bsnrogue = None
                                    self._segment_path = lambda: "bsnAccessPoint"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:enable/enable-choice/traps/wireless/bsnMobileStation/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SnmpServer.Enable.EnableChoice.Traps.Wireless.BsnMobileStation.BsnAccessPoint, [u'bsnrogue'], name, value)


        class EngineID(Entity):
            """
            Configure a local or remote SNMPv3 engineID
            
            .. attribute:: local
            
            	engineID of the local agent
            	**type**\: str
            
            	**length:** 1..24
            
            .. attribute:: remote
            
            	
            	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.EngineID.Remote>`
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.EngineID, self).__init__()

                self.yang_name = "engineID"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("remote", ("remote", Native.SnmpServer.EngineID.Remote))])
                self._leafs = OrderedDict([
                    ('local', (YLeaf(YType.str, 'local'), ['str'])),
                ])
                self.local = None

                self.remote = Native.SnmpServer.EngineID.Remote()
                self.remote.parent = self
                self._children_name_map["remote"] = "remote"
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:engineID"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.EngineID, [u'local'], name, value)


            class Remote(Entity):
                """
                
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.EngineID.Remote, self).__init__()

                    self.yang_name = "remote"
                    self.yang_parent_name = "engineID"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "remote"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:engineID/%s" % self._segment_path()
                    self._is_frozen = True


        class Group(Entity):
            """
            Define a User Security Model group
            
            .. attribute:: id  (key)
            
            	
            	**type**\: str
            
            .. attribute:: v1
            
            	
            	**type**\:  :py:class:`V1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Group.V1>`
            
            .. attribute:: v2c
            
            	
            	**type**\:  :py:class:`V2c <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Group.V2c>`
            
            .. attribute:: v3
            
            	group using the User Security Model (SNMPv3)
            	**type**\:  :py:class:`V3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Group.V3>`
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.Group, self).__init__()

                self.yang_name = "group"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("v1", ("v1", Native.SnmpServer.Group.V1)), ("v2c", ("v2c", Native.SnmpServer.Group.V2c)), ("v3", ("v3", Native.SnmpServer.Group.V3))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                ])
                self.id = None

                self.v1 = Native.SnmpServer.Group.V1()
                self.v1.parent = self
                self._children_name_map["v1"] = "v1"

                self.v2c = Native.SnmpServer.Group.V2c()
                self.v2c.parent = self
                self._children_name_map["v2c"] = "v2c"

                self.v3 = Native.SnmpServer.Group.V3()
                self.v3.parent = self
                self._children_name_map["v3"] = "v3"
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:group" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.Group, [u'id'], name, value)


            class V1(Entity):
                """
                
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.Group.V1, self).__init__()

                    self.yang_name = "v1"
                    self.yang_parent_name = "group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "v1"
                    self._is_frozen = True


            class V2c(Entity):
                """
                
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.Group.V2c, self).__init__()

                    self.yang_name = "v2c"
                    self.yang_parent_name = "group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "v2c"
                    self._is_frozen = True


            class V3(Entity):
                """
                group using the User Security Model (SNMPv3)
                
                .. attribute:: security_level
                
                	
                	**type**\:  :py:class:`SecurityLevel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Group.V3.SecurityLevel>`
                
                .. attribute:: context
                
                	specify a context to associate these views for the group
                	**type**\: str
                
                .. attribute:: match
                
                	context name match criteria
                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Group.V3.Match>`
                
                .. attribute:: read
                
                	specify a read view for the group
                	**type**\: str
                
                .. attribute:: write
                
                	specify a write view for the group
                	**type**\: str
                
                .. attribute:: notify
                
                	specify a notify view for the group
                	**type**\: str
                
                .. attribute:: access
                
                	specify an access\-list associated with this group
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: str
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.Group.V3, self).__init__()

                    self.yang_name = "v3"
                    self.yang_parent_name = "group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('security_level', (YLeaf(YType.enumeration, 'security-level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'SnmpServer.Group.V3.SecurityLevel')])),
                        ('context', (YLeaf(YType.str, 'context'), ['str'])),
                        ('match', (YLeaf(YType.enumeration, 'match'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'SnmpServer.Group.V3.Match')])),
                        ('read', (YLeaf(YType.str, 'read'), ['str'])),
                        ('write', (YLeaf(YType.str, 'write'), ['str'])),
                        ('notify', (YLeaf(YType.str, 'notify'), ['str'])),
                        ('access', (YLeaf(YType.str, 'access'), ['int','str'])),
                    ])
                    self.security_level = None
                    self.context = None
                    self.match = None
                    self.read = None
                    self.write = None
                    self.notify = None
                    self.access = None
                    self._segment_path = lambda: "v3"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SnmpServer.Group.V3, [u'security_level', u'context', u'match', u'read', u'write', u'notify', u'access'], name, value)

                class Match(Enum):
                    """
                    Match (Enum Class)

                    context name match criteria

                    .. data:: exact = 0

                    .. data:: prefix = 1

                    """

                    exact = Enum.YLeaf(0, "exact")

                    prefix = Enum.YLeaf(1, "prefix")


                class SecurityLevel(Enum):
                    """
                    SecurityLevel (Enum Class)

                    .. data:: auth = 0

                    .. data:: noauth = 1

                    .. data:: priv = 2

                    """

                    auth = Enum.YLeaf(0, "auth")

                    noauth = Enum.YLeaf(1, "noauth")

                    priv = Enum.YLeaf(2, "priv")



        class Host(Entity):
            """
            Specify hosts to receive SNMP notifications
            
            .. attribute:: ip_address  (key)
            
            	
            	**type**\: union of the below types:
            
            		**type**\: str
            
            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            		**type**\: str
            
            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            		**type**\: str
            
            			**pattern:** ((([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.)\*([a\-zA\-Z0\-9\_]([a\-zA\-Z0\-9\\\-\_]){0,61})?[a\-zA\-Z0\-9]\\.?)\|\\.
            
            .. attribute:: community_or_user  (key)
            
            	SNMPv1/v2c community string or SNMPv3 user name
            	**type**\: str
            
            .. attribute:: vrf
            
            	VPN Routing instance for this host
            	**type**\: str
            
            .. attribute:: informs
            
            	Send Inform messages to this host
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: traps
            
            	Send Trap messages to this host
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: version
            
            	SNMP version to use for notification messages
            	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Host.Version>`
            
            .. attribute:: security_level
            
            	
            	**type**\:  :py:class:`SecurityLevel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Host.SecurityLevel>`
            
            .. attribute:: udp_port
            
            	The notification host's UDP port number (default port 162)
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: trap_enable
            
            	
            	**type**\:  :py:class:`TrapEnable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Host.TrapEnable>`
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.Host, self).__init__()

                self.yang_name = "host"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['ip_address','community_or_user']
                self._child_classes = OrderedDict([("trap-enable", ("trap_enable", Native.SnmpServer.Host.TrapEnable))])
                self._leafs = OrderedDict([
                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str','str'])),
                    ('community_or_user', (YLeaf(YType.str, 'community-or-user'), ['str'])),
                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                    ('informs', (YLeaf(YType.empty, 'informs'), ['Empty'])),
                    ('traps', (YLeaf(YType.empty, 'traps'), ['Empty'])),
                    ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'SnmpServer.Host.Version')])),
                    ('security_level', (YLeaf(YType.enumeration, 'security-level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'SnmpServer.Host.SecurityLevel')])),
                    ('udp_port', (YLeaf(YType.uint16, 'udp-port'), ['int'])),
                ])
                self.ip_address = None
                self.community_or_user = None
                self.vrf = None
                self.informs = None
                self.traps = None
                self.version = None
                self.security_level = None
                self.udp_port = None

                self.trap_enable = Native.SnmpServer.Host.TrapEnable()
                self.trap_enable.parent = self
                self._children_name_map["trap_enable"] = "trap-enable"
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:host" + "[ip-address='" + str(self.ip_address) + "']" + "[community-or-user='" + str(self.community_or_user) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.Host, [u'ip_address', u'community_or_user', u'vrf', u'informs', u'traps', u'version', u'security_level', u'udp_port'], name, value)

            class SecurityLevel(Enum):
                """
                SecurityLevel (Enum Class)

                .. data:: auth = 0

                .. data:: noauth = 1

                .. data:: priv = 2

                """

                auth = Enum.YLeaf(0, "auth")

                noauth = Enum.YLeaf(1, "noauth")

                priv = Enum.YLeaf(2, "priv")


            class Version(Enum):
                """
                Version (Enum Class)

                SNMP version to use for notification messages

                .. data:: Y_1 = 0

                .. data:: Y_2c = 1

                .. data:: Y_3 = 2

                """

                Y_1 = Enum.YLeaf(0, "1")

                Y_2c = Enum.YLeaf(1, "2c")

                Y_3 = Enum.YLeaf(2, "3")



            class TrapEnable(Entity):
                """
                
                
                .. attribute:: aaa_server
                
                	Allow SNMP AAA traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: alarms
                
                	Allow SNMP alarms traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: atm
                
                	Allow SNMP atm traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bfd
                
                	Allow SNMP BFD traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bgp
                
                	Allow BGP state change traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bstun
                
                	Allow bstun event traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bulkstat
                
                	Allow Data\-Collection\-MIB traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: call_home
                
                	Allow SNMP CISCO\-CALLHOME\-MIB traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: casa
                
                	Allow casa event traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: cef
                
                	Allows cef traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: cnpd
                
                	Allow NBAR Protocol Discovery traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: config
                
                	Allow SNMP config traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: config_copy
                
                	Allow SNMP config\-copy traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: config_ctid
                
                	Allow SNMP config\-ctid traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: cpu
                
                	Allow cpu related traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dhcp
                
                	Allow dhcp traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dlsw
                
                	Allow dlsw traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ds1
                
                	Allow SNMP ds1 traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dsp
                
                	Allow SNMP DSP traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dspu
                
                	Allow dspu event traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: eigrp
                
                	Allow SNMP EIGRP traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: entity_
                
                	Allow SNMP entity traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: entity_diag
                
                	Allow SNMP CISCO\-ENTITY\-DIAG\-MIB traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: entity_qfp
                
                	Allow SNMP CISCO\-ENTITY\-QFP\-MIB traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: entity_state
                
                	Allow ENTITY\-STATE\-MIB traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ethernet_cfm
                
                	Allow SNMP Ethernet CFM traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: evc
                
                	Allow SNMP EVC traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: event_manager
                
                	Allow SNMP Embedded Event Manager traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: firewall
                
                	Allow SNMP Firewall traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: flash
                
                	Allow SNMP FLASH traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: flowmon
                
                	Allow SNMP flow monitor notifications
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: frame_relay
                
                	Allow SNMP frame\-relay traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: fru_ctrl
                
                	Allow entity FRU control traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: gdoi
                
                	Allows gdoi traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hsrp
                
                	Allow SNMP HSRP traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: iplocalpool
                
                	Allow SNMP IP Local Pool traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ipmulticast
                
                	Allow SNMP ipmulticast traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ipsec
                
                	Allow SNMP IPsec traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ipsla
                
                	Allow SNMP Host IP SLA traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: isakmp
                
                	Allow SNMP ISAKMP traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: isg_mib
                
                	Allow SNMP isgmib traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: isis
                
                	Allow IS\-IS traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: l2tun_pseudowire_status
                
                	Allow SNMP L2 pseudowire status traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: l2tun_session
                
                	Allow SNMP L2 session traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: license
                
                	Allow license traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: memory
                
                	Allow SNMP Mempool traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mpls_fast_reroute
                
                	Allow SNMP MPLS traffic engineering fast reroute traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mpls_ldp
                
                	Allow SNMP MPLS label distribution protocol traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mpls_traffic_eng
                
                	Allow SNMP MPLS traffic engineering traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mpls_vpn
                
                	Allow SNMP MPLS Virtual Private Network traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: msdp
                
                	Allow SNMP MSDP traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mvpn
                
                	Allow Multicast Virtual Private Network traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nhrp
                
                	Allow SNMP NHRP traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ospf
                
                	Allow OSPF traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ospfv3
                
                	Allow OSPFv3 traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pfr
                
                	Allow SNMP PfR traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pim
                
                	Allow SNMP PIM traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pw_vc
                
                	Allow SNMP Pseudowire VC traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: resource_policy
                
                	Enable CISCO\-ERM\-MIB notifications
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: rf
                
                	Allow all SNMP traps defined in CISCO\-RF\-MIB
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: rsrb
                
                	Allow rsrb event traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: rsvp
                
                	Allow RSVP flow change traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sdlc
                
                	Allow sdlc event traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sdllc
                
                	Allow sdllc event traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: snmp
                
                	Allow SNMP\-type notifications
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sonet
                
                	Allow SNMP SONET traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: srp
                
                	Allow SRP protocol traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: stun
                
                	Allow stun event traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: syslog
                
                	Allow SNMP syslog traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: trustsec_sxp
                
                	Allow SNMP CISCO\-TRUSTSEC\-SXP\-MIB traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: tty
                
                	Allow TCP connection traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: voice
                
                	Allow SNMP Voice traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vrfmib
                
                	Allow SNMP vrfmib traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vrrp
                
                	Allow SNMP vrrp traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: x25
                
                	Allow x25 event traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.Host.TrapEnable, self).__init__()

                    self.yang_name = "trap-enable"
                    self.yang_parent_name = "host"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('aaa_server', (YLeaf(YType.empty, 'aaa_server'), ['Empty'])),
                        ('alarms', (YLeaf(YType.empty, 'alarms'), ['Empty'])),
                        ('atm', (YLeaf(YType.empty, 'atm'), ['Empty'])),
                        ('bfd', (YLeaf(YType.empty, 'bfd'), ['Empty'])),
                        ('bgp', (YLeaf(YType.empty, 'bgp'), ['Empty'])),
                        ('bstun', (YLeaf(YType.empty, 'bstun'), ['Empty'])),
                        ('bulkstat', (YLeaf(YType.empty, 'bulkstat'), ['Empty'])),
                        ('call_home', (YLeaf(YType.empty, 'call-home'), ['Empty'])),
                        ('casa', (YLeaf(YType.empty, 'casa'), ['Empty'])),
                        ('cef', (YLeaf(YType.empty, 'cef'), ['Empty'])),
                        ('cnpd', (YLeaf(YType.empty, 'cnpd'), ['Empty'])),
                        ('config', (YLeaf(YType.empty, 'config'), ['Empty'])),
                        ('config_copy', (YLeaf(YType.empty, 'config-copy'), ['Empty'])),
                        ('config_ctid', (YLeaf(YType.empty, 'config-ctid'), ['Empty'])),
                        ('cpu', (YLeaf(YType.empty, 'cpu'), ['Empty'])),
                        ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                        ('dlsw', (YLeaf(YType.empty, 'dlsw'), ['Empty'])),
                        ('ds1', (YLeaf(YType.empty, 'ds1'), ['Empty'])),
                        ('dsp', (YLeaf(YType.empty, 'dsp'), ['Empty'])),
                        ('dspu', (YLeaf(YType.empty, 'dspu'), ['Empty'])),
                        ('eigrp', (YLeaf(YType.empty, 'eigrp'), ['Empty'])),
                        ('entity_', (YLeaf(YType.empty, 'entity'), ['Empty'])),
                        ('entity_diag', (YLeaf(YType.empty, 'entity-diag'), ['Empty'])),
                        ('entity_qfp', (YLeaf(YType.empty, 'entity-qfp'), ['Empty'])),
                        ('entity_state', (YLeaf(YType.empty, 'entity-state'), ['Empty'])),
                        ('ethernet_cfm', (YLeaf(YType.empty, 'ethernet-cfm'), ['Empty'])),
                        ('evc', (YLeaf(YType.empty, 'evc'), ['Empty'])),
                        ('event_manager', (YLeaf(YType.empty, 'event-manager'), ['Empty'])),
                        ('firewall', (YLeaf(YType.empty, 'firewall'), ['Empty'])),
                        ('flash', (YLeaf(YType.empty, 'flash'), ['Empty'])),
                        ('flowmon', (YLeaf(YType.empty, 'flowmon'), ['Empty'])),
                        ('frame_relay', (YLeaf(YType.empty, 'frame-relay'), ['Empty'])),
                        ('fru_ctrl', (YLeaf(YType.empty, 'fru-ctrl'), ['Empty'])),
                        ('gdoi', (YLeaf(YType.empty, 'gdoi'), ['Empty'])),
                        ('hsrp', (YLeaf(YType.empty, 'hsrp'), ['Empty'])),
                        ('iplocalpool', (YLeaf(YType.empty, 'iplocalpool'), ['Empty'])),
                        ('ipmulticast', (YLeaf(YType.empty, 'ipmulticast'), ['Empty'])),
                        ('ipsec', (YLeaf(YType.empty, 'ipsec'), ['Empty'])),
                        ('ipsla', (YLeaf(YType.empty, 'ipsla'), ['Empty'])),
                        ('isakmp', (YLeaf(YType.empty, 'isakmp'), ['Empty'])),
                        ('isg_mib', (YLeaf(YType.empty, 'isg-mib'), ['Empty'])),
                        ('isis', (YLeaf(YType.empty, 'isis'), ['Empty'])),
                        ('l2tun_pseudowire_status', (YLeaf(YType.empty, 'l2tun-pseudowire-status'), ['Empty'])),
                        ('l2tun_session', (YLeaf(YType.empty, 'l2tun-session'), ['Empty'])),
                        ('license', (YLeaf(YType.empty, 'license'), ['Empty'])),
                        ('memory', (YLeaf(YType.empty, 'memory'), ['Empty'])),
                        ('mpls_fast_reroute', (YLeaf(YType.empty, 'mpls-fast-reroute'), ['Empty'])),
                        ('mpls_ldp', (YLeaf(YType.empty, 'mpls-ldp'), ['Empty'])),
                        ('mpls_traffic_eng', (YLeaf(YType.empty, 'mpls-traffic-eng'), ['Empty'])),
                        ('mpls_vpn', (YLeaf(YType.empty, 'mpls-vpn'), ['Empty'])),
                        ('msdp', (YLeaf(YType.empty, 'msdp'), ['Empty'])),
                        ('mvpn', (YLeaf(YType.empty, 'mvpn'), ['Empty'])),
                        ('nhrp', (YLeaf(YType.empty, 'nhrp'), ['Empty'])),
                        ('ospf', (YLeaf(YType.empty, 'ospf'), ['Empty'])),
                        ('ospfv3', (YLeaf(YType.empty, 'ospfv3'), ['Empty'])),
                        ('pfr', (YLeaf(YType.empty, 'pfr'), ['Empty'])),
                        ('pim', (YLeaf(YType.empty, 'pim'), ['Empty'])),
                        ('pw_vc', (YLeaf(YType.empty, 'pw-vc'), ['Empty'])),
                        ('resource_policy', (YLeaf(YType.empty, 'resource-policy'), ['Empty'])),
                        ('rf', (YLeaf(YType.empty, 'rf'), ['Empty'])),
                        ('rsrb', (YLeaf(YType.empty, 'rsrb'), ['Empty'])),
                        ('rsvp', (YLeaf(YType.empty, 'rsvp'), ['Empty'])),
                        ('sdlc', (YLeaf(YType.empty, 'sdlc'), ['Empty'])),
                        ('sdllc', (YLeaf(YType.empty, 'sdllc'), ['Empty'])),
                        ('snmp', (YLeaf(YType.empty, 'snmp'), ['Empty'])),
                        ('sonet', (YLeaf(YType.empty, 'sonet'), ['Empty'])),
                        ('srp', (YLeaf(YType.empty, 'srp'), ['Empty'])),
                        ('stun', (YLeaf(YType.empty, 'stun'), ['Empty'])),
                        ('syslog', (YLeaf(YType.empty, 'syslog'), ['Empty'])),
                        ('trustsec_sxp', (YLeaf(YType.empty, 'trustsec-sxp'), ['Empty'])),
                        ('tty', (YLeaf(YType.empty, 'tty'), ['Empty'])),
                        ('voice', (YLeaf(YType.empty, 'voice'), ['Empty'])),
                        ('vrfmib', (YLeaf(YType.empty, 'vrfmib'), ['Empty'])),
                        ('vrrp', (YLeaf(YType.empty, 'vrrp'), ['Empty'])),
                        ('x25', (YLeaf(YType.empty, 'x25'), ['Empty'])),
                    ])
                    self.aaa_server = None
                    self.alarms = None
                    self.atm = None
                    self.bfd = None
                    self.bgp = None
                    self.bstun = None
                    self.bulkstat = None
                    self.call_home = None
                    self.casa = None
                    self.cef = None
                    self.cnpd = None
                    self.config = None
                    self.config_copy = None
                    self.config_ctid = None
                    self.cpu = None
                    self.dhcp = None
                    self.dlsw = None
                    self.ds1 = None
                    self.dsp = None
                    self.dspu = None
                    self.eigrp = None
                    self.entity_ = None
                    self.entity_diag = None
                    self.entity_qfp = None
                    self.entity_state = None
                    self.ethernet_cfm = None
                    self.evc = None
                    self.event_manager = None
                    self.firewall = None
                    self.flash = None
                    self.flowmon = None
                    self.frame_relay = None
                    self.fru_ctrl = None
                    self.gdoi = None
                    self.hsrp = None
                    self.iplocalpool = None
                    self.ipmulticast = None
                    self.ipsec = None
                    self.ipsla = None
                    self.isakmp = None
                    self.isg_mib = None
                    self.isis = None
                    self.l2tun_pseudowire_status = None
                    self.l2tun_session = None
                    self.license = None
                    self.memory = None
                    self.mpls_fast_reroute = None
                    self.mpls_ldp = None
                    self.mpls_traffic_eng = None
                    self.mpls_vpn = None
                    self.msdp = None
                    self.mvpn = None
                    self.nhrp = None
                    self.ospf = None
                    self.ospfv3 = None
                    self.pfr = None
                    self.pim = None
                    self.pw_vc = None
                    self.resource_policy = None
                    self.rf = None
                    self.rsrb = None
                    self.rsvp = None
                    self.sdlc = None
                    self.sdllc = None
                    self.snmp = None
                    self.sonet = None
                    self.srp = None
                    self.stun = None
                    self.syslog = None
                    self.trustsec_sxp = None
                    self.tty = None
                    self.voice = None
                    self.vrfmib = None
                    self.vrrp = None
                    self.x25 = None
                    self._segment_path = lambda: "trap-enable"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SnmpServer.Host.TrapEnable, [u'aaa_server', u'alarms', u'atm', u'bfd', u'bgp', u'bstun', u'bulkstat', u'call_home', u'casa', u'cef', u'cnpd', u'config', u'config_copy', u'config_ctid', u'cpu', u'dhcp', u'dlsw', u'ds1', u'dsp', u'dspu', u'eigrp', u'entity_', u'entity_diag', u'entity_qfp', u'entity_state', u'ethernet_cfm', u'evc', u'event_manager', u'firewall', u'flash', u'flowmon', u'frame_relay', u'fru_ctrl', u'gdoi', u'hsrp', u'iplocalpool', u'ipmulticast', u'ipsec', u'ipsla', u'isakmp', u'isg_mib', u'isis', u'l2tun_pseudowire_status', u'l2tun_session', u'license', u'memory', u'mpls_fast_reroute', u'mpls_ldp', u'mpls_traffic_eng', u'mpls_vpn', u'msdp', u'mvpn', u'nhrp', u'ospf', u'ospfv3', u'pfr', u'pim', u'pw_vc', u'resource_policy', u'rf', u'rsrb', u'rsvp', u'sdlc', u'sdllc', u'snmp', u'sonet', u'srp', u'stun', u'syslog', u'trustsec_sxp', u'tty', u'voice', u'vrfmib', u'vrrp', u'x25'], name, value)


        class Ip(Entity):
            """
            IP ToS configuration for SNMP traffic
            
            .. attribute:: dscp
            
            	IP DSCP value for SNMP traffic
            	**type**\: int
            
            	**range:** 0..63
            
            .. attribute:: precedence
            
            	IP Precedence value for SNMP traffic
            	**type**\: int
            
            	**range:** 0..7
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.Ip, self).__init__()

                self.yang_name = "ip"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('dscp', (YLeaf(YType.uint8, 'dscp'), ['int'])),
                    ('precedence', (YLeaf(YType.uint8, 'precedence'), ['int'])),
                ])
                self.dscp = None
                self.precedence = None
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:ip"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.Ip, [u'dscp', u'precedence'], name, value)


        class Ifindex(Entity):
            """
            Enable ifindex persistence
            
            .. attribute:: persist
            
            	Persist interface indices
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.Ifindex, self).__init__()

                self.yang_name = "ifindex"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('persist', (YLeaf(YType.empty, 'persist'), ['Empty'])),
                ])
                self.persist = None
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:ifindex"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.Ifindex, [u'persist'], name, value)


        class Manager(Entity):
            """
            Modify SNMP manager parameters
            
            .. attribute:: session_timeout
            
            	Timeout value for destroying sessions
            	**type**\: int
            
            	**range:** 10..2147483
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.Manager, self).__init__()

                self.yang_name = "manager"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('session_timeout', (YLeaf(YType.uint32, 'session-timeout'), ['int'])),
                ])
                self.session_timeout = None
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:manager"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.Manager, [u'session_timeout'], name, value)


        class SourceInterface(Entity):
            """
            Assign an source interface
            
            .. attribute:: informs
            
            	source interface for informs
            	**type**\:  :py:class:`Informs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.SourceInterface.Informs>`
            
            .. attribute:: traps
            
            	source interface for traps
            	**type**\:  :py:class:`Traps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.SourceInterface.Traps>`
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.SourceInterface, self).__init__()

                self.yang_name = "source-interface"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("informs", ("informs", Native.SnmpServer.SourceInterface.Informs)), ("traps", ("traps", Native.SnmpServer.SourceInterface.Traps))])
                self._leafs = OrderedDict()

                self.informs = Native.SnmpServer.SourceInterface.Informs()
                self.informs.parent = self
                self._children_name_map["informs"] = "informs"

                self.traps = Native.SnmpServer.SourceInterface.Traps()
                self.traps.parent = self
                self._children_name_map["traps"] = "traps"
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:source-interface"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.SourceInterface, [], name, value)


            class Informs(Entity):
                """
                source interface for informs
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.SourceInterface.Informs.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.SourceInterface.Informs.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.SourceInterface.Informs.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.SourceInterface.Informs.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.SourceInterface.Informs, self).__init__()

                    self.yang_name = "informs"
                    self.yang_parent_name = "source-interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.SnmpServer.SourceInterface.Informs.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.SnmpServer.SourceInterface.Informs.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.SnmpServer.SourceInterface.Informs.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.SnmpServer.SourceInterface.Informs.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.SnmpServer.SourceInterface.Informs.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.SnmpServer.SourceInterface.Informs.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.SnmpServer.SourceInterface.Informs.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.SnmpServer.SourceInterface.Informs.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "informs"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:source-interface/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SnmpServer.SourceInterface.Informs, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.SnmpServer.SourceInterface.Informs.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "informs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:source-interface/informs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SnmpServer.SourceInterface.Informs.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.SnmpServer.SourceInterface.Informs.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "informs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:source-interface/informs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SnmpServer.SourceInterface.Informs.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.SnmpServer.SourceInterface.Informs.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "informs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:source-interface/informs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SnmpServer.SourceInterface.Informs.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.SnmpServer.SourceInterface.Informs.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "informs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:source-interface/informs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SnmpServer.SourceInterface.Informs.PortChannelSubinterface, [u'port_channel'], name, value)


            class Traps(Entity):
                """
                source interface for traps
                
                .. attribute:: appnav_compress
                
                	Service\-Context Virtual Interface Compress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: appnav_uncompress
                
                	Service\-Context Virtual Interface UnCompress
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: atm
                
                	ATM interface
                	**type**\: str
                
                .. attribute:: atm_subinterface
                
                	
                	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.SourceInterface.Traps.ATMSubinterface>`
                
                .. attribute:: atm_acr
                
                	ATM\-ACR interface
                	**type**\: str
                
                	**pattern:** [0\-9]
                
                .. attribute:: atm_acrsubinterface
                
                	
                	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.SourceInterface.Traps.ATMACRsubinterface>`
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                .. attribute:: cem
                
                	CEM interface
                	**type**\: str
                
                	**pattern:** ([0\-9]/){2}[0\-9]
                
                .. attribute:: cem_acr
                
                	CEM\-ACR interface
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: embedded_service_engine
                
                	cisco embedded service engine module
                	**type**\: str
                
                .. attribute:: ethernet
                
                	IEEE 802.3
                	**type**\: str
                
                .. attribute:: fastethernet
                
                	FastEthernet IEEE 802.3
                	**type**\: str
                
                .. attribute:: gigabitethernet
                
                	GigabitEthernet IEEE 802.3z
                	**type**\: str
                
                .. attribute:: fivegigabitethernet
                
                	Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twentyfivegige
                
                	Twenty Five GigabitEthernet 
                	**type**\: str
                
                .. attribute:: twogigabitethernet
                
                	Two GigabitEthernet 
                	**type**\: str
                
                .. attribute:: fortygigabitethernet
                
                	Forty GigabitEthernet 
                	**type**\: str
                
                .. attribute:: hundredgige
                
                	Hundred GigabitEthernet
                	**type**\: str
                
                .. attribute:: lisp
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\: str
                
                .. attribute:: lisp_subinterface
                
                	Locator/ID Separation Protocol Virtual Interface
                	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.SourceInterface.Traps.LISPSubinterface>`
                
                .. attribute:: loopback
                
                	Loopback interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: multilink
                
                	Multilink\-group interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: nve
                
                	Network virtualization endpoint interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: overlay
                
                	Overlay interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: port_channel
                
                	Ethernet Channel of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_channel_subinterface
                
                	
                	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.SourceInterface.Traps.PortChannelSubinterface>`
                
                .. attribute:: pseudowire
                
                	Pseudowire Interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sm
                
                	SM Interface
                	**type**\: str
                
                .. attribute:: cellular
                
                	Cellular Interface
                	**type**\: str
                
                .. attribute:: serial
                
                	Serial interface
                	**type**\: str
                
                .. attribute:: tengigabitethernet
                
                	Ten Gigabit Ethernet
                	**type**\: str
                
                .. attribute:: tunnel
                
                	Tunnel interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_template
                
                	Virtual Template interface
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vlan
                
                	Iosxr Vlans
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasileft
                
                	vasileft
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: vasiright
                
                	vasiright
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.SourceInterface.Traps, self).__init__()

                    self.yang_name = "traps"
                    self.yang_parent_name = "source-interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.SnmpServer.SourceInterface.Traps.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.SnmpServer.SourceInterface.Traps.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.SnmpServer.SourceInterface.Traps.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.SnmpServer.SourceInterface.Traps.PortChannelSubinterface))])
                    self._leafs = OrderedDict([
                        ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                        ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                        ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                        ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                        ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                        ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                        ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                        ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                        ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                        ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                        ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                        ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                        ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                        ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                        ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                        ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                        ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                        ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                        ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                        ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                        ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                        ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                        ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                        ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                        ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                        ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                    ])
                    self.appnav_compress = None
                    self.appnav_uncompress = None
                    self.atm = None
                    self.atm_acr = None
                    self.bdi = None
                    self.cem = None
                    self.cem_acr = None
                    self.embedded_service_engine = None
                    self.ethernet = None
                    self.fastethernet = None
                    self.gigabitethernet = None
                    self.fivegigabitethernet = None
                    self.twentyfivegige = None
                    self.twogigabitethernet = None
                    self.fortygigabitethernet = None
                    self.hundredgige = None
                    self.lisp = None
                    self.loopback = None
                    self.multilink = None
                    self.nve = None
                    self.overlay = None
                    self.port_channel = None
                    self.pseudowire = None
                    self.sm = None
                    self.cellular = None
                    self.serial = None
                    self.tengigabitethernet = None
                    self.tunnel = None
                    self.virtual_template = None
                    self.vlan = None
                    self.virtualportgroup = None
                    self.vasileft = None
                    self.vasiright = None

                    self.atm_subinterface = Native.SnmpServer.SourceInterface.Traps.ATMSubinterface()
                    self.atm_subinterface.parent = self
                    self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                    self.atm_acrsubinterface = Native.SnmpServer.SourceInterface.Traps.ATMACRsubinterface()
                    self.atm_acrsubinterface.parent = self
                    self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                    self.lisp_subinterface = Native.SnmpServer.SourceInterface.Traps.LISPSubinterface()
                    self.lisp_subinterface.parent = self
                    self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                    self.port_channel_subinterface = Native.SnmpServer.SourceInterface.Traps.PortChannelSubinterface()
                    self.port_channel_subinterface.parent = self
                    self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                    self._segment_path = lambda: "traps"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:source-interface/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SnmpServer.SourceInterface.Traps, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


                class ATMSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.SnmpServer.SourceInterface.Traps.ATMSubinterface, self).__init__()

                        self.yang_name = "ATM-subinterface"
                        self.yang_parent_name = "traps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                        ])
                        self.atm = None
                        self._segment_path = lambda: "ATM-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:source-interface/traps/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SnmpServer.SourceInterface.Traps.ATMSubinterface, [u'atm'], name, value)


                class ATMACRsubinterface(Entity):
                    """
                    
                    
                    .. attribute:: atm_acr
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.SnmpServer.SourceInterface.Traps.ATMACRsubinterface, self).__init__()

                        self.yang_name = "ATM-ACRsubinterface"
                        self.yang_parent_name = "traps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                        ])
                        self.atm_acr = None
                        self._segment_path = lambda: "ATM-ACRsubinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:source-interface/traps/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SnmpServer.SourceInterface.Traps.ATMACRsubinterface, [u'atm_acr'], name, value)


                class LISPSubinterface(Entity):
                    """
                    Locator/ID Separation Protocol Virtual Interface
                    
                    .. attribute:: lisp
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.SnmpServer.SourceInterface.Traps.LISPSubinterface, self).__init__()

                        self.yang_name = "LISP-subinterface"
                        self.yang_parent_name = "traps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                        ])
                        self.lisp = None
                        self._segment_path = lambda: "LISP-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:source-interface/traps/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SnmpServer.SourceInterface.Traps.LISPSubinterface, [u'lisp'], name, value)


                class PortChannelSubinterface(Entity):
                    """
                    
                    
                    .. attribute:: port_channel
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.SnmpServer.SourceInterface.Traps.PortChannelSubinterface, self).__init__()

                        self.yang_name = "Port-channel-subinterface"
                        self.yang_parent_name = "traps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                        ])
                        self.port_channel = None
                        self._segment_path = lambda: "Port-channel-subinterface"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:source-interface/traps/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SnmpServer.SourceInterface.Traps.PortChannelSubinterface, [u'port_channel'], name, value)


        class Trap(Entity):
            """
            SNMP trap options
            
            .. attribute:: link
            
            	Assign/Enable SNMP link traps
            	**type**\:  :py:class:`Link <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.Trap.Link>`
            
            .. attribute:: timeout
            
            	Set timeout for TRAP message retransmissions
            	**type**\: int
            
            	**range:** 1..1000
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.Trap, self).__init__()

                self.yang_name = "trap"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("link", ("link", Native.SnmpServer.Trap.Link))])
                self._leafs = OrderedDict([
                    ('timeout', (YLeaf(YType.uint16, 'timeout'), ['int'])),
                ])
                self.timeout = None

                self.link = Native.SnmpServer.Trap.Link()
                self.link.parent = self
                self._children_name_map["link"] = "link"
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:trap"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.Trap, [u'timeout'], name, value)


            class Link(Entity):
                """
                Assign/Enable SNMP link traps
                
                .. attribute:: ietf
                
                	Use IETF standard for SNMP traps
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: switchover
                
                	Enable link up/down traps during switchover
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.Trap.Link, self).__init__()

                    self.yang_name = "link"
                    self.yang_parent_name = "trap"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ietf', (YLeaf(YType.empty, 'ietf'), ['Empty'])),
                        ('switchover', (YLeaf(YType.empty, 'switchover'), ['Empty'])),
                    ])
                    self.ietf = None
                    self.switchover = None
                    self._segment_path = lambda: "link"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:trap/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SnmpServer.Trap.Link, [u'ietf', u'switchover'], name, value)


        class TrapSource(Entity):
            """
            Assign an interface for the source address of all traps
            
            .. attribute:: appnav_compress
            
            	Service\-Context Virtual Interface Compress
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: appnav_uncompress
            
            	Service\-Context Virtual Interface UnCompress
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: atm
            
            	ATM interface
            	**type**\: str
            
            .. attribute:: atm_subinterface
            
            	
            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.TrapSource.ATMSubinterface>`
            
            .. attribute:: atm_acr
            
            	ATM\-ACR interface
            	**type**\: str
            
            	**pattern:** [0\-9]
            
            .. attribute:: atm_acrsubinterface
            
            	
            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.TrapSource.ATMACRsubinterface>`
            
            .. attribute:: bdi
            
            	Bridge\-Domain interface
            	**type**\: str
            
            .. attribute:: cem
            
            	CEM interface
            	**type**\: str
            
            	**pattern:** ([0\-9]/){2}[0\-9]
            
            .. attribute:: cem_acr
            
            	CEM\-ACR interface
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: embedded_service_engine
            
            	cisco embedded service engine module
            	**type**\: str
            
            .. attribute:: ethernet
            
            	IEEE 802.3
            	**type**\: str
            
            .. attribute:: fastethernet
            
            	FastEthernet IEEE 802.3
            	**type**\: str
            
            .. attribute:: gigabitethernet
            
            	GigabitEthernet IEEE 802.3z
            	**type**\: str
            
            .. attribute:: fivegigabitethernet
            
            	Five GigabitEthernet 
            	**type**\: str
            
            .. attribute:: twentyfivegige
            
            	Twenty Five GigabitEthernet 
            	**type**\: str
            
            .. attribute:: twogigabitethernet
            
            	Two GigabitEthernet 
            	**type**\: str
            
            .. attribute:: fortygigabitethernet
            
            	Forty GigabitEthernet 
            	**type**\: str
            
            .. attribute:: hundredgige
            
            	Hundred GigabitEthernet
            	**type**\: str
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol Virtual Interface
            	**type**\: str
            
            .. attribute:: lisp_subinterface
            
            	Locator/ID Separation Protocol Virtual Interface
            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.TrapSource.LISPSubinterface>`
            
            .. attribute:: loopback
            
            	Loopback interface
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: multilink
            
            	Multilink\-group interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: nve
            
            	Network virtualization endpoint interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: overlay
            
            	Overlay interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: port_channel
            
            	Ethernet Channel of interfaces
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: port_channel_subinterface
            
            	
            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.TrapSource.PortChannelSubinterface>`
            
            .. attribute:: pseudowire
            
            	Pseudowire Interface
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: sm
            
            	SM Interface
            	**type**\: str
            
            .. attribute:: cellular
            
            	Cellular Interface
            	**type**\: str
            
            .. attribute:: serial
            
            	Serial interface
            	**type**\: str
            
            .. attribute:: tengigabitethernet
            
            	Ten Gigabit Ethernet
            	**type**\: str
            
            .. attribute:: tunnel
            
            	Tunnel interface
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: virtual_template
            
            	Virtual Template interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: vlan
            
            	Iosxr Vlans
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: virtualportgroup
            
            	Virtual Port Group
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: vasileft
            
            	vasileft
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: vasiright
            
            	vasiright
            	**type**\: int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.TrapSource, self).__init__()

                self.yang_name = "trap-source"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.SnmpServer.TrapSource.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.SnmpServer.TrapSource.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.SnmpServer.TrapSource.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.SnmpServer.TrapSource.PortChannelSubinterface))])
                self._leafs = OrderedDict([
                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                ])
                self.appnav_compress = None
                self.appnav_uncompress = None
                self.atm = None
                self.atm_acr = None
                self.bdi = None
                self.cem = None
                self.cem_acr = None
                self.embedded_service_engine = None
                self.ethernet = None
                self.fastethernet = None
                self.gigabitethernet = None
                self.fivegigabitethernet = None
                self.twentyfivegige = None
                self.twogigabitethernet = None
                self.fortygigabitethernet = None
                self.hundredgige = None
                self.lisp = None
                self.loopback = None
                self.multilink = None
                self.nve = None
                self.overlay = None
                self.port_channel = None
                self.pseudowire = None
                self.sm = None
                self.cellular = None
                self.serial = None
                self.tengigabitethernet = None
                self.tunnel = None
                self.virtual_template = None
                self.vlan = None
                self.virtualportgroup = None
                self.vasileft = None
                self.vasiright = None

                self.atm_subinterface = Native.SnmpServer.TrapSource.ATMSubinterface()
                self.atm_subinterface.parent = self
                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                self.atm_acrsubinterface = Native.SnmpServer.TrapSource.ATMACRsubinterface()
                self.atm_acrsubinterface.parent = self
                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                self.lisp_subinterface = Native.SnmpServer.TrapSource.LISPSubinterface()
                self.lisp_subinterface.parent = self
                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                self.port_channel_subinterface = Native.SnmpServer.TrapSource.PortChannelSubinterface()
                self.port_channel_subinterface.parent = self
                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:trap-source"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.TrapSource, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


            class ATMSubinterface(Entity):
                """
                
                
                .. attribute:: atm
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.TrapSource.ATMSubinterface, self).__init__()

                    self.yang_name = "ATM-subinterface"
                    self.yang_parent_name = "trap-source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                    ])
                    self.atm = None
                    self._segment_path = lambda: "ATM-subinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:trap-source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SnmpServer.TrapSource.ATMSubinterface, [u'atm'], name, value)


            class ATMACRsubinterface(Entity):
                """
                
                
                .. attribute:: atm_acr
                
                	
                	**type**\: str
                
                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.TrapSource.ATMACRsubinterface, self).__init__()

                    self.yang_name = "ATM-ACRsubinterface"
                    self.yang_parent_name = "trap-source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                    ])
                    self.atm_acr = None
                    self._segment_path = lambda: "ATM-ACRsubinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:trap-source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SnmpServer.TrapSource.ATMACRsubinterface, [u'atm_acr'], name, value)


            class LISPSubinterface(Entity):
                """
                Locator/ID Separation Protocol Virtual Interface
                
                .. attribute:: lisp
                
                	
                	**type**\: str
                
                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.TrapSource.LISPSubinterface, self).__init__()

                    self.yang_name = "LISP-subinterface"
                    self.yang_parent_name = "trap-source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                    ])
                    self.lisp = None
                    self._segment_path = lambda: "LISP-subinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:trap-source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SnmpServer.TrapSource.LISPSubinterface, [u'lisp'], name, value)


            class PortChannelSubinterface(Entity):
                """
                
                
                .. attribute:: port_channel
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.TrapSource.PortChannelSubinterface, self).__init__()

                    self.yang_name = "Port-channel-subinterface"
                    self.yang_parent_name = "trap-source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                    ])
                    self.port_channel = None
                    self._segment_path = lambda: "Port-channel-subinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:trap-source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SnmpServer.TrapSource.PortChannelSubinterface, [u'port_channel'], name, value)


        class User(Entity):
            """
            Define a user who can access the SNMP engine
            
            .. attribute:: names
            
            	
            	**type**\: list of  		 :py:class:`Names <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.User.Names>`
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.User, self).__init__()

                self.yang_name = "user"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("names", ("names", Native.SnmpServer.User.Names))])
                self._leafs = OrderedDict()

                self.names = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:user"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.User, [], name, value)


            class Names(Entity):
                """
                
                
                .. attribute:: username  (key)
                
                	Name of the user
                	**type**\: str
                
                .. attribute:: grpname  (key)
                
                	Group to which the user belongs
                	**type**\: str
                
                .. attribute:: v3
                
                	user using the v3 security model
                	**type**\:  :py:class:`V3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.User.Names.V3>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-snmp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.SnmpServer.User.Names, self).__init__()

                    self.yang_name = "names"
                    self.yang_parent_name = "user"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['username','grpname']
                    self._child_classes = OrderedDict([("v3", ("v3", Native.SnmpServer.User.Names.V3))])
                    self._leafs = OrderedDict([
                        ('username', (YLeaf(YType.str, 'username'), ['str'])),
                        ('grpname', (YLeaf(YType.str, 'grpname'), ['str'])),
                    ])
                    self.username = None
                    self.grpname = None

                    self.v3 = None
                    self._children_name_map["v3"] = "v3"
                    self._segment_path = lambda: "names" + "[username='" + str(self.username) + "']" + "[grpname='" + str(self.grpname) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/Cisco-IOS-XE-snmp:user/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SnmpServer.User.Names, [u'username', u'grpname'], name, value)


                class V3(Entity):
                    """
                    user using the v3 security model
                    
                    .. attribute:: auth
                    
                    	authentication parameters for the user
                    	**type**\:  :py:class:`Auth <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.User.Names.V3.Auth>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-snmp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.SnmpServer.User.Names.V3, self).__init__()

                        self.yang_name = "v3"
                        self.yang_parent_name = "names"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auth", ("auth", Native.SnmpServer.User.Names.V3.Auth))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.auth = Native.SnmpServer.User.Names.V3.Auth()
                        self.auth.parent = self
                        self._children_name_map["auth"] = "auth"
                        self._segment_path = lambda: "v3"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SnmpServer.User.Names.V3, [], name, value)


                    class Auth(Entity):
                        """
                        authentication parameters for the user
                        
                        .. attribute:: sha
                        
                        	Use HMAC SHA algorithm for authentication
                        	**type**\:  :py:class:`Sha <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.User.Names.V3.Auth.Sha>`
                        
                        

                        """

                        _prefix = 'ios-snmp'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.SnmpServer.User.Names.V3.Auth, self).__init__()

                            self.yang_name = "auth"
                            self.yang_parent_name = "v3"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sha", ("sha", Native.SnmpServer.User.Names.V3.Auth.Sha))])
                            self._leafs = OrderedDict()

                            self.sha = Native.SnmpServer.User.Names.V3.Auth.Sha()
                            self.sha.parent = self
                            self._children_name_map["sha"] = "sha"
                            self._segment_path = lambda: "auth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SnmpServer.User.Names.V3.Auth, [], name, value)


                        class Sha(Entity):
                            """
                            Use HMAC SHA algorithm for authentication
                            
                            .. attribute:: auth
                            
                            	
                            	**type**\:  :py:class:`Auth_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_>`
                            
                            

                            """

                            _prefix = 'ios-snmp'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.SnmpServer.User.Names.V3.Auth.Sha, self).__init__()

                                self.yang_name = "sha"
                                self.yang_parent_name = "auth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("auth", ("auth", Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_))])
                                self._leafs = OrderedDict()

                                self.auth = Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_()
                                self.auth.parent = self
                                self._children_name_map["auth"] = "auth"
                                self._segment_path = lambda: "sha"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SnmpServer.User.Names.V3.Auth.Sha, [], name, value)


                            class Auth_(Entity):
                                """
                                
                                
                                .. attribute:: authpass
                                
                                	authentication password for user
                                	**type**\: str
                                
                                .. attribute:: priv
                                
                                	encryption parameters for the user
                                	**type**\:  :py:class:`Priv <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv>`
                                
                                

                                """

                                _prefix = 'ios-snmp'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_, self).__init__()

                                    self.yang_name = "auth"
                                    self.yang_parent_name = "sha"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("priv", ("priv", Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv))])
                                    self._leafs = OrderedDict([
                                        ('authpass', (YLeaf(YType.str, 'authpass'), ['str'])),
                                    ])
                                    self.authpass = None

                                    self.priv = Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv()
                                    self.priv.parent = self
                                    self._children_name_map["priv"] = "priv"
                                    self._segment_path = lambda: "auth"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_, [u'authpass'], name, value)


                                class Priv(Entity):
                                    """
                                    encryption parameters for the user
                                    
                                    .. attribute:: aes
                                    
                                    	Use AES algorithm for encryption
                                    	**type**\:  :py:class:`Aes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes>`
                                    
                                    

                                    """

                                    _prefix = 'ios-snmp'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv, self).__init__()

                                        self.yang_name = "priv"
                                        self.yang_parent_name = "auth"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("aes", ("aes", Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes))])
                                        self._leafs = OrderedDict()

                                        self.aes = Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes()
                                        self.aes.parent = self
                                        self._children_name_map["aes"] = "aes"
                                        self._segment_path = lambda: "priv"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv, [], name, value)


                                    class Aes(Entity):
                                        """
                                        Use AES algorithm for encryption
                                        
                                        .. attribute:: algo128
                                        
                                        	Use 128 bit AES algorithm for encryption
                                        	**type**\:  :py:class:`Algo128 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes.Algo128>`
                                        
                                        

                                        """

                                        _prefix = 'ios-snmp'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes, self).__init__()

                                            self.yang_name = "aes"
                                            self.yang_parent_name = "priv"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("algo128", ("algo128", Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes.Algo128))])
                                            self._leafs = OrderedDict()

                                            self.algo128 = Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes.Algo128()
                                            self.algo128.parent = self
                                            self._children_name_map["algo128"] = "algo128"
                                            self._segment_path = lambda: "aes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes, [], name, value)


                                        class Algo128(Entity):
                                            """
                                            Use 128 bit AES algorithm for encryption
                                            
                                            .. attribute:: privpass
                                            
                                            	
                                            	**type**\:  :py:class:`Privpass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes.Algo128.Privpass>`
                                            
                                            

                                            """

                                            _prefix = 'ios-snmp'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes.Algo128, self).__init__()

                                                self.yang_name = "algo128"
                                                self.yang_parent_name = "aes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("privpass", ("privpass", Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes.Algo128.Privpass))])
                                                self._leafs = OrderedDict()

                                                self.privpass = Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes.Algo128.Privpass()
                                                self.privpass.parent = self
                                                self._children_name_map["privpass"] = "privpass"
                                                self._segment_path = lambda: "algo128"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes.Algo128, [], name, value)


                                            class Privpass(Entity):
                                                """
                                                
                                                
                                                .. attribute:: privpass
                                                
                                                	privacy password for user
                                                	**type**\: str
                                                
                                                .. attribute:: access
                                                
                                                	Access\-list name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'ios-snmp'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes.Algo128.Privpass, self).__init__()

                                                    self.yang_name = "privpass"
                                                    self.yang_parent_name = "algo128"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('privpass', (YLeaf(YType.str, 'privpass'), ['str'])),
                                                        ('access', (YLeaf(YType.str, 'access'), ['str'])),
                                                    ])
                                                    self.privpass = None
                                                    self.access = None
                                                    self._segment_path = lambda: "privpass"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.SnmpServer.User.Names.V3.Auth.Sha.Auth_.Priv.Aes.Algo128.Privpass, [u'privpass', u'access'], name, value)


        class View(Entity):
            """
            Define an SNMPv2 MIB view
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: mib  (key)
            
            	
            	**type**\: str
            
            .. attribute:: inc_exl
            
            	
            	**type**\:  :py:class:`IncExl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SnmpServer.View.IncExl>`
            
            

            """

            _prefix = 'ios-snmp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.SnmpServer.View, self).__init__()

                self.yang_name = "view"
                self.yang_parent_name = "snmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name','mib']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('mib', (YLeaf(YType.str, 'mib'), ['str'])),
                    ('inc_exl', (YLeaf(YType.enumeration, 'inc-exl'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'SnmpServer.View.IncExl')])),
                ])
                self.name = None
                self.mib = None
                self.inc_exl = None
                self._segment_path = lambda: "Cisco-IOS-XE-snmp:view" + "[name='" + str(self.name) + "']" + "[mib='" + str(self.mib) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/snmp-server/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SnmpServer.View, [u'name', u'mib', u'inc_exl'], name, value)

            class IncExl(Enum):
                """
                IncExl (Enum Class)

                .. data:: excluded = 0

                .. data:: included = 1

                """

                excluded = Enum.YLeaf(0, "excluded")

                included = Enum.YLeaf(1, "included")



    class SegmentRouting(Entity):
        """
        Enter Segment Routing Mode
        
        .. attribute:: mpls
        
        	Segment Routing MPLS Mode
        	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.SegmentRouting, self).__init__()

            self.yang_name = "segment-routing"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-segment-routing:mpls", ("mpls", Native.SegmentRouting.Mpls))])
            self._leafs = OrderedDict()

            self.mpls = None
            self._children_name_map["mpls"] = "Cisco-IOS-XE-segment-routing:mpls"
            self._segment_path = lambda: "segment-routing"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.SegmentRouting, [], name, value)


        class Mpls(Entity):
            """
            Segment Routing MPLS Mode
            
            .. attribute:: connected_prefix_sid_map
            
            	Enter Connected Prefix Sid Map  Mode
            	**type**\:  :py:class:`ConnectedPrefixSidMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap>`
            
            	**presence node**\: True
            
            .. attribute:: global_block
            
            	SR Global Block Config
            	**type**\:  :py:class:`GlobalBlock <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.GlobalBlock>`
            
            .. attribute:: mapping_server
            
            	Enter Segment Routing Mapping Server Mode
            	**type**\:  :py:class:`MappingServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer>`
            
            	**presence node**\: True
            
            .. attribute:: set_attributes
            
            	Enter SR Set Attributes  Mode
            	**type**\:  :py:class:`SetAttributes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.SetAttributes>`
            
            	**presence node**\: True
            
            .. attribute:: shutdown
            
            	SR Shutdown
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-segment-routing'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.SegmentRouting.Mpls, self).__init__()

                self.yang_name = "mpls"
                self.yang_parent_name = "segment-routing"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("connected-prefix-sid-map", ("connected_prefix_sid_map", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap)), ("global-block", ("global_block", Native.SegmentRouting.Mpls.GlobalBlock)), ("mapping-server", ("mapping_server", Native.SegmentRouting.Mpls.MappingServer)), ("set-attributes", ("set_attributes", Native.SegmentRouting.Mpls.SetAttributes))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                ])
                self.shutdown = None

                self.connected_prefix_sid_map = None
                self._children_name_map["connected_prefix_sid_map"] = "connected-prefix-sid-map"

                self.global_block = Native.SegmentRouting.Mpls.GlobalBlock()
                self.global_block.parent = self
                self._children_name_map["global_block"] = "global-block"

                self.mapping_server = None
                self._children_name_map["mapping_server"] = "mapping-server"

                self.set_attributes = None
                self._children_name_map["set_attributes"] = "set-attributes"
                self._segment_path = lambda: "Cisco-IOS-XE-segment-routing:mpls"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SegmentRouting.Mpls, ['shutdown'], name, value)


            class ConnectedPrefixSidMap(Entity):
                """
                Enter Connected Prefix Sid Map  Mode
                
                .. attribute:: address_family
                
                	
                	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-segment-routing'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap, self).__init__()

                    self.yang_name = "connected-prefix-sid-map"
                    self.yang_parent_name = "mpls"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("address-family", ("address_family", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.address_family = Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily()
                    self.address_family.parent = self
                    self._children_name_map["address_family"] = "address-family"
                    self._segment_path = lambda: "connected-prefix-sid-map"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap, [], name, value)


                class AddressFamily(Entity):
                    """
                    
                    
                    .. attribute:: ipv4
                    
                    	
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: ipv4_strict_spf
                    
                    	
                    	**type**\:  :py:class:`Ipv4StrictSpf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf>`
                    
                    

                    """

                    _prefix = 'ios-segment-routing'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily, self).__init__()

                        self.yang_name = "address-family"
                        self.yang_parent_name = "connected-prefix-sid-map"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4)), ("ipv4-strict-spf", ("ipv4_strict_spf", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf))])
                        self._leafs = OrderedDict()

                        self.ipv4 = None
                        self._children_name_map["ipv4"] = "ipv4"

                        self.ipv4_strict_spf = Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf()
                        self.ipv4_strict_spf.parent = self
                        self._children_name_map["ipv4_strict_spf"] = "ipv4-strict-spf"
                        self._segment_path = lambda: "address-family"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/connected-prefix-sid-map/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily, [], name, value)


                    class Ipv4(Entity):
                        """
                        
                        
                        .. attribute:: prefixes
                        
                        	
                        	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-segment-routing'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "address-family"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.prefixes = YList(self)
                            self._segment_path = lambda: "ipv4"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/connected-prefix-sid-map/address-family/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4, [], name, value)


                        class Prefixes(Entity):
                            """
                            
                            
                            .. attribute:: ipprefix  (key)
                            
                            	
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            .. attribute:: index
                            
                            	
                            	**type**\:  :py:class:`Index <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes.Index>`
                            
                            .. attribute:: absolute
                            
                            	
                            	**type**\:  :py:class:`Absolute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes.Absolute>`
                            
                            

                            """

                            _prefix = 'ios-segment-routing'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes, self).__init__()

                                self.yang_name = "prefixes"
                                self.yang_parent_name = "ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['ipprefix']
                                self._child_classes = OrderedDict([("index", ("index", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes.Index)), ("absolute", ("absolute", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes.Absolute))])
                                self._leafs = OrderedDict([
                                    ('ipprefix', (YLeaf(YType.str, 'ipprefix'), ['str'])),
                                ])
                                self.ipprefix = None

                                self.index = Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes.Index()
                                self.index.parent = self
                                self._children_name_map["index"] = "index"

                                self.absolute = Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes.Absolute()
                                self.absolute.parent = self
                                self._children_name_map["absolute"] = "absolute"
                                self._segment_path = lambda: "prefixes" + "[ipprefix='" + str(self.ipprefix) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/connected-prefix-sid-map/address-family/ipv4/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes, ['ipprefix'], name, value)


                            class Index(Entity):
                                """
                                
                                
                                .. attribute:: range_start
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..1048575
                                
                                .. attribute:: range
                                
                                	Range value
                                	**type**\: int
                                
                                	**range:** 1..1048575
                                
                                .. attribute:: attach
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-segment-routing'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes.Index, self).__init__()

                                    self.yang_name = "index"
                                    self.yang_parent_name = "prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('range_start', (YLeaf(YType.uint32, 'range-start'), ['int'])),
                                        ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                        ('attach', (YLeaf(YType.empty, 'attach'), ['Empty'])),
                                    ])
                                    self.range_start = None
                                    self.range = None
                                    self.attach = None
                                    self._segment_path = lambda: "index"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes.Index, ['range_start', 'range', 'attach'], name, value)


                            class Absolute(Entity):
                                """
                                
                                
                                .. attribute:: range_start
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..1048575
                                
                                .. attribute:: range
                                
                                	Range value
                                	**type**\: int
                                
                                	**range:** 1..1048575
                                
                                .. attribute:: attach
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-segment-routing'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes.Absolute, self).__init__()

                                    self.yang_name = "absolute"
                                    self.yang_parent_name = "prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('range_start', (YLeaf(YType.uint32, 'range-start'), ['int'])),
                                        ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                        ('attach', (YLeaf(YType.empty, 'attach'), ['Empty'])),
                                    ])
                                    self.range_start = None
                                    self.range = None
                                    self.attach = None
                                    self._segment_path = lambda: "absolute"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4.Prefixes.Absolute, ['range_start', 'range', 'attach'], name, value)


                    class Ipv4StrictSpf(Entity):
                        """
                        
                        
                        .. attribute:: ipv4
                        
                        	Address Family
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4>`
                        
                        

                        """

                        _prefix = 'ios-segment-routing'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf, self).__init__()

                            self.yang_name = "ipv4-strict-spf"
                            self.yang_parent_name = "address-family"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4))])
                            self._leafs = OrderedDict()

                            self.ipv4 = Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"
                            self._segment_path = lambda: "ipv4-strict-spf"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/connected-prefix-sid-map/address-family/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf, [], name, value)


                        class Ipv4(Entity):
                            """
                            Address Family
                            
                            .. attribute:: strict_spf
                            
                            	
                            	**type**\:  :py:class:`StrictSpf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-segment-routing'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "ipv4-strict-spf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("strict-spf", ("strict_spf", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf))])
                                self._leafs = OrderedDict()

                                self.strict_spf = None
                                self._children_name_map["strict_spf"] = "strict-spf"
                                self._segment_path = lambda: "ipv4"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/connected-prefix-sid-map/address-family/ipv4-strict-spf/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4, [], name, value)


                            class StrictSpf(Entity):
                                """
                                
                                
                                .. attribute:: prefixes
                                
                                	
                                	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-segment-routing'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf, self).__init__()

                                    self.yang_name = "strict-spf"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.prefixes = YList(self)
                                    self._segment_path = lambda: "strict-spf"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/connected-prefix-sid-map/address-family/ipv4-strict-spf/ipv4/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf, [], name, value)


                                class Prefixes(Entity):
                                    """
                                    
                                    
                                    .. attribute:: ipprefix  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    .. attribute:: index
                                    
                                    	
                                    	**type**\:  :py:class:`Index <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Index>`
                                    
                                    .. attribute:: absolute
                                    
                                    	
                                    	**type**\:  :py:class:`Absolute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Absolute>`
                                    
                                    

                                    """

                                    _prefix = 'ios-segment-routing'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes, self).__init__()

                                        self.yang_name = "prefixes"
                                        self.yang_parent_name = "strict-spf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['ipprefix']
                                        self._child_classes = OrderedDict([("index", ("index", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Index)), ("absolute", ("absolute", Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Absolute))])
                                        self._leafs = OrderedDict([
                                            ('ipprefix', (YLeaf(YType.str, 'ipprefix'), ['str'])),
                                        ])
                                        self.ipprefix = None

                                        self.index = Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Index()
                                        self.index.parent = self
                                        self._children_name_map["index"] = "index"

                                        self.absolute = Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Absolute()
                                        self.absolute.parent = self
                                        self._children_name_map["absolute"] = "absolute"
                                        self._segment_path = lambda: "prefixes" + "[ipprefix='" + str(self.ipprefix) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/connected-prefix-sid-map/address-family/ipv4-strict-spf/ipv4/strict-spf/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes, ['ipprefix'], name, value)


                                    class Index(Entity):
                                        """
                                        
                                        
                                        .. attribute:: range_start
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..1048575
                                        
                                        .. attribute:: range
                                        
                                        	Range value
                                        	**type**\: int
                                        
                                        	**range:** 1..1048575
                                        
                                        .. attribute:: attach
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-segment-routing'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Index, self).__init__()

                                            self.yang_name = "index"
                                            self.yang_parent_name = "prefixes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('range_start', (YLeaf(YType.uint32, 'range-start'), ['int'])),
                                                ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                                ('attach', (YLeaf(YType.empty, 'attach'), ['Empty'])),
                                            ])
                                            self.range_start = None
                                            self.range = None
                                            self.attach = None
                                            self._segment_path = lambda: "index"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Index, ['range_start', 'range', 'attach'], name, value)


                                    class Absolute(Entity):
                                        """
                                        
                                        
                                        .. attribute:: range_start
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..1048575
                                        
                                        .. attribute:: range
                                        
                                        	Range value
                                        	**type**\: int
                                        
                                        	**range:** 1..1048575
                                        
                                        .. attribute:: attach
                                        
                                        	
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-segment-routing'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Absolute, self).__init__()

                                            self.yang_name = "absolute"
                                            self.yang_parent_name = "prefixes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('range_start', (YLeaf(YType.uint32, 'range-start'), ['int'])),
                                                ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                                ('attach', (YLeaf(YType.empty, 'attach'), ['Empty'])),
                                            ])
                                            self.range_start = None
                                            self.range = None
                                            self.attach = None
                                            self._segment_path = lambda: "absolute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.SegmentRouting.Mpls.ConnectedPrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Absolute, ['range_start', 'range', 'attach'], name, value)


            class GlobalBlock(Entity):
                """
                SR Global Block Config
                
                .. attribute:: range_start
                
                	SR GB Label Range Start
                	**type**\: int
                
                	**range:** 16..1048575
                
                .. attribute:: range_end
                
                	SR GB Label Range End
                	**type**\: int
                
                	**range:** 16..1048575
                
                

                """

                _prefix = 'ios-segment-routing'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.SegmentRouting.Mpls.GlobalBlock, self).__init__()

                    self.yang_name = "global-block"
                    self.yang_parent_name = "mpls"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('range_start', (YLeaf(YType.uint32, 'range-start'), ['int'])),
                        ('range_end', (YLeaf(YType.uint32, 'range-end'), ['int'])),
                    ])
                    self.range_start = None
                    self.range_end = None
                    self._segment_path = lambda: "global-block"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SegmentRouting.Mpls.GlobalBlock, ['range_start', 'range_end'], name, value)


            class MappingServer(Entity):
                """
                Enter Segment Routing Mapping Server Mode
                
                .. attribute:: prefix_sid_map
                
                	Enter Mapping Server Sidmap Mode
                	**type**\:  :py:class:`PrefixSidMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-segment-routing'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.SegmentRouting.Mpls.MappingServer, self).__init__()

                    self.yang_name = "mapping-server"
                    self.yang_parent_name = "mpls"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("prefix-sid-map", ("prefix_sid_map", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.prefix_sid_map = None
                    self._children_name_map["prefix_sid_map"] = "prefix-sid-map"
                    self._segment_path = lambda: "mapping-server"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer, [], name, value)


                class PrefixSidMap(Entity):
                    """
                    Enter Mapping Server Sidmap Mode
                    
                    .. attribute:: address_family
                    
                    	
                    	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-segment-routing'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap, self).__init__()

                        self.yang_name = "prefix-sid-map"
                        self.yang_parent_name = "mapping-server"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("address-family", ("address_family", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.address_family = Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"
                        self._segment_path = lambda: "prefix-sid-map"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/mapping-server/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap, [], name, value)


                    class AddressFamily(Entity):
                        """
                        
                        
                        .. attribute:: ipv4
                        
                        	
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: ipv4_strict_spf
                        
                        	
                        	**type**\:  :py:class:`Ipv4StrictSpf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf>`
                        
                        

                        """

                        _prefix = 'ios-segment-routing'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily, self).__init__()

                            self.yang_name = "address-family"
                            self.yang_parent_name = "prefix-sid-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4)), ("ipv4-strict-spf", ("ipv4_strict_spf", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf))])
                            self._leafs = OrderedDict()

                            self.ipv4 = None
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv4_strict_spf = Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf()
                            self.ipv4_strict_spf.parent = self
                            self._children_name_map["ipv4_strict_spf"] = "ipv4-strict-spf"
                            self._segment_path = lambda: "address-family"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/mapping-server/prefix-sid-map/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily, [], name, value)


                        class Ipv4(Entity):
                            """
                            
                            
                            .. attribute:: prefixes
                            
                            	
                            	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-segment-routing'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.prefixes = YList(self)
                                self._segment_path = lambda: "ipv4"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/mapping-server/prefix-sid-map/address-family/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4, [], name, value)


                            class Prefixes(Entity):
                                """
                                
                                
                                .. attribute:: ipprefix  (key)
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                .. attribute:: index
                                
                                	
                                	**type**\:  :py:class:`Index <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes.Index>`
                                
                                .. attribute:: absolute
                                
                                	
                                	**type**\:  :py:class:`Absolute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes.Absolute>`
                                
                                

                                """

                                _prefix = 'ios-segment-routing'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes, self).__init__()

                                    self.yang_name = "prefixes"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['ipprefix']
                                    self._child_classes = OrderedDict([("index", ("index", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes.Index)), ("absolute", ("absolute", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes.Absolute))])
                                    self._leafs = OrderedDict([
                                        ('ipprefix', (YLeaf(YType.str, 'ipprefix'), ['str'])),
                                    ])
                                    self.ipprefix = None

                                    self.index = Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes.Index()
                                    self.index.parent = self
                                    self._children_name_map["index"] = "index"

                                    self.absolute = Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes.Absolute()
                                    self.absolute.parent = self
                                    self._children_name_map["absolute"] = "absolute"
                                    self._segment_path = lambda: "prefixes" + "[ipprefix='" + str(self.ipprefix) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/mapping-server/prefix-sid-map/address-family/ipv4/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes, ['ipprefix'], name, value)


                                class Index(Entity):
                                    """
                                    
                                    
                                    .. attribute:: range_start
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..1048575
                                    
                                    .. attribute:: range
                                    
                                    	Range value
                                    	**type**\: int
                                    
                                    	**range:** 1..1048575
                                    
                                    .. attribute:: attach
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-segment-routing'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes.Index, self).__init__()

                                        self.yang_name = "index"
                                        self.yang_parent_name = "prefixes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('range_start', (YLeaf(YType.uint32, 'range-start'), ['int'])),
                                            ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                            ('attach', (YLeaf(YType.empty, 'attach'), ['Empty'])),
                                        ])
                                        self.range_start = None
                                        self.range = None
                                        self.attach = None
                                        self._segment_path = lambda: "index"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes.Index, ['range_start', 'range', 'attach'], name, value)


                                class Absolute(Entity):
                                    """
                                    
                                    
                                    .. attribute:: range_start
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..1048575
                                    
                                    .. attribute:: range
                                    
                                    	Range value
                                    	**type**\: int
                                    
                                    	**range:** 1..1048575
                                    
                                    .. attribute:: attach
                                    
                                    	
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-segment-routing'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes.Absolute, self).__init__()

                                        self.yang_name = "absolute"
                                        self.yang_parent_name = "prefixes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('range_start', (YLeaf(YType.uint32, 'range-start'), ['int'])),
                                            ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                            ('attach', (YLeaf(YType.empty, 'attach'), ['Empty'])),
                                        ])
                                        self.range_start = None
                                        self.range = None
                                        self.attach = None
                                        self._segment_path = lambda: "absolute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4.Prefixes.Absolute, ['range_start', 'range', 'attach'], name, value)


                        class Ipv4StrictSpf(Entity):
                            """
                            
                            
                            .. attribute:: ipv4
                            
                            	Address Family
                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4>`
                            
                            

                            """

                            _prefix = 'ios-segment-routing'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf, self).__init__()

                                self.yang_name = "ipv4-strict-spf"
                                self.yang_parent_name = "address-family"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4))])
                                self._leafs = OrderedDict()

                                self.ipv4 = Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                                self._segment_path = lambda: "ipv4-strict-spf"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/mapping-server/prefix-sid-map/address-family/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf, [], name, value)


                            class Ipv4(Entity):
                                """
                                Address Family
                                
                                .. attribute:: strict_spf
                                
                                	
                                	**type**\:  :py:class:`StrictSpf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf>`
                                
                                	**presence node**\: True
                                
                                

                                """

                                _prefix = 'ios-segment-routing'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4, self).__init__()

                                    self.yang_name = "ipv4"
                                    self.yang_parent_name = "ipv4-strict-spf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("strict-spf", ("strict_spf", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf))])
                                    self._leafs = OrderedDict()

                                    self.strict_spf = None
                                    self._children_name_map["strict_spf"] = "strict-spf"
                                    self._segment_path = lambda: "ipv4"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/mapping-server/prefix-sid-map/address-family/ipv4-strict-spf/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4, [], name, value)


                                class StrictSpf(Entity):
                                    """
                                    
                                    
                                    .. attribute:: prefixes
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`Prefixes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-segment-routing'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf, self).__init__()

                                        self.yang_name = "strict-spf"
                                        self.yang_parent_name = "ipv4"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefixes", ("prefixes", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.prefixes = YList(self)
                                        self._segment_path = lambda: "strict-spf"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/mapping-server/prefix-sid-map/address-family/ipv4-strict-spf/ipv4/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf, [], name, value)


                                    class Prefixes(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ipprefix  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        .. attribute:: index
                                        
                                        	
                                        	**type**\:  :py:class:`Index <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Index>`
                                        
                                        .. attribute:: absolute
                                        
                                        	
                                        	**type**\:  :py:class:`Absolute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Absolute>`
                                        
                                        

                                        """

                                        _prefix = 'ios-segment-routing'
                                        _revision = '2017-02-07'

                                        def __init__(self):
                                            super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes, self).__init__()

                                            self.yang_name = "prefixes"
                                            self.yang_parent_name = "strict-spf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = ['ipprefix']
                                            self._child_classes = OrderedDict([("index", ("index", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Index)), ("absolute", ("absolute", Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Absolute))])
                                            self._leafs = OrderedDict([
                                                ('ipprefix', (YLeaf(YType.str, 'ipprefix'), ['str'])),
                                            ])
                                            self.ipprefix = None

                                            self.index = Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Index()
                                            self.index.parent = self
                                            self._children_name_map["index"] = "index"

                                            self.absolute = Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Absolute()
                                            self.absolute.parent = self
                                            self._children_name_map["absolute"] = "absolute"
                                            self._segment_path = lambda: "prefixes" + "[ipprefix='" + str(self.ipprefix) + "']"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/mapping-server/prefix-sid-map/address-family/ipv4-strict-spf/ipv4/strict-spf/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes, ['ipprefix'], name, value)


                                        class Index(Entity):
                                            """
                                            
                                            
                                            .. attribute:: range_start
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..1048575
                                            
                                            .. attribute:: range
                                            
                                            	Range value
                                            	**type**\: int
                                            
                                            	**range:** 1..1048575
                                            
                                            .. attribute:: attach
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-segment-routing'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Index, self).__init__()

                                                self.yang_name = "index"
                                                self.yang_parent_name = "prefixes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('range_start', (YLeaf(YType.uint32, 'range-start'), ['int'])),
                                                    ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                                    ('attach', (YLeaf(YType.empty, 'attach'), ['Empty'])),
                                                ])
                                                self.range_start = None
                                                self.range = None
                                                self.attach = None
                                                self._segment_path = lambda: "index"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Index, ['range_start', 'range', 'attach'], name, value)


                                        class Absolute(Entity):
                                            """
                                            
                                            
                                            .. attribute:: range_start
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..1048575
                                            
                                            .. attribute:: range
                                            
                                            	Range value
                                            	**type**\: int
                                            
                                            	**range:** 1..1048575
                                            
                                            .. attribute:: attach
                                            
                                            	
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-segment-routing'
                                            _revision = '2017-02-07'

                                            def __init__(self):
                                                super(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Absolute, self).__init__()

                                                self.yang_name = "absolute"
                                                self.yang_parent_name = "prefixes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('range_start', (YLeaf(YType.uint32, 'range-start'), ['int'])),
                                                    ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                                    ('attach', (YLeaf(YType.empty, 'attach'), ['Empty'])),
                                                ])
                                                self.range_start = None
                                                self.range = None
                                                self.attach = None
                                                self._segment_path = lambda: "absolute"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.SegmentRouting.Mpls.MappingServer.PrefixSidMap.AddressFamily.Ipv4StrictSpf.Ipv4.StrictSpf.Prefixes.Absolute, ['range_start', 'range', 'attach'], name, value)


            class SetAttributes(Entity):
                """
                Enter SR Set Attributes  Mode
                
                .. attribute:: address_family
                
                	Enter Address Family command mode
                	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.SetAttributes.AddressFamily>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-segment-routing'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.SegmentRouting.Mpls.SetAttributes, self).__init__()

                    self.yang_name = "set-attributes"
                    self.yang_parent_name = "mpls"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("address-family", ("address_family", Native.SegmentRouting.Mpls.SetAttributes.AddressFamily))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.address_family = Native.SegmentRouting.Mpls.SetAttributes.AddressFamily()
                    self.address_family.parent = self
                    self._children_name_map["address_family"] = "address-family"
                    self._segment_path = lambda: "set-attributes"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SegmentRouting.Mpls.SetAttributes, [], name, value)


                class AddressFamily(Entity):
                    """
                    Enter Address Family command mode
                    
                    .. attribute:: ipv4
                    
                    	Address Family
                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SegmentRouting.Mpls.SetAttributes.AddressFamily.Ipv4>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-segment-routing'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.SegmentRouting.Mpls.SetAttributes.AddressFamily, self).__init__()

                        self.yang_name = "address-family"
                        self.yang_parent_name = "set-attributes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.SegmentRouting.Mpls.SetAttributes.AddressFamily.Ipv4))])
                        self._leafs = OrderedDict()

                        self.ipv4 = None
                        self._children_name_map["ipv4"] = "ipv4"
                        self._segment_path = lambda: "address-family"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/set-attributes/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SegmentRouting.Mpls.SetAttributes.AddressFamily, [], name, value)


                    class Ipv4(Entity):
                        """
                        Address Family
                        
                        .. attribute:: explicit_null
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: sr_label_preferred
                        
                        	
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-segment-routing'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.SegmentRouting.Mpls.SetAttributes.AddressFamily.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "address-family"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('explicit_null', (YLeaf(YType.empty, 'explicit-null'), ['Empty'])),
                                ('sr_label_preferred', (YLeaf(YType.empty, 'sr-label-preferred'), ['Empty'])),
                            ])
                            self.explicit_null = None
                            self.sr_label_preferred = None
                            self._segment_path = lambda: "ipv4"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/segment-routing/Cisco-IOS-XE-segment-routing:mpls/set-attributes/address-family/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SegmentRouting.Mpls.SetAttributes.AddressFamily.Ipv4, ['explicit_null', 'sr_label_preferred'], name, value)


    class License(Entity):
        """
        Configure license features
        
        .. attribute:: udi
        
        	
        	**type**\:  :py:class:`Udi <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Udi>`
        
        .. attribute:: feature
        
        	License features
        	**type**\:  :py:class:`Feature <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Feature>`
        
        .. attribute:: accept
        
        	
        	**type**\:  :py:class:`Accept <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Accept>`
        
        .. attribute:: boot
        
        	license boot config commands
        	**type**\:  :py:class:`Boot <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot>`
        
        .. attribute:: smart
        
        	Smart licensing
        	**type**\:  :py:class:`Smart <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Smart>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.License, self).__init__()

            self.yang_name = "license"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("udi", ("udi", Native.License.Udi)), ("feature", ("feature", Native.License.Feature)), ("accept", ("accept", Native.License.Accept)), ("boot", ("boot", Native.License.Boot)), ("smart", ("smart", Native.License.Smart))])
            self._leafs = OrderedDict()

            self.udi = Native.License.Udi()
            self.udi.parent = self
            self._children_name_map["udi"] = "udi"

            self.feature = Native.License.Feature()
            self.feature.parent = self
            self._children_name_map["feature"] = "feature"

            self.accept = Native.License.Accept()
            self.accept.parent = self
            self._children_name_map["accept"] = "accept"

            self.boot = Native.License.Boot()
            self.boot.parent = self
            self._children_name_map["boot"] = "boot"

            self.smart = Native.License.Smart()
            self.smart.parent = self
            self._children_name_map["smart"] = "smart"
            self._segment_path = lambda: "license"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.License, [], name, value)


        class Udi(Entity):
            """
            
            
            .. attribute:: pid
            
            	
            	**type**\: str
            
            .. attribute:: sn
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.License.Udi, self).__init__()

                self.yang_name = "udi"
                self.yang_parent_name = "license"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('pid', (YLeaf(YType.str, 'pid'), ['str'])),
                    ('sn', (YLeaf(YType.str, 'sn'), ['str'])),
                ])
                self.pid = None
                self.sn = None
                self._segment_path = lambda: "udi"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.License.Udi, [u'pid', u'sn'], name, value)


        class Feature(Entity):
            """
            License features
            
            .. attribute:: name
            
            	
            	**type**\: str
            
            .. attribute:: port
            
            	Enable Ports for IM
            	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Feature.Port>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.License.Feature, self).__init__()

                self.yang_name = "feature"
                self.yang_parent_name = "license"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("port", ("port", Native.License.Feature.Port))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.port = Native.License.Feature.Port()
                self.port.parent = self
                self._children_name_map["port"] = "port"
                self._segment_path = lambda: "feature"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.License.Feature, [u'name'], name, value)


            class Port(Entity):
                """
                Enable Ports for IM
                
                .. attribute:: bulk
                
                	Enable Bulk port licenes
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: onegig
                
                	Enable 1G port bundles
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: b_6xonegig
                
                	Enable 6x1G port bundles
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: tengig
                
                	Enable 10G port bundles
                	**type**\: int
                
                	**range:** 1..2
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.License.Feature.Port, self).__init__()

                    self.yang_name = "port"
                    self.yang_parent_name = "feature"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('bulk', (YLeaf(YType.empty, 'bulk'), ['Empty'])),
                        ('onegig', (YLeaf(YType.uint8, 'onegig'), ['int'])),
                        ('b_6xonegig', (YLeaf(YType.uint8, 'b-6xonegig'), ['int'])),
                        ('tengig', (YLeaf(YType.uint8, 'tengig'), ['int'])),
                    ])
                    self.bulk = None
                    self.onegig = None
                    self.b_6xonegig = None
                    self.tengig = None
                    self._segment_path = lambda: "port"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/feature/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.License.Feature.Port, [u'bulk', u'onegig', u'b_6xonegig', u'tengig'], name, value)


        class Accept(Entity):
            """
            
            
            .. attribute:: end
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: user
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: agreement
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.License.Accept, self).__init__()

                self.yang_name = "accept"
                self.yang_parent_name = "license"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('end', (YLeaf(YType.empty, 'end'), ['Empty'])),
                    ('user', (YLeaf(YType.empty, 'user'), ['Empty'])),
                    ('agreement', (YLeaf(YType.empty, 'agreement'), ['Empty'])),
                ])
                self.end = None
                self.user = None
                self.agreement = None
                self._segment_path = lambda: "accept"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.License.Accept, [u'end', u'user', u'agreement'], name, value)


        class Boot(Entity):
            """
            license boot config commands
            
            .. attribute:: level
            
            	which level to boot
            	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level>`
            
            .. attribute:: boot_module
            
            	
            	**type**\:  :py:class:`BootModule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.BootModule>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.License.Boot, self).__init__()

                self.yang_name = "boot"
                self.yang_parent_name = "license"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("level", ("level", Native.License.Boot.Level)), ("boot-module", ("boot_module", Native.License.Boot.BootModule))])
                self._leafs = OrderedDict()

                self.level = Native.License.Boot.Level()
                self.level.parent = self
                self._children_name_map["level"] = "level"

                self.boot_module = Native.License.Boot.BootModule()
                self.boot_module.parent = self
                self._children_name_map["boot_module"] = "boot-module"
                self._segment_path = lambda: "boot"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.License.Boot, [], name, value)


            class Level(Entity):
                """
                which level to boot
                
                .. attribute:: ipbase
                
                	ipbase level
                	**type**\:  :py:class:`Ipbase <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Ipbase>`
                
                	**presence node**\: True
                
                .. attribute:: ipbasek9
                
                	License Level IPBASEK9
                	**type**\:  :py:class:`Ipbasek9 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Ipbasek9>`
                
                	**presence node**\: True
                
                .. attribute:: ipservices
                
                	ipservices level
                	**type**\:  :py:class:`Ipservices <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Ipservices>`
                
                	**presence node**\: True
                
                .. attribute:: ipservicesk9
                
                	ipservicesk9 level
                	**type**\:  :py:class:`Ipservicesk9 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Ipservicesk9>`
                
                	**presence node**\: True
                
                .. attribute:: lanbase
                
                	lanbase level
                	**type**\:  :py:class:`Lanbase <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Lanbase>`
                
                	**presence node**\: True
                
                .. attribute:: lanbasek9
                
                	License Level LANBASEK9
                	**type**\:  :py:class:`Lanbasek9 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Lanbasek9>`
                
                	**presence node**\: True
                
                .. attribute:: lite
                
                	lite level
                	**type**\:  :py:class:`Lite <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Lite>`
                
                	**presence node**\: True
                
                .. attribute:: metroaggrservices
                
                	metroaggrservices level
                	**type**\:  :py:class:`Metroaggrservices <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Metroaggrservices>`
                
                	**presence node**\: True
                
                .. attribute:: metroipservices
                
                	Metroipservices License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: metroservices
                
                	Metroservices License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: advancedmetroipaccess
                
                	Advanced Metro IP Access License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: metroaccess
                
                	Metro Access License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: metroipaccess
                
                	Metro IP Access License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: entservices
                
                	Entservices License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: adventerprise
                
                	Adventerprise License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: appx
                
                	Appx License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: appxk9
                
                	Appxk9 License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ax
                
                	ax(ipb+sec+appx) License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: security
                
                	Security License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: securityk9
                
                	Securityk9 License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: uck9
                
                	Uck9 License Level
                	**type**\:  :py:class:`Uck9 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Uck9>`
                
                	**presence node**\: True
                
                .. attribute:: network_advantage
                
                	License Level Network\-Advantage
                	**type**\:  :py:class:`NetworkAdvantage <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.NetworkAdvantage>`
                
                	**presence node**\: True
                
                .. attribute:: network_essentials
                
                	License Level Network\-Essentials
                	**type**\:  :py:class:`NetworkEssentials <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.NetworkEssentials>`
                
                	**presence node**\: True
                
                .. attribute:: advucsuitek9
                
                	AdvUCSuiteK9 License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: foundationsuitek9
                
                	FoundationSuiteK9 License Level
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.License.Boot.Level, self).__init__()

                    self.yang_name = "level"
                    self.yang_parent_name = "boot"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipbase", ("ipbase", Native.License.Boot.Level.Ipbase)), ("ipbasek9", ("ipbasek9", Native.License.Boot.Level.Ipbasek9)), ("ipservices", ("ipservices", Native.License.Boot.Level.Ipservices)), ("ipservicesk9", ("ipservicesk9", Native.License.Boot.Level.Ipservicesk9)), ("lanbase", ("lanbase", Native.License.Boot.Level.Lanbase)), ("lanbasek9", ("lanbasek9", Native.License.Boot.Level.Lanbasek9)), ("lite", ("lite", Native.License.Boot.Level.Lite)), ("metroaggrservices", ("metroaggrservices", Native.License.Boot.Level.Metroaggrservices)), ("uck9", ("uck9", Native.License.Boot.Level.Uck9)), ("network-advantage", ("network_advantage", Native.License.Boot.Level.NetworkAdvantage)), ("network-essentials", ("network_essentials", Native.License.Boot.Level.NetworkEssentials))])
                    self._leafs = OrderedDict([
                        ('metroipservices', (YLeaf(YType.empty, 'metroipservices'), ['Empty'])),
                        ('metroservices', (YLeaf(YType.empty, 'metroservices'), ['Empty'])),
                        ('advancedmetroipaccess', (YLeaf(YType.empty, 'advancedmetroipaccess'), ['Empty'])),
                        ('metroaccess', (YLeaf(YType.empty, 'metroaccess'), ['Empty'])),
                        ('metroipaccess', (YLeaf(YType.empty, 'metroipaccess'), ['Empty'])),
                        ('entservices', (YLeaf(YType.empty, 'entservices'), ['Empty'])),
                        ('adventerprise', (YLeaf(YType.empty, 'adventerprise'), ['Empty'])),
                        ('appx', (YLeaf(YType.empty, 'appx'), ['Empty'])),
                        ('appxk9', (YLeaf(YType.empty, 'appxk9'), ['Empty'])),
                        ('ax', (YLeaf(YType.empty, 'ax'), ['Empty'])),
                        ('security', (YLeaf(YType.empty, 'security'), ['Empty'])),
                        ('securityk9', (YLeaf(YType.empty, 'securityk9'), ['Empty'])),
                        ('advucsuitek9', (YLeaf(YType.empty, 'AdvUCSuiteK9'), ['Empty'])),
                        ('foundationsuitek9', (YLeaf(YType.empty, 'FoundationSuiteK9'), ['Empty'])),
                    ])
                    self.metroipservices = None
                    self.metroservices = None
                    self.advancedmetroipaccess = None
                    self.metroaccess = None
                    self.metroipaccess = None
                    self.entservices = None
                    self.adventerprise = None
                    self.appx = None
                    self.appxk9 = None
                    self.ax = None
                    self.security = None
                    self.securityk9 = None
                    self.advucsuitek9 = None
                    self.foundationsuitek9 = None

                    self.ipbase = None
                    self._children_name_map["ipbase"] = "ipbase"

                    self.ipbasek9 = None
                    self._children_name_map["ipbasek9"] = "ipbasek9"

                    self.ipservices = None
                    self._children_name_map["ipservices"] = "ipservices"

                    self.ipservicesk9 = None
                    self._children_name_map["ipservicesk9"] = "ipservicesk9"

                    self.lanbase = None
                    self._children_name_map["lanbase"] = "lanbase"

                    self.lanbasek9 = None
                    self._children_name_map["lanbasek9"] = "lanbasek9"

                    self.lite = None
                    self._children_name_map["lite"] = "lite"

                    self.metroaggrservices = None
                    self._children_name_map["metroaggrservices"] = "metroaggrservices"

                    self.uck9 = None
                    self._children_name_map["uck9"] = "uck9"

                    self.network_advantage = None
                    self._children_name_map["network_advantage"] = "network-advantage"

                    self.network_essentials = None
                    self._children_name_map["network_essentials"] = "network-essentials"
                    self._segment_path = lambda: "level"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.License.Boot.Level, [u'metroipservices', u'metroservices', u'advancedmetroipaccess', u'metroaccess', u'metroipaccess', u'entservices', u'adventerprise', u'appx', u'appxk9', u'ax', u'security', u'securityk9', u'advucsuitek9', u'foundationsuitek9'], name, value)


                class Ipbase(Entity):
                    """
                    ipbase level
                    
                    .. attribute:: switch
                    
                    	Switch license information
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.Level.Ipbase, self).__init__()

                        self.yang_name = "ipbase"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('switch', (YLeaf(YType.uint8, 'switch'), ['int'])),
                        ])
                        self.switch = None
                        self._segment_path = lambda: "ipbase"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/level/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.Level.Ipbase, [u'switch'], name, value)


                class Ipbasek9(Entity):
                    """
                    License Level IPBASEK9
                    
                    .. attribute:: addon
                    
                    	select add\-on to include
                    	**type**\:  :py:class:`Addon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Ipbasek9.Addon>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.Level.Ipbasek9, self).__init__()

                        self.yang_name = "ipbasek9"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('addon', (YLeaf(YType.enumeration, 'addon'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'License.Boot.Level.Ipbasek9.Addon')])),
                        ])
                        self.addon = None
                        self._segment_path = lambda: "ipbasek9"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/level/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.Level.Ipbasek9, [u'addon'], name, value)

                    class Addon(Enum):
                        """
                        Addon (Enum Class)

                        select add\-on to include

                        .. data:: dna_advantage = 0

                        .. data:: dna_essentials = 1

                        """

                        dna_advantage = Enum.YLeaf(0, "dna-advantage")

                        dna_essentials = Enum.YLeaf(1, "dna-essentials")



                class Ipservices(Entity):
                    """
                    ipservices level
                    
                    .. attribute:: switch
                    
                    	Switch license information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.Level.Ipservices, self).__init__()

                        self.yang_name = "ipservices"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('switch', (YLeaf(YType.empty, 'switch'), ['Empty'])),
                        ])
                        self.switch = None
                        self._segment_path = lambda: "ipservices"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/level/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.Level.Ipservices, [u'switch'], name, value)


                class Ipservicesk9(Entity):
                    """
                    ipservicesk9 level
                    
                    .. attribute:: addon
                    
                    	select add\-on to include
                    	**type**\:  :py:class:`Addon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Ipservicesk9.Addon>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.Level.Ipservicesk9, self).__init__()

                        self.yang_name = "ipservicesk9"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('addon', (YLeaf(YType.enumeration, 'addon'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'License.Boot.Level.Ipservicesk9.Addon')])),
                        ])
                        self.addon = None
                        self._segment_path = lambda: "ipservicesk9"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/level/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.Level.Ipservicesk9, [u'addon'], name, value)

                    class Addon(Enum):
                        """
                        Addon (Enum Class)

                        select add\-on to include

                        .. data:: dna_advantage = 0

                        .. data:: dna_essentials = 1

                        """

                        dna_advantage = Enum.YLeaf(0, "dna-advantage")

                        dna_essentials = Enum.YLeaf(1, "dna-essentials")



                class Lanbase(Entity):
                    """
                    lanbase level
                    
                    .. attribute:: switch
                    
                    	Switch license information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.Level.Lanbase, self).__init__()

                        self.yang_name = "lanbase"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('switch', (YLeaf(YType.empty, 'switch'), ['Empty'])),
                        ])
                        self.switch = None
                        self._segment_path = lambda: "lanbase"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/level/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.Level.Lanbase, [u'switch'], name, value)


                class Lanbasek9(Entity):
                    """
                    License Level LANBASEK9
                    
                    .. attribute:: addon
                    
                    	select add\-on to include
                    	**type**\:  :py:class:`Addon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.Lanbasek9.Addon>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.Level.Lanbasek9, self).__init__()

                        self.yang_name = "lanbasek9"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('addon', (YLeaf(YType.enumeration, 'addon'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'License.Boot.Level.Lanbasek9.Addon')])),
                        ])
                        self.addon = None
                        self._segment_path = lambda: "lanbasek9"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/level/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.Level.Lanbasek9, [u'addon'], name, value)

                    class Addon(Enum):
                        """
                        Addon (Enum Class)

                        select add\-on to include

                        .. data:: dna_essentials = 0

                        """

                        dna_essentials = Enum.YLeaf(0, "dna-essentials")



                class Lite(Entity):
                    """
                    lite level
                    
                    .. attribute:: switch
                    
                    	Switch license information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.Level.Lite, self).__init__()

                        self.yang_name = "lite"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('switch', (YLeaf(YType.empty, 'switch'), ['Empty'])),
                        ])
                        self.switch = None
                        self._segment_path = lambda: "lite"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/level/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.Level.Lite, [u'switch'], name, value)


                class Metroaggrservices(Entity):
                    """
                    metroaggrservices level
                    
                    .. attribute:: switch
                    
                    	Switch license information
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.Level.Metroaggrservices, self).__init__()

                        self.yang_name = "metroaggrservices"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('switch', (YLeaf(YType.empty, 'switch'), ['Empty'])),
                        ])
                        self.switch = None
                        self._segment_path = lambda: "metroaggrservices"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/level/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.Level.Metroaggrservices, [u'switch'], name, value)


                class Uck9(Entity):
                    """
                    Uck9 License Level
                    
                    .. attribute:: disable
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.Level.Uck9, self).__init__()

                        self.yang_name = "uck9"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                        ])
                        self.disable = None
                        self._segment_path = lambda: "uck9"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/level/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.Level.Uck9, [u'disable'], name, value)


                class NetworkAdvantage(Entity):
                    """
                    License Level Network\-Advantage
                    
                    .. attribute:: addon
                    
                    	select add\-on to include
                    	**type**\:  :py:class:`Addon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.NetworkAdvantage.Addon>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.Level.NetworkAdvantage, self).__init__()

                        self.yang_name = "network-advantage"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('addon', (YLeaf(YType.enumeration, 'addon'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'License.Boot.Level.NetworkAdvantage.Addon')])),
                        ])
                        self.addon = None
                        self._segment_path = lambda: "network-advantage"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/level/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.Level.NetworkAdvantage, [u'addon'], name, value)

                    class Addon(Enum):
                        """
                        Addon (Enum Class)

                        select add\-on to include

                        .. data:: dna_advantage = 0

                        .. data:: dna_essentials = 1

                        """

                        dna_advantage = Enum.YLeaf(0, "dna-advantage")

                        dna_essentials = Enum.YLeaf(1, "dna-essentials")



                class NetworkEssentials(Entity):
                    """
                    License Level Network\-Essentials
                    
                    .. attribute:: addon
                    
                    	select add\-on to include
                    	**type**\:  :py:class:`Addon <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.Level.NetworkEssentials.Addon>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.Level.NetworkEssentials, self).__init__()

                        self.yang_name = "network-essentials"
                        self.yang_parent_name = "level"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('addon', (YLeaf(YType.enumeration, 'addon'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'License.Boot.Level.NetworkEssentials.Addon')])),
                        ])
                        self.addon = None
                        self._segment_path = lambda: "network-essentials"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/level/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.Level.NetworkEssentials, [u'addon'], name, value)

                    class Addon(Enum):
                        """
                        Addon (Enum Class)

                        select add\-on to include

                        .. data:: dna_essentials = 0

                        """

                        dna_essentials = Enum.YLeaf(0, "dna-essentials")



            class BootModule(Entity):
                """
                
                
                .. attribute:: module
                
                	
                	**type**\:  :py:class:`Module <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.BootModule.Module>`
                
                .. attribute:: technology_package
                
                	
                	**type**\:  :py:class:`TechnologyPackage <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Boot.BootModule.TechnologyPackage>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.License.Boot.BootModule, self).__init__()

                    self.yang_name = "boot-module"
                    self.yang_parent_name = "boot"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("technology-package", ("technology_package", Native.License.Boot.BootModule.TechnologyPackage))])
                    self._leafs = OrderedDict([
                        ('module', (YLeaf(YType.enumeration, 'module'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'License.Boot.BootModule.Module')])),
                    ])
                    self.module = None

                    self.technology_package = Native.License.Boot.BootModule.TechnologyPackage()
                    self.technology_package.parent = self
                    self._children_name_map["technology_package"] = "technology-package"
                    self._segment_path = lambda: "boot-module"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.License.Boot.BootModule, [u'module'], name, value)

                class Module(Enum):
                    """
                    Module (Enum Class)

                    .. data:: c2900 = 0

                    """

                    c2900 = Enum.YLeaf(0, "c2900")



                class TechnologyPackage(Entity):
                    """
                    
                    
                    .. attribute:: securityk9
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: uck9
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: datak9
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Boot.BootModule.TechnologyPackage, self).__init__()

                        self.yang_name = "technology-package"
                        self.yang_parent_name = "boot-module"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('securityk9', (YLeaf(YType.empty, 'securityk9'), ['Empty'])),
                            ('uck9', (YLeaf(YType.empty, 'uck9'), ['Empty'])),
                            ('datak9', (YLeaf(YType.empty, 'datak9'), ['Empty'])),
                        ])
                        self.securityk9 = None
                        self.uck9 = None
                        self.datak9 = None
                        self._segment_path = lambda: "technology-package"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/boot/boot-module/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Boot.BootModule.TechnologyPackage, [u'securityk9', u'uck9', u'datak9'], name, value)


        class Smart(Entity):
            """
            Smart licensing
            
            .. attribute:: customer_id
            
            	Customer defined id
            	**type**\: str
            
            .. attribute:: enable
            
            	Enable Smart licensing
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: transport_type
            
            	The transport type. If transport\-type is set to         callhome then any additional transport settings must         be done from the callhome CLI.        If the transport\-type is set to smart, additional         settings are available below
            	**type**\:  :py:class:`TransportType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Smart.TransportType>`
            
            .. attribute:: privacy
            
            	
            	**type**\:  :py:class:`Privacy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Smart.Privacy>`
            
            .. attribute:: utility
            
            	Enable or disable usage reporting on the device
            	**type**\:  :py:class:`Utility <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Smart.Utility>`
            
            .. attribute:: url
            
            	Specify the Smart Transport primary and the Utility URL
            	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Smart.Url>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.License.Smart, self).__init__()

                self.yang_name = "smart"
                self.yang_parent_name = "license"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("privacy", ("privacy", Native.License.Smart.Privacy)), ("utility", ("utility", Native.License.Smart.Utility)), ("url", ("url", Native.License.Smart.Url))])
                self._leafs = OrderedDict([
                    ('customer_id', (YLeaf(YType.str, 'customer-id'), ['str'])),
                    ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ('transport_type', (YLeaf(YType.enumeration, 'transport-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'License.Smart.TransportType')])),
                ])
                self.customer_id = None
                self.enable = None
                self.transport_type = None

                self.privacy = Native.License.Smart.Privacy()
                self.privacy.parent = self
                self._children_name_map["privacy"] = "privacy"

                self.utility = Native.License.Smart.Utility()
                self.utility.parent = self
                self._children_name_map["utility"] = "utility"

                self.url = Native.License.Smart.Url()
                self.url.parent = self
                self._children_name_map["url"] = "url"
                self._segment_path = lambda: "smart"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.License.Smart, [u'customer_id', u'enable', u'transport_type'], name, value)

            class TransportType(Enum):
                """
                TransportType (Enum Class)

                The transport type. If transport\-type is set to 

                       callhome then any additional transport settings must 

                       be done from the callhome CLI.

                       If the transport\-type is set to smart, additional 

                       settings are available below.

                .. data:: callhome = 0

                .. data:: smart = 1

                """

                callhome = Enum.YLeaf(0, "callhome")

                smart = Enum.YLeaf(1, "smart")



            class Privacy(Entity):
                """
                
                
                .. attribute:: hostname
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: version
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.License.Smart.Privacy, self).__init__()

                    self.yang_name = "privacy"
                    self.yang_parent_name = "smart"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('hostname', (YLeaf(YType.empty, 'hostname'), ['Empty'])),
                        ('version', (YLeaf(YType.empty, 'version'), ['Empty'])),
                    ])
                    self.hostname = None
                    self.version = None
                    self._segment_path = lambda: "privacy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/smart/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.License.Smart.Privacy, [u'hostname', u'version'], name, value)


            class Utility(Entity):
                """
                Enable or disable usage reporting on the device
                
                .. attribute:: enable
                
                	Enable or disable usage reporting
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: customer_info
                
                	
                	**type**\:  :py:class:`CustomerInfo <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.License.Smart.Utility.CustomerInfo>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.License.Smart.Utility, self).__init__()

                    self.yang_name = "utility"
                    self.yang_parent_name = "smart"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("customer-info", ("customer_info", Native.License.Smart.Utility.CustomerInfo))])
                    self._leafs = OrderedDict([
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.enable = None

                    self.customer_info = Native.License.Smart.Utility.CustomerInfo()
                    self.customer_info.parent = self
                    self._children_name_map["customer_info"] = "customer-info"
                    self._segment_path = lambda: "utility"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/smart/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.License.Smart.Utility, [u'enable'], name, value)


                class CustomerInfo(Entity):
                    """
                    
                    
                    .. attribute:: city
                    
                    	Customer defined city
                    	**type**\: str
                    
                    .. attribute:: country
                    
                    	Customer defined country
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	Customer defined id
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	Customer defined name
                    	**type**\: str
                    
                    .. attribute:: postalcode
                    
                    	Customer defined postalcode
                    	**type**\: str
                    
                    .. attribute:: state
                    
                    	Customer defined state
                    	**type**\: str
                    
                    .. attribute:: street
                    
                    	Customer defined street
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.License.Smart.Utility.CustomerInfo, self).__init__()

                        self.yang_name = "customer-info"
                        self.yang_parent_name = "utility"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('city', (YLeaf(YType.str, 'city'), ['str'])),
                            ('country', (YLeaf(YType.str, 'country'), ['str'])),
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('postalcode', (YLeaf(YType.str, 'postalcode'), ['str'])),
                            ('state', (YLeaf(YType.str, 'state'), ['str'])),
                            ('street', (YLeaf(YType.str, 'street'), ['str'])),
                        ])
                        self.city = None
                        self.country = None
                        self.id = None
                        self.name = None
                        self.postalcode = None
                        self.state = None
                        self.street = None
                        self._segment_path = lambda: "customer-info"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/smart/utility/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.License.Smart.Utility.CustomerInfo, [u'city', u'country', u'id', u'name', u'postalcode', u'state', u'street'], name, value)


            class Url(Entity):
                """
                Specify the Smart Transport primary and the Utility URL
                
                .. attribute:: default
                
                	Enable the default URLs for both url\-registration and url\-utility that point to  the Cisco SSM
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: name
                
                	Specify the URL used for registration, authorization and anything else not related to utility usage reporting
                	**type**\: str
                
                .. attribute:: utility
                
                	Specify the URL to be used for sending utility usage  reports. This should be the same as url\-registration  if you are using a satellite
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.License.Smart.Url, self).__init__()

                    self.yang_name = "url"
                    self.yang_parent_name = "smart"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('utility', (YLeaf(YType.str, 'utility'), ['str'])),
                    ])
                    self.default = None
                    self.name = None
                    self.utility = None
                    self._segment_path = lambda: "url"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/license/smart/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.License.Smart.Url, [u'default', u'name', u'utility'], name, value)


    class MemorySize(Entity):
        """
        Adjust memory size by percentage
        
        .. attribute:: iomem
        
        	I/O memory
        	**type**\: int
        
        	**range:** 5..25
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.MemorySize, self).__init__()

            self.yang_name = "memory-size"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('iomem', (YLeaf(YType.uint8, 'iomem'), ['int'])),
            ])
            self.iomem = None
            self._segment_path = lambda: "memory-size"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.MemorySize, [u'iomem'], name, value)


    class Transceiver(Entity):
        """
        Select from transceiver configuration commands
        
        .. attribute:: type
        
        	type keyword
        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Transceiver.Type>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Transceiver, self).__init__()

            self.yang_name = "transceiver"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("type", ("type", Native.Transceiver.Type))])
            self._leafs = OrderedDict()

            self.type = Native.Transceiver.Type()
            self.type.parent = self
            self._children_name_map["type"] = "type"
            self._segment_path = lambda: "transceiver"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Transceiver, [], name, value)


        class Type(Entity):
            """
            type keyword
            
            .. attribute:: all
            
            	
            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Transceiver.Type.All>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Transceiver.Type, self).__init__()

                self.yang_name = "type"
                self.yang_parent_name = "transceiver"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("all", ("all", Native.Transceiver.Type.All))])
                self._leafs = OrderedDict()

                self.all = Native.Transceiver.Type.All()
                self.all.parent = self
                self._children_name_map["all"] = "all"
                self._segment_path = lambda: "type"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/transceiver/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Transceiver.Type, [], name, value)


            class All(Entity):
                """
                
                
                .. attribute:: monitoring
                
                	Enable/disable monitoring
                	**type**\:  :py:class:`Monitoring <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Transceiver.Type.All.Monitoring>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Transceiver.Type.All, self).__init__()

                    self.yang_name = "all"
                    self.yang_parent_name = "type"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("monitoring", ("monitoring", Native.Transceiver.Type.All.Monitoring))])
                    self._leafs = OrderedDict()

                    self.monitoring = None
                    self._children_name_map["monitoring"] = "monitoring"
                    self._segment_path = lambda: "all"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/transceiver/type/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Transceiver.Type.All, [], name, value)


                class Monitoring(Entity):
                    """
                    Enable/disable monitoring
                    
                    .. attribute:: interval
                    
                    	Set interval for monitoring
                    	**type**\: int
                    
                    	**range:** 300..3600
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Transceiver.Type.All.Monitoring, self).__init__()

                        self.yang_name = "monitoring"
                        self.yang_parent_name = "all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('interval', (YLeaf(YType.uint16, 'interval'), ['int'])),
                        ])
                        self.interval = None
                        self._segment_path = lambda: "monitoring"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/transceiver/type/all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Transceiver.Type.All.Monitoring, [u'interval'], name, value)


    class ServiceInsertion(Entity):
        """
        Service Insertion mode
        
        .. attribute:: acg_reload_delay
        
        	Reload delay timer for ACG
        	**type**\: int
        
        	**range:** 120..450
        
        .. attribute:: appnav_controller_group
        
        	AppNav Controller Group
        	**type**\: list of  		 :py:class:`AppnavControllerGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceInsertion.AppnavControllerGroup>`
        
        .. attribute:: service_context
        
        	Service Context
        	**type**\:  :py:class:`ServiceContext <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceInsertion.ServiceContext>`
        
        .. attribute:: service_node_group
        
        	service node Group
        	**type**\: list of  		 :py:class:`ServiceNodeGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceInsertion.ServiceNodeGroup>`
        
        .. attribute:: swap
        
        	Swap src\-ip
        	**type**\:  :py:class:`Swap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceInsertion.Swap>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.ServiceInsertion, self).__init__()

            self.yang_name = "service-insertion"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-service-insertion:appnav-controller-group", ("appnav_controller_group", Native.ServiceInsertion.AppnavControllerGroup)), ("Cisco-IOS-XE-service-insertion:service-context", ("service_context", Native.ServiceInsertion.ServiceContext)), ("Cisco-IOS-XE-service-insertion:service-node-group", ("service_node_group", Native.ServiceInsertion.ServiceNodeGroup)), ("Cisco-IOS-XE-service-insertion:swap", ("swap", Native.ServiceInsertion.Swap))])
            self._leafs = OrderedDict([
                ('acg_reload_delay', (YLeaf(YType.uint16, 'Cisco-IOS-XE-service-insertion:acg-reload-delay'), ['int'])),
            ])
            self.acg_reload_delay = None

            self.service_context = Native.ServiceInsertion.ServiceContext()
            self.service_context.parent = self
            self._children_name_map["service_context"] = "Cisco-IOS-XE-service-insertion:service-context"

            self.swap = Native.ServiceInsertion.Swap()
            self.swap.parent = self
            self._children_name_map["swap"] = "Cisco-IOS-XE-service-insertion:swap"

            self.appnav_controller_group = YList(self)
            self.service_node_group = YList(self)
            self._segment_path = lambda: "service-insertion"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.ServiceInsertion, ['acg_reload_delay'], name, value)


        class AppnavControllerGroup(Entity):
            """
            AppNav Controller Group
            
            .. attribute:: group_name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: appnav_controller
            
            	AppNav controller
            	**type**\: list of str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: description
            
            	ACG description
            	**type**\: str
            
            

            """

            _prefix = 'ios-service-insertion'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.ServiceInsertion.AppnavControllerGroup, self).__init__()

                self.yang_name = "appnav-controller-group"
                self.yang_parent_name = "service-insertion"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['group_name']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                    ('appnav_controller', (YLeafList(YType.str, 'appnav-controller'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                ])
                self.group_name = None
                self.appnav_controller = []
                self.description = None
                self._segment_path = lambda: "Cisco-IOS-XE-service-insertion:appnav-controller-group" + "[group-name='" + str(self.group_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service-insertion/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceInsertion.AppnavControllerGroup, ['group_name', 'appnav_controller', 'description'], name, value)


        class ServiceContext(Entity):
            """
            Service Context
            
            .. attribute:: waas
            
            	Service controller waas
            	**type**\: list of  		 :py:class:`Waas <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceInsertion.ServiceContext.Waas>`
            
            

            """

            _prefix = 'ios-service-insertion'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.ServiceInsertion.ServiceContext, self).__init__()

                self.yang_name = "service-context"
                self.yang_parent_name = "service-insertion"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("waas", ("waas", Native.ServiceInsertion.ServiceContext.Waas))])
                self._leafs = OrderedDict()

                self.waas = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-service-insertion:service-context"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service-insertion/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceInsertion.ServiceContext, [], name, value)


            class Waas(Entity):
                """
                Service controller waas
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: appnav_controller_group
                
                	AppNav Controller Group
                	**type**\: str
                
                .. attribute:: authentication
                
                	Authentication key
                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceInsertion.ServiceContext.Waas.Authentication>`
                
                .. attribute:: service_node_group
                
                	service node Group
                	**type**\: str
                
                .. attribute:: service_policy
                
                	Specify a service policy for the service context
                	**type**\: str
                
                .. attribute:: enable
                
                	service context enable
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: vrf
                
                	VRF
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceInsertion.ServiceContext.Waas.Vrf>`
                
                

                """

                _prefix = 'ios-service-insertion'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.ServiceInsertion.ServiceContext.Waas, self).__init__()

                    self.yang_name = "waas"
                    self.yang_parent_name = "service-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("authentication", ("authentication", Native.ServiceInsertion.ServiceContext.Waas.Authentication)), ("vrf", ("vrf", Native.ServiceInsertion.ServiceContext.Waas.Vrf))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('appnav_controller_group', (YLeaf(YType.str, 'appnav-controller-group'), ['str'])),
                        ('service_node_group', (YLeaf(YType.str, 'service-node-group'), ['str'])),
                        ('service_policy', (YLeaf(YType.str, 'service-policy'), ['str'])),
                        ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                    ])
                    self.name = None
                    self.appnav_controller_group = None
                    self.service_node_group = None
                    self.service_policy = None
                    self.enable = None

                    self.authentication = Native.ServiceInsertion.ServiceContext.Waas.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"

                    self.vrf = Native.ServiceInsertion.ServiceContext.Waas.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._segment_path = lambda: "waas" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service-insertion/Cisco-IOS-XE-service-insertion:service-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ServiceInsertion.ServiceContext.Waas, ['name', 'appnav_controller_group', 'service_node_group', 'service_policy', 'enable'], name, value)


                class Authentication(Entity):
                    """
                    Authentication key
                    
                    .. attribute:: sha1
                    
                    	Authentication type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: key
                    
                    	Authentication Key
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: encrypt
                    
                    	
                    	**type**\:  :py:class:`Encrypt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceInsertion.ServiceContext.Waas.Authentication.Encrypt>`
                    
                    .. attribute:: string
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-service-insertion'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.ServiceInsertion.ServiceContext.Waas.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "waas"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sha1', (YLeaf(YType.empty, 'sha1'), ['Empty'])),
                            ('key', (YLeaf(YType.empty, 'key'), ['Empty'])),
                            ('encrypt', (YLeaf(YType.enumeration, 'encrypt'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'ServiceInsertion.ServiceContext.Waas.Authentication.Encrypt')])),
                            ('string', (YLeaf(YType.str, 'string'), ['str'])),
                        ])
                        self.sha1 = None
                        self.key = None
                        self.encrypt = None
                        self.string = None
                        self._segment_path = lambda: "authentication"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ServiceInsertion.ServiceContext.Waas.Authentication, ['sha1', 'key', 'encrypt', 'string'], name, value)

                    class Encrypt(Enum):
                        """
                        Encrypt (Enum Class)

                        .. data:: Y_0 = 0

                        .. data:: Y_7 = 1

                        """

                        Y_0 = Enum.YLeaf(0, "0")

                        Y_7 = Enum.YLeaf(1, "7")



                class Vrf(Entity):
                    """
                    VRF
                    
                    .. attribute:: default
                    
                    	default
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: global_
                    
                    	global
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: name
                    
                    	vrf name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-service-insertion'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.ServiceInsertion.ServiceContext.Waas.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "waas"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                            ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.default = None
                        self.global_ = None
                        self.name = None
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ServiceInsertion.ServiceContext.Waas.Vrf, ['default', 'global_', 'name'], name, value)


        class ServiceNodeGroup(Entity):
            """
            service node Group
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: description
            
            	Group Description
            	**type**\: str
            
            .. attribute:: node_discovery
            
            	service node auto discovery
            	**type**\:  :py:class:`NodeDiscovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceInsertion.ServiceNodeGroup.NodeDiscovery>`
            
            .. attribute:: service_node
            
            	service node
            	**type**\: list of str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ios-service-insertion'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.ServiceInsertion.ServiceNodeGroup, self).__init__()

                self.yang_name = "service-node-group"
                self.yang_parent_name = "service-insertion"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('node_discovery', (YLeaf(YType.enumeration, 'node-discovery'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'ServiceInsertion.ServiceNodeGroup.NodeDiscovery')])),
                    ('service_node', (YLeafList(YType.str, 'service-node'), ['str'])),
                ])
                self.name = None
                self.description = None
                self.node_discovery = None
                self.service_node = []
                self._segment_path = lambda: "Cisco-IOS-XE-service-insertion:service-node-group" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service-insertion/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceInsertion.ServiceNodeGroup, ['name', 'description', 'node_discovery', 'service_node'], name, value)

            class NodeDiscovery(Enum):
                """
                NodeDiscovery (Enum Class)

                service node auto discovery

                .. data:: enable = 0

                """

                enable = Enum.YLeaf(0, "enable")



        class Swap(Entity):
            """
            Swap src\-ip
            
            .. attribute:: src_ip
            
            	Swap source\-ip of service\-insertion packets
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-service-insertion'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.ServiceInsertion.Swap, self).__init__()

                self.yang_name = "swap"
                self.yang_parent_name = "service-insertion"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('src_ip', (YLeaf(YType.empty, 'src-ip'), ['Empty'])),
                ])
                self.src_ip = None
                self._segment_path = lambda: "Cisco-IOS-XE-service-insertion:swap"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/service-insertion/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceInsertion.Swap, ['src_ip'], name, value)


    class Udld(Entity):
        """
        Configure global UDLD setting
        
        .. attribute:: aggressive
        
        	Enable UDLD protocol in aggressive mode on fiber ports exceptwhere locally configured
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: enable
        
        	Enable UDLD protocol on fiber ports except where locally configured
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: message
        
        	Set UDLD message parameters
        	**type**\:  :py:class:`Message <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Udld.Message>`
        
        .. attribute:: recovery
        
        	Enable timer to recover from udld error disable state
        	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Udld.Recovery>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Udld, self).__init__()

            self.yang_name = "udld"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-udld:message", ("message", Native.Udld.Message)), ("Cisco-IOS-XE-udld:recovery", ("recovery", Native.Udld.Recovery))])
            self._leafs = OrderedDict([
                ('aggressive', (YLeaf(YType.empty, 'Cisco-IOS-XE-udld:aggressive'), ['Empty'])),
                ('enable', (YLeaf(YType.empty, 'Cisco-IOS-XE-udld:enable'), ['Empty'])),
            ])
            self.aggressive = None
            self.enable = None

            self.message = Native.Udld.Message()
            self.message.parent = self
            self._children_name_map["message"] = "Cisco-IOS-XE-udld:message"

            self.recovery = None
            self._children_name_map["recovery"] = "Cisco-IOS-XE-udld:recovery"
            self._segment_path = lambda: "udld"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Udld, ['aggressive', 'enable'], name, value)


        class Message(Entity):
            """
            Set UDLD message parameters
            
            .. attribute:: time
            
            	Set UDLD message time period
            	**type**\: int
            
            	**range:** 1..90
            
            

            """

            _prefix = 'ios-udld'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Udld.Message, self).__init__()

                self.yang_name = "message"
                self.yang_parent_name = "udld"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('time', (YLeaf(YType.uint8, 'time'), ['int'])),
                ])
                self.time = None
                self._segment_path = lambda: "Cisco-IOS-XE-udld:message"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/udld/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Udld.Message, ['time'], name, value)


        class Recovery(Entity):
            """
            Enable timer to recover from udld error disable state
            
            .. attribute:: interval
            
            	timer\-interval(sec)
            	**type**\: int
            
            	**range:** 30..86400
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-udld'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Udld.Recovery, self).__init__()

                self.yang_name = "recovery"
                self.yang_parent_name = "udld"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                ])
                self.interval = None
                self._segment_path = lambda: "Cisco-IOS-XE-udld:recovery"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/udld/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Udld.Recovery, ['interval'], name, value)


    class Qos(Entity):
        """
        Global QoS configuration commands
        
        .. attribute:: account
        
        	Additional lengths to be accounted by QoS Features
        	**type**\:  :py:class:`Account <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.Account>`
        
        .. attribute:: control_packets
        
        	Enable QoS on control packets
        	**type**\:  :py:class:`ControlPackets <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.ControlPackets>`
        
        	**presence node**\: True
        
        .. attribute:: preserve
        
        	Preserve packet header bits
        	**type**\:  :py:class:`Preserve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.Preserve>`
        
        .. attribute:: trace
        
        	QoS trace log settings
        	**type**\:  :py:class:`Trace <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.Trace>`
        
        .. attribute:: diffservmib
        
        	RFC3289 support for QoS policy\-maps
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: queue_softmax_multiplier
        
        	global multiplier(%) for queue soft buffer maximal size
        	**type**\:  :py:class:`QueueSoftmaxMultiplier <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.QueueSoftmaxMultiplier>`
        
        

        This class is a :ref:`presence class<presence-class>`

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Qos, self).__init__()

            self.yang_name = "qos"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-qos:account", ("account", Native.Qos.Account)), ("Cisco-IOS-XE-qos:control-packets", ("control_packets", Native.Qos.ControlPackets)), ("Cisco-IOS-XE-qos:preserve", ("preserve", Native.Qos.Preserve)), ("Cisco-IOS-XE-qos:trace", ("trace", Native.Qos.Trace)), ("Cisco-IOS-XE-qos:queue-softmax-multiplier", ("queue_softmax_multiplier", Native.Qos.QueueSoftmaxMultiplier))])
            self.is_presence_container = True
            self._leafs = OrderedDict([
                ('diffservmib', (YLeaf(YType.empty, 'Cisco-IOS-XE-qos:diffservmib'), ['Empty'])),
            ])
            self.diffservmib = None

            self.account = Native.Qos.Account()
            self.account.parent = self
            self._children_name_map["account"] = "Cisco-IOS-XE-qos:account"

            self.control_packets = None
            self._children_name_map["control_packets"] = "Cisco-IOS-XE-qos:control-packets"

            self.preserve = Native.Qos.Preserve()
            self.preserve.parent = self
            self._children_name_map["preserve"] = "Cisco-IOS-XE-qos:preserve"

            self.trace = Native.Qos.Trace()
            self.trace.parent = self
            self._children_name_map["trace"] = "Cisco-IOS-XE-qos:trace"

            self.queue_softmax_multiplier = Native.Qos.QueueSoftmaxMultiplier()
            self.queue_softmax_multiplier.parent = self
            self._children_name_map["queue_softmax_multiplier"] = "Cisco-IOS-XE-qos:queue-softmax-multiplier"
            self._segment_path = lambda: "qos"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Qos, ['diffservmib'], name, value)


        class Account(Entity):
            """
            Additional lengths to be accounted by QoS Features
            
            .. attribute:: layer_all
            
            	All layers, including L1
            	**type**\:  :py:class:`LayerAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.Account.LayerAll>`
            
            .. attribute:: layer2
            
            	Accounting Layer 2 headers
            	**type**\:  :py:class:`Layer2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.Account.Layer2>`
            
            

            """

            _prefix = 'ios-qos'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Qos.Account, self).__init__()

                self.yang_name = "account"
                self.yang_parent_name = "qos"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("layer-all", ("layer_all", Native.Qos.Account.LayerAll)), ("layer2", ("layer2", Native.Qos.Account.Layer2))])
                self._leafs = OrderedDict()

                self.layer_all = Native.Qos.Account.LayerAll()
                self.layer_all.parent = self
                self._children_name_map["layer_all"] = "layer-all"

                self.layer2 = Native.Qos.Account.Layer2()
                self.layer2.parent = self
                self._children_name_map["layer2"] = "layer2"
                self._segment_path = lambda: "Cisco-IOS-XE-qos:account"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Qos.Account, [], name, value)


            class LayerAll(Entity):
                """
                All layers, including L1
                
                .. attribute:: encapsulation
                
                	Account Layer 1 Encapsulation when applying QoS features
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-qos'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Qos.Account.LayerAll, self).__init__()

                    self.yang_name = "layer-all"
                    self.yang_parent_name = "account"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('encapsulation', (YLeaf(YType.empty, 'encapsulation'), ['Empty'])),
                    ])
                    self.encapsulation = None
                    self._segment_path = lambda: "layer-all"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/Cisco-IOS-XE-qos:account/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Qos.Account.LayerAll, ['encapsulation'], name, value)


            class Layer2(Entity):
                """
                Accounting Layer 2 headers
                
                .. attribute:: encapsulation
                
                	Account Layer 2 Encapsulation when applying QoS features
                	**type**\:  :py:class:`Encapsulation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.Account.Layer2.Encapsulation>`
                
                

                """

                _prefix = 'ios-qos'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Qos.Account.Layer2, self).__init__()

                    self.yang_name = "layer2"
                    self.yang_parent_name = "account"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("encapsulation", ("encapsulation", Native.Qos.Account.Layer2.Encapsulation))])
                    self._leafs = OrderedDict()

                    self.encapsulation = Native.Qos.Account.Layer2.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"
                    self._segment_path = lambda: "layer2"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/Cisco-IOS-XE-qos:account/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Qos.Account.Layer2, [], name, value)


                class Encapsulation(Entity):
                    """
                    Account Layer 2 Encapsulation when applying QoS features
                    
                    .. attribute:: arpa
                    
                    	ARPA Encapsulation Size (18 bytes)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dot1q
                    
                    	IEEE 802.1q Encapsulation Size (22 bytes)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: isl
                    
                    	ISL Encapsulation Size (48 bytes)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: length
                    
                    	Layer2 Encapsulation length in bytes
                    	**type**\:  :py:class:`Length <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.Account.Layer2.Encapsulation.Length>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-qos'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Qos.Account.Layer2.Encapsulation, self).__init__()

                        self.yang_name = "encapsulation"
                        self.yang_parent_name = "layer2"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("length", ("length", Native.Qos.Account.Layer2.Encapsulation.Length))])
                        self._leafs = OrderedDict([
                            ('arpa', (YLeaf(YType.empty, 'arpa'), ['Empty'])),
                            ('dot1q', (YLeaf(YType.empty, 'dot1q'), ['Empty'])),
                            ('isl', (YLeaf(YType.empty, 'isl'), ['Empty'])),
                        ])
                        self.arpa = None
                        self.dot1q = None
                        self.isl = None

                        self.length = None
                        self._children_name_map["length"] = "length"
                        self._segment_path = lambda: "encapsulation"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/Cisco-IOS-XE-qos:account/layer2/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Qos.Account.Layer2.Encapsulation, ['arpa', 'dot1q', 'isl'], name, value)


                    class Length(Entity):
                        """
                        Layer2 Encapsulation length in bytes
                        
                        .. attribute:: byte_length
                        
                        	Layer2 Encapsulation length in bytes, <0\-0>
                        	**type**\: int
                        
                        	**range:** \-128..127
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-qos'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Qos.Account.Layer2.Encapsulation.Length, self).__init__()

                            self.yang_name = "length"
                            self.yang_parent_name = "encapsulation"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('byte_length', (YLeaf(YType.int8, 'byte-length'), ['int'])),
                            ])
                            self.byte_length = None
                            self._segment_path = lambda: "length"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/Cisco-IOS-XE-qos:account/layer2/encapsulation/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Qos.Account.Layer2.Encapsulation.Length, ['byte_length'], name, value)


        class ControlPackets(Entity):
            """
            Enable QoS on control packets
            
            .. attribute:: bpdu_range
            
            	Enable QoS on BPDU\-range packets
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: cdp_vtp
            
            	Enable QoS on CDP and VTP packets
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: eapol
            
            	Enable QoS on EAPOL packets
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: lldp
            
            	Enable QoS on LLDP packets
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: protocol_tunnel
            
            	Enable QoS on protocol tunneled packets
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: sstp
            
            	Enable QoS on SSTP packets
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-qos'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Qos.ControlPackets, self).__init__()

                self.yang_name = "control-packets"
                self.yang_parent_name = "qos"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('bpdu_range', (YLeaf(YType.empty, 'bpdu-range'), ['Empty'])),
                    ('cdp_vtp', (YLeaf(YType.empty, 'cdp-vtp'), ['Empty'])),
                    ('eapol', (YLeaf(YType.empty, 'eapol'), ['Empty'])),
                    ('lldp', (YLeaf(YType.empty, 'lldp'), ['Empty'])),
                    ('protocol_tunnel', (YLeaf(YType.empty, 'protocol-tunnel'), ['Empty'])),
                    ('sstp', (YLeaf(YType.empty, 'sstp'), ['Empty'])),
                ])
                self.bpdu_range = None
                self.cdp_vtp = None
                self.eapol = None
                self.lldp = None
                self.protocol_tunnel = None
                self.sstp = None
                self._segment_path = lambda: "Cisco-IOS-XE-qos:control-packets"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Qos.ControlPackets, ['bpdu_range', 'cdp_vtp', 'eapol', 'lldp', 'protocol_tunnel', 'sstp'], name, value)


        class Preserve(Entity):
            """
            Preserve packet header bits
            
            .. attribute:: marking
            
            	Preserve cos/tos header bits
            	**type**\:  :py:class:`Marking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.Preserve.Marking>`
            
            .. attribute:: mpls
            
            	Preserve MPLS packet header bits
            	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.Preserve.Mpls>`
            
            

            """

            _prefix = 'ios-qos'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Qos.Preserve, self).__init__()

                self.yang_name = "preserve"
                self.yang_parent_name = "qos"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("marking", ("marking", Native.Qos.Preserve.Marking)), ("mpls", ("mpls", Native.Qos.Preserve.Mpls))])
                self._leafs = OrderedDict()

                self.marking = Native.Qos.Preserve.Marking()
                self.marking.parent = self
                self._children_name_map["marking"] = "marking"

                self.mpls = Native.Qos.Preserve.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"
                self._segment_path = lambda: "Cisco-IOS-XE-qos:preserve"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Qos.Preserve, [], name, value)


            class Marking(Entity):
                """
                Preserve cos/tos header bits
                
                .. attribute:: hipriority
                
                	Preserve marking in high priority generated control packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-qos'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Qos.Preserve.Marking, self).__init__()

                    self.yang_name = "marking"
                    self.yang_parent_name = "preserve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('hipriority', (YLeaf(YType.empty, 'hipriority'), ['Empty'])),
                    ])
                    self.hipriority = None
                    self._segment_path = lambda: "marking"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/Cisco-IOS-XE-qos:preserve/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Qos.Preserve.Marking, ['hipriority'], name, value)


            class Mpls(Entity):
                """
                Preserve MPLS packet header bits
                
                .. attribute:: exp
                
                	Preserve MPLS EXP packet header bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-qos'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Qos.Preserve.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "preserve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('exp', (YLeaf(YType.empty, 'exp'), ['Empty'])),
                    ])
                    self.exp = None
                    self._segment_path = lambda: "mpls"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/Cisco-IOS-XE-qos:preserve/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Qos.Preserve.Mpls, ['exp'], name, value)


        class Trace(Entity):
            """
            QoS trace log settings
            
            .. attribute:: resize
            
            	resize trace log
            	**type**\:  :py:class:`Resize <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Qos.Trace.Resize>`
            
            

            """

            _prefix = 'ios-qos'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Qos.Trace, self).__init__()

                self.yang_name = "trace"
                self.yang_parent_name = "qos"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("resize", ("resize", Native.Qos.Trace.Resize))])
                self._leafs = OrderedDict()

                self.resize = Native.Qos.Trace.Resize()
                self.resize.parent = self
                self._children_name_map["resize"] = "resize"
                self._segment_path = lambda: "Cisco-IOS-XE-qos:trace"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Qos.Trace, [], name, value)


            class Resize(Entity):
                """
                resize trace log
                
                .. attribute:: size
                
                	buffer size in bytes
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: all
                
                	all trace logs
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: error
                
                	error trace log
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: event
                
                	event trace log
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: warning
                
                	warning trace log
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ios-qos'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Qos.Trace.Resize, self).__init__()

                    self.yang_name = "resize"
                    self.yang_parent_name = "trace"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('size', (YLeaf(YType.int32, 'size'), ['int'])),
                        ('all', (YLeaf(YType.int32, 'all'), ['int'])),
                        ('error', (YLeaf(YType.int32, 'error'), ['int'])),
                        ('event', (YLeaf(YType.int32, 'event'), ['int'])),
                        ('warning', (YLeaf(YType.int32, 'warning'), ['int'])),
                    ])
                    self.size = None
                    self.all = None
                    self.error = None
                    self.event = None
                    self.warning = None
                    self._segment_path = lambda: "resize"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/Cisco-IOS-XE-qos:trace/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Qos.Trace.Resize, ['size', 'all', 'error', 'event', 'warning'], name, value)


        class QueueSoftmaxMultiplier(Entity):
            """
            global multiplier(%) for queue soft buffer maximal size
            
            .. attribute:: value
            
            	multiplier(%) 100 \- 1200
            	**type**\: int
            
            	**range:** 100..1200
            
            

            """

            _prefix = 'ios-qos'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Qos.QueueSoftmaxMultiplier, self).__init__()

                self.yang_name = "queue-softmax-multiplier"
                self.yang_parent_name = "qos"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('value', (YLeaf(YType.int16, 'value'), ['int'])),
                ])
                self.value = None
                self._segment_path = lambda: "Cisco-IOS-XE-qos:queue-softmax-multiplier"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/qos/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Qos.QueueSoftmaxMultiplier, ['value'], name, value)


    class TimeRange(Entity):
        """
        Define time range entries
        
        .. attribute:: word  (key)
        
        	
        	**type**\: str
        
        .. attribute:: absolute
        
        	absolute time and date
        	**type**\:  :py:class:`Absolute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TimeRange.Absolute>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.TimeRange, self).__init__()

            self.yang_name = "time-range"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['word']
            self._child_classes = OrderedDict([("absolute", ("absolute", Native.TimeRange.Absolute))])
            self._leafs = OrderedDict([
                ('word', (YLeaf(YType.str, 'word'), ['str'])),
            ])
            self.word = None

            self.absolute = Native.TimeRange.Absolute()
            self.absolute.parent = self
            self._children_name_map["absolute"] = "absolute"
            self._segment_path = lambda: "time-range" + "[word='" + str(self.word) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.TimeRange, [u'word'], name, value)


        class Absolute(Entity):
            """
            absolute time and date
            
            .. attribute:: start
            
            	starting time and date
            	**type**\:  :py:class:`Start <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.TimeRange.Absolute.Start>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.TimeRange.Absolute, self).__init__()

                self.yang_name = "absolute"
                self.yang_parent_name = "time-range"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("start", ("start", Native.TimeRange.Absolute.Start))])
                self._leafs = OrderedDict()

                self.start = Native.TimeRange.Absolute.Start()
                self.start.parent = self
                self._children_name_map["start"] = "start"
                self._segment_path = lambda: "absolute"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.TimeRange.Absolute, [], name, value)


            class Start(Entity):
                """
                starting time and date
                
                .. attribute:: start_time
                
                	Starting time
                	**type**\: str
                
                .. attribute:: day_of_month
                
                	<1\-31>  Day of the month
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: month
                
                	Month of the year [eg\: Jan for January, Jun for June]
                	**type**\: str
                
                .. attribute:: year
                
                	Year
                	**type**\: int
                
                	**range:** 1993..2035
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.TimeRange.Absolute.Start, self).__init__()

                    self.yang_name = "start"
                    self.yang_parent_name = "absolute"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('start_time', (YLeaf(YType.str, 'start-time'), ['str'])),
                        ('day_of_month', (YLeaf(YType.uint8, 'day-of-month'), ['int'])),
                        ('month', (YLeaf(YType.str, 'month'), ['str'])),
                        ('year', (YLeaf(YType.uint16, 'year'), ['int'])),
                    ])
                    self.start_time = None
                    self.day_of_month = None
                    self.month = None
                    self.year = None
                    self._segment_path = lambda: "start"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.TimeRange.Absolute.Start, [u'start_time', u'day_of_month', u'month', u'year'], name, value)


    class DeviceTracking(Entity):
        """
        Device tracking configuration commands
        
        .. attribute:: policy
        
        	Configure a policy for feature device\-tracking
        	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Policy>`
        
        .. attribute:: tracking
        
        	
        	**type**\:  :py:class:`Tracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Tracking>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.DeviceTracking, self).__init__()

            self.yang_name = "device-tracking"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-device-tracking:policy", ("policy", Native.DeviceTracking.Policy)), ("Cisco-IOS-XE-device-tracking:tracking", ("tracking", Native.DeviceTracking.Tracking))])
            self._leafs = OrderedDict()

            self.tracking = None
            self._children_name_map["tracking"] = "Cisco-IOS-XE-device-tracking:tracking"

            self.policy = YList(self)
            self._segment_path = lambda: "device-tracking"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.DeviceTracking, [], name, value)


        class Policy(Entity):
            """
            Configure a policy for feature device\-tracking
            
            .. attribute:: word  (key)
            
            	
            	**type**\: str
            
            .. attribute:: device_role
            
            	Sets the role of the device attached to the port
            	**type**\:  :py:class:`DeviceRole <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Policy.DeviceRole>`
            
            .. attribute:: protocol
            
            	Set the protocol to glean (default all)
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Policy.Protocol>`
            
            .. attribute:: tracking
            
            	Override default tracking behavior
            	**type**\:  :py:class:`Tracking <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Policy.Tracking>`
            
            .. attribute:: limit
            
            	Specifies a limit
            	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Policy.Limit>`
            
            .. attribute:: security_level
            
            	setup security level
            	**type**\:  :py:class:`SecurityLevel <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Policy.SecurityLevel>`
            
            

            """

            _prefix = 'ios-dt'
            _revision = '2017-06-07'

            def __init__(self):
                super(Native.DeviceTracking.Policy, self).__init__()

                self.yang_name = "policy"
                self.yang_parent_name = "device-tracking"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['word']
                self._child_classes = OrderedDict([("device-role", ("device_role", Native.DeviceTracking.Policy.DeviceRole)), ("protocol", ("protocol", Native.DeviceTracking.Policy.Protocol)), ("tracking", ("tracking", Native.DeviceTracking.Policy.Tracking)), ("limit", ("limit", Native.DeviceTracking.Policy.Limit)), ("security-level", ("security_level", Native.DeviceTracking.Policy.SecurityLevel))])
                self._leafs = OrderedDict([
                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                ])
                self.word = None

                self.device_role = Native.DeviceTracking.Policy.DeviceRole()
                self.device_role.parent = self
                self._children_name_map["device_role"] = "device-role"

                self.protocol = Native.DeviceTracking.Policy.Protocol()
                self.protocol.parent = self
                self._children_name_map["protocol"] = "protocol"

                self.tracking = Native.DeviceTracking.Policy.Tracking()
                self.tracking.parent = self
                self._children_name_map["tracking"] = "tracking"

                self.limit = Native.DeviceTracking.Policy.Limit()
                self.limit.parent = self
                self._children_name_map["limit"] = "limit"

                self.security_level = Native.DeviceTracking.Policy.SecurityLevel()
                self.security_level.parent = self
                self._children_name_map["security_level"] = "security-level"
                self._segment_path = lambda: "Cisco-IOS-XE-device-tracking:policy" + "[word='" + str(self.word) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/device-tracking/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.DeviceTracking.Policy, [u'word'], name, value)


            class DeviceRole(Entity):
                """
                Sets the role of the device attached to the port
                
                .. attribute:: node
                
                	
                	**type**\: bool
                
                	**default value**\: true
                
                .. attribute:: switch
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-dt'
                _revision = '2017-06-07'

                def __init__(self):
                    super(Native.DeviceTracking.Policy.DeviceRole, self).__init__()

                    self.yang_name = "device-role"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('node', (YLeaf(YType.boolean, 'node'), ['bool'])),
                        ('switch', (YLeaf(YType.empty, 'switch'), ['Empty'])),
                    ])
                    self.node = None
                    self.switch = None
                    self._segment_path = lambda: "device-role"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.DeviceTracking.Policy.DeviceRole, [u'node', u'switch'], name, value)


            class Protocol(Entity):
                """
                Set the protocol to glean (default all)
                
                .. attribute:: udp
                
                	
                	**type**\: bool
                
                .. attribute:: arp
                
                	Glean addresses in ARP packets
                	**type**\: bool
                
                .. attribute:: dhcp4
                
                	Glean addresses in DHCPv4 packets
                	**type**\: bool
                
                .. attribute:: dhcp6
                
                	Glean addresses in DHCPv6 packets
                	**type**\: bool
                
                .. attribute:: ndp
                
                	Glean addresses in NDP packets
                	**type**\: bool
                
                

                """

                _prefix = 'ios-dt'
                _revision = '2017-06-07'

                def __init__(self):
                    super(Native.DeviceTracking.Policy.Protocol, self).__init__()

                    self.yang_name = "protocol"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('udp', (YLeaf(YType.boolean, 'udp'), ['bool'])),
                        ('arp', (YLeaf(YType.boolean, 'arp'), ['bool'])),
                        ('dhcp4', (YLeaf(YType.boolean, 'dhcp4'), ['bool'])),
                        ('dhcp6', (YLeaf(YType.boolean, 'dhcp6'), ['bool'])),
                        ('ndp', (YLeaf(YType.boolean, 'ndp'), ['bool'])),
                    ])
                    self.udp = None
                    self.arp = None
                    self.dhcp4 = None
                    self.dhcp6 = None
                    self.ndp = None
                    self._segment_path = lambda: "protocol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.DeviceTracking.Policy.Protocol, [u'udp', u'arp', u'dhcp4', u'dhcp6', u'ndp'], name, value)


            class Tracking(Entity):
                """
                Override default tracking behavior
                
                .. attribute:: enable
                
                	
                	**type**\:  :py:class:`Enable <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Policy.Tracking.Enable>`
                
                	**presence node**\: True
                
                .. attribute:: disable
                
                	Tracking on or off
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-dt'
                _revision = '2017-06-07'

                def __init__(self):
                    super(Native.DeviceTracking.Policy.Tracking, self).__init__()

                    self.yang_name = "tracking"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("enable", ("enable", Native.DeviceTracking.Policy.Tracking.Enable))])
                    self._leafs = OrderedDict([
                        ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                    ])
                    self.disable = None

                    self.enable = None
                    self._children_name_map["enable"] = "enable"
                    self._segment_path = lambda: "tracking"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.DeviceTracking.Policy.Tracking, [u'disable'], name, value)


                class Enable(Entity):
                    """
                    
                    
                    .. attribute:: reachable_lifetime
                    
                    	Time entry is kept REACHABLE
                    	**type**\:  :py:class:`ReachableLifetime <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Policy.Tracking.Enable.ReachableLifetime>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-dt'
                    _revision = '2017-06-07'

                    def __init__(self):
                        super(Native.DeviceTracking.Policy.Tracking.Enable, self).__init__()

                        self.yang_name = "enable"
                        self.yang_parent_name = "tracking"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reachable-lifetime", ("reachable_lifetime", Native.DeviceTracking.Policy.Tracking.Enable.ReachableLifetime))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.reachable_lifetime = Native.DeviceTracking.Policy.Tracking.Enable.ReachableLifetime()
                        self.reachable_lifetime.parent = self
                        self._children_name_map["reachable_lifetime"] = "reachable-lifetime"
                        self._segment_path = lambda: "enable"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.DeviceTracking.Policy.Tracking.Enable, [], name, value)


                    class ReachableLifetime(Entity):
                        """
                        Time entry is kept REACHABLE
                        
                        .. attribute:: seconds
                        
                        	Seconds
                        	**type**\: int
                        
                        	**range:** 1..86400
                        
                        

                        """

                        _prefix = 'ios-dt'
                        _revision = '2017-06-07'

                        def __init__(self):
                            super(Native.DeviceTracking.Policy.Tracking.Enable.ReachableLifetime, self).__init__()

                            self.yang_name = "reachable-lifetime"
                            self.yang_parent_name = "enable"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                            ])
                            self.seconds = None
                            self._segment_path = lambda: "reachable-lifetime"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.DeviceTracking.Policy.Tracking.Enable.ReachableLifetime, [u'seconds'], name, value)


            class Limit(Entity):
                """
                Specifies a limit
                
                .. attribute:: address_count
                
                	Configure maximum address per port
                	**type**\: int
                
                	**range:** 1..32000
                
                

                """

                _prefix = 'ios-dt'
                _revision = '2017-06-07'

                def __init__(self):
                    super(Native.DeviceTracking.Policy.Limit, self).__init__()

                    self.yang_name = "limit"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address_count', (YLeaf(YType.uint16, 'address-count'), ['int'])),
                    ])
                    self.address_count = None
                    self._segment_path = lambda: "limit"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.DeviceTracking.Policy.Limit, [u'address_count'], name, value)


            class SecurityLevel(Entity):
                """
                setup security level
                
                .. attribute:: glean
                
                	glean addresses passively
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-dt'
                _revision = '2017-06-07'

                def __init__(self):
                    super(Native.DeviceTracking.Policy.SecurityLevel, self).__init__()

                    self.yang_name = "security-level"
                    self.yang_parent_name = "policy"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('glean', (YLeaf(YType.empty, 'glean'), ['Empty'])),
                    ])
                    self.glean = None
                    self._segment_path = lambda: "security-level"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.DeviceTracking.Policy.SecurityLevel, [u'glean'], name, value)


        class Tracking(Entity):
            """
            
            
            .. attribute:: auto_source
            
            	
            	**type**\:  :py:class:`AutoSource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Tracking.AutoSource>`
            
            	**presence node**\: True
            
            .. attribute:: retry_interval
            
            	Interval time  between two probing
            	**type**\: int
            
            	**range:** 1..3600
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-dt'
            _revision = '2017-06-07'

            def __init__(self):
                super(Native.DeviceTracking.Tracking, self).__init__()

                self.yang_name = "tracking"
                self.yang_parent_name = "device-tracking"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("auto-source", ("auto_source", Native.DeviceTracking.Tracking.AutoSource))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('retry_interval', (YLeaf(YType.uint16, 'retry-interval'), ['int'])),
                ])
                self.retry_interval = None

                self.auto_source = None
                self._children_name_map["auto_source"] = "auto-source"
                self._segment_path = lambda: "Cisco-IOS-XE-device-tracking:tracking"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/device-tracking/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.DeviceTracking.Tracking, [u'retry_interval'], name, value)


            class AutoSource(Entity):
                """
                
                
                .. attribute:: fallback
                
                	Specify IP and MASK to use as last resort
                	**type**\:  :py:class:`Fallback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Tracking.AutoSource.Fallback>`
                
                .. attribute:: override
                
                	Do not select source address from device track table
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-dt'
                _revision = '2017-06-07'

                def __init__(self):
                    super(Native.DeviceTracking.Tracking.AutoSource, self).__init__()

                    self.yang_name = "auto-source"
                    self.yang_parent_name = "tracking"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("fallback", ("fallback", Native.DeviceTracking.Tracking.AutoSource.Fallback))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('override', (YLeaf(YType.empty, 'override'), ['Empty'])),
                    ])
                    self.override = None

                    self.fallback = Native.DeviceTracking.Tracking.AutoSource.Fallback()
                    self.fallback.parent = self
                    self._children_name_map["fallback"] = "fallback"
                    self._segment_path = lambda: "auto-source"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/device-tracking/Cisco-IOS-XE-device-tracking:tracking/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.DeviceTracking.Tracking.AutoSource, [u'override'], name, value)


                class Fallback(Entity):
                    """
                    Specify IP and MASK to use as last resort
                    
                    .. attribute:: ipv4_subnet_type1
                    
                    	
                    	**type**\:  :py:class:`Ipv4SubnetType1 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Tracking.AutoSource.Fallback.Ipv4SubnetType1>`
                    
                    .. attribute:: ipv4_subnet_type2
                    
                    	
                    	**type**\:  :py:class:`Ipv4SubnetType2 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceTracking.Tracking.AutoSource.Fallback.Ipv4SubnetType2>`
                    
                    

                    """

                    _prefix = 'ios-dt'
                    _revision = '2017-06-07'

                    def __init__(self):
                        super(Native.DeviceTracking.Tracking.AutoSource.Fallback, self).__init__()

                        self.yang_name = "fallback"
                        self.yang_parent_name = "auto-source"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv4-subnet-type1", ("ipv4_subnet_type1", Native.DeviceTracking.Tracking.AutoSource.Fallback.Ipv4SubnetType1)), ("ipv4-subnet-type2", ("ipv4_subnet_type2", Native.DeviceTracking.Tracking.AutoSource.Fallback.Ipv4SubnetType2))])
                        self._leafs = OrderedDict()

                        self.ipv4_subnet_type1 = Native.DeviceTracking.Tracking.AutoSource.Fallback.Ipv4SubnetType1()
                        self.ipv4_subnet_type1.parent = self
                        self._children_name_map["ipv4_subnet_type1"] = "ipv4-subnet-type1"

                        self.ipv4_subnet_type2 = Native.DeviceTracking.Tracking.AutoSource.Fallback.Ipv4SubnetType2()
                        self.ipv4_subnet_type2.parent = self
                        self._children_name_map["ipv4_subnet_type2"] = "ipv4-subnet-type2"
                        self._segment_path = lambda: "fallback"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/device-tracking/Cisco-IOS-XE-device-tracking:tracking/auto-source/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.DeviceTracking.Tracking.AutoSource.Fallback, [], name, value)


                    class Ipv4SubnetType1(Entity):
                        """
                        
                        
                        .. attribute:: ipv4
                        
                        	IPv4 address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mask
                        
                        	IP prefix mask
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: override
                        
                        	Do not select source address from device track table
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-dt'
                        _revision = '2017-06-07'

                        def __init__(self):
                            super(Native.DeviceTracking.Tracking.AutoSource.Fallback.Ipv4SubnetType1, self).__init__()

                            self.yang_name = "ipv4-subnet-type1"
                            self.yang_parent_name = "fallback"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                                ('override', (YLeaf(YType.empty, 'override'), ['Empty'])),
                            ])
                            self.ipv4 = None
                            self.mask = None
                            self.override = None
                            self._segment_path = lambda: "ipv4-subnet-type1"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/device-tracking/Cisco-IOS-XE-device-tracking:tracking/auto-source/fallback/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.DeviceTracking.Tracking.AutoSource.Fallback.Ipv4SubnetType1, [u'ipv4', u'mask', u'override'], name, value)


                    class Ipv4SubnetType2(Entity):
                        """
                        
                        
                        .. attribute:: ipv4_prefix_name
                        
                        	ip address/length <network>/<length>, e.g., 192.168.12.12/16
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        .. attribute:: override
                        
                        	Do not select source address from device track table
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-dt'
                        _revision = '2017-06-07'

                        def __init__(self):
                            super(Native.DeviceTracking.Tracking.AutoSource.Fallback.Ipv4SubnetType2, self).__init__()

                            self.yang_name = "ipv4-subnet-type2"
                            self.yang_parent_name = "fallback"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_prefix_name', (YLeaf(YType.str, 'ipv4-prefix-name'), ['str'])),
                                ('override', (YLeaf(YType.empty, 'override'), ['Empty'])),
                            ])
                            self.ipv4_prefix_name = None
                            self.override = None
                            self._segment_path = lambda: "ipv4-subnet-type2"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/device-tracking/Cisco-IOS-XE-device-tracking:tracking/auto-source/fallback/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.DeviceTracking.Tracking.AutoSource.Fallback.Ipv4SubnetType2, [u'ipv4_prefix_name', u'override'], name, value)


    class Fhrp(Entity):
        """
        Configure First Hop Redundancy Protocols
        
        .. attribute:: version
        
        	Configure which FHRP version is allowed to run
        	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fhrp.Version>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Fhrp, self).__init__()

            self.yang_name = "fhrp"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("version", ("version", Native.Fhrp.Version))])
            self._leafs = OrderedDict()

            self.version = Native.Fhrp.Version()
            self.version.parent = self
            self._children_name_map["version"] = "version"
            self._segment_path = lambda: "fhrp"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Fhrp, [], name, value)


        class Version(Entity):
            """
            Configure which FHRP version is allowed to run
            
            .. attribute:: vrrp
            
            	Configure Virtual Router Rendundancy Protocol
            	**type**\:  :py:class:`Vrrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Fhrp.Version.Vrrp>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Fhrp.Version, self).__init__()

                self.yang_name = "version"
                self.yang_parent_name = "fhrp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('vrrp', (YLeaf(YType.enumeration, 'vrrp'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Fhrp.Version.Vrrp')])),
                ])
                self.vrrp = None
                self._segment_path = lambda: "version"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/fhrp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Fhrp.Version, [u'vrrp'], name, value)

            class Vrrp(Enum):
                """
                Vrrp (Enum Class)

                Configure Virtual Router Rendundancy Protocol

                .. data:: v2 = 0

                .. data:: v3 = 1

                """

                v2 = Enum.YLeaf(0, "v2")

                v3 = Enum.YLeaf(1, "v3")



    class Metadata(Entity):
        """
        Metadata Application
        
        .. attribute:: flow
        
        	Enable Metadata Flow Handling
        	**type**\:  :py:class:`Flow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Metadata.Flow>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Metadata, self).__init__()

            self.yang_name = "metadata"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("flow", ("flow", Native.Metadata.Flow))])
            self._leafs = OrderedDict()

            self.flow = None
            self._children_name_map["flow"] = "flow"
            self._segment_path = lambda: "metadata"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Metadata, [], name, value)


        class Flow(Entity):
            """
            Enable Metadata Flow Handling
            
            .. attribute:: transmit
            
            	Enable Metadata Flow Transmit 
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Metadata.Flow, self).__init__()

                self.yang_name = "flow"
                self.yang_parent_name = "metadata"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('transmit', (YLeaf(YType.empty, 'transmit'), ['Empty'])),
                ])
                self.transmit = None
                self._segment_path = lambda: "flow"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/metadata/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Metadata.Flow, [u'transmit'], name, value)


    class Profile(Entity):
        """
        MSP Profile
        
        .. attribute:: flow
        
        	MSP Profile Flow
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Profile, self).__init__()

            self.yang_name = "profile"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('flow', (YLeaf(YType.empty, 'flow'), ['Empty'])),
            ])
            self.flow = None
            self._segment_path = lambda: "profile"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Profile, [u'flow'], name, value)


    class Alias(Entity):
        """
        Create command alias
        
        .. attribute:: exec_
        
        	Exec mode
        	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Alias.Exec>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Alias, self).__init__()

            self.yang_name = "alias"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("exec", ("exec_", Native.Alias.Exec))])
            self._leafs = OrderedDict()

            self.exec_ = Native.Alias.Exec()
            self.exec_.parent = self
            self._children_name_map["exec_"] = "exec"
            self._segment_path = lambda: "alias"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Alias, [], name, value)


        class Exec(Entity):
            """
            Exec mode
            
            .. attribute:: alias_name
            
            	
            	**type**\: str
            
            .. attribute:: new_alias_name
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Alias.Exec, self).__init__()

                self.yang_name = "exec"
                self.yang_parent_name = "alias"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('alias_name', (YLeaf(YType.str, 'alias-name'), ['str'])),
                    ('new_alias_name', (YLeaf(YType.str, 'new-alias-name'), ['str'])),
                ])
                self.alias_name = None
                self.new_alias_name = None
                self._segment_path = lambda: "exec"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/alias/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Alias.Exec, [u'alias_name', u'new_alias_name'], name, value)


    class Line(Entity):
        """
        Configure a terminal line
        
        .. attribute:: line_list
        
        	
        	**type**\: list of  		 :py:class:`LineList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList>`
        
        .. attribute:: aux
        
        	Auxiliary line
        	**type**\: list of  		 :py:class:`Aux <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux>`
        
        .. attribute:: console
        
        	Primary terminal line
        	**type**\: list of  		 :py:class:`Console <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console>`
        
        .. attribute:: vty
        
        	Virtual terminal
        	**type**\: list of  		 :py:class:`Vty <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Line, self).__init__()

            self.yang_name = "line"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("line-list", ("line_list", Native.Line.LineList)), ("aux", ("aux", Native.Line.Aux)), ("console", ("console", Native.Line.Console)), ("vty", ("vty", Native.Line.Vty))])
            self._leafs = OrderedDict()

            self.line_list = YList(self)
            self.aux = YList(self)
            self.console = YList(self)
            self.vty = YList(self)
            self._segment_path = lambda: "line"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Line, [], name, value)


        class LineList(Entity):
            """
            
            
            .. attribute:: first_number  (key)
            
            	First Line number
            	**type**\: int
            
            	**range:** 0..17
            
            .. attribute:: last_number
            
            	
            	**type**\: int
            
            	**range:** 1..17
            
            .. attribute:: authorization
            
            	Authorization parameters
            	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Authorization>`
            
            .. attribute:: access_class
            
            	Filter connections based on an IP access list
            	**type**\:  :py:class:`AccessClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.AccessClass>`
            
            .. attribute:: no_activation_character
            
            	
            	**type**\: bool
            
            .. attribute:: activation_character
            
            	Define the activation character
            	**type**\: union of the below types:
            
            		**type**\: str
            
            		**type**\: int
            
            			**range:** 0..127
            
            .. attribute:: autocommand
            
            	Automatically execute an EXEC command
            	**type**\:  :py:class:`Autocommand <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Autocommand>`
            
            .. attribute:: autocommand_options
            
            	Autocommand options
            	**type**\:  :py:class:`AutocommandOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.AutocommandOptions>`
            
            	**presence node**\: True
            
            .. attribute:: data_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: databits
            
            	Set number of data bits per character
            	**type**\:  :py:class:`Databits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Databits>`
            
            .. attribute:: domain_lookup
            
            	Enable domain lookups in show commands
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: editing
            
            	Enable command line editing
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: escape_character
            
            	Change the current line's escape character
            	**type**\:  :py:class:`EscapeCharacter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.EscapeCharacter>`
            
            .. attribute:: no_exec
            
            	
            	**type**\:  :py:class:`NoExec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.NoExec>`
            
            .. attribute:: exec_
            
            	
            	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Exec>`
            
            .. attribute:: exec_banner
            
            	Enable the display of the EXEC banner
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: exec_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: exec_timeout
            
            	Set the EXEC timeout
            	**type**\:  :py:class:`ExecTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.ExecTimeout>`
            
            .. attribute:: flowcontrol
            
            	Set the flow control
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Flowcontrol>`
            
            .. attribute:: full_help
            
            	Provide help to unprivileged user
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: history
            
            	Enable and control the command history function
            	**type**\:  :py:class:`History <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.History>`
            
            	**presence node**\: True
            
            .. attribute:: international
            
            	Enable international 8\-bit character support
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ip
            
            	IP options
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Ip>`
            
            .. attribute:: ipv6
            
            	
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Ipv6>`
            
            .. attribute:: length
            
            	Set number of lines on a screen
            	**type**\: int
            
            	**range:** 0..512
            
            .. attribute:: line
            
            	
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: location
            
            	One text line describing the terminal's location
            	**type**\: str
            
            .. attribute:: logging
            
            	Modify message logging facilities
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Logging>`
            
            .. attribute:: login
            
            	Enable password checking
            	**type**\:  :py:class:`Login <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Login>`
            
            	**presence node**\: True
            
            .. attribute:: media_type
            
            	Console connection media type
            	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.MediaType>`
            
            .. attribute:: modem
            
            	Configure the Modem Control Lines
            	**type**\:  :py:class:`Modem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Modem>`
            
            .. attribute:: monitor
            
            	Copy debug output to the current terminal line
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: motd_banner
            
            	Enable the display of the MOTD banner
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: notify
            
            	Inform users of output from concurrent sessions
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: padding
            
            	Set padding for a specified output character
            	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Padding>`
            
            .. attribute:: parity
            
            	Set terminal parity
            	**type**\:  :py:class:`Parity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Parity>`
            
            .. attribute:: password
            
            	Set a password
            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Password>`
            
            .. attribute:: prc
            
            	PRC commands
            	**type**\:  :py:class:`Prc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Prc>`
            
            .. attribute:: privilege
            
            	Change privilege level for line
            	**type**\:  :py:class:`Privilege <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Privilege>`
            
            .. attribute:: rotary
            
            	Rotary group to add line to
            	**type**\: int
            
            	**range:** 1..99
            
            .. attribute:: rxspeed
            
            	Receive speed
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_limit
            
            	Set maximum number of sessions
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_timeout
            
            	Set interval for closing connection when there is no input traffic
            	**type**\:  :py:class:`SessionTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.SessionTimeout>`
            
            .. attribute:: special_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: speed
            
            	Transmit and receive speeds
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: start_character
            
            	Define the start character
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..255
            
            		**type**\: str
            
            .. attribute:: stop_character
            
            	Define the stop character
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..255
            
            		**type**\: str
            
            .. attribute:: stopbits
            
            	Set async line stop bits
            	**type**\:  :py:class:`Stopbits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Stopbits>`
            
            .. attribute:: terminal_type
            
            	Terminal type
            	**type**\: str
            
            .. attribute:: timeout
            
            	Timeouts for the line
            	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Timeout>`
            
            .. attribute:: telnet
            
            	Telnet protocol\-specific configuration
            	**type**\:  :py:class:`Telnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Telnet>`
            
            .. attribute:: transport
            
            	Define transport protocols for line
            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Transport>`
            
            .. attribute:: txspeed
            
            	Transmit speed
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: usb_inactivity_timeout
            
            	Inactivity timeout for USB media type
            	**type**\:  :py:class:`UsbInactivityTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.UsbInactivityTimeout>`
            
            .. attribute:: width
            
            	Number of characters on a screen line
            	**type**\: int
            
            	**range:** 0..512
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Line.LineList, self).__init__()

                self.yang_name = "line-list"
                self.yang_parent_name = "line"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['first_number']
                self._child_classes = OrderedDict([("authorization", ("authorization", Native.Line.LineList.Authorization)), ("access-class", ("access_class", Native.Line.LineList.AccessClass)), ("autocommand", ("autocommand", Native.Line.LineList.Autocommand)), ("autocommand-options", ("autocommand_options", Native.Line.LineList.AutocommandOptions)), ("databits", ("databits", Native.Line.LineList.Databits)), ("escape-character", ("escape_character", Native.Line.LineList.EscapeCharacter)), ("no-exec", ("no_exec", Native.Line.LineList.NoExec)), ("exec", ("exec_", Native.Line.LineList.Exec)), ("exec-timeout", ("exec_timeout", Native.Line.LineList.ExecTimeout)), ("flowcontrol", ("flowcontrol", Native.Line.LineList.Flowcontrol)), ("history", ("history", Native.Line.LineList.History)), ("ip", ("ip", Native.Line.LineList.Ip)), ("ipv6", ("ipv6", Native.Line.LineList.Ipv6)), ("logging", ("logging", Native.Line.LineList.Logging)), ("login", ("login", Native.Line.LineList.Login)), ("media-type", ("media_type", Native.Line.LineList.MediaType)), ("modem", ("modem", Native.Line.LineList.Modem)), ("padding", ("padding", Native.Line.LineList.Padding)), ("parity", ("parity", Native.Line.LineList.Parity)), ("password", ("password", Native.Line.LineList.Password)), ("prc", ("prc", Native.Line.LineList.Prc)), ("privilege", ("privilege", Native.Line.LineList.Privilege)), ("session-timeout", ("session_timeout", Native.Line.LineList.SessionTimeout)), ("timeout", ("timeout", Native.Line.LineList.Timeout)), ("telnet", ("telnet", Native.Line.LineList.Telnet)), ("transport", ("transport", Native.Line.LineList.Transport)), ("usb-inactivity-timeout", ("usb_inactivity_timeout", Native.Line.LineList.UsbInactivityTimeout))])
                self._leafs = OrderedDict([
                    ('first_number', (YLeaf(YType.uint8, 'first-number'), ['int'])),
                    ('last_number', (YLeaf(YType.uint16, 'last-number'), ['int'])),
                    ('no_activation_character', (YLeaf(YType.boolean, 'no-activation-character'), ['bool'])),
                    ('activation_character', (YLeaf(YType.str, 'activation-character'), ['str','int'])),
                    ('data_character_bits', (YLeaf(YType.uint8, 'data-character-bits'), ['int'])),
                    ('domain_lookup', (YLeaf(YType.empty, 'domain-lookup'), ['Empty'])),
                    ('editing', (YLeaf(YType.empty, 'editing'), ['Empty'])),
                    ('exec_banner', (YLeaf(YType.empty, 'exec-banner'), ['Empty'])),
                    ('exec_character_bits', (YLeaf(YType.uint8, 'exec-character-bits'), ['int'])),
                    ('full_help', (YLeaf(YType.empty, 'full-help'), ['Empty'])),
                    ('international', (YLeaf(YType.empty, 'international'), ['Empty'])),
                    ('length', (YLeaf(YType.uint16, 'length'), ['int'])),
                    ('line', (YLeaf(YType.uint8, 'line'), ['int'])),
                    ('location', (YLeaf(YType.str, 'location'), ['str'])),
                    ('monitor', (YLeaf(YType.empty, 'monitor'), ['Empty'])),
                    ('motd_banner', (YLeaf(YType.empty, 'motd-banner'), ['Empty'])),
                    ('notify', (YLeaf(YType.empty, 'notify'), ['Empty'])),
                    ('rotary', (YLeaf(YType.uint8, 'rotary'), ['int'])),
                    ('rxspeed', (YLeaf(YType.uint32, 'rxspeed'), ['int'])),
                    ('session_limit', (YLeaf(YType.uint32, 'session-limit'), ['int'])),
                    ('special_character_bits', (YLeaf(YType.uint8, 'special-character-bits'), ['int'])),
                    ('speed', (YLeaf(YType.uint32, 'speed'), ['int'])),
                    ('start_character', (YLeaf(YType.str, 'start-character'), ['int','str'])),
                    ('stop_character', (YLeaf(YType.str, 'stop-character'), ['int','str'])),
                    ('stopbits', (YLeaf(YType.enumeration, 'stopbits'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.LineList.Stopbits')])),
                    ('terminal_type', (YLeaf(YType.str, 'terminal-type'), ['str'])),
                    ('txspeed', (YLeaf(YType.uint32, 'txspeed'), ['int'])),
                    ('width', (YLeaf(YType.uint16, 'width'), ['int'])),
                ])
                self.first_number = None
                self.last_number = None
                self.no_activation_character = None
                self.activation_character = None
                self.data_character_bits = None
                self.domain_lookup = None
                self.editing = None
                self.exec_banner = None
                self.exec_character_bits = None
                self.full_help = None
                self.international = None
                self.length = None
                self.line = None
                self.location = None
                self.monitor = None
                self.motd_banner = None
                self.notify = None
                self.rotary = None
                self.rxspeed = None
                self.session_limit = None
                self.special_character_bits = None
                self.speed = None
                self.start_character = None
                self.stop_character = None
                self.stopbits = None
                self.terminal_type = None
                self.txspeed = None
                self.width = None

                self.authorization = Native.Line.LineList.Authorization()
                self.authorization.parent = self
                self._children_name_map["authorization"] = "authorization"

                self.access_class = Native.Line.LineList.AccessClass()
                self.access_class.parent = self
                self._children_name_map["access_class"] = "access-class"

                self.autocommand = Native.Line.LineList.Autocommand()
                self.autocommand.parent = self
                self._children_name_map["autocommand"] = "autocommand"

                self.autocommand_options = None
                self._children_name_map["autocommand_options"] = "autocommand-options"

                self.databits = Native.Line.LineList.Databits()
                self.databits.parent = self
                self._children_name_map["databits"] = "databits"

                self.escape_character = Native.Line.LineList.EscapeCharacter()
                self.escape_character.parent = self
                self._children_name_map["escape_character"] = "escape-character"

                self.no_exec = Native.Line.LineList.NoExec()
                self.no_exec.parent = self
                self._children_name_map["no_exec"] = "no-exec"

                self.exec_ = Native.Line.LineList.Exec()
                self.exec_.parent = self
                self._children_name_map["exec_"] = "exec"

                self.exec_timeout = Native.Line.LineList.ExecTimeout()
                self.exec_timeout.parent = self
                self._children_name_map["exec_timeout"] = "exec-timeout"

                self.flowcontrol = Native.Line.LineList.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.history = None
                self._children_name_map["history"] = "history"

                self.ip = Native.Line.LineList.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Line.LineList.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Line.LineList.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.login = None
                self._children_name_map["login"] = "login"

                self.media_type = Native.Line.LineList.MediaType()
                self.media_type.parent = self
                self._children_name_map["media_type"] = "media-type"

                self.modem = Native.Line.LineList.Modem()
                self.modem.parent = self
                self._children_name_map["modem"] = "modem"

                self.padding = Native.Line.LineList.Padding()
                self.padding.parent = self
                self._children_name_map["padding"] = "padding"

                self.parity = Native.Line.LineList.Parity()
                self.parity.parent = self
                self._children_name_map["parity"] = "parity"

                self.password = Native.Line.LineList.Password()
                self.password.parent = self
                self._children_name_map["password"] = "password"

                self.prc = Native.Line.LineList.Prc()
                self.prc.parent = self
                self._children_name_map["prc"] = "prc"

                self.privilege = Native.Line.LineList.Privilege()
                self.privilege.parent = self
                self._children_name_map["privilege"] = "privilege"

                self.session_timeout = Native.Line.LineList.SessionTimeout()
                self.session_timeout.parent = self
                self._children_name_map["session_timeout"] = "session-timeout"

                self.timeout = Native.Line.LineList.Timeout()
                self.timeout.parent = self
                self._children_name_map["timeout"] = "timeout"

                self.telnet = Native.Line.LineList.Telnet()
                self.telnet.parent = self
                self._children_name_map["telnet"] = "telnet"

                self.transport = Native.Line.LineList.Transport()
                self.transport.parent = self
                self._children_name_map["transport"] = "transport"

                self.usb_inactivity_timeout = Native.Line.LineList.UsbInactivityTimeout()
                self.usb_inactivity_timeout.parent = self
                self._children_name_map["usb_inactivity_timeout"] = "usb-inactivity-timeout"
                self._segment_path = lambda: "line-list" + "[first-number='" + str(self.first_number) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/line/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Line.LineList, [u'first_number', u'last_number', u'no_activation_character', u'activation_character', u'data_character_bits', u'domain_lookup', u'editing', u'exec_banner', u'exec_character_bits', u'full_help', u'international', u'length', u'line', u'location', u'monitor', u'motd_banner', u'notify', u'rotary', u'rxspeed', u'session_limit', u'special_character_bits', u'speed', u'start_character', u'stop_character', u'stopbits', u'terminal_type', u'txspeed', u'width'], name, value)

            class Stopbits(Enum):
                """
                Stopbits (Enum Class)

                Set async line stop bits

                .. data:: Y_1 = 0

                .. data:: Y_1__DOT__5 = 1

                .. data:: Y_2 = 2

                """

                Y_1 = Enum.YLeaf(0, "1")

                Y_1__DOT__5 = Enum.YLeaf(1, "1.5")

                Y_2 = Enum.YLeaf(2, "2")



            class Authorization(Entity):
                """
                Authorization parameters
                
                .. attribute:: command
                
                	For exec (shell) commands
                	**type**\:  :py:class:`Command <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Authorization.Command>`
                
                .. attribute:: exec_
                
                	For starting an exec (shell)
                	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Authorization.Exec>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Authorization, self).__init__()

                    self.yang_name = "authorization"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("command", ("command", Native.Line.LineList.Authorization.Command)), ("exec", ("exec_", Native.Line.LineList.Authorization.Exec))])
                    self._leafs = OrderedDict()

                    self.command = Native.Line.LineList.Authorization.Command()
                    self.command.parent = self
                    self._children_name_map["command"] = "command"

                    self.exec_ = Native.Line.LineList.Authorization.Exec()
                    self.exec_.parent = self
                    self._children_name_map["exec_"] = "exec"
                    self._segment_path = lambda: "authorization"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Authorization, [], name, value)


                class Command(Entity):
                    """
                    For exec (shell) commands
                    
                    .. attribute:: enable_level
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..15
                    
                    .. attribute:: auth_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.Authorization.Command, self).__init__()

                        self.yang_name = "command"
                        self.yang_parent_name = "authorization"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable_level', (YLeaf(YType.uint8, 'enable-level'), ['int'])),
                            ('auth_name', (YLeaf(YType.str, 'auth-name'), ['str'])),
                        ])
                        self.enable_level = None
                        self.auth_name = None
                        self._segment_path = lambda: "command"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.Authorization.Command, [u'enable_level', u'auth_name'], name, value)


                class Exec(Entity):
                    """
                    For starting an exec (shell)
                    
                    .. attribute:: authorization_name
                    
                    	Use an authorization list with this name
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	Use the default authorization list
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.Authorization.Exec, self).__init__()

                        self.yang_name = "exec"
                        self.yang_parent_name = "authorization"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('authorization_name', (YLeaf(YType.str, 'authorization-name'), ['str'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.authorization_name = None
                        self.default = None
                        self._segment_path = lambda: "exec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.Authorization.Exec, [u'authorization_name', u'default'], name, value)


            class AccessClass(Entity):
                """
                Filter connections based on an IP access list
                
                .. attribute:: acccess_list
                
                	
                	**type**\: list of  		 :py:class:`AcccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.AccessClass.AcccessList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.AccessClass, self).__init__()

                    self.yang_name = "access-class"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("acccess-list", ("acccess_list", Native.Line.LineList.AccessClass.AcccessList))])
                    self._leafs = OrderedDict()

                    self.acccess_list = YList(self)
                    self._segment_path = lambda: "access-class"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.AccessClass, [], name, value)


                class AcccessList(Entity):
                    """
                    
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.AccessClass.AcccessList.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    	**mandatory**\: True
                    
                    .. attribute:: vrf_also
                    
                    	Same access list is applied for all VRFs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.AccessClass.AcccessList, self).__init__()

                        self.yang_name = "acccess-list"
                        self.yang_parent_name = "access-class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.LineList.AccessClass.AcccessList.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['int','str'])),
                            ('vrf_also', (YLeaf(YType.empty, 'vrf-also'), ['Empty'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self.vrf_also = None
                        self._segment_path = lambda: "acccess-list" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.AccessClass.AcccessList, [u'direction', u'access_list', u'vrf_also'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Autocommand(Entity):
                """
                Automatically execute an EXEC command
                
                .. attribute:: line
                
                	Appropriate EXEC command
                	**type**\: str
                
                .. attribute:: no_suppress_linenumber
                
                	Display service linenumber message
                	**type**\:  :py:class:`NoSuppressLinenumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Autocommand.NoSuppressLinenumber>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Autocommand, self).__init__()

                    self.yang_name = "autocommand"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("no-suppress-linenumber", ("no_suppress_linenumber", Native.Line.LineList.Autocommand.NoSuppressLinenumber))])
                    self._leafs = OrderedDict([
                        ('line', (YLeaf(YType.str, 'line'), ['str'])),
                    ])
                    self.line = None

                    self.no_suppress_linenumber = None
                    self._children_name_map["no_suppress_linenumber"] = "no-suppress-linenumber"
                    self._segment_path = lambda: "autocommand"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Autocommand, [u'line'], name, value)


                class NoSuppressLinenumber(Entity):
                    """
                    Display service linenumber message
                    
                    .. attribute:: line
                    
                    	Appropriate EXEC command
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.Autocommand.NoSuppressLinenumber, self).__init__()

                        self.yang_name = "no-suppress-linenumber"
                        self.yang_parent_name = "autocommand"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('line', (YLeaf(YType.str, 'line'), ['str'])),
                        ])
                        self.line = None
                        self._segment_path = lambda: "no-suppress-linenumber"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.Autocommand.NoSuppressLinenumber, [u'line'], name, value)


            class AutocommandOptions(Entity):
                """
                Autocommand options
                
                .. attribute:: abort_character
                
                	Autocommand abort character
                	**type**\:  :py:class:`AbortCharacter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.AutocommandOptions.AbortCharacter>`
                
                	**presence node**\: True
                
                .. attribute:: delay
                
                	Delay autocommand execution
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.AutocommandOptions.Delay>`
                
                	**presence node**\: True
                
                .. attribute:: nohangup
                
                	No hangup after autocommand completion
                	**type**\:  :py:class:`Nohangup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.AutocommandOptions.Nohangup>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.AutocommandOptions, self).__init__()

                    self.yang_name = "autocommand-options"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("abort-character", ("abort_character", Native.Line.LineList.AutocommandOptions.AbortCharacter)), ("delay", ("delay", Native.Line.LineList.AutocommandOptions.Delay)), ("nohangup", ("nohangup", Native.Line.LineList.AutocommandOptions.Nohangup))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.abort_character = None
                    self._children_name_map["abort_character"] = "abort-character"

                    self.delay = None
                    self._children_name_map["delay"] = "delay"

                    self.nohangup = None
                    self._children_name_map["nohangup"] = "nohangup"
                    self._segment_path = lambda: "autocommand-options"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.AutocommandOptions, [], name, value)


                class AbortCharacter(Entity):
                    """
                    Autocommand abort character
                    
                    .. attribute:: character
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..255
                    
                    		**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.AutocommandOptions.AbortCharacter, self).__init__()

                        self.yang_name = "abort-character"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('character', (YLeaf(YType.str, 'character'), ['int','str'])),
                        ])
                        self.character = None
                        self._segment_path = lambda: "abort-character"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.AutocommandOptions.AbortCharacter, [u'character'], name, value)


                class Delay(Entity):
                    """
                    Delay autocommand execution
                    
                    .. attribute:: time
                    
                    	Time in seconds
                    	**type**\: int
                    
                    	**range:** 0..120
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.AutocommandOptions.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('time', (YLeaf(YType.uint8, 'time'), ['int'])),
                        ])
                        self.time = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.AutocommandOptions.Delay, [u'time'], name, value)


                class Nohangup(Entity):
                    """
                    No hangup after autocommand completion
                    
                    .. attribute:: abort_character
                    
                    	Autocommand abort character
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: delay
                    
                    	Delay autocommand execution
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.AutocommandOptions.Nohangup, self).__init__()

                        self.yang_name = "nohangup"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('abort_character', (YLeaf(YType.empty, 'abort-character'), ['Empty'])),
                            ('delay', (YLeaf(YType.empty, 'delay'), ['Empty'])),
                        ])
                        self.abort_character = None
                        self.delay = None
                        self._segment_path = lambda: "nohangup"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.AutocommandOptions.Nohangup, [u'abort_character', u'delay'], name, value)


            class Databits(Entity):
                """
                Set number of data bits per character
                
                .. attribute:: set_to_5
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_6
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_7
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_8
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Databits, self).__init__()

                    self.yang_name = "databits"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('set_to_5', (YLeaf(YType.empty, 'set-to-5'), ['Empty'])),
                        ('set_to_6', (YLeaf(YType.empty, 'set-to-6'), ['Empty'])),
                        ('set_to_7', (YLeaf(YType.empty, 'set-to-7'), ['Empty'])),
                        ('set_to_8', (YLeaf(YType.empty, 'set-to-8'), ['Empty'])),
                    ])
                    self.set_to_5 = None
                    self.set_to_6 = None
                    self.set_to_7 = None
                    self.set_to_8 = None
                    self._segment_path = lambda: "databits"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Databits, [u'set_to_5', u'set_to_6', u'set_to_7', u'set_to_8'], name, value)


            class EscapeCharacter(Entity):
                """
                Change the current line's escape character
                
                .. attribute:: char
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..255
                
                		**type**\:  :py:class:`Char <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.EscapeCharacter.Char>`
                
                		**type**\: str
                
                .. attribute:: soft
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.EscapeCharacter, self).__init__()

                    self.yang_name = "escape-character"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('char', (YLeaf(YType.str, 'char'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.EscapeCharacter.Char'),'str'])),
                        ('soft', (YLeaf(YType.empty, 'soft'), ['Empty'])),
                    ])
                    self.char = None
                    self.soft = None
                    self._segment_path = lambda: "escape-character"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.EscapeCharacter, [u'char', u'soft'], name, value)

                class Char(Enum):
                    """
                    Char (Enum Class)

                    .. data:: BREAK = 0

                    .. data:: DEFAULT = 1

                    .. data:: NONE = 2

                    """

                    BREAK = Enum.YLeaf(0, "BREAK")

                    DEFAULT = Enum.YLeaf(1, "DEFAULT")

                    NONE = Enum.YLeaf(2, "NONE")



            class NoExec(Entity):
                """
                
                
                .. attribute:: exec_
                
                	Configure EXEC
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.NoExec, self).__init__()

                    self.yang_name = "no-exec"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('exec_', (YLeaf(YType.boolean, 'exec'), ['bool'])),
                    ])
                    self.exec_ = None
                    self._segment_path = lambda: "no-exec"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.NoExec, [u'exec_'], name, value)


            class Exec(Entity):
                """
                
                
                .. attribute:: prompt
                
                	
                	**type**\:  :py:class:`Prompt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Exec.Prompt>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Exec, self).__init__()

                    self.yang_name = "exec"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("prompt", ("prompt", Native.Line.LineList.Exec.Prompt))])
                    self._leafs = OrderedDict()

                    self.prompt = Native.Line.LineList.Exec.Prompt()
                    self.prompt.parent = self
                    self._children_name_map["prompt"] = "prompt"
                    self._segment_path = lambda: "exec"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Exec, [], name, value)


                class Prompt(Entity):
                    """
                    
                    
                    .. attribute:: timestamp
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.Exec.Prompt, self).__init__()

                        self.yang_name = "prompt"
                        self.yang_parent_name = "exec"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('timestamp', (YLeaf(YType.empty, 'timestamp'), ['Empty'])),
                        ])
                        self.timestamp = None
                        self._segment_path = lambda: "prompt"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.Exec.Prompt, [u'timestamp'], name, value)


            class ExecTimeout(Entity):
                """
                Set the EXEC timeout
                
                .. attribute:: minutes
                
                	<0\-35791>;;Timeout in minutes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: seconds
                
                	<0\-2147483>;;Timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.ExecTimeout, self).__init__()

                    self.yang_name = "exec-timeout"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('minutes', (YLeaf(YType.uint32, 'minutes'), ['int'])),
                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                    ])
                    self.minutes = None
                    self.seconds = None
                    self._segment_path = lambda: "exec-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.ExecTimeout, [u'minutes', u'seconds'], name, value)


            class Flowcontrol(Entity):
                """
                Set the flow control
                
                .. attribute:: none
                
                	Set no flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hardware
                
                	Set hardware flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: software
                
                	Set software flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('none', (YLeaf(YType.empty, 'NONE'), ['Empty'])),
                        ('hardware', (YLeaf(YType.empty, 'hardware'), ['Empty'])),
                        ('software', (YLeaf(YType.empty, 'software'), ['Empty'])),
                    ])
                    self.none = None
                    self.hardware = None
                    self.software = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Flowcontrol, [u'none', u'hardware', u'software'], name, value)


            class History(Entity):
                """
                Enable and control the command history function
                
                .. attribute:: size
                
                	Set history buffer size
                	**type**\: int
                
                	**range:** 0..256
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.History, self).__init__()

                    self.yang_name = "history"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                    ])
                    self.size = None
                    self._segment_path = lambda: "history"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.History, [u'size'], name, value)


            class Ip(Entity):
                """
                IP options
                
                .. attribute:: netmask_format
                
                	Change display of netmasks
                	**type**\:  :py:class:`NetmaskFormat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Ip.NetmaskFormat>`
                
                	**presence node**\: True
                
                .. attribute:: tcp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("netmask-format", ("netmask_format", Native.Line.LineList.Ip.NetmaskFormat))])
                    self._leafs = OrderedDict([
                        ('tcp', (YLeaf(YType.empty, 'tcp'), ['Empty'])),
                    ])
                    self.tcp = None

                    self.netmask_format = None
                    self._children_name_map["netmask_format"] = "netmask-format"
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Ip, [u'tcp'], name, value)


                class NetmaskFormat(Entity):
                    """
                    Change display of netmasks
                    
                    .. attribute:: format
                    
                    	
                    	**type**\:  :py:class:`Format <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Ip.NetmaskFormat.Format>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.Ip.NetmaskFormat, self).__init__()

                        self.yang_name = "netmask-format"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('format', (YLeaf(YType.enumeration, 'format'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.LineList.Ip.NetmaskFormat.Format')])),
                        ])
                        self.format = None
                        self._segment_path = lambda: "netmask-format"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.Ip.NetmaskFormat, [u'format'], name, value)

                    class Format(Enum):
                        """
                        Format (Enum Class)

                        .. data:: bit_count = 0

                        .. data:: decimal = 1

                        .. data:: hexadecimal = 2

                        """

                        bit_count = Enum.YLeaf(0, "bit-count")

                        decimal = Enum.YLeaf(1, "decimal")

                        hexadecimal = Enum.YLeaf(2, "hexadecimal")



            class Ipv6(Entity):
                """
                
                
                .. attribute:: access_class
                
                	
                	**type**\:  :py:class:`AccessClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Ipv6.AccessClass>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-class", ("access_class", Native.Line.LineList.Ipv6.AccessClass))])
                    self._leafs = OrderedDict()

                    self.access_class = Native.Line.LineList.Ipv6.AccessClass()
                    self.access_class.parent = self
                    self._children_name_map["access_class"] = "access-class"
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Ipv6, [], name, value)


                class AccessClass(Entity):
                    """
                    
                    
                    .. attribute:: access_class
                    
                    	
                    	**type**\: list of  		 :py:class:`AccessClass_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Ipv6.AccessClass.AccessClass_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.Ipv6.AccessClass, self).__init__()

                        self.yang_name = "access-class"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-class", ("access_class", Native.Line.LineList.Ipv6.AccessClass.AccessClass_))])
                        self._leafs = OrderedDict()

                        self.access_class = YList(self)
                        self._segment_path = lambda: "access-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.Ipv6.AccessClass, [], name, value)


                    class AccessClass_(Entity):
                        """
                        
                        
                        .. attribute:: access_class_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: enumeration_in_out
                        
                        	
                        	**type**\:  :py:class:`EnumerationInOut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Ipv6.AccessClass.AccessClass_.EnumerationInOut>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Line.LineList.Ipv6.AccessClass.AccessClass_, self).__init__()

                            self.yang_name = "access-class"
                            self.yang_parent_name = "access-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['access_class_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_class_name', (YLeaf(YType.str, 'access-class-name'), ['str'])),
                                ('enumeration_in_out', (YLeaf(YType.enumeration, 'enumeration-in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.LineList.Ipv6.AccessClass.AccessClass_.EnumerationInOut')])),
                            ])
                            self.access_class_name = None
                            self.enumeration_in_out = None
                            self._segment_path = lambda: "access-class" + "[access-class-name='" + str(self.access_class_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Line.LineList.Ipv6.AccessClass.AccessClass_, [u'access_class_name', u'enumeration_in_out'], name, value)

                        class EnumerationInOut(Enum):
                            """
                            EnumerationInOut (Enum Class)

                            .. data:: in_ = 0

                            .. data:: out = 1

                            """

                            in_ = Enum.YLeaf(0, "in")

                            out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Modify message logging facilities
                
                .. attribute:: synchronous
                
                	Synchronized message output
                	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Logging.Synchronous>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("synchronous", ("synchronous", Native.Line.LineList.Logging.Synchronous))])
                    self._leafs = OrderedDict()

                    self.synchronous = None
                    self._children_name_map["synchronous"] = "synchronous"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Logging, [], name, value)


                class Synchronous(Entity):
                    """
                    Synchronized message output
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.Logging.Synchronous, self).__init__()

                        self.yang_name = "synchronous"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "synchronous"
                        self._is_frozen = True


            class Login(Entity):
                """
                Enable password checking
                
                .. attribute:: local
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: authentication
                
                	
                	**type**\: str
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Login, self).__init__()

                    self.yang_name = "login"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ('authentication', (YLeaf(YType.str, 'authentication'), ['str'])),
                    ])
                    self.local = None
                    self.authentication = None
                    self._segment_path = lambda: "login"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Login, [u'local', u'authentication'], name, value)


            class MediaType(Entity):
                """
                Console connection media type
                
                .. attribute:: rj45
                
                	Console connection set to RJ45
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.MediaType, self).__init__()

                    self.yang_name = "media-type"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('rj45', (YLeaf(YType.empty, 'rj45'), ['Empty'])),
                    ])
                    self.rj45 = None
                    self._segment_path = lambda: "media-type"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.MediaType, [u'rj45'], name, value)


            class Modem(Entity):
                """
                Configure the Modem Control Lines
                
                .. attribute:: cts_alarm
                
                	Alarm device which only uses CTS for call control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dtr_active
                
                	Leave DTR low unless line has an active incoming connection or EXEC
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dialin
                
                	Configure line for a modern dial\-in modem
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Devices that expect an incoming modem call
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: inout
                
                	Configure line for incoming AND outgoing use of modem
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: printer
                
                	Devices that require DSR/CD active
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: answer_timeout
                
                	Set interval between raising DTR and CTS response
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dtr_delay
                
                	Set interval during which DTR is held low
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Modem, self).__init__()

                    self.yang_name = "modem"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('cts_alarm', (YLeaf(YType.empty, 'CTS-Alarm'), ['Empty'])),
                        ('dtr_active', (YLeaf(YType.empty, 'DTR-active'), ['Empty'])),
                        ('dialin', (YLeaf(YType.empty, 'Dialin'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Host'), ['Empty'])),
                        ('inout', (YLeaf(YType.empty, 'InOut'), ['Empty'])),
                        ('printer', (YLeaf(YType.empty, 'Printer'), ['Empty'])),
                        ('answer_timeout', (YLeaf(YType.empty, 'answer-timeout'), ['Empty'])),
                        ('dtr_delay', (YLeaf(YType.empty, 'dtr-delay'), ['Empty'])),
                    ])
                    self.cts_alarm = None
                    self.dtr_active = None
                    self.dialin = None
                    self.host = None
                    self.inout = None
                    self.printer = None
                    self.answer_timeout = None
                    self.dtr_delay = None
                    self._segment_path = lambda: "modem"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Modem, [u'cts_alarm', u'dtr_active', u'dialin', u'host', u'inout', u'printer', u'answer_timeout', u'dtr_delay'], name, value)


            class Padding(Entity):
                """
                Set padding for a specified output character
                
                .. attribute:: character
                
                	Character to be padded
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..127
                
                		**type**\: str
                
                .. attribute:: null
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Padding, self).__init__()

                    self.yang_name = "padding"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('character', (YLeaf(YType.str, 'character'), ['int','str'])),
                        ('null', (YLeaf(YType.uint8, 'null'), ['int'])),
                    ])
                    self.character = None
                    self.null = None
                    self._segment_path = lambda: "padding"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Padding, [u'character', u'null'], name, value)


            class Parity(Entity):
                """
                Set terminal parity
                
                .. attribute:: even
                
                	Even parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mark
                
                	Mark parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: none
                
                	No parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: odd
                
                	Odd parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: space
                
                	Space parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Parity, self).__init__()

                    self.yang_name = "parity"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('even', (YLeaf(YType.empty, 'even'), ['Empty'])),
                        ('mark', (YLeaf(YType.empty, 'mark'), ['Empty'])),
                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ('odd', (YLeaf(YType.empty, 'odd'), ['Empty'])),
                        ('space', (YLeaf(YType.empty, 'space'), ['Empty'])),
                    ])
                    self.even = None
                    self.mark = None
                    self.none = None
                    self.odd = None
                    self.space = None
                    self._segment_path = lambda: "parity"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Parity, [u'even', u'mark', u'none', u'odd', u'space'], name, value)


            class Password(Entity):
                """
                Set a password
                
                .. attribute:: level
                
                	Set exec level password
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: type
                
                	
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Password.Type>`
                
                .. attribute:: secret
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Password, self).__init__()

                    self.yang_name = "password"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.LineList.Password.Type')])),
                        ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                    ])
                    self.level = None
                    self.type = None
                    self.secret = None
                    self._segment_path = lambda: "password"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Password, [u'level', u'type', u'secret'], name, value)

                class Type(Enum):
                    """
                    Type (Enum Class)

                    .. data:: Y_0 = 0

                    .. data:: Y_7 = 1

                    """

                    Y_0 = Enum.YLeaf(0, "0")

                    Y_7 = Enum.YLeaf(1, "7")



            class Prc(Entity):
                """
                PRC commands
                
                .. attribute:: expose
                
                	Expose PRC data
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hide
                
                	Hide PRC data
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Prc, self).__init__()

                    self.yang_name = "prc"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('expose', (YLeaf(YType.empty, 'expose'), ['Empty'])),
                        ('hide', (YLeaf(YType.empty, 'hide'), ['Empty'])),
                    ])
                    self.expose = None
                    self.hide = None
                    self._segment_path = lambda: "prc"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Prc, [u'expose', u'hide'], name, value)


            class Privilege(Entity):
                """
                Change privilege level for line
                
                .. attribute:: level
                
                	Assign default privilege level for line
                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Privilege.Level>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Privilege, self).__init__()

                    self.yang_name = "privilege"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Line.LineList.Privilege.Level))])
                    self._leafs = OrderedDict()

                    self.level = None
                    self._children_name_map["level"] = "level"
                    self._segment_path = lambda: "privilege"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Privilege, [], name, value)


                class Level(Entity):
                    """
                    Assign default privilege level for line
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..15
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.Privilege.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "privilege"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                        ])
                        self.number = None
                        self._segment_path = lambda: "level"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.Privilege.Level, [u'number'], name, value)


            class SessionTimeout(Entity):
                """
                Set interval for closing connection when there is no input traffic
                
                .. attribute:: session_timeout_value
                
                	
                	**type**\: int
                
                	**range:** 0..35791
                
                .. attribute:: output
                
                	Include output traffic as well as input traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.SessionTimeout, self).__init__()

                    self.yang_name = "session-timeout"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('session_timeout_value', (YLeaf(YType.uint16, 'session-timeout-value'), ['int'])),
                        ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                    ])
                    self.session_timeout_value = None
                    self.output = None
                    self._segment_path = lambda: "session-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.SessionTimeout, [u'session_timeout_value', u'output'], name, value)


            class Timeout(Entity):
                """
                Timeouts for the line
                
                .. attribute:: login
                
                	Timeouts related to the login sequence
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Timeout, self).__init__()

                    self.yang_name = "timeout"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('login', (YLeaf(YType.empty, 'login'), ['Empty'])),
                    ])
                    self.login = None
                    self._segment_path = lambda: "timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Timeout, [u'login'], name, value)


            class Telnet(Entity):
                """
                Telnet protocol\-specific configuration
                
                .. attribute:: transparent
                
                	Send a CR as a CR followed by a NULL instead of a CR followed by a LF
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Telnet, self).__init__()

                    self.yang_name = "telnet"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                    ])
                    self.transparent = None
                    self._segment_path = lambda: "telnet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Telnet, [u'transparent'], name, value)


            class Transport(Entity):
                """
                Define transport protocols for line
                
                .. attribute:: input
                
                	
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Transport.Input>`
                
                .. attribute:: output
                
                	
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Transport.Output>`
                
                .. attribute:: preferred
                
                	Specify the preferred protocol to use
                	**type**\:  :py:class:`Preferred <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Transport.Preferred>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.Transport, self).__init__()

                    self.yang_name = "transport"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Line.LineList.Transport.Input)), ("output", ("output", Native.Line.LineList.Transport.Output)), ("preferred", ("preferred", Native.Line.LineList.Transport.Preferred))])
                    self._leafs = OrderedDict()

                    self.input = Native.Line.LineList.Transport.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Line.LineList.Transport.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"

                    self.preferred = None
                    self._children_name_map["preferred"] = "preferred"
                    self._segment_path = lambda: "transport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.Transport, [], name, value)


                class Input(Entity):
                    """
                    
                    
                    .. attribute:: input
                    
                    	Define which protocols to use when connecting to the terminal server
                    	**type**\: list of   :py:class:`Input_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Transport.Input.Input_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.Transport.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeafList(YType.enumeration, 'input'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.LineList.Transport.Input.Input_')])),
                        ])
                        self.input = []
                        self._segment_path = lambda: "input"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.Transport.Input, [u'input'], name, value)

                    class Input_(Enum):
                        """
                        Input\_ (Enum Class)

                        Define which protocols to use when connecting to the terminal server

                        .. data:: acercon = 0

                        .. data:: all = 1

                        .. data:: lapb_ta = 2

                        .. data:: lat = 3

                        .. data:: mop = 4

                        .. data:: nasi = 5

                        .. data:: none = 6

                        .. data:: pad = 7

                        .. data:: rlogin = 8

                        .. data:: ssh = 9

                        .. data:: telnet = 10

                        .. data:: udptn = 11

                        .. data:: v120 = 12

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        all = Enum.YLeaf(1, "all")

                        lapb_ta = Enum.YLeaf(2, "lapb-ta")

                        lat = Enum.YLeaf(3, "lat")

                        mop = Enum.YLeaf(4, "mop")

                        nasi = Enum.YLeaf(5, "nasi")

                        none = Enum.YLeaf(6, "none")

                        pad = Enum.YLeaf(7, "pad")

                        rlogin = Enum.YLeaf(8, "rlogin")

                        ssh = Enum.YLeaf(9, "ssh")

                        telnet = Enum.YLeaf(10, "telnet")

                        udptn = Enum.YLeaf(11, "udptn")

                        v120 = Enum.YLeaf(12, "v120")



                class Output(Entity):
                    """
                    
                    
                    .. attribute:: output
                    
                    	Define which protocols to use for outgoing connections
                    	**type**\: list of   :py:class:`Output_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Transport.Output.Output_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.Transport.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('output', (YLeafList(YType.enumeration, 'output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.LineList.Transport.Output.Output_')])),
                        ])
                        self.output = []
                        self._segment_path = lambda: "output"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.Transport.Output, [u'output'], name, value)

                    class Output_(Enum):
                        """
                        Output\_ (Enum Class)

                        Define which protocols to use for outgoing connections

                        .. data:: acercon = 0

                        .. data:: all = 1

                        .. data:: lapb_ta = 2

                        .. data:: lat = 3

                        .. data:: mop = 4

                        .. data:: nasi = 5

                        .. data:: none = 6

                        .. data:: pad = 7

                        .. data:: rlogin = 8

                        .. data:: ssh = 9

                        .. data:: telnet = 10

                        .. data:: udptn = 11

                        .. data:: v120 = 12

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        all = Enum.YLeaf(1, "all")

                        lapb_ta = Enum.YLeaf(2, "lapb-ta")

                        lat = Enum.YLeaf(3, "lat")

                        mop = Enum.YLeaf(4, "mop")

                        nasi = Enum.YLeaf(5, "nasi")

                        none = Enum.YLeaf(6, "none")

                        pad = Enum.YLeaf(7, "pad")

                        rlogin = Enum.YLeaf(8, "rlogin")

                        ssh = Enum.YLeaf(9, "ssh")

                        telnet = Enum.YLeaf(10, "telnet")

                        udptn = Enum.YLeaf(11, "udptn")

                        v120 = Enum.YLeaf(12, "v120")



                class Preferred(Entity):
                    """
                    Specify the preferred protocol to use
                    
                    .. attribute:: protocol
                    
                    	
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.LineList.Transport.Preferred.Protocol>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.LineList.Transport.Preferred, self).__init__()

                        self.yang_name = "preferred"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.LineList.Transport.Preferred.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "preferred"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.LineList.Transport.Preferred, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        .. data:: acercon = 0

                        .. data:: lat = 1

                        .. data:: mop = 2

                        .. data:: nasi = 3

                        .. data:: none = 4

                        .. data:: pad = 5

                        .. data:: rlogin = 6

                        .. data:: ssh = 7

                        .. data:: telnet = 8

                        .. data:: udptn = 9

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        lat = Enum.YLeaf(1, "lat")

                        mop = Enum.YLeaf(2, "mop")

                        nasi = Enum.YLeaf(3, "nasi")

                        none = Enum.YLeaf(4, "none")

                        pad = Enum.YLeaf(5, "pad")

                        rlogin = Enum.YLeaf(6, "rlogin")

                        ssh = Enum.YLeaf(7, "ssh")

                        telnet = Enum.YLeaf(8, "telnet")

                        udptn = Enum.YLeaf(9, "udptn")



            class UsbInactivityTimeout(Entity):
                """
                Inactivity timeout for USB media type
                
                .. attribute:: switch
                
                	Switch Number
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.LineList.UsbInactivityTimeout, self).__init__()

                    self.yang_name = "usb-inactivity-timeout"
                    self.yang_parent_name = "line-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switch', (YLeaf(YType.empty, 'switch'), ['Empty'])),
                    ])
                    self.switch = None
                    self._segment_path = lambda: "usb-inactivity-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.LineList.UsbInactivityTimeout, [u'switch'], name, value)


        class Aux(Entity):
            """
            Auxiliary line
            
            .. attribute:: first  (key)
            
            	
            	**type**\:  :py:class:`First <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.First>`
            
            .. attribute:: authorization
            
            	Authorization parameters
            	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Authorization>`
            
            .. attribute:: access_class
            
            	Filter connections based on an IP access list
            	**type**\:  :py:class:`AccessClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.AccessClass>`
            
            .. attribute:: no_activation_character
            
            	
            	**type**\: bool
            
            .. attribute:: activation_character
            
            	Define the activation character
            	**type**\: union of the below types:
            
            		**type**\: str
            
            		**type**\: int
            
            			**range:** 0..127
            
            .. attribute:: autocommand
            
            	Automatically execute an EXEC command
            	**type**\:  :py:class:`Autocommand <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Autocommand>`
            
            .. attribute:: autocommand_options
            
            	Autocommand options
            	**type**\:  :py:class:`AutocommandOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.AutocommandOptions>`
            
            	**presence node**\: True
            
            .. attribute:: data_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: databits
            
            	Set number of data bits per character
            	**type**\:  :py:class:`Databits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Databits>`
            
            .. attribute:: domain_lookup
            
            	Enable domain lookups in show commands
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: editing
            
            	Enable command line editing
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: escape_character
            
            	Change the current line's escape character
            	**type**\:  :py:class:`EscapeCharacter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.EscapeCharacter>`
            
            .. attribute:: no_exec
            
            	
            	**type**\:  :py:class:`NoExec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.NoExec>`
            
            .. attribute:: exec_
            
            	
            	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Exec>`
            
            .. attribute:: exec_banner
            
            	Enable the display of the EXEC banner
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: exec_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: exec_timeout
            
            	Set the EXEC timeout
            	**type**\:  :py:class:`ExecTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.ExecTimeout>`
            
            .. attribute:: flowcontrol
            
            	Set the flow control
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Flowcontrol>`
            
            .. attribute:: full_help
            
            	Provide help to unprivileged user
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: history
            
            	Enable and control the command history function
            	**type**\:  :py:class:`History <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.History>`
            
            	**presence node**\: True
            
            .. attribute:: international
            
            	Enable international 8\-bit character support
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ip
            
            	IP options
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Ip>`
            
            .. attribute:: ipv6
            
            	
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Ipv6>`
            
            .. attribute:: length
            
            	Set number of lines on a screen
            	**type**\: int
            
            	**range:** 0..512
            
            .. attribute:: line
            
            	
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: location
            
            	One text line describing the terminal's location
            	**type**\: str
            
            .. attribute:: logging
            
            	Modify message logging facilities
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Logging>`
            
            .. attribute:: login
            
            	Enable password checking
            	**type**\:  :py:class:`Login <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Login>`
            
            	**presence node**\: True
            
            .. attribute:: media_type
            
            	Console connection media type
            	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.MediaType>`
            
            .. attribute:: modem
            
            	Configure the Modem Control Lines
            	**type**\:  :py:class:`Modem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Modem>`
            
            .. attribute:: monitor
            
            	Copy debug output to the current terminal line
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: motd_banner
            
            	Enable the display of the MOTD banner
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: notify
            
            	Inform users of output from concurrent sessions
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: padding
            
            	Set padding for a specified output character
            	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Padding>`
            
            .. attribute:: parity
            
            	Set terminal parity
            	**type**\:  :py:class:`Parity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Parity>`
            
            .. attribute:: password
            
            	Set a password
            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Password>`
            
            .. attribute:: prc
            
            	PRC commands
            	**type**\:  :py:class:`Prc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Prc>`
            
            .. attribute:: privilege
            
            	Change privilege level for line
            	**type**\:  :py:class:`Privilege <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Privilege>`
            
            .. attribute:: rotary
            
            	Rotary group to add line to
            	**type**\: int
            
            	**range:** 1..99
            
            .. attribute:: rxspeed
            
            	Receive speed
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_limit
            
            	Set maximum number of sessions
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_timeout
            
            	Set interval for closing connection when there is no input traffic
            	**type**\:  :py:class:`SessionTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.SessionTimeout>`
            
            .. attribute:: special_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: speed
            
            	Transmit and receive speeds
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: start_character
            
            	Define the start character
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..255
            
            		**type**\: str
            
            .. attribute:: stop_character
            
            	Define the stop character
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..255
            
            		**type**\: str
            
            .. attribute:: stopbits
            
            	Set async line stop bits
            	**type**\:  :py:class:`Stopbits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Stopbits>`
            
            .. attribute:: terminal_type
            
            	Terminal type
            	**type**\: str
            
            .. attribute:: timeout
            
            	Timeouts for the line
            	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Timeout>`
            
            .. attribute:: telnet
            
            	Telnet protocol\-specific configuration
            	**type**\:  :py:class:`Telnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Telnet>`
            
            .. attribute:: transport
            
            	Define transport protocols for line
            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Transport>`
            
            .. attribute:: txspeed
            
            	Transmit speed
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: usb_inactivity_timeout
            
            	Inactivity timeout for USB media type
            	**type**\:  :py:class:`UsbInactivityTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.UsbInactivityTimeout>`
            
            .. attribute:: width
            
            	Number of characters on a screen line
            	**type**\: int
            
            	**range:** 0..512
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Line.Aux, self).__init__()

                self.yang_name = "aux"
                self.yang_parent_name = "line"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['first']
                self._child_classes = OrderedDict([("authorization", ("authorization", Native.Line.Aux.Authorization)), ("access-class", ("access_class", Native.Line.Aux.AccessClass)), ("autocommand", ("autocommand", Native.Line.Aux.Autocommand)), ("autocommand-options", ("autocommand_options", Native.Line.Aux.AutocommandOptions)), ("databits", ("databits", Native.Line.Aux.Databits)), ("escape-character", ("escape_character", Native.Line.Aux.EscapeCharacter)), ("no-exec", ("no_exec", Native.Line.Aux.NoExec)), ("exec", ("exec_", Native.Line.Aux.Exec)), ("exec-timeout", ("exec_timeout", Native.Line.Aux.ExecTimeout)), ("flowcontrol", ("flowcontrol", Native.Line.Aux.Flowcontrol)), ("history", ("history", Native.Line.Aux.History)), ("ip", ("ip", Native.Line.Aux.Ip)), ("ipv6", ("ipv6", Native.Line.Aux.Ipv6)), ("logging", ("logging", Native.Line.Aux.Logging)), ("login", ("login", Native.Line.Aux.Login)), ("media-type", ("media_type", Native.Line.Aux.MediaType)), ("modem", ("modem", Native.Line.Aux.Modem)), ("padding", ("padding", Native.Line.Aux.Padding)), ("parity", ("parity", Native.Line.Aux.Parity)), ("password", ("password", Native.Line.Aux.Password)), ("prc", ("prc", Native.Line.Aux.Prc)), ("privilege", ("privilege", Native.Line.Aux.Privilege)), ("session-timeout", ("session_timeout", Native.Line.Aux.SessionTimeout)), ("timeout", ("timeout", Native.Line.Aux.Timeout)), ("telnet", ("telnet", Native.Line.Aux.Telnet)), ("transport", ("transport", Native.Line.Aux.Transport)), ("usb-inactivity-timeout", ("usb_inactivity_timeout", Native.Line.Aux.UsbInactivityTimeout))])
                self._leafs = OrderedDict([
                    ('first', (YLeaf(YType.enumeration, 'first'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Aux.First')])),
                    ('no_activation_character', (YLeaf(YType.boolean, 'no-activation-character'), ['bool'])),
                    ('activation_character', (YLeaf(YType.str, 'activation-character'), ['str','int'])),
                    ('data_character_bits', (YLeaf(YType.uint8, 'data-character-bits'), ['int'])),
                    ('domain_lookup', (YLeaf(YType.empty, 'domain-lookup'), ['Empty'])),
                    ('editing', (YLeaf(YType.empty, 'editing'), ['Empty'])),
                    ('exec_banner', (YLeaf(YType.empty, 'exec-banner'), ['Empty'])),
                    ('exec_character_bits', (YLeaf(YType.uint8, 'exec-character-bits'), ['int'])),
                    ('full_help', (YLeaf(YType.empty, 'full-help'), ['Empty'])),
                    ('international', (YLeaf(YType.empty, 'international'), ['Empty'])),
                    ('length', (YLeaf(YType.uint16, 'length'), ['int'])),
                    ('line', (YLeaf(YType.uint8, 'line'), ['int'])),
                    ('location', (YLeaf(YType.str, 'location'), ['str'])),
                    ('monitor', (YLeaf(YType.empty, 'monitor'), ['Empty'])),
                    ('motd_banner', (YLeaf(YType.empty, 'motd-banner'), ['Empty'])),
                    ('notify', (YLeaf(YType.empty, 'notify'), ['Empty'])),
                    ('rotary', (YLeaf(YType.uint8, 'rotary'), ['int'])),
                    ('rxspeed', (YLeaf(YType.uint32, 'rxspeed'), ['int'])),
                    ('session_limit', (YLeaf(YType.uint32, 'session-limit'), ['int'])),
                    ('special_character_bits', (YLeaf(YType.uint8, 'special-character-bits'), ['int'])),
                    ('speed', (YLeaf(YType.uint32, 'speed'), ['int'])),
                    ('start_character', (YLeaf(YType.str, 'start-character'), ['int','str'])),
                    ('stop_character', (YLeaf(YType.str, 'stop-character'), ['int','str'])),
                    ('stopbits', (YLeaf(YType.enumeration, 'stopbits'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Aux.Stopbits')])),
                    ('terminal_type', (YLeaf(YType.str, 'terminal-type'), ['str'])),
                    ('txspeed', (YLeaf(YType.uint32, 'txspeed'), ['int'])),
                    ('width', (YLeaf(YType.uint16, 'width'), ['int'])),
                ])
                self.first = None
                self.no_activation_character = None
                self.activation_character = None
                self.data_character_bits = None
                self.domain_lookup = None
                self.editing = None
                self.exec_banner = None
                self.exec_character_bits = None
                self.full_help = None
                self.international = None
                self.length = None
                self.line = None
                self.location = None
                self.monitor = None
                self.motd_banner = None
                self.notify = None
                self.rotary = None
                self.rxspeed = None
                self.session_limit = None
                self.special_character_bits = None
                self.speed = None
                self.start_character = None
                self.stop_character = None
                self.stopbits = None
                self.terminal_type = None
                self.txspeed = None
                self.width = None

                self.authorization = Native.Line.Aux.Authorization()
                self.authorization.parent = self
                self._children_name_map["authorization"] = "authorization"

                self.access_class = Native.Line.Aux.AccessClass()
                self.access_class.parent = self
                self._children_name_map["access_class"] = "access-class"

                self.autocommand = Native.Line.Aux.Autocommand()
                self.autocommand.parent = self
                self._children_name_map["autocommand"] = "autocommand"

                self.autocommand_options = None
                self._children_name_map["autocommand_options"] = "autocommand-options"

                self.databits = Native.Line.Aux.Databits()
                self.databits.parent = self
                self._children_name_map["databits"] = "databits"

                self.escape_character = Native.Line.Aux.EscapeCharacter()
                self.escape_character.parent = self
                self._children_name_map["escape_character"] = "escape-character"

                self.no_exec = Native.Line.Aux.NoExec()
                self.no_exec.parent = self
                self._children_name_map["no_exec"] = "no-exec"

                self.exec_ = Native.Line.Aux.Exec()
                self.exec_.parent = self
                self._children_name_map["exec_"] = "exec"

                self.exec_timeout = Native.Line.Aux.ExecTimeout()
                self.exec_timeout.parent = self
                self._children_name_map["exec_timeout"] = "exec-timeout"

                self.flowcontrol = Native.Line.Aux.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.history = None
                self._children_name_map["history"] = "history"

                self.ip = Native.Line.Aux.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Line.Aux.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Line.Aux.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.login = None
                self._children_name_map["login"] = "login"

                self.media_type = Native.Line.Aux.MediaType()
                self.media_type.parent = self
                self._children_name_map["media_type"] = "media-type"

                self.modem = Native.Line.Aux.Modem()
                self.modem.parent = self
                self._children_name_map["modem"] = "modem"

                self.padding = Native.Line.Aux.Padding()
                self.padding.parent = self
                self._children_name_map["padding"] = "padding"

                self.parity = Native.Line.Aux.Parity()
                self.parity.parent = self
                self._children_name_map["parity"] = "parity"

                self.password = Native.Line.Aux.Password()
                self.password.parent = self
                self._children_name_map["password"] = "password"

                self.prc = Native.Line.Aux.Prc()
                self.prc.parent = self
                self._children_name_map["prc"] = "prc"

                self.privilege = Native.Line.Aux.Privilege()
                self.privilege.parent = self
                self._children_name_map["privilege"] = "privilege"

                self.session_timeout = Native.Line.Aux.SessionTimeout()
                self.session_timeout.parent = self
                self._children_name_map["session_timeout"] = "session-timeout"

                self.timeout = Native.Line.Aux.Timeout()
                self.timeout.parent = self
                self._children_name_map["timeout"] = "timeout"

                self.telnet = Native.Line.Aux.Telnet()
                self.telnet.parent = self
                self._children_name_map["telnet"] = "telnet"

                self.transport = Native.Line.Aux.Transport()
                self.transport.parent = self
                self._children_name_map["transport"] = "transport"

                self.usb_inactivity_timeout = Native.Line.Aux.UsbInactivityTimeout()
                self.usb_inactivity_timeout.parent = self
                self._children_name_map["usb_inactivity_timeout"] = "usb-inactivity-timeout"
                self._segment_path = lambda: "aux" + "[first='" + str(self.first) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/line/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Line.Aux, [u'first', u'no_activation_character', u'activation_character', u'data_character_bits', u'domain_lookup', u'editing', u'exec_banner', u'exec_character_bits', u'full_help', u'international', u'length', u'line', u'location', u'monitor', u'motd_banner', u'notify', u'rotary', u'rxspeed', u'session_limit', u'special_character_bits', u'speed', u'start_character', u'stop_character', u'stopbits', u'terminal_type', u'txspeed', u'width'], name, value)

            class First(Enum):
                """
                First (Enum Class)

                .. data:: Y_0 = 0

                """

                Y_0 = Enum.YLeaf(0, "0")


            class Stopbits(Enum):
                """
                Stopbits (Enum Class)

                Set async line stop bits

                .. data:: Y_1 = 0

                .. data:: Y_1__DOT__5 = 1

                .. data:: Y_2 = 2

                """

                Y_1 = Enum.YLeaf(0, "1")

                Y_1__DOT__5 = Enum.YLeaf(1, "1.5")

                Y_2 = Enum.YLeaf(2, "2")



            class Authorization(Entity):
                """
                Authorization parameters
                
                .. attribute:: command
                
                	For exec (shell) commands
                	**type**\:  :py:class:`Command <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Authorization.Command>`
                
                .. attribute:: exec_
                
                	For starting an exec (shell)
                	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Authorization.Exec>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Authorization, self).__init__()

                    self.yang_name = "authorization"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("command", ("command", Native.Line.Aux.Authorization.Command)), ("exec", ("exec_", Native.Line.Aux.Authorization.Exec))])
                    self._leafs = OrderedDict()

                    self.command = Native.Line.Aux.Authorization.Command()
                    self.command.parent = self
                    self._children_name_map["command"] = "command"

                    self.exec_ = Native.Line.Aux.Authorization.Exec()
                    self.exec_.parent = self
                    self._children_name_map["exec_"] = "exec"
                    self._segment_path = lambda: "authorization"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Authorization, [], name, value)


                class Command(Entity):
                    """
                    For exec (shell) commands
                    
                    .. attribute:: enable_level
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..15
                    
                    .. attribute:: auth_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.Authorization.Command, self).__init__()

                        self.yang_name = "command"
                        self.yang_parent_name = "authorization"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable_level', (YLeaf(YType.uint8, 'enable-level'), ['int'])),
                            ('auth_name', (YLeaf(YType.str, 'auth-name'), ['str'])),
                        ])
                        self.enable_level = None
                        self.auth_name = None
                        self._segment_path = lambda: "command"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.Authorization.Command, [u'enable_level', u'auth_name'], name, value)


                class Exec(Entity):
                    """
                    For starting an exec (shell)
                    
                    .. attribute:: authorization_name
                    
                    	Use an authorization list with this name
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	Use the default authorization list
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.Authorization.Exec, self).__init__()

                        self.yang_name = "exec"
                        self.yang_parent_name = "authorization"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('authorization_name', (YLeaf(YType.str, 'authorization-name'), ['str'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.authorization_name = None
                        self.default = None
                        self._segment_path = lambda: "exec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.Authorization.Exec, [u'authorization_name', u'default'], name, value)


            class AccessClass(Entity):
                """
                Filter connections based on an IP access list
                
                .. attribute:: acccess_list
                
                	
                	**type**\: list of  		 :py:class:`AcccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.AccessClass.AcccessList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.AccessClass, self).__init__()

                    self.yang_name = "access-class"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("acccess-list", ("acccess_list", Native.Line.Aux.AccessClass.AcccessList))])
                    self._leafs = OrderedDict()

                    self.acccess_list = YList(self)
                    self._segment_path = lambda: "access-class"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.AccessClass, [], name, value)


                class AcccessList(Entity):
                    """
                    
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.AccessClass.AcccessList.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    	**mandatory**\: True
                    
                    .. attribute:: vrf_also
                    
                    	Same access list is applied for all VRFs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.AccessClass.AcccessList, self).__init__()

                        self.yang_name = "acccess-list"
                        self.yang_parent_name = "access-class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Aux.AccessClass.AcccessList.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['int','str'])),
                            ('vrf_also', (YLeaf(YType.empty, 'vrf-also'), ['Empty'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self.vrf_also = None
                        self._segment_path = lambda: "acccess-list" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.AccessClass.AcccessList, [u'direction', u'access_list', u'vrf_also'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Autocommand(Entity):
                """
                Automatically execute an EXEC command
                
                .. attribute:: line
                
                	Appropriate EXEC command
                	**type**\: str
                
                .. attribute:: no_suppress_linenumber
                
                	Display service linenumber message
                	**type**\:  :py:class:`NoSuppressLinenumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Autocommand.NoSuppressLinenumber>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Autocommand, self).__init__()

                    self.yang_name = "autocommand"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("no-suppress-linenumber", ("no_suppress_linenumber", Native.Line.Aux.Autocommand.NoSuppressLinenumber))])
                    self._leafs = OrderedDict([
                        ('line', (YLeaf(YType.str, 'line'), ['str'])),
                    ])
                    self.line = None

                    self.no_suppress_linenumber = None
                    self._children_name_map["no_suppress_linenumber"] = "no-suppress-linenumber"
                    self._segment_path = lambda: "autocommand"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Autocommand, [u'line'], name, value)


                class NoSuppressLinenumber(Entity):
                    """
                    Display service linenumber message
                    
                    .. attribute:: line
                    
                    	Appropriate EXEC command
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.Autocommand.NoSuppressLinenumber, self).__init__()

                        self.yang_name = "no-suppress-linenumber"
                        self.yang_parent_name = "autocommand"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('line', (YLeaf(YType.str, 'line'), ['str'])),
                        ])
                        self.line = None
                        self._segment_path = lambda: "no-suppress-linenumber"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.Autocommand.NoSuppressLinenumber, [u'line'], name, value)


            class AutocommandOptions(Entity):
                """
                Autocommand options
                
                .. attribute:: abort_character
                
                	Autocommand abort character
                	**type**\:  :py:class:`AbortCharacter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.AutocommandOptions.AbortCharacter>`
                
                	**presence node**\: True
                
                .. attribute:: delay
                
                	Delay autocommand execution
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.AutocommandOptions.Delay>`
                
                	**presence node**\: True
                
                .. attribute:: nohangup
                
                	No hangup after autocommand completion
                	**type**\:  :py:class:`Nohangup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.AutocommandOptions.Nohangup>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.AutocommandOptions, self).__init__()

                    self.yang_name = "autocommand-options"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("abort-character", ("abort_character", Native.Line.Aux.AutocommandOptions.AbortCharacter)), ("delay", ("delay", Native.Line.Aux.AutocommandOptions.Delay)), ("nohangup", ("nohangup", Native.Line.Aux.AutocommandOptions.Nohangup))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.abort_character = None
                    self._children_name_map["abort_character"] = "abort-character"

                    self.delay = None
                    self._children_name_map["delay"] = "delay"

                    self.nohangup = None
                    self._children_name_map["nohangup"] = "nohangup"
                    self._segment_path = lambda: "autocommand-options"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.AutocommandOptions, [], name, value)


                class AbortCharacter(Entity):
                    """
                    Autocommand abort character
                    
                    .. attribute:: character
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..255
                    
                    		**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.AutocommandOptions.AbortCharacter, self).__init__()

                        self.yang_name = "abort-character"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('character', (YLeaf(YType.str, 'character'), ['int','str'])),
                        ])
                        self.character = None
                        self._segment_path = lambda: "abort-character"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.AutocommandOptions.AbortCharacter, [u'character'], name, value)


                class Delay(Entity):
                    """
                    Delay autocommand execution
                    
                    .. attribute:: time
                    
                    	Time in seconds
                    	**type**\: int
                    
                    	**range:** 0..120
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.AutocommandOptions.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('time', (YLeaf(YType.uint8, 'time'), ['int'])),
                        ])
                        self.time = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.AutocommandOptions.Delay, [u'time'], name, value)


                class Nohangup(Entity):
                    """
                    No hangup after autocommand completion
                    
                    .. attribute:: abort_character
                    
                    	Autocommand abort character
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: delay
                    
                    	Delay autocommand execution
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.AutocommandOptions.Nohangup, self).__init__()

                        self.yang_name = "nohangup"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('abort_character', (YLeaf(YType.empty, 'abort-character'), ['Empty'])),
                            ('delay', (YLeaf(YType.empty, 'delay'), ['Empty'])),
                        ])
                        self.abort_character = None
                        self.delay = None
                        self._segment_path = lambda: "nohangup"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.AutocommandOptions.Nohangup, [u'abort_character', u'delay'], name, value)


            class Databits(Entity):
                """
                Set number of data bits per character
                
                .. attribute:: set_to_5
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_6
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_7
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_8
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Databits, self).__init__()

                    self.yang_name = "databits"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('set_to_5', (YLeaf(YType.empty, 'set-to-5'), ['Empty'])),
                        ('set_to_6', (YLeaf(YType.empty, 'set-to-6'), ['Empty'])),
                        ('set_to_7', (YLeaf(YType.empty, 'set-to-7'), ['Empty'])),
                        ('set_to_8', (YLeaf(YType.empty, 'set-to-8'), ['Empty'])),
                    ])
                    self.set_to_5 = None
                    self.set_to_6 = None
                    self.set_to_7 = None
                    self.set_to_8 = None
                    self._segment_path = lambda: "databits"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Databits, [u'set_to_5', u'set_to_6', u'set_to_7', u'set_to_8'], name, value)


            class EscapeCharacter(Entity):
                """
                Change the current line's escape character
                
                .. attribute:: char
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..255
                
                		**type**\:  :py:class:`Char <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.EscapeCharacter.Char>`
                
                		**type**\: str
                
                .. attribute:: soft
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.EscapeCharacter, self).__init__()

                    self.yang_name = "escape-character"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('char', (YLeaf(YType.str, 'char'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.EscapeCharacter.Char'),'str'])),
                        ('soft', (YLeaf(YType.empty, 'soft'), ['Empty'])),
                    ])
                    self.char = None
                    self.soft = None
                    self._segment_path = lambda: "escape-character"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.EscapeCharacter, [u'char', u'soft'], name, value)

                class Char(Enum):
                    """
                    Char (Enum Class)

                    .. data:: BREAK = 0

                    .. data:: DEFAULT = 1

                    .. data:: NONE = 2

                    """

                    BREAK = Enum.YLeaf(0, "BREAK")

                    DEFAULT = Enum.YLeaf(1, "DEFAULT")

                    NONE = Enum.YLeaf(2, "NONE")



            class NoExec(Entity):
                """
                
                
                .. attribute:: exec_
                
                	Configure EXEC
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.NoExec, self).__init__()

                    self.yang_name = "no-exec"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('exec_', (YLeaf(YType.boolean, 'exec'), ['bool'])),
                    ])
                    self.exec_ = None
                    self._segment_path = lambda: "no-exec"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.NoExec, [u'exec_'], name, value)


            class Exec(Entity):
                """
                
                
                .. attribute:: prompt
                
                	
                	**type**\:  :py:class:`Prompt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Exec.Prompt>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Exec, self).__init__()

                    self.yang_name = "exec"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("prompt", ("prompt", Native.Line.Aux.Exec.Prompt))])
                    self._leafs = OrderedDict()

                    self.prompt = Native.Line.Aux.Exec.Prompt()
                    self.prompt.parent = self
                    self._children_name_map["prompt"] = "prompt"
                    self._segment_path = lambda: "exec"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Exec, [], name, value)


                class Prompt(Entity):
                    """
                    
                    
                    .. attribute:: timestamp
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.Exec.Prompt, self).__init__()

                        self.yang_name = "prompt"
                        self.yang_parent_name = "exec"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('timestamp', (YLeaf(YType.empty, 'timestamp'), ['Empty'])),
                        ])
                        self.timestamp = None
                        self._segment_path = lambda: "prompt"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.Exec.Prompt, [u'timestamp'], name, value)


            class ExecTimeout(Entity):
                """
                Set the EXEC timeout
                
                .. attribute:: minutes
                
                	<0\-35791>;;Timeout in minutes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: seconds
                
                	<0\-2147483>;;Timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.ExecTimeout, self).__init__()

                    self.yang_name = "exec-timeout"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('minutes', (YLeaf(YType.uint32, 'minutes'), ['int'])),
                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                    ])
                    self.minutes = None
                    self.seconds = None
                    self._segment_path = lambda: "exec-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.ExecTimeout, [u'minutes', u'seconds'], name, value)


            class Flowcontrol(Entity):
                """
                Set the flow control
                
                .. attribute:: none
                
                	Set no flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hardware
                
                	Set hardware flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: software
                
                	Set software flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('none', (YLeaf(YType.empty, 'NONE'), ['Empty'])),
                        ('hardware', (YLeaf(YType.empty, 'hardware'), ['Empty'])),
                        ('software', (YLeaf(YType.empty, 'software'), ['Empty'])),
                    ])
                    self.none = None
                    self.hardware = None
                    self.software = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Flowcontrol, [u'none', u'hardware', u'software'], name, value)


            class History(Entity):
                """
                Enable and control the command history function
                
                .. attribute:: size
                
                	Set history buffer size
                	**type**\: int
                
                	**range:** 0..256
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.History, self).__init__()

                    self.yang_name = "history"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                    ])
                    self.size = None
                    self._segment_path = lambda: "history"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.History, [u'size'], name, value)


            class Ip(Entity):
                """
                IP options
                
                .. attribute:: netmask_format
                
                	Change display of netmasks
                	**type**\:  :py:class:`NetmaskFormat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Ip.NetmaskFormat>`
                
                	**presence node**\: True
                
                .. attribute:: tcp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("netmask-format", ("netmask_format", Native.Line.Aux.Ip.NetmaskFormat))])
                    self._leafs = OrderedDict([
                        ('tcp', (YLeaf(YType.empty, 'tcp'), ['Empty'])),
                    ])
                    self.tcp = None

                    self.netmask_format = None
                    self._children_name_map["netmask_format"] = "netmask-format"
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Ip, [u'tcp'], name, value)


                class NetmaskFormat(Entity):
                    """
                    Change display of netmasks
                    
                    .. attribute:: format
                    
                    	
                    	**type**\:  :py:class:`Format <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Ip.NetmaskFormat.Format>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.Ip.NetmaskFormat, self).__init__()

                        self.yang_name = "netmask-format"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('format', (YLeaf(YType.enumeration, 'format'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Aux.Ip.NetmaskFormat.Format')])),
                        ])
                        self.format = None
                        self._segment_path = lambda: "netmask-format"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.Ip.NetmaskFormat, [u'format'], name, value)

                    class Format(Enum):
                        """
                        Format (Enum Class)

                        .. data:: bit_count = 0

                        .. data:: decimal = 1

                        .. data:: hexadecimal = 2

                        """

                        bit_count = Enum.YLeaf(0, "bit-count")

                        decimal = Enum.YLeaf(1, "decimal")

                        hexadecimal = Enum.YLeaf(2, "hexadecimal")



            class Ipv6(Entity):
                """
                
                
                .. attribute:: access_class
                
                	
                	**type**\:  :py:class:`AccessClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Ipv6.AccessClass>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-class", ("access_class", Native.Line.Aux.Ipv6.AccessClass))])
                    self._leafs = OrderedDict()

                    self.access_class = Native.Line.Aux.Ipv6.AccessClass()
                    self.access_class.parent = self
                    self._children_name_map["access_class"] = "access-class"
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Ipv6, [], name, value)


                class AccessClass(Entity):
                    """
                    
                    
                    .. attribute:: access_class
                    
                    	
                    	**type**\: list of  		 :py:class:`AccessClass_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Ipv6.AccessClass.AccessClass_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.Ipv6.AccessClass, self).__init__()

                        self.yang_name = "access-class"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-class", ("access_class", Native.Line.Aux.Ipv6.AccessClass.AccessClass_))])
                        self._leafs = OrderedDict()

                        self.access_class = YList(self)
                        self._segment_path = lambda: "access-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.Ipv6.AccessClass, [], name, value)


                    class AccessClass_(Entity):
                        """
                        
                        
                        .. attribute:: access_class_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: enumeration_in_out
                        
                        	
                        	**type**\:  :py:class:`EnumerationInOut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Ipv6.AccessClass.AccessClass_.EnumerationInOut>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Line.Aux.Ipv6.AccessClass.AccessClass_, self).__init__()

                            self.yang_name = "access-class"
                            self.yang_parent_name = "access-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['access_class_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_class_name', (YLeaf(YType.str, 'access-class-name'), ['str'])),
                                ('enumeration_in_out', (YLeaf(YType.enumeration, 'enumeration-in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Aux.Ipv6.AccessClass.AccessClass_.EnumerationInOut')])),
                            ])
                            self.access_class_name = None
                            self.enumeration_in_out = None
                            self._segment_path = lambda: "access-class" + "[access-class-name='" + str(self.access_class_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Line.Aux.Ipv6.AccessClass.AccessClass_, [u'access_class_name', u'enumeration_in_out'], name, value)

                        class EnumerationInOut(Enum):
                            """
                            EnumerationInOut (Enum Class)

                            .. data:: in_ = 0

                            .. data:: out = 1

                            """

                            in_ = Enum.YLeaf(0, "in")

                            out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Modify message logging facilities
                
                .. attribute:: synchronous
                
                	Synchronized message output
                	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Logging.Synchronous>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("synchronous", ("synchronous", Native.Line.Aux.Logging.Synchronous))])
                    self._leafs = OrderedDict()

                    self.synchronous = None
                    self._children_name_map["synchronous"] = "synchronous"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Logging, [], name, value)


                class Synchronous(Entity):
                    """
                    Synchronized message output
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.Logging.Synchronous, self).__init__()

                        self.yang_name = "synchronous"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "synchronous"
                        self._is_frozen = True


            class Login(Entity):
                """
                Enable password checking
                
                .. attribute:: local
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: authentication
                
                	
                	**type**\: str
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Login, self).__init__()

                    self.yang_name = "login"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ('authentication', (YLeaf(YType.str, 'authentication'), ['str'])),
                    ])
                    self.local = None
                    self.authentication = None
                    self._segment_path = lambda: "login"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Login, [u'local', u'authentication'], name, value)


            class MediaType(Entity):
                """
                Console connection media type
                
                .. attribute:: rj45
                
                	Console connection set to RJ45
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.MediaType, self).__init__()

                    self.yang_name = "media-type"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('rj45', (YLeaf(YType.empty, 'rj45'), ['Empty'])),
                    ])
                    self.rj45 = None
                    self._segment_path = lambda: "media-type"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.MediaType, [u'rj45'], name, value)


            class Modem(Entity):
                """
                Configure the Modem Control Lines
                
                .. attribute:: cts_alarm
                
                	Alarm device which only uses CTS for call control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dtr_active
                
                	Leave DTR low unless line has an active incoming connection or EXEC
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dialin
                
                	Configure line for a modern dial\-in modem
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Devices that expect an incoming modem call
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: inout
                
                	Configure line for incoming AND outgoing use of modem
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: printer
                
                	Devices that require DSR/CD active
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: answer_timeout
                
                	Set interval between raising DTR and CTS response
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dtr_delay
                
                	Set interval during which DTR is held low
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Modem, self).__init__()

                    self.yang_name = "modem"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('cts_alarm', (YLeaf(YType.empty, 'CTS-Alarm'), ['Empty'])),
                        ('dtr_active', (YLeaf(YType.empty, 'DTR-active'), ['Empty'])),
                        ('dialin', (YLeaf(YType.empty, 'Dialin'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Host'), ['Empty'])),
                        ('inout', (YLeaf(YType.empty, 'InOut'), ['Empty'])),
                        ('printer', (YLeaf(YType.empty, 'Printer'), ['Empty'])),
                        ('answer_timeout', (YLeaf(YType.empty, 'answer-timeout'), ['Empty'])),
                        ('dtr_delay', (YLeaf(YType.empty, 'dtr-delay'), ['Empty'])),
                    ])
                    self.cts_alarm = None
                    self.dtr_active = None
                    self.dialin = None
                    self.host = None
                    self.inout = None
                    self.printer = None
                    self.answer_timeout = None
                    self.dtr_delay = None
                    self._segment_path = lambda: "modem"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Modem, [u'cts_alarm', u'dtr_active', u'dialin', u'host', u'inout', u'printer', u'answer_timeout', u'dtr_delay'], name, value)


            class Padding(Entity):
                """
                Set padding for a specified output character
                
                .. attribute:: character
                
                	Character to be padded
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..127
                
                		**type**\: str
                
                .. attribute:: null
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Padding, self).__init__()

                    self.yang_name = "padding"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('character', (YLeaf(YType.str, 'character'), ['int','str'])),
                        ('null', (YLeaf(YType.uint8, 'null'), ['int'])),
                    ])
                    self.character = None
                    self.null = None
                    self._segment_path = lambda: "padding"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Padding, [u'character', u'null'], name, value)


            class Parity(Entity):
                """
                Set terminal parity
                
                .. attribute:: even
                
                	Even parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mark
                
                	Mark parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: none
                
                	No parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: odd
                
                	Odd parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: space
                
                	Space parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Parity, self).__init__()

                    self.yang_name = "parity"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('even', (YLeaf(YType.empty, 'even'), ['Empty'])),
                        ('mark', (YLeaf(YType.empty, 'mark'), ['Empty'])),
                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ('odd', (YLeaf(YType.empty, 'odd'), ['Empty'])),
                        ('space', (YLeaf(YType.empty, 'space'), ['Empty'])),
                    ])
                    self.even = None
                    self.mark = None
                    self.none = None
                    self.odd = None
                    self.space = None
                    self._segment_path = lambda: "parity"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Parity, [u'even', u'mark', u'none', u'odd', u'space'], name, value)


            class Password(Entity):
                """
                Set a password
                
                .. attribute:: level
                
                	Set exec level password
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: type
                
                	
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Password.Type>`
                
                .. attribute:: secret
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Password, self).__init__()

                    self.yang_name = "password"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Aux.Password.Type')])),
                        ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                    ])
                    self.level = None
                    self.type = None
                    self.secret = None
                    self._segment_path = lambda: "password"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Password, [u'level', u'type', u'secret'], name, value)

                class Type(Enum):
                    """
                    Type (Enum Class)

                    .. data:: Y_0 = 0

                    .. data:: Y_7 = 1

                    """

                    Y_0 = Enum.YLeaf(0, "0")

                    Y_7 = Enum.YLeaf(1, "7")



            class Prc(Entity):
                """
                PRC commands
                
                .. attribute:: expose
                
                	Expose PRC data
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hide
                
                	Hide PRC data
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Prc, self).__init__()

                    self.yang_name = "prc"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('expose', (YLeaf(YType.empty, 'expose'), ['Empty'])),
                        ('hide', (YLeaf(YType.empty, 'hide'), ['Empty'])),
                    ])
                    self.expose = None
                    self.hide = None
                    self._segment_path = lambda: "prc"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Prc, [u'expose', u'hide'], name, value)


            class Privilege(Entity):
                """
                Change privilege level for line
                
                .. attribute:: level
                
                	Assign default privilege level for line
                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Privilege.Level>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Privilege, self).__init__()

                    self.yang_name = "privilege"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Line.Aux.Privilege.Level))])
                    self._leafs = OrderedDict()

                    self.level = None
                    self._children_name_map["level"] = "level"
                    self._segment_path = lambda: "privilege"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Privilege, [], name, value)


                class Level(Entity):
                    """
                    Assign default privilege level for line
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..15
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.Privilege.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "privilege"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                        ])
                        self.number = None
                        self._segment_path = lambda: "level"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.Privilege.Level, [u'number'], name, value)


            class SessionTimeout(Entity):
                """
                Set interval for closing connection when there is no input traffic
                
                .. attribute:: session_timeout_value
                
                	
                	**type**\: int
                
                	**range:** 0..35791
                
                .. attribute:: output
                
                	Include output traffic as well as input traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.SessionTimeout, self).__init__()

                    self.yang_name = "session-timeout"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('session_timeout_value', (YLeaf(YType.uint16, 'session-timeout-value'), ['int'])),
                        ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                    ])
                    self.session_timeout_value = None
                    self.output = None
                    self._segment_path = lambda: "session-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.SessionTimeout, [u'session_timeout_value', u'output'], name, value)


            class Timeout(Entity):
                """
                Timeouts for the line
                
                .. attribute:: login
                
                	Timeouts related to the login sequence
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Timeout, self).__init__()

                    self.yang_name = "timeout"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('login', (YLeaf(YType.empty, 'login'), ['Empty'])),
                    ])
                    self.login = None
                    self._segment_path = lambda: "timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Timeout, [u'login'], name, value)


            class Telnet(Entity):
                """
                Telnet protocol\-specific configuration
                
                .. attribute:: transparent
                
                	Send a CR as a CR followed by a NULL instead of a CR followed by a LF
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Telnet, self).__init__()

                    self.yang_name = "telnet"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                    ])
                    self.transparent = None
                    self._segment_path = lambda: "telnet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Telnet, [u'transparent'], name, value)


            class Transport(Entity):
                """
                Define transport protocols for line
                
                .. attribute:: input
                
                	
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Transport.Input>`
                
                .. attribute:: output
                
                	
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Transport.Output>`
                
                .. attribute:: preferred
                
                	Specify the preferred protocol to use
                	**type**\:  :py:class:`Preferred <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Transport.Preferred>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.Transport, self).__init__()

                    self.yang_name = "transport"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Line.Aux.Transport.Input)), ("output", ("output", Native.Line.Aux.Transport.Output)), ("preferred", ("preferred", Native.Line.Aux.Transport.Preferred))])
                    self._leafs = OrderedDict()

                    self.input = Native.Line.Aux.Transport.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Line.Aux.Transport.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"

                    self.preferred = None
                    self._children_name_map["preferred"] = "preferred"
                    self._segment_path = lambda: "transport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.Transport, [], name, value)


                class Input(Entity):
                    """
                    
                    
                    .. attribute:: input
                    
                    	Define which protocols to use when connecting to the terminal server
                    	**type**\: list of   :py:class:`Input_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Transport.Input.Input_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.Transport.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeafList(YType.enumeration, 'input'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Aux.Transport.Input.Input_')])),
                        ])
                        self.input = []
                        self._segment_path = lambda: "input"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.Transport.Input, [u'input'], name, value)

                    class Input_(Enum):
                        """
                        Input\_ (Enum Class)

                        Define which protocols to use when connecting to the terminal server

                        .. data:: acercon = 0

                        .. data:: all = 1

                        .. data:: lapb_ta = 2

                        .. data:: lat = 3

                        .. data:: mop = 4

                        .. data:: nasi = 5

                        .. data:: none = 6

                        .. data:: pad = 7

                        .. data:: rlogin = 8

                        .. data:: ssh = 9

                        .. data:: telnet = 10

                        .. data:: udptn = 11

                        .. data:: v120 = 12

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        all = Enum.YLeaf(1, "all")

                        lapb_ta = Enum.YLeaf(2, "lapb-ta")

                        lat = Enum.YLeaf(3, "lat")

                        mop = Enum.YLeaf(4, "mop")

                        nasi = Enum.YLeaf(5, "nasi")

                        none = Enum.YLeaf(6, "none")

                        pad = Enum.YLeaf(7, "pad")

                        rlogin = Enum.YLeaf(8, "rlogin")

                        ssh = Enum.YLeaf(9, "ssh")

                        telnet = Enum.YLeaf(10, "telnet")

                        udptn = Enum.YLeaf(11, "udptn")

                        v120 = Enum.YLeaf(12, "v120")



                class Output(Entity):
                    """
                    
                    
                    .. attribute:: output
                    
                    	Define which protocols to use for outgoing connections
                    	**type**\: list of   :py:class:`Output_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Transport.Output.Output_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.Transport.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('output', (YLeafList(YType.enumeration, 'output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Aux.Transport.Output.Output_')])),
                        ])
                        self.output = []
                        self._segment_path = lambda: "output"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.Transport.Output, [u'output'], name, value)

                    class Output_(Enum):
                        """
                        Output\_ (Enum Class)

                        Define which protocols to use for outgoing connections

                        .. data:: acercon = 0

                        .. data:: all = 1

                        .. data:: lapb_ta = 2

                        .. data:: lat = 3

                        .. data:: mop = 4

                        .. data:: nasi = 5

                        .. data:: none = 6

                        .. data:: pad = 7

                        .. data:: rlogin = 8

                        .. data:: ssh = 9

                        .. data:: telnet = 10

                        .. data:: udptn = 11

                        .. data:: v120 = 12

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        all = Enum.YLeaf(1, "all")

                        lapb_ta = Enum.YLeaf(2, "lapb-ta")

                        lat = Enum.YLeaf(3, "lat")

                        mop = Enum.YLeaf(4, "mop")

                        nasi = Enum.YLeaf(5, "nasi")

                        none = Enum.YLeaf(6, "none")

                        pad = Enum.YLeaf(7, "pad")

                        rlogin = Enum.YLeaf(8, "rlogin")

                        ssh = Enum.YLeaf(9, "ssh")

                        telnet = Enum.YLeaf(10, "telnet")

                        udptn = Enum.YLeaf(11, "udptn")

                        v120 = Enum.YLeaf(12, "v120")



                class Preferred(Entity):
                    """
                    Specify the preferred protocol to use
                    
                    .. attribute:: protocol
                    
                    	
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Aux.Transport.Preferred.Protocol>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Aux.Transport.Preferred, self).__init__()

                        self.yang_name = "preferred"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Aux.Transport.Preferred.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "preferred"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Aux.Transport.Preferred, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        .. data:: acercon = 0

                        .. data:: lat = 1

                        .. data:: mop = 2

                        .. data:: nasi = 3

                        .. data:: none = 4

                        .. data:: pad = 5

                        .. data:: rlogin = 6

                        .. data:: ssh = 7

                        .. data:: telnet = 8

                        .. data:: udptn = 9

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        lat = Enum.YLeaf(1, "lat")

                        mop = Enum.YLeaf(2, "mop")

                        nasi = Enum.YLeaf(3, "nasi")

                        none = Enum.YLeaf(4, "none")

                        pad = Enum.YLeaf(5, "pad")

                        rlogin = Enum.YLeaf(6, "rlogin")

                        ssh = Enum.YLeaf(7, "ssh")

                        telnet = Enum.YLeaf(8, "telnet")

                        udptn = Enum.YLeaf(9, "udptn")



            class UsbInactivityTimeout(Entity):
                """
                Inactivity timeout for USB media type
                
                .. attribute:: switch
                
                	Switch Number
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Aux.UsbInactivityTimeout, self).__init__()

                    self.yang_name = "usb-inactivity-timeout"
                    self.yang_parent_name = "aux"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switch', (YLeaf(YType.empty, 'switch'), ['Empty'])),
                    ])
                    self.switch = None
                    self._segment_path = lambda: "usb-inactivity-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Aux.UsbInactivityTimeout, [u'switch'], name, value)


        class Console(Entity):
            """
            Primary terminal line
            
            .. attribute:: first  (key)
            
            	
            	**type**\:  :py:class:`First <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.First>`
            
            .. attribute:: authorization
            
            	Authorization parameters
            	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Authorization>`
            
            .. attribute:: access_class
            
            	Filter connections based on an IP access list
            	**type**\:  :py:class:`AccessClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.AccessClass>`
            
            .. attribute:: no_activation_character
            
            	
            	**type**\: bool
            
            .. attribute:: activation_character
            
            	Define the activation character
            	**type**\: union of the below types:
            
            		**type**\: str
            
            		**type**\: int
            
            			**range:** 0..127
            
            .. attribute:: autocommand
            
            	Automatically execute an EXEC command
            	**type**\:  :py:class:`Autocommand <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Autocommand>`
            
            .. attribute:: autocommand_options
            
            	Autocommand options
            	**type**\:  :py:class:`AutocommandOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.AutocommandOptions>`
            
            	**presence node**\: True
            
            .. attribute:: data_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: databits
            
            	Set number of data bits per character
            	**type**\:  :py:class:`Databits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Databits>`
            
            .. attribute:: domain_lookup
            
            	Enable domain lookups in show commands
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: editing
            
            	Enable command line editing
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: escape_character
            
            	Change the current line's escape character
            	**type**\:  :py:class:`EscapeCharacter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.EscapeCharacter>`
            
            .. attribute:: no_exec
            
            	
            	**type**\:  :py:class:`NoExec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.NoExec>`
            
            .. attribute:: exec_
            
            	
            	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Exec>`
            
            .. attribute:: exec_banner
            
            	Enable the display of the EXEC banner
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: exec_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: exec_timeout
            
            	Set the EXEC timeout
            	**type**\:  :py:class:`ExecTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.ExecTimeout>`
            
            .. attribute:: flowcontrol
            
            	Set the flow control
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Flowcontrol>`
            
            .. attribute:: full_help
            
            	Provide help to unprivileged user
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: history
            
            	Enable and control the command history function
            	**type**\:  :py:class:`History <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.History>`
            
            	**presence node**\: True
            
            .. attribute:: international
            
            	Enable international 8\-bit character support
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ip
            
            	IP options
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Ip>`
            
            .. attribute:: ipv6
            
            	
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Ipv6>`
            
            .. attribute:: length
            
            	Set number of lines on a screen
            	**type**\: int
            
            	**range:** 0..512
            
            .. attribute:: line
            
            	
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: location
            
            	One text line describing the terminal's location
            	**type**\: str
            
            .. attribute:: logging
            
            	Modify message logging facilities
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Logging>`
            
            .. attribute:: login
            
            	Enable password checking
            	**type**\:  :py:class:`Login <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Login>`
            
            	**presence node**\: True
            
            .. attribute:: media_type
            
            	Console connection media type
            	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.MediaType>`
            
            .. attribute:: modem
            
            	Configure the Modem Control Lines
            	**type**\:  :py:class:`Modem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Modem>`
            
            .. attribute:: monitor
            
            	Copy debug output to the current terminal line
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: motd_banner
            
            	Enable the display of the MOTD banner
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: notify
            
            	Inform users of output from concurrent sessions
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: padding
            
            	Set padding for a specified output character
            	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Padding>`
            
            .. attribute:: parity
            
            	Set terminal parity
            	**type**\:  :py:class:`Parity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Parity>`
            
            .. attribute:: password
            
            	Set a password
            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Password>`
            
            .. attribute:: prc
            
            	PRC commands
            	**type**\:  :py:class:`Prc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Prc>`
            
            .. attribute:: privilege
            
            	Change privilege level for line
            	**type**\:  :py:class:`Privilege <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Privilege>`
            
            .. attribute:: rotary
            
            	Rotary group to add line to
            	**type**\: int
            
            	**range:** 1..99
            
            .. attribute:: rxspeed
            
            	Receive speed
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_limit
            
            	Set maximum number of sessions
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_timeout
            
            	Set interval for closing connection when there is no input traffic
            	**type**\:  :py:class:`SessionTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.SessionTimeout>`
            
            .. attribute:: special_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: speed
            
            	Transmit and receive speeds
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: start_character
            
            	Define the start character
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..255
            
            		**type**\: str
            
            .. attribute:: stop_character
            
            	Define the stop character
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..255
            
            		**type**\: str
            
            .. attribute:: stopbits
            
            	Set async line stop bits
            	**type**\:  :py:class:`Stopbits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Stopbits>`
            
            .. attribute:: terminal_type
            
            	Terminal type
            	**type**\: str
            
            .. attribute:: timeout
            
            	Timeouts for the line
            	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Timeout>`
            
            .. attribute:: telnet
            
            	Telnet protocol\-specific configuration
            	**type**\:  :py:class:`Telnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Telnet>`
            
            .. attribute:: transport
            
            	Define transport protocols for line
            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Transport>`
            
            .. attribute:: txspeed
            
            	Transmit speed
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: usb_inactivity_timeout
            
            	Inactivity timeout for USB media type
            	**type**\:  :py:class:`UsbInactivityTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.UsbInactivityTimeout>`
            
            .. attribute:: width
            
            	Number of characters on a screen line
            	**type**\: int
            
            	**range:** 0..512
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Line.Console, self).__init__()

                self.yang_name = "console"
                self.yang_parent_name = "line"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['first']
                self._child_classes = OrderedDict([("authorization", ("authorization", Native.Line.Console.Authorization)), ("access-class", ("access_class", Native.Line.Console.AccessClass)), ("autocommand", ("autocommand", Native.Line.Console.Autocommand)), ("autocommand-options", ("autocommand_options", Native.Line.Console.AutocommandOptions)), ("databits", ("databits", Native.Line.Console.Databits)), ("escape-character", ("escape_character", Native.Line.Console.EscapeCharacter)), ("no-exec", ("no_exec", Native.Line.Console.NoExec)), ("exec", ("exec_", Native.Line.Console.Exec)), ("exec-timeout", ("exec_timeout", Native.Line.Console.ExecTimeout)), ("flowcontrol", ("flowcontrol", Native.Line.Console.Flowcontrol)), ("history", ("history", Native.Line.Console.History)), ("ip", ("ip", Native.Line.Console.Ip)), ("ipv6", ("ipv6", Native.Line.Console.Ipv6)), ("logging", ("logging", Native.Line.Console.Logging)), ("login", ("login", Native.Line.Console.Login)), ("media-type", ("media_type", Native.Line.Console.MediaType)), ("modem", ("modem", Native.Line.Console.Modem)), ("padding", ("padding", Native.Line.Console.Padding)), ("parity", ("parity", Native.Line.Console.Parity)), ("password", ("password", Native.Line.Console.Password)), ("prc", ("prc", Native.Line.Console.Prc)), ("privilege", ("privilege", Native.Line.Console.Privilege)), ("session-timeout", ("session_timeout", Native.Line.Console.SessionTimeout)), ("timeout", ("timeout", Native.Line.Console.Timeout)), ("telnet", ("telnet", Native.Line.Console.Telnet)), ("transport", ("transport", Native.Line.Console.Transport)), ("usb-inactivity-timeout", ("usb_inactivity_timeout", Native.Line.Console.UsbInactivityTimeout))])
                self._leafs = OrderedDict([
                    ('first', (YLeaf(YType.enumeration, 'first'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Console.First')])),
                    ('no_activation_character', (YLeaf(YType.boolean, 'no-activation-character'), ['bool'])),
                    ('activation_character', (YLeaf(YType.str, 'activation-character'), ['str','int'])),
                    ('data_character_bits', (YLeaf(YType.uint8, 'data-character-bits'), ['int'])),
                    ('domain_lookup', (YLeaf(YType.empty, 'domain-lookup'), ['Empty'])),
                    ('editing', (YLeaf(YType.empty, 'editing'), ['Empty'])),
                    ('exec_banner', (YLeaf(YType.empty, 'exec-banner'), ['Empty'])),
                    ('exec_character_bits', (YLeaf(YType.uint8, 'exec-character-bits'), ['int'])),
                    ('full_help', (YLeaf(YType.empty, 'full-help'), ['Empty'])),
                    ('international', (YLeaf(YType.empty, 'international'), ['Empty'])),
                    ('length', (YLeaf(YType.uint16, 'length'), ['int'])),
                    ('line', (YLeaf(YType.uint8, 'line'), ['int'])),
                    ('location', (YLeaf(YType.str, 'location'), ['str'])),
                    ('monitor', (YLeaf(YType.empty, 'monitor'), ['Empty'])),
                    ('motd_banner', (YLeaf(YType.empty, 'motd-banner'), ['Empty'])),
                    ('notify', (YLeaf(YType.empty, 'notify'), ['Empty'])),
                    ('rotary', (YLeaf(YType.uint8, 'rotary'), ['int'])),
                    ('rxspeed', (YLeaf(YType.uint32, 'rxspeed'), ['int'])),
                    ('session_limit', (YLeaf(YType.uint32, 'session-limit'), ['int'])),
                    ('special_character_bits', (YLeaf(YType.uint8, 'special-character-bits'), ['int'])),
                    ('speed', (YLeaf(YType.uint32, 'speed'), ['int'])),
                    ('start_character', (YLeaf(YType.str, 'start-character'), ['int','str'])),
                    ('stop_character', (YLeaf(YType.str, 'stop-character'), ['int','str'])),
                    ('stopbits', (YLeaf(YType.enumeration, 'stopbits'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Console.Stopbits')])),
                    ('terminal_type', (YLeaf(YType.str, 'terminal-type'), ['str'])),
                    ('txspeed', (YLeaf(YType.uint32, 'txspeed'), ['int'])),
                    ('width', (YLeaf(YType.uint16, 'width'), ['int'])),
                ])
                self.first = None
                self.no_activation_character = None
                self.activation_character = None
                self.data_character_bits = None
                self.domain_lookup = None
                self.editing = None
                self.exec_banner = None
                self.exec_character_bits = None
                self.full_help = None
                self.international = None
                self.length = None
                self.line = None
                self.location = None
                self.monitor = None
                self.motd_banner = None
                self.notify = None
                self.rotary = None
                self.rxspeed = None
                self.session_limit = None
                self.special_character_bits = None
                self.speed = None
                self.start_character = None
                self.stop_character = None
                self.stopbits = None
                self.terminal_type = None
                self.txspeed = None
                self.width = None

                self.authorization = Native.Line.Console.Authorization()
                self.authorization.parent = self
                self._children_name_map["authorization"] = "authorization"

                self.access_class = Native.Line.Console.AccessClass()
                self.access_class.parent = self
                self._children_name_map["access_class"] = "access-class"

                self.autocommand = Native.Line.Console.Autocommand()
                self.autocommand.parent = self
                self._children_name_map["autocommand"] = "autocommand"

                self.autocommand_options = None
                self._children_name_map["autocommand_options"] = "autocommand-options"

                self.databits = Native.Line.Console.Databits()
                self.databits.parent = self
                self._children_name_map["databits"] = "databits"

                self.escape_character = Native.Line.Console.EscapeCharacter()
                self.escape_character.parent = self
                self._children_name_map["escape_character"] = "escape-character"

                self.no_exec = Native.Line.Console.NoExec()
                self.no_exec.parent = self
                self._children_name_map["no_exec"] = "no-exec"

                self.exec_ = Native.Line.Console.Exec()
                self.exec_.parent = self
                self._children_name_map["exec_"] = "exec"

                self.exec_timeout = Native.Line.Console.ExecTimeout()
                self.exec_timeout.parent = self
                self._children_name_map["exec_timeout"] = "exec-timeout"

                self.flowcontrol = Native.Line.Console.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.history = None
                self._children_name_map["history"] = "history"

                self.ip = Native.Line.Console.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Line.Console.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Line.Console.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.login = None
                self._children_name_map["login"] = "login"

                self.media_type = Native.Line.Console.MediaType()
                self.media_type.parent = self
                self._children_name_map["media_type"] = "media-type"

                self.modem = Native.Line.Console.Modem()
                self.modem.parent = self
                self._children_name_map["modem"] = "modem"

                self.padding = Native.Line.Console.Padding()
                self.padding.parent = self
                self._children_name_map["padding"] = "padding"

                self.parity = Native.Line.Console.Parity()
                self.parity.parent = self
                self._children_name_map["parity"] = "parity"

                self.password = Native.Line.Console.Password()
                self.password.parent = self
                self._children_name_map["password"] = "password"

                self.prc = Native.Line.Console.Prc()
                self.prc.parent = self
                self._children_name_map["prc"] = "prc"

                self.privilege = Native.Line.Console.Privilege()
                self.privilege.parent = self
                self._children_name_map["privilege"] = "privilege"

                self.session_timeout = Native.Line.Console.SessionTimeout()
                self.session_timeout.parent = self
                self._children_name_map["session_timeout"] = "session-timeout"

                self.timeout = Native.Line.Console.Timeout()
                self.timeout.parent = self
                self._children_name_map["timeout"] = "timeout"

                self.telnet = Native.Line.Console.Telnet()
                self.telnet.parent = self
                self._children_name_map["telnet"] = "telnet"

                self.transport = Native.Line.Console.Transport()
                self.transport.parent = self
                self._children_name_map["transport"] = "transport"

                self.usb_inactivity_timeout = Native.Line.Console.UsbInactivityTimeout()
                self.usb_inactivity_timeout.parent = self
                self._children_name_map["usb_inactivity_timeout"] = "usb-inactivity-timeout"
                self._segment_path = lambda: "console" + "[first='" + str(self.first) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/line/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Line.Console, [u'first', u'no_activation_character', u'activation_character', u'data_character_bits', u'domain_lookup', u'editing', u'exec_banner', u'exec_character_bits', u'full_help', u'international', u'length', u'line', u'location', u'monitor', u'motd_banner', u'notify', u'rotary', u'rxspeed', u'session_limit', u'special_character_bits', u'speed', u'start_character', u'stop_character', u'stopbits', u'terminal_type', u'txspeed', u'width'], name, value)

            class First(Enum):
                """
                First (Enum Class)

                .. data:: Y_0 = 0

                """

                Y_0 = Enum.YLeaf(0, "0")


            class Stopbits(Enum):
                """
                Stopbits (Enum Class)

                Set async line stop bits

                .. data:: Y_1 = 0

                .. data:: Y_1__DOT__5 = 1

                .. data:: Y_2 = 2

                """

                Y_1 = Enum.YLeaf(0, "1")

                Y_1__DOT__5 = Enum.YLeaf(1, "1.5")

                Y_2 = Enum.YLeaf(2, "2")



            class Authorization(Entity):
                """
                Authorization parameters
                
                .. attribute:: command
                
                	For exec (shell) commands
                	**type**\:  :py:class:`Command <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Authorization.Command>`
                
                .. attribute:: exec_
                
                	For starting an exec (shell)
                	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Authorization.Exec>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Authorization, self).__init__()

                    self.yang_name = "authorization"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("command", ("command", Native.Line.Console.Authorization.Command)), ("exec", ("exec_", Native.Line.Console.Authorization.Exec))])
                    self._leafs = OrderedDict()

                    self.command = Native.Line.Console.Authorization.Command()
                    self.command.parent = self
                    self._children_name_map["command"] = "command"

                    self.exec_ = Native.Line.Console.Authorization.Exec()
                    self.exec_.parent = self
                    self._children_name_map["exec_"] = "exec"
                    self._segment_path = lambda: "authorization"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Authorization, [], name, value)


                class Command(Entity):
                    """
                    For exec (shell) commands
                    
                    .. attribute:: enable_level
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..15
                    
                    .. attribute:: auth_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.Authorization.Command, self).__init__()

                        self.yang_name = "command"
                        self.yang_parent_name = "authorization"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable_level', (YLeaf(YType.uint8, 'enable-level'), ['int'])),
                            ('auth_name', (YLeaf(YType.str, 'auth-name'), ['str'])),
                        ])
                        self.enable_level = None
                        self.auth_name = None
                        self._segment_path = lambda: "command"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.Authorization.Command, [u'enable_level', u'auth_name'], name, value)


                class Exec(Entity):
                    """
                    For starting an exec (shell)
                    
                    .. attribute:: authorization_name
                    
                    	Use an authorization list with this name
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	Use the default authorization list
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.Authorization.Exec, self).__init__()

                        self.yang_name = "exec"
                        self.yang_parent_name = "authorization"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('authorization_name', (YLeaf(YType.str, 'authorization-name'), ['str'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.authorization_name = None
                        self.default = None
                        self._segment_path = lambda: "exec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.Authorization.Exec, [u'authorization_name', u'default'], name, value)


            class AccessClass(Entity):
                """
                Filter connections based on an IP access list
                
                .. attribute:: acccess_list
                
                	
                	**type**\: list of  		 :py:class:`AcccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.AccessClass.AcccessList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.AccessClass, self).__init__()

                    self.yang_name = "access-class"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("acccess-list", ("acccess_list", Native.Line.Console.AccessClass.AcccessList))])
                    self._leafs = OrderedDict()

                    self.acccess_list = YList(self)
                    self._segment_path = lambda: "access-class"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.AccessClass, [], name, value)


                class AcccessList(Entity):
                    """
                    
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.AccessClass.AcccessList.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    	**mandatory**\: True
                    
                    .. attribute:: vrf_also
                    
                    	Same access list is applied for all VRFs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.AccessClass.AcccessList, self).__init__()

                        self.yang_name = "acccess-list"
                        self.yang_parent_name = "access-class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Console.AccessClass.AcccessList.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['int','str'])),
                            ('vrf_also', (YLeaf(YType.empty, 'vrf-also'), ['Empty'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self.vrf_also = None
                        self._segment_path = lambda: "acccess-list" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.AccessClass.AcccessList, [u'direction', u'access_list', u'vrf_also'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Autocommand(Entity):
                """
                Automatically execute an EXEC command
                
                .. attribute:: line
                
                	Appropriate EXEC command
                	**type**\: str
                
                .. attribute:: no_suppress_linenumber
                
                	Display service linenumber message
                	**type**\:  :py:class:`NoSuppressLinenumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Autocommand.NoSuppressLinenumber>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Autocommand, self).__init__()

                    self.yang_name = "autocommand"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("no-suppress-linenumber", ("no_suppress_linenumber", Native.Line.Console.Autocommand.NoSuppressLinenumber))])
                    self._leafs = OrderedDict([
                        ('line', (YLeaf(YType.str, 'line'), ['str'])),
                    ])
                    self.line = None

                    self.no_suppress_linenumber = None
                    self._children_name_map["no_suppress_linenumber"] = "no-suppress-linenumber"
                    self._segment_path = lambda: "autocommand"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Autocommand, [u'line'], name, value)


                class NoSuppressLinenumber(Entity):
                    """
                    Display service linenumber message
                    
                    .. attribute:: line
                    
                    	Appropriate EXEC command
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.Autocommand.NoSuppressLinenumber, self).__init__()

                        self.yang_name = "no-suppress-linenumber"
                        self.yang_parent_name = "autocommand"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('line', (YLeaf(YType.str, 'line'), ['str'])),
                        ])
                        self.line = None
                        self._segment_path = lambda: "no-suppress-linenumber"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.Autocommand.NoSuppressLinenumber, [u'line'], name, value)


            class AutocommandOptions(Entity):
                """
                Autocommand options
                
                .. attribute:: abort_character
                
                	Autocommand abort character
                	**type**\:  :py:class:`AbortCharacter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.AutocommandOptions.AbortCharacter>`
                
                	**presence node**\: True
                
                .. attribute:: delay
                
                	Delay autocommand execution
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.AutocommandOptions.Delay>`
                
                	**presence node**\: True
                
                .. attribute:: nohangup
                
                	No hangup after autocommand completion
                	**type**\:  :py:class:`Nohangup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.AutocommandOptions.Nohangup>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.AutocommandOptions, self).__init__()

                    self.yang_name = "autocommand-options"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("abort-character", ("abort_character", Native.Line.Console.AutocommandOptions.AbortCharacter)), ("delay", ("delay", Native.Line.Console.AutocommandOptions.Delay)), ("nohangup", ("nohangup", Native.Line.Console.AutocommandOptions.Nohangup))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.abort_character = None
                    self._children_name_map["abort_character"] = "abort-character"

                    self.delay = None
                    self._children_name_map["delay"] = "delay"

                    self.nohangup = None
                    self._children_name_map["nohangup"] = "nohangup"
                    self._segment_path = lambda: "autocommand-options"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.AutocommandOptions, [], name, value)


                class AbortCharacter(Entity):
                    """
                    Autocommand abort character
                    
                    .. attribute:: character
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..255
                    
                    		**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.AutocommandOptions.AbortCharacter, self).__init__()

                        self.yang_name = "abort-character"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('character', (YLeaf(YType.str, 'character'), ['int','str'])),
                        ])
                        self.character = None
                        self._segment_path = lambda: "abort-character"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.AutocommandOptions.AbortCharacter, [u'character'], name, value)


                class Delay(Entity):
                    """
                    Delay autocommand execution
                    
                    .. attribute:: time
                    
                    	Time in seconds
                    	**type**\: int
                    
                    	**range:** 0..120
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.AutocommandOptions.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('time', (YLeaf(YType.uint8, 'time'), ['int'])),
                        ])
                        self.time = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.AutocommandOptions.Delay, [u'time'], name, value)


                class Nohangup(Entity):
                    """
                    No hangup after autocommand completion
                    
                    .. attribute:: abort_character
                    
                    	Autocommand abort character
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: delay
                    
                    	Delay autocommand execution
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.AutocommandOptions.Nohangup, self).__init__()

                        self.yang_name = "nohangup"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('abort_character', (YLeaf(YType.empty, 'abort-character'), ['Empty'])),
                            ('delay', (YLeaf(YType.empty, 'delay'), ['Empty'])),
                        ])
                        self.abort_character = None
                        self.delay = None
                        self._segment_path = lambda: "nohangup"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.AutocommandOptions.Nohangup, [u'abort_character', u'delay'], name, value)


            class Databits(Entity):
                """
                Set number of data bits per character
                
                .. attribute:: set_to_5
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_6
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_7
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_8
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Databits, self).__init__()

                    self.yang_name = "databits"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('set_to_5', (YLeaf(YType.empty, 'set-to-5'), ['Empty'])),
                        ('set_to_6', (YLeaf(YType.empty, 'set-to-6'), ['Empty'])),
                        ('set_to_7', (YLeaf(YType.empty, 'set-to-7'), ['Empty'])),
                        ('set_to_8', (YLeaf(YType.empty, 'set-to-8'), ['Empty'])),
                    ])
                    self.set_to_5 = None
                    self.set_to_6 = None
                    self.set_to_7 = None
                    self.set_to_8 = None
                    self._segment_path = lambda: "databits"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Databits, [u'set_to_5', u'set_to_6', u'set_to_7', u'set_to_8'], name, value)


            class EscapeCharacter(Entity):
                """
                Change the current line's escape character
                
                .. attribute:: char
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..255
                
                		**type**\:  :py:class:`Char <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.EscapeCharacter.Char>`
                
                		**type**\: str
                
                .. attribute:: soft
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.EscapeCharacter, self).__init__()

                    self.yang_name = "escape-character"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('char', (YLeaf(YType.str, 'char'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.EscapeCharacter.Char'),'str'])),
                        ('soft', (YLeaf(YType.empty, 'soft'), ['Empty'])),
                    ])
                    self.char = None
                    self.soft = None
                    self._segment_path = lambda: "escape-character"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.EscapeCharacter, [u'char', u'soft'], name, value)

                class Char(Enum):
                    """
                    Char (Enum Class)

                    .. data:: BREAK = 0

                    .. data:: DEFAULT = 1

                    .. data:: NONE = 2

                    """

                    BREAK = Enum.YLeaf(0, "BREAK")

                    DEFAULT = Enum.YLeaf(1, "DEFAULT")

                    NONE = Enum.YLeaf(2, "NONE")



            class NoExec(Entity):
                """
                
                
                .. attribute:: exec_
                
                	Configure EXEC
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.NoExec, self).__init__()

                    self.yang_name = "no-exec"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('exec_', (YLeaf(YType.boolean, 'exec'), ['bool'])),
                    ])
                    self.exec_ = None
                    self._segment_path = lambda: "no-exec"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.NoExec, [u'exec_'], name, value)


            class Exec(Entity):
                """
                
                
                .. attribute:: prompt
                
                	
                	**type**\:  :py:class:`Prompt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Exec.Prompt>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Exec, self).__init__()

                    self.yang_name = "exec"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("prompt", ("prompt", Native.Line.Console.Exec.Prompt))])
                    self._leafs = OrderedDict()

                    self.prompt = Native.Line.Console.Exec.Prompt()
                    self.prompt.parent = self
                    self._children_name_map["prompt"] = "prompt"
                    self._segment_path = lambda: "exec"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Exec, [], name, value)


                class Prompt(Entity):
                    """
                    
                    
                    .. attribute:: timestamp
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.Exec.Prompt, self).__init__()

                        self.yang_name = "prompt"
                        self.yang_parent_name = "exec"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('timestamp', (YLeaf(YType.empty, 'timestamp'), ['Empty'])),
                        ])
                        self.timestamp = None
                        self._segment_path = lambda: "prompt"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.Exec.Prompt, [u'timestamp'], name, value)


            class ExecTimeout(Entity):
                """
                Set the EXEC timeout
                
                .. attribute:: minutes
                
                	<0\-35791>;;Timeout in minutes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: seconds
                
                	<0\-2147483>;;Timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.ExecTimeout, self).__init__()

                    self.yang_name = "exec-timeout"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('minutes', (YLeaf(YType.uint32, 'minutes'), ['int'])),
                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                    ])
                    self.minutes = None
                    self.seconds = None
                    self._segment_path = lambda: "exec-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.ExecTimeout, [u'minutes', u'seconds'], name, value)


            class Flowcontrol(Entity):
                """
                Set the flow control
                
                .. attribute:: none
                
                	Set no flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hardware
                
                	Set hardware flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: software
                
                	Set software flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('none', (YLeaf(YType.empty, 'NONE'), ['Empty'])),
                        ('hardware', (YLeaf(YType.empty, 'hardware'), ['Empty'])),
                        ('software', (YLeaf(YType.empty, 'software'), ['Empty'])),
                    ])
                    self.none = None
                    self.hardware = None
                    self.software = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Flowcontrol, [u'none', u'hardware', u'software'], name, value)


            class History(Entity):
                """
                Enable and control the command history function
                
                .. attribute:: size
                
                	Set history buffer size
                	**type**\: int
                
                	**range:** 0..256
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.History, self).__init__()

                    self.yang_name = "history"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                    ])
                    self.size = None
                    self._segment_path = lambda: "history"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.History, [u'size'], name, value)


            class Ip(Entity):
                """
                IP options
                
                .. attribute:: netmask_format
                
                	Change display of netmasks
                	**type**\:  :py:class:`NetmaskFormat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Ip.NetmaskFormat>`
                
                	**presence node**\: True
                
                .. attribute:: tcp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("netmask-format", ("netmask_format", Native.Line.Console.Ip.NetmaskFormat))])
                    self._leafs = OrderedDict([
                        ('tcp', (YLeaf(YType.empty, 'tcp'), ['Empty'])),
                    ])
                    self.tcp = None

                    self.netmask_format = None
                    self._children_name_map["netmask_format"] = "netmask-format"
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Ip, [u'tcp'], name, value)


                class NetmaskFormat(Entity):
                    """
                    Change display of netmasks
                    
                    .. attribute:: format
                    
                    	
                    	**type**\:  :py:class:`Format <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Ip.NetmaskFormat.Format>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.Ip.NetmaskFormat, self).__init__()

                        self.yang_name = "netmask-format"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('format', (YLeaf(YType.enumeration, 'format'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Console.Ip.NetmaskFormat.Format')])),
                        ])
                        self.format = None
                        self._segment_path = lambda: "netmask-format"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.Ip.NetmaskFormat, [u'format'], name, value)

                    class Format(Enum):
                        """
                        Format (Enum Class)

                        .. data:: bit_count = 0

                        .. data:: decimal = 1

                        .. data:: hexadecimal = 2

                        """

                        bit_count = Enum.YLeaf(0, "bit-count")

                        decimal = Enum.YLeaf(1, "decimal")

                        hexadecimal = Enum.YLeaf(2, "hexadecimal")



            class Ipv6(Entity):
                """
                
                
                .. attribute:: access_class
                
                	
                	**type**\:  :py:class:`AccessClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Ipv6.AccessClass>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-class", ("access_class", Native.Line.Console.Ipv6.AccessClass))])
                    self._leafs = OrderedDict()

                    self.access_class = Native.Line.Console.Ipv6.AccessClass()
                    self.access_class.parent = self
                    self._children_name_map["access_class"] = "access-class"
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Ipv6, [], name, value)


                class AccessClass(Entity):
                    """
                    
                    
                    .. attribute:: access_class
                    
                    	
                    	**type**\: list of  		 :py:class:`AccessClass_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Ipv6.AccessClass.AccessClass_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.Ipv6.AccessClass, self).__init__()

                        self.yang_name = "access-class"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-class", ("access_class", Native.Line.Console.Ipv6.AccessClass.AccessClass_))])
                        self._leafs = OrderedDict()

                        self.access_class = YList(self)
                        self._segment_path = lambda: "access-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.Ipv6.AccessClass, [], name, value)


                    class AccessClass_(Entity):
                        """
                        
                        
                        .. attribute:: access_class_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: enumeration_in_out
                        
                        	
                        	**type**\:  :py:class:`EnumerationInOut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Ipv6.AccessClass.AccessClass_.EnumerationInOut>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Line.Console.Ipv6.AccessClass.AccessClass_, self).__init__()

                            self.yang_name = "access-class"
                            self.yang_parent_name = "access-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['access_class_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_class_name', (YLeaf(YType.str, 'access-class-name'), ['str'])),
                                ('enumeration_in_out', (YLeaf(YType.enumeration, 'enumeration-in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Console.Ipv6.AccessClass.AccessClass_.EnumerationInOut')])),
                            ])
                            self.access_class_name = None
                            self.enumeration_in_out = None
                            self._segment_path = lambda: "access-class" + "[access-class-name='" + str(self.access_class_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Line.Console.Ipv6.AccessClass.AccessClass_, [u'access_class_name', u'enumeration_in_out'], name, value)

                        class EnumerationInOut(Enum):
                            """
                            EnumerationInOut (Enum Class)

                            .. data:: in_ = 0

                            .. data:: out = 1

                            """

                            in_ = Enum.YLeaf(0, "in")

                            out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Modify message logging facilities
                
                .. attribute:: synchronous
                
                	Synchronized message output
                	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Logging.Synchronous>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("synchronous", ("synchronous", Native.Line.Console.Logging.Synchronous))])
                    self._leafs = OrderedDict()

                    self.synchronous = None
                    self._children_name_map["synchronous"] = "synchronous"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Logging, [], name, value)


                class Synchronous(Entity):
                    """
                    Synchronized message output
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.Logging.Synchronous, self).__init__()

                        self.yang_name = "synchronous"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "synchronous"
                        self._is_frozen = True


            class Login(Entity):
                """
                Enable password checking
                
                .. attribute:: local
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: authentication
                
                	
                	**type**\: str
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Login, self).__init__()

                    self.yang_name = "login"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ('authentication', (YLeaf(YType.str, 'authentication'), ['str'])),
                    ])
                    self.local = None
                    self.authentication = None
                    self._segment_path = lambda: "login"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Login, [u'local', u'authentication'], name, value)


            class MediaType(Entity):
                """
                Console connection media type
                
                .. attribute:: rj45
                
                	Console connection set to RJ45
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.MediaType, self).__init__()

                    self.yang_name = "media-type"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('rj45', (YLeaf(YType.empty, 'rj45'), ['Empty'])),
                    ])
                    self.rj45 = None
                    self._segment_path = lambda: "media-type"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.MediaType, [u'rj45'], name, value)


            class Modem(Entity):
                """
                Configure the Modem Control Lines
                
                .. attribute:: cts_alarm
                
                	Alarm device which only uses CTS for call control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dtr_active
                
                	Leave DTR low unless line has an active incoming connection or EXEC
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dialin
                
                	Configure line for a modern dial\-in modem
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Devices that expect an incoming modem call
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: inout
                
                	Configure line for incoming AND outgoing use of modem
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: printer
                
                	Devices that require DSR/CD active
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: answer_timeout
                
                	Set interval between raising DTR and CTS response
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dtr_delay
                
                	Set interval during which DTR is held low
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Modem, self).__init__()

                    self.yang_name = "modem"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('cts_alarm', (YLeaf(YType.empty, 'CTS-Alarm'), ['Empty'])),
                        ('dtr_active', (YLeaf(YType.empty, 'DTR-active'), ['Empty'])),
                        ('dialin', (YLeaf(YType.empty, 'Dialin'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Host'), ['Empty'])),
                        ('inout', (YLeaf(YType.empty, 'InOut'), ['Empty'])),
                        ('printer', (YLeaf(YType.empty, 'Printer'), ['Empty'])),
                        ('answer_timeout', (YLeaf(YType.empty, 'answer-timeout'), ['Empty'])),
                        ('dtr_delay', (YLeaf(YType.empty, 'dtr-delay'), ['Empty'])),
                    ])
                    self.cts_alarm = None
                    self.dtr_active = None
                    self.dialin = None
                    self.host = None
                    self.inout = None
                    self.printer = None
                    self.answer_timeout = None
                    self.dtr_delay = None
                    self._segment_path = lambda: "modem"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Modem, [u'cts_alarm', u'dtr_active', u'dialin', u'host', u'inout', u'printer', u'answer_timeout', u'dtr_delay'], name, value)


            class Padding(Entity):
                """
                Set padding for a specified output character
                
                .. attribute:: character
                
                	Character to be padded
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..127
                
                		**type**\: str
                
                .. attribute:: null
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Padding, self).__init__()

                    self.yang_name = "padding"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('character', (YLeaf(YType.str, 'character'), ['int','str'])),
                        ('null', (YLeaf(YType.uint8, 'null'), ['int'])),
                    ])
                    self.character = None
                    self.null = None
                    self._segment_path = lambda: "padding"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Padding, [u'character', u'null'], name, value)


            class Parity(Entity):
                """
                Set terminal parity
                
                .. attribute:: even
                
                	Even parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mark
                
                	Mark parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: none
                
                	No parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: odd
                
                	Odd parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: space
                
                	Space parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Parity, self).__init__()

                    self.yang_name = "parity"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('even', (YLeaf(YType.empty, 'even'), ['Empty'])),
                        ('mark', (YLeaf(YType.empty, 'mark'), ['Empty'])),
                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ('odd', (YLeaf(YType.empty, 'odd'), ['Empty'])),
                        ('space', (YLeaf(YType.empty, 'space'), ['Empty'])),
                    ])
                    self.even = None
                    self.mark = None
                    self.none = None
                    self.odd = None
                    self.space = None
                    self._segment_path = lambda: "parity"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Parity, [u'even', u'mark', u'none', u'odd', u'space'], name, value)


            class Password(Entity):
                """
                Set a password
                
                .. attribute:: level
                
                	Set exec level password
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: type
                
                	
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Password.Type>`
                
                .. attribute:: secret
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Password, self).__init__()

                    self.yang_name = "password"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Console.Password.Type')])),
                        ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                    ])
                    self.level = None
                    self.type = None
                    self.secret = None
                    self._segment_path = lambda: "password"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Password, [u'level', u'type', u'secret'], name, value)

                class Type(Enum):
                    """
                    Type (Enum Class)

                    .. data:: Y_0 = 0

                    .. data:: Y_7 = 1

                    """

                    Y_0 = Enum.YLeaf(0, "0")

                    Y_7 = Enum.YLeaf(1, "7")



            class Prc(Entity):
                """
                PRC commands
                
                .. attribute:: expose
                
                	Expose PRC data
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hide
                
                	Hide PRC data
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Prc, self).__init__()

                    self.yang_name = "prc"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('expose', (YLeaf(YType.empty, 'expose'), ['Empty'])),
                        ('hide', (YLeaf(YType.empty, 'hide'), ['Empty'])),
                    ])
                    self.expose = None
                    self.hide = None
                    self._segment_path = lambda: "prc"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Prc, [u'expose', u'hide'], name, value)


            class Privilege(Entity):
                """
                Change privilege level for line
                
                .. attribute:: level
                
                	Assign default privilege level for line
                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Privilege.Level>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Privilege, self).__init__()

                    self.yang_name = "privilege"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Line.Console.Privilege.Level))])
                    self._leafs = OrderedDict()

                    self.level = None
                    self._children_name_map["level"] = "level"
                    self._segment_path = lambda: "privilege"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Privilege, [], name, value)


                class Level(Entity):
                    """
                    Assign default privilege level for line
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..15
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.Privilege.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "privilege"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                        ])
                        self.number = None
                        self._segment_path = lambda: "level"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.Privilege.Level, [u'number'], name, value)


            class SessionTimeout(Entity):
                """
                Set interval for closing connection when there is no input traffic
                
                .. attribute:: session_timeout_value
                
                	
                	**type**\: int
                
                	**range:** 0..35791
                
                .. attribute:: output
                
                	Include output traffic as well as input traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.SessionTimeout, self).__init__()

                    self.yang_name = "session-timeout"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('session_timeout_value', (YLeaf(YType.uint16, 'session-timeout-value'), ['int'])),
                        ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                    ])
                    self.session_timeout_value = None
                    self.output = None
                    self._segment_path = lambda: "session-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.SessionTimeout, [u'session_timeout_value', u'output'], name, value)


            class Timeout(Entity):
                """
                Timeouts for the line
                
                .. attribute:: login
                
                	Timeouts related to the login sequence
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Timeout, self).__init__()

                    self.yang_name = "timeout"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('login', (YLeaf(YType.empty, 'login'), ['Empty'])),
                    ])
                    self.login = None
                    self._segment_path = lambda: "timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Timeout, [u'login'], name, value)


            class Telnet(Entity):
                """
                Telnet protocol\-specific configuration
                
                .. attribute:: transparent
                
                	Send a CR as a CR followed by a NULL instead of a CR followed by a LF
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Telnet, self).__init__()

                    self.yang_name = "telnet"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                    ])
                    self.transparent = None
                    self._segment_path = lambda: "telnet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Telnet, [u'transparent'], name, value)


            class Transport(Entity):
                """
                Define transport protocols for line
                
                .. attribute:: input
                
                	
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Transport.Input>`
                
                .. attribute:: output
                
                	
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Transport.Output>`
                
                .. attribute:: preferred
                
                	Specify the preferred protocol to use
                	**type**\:  :py:class:`Preferred <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Transport.Preferred>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.Transport, self).__init__()

                    self.yang_name = "transport"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Line.Console.Transport.Input)), ("output", ("output", Native.Line.Console.Transport.Output)), ("preferred", ("preferred", Native.Line.Console.Transport.Preferred))])
                    self._leafs = OrderedDict()

                    self.input = Native.Line.Console.Transport.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Line.Console.Transport.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"

                    self.preferred = None
                    self._children_name_map["preferred"] = "preferred"
                    self._segment_path = lambda: "transport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.Transport, [], name, value)


                class Input(Entity):
                    """
                    
                    
                    .. attribute:: input
                    
                    	Define which protocols to use when connecting to the terminal server
                    	**type**\: list of   :py:class:`Input_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Transport.Input.Input_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.Transport.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeafList(YType.enumeration, 'input'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Console.Transport.Input.Input_')])),
                        ])
                        self.input = []
                        self._segment_path = lambda: "input"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.Transport.Input, [u'input'], name, value)

                    class Input_(Enum):
                        """
                        Input\_ (Enum Class)

                        Define which protocols to use when connecting to the terminal server

                        .. data:: acercon = 0

                        .. data:: all = 1

                        .. data:: lapb_ta = 2

                        .. data:: lat = 3

                        .. data:: mop = 4

                        .. data:: nasi = 5

                        .. data:: none = 6

                        .. data:: pad = 7

                        .. data:: rlogin = 8

                        .. data:: ssh = 9

                        .. data:: telnet = 10

                        .. data:: udptn = 11

                        .. data:: v120 = 12

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        all = Enum.YLeaf(1, "all")

                        lapb_ta = Enum.YLeaf(2, "lapb-ta")

                        lat = Enum.YLeaf(3, "lat")

                        mop = Enum.YLeaf(4, "mop")

                        nasi = Enum.YLeaf(5, "nasi")

                        none = Enum.YLeaf(6, "none")

                        pad = Enum.YLeaf(7, "pad")

                        rlogin = Enum.YLeaf(8, "rlogin")

                        ssh = Enum.YLeaf(9, "ssh")

                        telnet = Enum.YLeaf(10, "telnet")

                        udptn = Enum.YLeaf(11, "udptn")

                        v120 = Enum.YLeaf(12, "v120")



                class Output(Entity):
                    """
                    
                    
                    .. attribute:: output
                    
                    	Define which protocols to use for outgoing connections
                    	**type**\: list of   :py:class:`Output_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Transport.Output.Output_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.Transport.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('output', (YLeafList(YType.enumeration, 'output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Console.Transport.Output.Output_')])),
                        ])
                        self.output = []
                        self._segment_path = lambda: "output"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.Transport.Output, [u'output'], name, value)

                    class Output_(Enum):
                        """
                        Output\_ (Enum Class)

                        Define which protocols to use for outgoing connections

                        .. data:: acercon = 0

                        .. data:: all = 1

                        .. data:: lapb_ta = 2

                        .. data:: lat = 3

                        .. data:: mop = 4

                        .. data:: nasi = 5

                        .. data:: none = 6

                        .. data:: pad = 7

                        .. data:: rlogin = 8

                        .. data:: ssh = 9

                        .. data:: telnet = 10

                        .. data:: udptn = 11

                        .. data:: v120 = 12

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        all = Enum.YLeaf(1, "all")

                        lapb_ta = Enum.YLeaf(2, "lapb-ta")

                        lat = Enum.YLeaf(3, "lat")

                        mop = Enum.YLeaf(4, "mop")

                        nasi = Enum.YLeaf(5, "nasi")

                        none = Enum.YLeaf(6, "none")

                        pad = Enum.YLeaf(7, "pad")

                        rlogin = Enum.YLeaf(8, "rlogin")

                        ssh = Enum.YLeaf(9, "ssh")

                        telnet = Enum.YLeaf(10, "telnet")

                        udptn = Enum.YLeaf(11, "udptn")

                        v120 = Enum.YLeaf(12, "v120")



                class Preferred(Entity):
                    """
                    Specify the preferred protocol to use
                    
                    .. attribute:: protocol
                    
                    	
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Console.Transport.Preferred.Protocol>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Console.Transport.Preferred, self).__init__()

                        self.yang_name = "preferred"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Console.Transport.Preferred.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "preferred"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Console.Transport.Preferred, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        .. data:: acercon = 0

                        .. data:: lat = 1

                        .. data:: mop = 2

                        .. data:: nasi = 3

                        .. data:: none = 4

                        .. data:: pad = 5

                        .. data:: rlogin = 6

                        .. data:: ssh = 7

                        .. data:: telnet = 8

                        .. data:: udptn = 9

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        lat = Enum.YLeaf(1, "lat")

                        mop = Enum.YLeaf(2, "mop")

                        nasi = Enum.YLeaf(3, "nasi")

                        none = Enum.YLeaf(4, "none")

                        pad = Enum.YLeaf(5, "pad")

                        rlogin = Enum.YLeaf(6, "rlogin")

                        ssh = Enum.YLeaf(7, "ssh")

                        telnet = Enum.YLeaf(8, "telnet")

                        udptn = Enum.YLeaf(9, "udptn")



            class UsbInactivityTimeout(Entity):
                """
                Inactivity timeout for USB media type
                
                .. attribute:: switch
                
                	Switch Number
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Console.UsbInactivityTimeout, self).__init__()

                    self.yang_name = "usb-inactivity-timeout"
                    self.yang_parent_name = "console"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switch', (YLeaf(YType.empty, 'switch'), ['Empty'])),
                    ])
                    self.switch = None
                    self._segment_path = lambda: "usb-inactivity-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Console.UsbInactivityTimeout, [u'switch'], name, value)


        class Vty(Entity):
            """
            Virtual terminal
            
            .. attribute:: first  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..1869
            
            .. attribute:: last
            
            	
            	**type**\: int
            
            	**range:** 1..1869
            
            .. attribute:: authorization
            
            	Authorization parameters
            	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Authorization>`
            
            .. attribute:: access_class
            
            	Filter connections based on an IP access list
            	**type**\:  :py:class:`AccessClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.AccessClass>`
            
            .. attribute:: no_activation_character
            
            	
            	**type**\: bool
            
            .. attribute:: activation_character
            
            	Define the activation character
            	**type**\: union of the below types:
            
            		**type**\: str
            
            		**type**\: int
            
            			**range:** 0..127
            
            .. attribute:: autocommand
            
            	Automatically execute an EXEC command
            	**type**\:  :py:class:`Autocommand <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Autocommand>`
            
            .. attribute:: autocommand_options
            
            	Autocommand options
            	**type**\:  :py:class:`AutocommandOptions <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.AutocommandOptions>`
            
            	**presence node**\: True
            
            .. attribute:: data_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: databits
            
            	Set number of data bits per character
            	**type**\:  :py:class:`Databits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Databits>`
            
            .. attribute:: domain_lookup
            
            	Enable domain lookups in show commands
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: editing
            
            	Enable command line editing
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: escape_character
            
            	Change the current line's escape character
            	**type**\:  :py:class:`EscapeCharacter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.EscapeCharacter>`
            
            .. attribute:: no_exec
            
            	
            	**type**\:  :py:class:`NoExec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.NoExec>`
            
            .. attribute:: exec_
            
            	
            	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Exec>`
            
            .. attribute:: exec_banner
            
            	Enable the display of the EXEC banner
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: exec_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: exec_timeout
            
            	Set the EXEC timeout
            	**type**\:  :py:class:`ExecTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.ExecTimeout>`
            
            .. attribute:: flowcontrol
            
            	Set the flow control
            	**type**\:  :py:class:`Flowcontrol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Flowcontrol>`
            
            .. attribute:: full_help
            
            	Provide help to unprivileged user
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: history
            
            	Enable and control the command history function
            	**type**\:  :py:class:`History <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.History>`
            
            	**presence node**\: True
            
            .. attribute:: international
            
            	Enable international 8\-bit character support
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ip
            
            	IP options
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Ip>`
            
            .. attribute:: ipv6
            
            	
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Ipv6>`
            
            .. attribute:: length
            
            	Set number of lines on a screen
            	**type**\: int
            
            	**range:** 0..512
            
            .. attribute:: line
            
            	
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: location
            
            	One text line describing the terminal's location
            	**type**\: str
            
            .. attribute:: logging
            
            	Modify message logging facilities
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Logging>`
            
            .. attribute:: login
            
            	Enable password checking
            	**type**\:  :py:class:`Login <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Login>`
            
            	**presence node**\: True
            
            .. attribute:: media_type
            
            	Console connection media type
            	**type**\:  :py:class:`MediaType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.MediaType>`
            
            .. attribute:: modem
            
            	Configure the Modem Control Lines
            	**type**\:  :py:class:`Modem <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Modem>`
            
            .. attribute:: monitor
            
            	Copy debug output to the current terminal line
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: motd_banner
            
            	Enable the display of the MOTD banner
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: notify
            
            	Inform users of output from concurrent sessions
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: padding
            
            	Set padding for a specified output character
            	**type**\:  :py:class:`Padding <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Padding>`
            
            .. attribute:: parity
            
            	Set terminal parity
            	**type**\:  :py:class:`Parity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Parity>`
            
            .. attribute:: password
            
            	Set a password
            	**type**\:  :py:class:`Password <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Password>`
            
            .. attribute:: prc
            
            	PRC commands
            	**type**\:  :py:class:`Prc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Prc>`
            
            .. attribute:: privilege
            
            	Change privilege level for line
            	**type**\:  :py:class:`Privilege <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Privilege>`
            
            .. attribute:: rotary
            
            	Rotary group to add line to
            	**type**\: int
            
            	**range:** 1..99
            
            .. attribute:: rxspeed
            
            	Receive speed
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_limit
            
            	Set maximum number of sessions
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_timeout
            
            	Set interval for closing connection when there is no input traffic
            	**type**\:  :py:class:`SessionTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.SessionTimeout>`
            
            .. attribute:: special_character_bits
            
            	Bits per character
            	**type**\: int
            
            	**range:** 7..8
            
            .. attribute:: speed
            
            	Transmit and receive speeds
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: start_character
            
            	Define the start character
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..255
            
            		**type**\: str
            
            .. attribute:: stop_character
            
            	Define the stop character
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 0..255
            
            		**type**\: str
            
            .. attribute:: stopbits
            
            	Set async line stop bits
            	**type**\:  :py:class:`Stopbits <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Stopbits>`
            
            .. attribute:: terminal_type
            
            	Terminal type
            	**type**\: str
            
            .. attribute:: timeout
            
            	Timeouts for the line
            	**type**\:  :py:class:`Timeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Timeout>`
            
            .. attribute:: telnet
            
            	Telnet protocol\-specific configuration
            	**type**\:  :py:class:`Telnet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Telnet>`
            
            .. attribute:: transport
            
            	Define transport protocols for line
            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Transport>`
            
            .. attribute:: txspeed
            
            	Transmit speed
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: usb_inactivity_timeout
            
            	Inactivity timeout for USB media type
            	**type**\:  :py:class:`UsbInactivityTimeout <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.UsbInactivityTimeout>`
            
            .. attribute:: width
            
            	Number of characters on a screen line
            	**type**\: int
            
            	**range:** 0..512
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Line.Vty, self).__init__()

                self.yang_name = "vty"
                self.yang_parent_name = "line"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['first']
                self._child_classes = OrderedDict([("authorization", ("authorization", Native.Line.Vty.Authorization)), ("access-class", ("access_class", Native.Line.Vty.AccessClass)), ("autocommand", ("autocommand", Native.Line.Vty.Autocommand)), ("autocommand-options", ("autocommand_options", Native.Line.Vty.AutocommandOptions)), ("databits", ("databits", Native.Line.Vty.Databits)), ("escape-character", ("escape_character", Native.Line.Vty.EscapeCharacter)), ("no-exec", ("no_exec", Native.Line.Vty.NoExec)), ("exec", ("exec_", Native.Line.Vty.Exec)), ("exec-timeout", ("exec_timeout", Native.Line.Vty.ExecTimeout)), ("flowcontrol", ("flowcontrol", Native.Line.Vty.Flowcontrol)), ("history", ("history", Native.Line.Vty.History)), ("ip", ("ip", Native.Line.Vty.Ip)), ("ipv6", ("ipv6", Native.Line.Vty.Ipv6)), ("logging", ("logging", Native.Line.Vty.Logging)), ("login", ("login", Native.Line.Vty.Login)), ("media-type", ("media_type", Native.Line.Vty.MediaType)), ("modem", ("modem", Native.Line.Vty.Modem)), ("padding", ("padding", Native.Line.Vty.Padding)), ("parity", ("parity", Native.Line.Vty.Parity)), ("password", ("password", Native.Line.Vty.Password)), ("prc", ("prc", Native.Line.Vty.Prc)), ("privilege", ("privilege", Native.Line.Vty.Privilege)), ("session-timeout", ("session_timeout", Native.Line.Vty.SessionTimeout)), ("timeout", ("timeout", Native.Line.Vty.Timeout)), ("telnet", ("telnet", Native.Line.Vty.Telnet)), ("transport", ("transport", Native.Line.Vty.Transport)), ("usb-inactivity-timeout", ("usb_inactivity_timeout", Native.Line.Vty.UsbInactivityTimeout))])
                self._leafs = OrderedDict([
                    ('first', (YLeaf(YType.uint16, 'first'), ['int'])),
                    ('last', (YLeaf(YType.uint16, 'last'), ['int'])),
                    ('no_activation_character', (YLeaf(YType.boolean, 'no-activation-character'), ['bool'])),
                    ('activation_character', (YLeaf(YType.str, 'activation-character'), ['str','int'])),
                    ('data_character_bits', (YLeaf(YType.uint8, 'data-character-bits'), ['int'])),
                    ('domain_lookup', (YLeaf(YType.empty, 'domain-lookup'), ['Empty'])),
                    ('editing', (YLeaf(YType.empty, 'editing'), ['Empty'])),
                    ('exec_banner', (YLeaf(YType.empty, 'exec-banner'), ['Empty'])),
                    ('exec_character_bits', (YLeaf(YType.uint8, 'exec-character-bits'), ['int'])),
                    ('full_help', (YLeaf(YType.empty, 'full-help'), ['Empty'])),
                    ('international', (YLeaf(YType.empty, 'international'), ['Empty'])),
                    ('length', (YLeaf(YType.uint16, 'length'), ['int'])),
                    ('line', (YLeaf(YType.uint8, 'line'), ['int'])),
                    ('location', (YLeaf(YType.str, 'location'), ['str'])),
                    ('monitor', (YLeaf(YType.empty, 'monitor'), ['Empty'])),
                    ('motd_banner', (YLeaf(YType.empty, 'motd-banner'), ['Empty'])),
                    ('notify', (YLeaf(YType.empty, 'notify'), ['Empty'])),
                    ('rotary', (YLeaf(YType.uint8, 'rotary'), ['int'])),
                    ('rxspeed', (YLeaf(YType.uint32, 'rxspeed'), ['int'])),
                    ('session_limit', (YLeaf(YType.uint32, 'session-limit'), ['int'])),
                    ('special_character_bits', (YLeaf(YType.uint8, 'special-character-bits'), ['int'])),
                    ('speed', (YLeaf(YType.uint32, 'speed'), ['int'])),
                    ('start_character', (YLeaf(YType.str, 'start-character'), ['int','str'])),
                    ('stop_character', (YLeaf(YType.str, 'stop-character'), ['int','str'])),
                    ('stopbits', (YLeaf(YType.enumeration, 'stopbits'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.Stopbits')])),
                    ('terminal_type', (YLeaf(YType.str, 'terminal-type'), ['str'])),
                    ('txspeed', (YLeaf(YType.uint32, 'txspeed'), ['int'])),
                    ('width', (YLeaf(YType.uint16, 'width'), ['int'])),
                ])
                self.first = None
                self.last = None
                self.no_activation_character = None
                self.activation_character = None
                self.data_character_bits = None
                self.domain_lookup = None
                self.editing = None
                self.exec_banner = None
                self.exec_character_bits = None
                self.full_help = None
                self.international = None
                self.length = None
                self.line = None
                self.location = None
                self.monitor = None
                self.motd_banner = None
                self.notify = None
                self.rotary = None
                self.rxspeed = None
                self.session_limit = None
                self.special_character_bits = None
                self.speed = None
                self.start_character = None
                self.stop_character = None
                self.stopbits = None
                self.terminal_type = None
                self.txspeed = None
                self.width = None

                self.authorization = Native.Line.Vty.Authorization()
                self.authorization.parent = self
                self._children_name_map["authorization"] = "authorization"

                self.access_class = Native.Line.Vty.AccessClass()
                self.access_class.parent = self
                self._children_name_map["access_class"] = "access-class"

                self.autocommand = Native.Line.Vty.Autocommand()
                self.autocommand.parent = self
                self._children_name_map["autocommand"] = "autocommand"

                self.autocommand_options = None
                self._children_name_map["autocommand_options"] = "autocommand-options"

                self.databits = Native.Line.Vty.Databits()
                self.databits.parent = self
                self._children_name_map["databits"] = "databits"

                self.escape_character = Native.Line.Vty.EscapeCharacter()
                self.escape_character.parent = self
                self._children_name_map["escape_character"] = "escape-character"

                self.no_exec = Native.Line.Vty.NoExec()
                self.no_exec.parent = self
                self._children_name_map["no_exec"] = "no-exec"

                self.exec_ = Native.Line.Vty.Exec()
                self.exec_.parent = self
                self._children_name_map["exec_"] = "exec"

                self.exec_timeout = Native.Line.Vty.ExecTimeout()
                self.exec_timeout.parent = self
                self._children_name_map["exec_timeout"] = "exec-timeout"

                self.flowcontrol = Native.Line.Vty.Flowcontrol()
                self.flowcontrol.parent = self
                self._children_name_map["flowcontrol"] = "flowcontrol"

                self.history = None
                self._children_name_map["history"] = "history"

                self.ip = Native.Line.Vty.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"

                self.ipv6 = Native.Line.Vty.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.logging = Native.Line.Vty.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.login = None
                self._children_name_map["login"] = "login"

                self.media_type = Native.Line.Vty.MediaType()
                self.media_type.parent = self
                self._children_name_map["media_type"] = "media-type"

                self.modem = Native.Line.Vty.Modem()
                self.modem.parent = self
                self._children_name_map["modem"] = "modem"

                self.padding = Native.Line.Vty.Padding()
                self.padding.parent = self
                self._children_name_map["padding"] = "padding"

                self.parity = Native.Line.Vty.Parity()
                self.parity.parent = self
                self._children_name_map["parity"] = "parity"

                self.password = Native.Line.Vty.Password()
                self.password.parent = self
                self._children_name_map["password"] = "password"

                self.prc = Native.Line.Vty.Prc()
                self.prc.parent = self
                self._children_name_map["prc"] = "prc"

                self.privilege = Native.Line.Vty.Privilege()
                self.privilege.parent = self
                self._children_name_map["privilege"] = "privilege"

                self.session_timeout = Native.Line.Vty.SessionTimeout()
                self.session_timeout.parent = self
                self._children_name_map["session_timeout"] = "session-timeout"

                self.timeout = Native.Line.Vty.Timeout()
                self.timeout.parent = self
                self._children_name_map["timeout"] = "timeout"

                self.telnet = Native.Line.Vty.Telnet()
                self.telnet.parent = self
                self._children_name_map["telnet"] = "telnet"

                self.transport = Native.Line.Vty.Transport()
                self.transport.parent = self
                self._children_name_map["transport"] = "transport"

                self.usb_inactivity_timeout = Native.Line.Vty.UsbInactivityTimeout()
                self.usb_inactivity_timeout.parent = self
                self._children_name_map["usb_inactivity_timeout"] = "usb-inactivity-timeout"
                self._segment_path = lambda: "vty" + "[first='" + str(self.first) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/line/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Line.Vty, [u'first', u'last', u'no_activation_character', u'activation_character', u'data_character_bits', u'domain_lookup', u'editing', u'exec_banner', u'exec_character_bits', u'full_help', u'international', u'length', u'line', u'location', u'monitor', u'motd_banner', u'notify', u'rotary', u'rxspeed', u'session_limit', u'special_character_bits', u'speed', u'start_character', u'stop_character', u'stopbits', u'terminal_type', u'txspeed', u'width'], name, value)

            class Stopbits(Enum):
                """
                Stopbits (Enum Class)

                Set async line stop bits

                .. data:: Y_1 = 0

                .. data:: Y_1__DOT__5 = 1

                .. data:: Y_2 = 2

                """

                Y_1 = Enum.YLeaf(0, "1")

                Y_1__DOT__5 = Enum.YLeaf(1, "1.5")

                Y_2 = Enum.YLeaf(2, "2")



            class Authorization(Entity):
                """
                Authorization parameters
                
                .. attribute:: command
                
                	For exec (shell) commands
                	**type**\:  :py:class:`Command <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Authorization.Command>`
                
                .. attribute:: exec_
                
                	For starting an exec (shell)
                	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Authorization.Exec>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Authorization, self).__init__()

                    self.yang_name = "authorization"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("command", ("command", Native.Line.Vty.Authorization.Command)), ("exec", ("exec_", Native.Line.Vty.Authorization.Exec))])
                    self._leafs = OrderedDict()

                    self.command = Native.Line.Vty.Authorization.Command()
                    self.command.parent = self
                    self._children_name_map["command"] = "command"

                    self.exec_ = Native.Line.Vty.Authorization.Exec()
                    self.exec_.parent = self
                    self._children_name_map["exec_"] = "exec"
                    self._segment_path = lambda: "authorization"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Authorization, [], name, value)


                class Command(Entity):
                    """
                    For exec (shell) commands
                    
                    .. attribute:: enable_level
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..15
                    
                    .. attribute:: auth_name
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.Authorization.Command, self).__init__()

                        self.yang_name = "command"
                        self.yang_parent_name = "authorization"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable_level', (YLeaf(YType.uint8, 'enable-level'), ['int'])),
                            ('auth_name', (YLeaf(YType.str, 'auth-name'), ['str'])),
                        ])
                        self.enable_level = None
                        self.auth_name = None
                        self._segment_path = lambda: "command"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.Authorization.Command, [u'enable_level', u'auth_name'], name, value)


                class Exec(Entity):
                    """
                    For starting an exec (shell)
                    
                    .. attribute:: authorization_name
                    
                    	Use an authorization list with this name
                    	**type**\: str
                    
                    .. attribute:: default
                    
                    	Use the default authorization list
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.Authorization.Exec, self).__init__()

                        self.yang_name = "exec"
                        self.yang_parent_name = "authorization"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('authorization_name', (YLeaf(YType.str, 'authorization-name'), ['str'])),
                            ('default', (YLeaf(YType.empty, 'default'), ['Empty'])),
                        ])
                        self.authorization_name = None
                        self.default = None
                        self._segment_path = lambda: "exec"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.Authorization.Exec, [u'authorization_name', u'default'], name, value)


            class AccessClass(Entity):
                """
                Filter connections based on an IP access list
                
                .. attribute:: acccess_list
                
                	
                	**type**\: list of  		 :py:class:`AcccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.AccessClass.AcccessList>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.AccessClass, self).__init__()

                    self.yang_name = "access-class"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("acccess-list", ("acccess_list", Native.Line.Vty.AccessClass.AcccessList))])
                    self._leafs = OrderedDict()

                    self.acccess_list = YList(self)
                    self._segment_path = lambda: "access-class"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.AccessClass, [], name, value)


                class AcccessList(Entity):
                    """
                    
                    
                    .. attribute:: direction  (key)
                    
                    	
                    	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.AccessClass.AcccessList.Direction>`
                    
                    .. attribute:: access_list
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..199 \| 1300..2699
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    	**mandatory**\: True
                    
                    .. attribute:: vrf_also
                    
                    	Same access list is applied for all VRFs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.AccessClass.AcccessList, self).__init__()

                        self.yang_name = "acccess-list"
                        self.yang_parent_name = "access-class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['direction']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.AccessClass.AcccessList.Direction')])),
                            ('access_list', (YLeaf(YType.str, 'access-list'), ['int','str'])),
                            ('vrf_also', (YLeaf(YType.empty, 'vrf-also'), ['Empty'])),
                        ])
                        self.direction = None
                        self.access_list = None
                        self.vrf_also = None
                        self._segment_path = lambda: "acccess-list" + "[direction='" + str(self.direction) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.AccessClass.AcccessList, [u'direction', u'access_list', u'vrf_also'], name, value)

                    class Direction(Enum):
                        """
                        Direction (Enum Class)

                        .. data:: in_ = 0

                        .. data:: out = 1

                        """

                        in_ = Enum.YLeaf(0, "in")

                        out = Enum.YLeaf(1, "out")



            class Autocommand(Entity):
                """
                Automatically execute an EXEC command
                
                .. attribute:: line
                
                	Appropriate EXEC command
                	**type**\: str
                
                .. attribute:: no_suppress_linenumber
                
                	Display service linenumber message
                	**type**\:  :py:class:`NoSuppressLinenumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Autocommand.NoSuppressLinenumber>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Autocommand, self).__init__()

                    self.yang_name = "autocommand"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("no-suppress-linenumber", ("no_suppress_linenumber", Native.Line.Vty.Autocommand.NoSuppressLinenumber))])
                    self._leafs = OrderedDict([
                        ('line', (YLeaf(YType.str, 'line'), ['str'])),
                    ])
                    self.line = None

                    self.no_suppress_linenumber = None
                    self._children_name_map["no_suppress_linenumber"] = "no-suppress-linenumber"
                    self._segment_path = lambda: "autocommand"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Autocommand, [u'line'], name, value)


                class NoSuppressLinenumber(Entity):
                    """
                    Display service linenumber message
                    
                    .. attribute:: line
                    
                    	Appropriate EXEC command
                    	**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.Autocommand.NoSuppressLinenumber, self).__init__()

                        self.yang_name = "no-suppress-linenumber"
                        self.yang_parent_name = "autocommand"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('line', (YLeaf(YType.str, 'line'), ['str'])),
                        ])
                        self.line = None
                        self._segment_path = lambda: "no-suppress-linenumber"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.Autocommand.NoSuppressLinenumber, [u'line'], name, value)


            class AutocommandOptions(Entity):
                """
                Autocommand options
                
                .. attribute:: abort_character
                
                	Autocommand abort character
                	**type**\:  :py:class:`AbortCharacter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.AutocommandOptions.AbortCharacter>`
                
                	**presence node**\: True
                
                .. attribute:: delay
                
                	Delay autocommand execution
                	**type**\:  :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.AutocommandOptions.Delay>`
                
                	**presence node**\: True
                
                .. attribute:: nohangup
                
                	No hangup after autocommand completion
                	**type**\:  :py:class:`Nohangup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.AutocommandOptions.Nohangup>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.AutocommandOptions, self).__init__()

                    self.yang_name = "autocommand-options"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("abort-character", ("abort_character", Native.Line.Vty.AutocommandOptions.AbortCharacter)), ("delay", ("delay", Native.Line.Vty.AutocommandOptions.Delay)), ("nohangup", ("nohangup", Native.Line.Vty.AutocommandOptions.Nohangup))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.abort_character = None
                    self._children_name_map["abort_character"] = "abort-character"

                    self.delay = None
                    self._children_name_map["delay"] = "delay"

                    self.nohangup = None
                    self._children_name_map["nohangup"] = "nohangup"
                    self._segment_path = lambda: "autocommand-options"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.AutocommandOptions, [], name, value)


                class AbortCharacter(Entity):
                    """
                    Autocommand abort character
                    
                    .. attribute:: character
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 0..255
                    
                    		**type**\: str
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.AutocommandOptions.AbortCharacter, self).__init__()

                        self.yang_name = "abort-character"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('character', (YLeaf(YType.str, 'character'), ['int','str'])),
                        ])
                        self.character = None
                        self._segment_path = lambda: "abort-character"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.AutocommandOptions.AbortCharacter, [u'character'], name, value)


                class Delay(Entity):
                    """
                    Delay autocommand execution
                    
                    .. attribute:: time
                    
                    	Time in seconds
                    	**type**\: int
                    
                    	**range:** 0..120
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.AutocommandOptions.Delay, self).__init__()

                        self.yang_name = "delay"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('time', (YLeaf(YType.uint8, 'time'), ['int'])),
                        ])
                        self.time = None
                        self._segment_path = lambda: "delay"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.AutocommandOptions.Delay, [u'time'], name, value)


                class Nohangup(Entity):
                    """
                    No hangup after autocommand completion
                    
                    .. attribute:: abort_character
                    
                    	Autocommand abort character
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: delay
                    
                    	Delay autocommand execution
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.AutocommandOptions.Nohangup, self).__init__()

                        self.yang_name = "nohangup"
                        self.yang_parent_name = "autocommand-options"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('abort_character', (YLeaf(YType.empty, 'abort-character'), ['Empty'])),
                            ('delay', (YLeaf(YType.empty, 'delay'), ['Empty'])),
                        ])
                        self.abort_character = None
                        self.delay = None
                        self._segment_path = lambda: "nohangup"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.AutocommandOptions.Nohangup, [u'abort_character', u'delay'], name, value)


            class Databits(Entity):
                """
                Set number of data bits per character
                
                .. attribute:: set_to_5
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_6
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_7
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: set_to_8
                
                	Number of data bits
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Databits, self).__init__()

                    self.yang_name = "databits"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('set_to_5', (YLeaf(YType.empty, 'set-to-5'), ['Empty'])),
                        ('set_to_6', (YLeaf(YType.empty, 'set-to-6'), ['Empty'])),
                        ('set_to_7', (YLeaf(YType.empty, 'set-to-7'), ['Empty'])),
                        ('set_to_8', (YLeaf(YType.empty, 'set-to-8'), ['Empty'])),
                    ])
                    self.set_to_5 = None
                    self.set_to_6 = None
                    self.set_to_7 = None
                    self.set_to_8 = None
                    self._segment_path = lambda: "databits"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Databits, [u'set_to_5', u'set_to_6', u'set_to_7', u'set_to_8'], name, value)


            class EscapeCharacter(Entity):
                """
                Change the current line's escape character
                
                .. attribute:: char
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..255
                
                		**type**\:  :py:class:`Char <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.EscapeCharacter.Char>`
                
                		**type**\: str
                
                .. attribute:: soft
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.EscapeCharacter, self).__init__()

                    self.yang_name = "escape-character"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('char', (YLeaf(YType.str, 'char'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.EscapeCharacter.Char'),'str'])),
                        ('soft', (YLeaf(YType.empty, 'soft'), ['Empty'])),
                    ])
                    self.char = None
                    self.soft = None
                    self._segment_path = lambda: "escape-character"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.EscapeCharacter, [u'char', u'soft'], name, value)

                class Char(Enum):
                    """
                    Char (Enum Class)

                    .. data:: BREAK = 0

                    .. data:: DEFAULT = 1

                    .. data:: NONE = 2

                    """

                    BREAK = Enum.YLeaf(0, "BREAK")

                    DEFAULT = Enum.YLeaf(1, "DEFAULT")

                    NONE = Enum.YLeaf(2, "NONE")



            class NoExec(Entity):
                """
                
                
                .. attribute:: exec_
                
                	Configure EXEC
                	**type**\: bool
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.NoExec, self).__init__()

                    self.yang_name = "no-exec"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('exec_', (YLeaf(YType.boolean, 'exec'), ['bool'])),
                    ])
                    self.exec_ = None
                    self._segment_path = lambda: "no-exec"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.NoExec, [u'exec_'], name, value)


            class Exec(Entity):
                """
                
                
                .. attribute:: prompt
                
                	
                	**type**\:  :py:class:`Prompt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Exec.Prompt>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Exec, self).__init__()

                    self.yang_name = "exec"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("prompt", ("prompt", Native.Line.Vty.Exec.Prompt))])
                    self._leafs = OrderedDict()

                    self.prompt = Native.Line.Vty.Exec.Prompt()
                    self.prompt.parent = self
                    self._children_name_map["prompt"] = "prompt"
                    self._segment_path = lambda: "exec"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Exec, [], name, value)


                class Prompt(Entity):
                    """
                    
                    
                    .. attribute:: timestamp
                    
                    	
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.Exec.Prompt, self).__init__()

                        self.yang_name = "prompt"
                        self.yang_parent_name = "exec"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('timestamp', (YLeaf(YType.empty, 'timestamp'), ['Empty'])),
                        ])
                        self.timestamp = None
                        self._segment_path = lambda: "prompt"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.Exec.Prompt, [u'timestamp'], name, value)


            class ExecTimeout(Entity):
                """
                Set the EXEC timeout
                
                .. attribute:: minutes
                
                	<0\-35791>;;Timeout in minutes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: seconds
                
                	<0\-2147483>;;Timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.ExecTimeout, self).__init__()

                    self.yang_name = "exec-timeout"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('minutes', (YLeaf(YType.uint32, 'minutes'), ['int'])),
                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                    ])
                    self.minutes = None
                    self.seconds = None
                    self._segment_path = lambda: "exec-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.ExecTimeout, [u'minutes', u'seconds'], name, value)


            class Flowcontrol(Entity):
                """
                Set the flow control
                
                .. attribute:: none
                
                	Set no flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hardware
                
                	Set hardware flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: software
                
                	Set software flow control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Flowcontrol, self).__init__()

                    self.yang_name = "flowcontrol"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('none', (YLeaf(YType.empty, 'NONE'), ['Empty'])),
                        ('hardware', (YLeaf(YType.empty, 'hardware'), ['Empty'])),
                        ('software', (YLeaf(YType.empty, 'software'), ['Empty'])),
                    ])
                    self.none = None
                    self.hardware = None
                    self.software = None
                    self._segment_path = lambda: "flowcontrol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Flowcontrol, [u'none', u'hardware', u'software'], name, value)


            class History(Entity):
                """
                Enable and control the command history function
                
                .. attribute:: size
                
                	Set history buffer size
                	**type**\: int
                
                	**range:** 0..256
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.History, self).__init__()

                    self.yang_name = "history"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                    ])
                    self.size = None
                    self._segment_path = lambda: "history"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.History, [u'size'], name, value)


            class Ip(Entity):
                """
                IP options
                
                .. attribute:: netmask_format
                
                	Change display of netmasks
                	**type**\:  :py:class:`NetmaskFormat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Ip.NetmaskFormat>`
                
                	**presence node**\: True
                
                .. attribute:: tcp
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("netmask-format", ("netmask_format", Native.Line.Vty.Ip.NetmaskFormat))])
                    self._leafs = OrderedDict([
                        ('tcp', (YLeaf(YType.empty, 'tcp'), ['Empty'])),
                    ])
                    self.tcp = None

                    self.netmask_format = None
                    self._children_name_map["netmask_format"] = "netmask-format"
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Ip, [u'tcp'], name, value)


                class NetmaskFormat(Entity):
                    """
                    Change display of netmasks
                    
                    .. attribute:: format
                    
                    	
                    	**type**\:  :py:class:`Format <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Ip.NetmaskFormat.Format>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.Ip.NetmaskFormat, self).__init__()

                        self.yang_name = "netmask-format"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('format', (YLeaf(YType.enumeration, 'format'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.Ip.NetmaskFormat.Format')])),
                        ])
                        self.format = None
                        self._segment_path = lambda: "netmask-format"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.Ip.NetmaskFormat, [u'format'], name, value)

                    class Format(Enum):
                        """
                        Format (Enum Class)

                        .. data:: bit_count = 0

                        .. data:: decimal = 1

                        .. data:: hexadecimal = 2

                        """

                        bit_count = Enum.YLeaf(0, "bit-count")

                        decimal = Enum.YLeaf(1, "decimal")

                        hexadecimal = Enum.YLeaf(2, "hexadecimal")



            class Ipv6(Entity):
                """
                
                
                .. attribute:: access_class
                
                	
                	**type**\:  :py:class:`AccessClass <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Ipv6.AccessClass>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("access-class", ("access_class", Native.Line.Vty.Ipv6.AccessClass))])
                    self._leafs = OrderedDict()

                    self.access_class = Native.Line.Vty.Ipv6.AccessClass()
                    self.access_class.parent = self
                    self._children_name_map["access_class"] = "access-class"
                    self._segment_path = lambda: "ipv6"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Ipv6, [], name, value)


                class AccessClass(Entity):
                    """
                    
                    
                    .. attribute:: access_class
                    
                    	
                    	**type**\: list of  		 :py:class:`AccessClass_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Ipv6.AccessClass.AccessClass_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.Ipv6.AccessClass, self).__init__()

                        self.yang_name = "access-class"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("access-class", ("access_class", Native.Line.Vty.Ipv6.AccessClass.AccessClass_))])
                        self._leafs = OrderedDict()

                        self.access_class = YList(self)
                        self._segment_path = lambda: "access-class"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.Ipv6.AccessClass, [], name, value)


                    class AccessClass_(Entity):
                        """
                        
                        
                        .. attribute:: access_class_name  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: enumeration_in_out
                        
                        	
                        	**type**\:  :py:class:`EnumerationInOut <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Ipv6.AccessClass.AccessClass_.EnumerationInOut>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Line.Vty.Ipv6.AccessClass.AccessClass_, self).__init__()

                            self.yang_name = "access-class"
                            self.yang_parent_name = "access-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['access_class_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('access_class_name', (YLeaf(YType.str, 'access-class-name'), ['str'])),
                                ('enumeration_in_out', (YLeaf(YType.enumeration, 'enumeration-in-out'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.Ipv6.AccessClass.AccessClass_.EnumerationInOut')])),
                            ])
                            self.access_class_name = None
                            self.enumeration_in_out = None
                            self._segment_path = lambda: "access-class" + "[access-class-name='" + str(self.access_class_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Line.Vty.Ipv6.AccessClass.AccessClass_, [u'access_class_name', u'enumeration_in_out'], name, value)

                        class EnumerationInOut(Enum):
                            """
                            EnumerationInOut (Enum Class)

                            .. data:: in_ = 0

                            .. data:: out = 1

                            """

                            in_ = Enum.YLeaf(0, "in")

                            out = Enum.YLeaf(1, "out")



            class Logging(Entity):
                """
                Modify message logging facilities
                
                .. attribute:: synchronous
                
                	Synchronized message output
                	**type**\:  :py:class:`Synchronous <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Logging.Synchronous>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("synchronous", ("synchronous", Native.Line.Vty.Logging.Synchronous))])
                    self._leafs = OrderedDict()

                    self.synchronous = None
                    self._children_name_map["synchronous"] = "synchronous"
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Logging, [], name, value)


                class Synchronous(Entity):
                    """
                    Synchronized message output
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.Logging.Synchronous, self).__init__()

                        self.yang_name = "synchronous"
                        self.yang_parent_name = "logging"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "synchronous"
                        self._is_frozen = True


            class Login(Entity):
                """
                Enable password checking
                
                .. attribute:: local
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: authentication
                
                	
                	**type**\: str
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Login, self).__init__()

                    self.yang_name = "login"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('local', (YLeaf(YType.empty, 'local'), ['Empty'])),
                        ('authentication', (YLeaf(YType.str, 'authentication'), ['str'])),
                    ])
                    self.local = None
                    self.authentication = None
                    self._segment_path = lambda: "login"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Login, [u'local', u'authentication'], name, value)


            class MediaType(Entity):
                """
                Console connection media type
                
                .. attribute:: rj45
                
                	Console connection set to RJ45
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.MediaType, self).__init__()

                    self.yang_name = "media-type"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('rj45', (YLeaf(YType.empty, 'rj45'), ['Empty'])),
                    ])
                    self.rj45 = None
                    self._segment_path = lambda: "media-type"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.MediaType, [u'rj45'], name, value)


            class Modem(Entity):
                """
                Configure the Modem Control Lines
                
                .. attribute:: cts_alarm
                
                	Alarm device which only uses CTS for call control
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dtr_active
                
                	Leave DTR low unless line has an active incoming connection or EXEC
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dialin
                
                	Configure line for a modern dial\-in modem
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: host
                
                	Devices that expect an incoming modem call
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: inout
                
                	Configure line for incoming AND outgoing use of modem
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: printer
                
                	Devices that require DSR/CD active
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: answer_timeout
                
                	Set interval between raising DTR and CTS response
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: dtr_delay
                
                	Set interval during which DTR is held low
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Modem, self).__init__()

                    self.yang_name = "modem"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('cts_alarm', (YLeaf(YType.empty, 'CTS-Alarm'), ['Empty'])),
                        ('dtr_active', (YLeaf(YType.empty, 'DTR-active'), ['Empty'])),
                        ('dialin', (YLeaf(YType.empty, 'Dialin'), ['Empty'])),
                        ('host', (YLeaf(YType.empty, 'Host'), ['Empty'])),
                        ('inout', (YLeaf(YType.empty, 'InOut'), ['Empty'])),
                        ('printer', (YLeaf(YType.empty, 'Printer'), ['Empty'])),
                        ('answer_timeout', (YLeaf(YType.empty, 'answer-timeout'), ['Empty'])),
                        ('dtr_delay', (YLeaf(YType.empty, 'dtr-delay'), ['Empty'])),
                    ])
                    self.cts_alarm = None
                    self.dtr_active = None
                    self.dialin = None
                    self.host = None
                    self.inout = None
                    self.printer = None
                    self.answer_timeout = None
                    self.dtr_delay = None
                    self._segment_path = lambda: "modem"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Modem, [u'cts_alarm', u'dtr_active', u'dialin', u'host', u'inout', u'printer', u'answer_timeout', u'dtr_delay'], name, value)


            class Padding(Entity):
                """
                Set padding for a specified output character
                
                .. attribute:: character
                
                	Character to be padded
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 0..127
                
                		**type**\: str
                
                .. attribute:: null
                
                	
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Padding, self).__init__()

                    self.yang_name = "padding"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('character', (YLeaf(YType.str, 'character'), ['int','str'])),
                        ('null', (YLeaf(YType.uint8, 'null'), ['int'])),
                    ])
                    self.character = None
                    self.null = None
                    self._segment_path = lambda: "padding"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Padding, [u'character', u'null'], name, value)


            class Parity(Entity):
                """
                Set terminal parity
                
                .. attribute:: even
                
                	Even parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: mark
                
                	Mark parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: none
                
                	No parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: odd
                
                	Odd parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: space
                
                	Space parity
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Parity, self).__init__()

                    self.yang_name = "parity"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('even', (YLeaf(YType.empty, 'even'), ['Empty'])),
                        ('mark', (YLeaf(YType.empty, 'mark'), ['Empty'])),
                        ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                        ('odd', (YLeaf(YType.empty, 'odd'), ['Empty'])),
                        ('space', (YLeaf(YType.empty, 'space'), ['Empty'])),
                    ])
                    self.even = None
                    self.mark = None
                    self.none = None
                    self.odd = None
                    self.space = None
                    self._segment_path = lambda: "parity"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Parity, [u'even', u'mark', u'none', u'odd', u'space'], name, value)


            class Password(Entity):
                """
                Set a password
                
                .. attribute:: level
                
                	Set exec level password
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: type
                
                	
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Password.Type>`
                
                .. attribute:: secret
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Password, self).__init__()

                    self.yang_name = "password"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('level', (YLeaf(YType.uint8, 'level'), ['int'])),
                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.Password.Type')])),
                        ('secret', (YLeaf(YType.str, 'secret'), ['str'])),
                    ])
                    self.level = None
                    self.type = None
                    self.secret = None
                    self._segment_path = lambda: "password"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Password, [u'level', u'type', u'secret'], name, value)

                class Type(Enum):
                    """
                    Type (Enum Class)

                    .. data:: Y_0 = 0

                    .. data:: Y_7 = 1

                    """

                    Y_0 = Enum.YLeaf(0, "0")

                    Y_7 = Enum.YLeaf(1, "7")



            class Prc(Entity):
                """
                PRC commands
                
                .. attribute:: expose
                
                	Expose PRC data
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hide
                
                	Hide PRC data
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Prc, self).__init__()

                    self.yang_name = "prc"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('expose', (YLeaf(YType.empty, 'expose'), ['Empty'])),
                        ('hide', (YLeaf(YType.empty, 'hide'), ['Empty'])),
                    ])
                    self.expose = None
                    self.hide = None
                    self._segment_path = lambda: "prc"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Prc, [u'expose', u'hide'], name, value)


            class Privilege(Entity):
                """
                Change privilege level for line
                
                .. attribute:: level
                
                	Assign default privilege level for line
                	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Privilege.Level>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Privilege, self).__init__()

                    self.yang_name = "privilege"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Native.Line.Vty.Privilege.Level))])
                    self._leafs = OrderedDict()

                    self.level = None
                    self._children_name_map["level"] = "level"
                    self._segment_path = lambda: "privilege"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Privilege, [], name, value)


                class Level(Entity):
                    """
                    Assign default privilege level for line
                    
                    .. attribute:: number
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..15
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.Privilege.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "privilege"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                        ])
                        self.number = None
                        self._segment_path = lambda: "level"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.Privilege.Level, [u'number'], name, value)


            class SessionTimeout(Entity):
                """
                Set interval for closing connection when there is no input traffic
                
                .. attribute:: session_timeout_value
                
                	
                	**type**\: int
                
                	**range:** 0..35791
                
                .. attribute:: output
                
                	Include output traffic as well as input traffic
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.SessionTimeout, self).__init__()

                    self.yang_name = "session-timeout"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('session_timeout_value', (YLeaf(YType.uint16, 'session-timeout-value'), ['int'])),
                        ('output', (YLeaf(YType.empty, 'output'), ['Empty'])),
                    ])
                    self.session_timeout_value = None
                    self.output = None
                    self._segment_path = lambda: "session-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.SessionTimeout, [u'session_timeout_value', u'output'], name, value)


            class Timeout(Entity):
                """
                Timeouts for the line
                
                .. attribute:: login
                
                	Timeouts related to the login sequence
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Timeout, self).__init__()

                    self.yang_name = "timeout"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('login', (YLeaf(YType.empty, 'login'), ['Empty'])),
                    ])
                    self.login = None
                    self._segment_path = lambda: "timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Timeout, [u'login'], name, value)


            class Telnet(Entity):
                """
                Telnet protocol\-specific configuration
                
                .. attribute:: transparent
                
                	Send a CR as a CR followed by a NULL instead of a CR followed by a LF
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Telnet, self).__init__()

                    self.yang_name = "telnet"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('transparent', (YLeaf(YType.empty, 'transparent'), ['Empty'])),
                    ])
                    self.transparent = None
                    self._segment_path = lambda: "telnet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Telnet, [u'transparent'], name, value)


            class Transport(Entity):
                """
                Define transport protocols for line
                
                .. attribute:: input
                
                	
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Transport.Input>`
                
                .. attribute:: output
                
                	
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Transport.Output>`
                
                .. attribute:: preferred
                
                	Specify the preferred protocol to use
                	**type**\:  :py:class:`Preferred <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Transport.Preferred>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.Transport, self).__init__()

                    self.yang_name = "transport"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Line.Vty.Transport.Input)), ("output", ("output", Native.Line.Vty.Transport.Output)), ("preferred", ("preferred", Native.Line.Vty.Transport.Preferred))])
                    self._leafs = OrderedDict()

                    self.input = Native.Line.Vty.Transport.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Line.Vty.Transport.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"

                    self.preferred = None
                    self._children_name_map["preferred"] = "preferred"
                    self._segment_path = lambda: "transport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.Transport, [], name, value)


                class Input(Entity):
                    """
                    
                    
                    .. attribute:: input
                    
                    	Define which protocols to use when connecting to the terminal server
                    	**type**\: list of   :py:class:`Input_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Transport.Input.Input_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.Transport.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('input', (YLeafList(YType.enumeration, 'input'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.Transport.Input.Input_')])),
                        ])
                        self.input = []
                        self._segment_path = lambda: "input"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.Transport.Input, [u'input'], name, value)

                    class Input_(Enum):
                        """
                        Input\_ (Enum Class)

                        Define which protocols to use when connecting to the terminal server

                        .. data:: acercon = 0

                        .. data:: all = 1

                        .. data:: lapb_ta = 2

                        .. data:: lat = 3

                        .. data:: mop = 4

                        .. data:: nasi = 5

                        .. data:: none = 6

                        .. data:: pad = 7

                        .. data:: rlogin = 8

                        .. data:: ssh = 9

                        .. data:: telnet = 10

                        .. data:: udptn = 11

                        .. data:: v120 = 12

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        all = Enum.YLeaf(1, "all")

                        lapb_ta = Enum.YLeaf(2, "lapb-ta")

                        lat = Enum.YLeaf(3, "lat")

                        mop = Enum.YLeaf(4, "mop")

                        nasi = Enum.YLeaf(5, "nasi")

                        none = Enum.YLeaf(6, "none")

                        pad = Enum.YLeaf(7, "pad")

                        rlogin = Enum.YLeaf(8, "rlogin")

                        ssh = Enum.YLeaf(9, "ssh")

                        telnet = Enum.YLeaf(10, "telnet")

                        udptn = Enum.YLeaf(11, "udptn")

                        v120 = Enum.YLeaf(12, "v120")



                class Output(Entity):
                    """
                    
                    
                    .. attribute:: output
                    
                    	Define which protocols to use for outgoing connections
                    	**type**\: list of   :py:class:`Output_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Transport.Output.Output_>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.Transport.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('output', (YLeafList(YType.enumeration, 'output'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.Transport.Output.Output_')])),
                        ])
                        self.output = []
                        self._segment_path = lambda: "output"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.Transport.Output, [u'output'], name, value)

                    class Output_(Enum):
                        """
                        Output\_ (Enum Class)

                        Define which protocols to use for outgoing connections

                        .. data:: acercon = 0

                        .. data:: all = 1

                        .. data:: lapb_ta = 2

                        .. data:: lat = 3

                        .. data:: mop = 4

                        .. data:: nasi = 5

                        .. data:: none = 6

                        .. data:: pad = 7

                        .. data:: rlogin = 8

                        .. data:: ssh = 9

                        .. data:: telnet = 10

                        .. data:: udptn = 11

                        .. data:: v120 = 12

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        all = Enum.YLeaf(1, "all")

                        lapb_ta = Enum.YLeaf(2, "lapb-ta")

                        lat = Enum.YLeaf(3, "lat")

                        mop = Enum.YLeaf(4, "mop")

                        nasi = Enum.YLeaf(5, "nasi")

                        none = Enum.YLeaf(6, "none")

                        pad = Enum.YLeaf(7, "pad")

                        rlogin = Enum.YLeaf(8, "rlogin")

                        ssh = Enum.YLeaf(9, "ssh")

                        telnet = Enum.YLeaf(10, "telnet")

                        udptn = Enum.YLeaf(11, "udptn")

                        v120 = Enum.YLeaf(12, "v120")



                class Preferred(Entity):
                    """
                    Specify the preferred protocol to use
                    
                    .. attribute:: protocol
                    
                    	
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Line.Vty.Transport.Preferred.Protocol>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Line.Vty.Transport.Preferred, self).__init__()

                        self.yang_name = "preferred"
                        self.yang_parent_name = "transport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Line.Vty.Transport.Preferred.Protocol')])),
                        ])
                        self.protocol = None
                        self._segment_path = lambda: "preferred"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Line.Vty.Transport.Preferred, [u'protocol'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        .. data:: acercon = 0

                        .. data:: lat = 1

                        .. data:: mop = 2

                        .. data:: nasi = 3

                        .. data:: none = 4

                        .. data:: pad = 5

                        .. data:: rlogin = 6

                        .. data:: ssh = 7

                        .. data:: telnet = 8

                        .. data:: udptn = 9

                        """

                        acercon = Enum.YLeaf(0, "acercon")

                        lat = Enum.YLeaf(1, "lat")

                        mop = Enum.YLeaf(2, "mop")

                        nasi = Enum.YLeaf(3, "nasi")

                        none = Enum.YLeaf(4, "none")

                        pad = Enum.YLeaf(5, "pad")

                        rlogin = Enum.YLeaf(6, "rlogin")

                        ssh = Enum.YLeaf(7, "ssh")

                        telnet = Enum.YLeaf(8, "telnet")

                        udptn = Enum.YLeaf(9, "udptn")



            class UsbInactivityTimeout(Entity):
                """
                Inactivity timeout for USB media type
                
                .. attribute:: switch
                
                	Switch Number
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Line.Vty.UsbInactivityTimeout, self).__init__()

                    self.yang_name = "usb-inactivity-timeout"
                    self.yang_parent_name = "vty"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('switch', (YLeaf(YType.empty, 'switch'), ['Empty'])),
                    ])
                    self.switch = None
                    self._segment_path = lambda: "usb-inactivity-timeout"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Line.Vty.UsbInactivityTimeout, [u'switch'], name, value)


    class Ntp(Entity):
        """
        Configure NTP
        
        .. attribute:: access_group
        
        	Control NTP access
        	**type**\:  :py:class:`AccessGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup>`
        
        .. attribute:: allow
        
        	Allow processing of packets
        	**type**\:  :py:class:`Allow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Allow>`
        
        .. attribute:: authenticate
        
        	Authenticate time sources
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: authentication_key
        
        	Authentication key for trusted time sources
        	**type**\: list of  		 :py:class:`AuthenticationKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AuthenticationKey>`
        
        .. attribute:: broadcastdelay
        
        	Estimated round\-trip delay in microseconds
        	**type**\: int
        
        	**range:** 1..999999
        
        .. attribute:: clock_period
        
        	Length of hardware clock tick
        	**type**\: int
        
        	**range:** 0..4294967295
        
        .. attribute:: logging
        
        	Enable NTP message logging
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: master
        
        	Act as NTP master clock
        	**type**\:  :py:class:`Master <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Master>`
        
        	**presence node**\: True
        
        .. attribute:: max_associations
        
        	Set maximum number of associations
        	**type**\: int
        
        	**range:** 0..4294967295
        
        .. attribute:: maxdistance
        
        	Maximum Distance for synchronization
        	**type**\: int
        
        	**range:** 1..16
        
        .. attribute:: mindistance
        
        	Minimum distance to consider for clockhop
        	**type**\: int
        
        	**range:** 1..500
        
        .. attribute:: orphan
        
        	Threshold Stratum for orphan mode
        	**type**\: int
        
        	**range:** 1..16
        
        .. attribute:: panic
        
        	Reject time updates > panic threshold (default 1000Sec)
        	**type**\:  :py:class:`Panic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Panic>`
        
        .. attribute:: passive
        
        	NTP passive mode
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: peer
        
        	Configure NTP peer
        	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Peer>`
        
        .. attribute:: server
        
        	Configure NTP server
        	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Server>`
        
        .. attribute:: source
        
        	Configure interface for source address
        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Source>`
        
        .. attribute:: trusted_key
        
        	Key numbers for trusted time sources
        	**type**\: list of  		 :py:class:`TrustedKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.TrustedKey>`
        
        .. attribute:: update_calendar
        
        	Periodically update calendar with NTP time
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Ntp, self).__init__()

            self.yang_name = "ntp"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-ntp:access-group", ("access_group", Native.Ntp.AccessGroup)), ("Cisco-IOS-XE-ntp:allow", ("allow", Native.Ntp.Allow)), ("Cisco-IOS-XE-ntp:authentication-key", ("authentication_key", Native.Ntp.AuthenticationKey)), ("Cisco-IOS-XE-ntp:master", ("master", Native.Ntp.Master)), ("Cisco-IOS-XE-ntp:panic", ("panic", Native.Ntp.Panic)), ("Cisco-IOS-XE-ntp:peer", ("peer", Native.Ntp.Peer)), ("Cisco-IOS-XE-ntp:server", ("server", Native.Ntp.Server)), ("Cisco-IOS-XE-ntp:source", ("source", Native.Ntp.Source)), ("Cisco-IOS-XE-ntp:trusted-key", ("trusted_key", Native.Ntp.TrustedKey))])
            self._leafs = OrderedDict([
                ('authenticate', (YLeaf(YType.empty, 'Cisco-IOS-XE-ntp:authenticate'), ['Empty'])),
                ('broadcastdelay', (YLeaf(YType.uint32, 'Cisco-IOS-XE-ntp:broadcastdelay'), ['int'])),
                ('clock_period', (YLeaf(YType.uint32, 'Cisco-IOS-XE-ntp:clock-period'), ['int'])),
                ('logging', (YLeaf(YType.empty, 'Cisco-IOS-XE-ntp:logging'), ['Empty'])),
                ('max_associations', (YLeaf(YType.uint32, 'Cisco-IOS-XE-ntp:max-associations'), ['int'])),
                ('maxdistance', (YLeaf(YType.uint8, 'Cisco-IOS-XE-ntp:maxdistance'), ['int'])),
                ('mindistance', (YLeaf(YType.uint16, 'Cisco-IOS-XE-ntp:mindistance'), ['int'])),
                ('orphan', (YLeaf(YType.uint8, 'Cisco-IOS-XE-ntp:orphan'), ['int'])),
                ('passive', (YLeaf(YType.empty, 'Cisco-IOS-XE-ntp:passive'), ['Empty'])),
                ('update_calendar', (YLeaf(YType.empty, 'Cisco-IOS-XE-ntp:update-calendar'), ['Empty'])),
            ])
            self.authenticate = None
            self.broadcastdelay = None
            self.clock_period = None
            self.logging = None
            self.max_associations = None
            self.maxdistance = None
            self.mindistance = None
            self.orphan = None
            self.passive = None
            self.update_calendar = None

            self.access_group = Native.Ntp.AccessGroup()
            self.access_group.parent = self
            self._children_name_map["access_group"] = "Cisco-IOS-XE-ntp:access-group"

            self.allow = Native.Ntp.Allow()
            self.allow.parent = self
            self._children_name_map["allow"] = "Cisco-IOS-XE-ntp:allow"

            self.master = None
            self._children_name_map["master"] = "Cisco-IOS-XE-ntp:master"

            self.panic = Native.Ntp.Panic()
            self.panic.parent = self
            self._children_name_map["panic"] = "Cisco-IOS-XE-ntp:panic"

            self.peer = Native.Ntp.Peer()
            self.peer.parent = self
            self._children_name_map["peer"] = "Cisco-IOS-XE-ntp:peer"

            self.server = Native.Ntp.Server()
            self.server.parent = self
            self._children_name_map["server"] = "Cisco-IOS-XE-ntp:server"

            self.source = Native.Ntp.Source()
            self.source.parent = self
            self._children_name_map["source"] = "Cisco-IOS-XE-ntp:source"

            self.authentication_key = YList(self)
            self.trusted_key = YList(self)
            self._segment_path = lambda: "ntp"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Ntp, ['authenticate', 'broadcastdelay', 'clock_period', 'logging', 'max_associations', 'maxdistance', 'mindistance', 'orphan', 'passive', 'update_calendar'], name, value)


        class AccessGroup(Entity):
            """
            Control NTP access
            
            .. attribute:: ipv4
            
            	ipv4 access lists
            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Ipv4>`
            
            .. attribute:: ipv6
            
            	ipv6 access lists
            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Ipv6>`
            
            .. attribute:: peer
            
            	Provide full access
            	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Peer>`
            
            .. attribute:: query_only
            
            	Provide server and query access
            	**type**\:  :py:class:`QueryOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.QueryOnly>`
            
            .. attribute:: serve
            
            	Provide server and query access
            	**type**\:  :py:class:`Serve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Serve>`
            
            .. attribute:: serve_only
            
            	Provide only server access
            	**type**\:  :py:class:`ServeOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.ServeOnly>`
            
            

            """

            _prefix = 'ios-ntp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ntp.AccessGroup, self).__init__()

                self.yang_name = "access-group"
                self.yang_parent_name = "ntp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Ntp.AccessGroup.Ipv4)), ("ipv6", ("ipv6", Native.Ntp.AccessGroup.Ipv6)), ("peer", ("peer", Native.Ntp.AccessGroup.Peer)), ("query-only", ("query_only", Native.Ntp.AccessGroup.QueryOnly)), ("serve", ("serve", Native.Ntp.AccessGroup.Serve)), ("serve-only", ("serve_only", Native.Ntp.AccessGroup.ServeOnly))])
                self._leafs = OrderedDict()

                self.ipv4 = Native.Ntp.AccessGroup.Ipv4()
                self.ipv4.parent = self
                self._children_name_map["ipv4"] = "ipv4"

                self.ipv6 = Native.Ntp.AccessGroup.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"

                self.peer = Native.Ntp.AccessGroup.Peer()
                self.peer.parent = self
                self._children_name_map["peer"] = "peer"

                self.query_only = Native.Ntp.AccessGroup.QueryOnly()
                self.query_only.parent = self
                self._children_name_map["query_only"] = "query-only"

                self.serve = Native.Ntp.AccessGroup.Serve()
                self.serve.parent = self
                self._children_name_map["serve"] = "serve"

                self.serve_only = Native.Ntp.AccessGroup.ServeOnly()
                self.serve_only.parent = self
                self._children_name_map["serve_only"] = "serve-only"
                self._segment_path = lambda: "Cisco-IOS-XE-ntp:access-group"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ntp.AccessGroup, [], name, value)


            class Ipv4(Entity):
                """
                ipv4 access lists
                
                .. attribute:: peer
                
                	Provide full access
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Ipv4.Peer>`
                
                .. attribute:: query_only
                
                	Provide server and query access
                	**type**\:  :py:class:`QueryOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Ipv4.QueryOnly>`
                
                .. attribute:: serve
                
                	Provide server and query access
                	**type**\:  :py:class:`Serve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Ipv4.Serve>`
                
                .. attribute:: serve_only
                
                	Provide only server access
                	**type**\:  :py:class:`ServeOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Ipv4.ServeOnly>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.AccessGroup.Ipv4, self).__init__()

                    self.yang_name = "ipv4"
                    self.yang_parent_name = "access-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("peer", ("peer", Native.Ntp.AccessGroup.Ipv4.Peer)), ("query-only", ("query_only", Native.Ntp.AccessGroup.Ipv4.QueryOnly)), ("serve", ("serve", Native.Ntp.AccessGroup.Ipv4.Serve)), ("serve-only", ("serve_only", Native.Ntp.AccessGroup.Ipv4.ServeOnly))])
                    self._leafs = OrderedDict()

                    self.peer = Native.Ntp.AccessGroup.Ipv4.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"

                    self.query_only = Native.Ntp.AccessGroup.Ipv4.QueryOnly()
                    self.query_only.parent = self
                    self._children_name_map["query_only"] = "query-only"

                    self.serve = Native.Ntp.AccessGroup.Ipv4.Serve()
                    self.serve.parent = self
                    self._children_name_map["serve"] = "serve"

                    self.serve_only = Native.Ntp.AccessGroup.Ipv4.ServeOnly()
                    self.serve_only.parent = self
                    self._children_name_map["serve_only"] = "serve-only"
                    self._segment_path = lambda: "ipv4"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.AccessGroup.Ipv4, [], name, value)


                class Peer(Entity):
                    """
                    Provide full access
                    
                    .. attribute:: acl
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: kod
                    
                    	Send a Kiss\-o\-Death packet for failing peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.AccessGroup.Ipv4.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                            ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                        ])
                        self.acl = None
                        self.kod = None
                        self._segment_path = lambda: "peer"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.AccessGroup.Ipv4.Peer, ['acl', 'kod'], name, value)


                class QueryOnly(Entity):
                    """
                    Provide server and query access
                    
                    .. attribute:: acl
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: kod
                    
                    	Send a Kiss\-o\-Death packet for failing peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.AccessGroup.Ipv4.QueryOnly, self).__init__()

                        self.yang_name = "query-only"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                            ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                        ])
                        self.acl = None
                        self.kod = None
                        self._segment_path = lambda: "query-only"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.AccessGroup.Ipv4.QueryOnly, ['acl', 'kod'], name, value)


                class Serve(Entity):
                    """
                    Provide server and query access
                    
                    .. attribute:: acl
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: kod
                    
                    	Send a Kiss\-o\-Death packet for failing peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.AccessGroup.Ipv4.Serve, self).__init__()

                        self.yang_name = "serve"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                            ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                        ])
                        self.acl = None
                        self.kod = None
                        self._segment_path = lambda: "serve"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.AccessGroup.Ipv4.Serve, ['acl', 'kod'], name, value)


                class ServeOnly(Entity):
                    """
                    Provide only server access
                    
                    .. attribute:: acl
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: kod
                    
                    	Send a Kiss\-o\-Death packet for failing peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.AccessGroup.Ipv4.ServeOnly, self).__init__()

                        self.yang_name = "serve-only"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                            ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                        ])
                        self.acl = None
                        self.kod = None
                        self._segment_path = lambda: "serve-only"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/ipv4/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.AccessGroup.Ipv4.ServeOnly, ['acl', 'kod'], name, value)


            class Ipv6(Entity):
                """
                ipv6 access lists
                
                .. attribute:: peer
                
                	Provide full access
                	**type**\:  :py:class:`Peer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Ipv6.Peer>`
                
                .. attribute:: query_only
                
                	Provide server and query access
                	**type**\:  :py:class:`QueryOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Ipv6.QueryOnly>`
                
                .. attribute:: serve
                
                	Provide server and query access
                	**type**\:  :py:class:`Serve <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Ipv6.Serve>`
                
                .. attribute:: serve_only
                
                	Provide only server access
                	**type**\:  :py:class:`ServeOnly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.AccessGroup.Ipv6.ServeOnly>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.AccessGroup.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "access-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("peer", ("peer", Native.Ntp.AccessGroup.Ipv6.Peer)), ("query-only", ("query_only", Native.Ntp.AccessGroup.Ipv6.QueryOnly)), ("serve", ("serve", Native.Ntp.AccessGroup.Ipv6.Serve)), ("serve-only", ("serve_only", Native.Ntp.AccessGroup.Ipv6.ServeOnly))])
                    self._leafs = OrderedDict()

                    self.peer = Native.Ntp.AccessGroup.Ipv6.Peer()
                    self.peer.parent = self
                    self._children_name_map["peer"] = "peer"

                    self.query_only = Native.Ntp.AccessGroup.Ipv6.QueryOnly()
                    self.query_only.parent = self
                    self._children_name_map["query_only"] = "query-only"

                    self.serve = Native.Ntp.AccessGroup.Ipv6.Serve()
                    self.serve.parent = self
                    self._children_name_map["serve"] = "serve"

                    self.serve_only = Native.Ntp.AccessGroup.Ipv6.ServeOnly()
                    self.serve_only.parent = self
                    self._children_name_map["serve_only"] = "serve-only"
                    self._segment_path = lambda: "ipv6"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.AccessGroup.Ipv6, [], name, value)


                class Peer(Entity):
                    """
                    Provide full access
                    
                    .. attribute:: acl
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: kod
                    
                    	Send a Kiss\-o\-Death packet for failing peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.AccessGroup.Ipv6.Peer, self).__init__()

                        self.yang_name = "peer"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                            ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                        ])
                        self.acl = None
                        self.kod = None
                        self._segment_path = lambda: "peer"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.AccessGroup.Ipv6.Peer, ['acl', 'kod'], name, value)


                class QueryOnly(Entity):
                    """
                    Provide server and query access
                    
                    .. attribute:: acl
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: kod
                    
                    	Send a Kiss\-o\-Death packet for failing peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.AccessGroup.Ipv6.QueryOnly, self).__init__()

                        self.yang_name = "query-only"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                            ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                        ])
                        self.acl = None
                        self.kod = None
                        self._segment_path = lambda: "query-only"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.AccessGroup.Ipv6.QueryOnly, ['acl', 'kod'], name, value)


                class Serve(Entity):
                    """
                    Provide server and query access
                    
                    .. attribute:: acl
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: kod
                    
                    	Send a Kiss\-o\-Death packet for failing peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.AccessGroup.Ipv6.Serve, self).__init__()

                        self.yang_name = "serve"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                            ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                        ])
                        self.acl = None
                        self.kod = None
                        self._segment_path = lambda: "serve"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.AccessGroup.Ipv6.Serve, ['acl', 'kod'], name, value)


                class ServeOnly(Entity):
                    """
                    Provide only server access
                    
                    .. attribute:: acl
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: int
                    
                    			**range:** 1..99
                    
                    		**type**\: int
                    
                    			**range:** 1300..1999
                    
                    		**type**\: str
                    
                    			**pattern:** [a\-zA\-Z].\*
                    
                    .. attribute:: kod
                    
                    	Send a Kiss\-o\-Death packet for failing peers
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.AccessGroup.Ipv6.ServeOnly, self).__init__()

                        self.yang_name = "serve-only"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                            ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                        ])
                        self.acl = None
                        self.kod = None
                        self._segment_path = lambda: "serve-only"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/ipv6/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.AccessGroup.Ipv6.ServeOnly, ['acl', 'kod'], name, value)


            class Peer(Entity):
                """
                Provide full access
                
                .. attribute:: acl
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: int
                
                			**range:** 1300..1999
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: kod
                
                	Send a Kiss\-o\-Death packet for failing peers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.AccessGroup.Peer, self).__init__()

                    self.yang_name = "peer"
                    self.yang_parent_name = "access-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                        ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                    ])
                    self.acl = None
                    self.kod = None
                    self._segment_path = lambda: "peer"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.AccessGroup.Peer, ['acl', 'kod'], name, value)


            class QueryOnly(Entity):
                """
                Provide server and query access
                
                .. attribute:: acl
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: int
                
                			**range:** 1300..1999
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: kod
                
                	Send a Kiss\-o\-Death packet for failing peers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.AccessGroup.QueryOnly, self).__init__()

                    self.yang_name = "query-only"
                    self.yang_parent_name = "access-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                        ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                    ])
                    self.acl = None
                    self.kod = None
                    self._segment_path = lambda: "query-only"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.AccessGroup.QueryOnly, ['acl', 'kod'], name, value)


            class Serve(Entity):
                """
                Provide server and query access
                
                .. attribute:: acl
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: int
                
                			**range:** 1300..1999
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: kod
                
                	Send a Kiss\-o\-Death packet for failing peers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.AccessGroup.Serve, self).__init__()

                    self.yang_name = "serve"
                    self.yang_parent_name = "access-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                        ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                    ])
                    self.acl = None
                    self.kod = None
                    self._segment_path = lambda: "serve"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.AccessGroup.Serve, ['acl', 'kod'], name, value)


            class ServeOnly(Entity):
                """
                Provide only server access
                
                .. attribute:: acl
                
                	
                	**type**\: union of the below types:
                
                		**type**\: int
                
                			**range:** 1..99
                
                		**type**\: int
                
                			**range:** 1300..1999
                
                		**type**\: str
                
                			**pattern:** [a\-zA\-Z].\*
                
                .. attribute:: kod
                
                	Send a Kiss\-o\-Death packet for failing peers
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.AccessGroup.ServeOnly, self).__init__()

                    self.yang_name = "serve-only"
                    self.yang_parent_name = "access-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('acl', (YLeaf(YType.str, 'acl'), ['int','int','str'])),
                        ('kod', (YLeaf(YType.empty, 'kod'), ['Empty'])),
                    ])
                    self.acl = None
                    self.kod = None
                    self._segment_path = lambda: "serve-only"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:access-group/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.AccessGroup.ServeOnly, ['acl', 'kod'], name, value)


        class Allow(Entity):
            """
            Allow processing of packets
            
            .. attribute:: mode
            
            	Allow processing of particular mode packets
            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Allow.Mode>`
            
            

            """

            _prefix = 'ios-ntp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ntp.Allow, self).__init__()

                self.yang_name = "allow"
                self.yang_parent_name = "ntp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("mode", ("mode", Native.Ntp.Allow.Mode))])
                self._leafs = OrderedDict()

                self.mode = Native.Ntp.Allow.Mode()
                self.mode.parent = self
                self._children_name_map["mode"] = "mode"
                self._segment_path = lambda: "Cisco-IOS-XE-ntp:allow"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ntp.Allow, [], name, value)


            class Mode(Entity):
                """
                Allow processing of particular mode packets
                
                .. attribute:: control
                
                	Allow processing control mode packets
                	**type**\:  :py:class:`Control <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Allow.Mode.Control>`
                
                	**presence node**\: True
                
                .. attribute:: private
                
                	Allow processing private mode packets
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Allow.Mode, self).__init__()

                    self.yang_name = "mode"
                    self.yang_parent_name = "allow"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("control", ("control", Native.Ntp.Allow.Mode.Control))])
                    self._leafs = OrderedDict([
                        ('private', (YLeaf(YType.empty, 'private'), ['Empty'])),
                    ])
                    self.private = None

                    self.control = None
                    self._children_name_map["control"] = "control"
                    self._segment_path = lambda: "mode"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:allow/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Allow.Mode, ['private'], name, value)


                class Control(Entity):
                    """
                    Allow processing control mode packets
                    
                    .. attribute:: delay
                    
                    	Rate limiting delay (s)
                    	**type**\: int
                    
                    	**range:** 3..15
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.Allow.Mode.Control, self).__init__()

                        self.yang_name = "control"
                        self.yang_parent_name = "mode"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('delay', (YLeaf(YType.uint8, 'delay'), ['int'])),
                        ])
                        self.delay = None
                        self._segment_path = lambda: "control"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:allow/mode/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.Allow.Mode.Control, ['delay'], name, value)


        class AuthenticationKey(Entity):
            """
            Authentication key for trusted time sources
            
            .. attribute:: number  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: md5
            
            	MD5 authentication
            	**type**\: str
            
            .. attribute:: encryption_type
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ios-ntp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ntp.AuthenticationKey, self).__init__()

                self.yang_name = "authentication-key"
                self.yang_parent_name = "ntp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['number']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                    ('md5', (YLeaf(YType.str, 'md5'), ['str'])),
                    ('encryption_type', (YLeaf(YType.uint32, 'encryption-type'), ['int'])),
                ])
                self.number = None
                self.md5 = None
                self.encryption_type = None
                self._segment_path = lambda: "Cisco-IOS-XE-ntp:authentication-key" + "[number='" + str(self.number) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ntp.AuthenticationKey, ['number', 'md5', 'encryption_type'], name, value)


        class Master(Entity):
            """
            Act as NTP master clock
            
            .. attribute:: stratum_number
            
            	
            	**type**\: int
            
            	**range:** 1..15
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-ntp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ntp.Master, self).__init__()

                self.yang_name = "master"
                self.yang_parent_name = "ntp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('stratum_number', (YLeaf(YType.uint8, 'stratum-number'), ['int'])),
                ])
                self.stratum_number = None
                self._segment_path = lambda: "Cisco-IOS-XE-ntp:master"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ntp.Master, ['stratum_number'], name, value)


        class Panic(Entity):
            """
            Reject time updates > panic threshold (default 1000Sec)
            
            .. attribute:: update
            
            	Reject time updates > panic threshold (default 1000Sec)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-ntp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ntp.Panic, self).__init__()

                self.yang_name = "panic"
                self.yang_parent_name = "ntp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('update', (YLeaf(YType.empty, 'update'), ['Empty'])),
                ])
                self.update = None
                self._segment_path = lambda: "Cisco-IOS-XE-ntp:panic"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ntp.Panic, ['update'], name, value)


        class Peer(Entity):
            """
            Configure NTP peer
            
            .. attribute:: server_list
            
            	
            	**type**\: list of  		 :py:class:`ServerList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Peer.ServerList>`
            
            .. attribute:: ip
            
            	Use IP for DNS resolution
            	**type**\: list of  		 :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Peer.Ip>`
            
            .. attribute:: ipv6
            
            	Use IPv6 for DNS resolution
            	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Peer.Ipv6>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding Information
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Peer.Vrf>`
            
            

            """

            _prefix = 'ios-ntp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ntp.Peer, self).__init__()

                self.yang_name = "peer"
                self.yang_parent_name = "ntp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("server-list", ("server_list", Native.Ntp.Peer.ServerList)), ("ip", ("ip", Native.Ntp.Peer.Ip)), ("ipv6", ("ipv6", Native.Ntp.Peer.Ipv6)), ("vrf", ("vrf", Native.Ntp.Peer.Vrf))])
                self._leafs = OrderedDict()

                self.server_list = YList(self)
                self.ip = YList(self)
                self.ipv6 = YList(self)
                self.vrf = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-ntp:peer"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ntp.Peer, [], name, value)


            class ServerList(Entity):
                """
                
                
                .. attribute:: ip_address  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                .. attribute:: burst
                
                	Send a burst when peer is reachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: iburst
                
                	Send a burst when peer is unreachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: key
                
                	Configure peer authentication key
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: maxpoll
                
                	Maximum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: minpoll
                
                	Minimum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: prefer
                
                	Prefer this peer when possible
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: source
                
                	Interface for source address
                	**type**\: str
                
                .. attribute:: version
                
                	    Configure NTP version
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Peer.ServerList, self).__init__()

                    self.yang_name = "server-list"
                    self.yang_parent_name = "peer"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['ip_address']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str','str'])),
                        ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                        ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                        ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                        ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                        ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                        ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                        ('source', (YLeaf(YType.str, 'source'), ['str'])),
                        ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                    ])
                    self.ip_address = None
                    self.burst = None
                    self.iburst = None
                    self.key = None
                    self.maxpoll = None
                    self.minpoll = None
                    self.prefer = None
                    self.source = None
                    self.version = None
                    self._segment_path = lambda: "server-list" + "[ip-address='" + str(self.ip_address) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:peer/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Peer.ServerList, ['ip_address', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


            class Ip(Entity):
                """
                Use IP for DNS resolution
                
                .. attribute:: host_name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: burst
                
                	Send a burst when peer is reachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: iburst
                
                	Send a burst when peer is unreachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: key
                
                	Configure peer authentication key
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: maxpoll
                
                	Maximum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: minpoll
                
                	Minimum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: prefer
                
                	Prefer this peer when possible
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: source
                
                	Interface for source address
                	**type**\: str
                
                .. attribute:: version
                
                	    Configure NTP version
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Peer.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "peer"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['host_name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('host_name', (YLeaf(YType.str, 'host-name'), ['str'])),
                        ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                        ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                        ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                        ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                        ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                        ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                        ('source', (YLeaf(YType.str, 'source'), ['str'])),
                        ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                    ])
                    self.host_name = None
                    self.burst = None
                    self.iburst = None
                    self.key = None
                    self.maxpoll = None
                    self.minpoll = None
                    self.prefer = None
                    self.source = None
                    self.version = None
                    self._segment_path = lambda: "ip" + "[host-name='" + str(self.host_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:peer/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Peer.Ip, ['host_name', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


            class Ipv6(Entity):
                """
                Use IPv6 for DNS resolution
                
                .. attribute:: host_name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: burst
                
                	Send a burst when peer is reachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: iburst
                
                	Send a burst when peer is unreachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: key
                
                	Configure peer authentication key
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: maxpoll
                
                	Maximum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: minpoll
                
                	Minimum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: prefer
                
                	Prefer this peer when possible
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: source
                
                	Interface for source address
                	**type**\: str
                
                .. attribute:: version
                
                	    Configure NTP version
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Peer.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "peer"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['host_name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('host_name', (YLeaf(YType.str, 'host-name'), ['str'])),
                        ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                        ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                        ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                        ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                        ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                        ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                        ('source', (YLeaf(YType.str, 'source'), ['str'])),
                        ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                    ])
                    self.host_name = None
                    self.burst = None
                    self.iburst = None
                    self.key = None
                    self.maxpoll = None
                    self.minpoll = None
                    self.prefer = None
                    self.source = None
                    self.version = None
                    self._segment_path = lambda: "ipv6" + "[host-name='" + str(self.host_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:peer/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Peer.Ipv6, ['host_name', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding Information
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: server_list
                
                	
                	**type**\: list of  		 :py:class:`ServerList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Peer.Vrf.ServerList>`
                
                .. attribute:: ip
                
                	Use IP for DNS resolution
                	**type**\: list of  		 :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Peer.Vrf.Ip>`
                
                .. attribute:: ipv6
                
                	Use IPv6 for DNS resolution
                	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Peer.Vrf.Ipv6>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Peer.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "peer"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("server-list", ("server_list", Native.Ntp.Peer.Vrf.ServerList)), ("ip", ("ip", Native.Ntp.Peer.Vrf.Ip)), ("ipv6", ("ipv6", Native.Ntp.Peer.Vrf.Ipv6))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.server_list = YList(self)
                    self.ip = YList(self)
                    self.ipv6 = YList(self)
                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:peer/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Peer.Vrf, ['name'], name, value)


                class ServerList(Entity):
                    """
                    
                    
                    .. attribute:: ip_address  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    .. attribute:: burst
                    
                    	Send a burst when peer is reachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: iburst
                    
                    	Send a burst when peer is unreachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: key
                    
                    	Configure peer authentication key
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maxpoll
                    
                    	Maximum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: minpoll
                    
                    	Minimum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: prefer
                    
                    	Prefer this peer when possible
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: source
                    
                    	Interface for source address
                    	**type**\: str
                    
                    .. attribute:: version
                    
                    	    Configure NTP version
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.Peer.Vrf.ServerList, self).__init__()

                        self.yang_name = "server-list"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['ip_address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str','str'])),
                            ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                            ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                            ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                            ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                            ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                            ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                            ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.ip_address = None
                        self.burst = None
                        self.iburst = None
                        self.key = None
                        self.maxpoll = None
                        self.minpoll = None
                        self.prefer = None
                        self.source = None
                        self.version = None
                        self._segment_path = lambda: "server-list" + "[ip-address='" + str(self.ip_address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.Peer.Vrf.ServerList, ['ip_address', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


                class Ip(Entity):
                    """
                    Use IP for DNS resolution
                    
                    .. attribute:: host_name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: burst
                    
                    	Send a burst when peer is reachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: iburst
                    
                    	Send a burst when peer is unreachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: key
                    
                    	Configure peer authentication key
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maxpoll
                    
                    	Maximum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: minpoll
                    
                    	Minimum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: prefer
                    
                    	Prefer this peer when possible
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: source
                    
                    	Interface for source address
                    	**type**\: str
                    
                    .. attribute:: version
                    
                    	    Configure NTP version
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.Peer.Vrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['host_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('host_name', (YLeaf(YType.str, 'host-name'), ['str'])),
                            ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                            ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                            ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                            ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                            ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                            ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                            ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.host_name = None
                        self.burst = None
                        self.iburst = None
                        self.key = None
                        self.maxpoll = None
                        self.minpoll = None
                        self.prefer = None
                        self.source = None
                        self.version = None
                        self._segment_path = lambda: "ip" + "[host-name='" + str(self.host_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.Peer.Vrf.Ip, ['host_name', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


                class Ipv6(Entity):
                    """
                    Use IPv6 for DNS resolution
                    
                    .. attribute:: host_name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: burst
                    
                    	Send a burst when peer is reachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: iburst
                    
                    	Send a burst when peer is unreachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: key
                    
                    	Configure peer authentication key
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maxpoll
                    
                    	Maximum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: minpoll
                    
                    	Minimum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: prefer
                    
                    	Prefer this peer when possible
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: source
                    
                    	Interface for source address
                    	**type**\: str
                    
                    .. attribute:: version
                    
                    	    Configure NTP version
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.Peer.Vrf.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['host_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('host_name', (YLeaf(YType.str, 'host-name'), ['str'])),
                            ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                            ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                            ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                            ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                            ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                            ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                            ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.host_name = None
                        self.burst = None
                        self.iburst = None
                        self.key = None
                        self.maxpoll = None
                        self.minpoll = None
                        self.prefer = None
                        self.source = None
                        self.version = None
                        self._segment_path = lambda: "ipv6" + "[host-name='" + str(self.host_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.Peer.Vrf.Ipv6, ['host_name', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


        class Server(Entity):
            """
            Configure NTP server
            
            .. attribute:: server_list
            
            	
            	**type**\: list of  		 :py:class:`ServerList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Server.ServerList>`
            
            .. attribute:: ip
            
            	Use IP for DNS resolution
            	**type**\: list of  		 :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Server.Ip>`
            
            .. attribute:: ipv6
            
            	Use IPv6 for DNS resolution
            	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Server.Ipv6>`
            
            .. attribute:: vrf
            
            	VPN Routing/Forwarding Information
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Server.Vrf>`
            
            

            """

            _prefix = 'ios-ntp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ntp.Server, self).__init__()

                self.yang_name = "server"
                self.yang_parent_name = "ntp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("server-list", ("server_list", Native.Ntp.Server.ServerList)), ("ip", ("ip", Native.Ntp.Server.Ip)), ("ipv6", ("ipv6", Native.Ntp.Server.Ipv6)), ("vrf", ("vrf", Native.Ntp.Server.Vrf))])
                self._leafs = OrderedDict()

                self.server_list = YList(self)
                self.ip = YList(self)
                self.ipv6 = YList(self)
                self.vrf = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-ntp:server"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ntp.Server, [], name, value)


            class ServerList(Entity):
                """
                
                
                .. attribute:: ip_address  (key)
                
                	
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                .. attribute:: burst
                
                	Send a burst when peer is reachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: iburst
                
                	Send a burst when peer is unreachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: key
                
                	Configure peer authentication key
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: maxpoll
                
                	Maximum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: minpoll
                
                	Minimum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: prefer
                
                	Prefer this peer when possible
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: source
                
                	Interface for source address
                	**type**\: str
                
                .. attribute:: version
                
                	    Configure NTP version
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Server.ServerList, self).__init__()

                    self.yang_name = "server-list"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['ip_address']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str','str'])),
                        ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                        ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                        ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                        ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                        ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                        ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                        ('source', (YLeaf(YType.str, 'source'), ['str'])),
                        ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                    ])
                    self.ip_address = None
                    self.burst = None
                    self.iburst = None
                    self.key = None
                    self.maxpoll = None
                    self.minpoll = None
                    self.prefer = None
                    self.source = None
                    self.version = None
                    self._segment_path = lambda: "server-list" + "[ip-address='" + str(self.ip_address) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:server/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Server.ServerList, ['ip_address', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


            class Ip(Entity):
                """
                Use IP for DNS resolution
                
                .. attribute:: host_name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: burst
                
                	Send a burst when peer is reachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: iburst
                
                	Send a burst when peer is unreachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: key
                
                	Configure peer authentication key
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: maxpoll
                
                	Maximum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: minpoll
                
                	Minimum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: prefer
                
                	Prefer this peer when possible
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: source
                
                	Interface for source address
                	**type**\: str
                
                .. attribute:: version
                
                	    Configure NTP version
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Server.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['host_name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('host_name', (YLeaf(YType.str, 'host-name'), ['str'])),
                        ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                        ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                        ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                        ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                        ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                        ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                        ('source', (YLeaf(YType.str, 'source'), ['str'])),
                        ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                    ])
                    self.host_name = None
                    self.burst = None
                    self.iburst = None
                    self.key = None
                    self.maxpoll = None
                    self.minpoll = None
                    self.prefer = None
                    self.source = None
                    self.version = None
                    self._segment_path = lambda: "ip" + "[host-name='" + str(self.host_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:server/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Server.Ip, ['host_name', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


            class Ipv6(Entity):
                """
                Use IPv6 for DNS resolution
                
                .. attribute:: host_name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: burst
                
                	Send a burst when peer is reachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: iburst
                
                	Send a burst when peer is unreachable (Default)
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: key
                
                	Configure peer authentication key
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: maxpoll
                
                	Maximum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: minpoll
                
                	Minimum poll interval
                	**type**\: int
                
                	**range:** 4..17
                
                .. attribute:: prefer
                
                	Prefer this peer when possible
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: source
                
                	Interface for source address
                	**type**\: str
                
                .. attribute:: version
                
                	    Configure NTP version
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Server.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['host_name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('host_name', (YLeaf(YType.str, 'host-name'), ['str'])),
                        ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                        ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                        ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                        ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                        ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                        ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                        ('source', (YLeaf(YType.str, 'source'), ['str'])),
                        ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                    ])
                    self.host_name = None
                    self.burst = None
                    self.iburst = None
                    self.key = None
                    self.maxpoll = None
                    self.minpoll = None
                    self.prefer = None
                    self.source = None
                    self.version = None
                    self._segment_path = lambda: "ipv6" + "[host-name='" + str(self.host_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:server/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Server.Ipv6, ['host_name', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


            class Vrf(Entity):
                """
                VPN Routing/Forwarding Information
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: server_list
                
                	
                	**type**\: list of  		 :py:class:`ServerList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Server.Vrf.ServerList>`
                
                .. attribute:: ip
                
                	Use IP for DNS resolution
                	**type**\: list of  		 :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Server.Vrf.Ip>`
                
                .. attribute:: ipv6
                
                	Use IPv6 for DNS resolution
                	**type**\: list of  		 :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Server.Vrf.Ipv6>`
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Server.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "server"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("server-list", ("server_list", Native.Ntp.Server.Vrf.ServerList)), ("ip", ("ip", Native.Ntp.Server.Vrf.Ip)), ("ipv6", ("ipv6", Native.Ntp.Server.Vrf.Ipv6))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.server_list = YList(self)
                    self.ip = YList(self)
                    self.ipv6 = YList(self)
                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:server/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Server.Vrf, ['name'], name, value)


                class ServerList(Entity):
                    """
                    
                    
                    .. attribute:: ip_address  (key)
                    
                    	
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    .. attribute:: burst
                    
                    	Send a burst when peer is reachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: iburst
                    
                    	Send a burst when peer is unreachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: key
                    
                    	Configure peer authentication key
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maxpoll
                    
                    	Maximum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: minpoll
                    
                    	Minimum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: prefer
                    
                    	Prefer this peer when possible
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: source
                    
                    	Interface for source address
                    	**type**\: str
                    
                    .. attribute:: version
                    
                    	    Configure NTP version
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.Server.Vrf.ServerList, self).__init__()

                        self.yang_name = "server-list"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['ip_address']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str','str'])),
                            ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                            ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                            ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                            ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                            ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                            ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                            ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.ip_address = None
                        self.burst = None
                        self.iburst = None
                        self.key = None
                        self.maxpoll = None
                        self.minpoll = None
                        self.prefer = None
                        self.source = None
                        self.version = None
                        self._segment_path = lambda: "server-list" + "[ip-address='" + str(self.ip_address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.Server.Vrf.ServerList, ['ip_address', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


                class Ip(Entity):
                    """
                    Use IP for DNS resolution
                    
                    .. attribute:: host_name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: burst
                    
                    	Send a burst when peer is reachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: iburst
                    
                    	Send a burst when peer is unreachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: key
                    
                    	Configure peer authentication key
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maxpoll
                    
                    	Maximum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: minpoll
                    
                    	Minimum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: prefer
                    
                    	Prefer this peer when possible
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: source
                    
                    	Interface for source address
                    	**type**\: str
                    
                    .. attribute:: version
                    
                    	    Configure NTP version
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.Server.Vrf.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['host_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('host_name', (YLeaf(YType.str, 'host-name'), ['str'])),
                            ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                            ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                            ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                            ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                            ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                            ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                            ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.host_name = None
                        self.burst = None
                        self.iburst = None
                        self.key = None
                        self.maxpoll = None
                        self.minpoll = None
                        self.prefer = None
                        self.source = None
                        self.version = None
                        self._segment_path = lambda: "ip" + "[host-name='" + str(self.host_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.Server.Vrf.Ip, ['host_name', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


                class Ipv6(Entity):
                    """
                    Use IPv6 for DNS resolution
                    
                    .. attribute:: host_name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: burst
                    
                    	Send a burst when peer is reachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: iburst
                    
                    	Send a burst when peer is unreachable (Default)
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: key
                    
                    	Configure peer authentication key
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maxpoll
                    
                    	Maximum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: minpoll
                    
                    	Minimum poll interval
                    	**type**\: int
                    
                    	**range:** 4..17
                    
                    .. attribute:: prefer
                    
                    	Prefer this peer when possible
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: source
                    
                    	Interface for source address
                    	**type**\: str
                    
                    .. attribute:: version
                    
                    	    Configure NTP version
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ios-ntp'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.Ntp.Server.Vrf.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['host_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('host_name', (YLeaf(YType.str, 'host-name'), ['str'])),
                            ('burst', (YLeaf(YType.empty, 'burst'), ['Empty'])),
                            ('iburst', (YLeaf(YType.empty, 'iburst'), ['Empty'])),
                            ('key', (YLeaf(YType.uint32, 'key'), ['int'])),
                            ('maxpoll', (YLeaf(YType.uint8, 'maxpoll'), ['int'])),
                            ('minpoll', (YLeaf(YType.uint8, 'minpoll'), ['int'])),
                            ('prefer', (YLeaf(YType.empty, 'prefer'), ['Empty'])),
                            ('source', (YLeaf(YType.str, 'source'), ['str'])),
                            ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                        ])
                        self.host_name = None
                        self.burst = None
                        self.iburst = None
                        self.key = None
                        self.maxpoll = None
                        self.minpoll = None
                        self.prefer = None
                        self.source = None
                        self.version = None
                        self._segment_path = lambda: "ipv6" + "[host-name='" + str(self.host_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Ntp.Server.Vrf.Ipv6, ['host_name', 'burst', 'iburst', 'key', 'maxpoll', 'minpoll', 'prefer', 'source', 'version'], name, value)


        class Source(Entity):
            """
            Configure interface for source address
            
            .. attribute:: appnav_compress
            
            	Service\-Context Virtual Interface Compress
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: appnav_uncompress
            
            	Service\-Context Virtual Interface UnCompress
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: atm
            
            	ATM interface
            	**type**\: str
            
            .. attribute:: atm_subinterface
            
            	
            	**type**\:  :py:class:`ATMSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Source.ATMSubinterface>`
            
            .. attribute:: atm_acr
            
            	ATM\-ACR interface
            	**type**\: str
            
            	**pattern:** [0\-9]
            
            .. attribute:: atm_acrsubinterface
            
            	
            	**type**\:  :py:class:`ATMACRsubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Source.ATMACRsubinterface>`
            
            .. attribute:: bdi
            
            	Bridge\-Domain interface
            	**type**\: str
            
            .. attribute:: cem
            
            	CEM interface
            	**type**\: str
            
            	**pattern:** ([0\-9]/){2}[0\-9]
            
            .. attribute:: cem_acr
            
            	CEM\-ACR interface
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: embedded_service_engine
            
            	cisco embedded service engine module
            	**type**\: str
            
            .. attribute:: ethernet
            
            	IEEE 802.3
            	**type**\: str
            
            .. attribute:: fastethernet
            
            	FastEthernet IEEE 802.3
            	**type**\: str
            
            .. attribute:: gigabitethernet
            
            	GigabitEthernet IEEE 802.3z
            	**type**\: str
            
            .. attribute:: fivegigabitethernet
            
            	Five GigabitEthernet 
            	**type**\: str
            
            .. attribute:: twentyfivegige
            
            	Twenty Five GigabitEthernet 
            	**type**\: str
            
            .. attribute:: twogigabitethernet
            
            	Two GigabitEthernet 
            	**type**\: str
            
            .. attribute:: fortygigabitethernet
            
            	Forty GigabitEthernet 
            	**type**\: str
            
            .. attribute:: hundredgige
            
            	Hundred GigabitEthernet
            	**type**\: str
            
            .. attribute:: lisp
            
            	Locator/ID Separation Protocol Virtual Interface
            	**type**\: str
            
            .. attribute:: lisp_subinterface
            
            	Locator/ID Separation Protocol Virtual Interface
            	**type**\:  :py:class:`LISPSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Source.LISPSubinterface>`
            
            .. attribute:: loopback
            
            	Loopback interface
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: multilink
            
            	Multilink\-group interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: nve
            
            	Network virtualization endpoint interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: overlay
            
            	Overlay interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: port_channel
            
            	Ethernet Channel of interfaces
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: port_channel_subinterface
            
            	
            	**type**\:  :py:class:`PortChannelSubinterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Ntp.Source.PortChannelSubinterface>`
            
            .. attribute:: pseudowire
            
            	Pseudowire Interface
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: sm
            
            	SM Interface
            	**type**\: str
            
            .. attribute:: cellular
            
            	Cellular Interface
            	**type**\: str
            
            .. attribute:: serial
            
            	Serial interface
            	**type**\: str
            
            .. attribute:: tengigabitethernet
            
            	Ten Gigabit Ethernet
            	**type**\: str
            
            .. attribute:: tunnel
            
            	Tunnel interface
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: virtual_template
            
            	Virtual Template interface
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: vlan
            
            	Iosxr Vlans
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: virtualportgroup
            
            	Virtual Port Group
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: vasileft
            
            	vasileft
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: vasiright
            
            	vasiright
            	**type**\: int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'ios-ntp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ntp.Source, self).__init__()

                self.yang_name = "source"
                self.yang_parent_name = "ntp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ATM-subinterface", ("atm_subinterface", Native.Ntp.Source.ATMSubinterface)), ("ATM-ACRsubinterface", ("atm_acrsubinterface", Native.Ntp.Source.ATMACRsubinterface)), ("LISP-subinterface", ("lisp_subinterface", Native.Ntp.Source.LISPSubinterface)), ("Port-channel-subinterface", ("port_channel_subinterface", Native.Ntp.Source.PortChannelSubinterface))])
                self._leafs = OrderedDict([
                    ('appnav_compress', (YLeaf(YType.uint16, 'AppNav-Compress'), ['int'])),
                    ('appnav_uncompress', (YLeaf(YType.uint16, 'AppNav-UnCompress'), ['int'])),
                    ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                    ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                    ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                    ('cem', (YLeaf(YType.str, 'CEM'), ['str'])),
                    ('cem_acr', (YLeaf(YType.uint8, 'CEM-ACR'), ['int'])),
                    ('embedded_service_engine', (YLeaf(YType.str, 'Embedded-Service-Engine'), ['str'])),
                    ('ethernet', (YLeaf(YType.str, 'Ethernet'), ['str'])),
                    ('fastethernet', (YLeaf(YType.str, 'FastEthernet'), ['str'])),
                    ('gigabitethernet', (YLeaf(YType.str, 'GigabitEthernet'), ['str'])),
                    ('fivegigabitethernet', (YLeaf(YType.str, 'FiveGigabitEthernet'), ['str'])),
                    ('twentyfivegige', (YLeaf(YType.str, 'TwentyFiveGigE'), ['str'])),
                    ('twogigabitethernet', (YLeaf(YType.str, 'TwoGigabitEthernet'), ['str'])),
                    ('fortygigabitethernet', (YLeaf(YType.str, 'FortyGigabitEthernet'), ['str'])),
                    ('hundredgige', (YLeaf(YType.str, 'HundredGigE'), ['str'])),
                    ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                    ('multilink', (YLeaf(YType.uint16, 'Multilink'), ['int'])),
                    ('nve', (YLeaf(YType.uint16, 'nve'), ['int'])),
                    ('overlay', (YLeaf(YType.uint16, 'overlay'), ['int'])),
                    ('port_channel', (YLeaf(YType.uint32, 'Port-channel'), ['int'])),
                    ('pseudowire', (YLeaf(YType.uint32, 'pseudowire'), ['int'])),
                    ('sm', (YLeaf(YType.str, 'SM'), ['str'])),
                    ('cellular', (YLeaf(YType.str, 'Cellular'), ['str'])),
                    ('serial', (YLeaf(YType.str, 'Serial'), ['str'])),
                    ('tengigabitethernet', (YLeaf(YType.str, 'TenGigabitEthernet'), ['str'])),
                    ('tunnel', (YLeaf(YType.uint32, 'Tunnel'), ['int'])),
                    ('virtual_template', (YLeaf(YType.uint16, 'Virtual-Template'), ['int'])),
                    ('vlan', (YLeaf(YType.uint16, 'Vlan'), ['int'])),
                    ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                    ('vasileft', (YLeaf(YType.uint16, 'vasileft'), ['int'])),
                    ('vasiright', (YLeaf(YType.uint16, 'vasiright'), ['int'])),
                ])
                self.appnav_compress = None
                self.appnav_uncompress = None
                self.atm = None
                self.atm_acr = None
                self.bdi = None
                self.cem = None
                self.cem_acr = None
                self.embedded_service_engine = None
                self.ethernet = None
                self.fastethernet = None
                self.gigabitethernet = None
                self.fivegigabitethernet = None
                self.twentyfivegige = None
                self.twogigabitethernet = None
                self.fortygigabitethernet = None
                self.hundredgige = None
                self.lisp = None
                self.loopback = None
                self.multilink = None
                self.nve = None
                self.overlay = None
                self.port_channel = None
                self.pseudowire = None
                self.sm = None
                self.cellular = None
                self.serial = None
                self.tengigabitethernet = None
                self.tunnel = None
                self.virtual_template = None
                self.vlan = None
                self.virtualportgroup = None
                self.vasileft = None
                self.vasiright = None

                self.atm_subinterface = Native.Ntp.Source.ATMSubinterface()
                self.atm_subinterface.parent = self
                self._children_name_map["atm_subinterface"] = "ATM-subinterface"

                self.atm_acrsubinterface = Native.Ntp.Source.ATMACRsubinterface()
                self.atm_acrsubinterface.parent = self
                self._children_name_map["atm_acrsubinterface"] = "ATM-ACRsubinterface"

                self.lisp_subinterface = Native.Ntp.Source.LISPSubinterface()
                self.lisp_subinterface.parent = self
                self._children_name_map["lisp_subinterface"] = "LISP-subinterface"

                self.port_channel_subinterface = Native.Ntp.Source.PortChannelSubinterface()
                self.port_channel_subinterface.parent = self
                self._children_name_map["port_channel_subinterface"] = "Port-channel-subinterface"
                self._segment_path = lambda: "Cisco-IOS-XE-ntp:source"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ntp.Source, [u'appnav_compress', u'appnav_uncompress', u'atm', u'atm_acr', u'bdi', u'cem', u'cem_acr', u'embedded_service_engine', u'ethernet', u'fastethernet', u'gigabitethernet', u'fivegigabitethernet', u'twentyfivegige', u'twogigabitethernet', u'fortygigabitethernet', u'hundredgige', u'lisp', u'loopback', u'multilink', u'nve', u'overlay', u'port_channel', u'pseudowire', u'sm', u'cellular', u'serial', u'tengigabitethernet', u'tunnel', u'virtual_template', u'vlan', u'virtualportgroup', u'vasileft', u'vasiright'], name, value)


            class ATMSubinterface(Entity):
                """
                
                
                .. attribute:: atm
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Source.ATMSubinterface, self).__init__()

                    self.yang_name = "ATM-subinterface"
                    self.yang_parent_name = "source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('atm', (YLeaf(YType.str, 'ATM'), ['str'])),
                    ])
                    self.atm = None
                    self._segment_path = lambda: "ATM-subinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Source.ATMSubinterface, [u'atm'], name, value)


            class ATMACRsubinterface(Entity):
                """
                
                
                .. attribute:: atm_acr
                
                	
                	**type**\: str
                
                	**pattern:** [0\-9]\\.([0\-9]/){3}[0\-9]
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Source.ATMACRsubinterface, self).__init__()

                    self.yang_name = "ATM-ACRsubinterface"
                    self.yang_parent_name = "source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('atm_acr', (YLeaf(YType.str, 'ATM-ACR'), ['str'])),
                    ])
                    self.atm_acr = None
                    self._segment_path = lambda: "ATM-ACRsubinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Source.ATMACRsubinterface, [u'atm_acr'], name, value)


            class LISPSubinterface(Entity):
                """
                Locator/ID Separation Protocol Virtual Interface
                
                .. attribute:: lisp
                
                	
                	**type**\: str
                
                	**pattern:** [0\-9]\*(. ?[1\-9][0\-9]\*)\*
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Source.LISPSubinterface, self).__init__()

                    self.yang_name = "LISP-subinterface"
                    self.yang_parent_name = "source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('lisp', (YLeaf(YType.str, 'LISP'), ['str'])),
                    ])
                    self.lisp = None
                    self._segment_path = lambda: "LISP-subinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Source.LISPSubinterface, [u'lisp'], name, value)


            class PortChannelSubinterface(Entity):
                """
                
                
                .. attribute:: port_channel
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-ntp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Ntp.Source.PortChannelSubinterface, self).__init__()

                    self.yang_name = "Port-channel-subinterface"
                    self.yang_parent_name = "source"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('port_channel', (YLeaf(YType.str, 'Port-channel'), ['str'])),
                    ])
                    self.port_channel = None
                    self._segment_path = lambda: "Port-channel-subinterface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/Cisco-IOS-XE-ntp:source/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Ntp.Source.PortChannelSubinterface, [u'port_channel'], name, value)


        class TrustedKey(Entity):
            """
            Key numbers for trusted time sources
            
            .. attribute:: number  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..65535
            
            .. attribute:: end_key
            
            	End Key
            	**type**\: int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'ios-ntp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Ntp.TrustedKey, self).__init__()

                self.yang_name = "trusted-key"
                self.yang_parent_name = "ntp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['number']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                    ('end_key', (YLeaf(YType.uint16, 'end-key'), ['int'])),
                ])
                self.number = None
                self.end_key = None
                self._segment_path = lambda: "Cisco-IOS-XE-ntp:trusted-key" + "[number='" + str(self.number) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/ntp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Ntp.TrustedKey, ['number', 'end_key'], name, value)


    class Wsma(Entity):
        """
        Configure Web Services Management Agents
        
        .. attribute:: agent
        
        	Configure WSMA agents
        	**type**\:  :py:class:`Agent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Wsma.Agent>`
        
        .. attribute:: profile
        
        	Configure WSMA profile
        	**type**\:  :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Wsma.Profile>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Wsma, self).__init__()

            self.yang_name = "wsma"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-wsma:agent", ("agent", Native.Wsma.Agent)), ("Cisco-IOS-XE-wsma:profile", ("profile", Native.Wsma.Profile))])
            self._leafs = OrderedDict()

            self.agent = Native.Wsma.Agent()
            self.agent.parent = self
            self._children_name_map["agent"] = "Cisco-IOS-XE-wsma:agent"

            self.profile = Native.Wsma.Profile()
            self.profile.parent = self
            self._children_name_map["profile"] = "Cisco-IOS-XE-wsma:profile"
            self._segment_path = lambda: "wsma"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Wsma, [], name, value)


        class Agent(Entity):
            """
            Configure WSMA agents
            
            .. attribute:: exec_
            
            	Start WSMA exec agent
            	**type**\:  :py:class:`Exec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Wsma.Agent.Exec>`
            
            .. attribute:: config
            
            	Start WSMA config agent
            	**type**\:  :py:class:`Config <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Wsma.Agent.Config>`
            
            .. attribute:: filesys
            
            	Start WSMA file system agent
            	**type**\:  :py:class:`Filesys <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Wsma.Agent.Filesys>`
            
            .. attribute:: notify
            
            	Start WSMA notify agent
            	**type**\:  :py:class:`Notify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Wsma.Agent.Notify>`
            
            

            """

            _prefix = 'ios-wsma'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Wsma.Agent, self).__init__()

                self.yang_name = "agent"
                self.yang_parent_name = "wsma"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("exec", ("exec_", Native.Wsma.Agent.Exec)), ("config", ("config", Native.Wsma.Agent.Config)), ("filesys", ("filesys", Native.Wsma.Agent.Filesys)), ("notify", ("notify", Native.Wsma.Agent.Notify))])
                self._leafs = OrderedDict()

                self.exec_ = Native.Wsma.Agent.Exec()
                self.exec_.parent = self
                self._children_name_map["exec_"] = "exec"

                self.config = Native.Wsma.Agent.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"

                self.filesys = Native.Wsma.Agent.Filesys()
                self.filesys.parent = self
                self._children_name_map["filesys"] = "filesys"

                self.notify = Native.Wsma.Agent.Notify()
                self.notify.parent = self
                self._children_name_map["notify"] = "notify"
                self._segment_path = lambda: "Cisco-IOS-XE-wsma:agent"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/wsma/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Wsma.Agent, [], name, value)


            class Exec(Entity):
                """
                Start WSMA exec agent
                
                .. attribute:: profile
                
                	
                	**type**\: list of str
                
                

                """

                _prefix = 'ios-wsma'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Wsma.Agent.Exec, self).__init__()

                    self.yang_name = "exec"
                    self.yang_parent_name = "agent"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('profile', (YLeafList(YType.str, 'profile'), ['str'])),
                    ])
                    self.profile = []
                    self._segment_path = lambda: "exec"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/wsma/Cisco-IOS-XE-wsma:agent/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Wsma.Agent.Exec, ['profile'], name, value)


            class Config(Entity):
                """
                Start WSMA config agent
                
                .. attribute:: profile
                
                	
                	**type**\: list of str
                
                

                """

                _prefix = 'ios-wsma'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Wsma.Agent.Config, self).__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "agent"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('profile', (YLeafList(YType.str, 'profile'), ['str'])),
                    ])
                    self.profile = []
                    self._segment_path = lambda: "config"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/wsma/Cisco-IOS-XE-wsma:agent/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Wsma.Agent.Config, ['profile'], name, value)


            class Filesys(Entity):
                """
                Start WSMA file system agent
                
                .. attribute:: profile
                
                	
                	**type**\: list of str
                
                

                """

                _prefix = 'ios-wsma'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Wsma.Agent.Filesys, self).__init__()

                    self.yang_name = "filesys"
                    self.yang_parent_name = "agent"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('profile', (YLeafList(YType.str, 'profile'), ['str'])),
                    ])
                    self.profile = []
                    self._segment_path = lambda: "filesys"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/wsma/Cisco-IOS-XE-wsma:agent/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Wsma.Agent.Filesys, ['profile'], name, value)


            class Notify(Entity):
                """
                Start WSMA notify agent
                
                .. attribute:: profile
                
                	
                	**type**\: list of str
                
                

                """

                _prefix = 'ios-wsma'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Wsma.Agent.Notify, self).__init__()

                    self.yang_name = "notify"
                    self.yang_parent_name = "agent"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('profile', (YLeafList(YType.str, 'profile'), ['str'])),
                    ])
                    self.profile = []
                    self._segment_path = lambda: "notify"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/wsma/Cisco-IOS-XE-wsma:agent/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Wsma.Agent.Notify, ['profile'], name, value)


        class Profile(Entity):
            """
            Configure WSMA profile
            
            .. attribute:: listener
            
            	Configure a listener profile
            	**type**\: list of  		 :py:class:`Listener <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Wsma.Profile.Listener>`
            
            

            """

            _prefix = 'ios-wsma'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Wsma.Profile, self).__init__()

                self.yang_name = "profile"
                self.yang_parent_name = "wsma"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("listener", ("listener", Native.Wsma.Profile.Listener))])
                self._leafs = OrderedDict()

                self.listener = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-wsma:profile"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/wsma/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Wsma.Profile, [], name, value)


            class Listener(Entity):
                """
                Configure a listener profile
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: transport
                
                	The transport to use
                	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Wsma.Profile.Listener.Transport>`
                
                

                """

                _prefix = 'ios-wsma'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Wsma.Profile.Listener, self).__init__()

                    self.yang_name = "listener"
                    self.yang_parent_name = "profile"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('transport', (YLeaf(YType.enumeration, 'transport'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Wsma.Profile.Listener.Transport')])),
                    ])
                    self.name = None
                    self.transport = None
                    self._segment_path = lambda: "listener" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/wsma/Cisco-IOS-XE-wsma:profile/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Wsma.Profile.Listener, ['name', 'transport'], name, value)

                class Transport(Enum):
                    """
                    Transport (Enum Class)

                    The transport to use

                    .. data:: http = 0

                    .. data:: https = 1

                    .. data:: ssh = 2

                    .. data:: tls = 3

                    """

                    http = Enum.YLeaf(0, "http")

                    https = Enum.YLeaf(1, "https")

                    ssh = Enum.YLeaf(2, "ssh")

                    tls = Enum.YLeaf(3, "tls")



    class Event(Entity):
        """
        Event related configuration commands
        
        .. attribute:: manager
        
        	Event Manager configuration commands
        	**type**\:  :py:class:`Manager <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Event, self).__init__()

            self.yang_name = "event"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-eem:manager", ("manager", Native.Event.Manager))])
            self._leafs = OrderedDict()

            self.manager = Native.Event.Manager()
            self.manager.parent = self
            self._children_name_map["manager"] = "Cisco-IOS-XE-eem:manager"
            self._segment_path = lambda: "event"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Event, [], name, value)


        class Manager(Entity):
            """
            Event Manager configuration commands
            
            .. attribute:: environment
            
            	Set an Embedded Event Manager global environment variable
            	**type**\: list of  		 :py:class:`Environment <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Environment>`
            
            .. attribute:: directory
            
            	Set Embedded Event Manager directory information
            	**type**\:  :py:class:`Directory <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Directory>`
            
            .. attribute:: session
            
            	Set Embedded Event Manager session attributes
            	**type**\:  :py:class:`Session <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Session>`
            
            .. attribute:: applet
            
            	Register an Event Manager applet
            	**type**\: list of  		 :py:class:`Applet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet>`
            
            

            """

            _prefix = 'ios-eem'
            _revision = '2017-12-20'

            def __init__(self):
                super(Native.Event.Manager, self).__init__()

                self.yang_name = "manager"
                self.yang_parent_name = "event"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("environment", ("environment", Native.Event.Manager.Environment)), ("directory", ("directory", Native.Event.Manager.Directory)), ("session", ("session", Native.Event.Manager.Session)), ("applet", ("applet", Native.Event.Manager.Applet))])
                self._leafs = OrderedDict()

                self.directory = Native.Event.Manager.Directory()
                self.directory.parent = self
                self._children_name_map["directory"] = "directory"

                self.session = Native.Event.Manager.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"

                self.environment = YList(self)
                self.applet = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XE-eem:manager"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/event/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Event.Manager, [], name, value)


            class Environment(Entity):
                """
                Set an Embedded Event Manager global environment variable
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: value
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-eem'
                _revision = '2017-12-20'

                def __init__(self):
                    super(Native.Event.Manager.Environment, self).__init__()

                    self.yang_name = "environment"
                    self.yang_parent_name = "manager"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('value', (YLeaf(YType.str, 'value'), ['str'])),
                    ])
                    self.name = None
                    self.value = None
                    self._segment_path = lambda: "environment" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/event/Cisco-IOS-XE-eem:manager/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Event.Manager.Environment, ['name', 'value'], name, value)


            class Directory(Entity):
                """
                Set Embedded Event Manager directory information
                
                .. attribute:: user
                
                	Set Embedded Event Manager user directory information
                	**type**\:  :py:class:`User <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Directory.User>`
                
                

                """

                _prefix = 'ios-eem'
                _revision = '2017-12-20'

                def __init__(self):
                    super(Native.Event.Manager.Directory, self).__init__()

                    self.yang_name = "directory"
                    self.yang_parent_name = "manager"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("user", ("user", Native.Event.Manager.Directory.User))])
                    self._leafs = OrderedDict()

                    self.user = Native.Event.Manager.Directory.User()
                    self.user.parent = self
                    self._children_name_map["user"] = "user"
                    self._segment_path = lambda: "directory"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/event/Cisco-IOS-XE-eem:manager/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Event.Manager.Directory, [], name, value)


                class User(Entity):
                    """
                    Set Embedded Event Manager user directory information
                    
                    .. attribute:: policy
                    
                    	Set Embedded Event Manager user policy directory
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-eem'
                    _revision = '2017-12-20'

                    def __init__(self):
                        super(Native.Event.Manager.Directory.User, self).__init__()

                        self.yang_name = "user"
                        self.yang_parent_name = "directory"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy', (YLeaf(YType.str, 'policy'), ['str'])),
                        ])
                        self.policy = None
                        self._segment_path = lambda: "user"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/event/Cisco-IOS-XE-eem:manager/directory/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Event.Manager.Directory.User, ['policy'], name, value)


            class Session(Entity):
                """
                Set Embedded Event Manager session attributes
                
                .. attribute:: cli
                
                	Set Embedded Event Manager session cli attributes
                	**type**\:  :py:class:`Cli <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Session.Cli>`
                
                

                """

                _prefix = 'ios-eem'
                _revision = '2017-12-20'

                def __init__(self):
                    super(Native.Event.Manager.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "manager"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("cli", ("cli", Native.Event.Manager.Session.Cli))])
                    self._leafs = OrderedDict()

                    self.cli = Native.Event.Manager.Session.Cli()
                    self.cli.parent = self
                    self._children_name_map["cli"] = "cli"
                    self._segment_path = lambda: "session"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/event/Cisco-IOS-XE-eem:manager/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Event.Manager.Session, [], name, value)


                class Cli(Entity):
                    """
                    Set Embedded Event Manager session cli attributes
                    
                    .. attribute:: username
                    
                    	Set username used in Embedded Event Manager cli sessions
                    	**type**\:  :py:class:`Username <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Session.Cli.Username>`
                    
                    

                    """

                    _prefix = 'ios-eem'
                    _revision = '2017-12-20'

                    def __init__(self):
                        super(Native.Event.Manager.Session.Cli, self).__init__()

                        self.yang_name = "cli"
                        self.yang_parent_name = "session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("username", ("username", Native.Event.Manager.Session.Cli.Username))])
                        self._leafs = OrderedDict()

                        self.username = Native.Event.Manager.Session.Cli.Username()
                        self.username.parent = self
                        self._children_name_map["username"] = "username"
                        self._segment_path = lambda: "cli"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/event/Cisco-IOS-XE-eem:manager/session/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Event.Manager.Session.Cli, [], name, value)


                    class Username(Entity):
                        """
                        Set username used in Embedded Event Manager cli sessions
                        
                        .. attribute:: username_in_word
                        
                        	
                        	**type**\: list of  		 :py:class:`UsernameInWord <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Session.Cli.Username.UsernameInWord>`
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Session.Cli.Username, self).__init__()

                            self.yang_name = "username"
                            self.yang_parent_name = "cli"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("username_in_word", ("username_in_word", Native.Event.Manager.Session.Cli.Username.UsernameInWord))])
                            self._leafs = OrderedDict()

                            self.username_in_word = YList(self)
                            self._segment_path = lambda: "username"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/event/Cisco-IOS-XE-eem:manager/session/cli/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Session.Cli.Username, [], name, value)


                        class UsernameInWord(Entity):
                            """
                            
                            
                            .. attribute:: username_in_word  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: privilege
                            
                            	Set user privilege level
                            	**type**\: int
                            
                            	**range:** 0..15
                            
                            

                            """

                            _prefix = 'ios-eem'
                            _revision = '2017-12-20'

                            def __init__(self):
                                super(Native.Event.Manager.Session.Cli.Username.UsernameInWord, self).__init__()

                                self.yang_name = "username_in_word"
                                self.yang_parent_name = "username"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['username_in_word']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('username_in_word', (YLeaf(YType.str, 'username_in_word'), ['str'])),
                                    ('privilege', (YLeaf(YType.uint8, 'privilege'), ['int'])),
                                ])
                                self.username_in_word = None
                                self.privilege = None
                                self._segment_path = lambda: "username_in_word" + "[username_in_word='" + str(self.username_in_word) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/event/Cisco-IOS-XE-eem:manager/session/cli/username/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Event.Manager.Session.Cli.Username.UsernameInWord, ['username_in_word', 'privilege'], name, value)


            class Applet(Entity):
                """
                Register an Event Manager applet
                
                .. attribute:: name  (key)
                
                	
                	**type**\: str
                
                .. attribute:: authorization
                
                	Specify an authorization type for the applet
                	**type**\:  :py:class:`Authorization <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Authorization>`
                
                .. attribute:: class_
                
                	Specify a class for the applet
                	**type**\: str
                
                	**pattern:** [A\-Z]\|default
                
                .. attribute:: trap
                
                	Generate an SNMP trap when applet is triggered
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: event
                
                	Add or modify event information
                	**type**\:  :py:class:`Event_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_>`
                
                .. attribute:: action
                
                	Add or modify an action statement
                	**type**\: list of  		 :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action>`
                
                .. attribute:: description
                
                	Add or modify an applet description
                	**type**\: str
                
                .. attribute:: trigger
                
                	Enter applet trigger configuration submode
                	**type**\:  :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Trigger>`
                
                

                """

                _prefix = 'ios-eem'
                _revision = '2017-12-20'

                def __init__(self):
                    super(Native.Event.Manager.Applet, self).__init__()

                    self.yang_name = "applet"
                    self.yang_parent_name = "manager"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("event", ("event", Native.Event.Manager.Applet.Event_)), ("action", ("action", Native.Event.Manager.Applet.Action)), ("trigger", ("trigger", Native.Event.Manager.Applet.Trigger))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('authorization', (YLeaf(YType.enumeration, 'authorization'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Event.Manager.Applet.Authorization')])),
                        ('class_', (YLeaf(YType.str, 'class'), ['str'])),
                        ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.name = None
                    self.authorization = None
                    self.class_ = None
                    self.trap = None
                    self.description = None

                    self.event = Native.Event.Manager.Applet.Event_()
                    self.event.parent = self
                    self._children_name_map["event"] = "event"

                    self.trigger = Native.Event.Manager.Applet.Trigger()
                    self.trigger.parent = self
                    self._children_name_map["trigger"] = "trigger"

                    self.action = YList(self)
                    self._segment_path = lambda: "applet" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/event/Cisco-IOS-XE-eem:manager/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Event.Manager.Applet, ['name', 'authorization', 'class_', 'trap', 'description'], name, value)

                class Authorization(Enum):
                    """
                    Authorization (Enum Class)

                    Specify an authorization type for the applet

                    .. data:: bypass = 0

                    """

                    bypass = Enum.YLeaf(0, "bypass")



                class Event_(Entity):
                    """
                    Add or modify event information
                    
                    .. attribute:: timer
                    
                    	Timer event
                    	**type**\:  :py:class:`Timer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Timer>`
                    
                    .. attribute:: snmp_notification
                    
                    	SNMP Notification Event
                    	**type**\:  :py:class:`SnmpNotification <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.SnmpNotification>`
                    
                    .. attribute:: syslog
                    
                    	Syslog event
                    	**type**\:  :py:class:`Syslog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Syslog>`
                    
                    .. attribute:: track
                    
                    	Tracking object event
                    	**type**\:  :py:class:`Track <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Track>`
                    
                    .. attribute:: none
                    
                    	Manually run policy event
                    	**type**\:  :py:class:`Y_None <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Y_None>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: resource
                    
                    	Resource event
                    	**type**\:  :py:class:`Resource <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Resource>`
                    
                    .. attribute:: rpc
                    
                    	Remote Procedure Call event
                    	**type**\:  :py:class:`Rpc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Rpc>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: config
                    
                    	Configuration policy event
                    	**type**\:  :py:class:`Config <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Config>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: env
                    
                    	Environmental event
                    	**type**\:  :py:class:`Env <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Env>`
                    
                    .. attribute:: oir
                    
                    	OIR event
                    	**type**\:  :py:class:`Oir <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Oir>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: rf
                    
                    	event match string
                    	**type**\:  :py:class:`Rf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Rf>`
                    
                    

                    """

                    _prefix = 'ios-eem'
                    _revision = '2017-12-20'

                    def __init__(self):
                        super(Native.Event.Manager.Applet.Event_, self).__init__()

                        self.yang_name = "event"
                        self.yang_parent_name = "applet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("timer", ("timer", Native.Event.Manager.Applet.Event_.Timer)), ("snmp-notification", ("snmp_notification", Native.Event.Manager.Applet.Event_.SnmpNotification)), ("syslog", ("syslog", Native.Event.Manager.Applet.Event_.Syslog)), ("track", ("track", Native.Event.Manager.Applet.Event_.Track)), ("none", ("none", Native.Event.Manager.Applet.Event_.Y_None)), ("resource", ("resource", Native.Event.Manager.Applet.Event_.Resource)), ("rpc", ("rpc", Native.Event.Manager.Applet.Event_.Rpc)), ("config", ("config", Native.Event.Manager.Applet.Event_.Config)), ("env", ("env", Native.Event.Manager.Applet.Event_.Env)), ("oir", ("oir", Native.Event.Manager.Applet.Event_.Oir)), ("rf", ("rf", Native.Event.Manager.Applet.Event_.Rf))])
                        self._leafs = OrderedDict()

                        self.timer = Native.Event.Manager.Applet.Event_.Timer()
                        self.timer.parent = self
                        self._children_name_map["timer"] = "timer"

                        self.snmp_notification = Native.Event.Manager.Applet.Event_.SnmpNotification()
                        self.snmp_notification.parent = self
                        self._children_name_map["snmp_notification"] = "snmp-notification"

                        self.syslog = Native.Event.Manager.Applet.Event_.Syslog()
                        self.syslog.parent = self
                        self._children_name_map["syslog"] = "syslog"

                        self.track = Native.Event.Manager.Applet.Event_.Track()
                        self.track.parent = self
                        self._children_name_map["track"] = "track"

                        self.none = None
                        self._children_name_map["none"] = "none"

                        self.resource = Native.Event.Manager.Applet.Event_.Resource()
                        self.resource.parent = self
                        self._children_name_map["resource"] = "resource"

                        self.rpc = None
                        self._children_name_map["rpc"] = "rpc"

                        self.config = None
                        self._children_name_map["config"] = "config"

                        self.env = Native.Event.Manager.Applet.Event_.Env()
                        self.env.parent = self
                        self._children_name_map["env"] = "env"

                        self.oir = None
                        self._children_name_map["oir"] = "oir"

                        self.rf = Native.Event.Manager.Applet.Event_.Rf()
                        self.rf.parent = self
                        self._children_name_map["rf"] = "rf"
                        self._segment_path = lambda: "event"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Event.Manager.Applet.Event_, [], name, value)


                    class Timer(Entity):
                        """
                        Timer event
                        
                        .. attribute:: absolute
                        
                        	Absolute timer event
                        	**type**\:  :py:class:`Absolute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Timer.Absolute>`
                        
                        .. attribute:: countdown
                        
                        	Countdown timer event
                        	**type**\:  :py:class:`Countdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Timer.Countdown>`
                        
                        .. attribute:: cron
                        
                        	cron timer event
                        	**type**\:  :py:class:`Cron <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Timer.Cron>`
                        
                        .. attribute:: watchdog
                        
                        	Watchdog timer event
                        	**type**\:  :py:class:`Watchdog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Timer.Watchdog>`
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Event_.Timer, self).__init__()

                            self.yang_name = "timer"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("absolute", ("absolute", Native.Event.Manager.Applet.Event_.Timer.Absolute)), ("countdown", ("countdown", Native.Event.Manager.Applet.Event_.Timer.Countdown)), ("cron", ("cron", Native.Event.Manager.Applet.Event_.Timer.Cron)), ("watchdog", ("watchdog", Native.Event.Manager.Applet.Event_.Timer.Watchdog))])
                            self._leafs = OrderedDict()

                            self.absolute = Native.Event.Manager.Applet.Event_.Timer.Absolute()
                            self.absolute.parent = self
                            self._children_name_map["absolute"] = "absolute"

                            self.countdown = Native.Event.Manager.Applet.Event_.Timer.Countdown()
                            self.countdown.parent = self
                            self._children_name_map["countdown"] = "countdown"

                            self.cron = Native.Event.Manager.Applet.Event_.Timer.Cron()
                            self.cron.parent = self
                            self._children_name_map["cron"] = "cron"

                            self.watchdog = Native.Event.Manager.Applet.Event_.Timer.Watchdog()
                            self.watchdog.parent = self
                            self._children_name_map["watchdog"] = "watchdog"
                            self._segment_path = lambda: "timer"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Event_.Timer, [], name, value)


                        class Absolute(Entity):
                            """
                            Absolute timer event
                            
                            .. attribute:: maxrun
                            
                            	Maximum runtime of applet
                            	**type**\: int
                            
                            	**range:** 0..31536000
                            
                            .. attribute:: name
                            
                            	Timer name string
                            	**type**\: str
                            
                            .. attribute:: ratelimit
                            
                            	seconds[.milliseconds] value
                            	**type**\: int
                            
                            	**range:** 0..31536000
                            
                            .. attribute:: time
                            
                            	Time period for watchdog / countdown / absolute timer
                            	**type**\: int
                            
                            	**range:** 1..2085978494
                            
                            

                            """

                            _prefix = 'ios-eem'
                            _revision = '2017-12-20'

                            def __init__(self):
                                super(Native.Event.Manager.Applet.Event_.Timer.Absolute, self).__init__()

                                self.yang_name = "absolute"
                                self.yang_parent_name = "timer"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('ratelimit', (YLeaf(YType.uint32, 'ratelimit'), ['int'])),
                                    ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                ])
                                self.maxrun = None
                                self.name = None
                                self.ratelimit = None
                                self.time = None
                                self._segment_path = lambda: "absolute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Event.Manager.Applet.Event_.Timer.Absolute, ['maxrun', 'name', 'ratelimit', 'time'], name, value)


                        class Countdown(Entity):
                            """
                            Countdown timer event
                            
                            .. attribute:: maxrun
                            
                            	Maximum runtime of applet
                            	**type**\: int
                            
                            	**range:** 0..31536000
                            
                            .. attribute:: name
                            
                            	Timer name string
                            	**type**\: str
                            
                            .. attribute:: ratelimit
                            
                            	seconds[.milliseconds] value
                            	**type**\: int
                            
                            	**range:** 0..31536000
                            
                            .. attribute:: time
                            
                            	Time period for watchdog / countdown / absolute timer
                            	**type**\: int
                            
                            	**range:** 1..2085978494
                            
                            

                            """

                            _prefix = 'ios-eem'
                            _revision = '2017-12-20'

                            def __init__(self):
                                super(Native.Event.Manager.Applet.Event_.Timer.Countdown, self).__init__()

                                self.yang_name = "countdown"
                                self.yang_parent_name = "timer"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('ratelimit', (YLeaf(YType.uint32, 'ratelimit'), ['int'])),
                                    ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                ])
                                self.maxrun = None
                                self.name = None
                                self.ratelimit = None
                                self.time = None
                                self._segment_path = lambda: "countdown"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Event.Manager.Applet.Event_.Timer.Countdown, ['maxrun', 'name', 'ratelimit', 'time'], name, value)


                        class Cron(Entity):
                            """
                            cron timer event
                            
                            .. attribute:: maxrun
                            
                            	Maximum runtime of applet
                            	**type**\: int
                            
                            	**range:** 0..31536000
                            
                            .. attribute:: name
                            
                            	Timer name string
                            	**type**\: str
                            
                            .. attribute:: ratelimit
                            
                            	seconds[.milliseconds] value
                            	**type**\: int
                            
                            	**range:** 0..31536000
                            
                            .. attribute:: cron_entry
                            
                            	Cron entry for cron timer
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-eem'
                            _revision = '2017-12-20'

                            def __init__(self):
                                super(Native.Event.Manager.Applet.Event_.Timer.Cron, self).__init__()

                                self.yang_name = "cron"
                                self.yang_parent_name = "timer"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('ratelimit', (YLeaf(YType.uint32, 'ratelimit'), ['int'])),
                                    ('cron_entry', (YLeaf(YType.str, 'cron-entry'), ['str'])),
                                ])
                                self.maxrun = None
                                self.name = None
                                self.ratelimit = None
                                self.cron_entry = None
                                self._segment_path = lambda: "cron"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Event.Manager.Applet.Event_.Timer.Cron, ['maxrun', 'name', 'ratelimit', 'cron_entry'], name, value)


                        class Watchdog(Entity):
                            """
                            Watchdog timer event
                            
                            .. attribute:: maxrun
                            
                            	Maximum runtime of applet
                            	**type**\: int
                            
                            	**range:** 0..31536000
                            
                            .. attribute:: name
                            
                            	Timer name string
                            	**type**\: str
                            
                            .. attribute:: ratelimit
                            
                            	seconds[.milliseconds] value
                            	**type**\: int
                            
                            	**range:** 0..31536000
                            
                            .. attribute:: time
                            
                            	Time period for watchdog / countdown / absolute timer
                            	**type**\: int
                            
                            	**range:** 1..2085978494
                            
                            

                            """

                            _prefix = 'ios-eem'
                            _revision = '2017-12-20'

                            def __init__(self):
                                super(Native.Event.Manager.Applet.Event_.Timer.Watchdog, self).__init__()

                                self.yang_name = "watchdog"
                                self.yang_parent_name = "timer"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('ratelimit', (YLeaf(YType.uint32, 'ratelimit'), ['int'])),
                                    ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                ])
                                self.maxrun = None
                                self.name = None
                                self.ratelimit = None
                                self.time = None
                                self._segment_path = lambda: "watchdog"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Event.Manager.Applet.Event_.Timer.Watchdog, ['maxrun', 'name', 'ratelimit', 'time'], name, value)


                    class SnmpNotification(Entity):
                        """
                        SNMP Notification Event
                        
                        .. attribute:: oid
                        
                        	Object ID of data element
                        	**type**\: str
                        
                        .. attribute:: oid_val
                        
                        	Comparison value
                        	**type**\: str
                        
                        .. attribute:: op
                        
                        	Operator
                        	**type**\:  :py:class:`OperatorType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_eem.OperatorType>`
                        
                        .. attribute:: src_ip_address
                        
                        	Source ip address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: dest_ip_address
                        
                        	Destination ip address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Event_.SnmpNotification, self).__init__()

                            self.yang_name = "snmp-notification"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('oid', (YLeaf(YType.str, 'oid'), ['str'])),
                                ('oid_val', (YLeaf(YType.str, 'oid-val'), ['str'])),
                                ('op', (YLeaf(YType.enumeration, 'op'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_eem', 'OperatorType', '')])),
                                ('src_ip_address', (YLeaf(YType.str, 'src-ip-address'), ['str','str'])),
                                ('dest_ip_address', (YLeaf(YType.str, 'dest-ip-address'), ['str','str'])),
                            ])
                            self.oid = None
                            self.oid_val = None
                            self.op = None
                            self.src_ip_address = None
                            self.dest_ip_address = None
                            self._segment_path = lambda: "snmp-notification"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Event_.SnmpNotification, ['oid', 'oid_val', 'op', 'src_ip_address', 'dest_ip_address'], name, value)


                    class Syslog(Entity):
                        """
                        Syslog event
                        
                        .. attribute:: pattern
                        
                        	Pattern match string for the entire message
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Event_.Syslog, self).__init__()

                            self.yang_name = "syslog"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('pattern', (YLeaf(YType.str, 'pattern'), ['str'])),
                            ])
                            self.pattern = None
                            self._segment_path = lambda: "syslog"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Event_.Syslog, ['pattern'], name, value)


                    class Track(Entity):
                        """
                        Tracking object event
                        
                        .. attribute:: track_object_number
                        
                        	Tracking object number
                        	**type**\: int
                        
                        	**range:** 1..1000
                        
                        .. attribute:: state
                        
                        	State of tracking object
                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Track.State>`
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Event_.Track, self).__init__()

                            self.yang_name = "track"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('track_object_number', (YLeaf(YType.uint16, 'track-object-number'), ['int'])),
                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Event.Manager.Applet.Event_.Track.State')])),
                            ])
                            self.track_object_number = None
                            self.state = None
                            self._segment_path = lambda: "track"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Event_.Track, ['track_object_number', 'state'], name, value)

                        class State(Enum):
                            """
                            State (Enum Class)

                            State of tracking object

                            .. data:: any = 0

                            .. data:: down = 1

                            .. data:: up = 2

                            """

                            any = Enum.YLeaf(0, "any")

                            down = Enum.YLeaf(1, "down")

                            up = Enum.YLeaf(2, "up")



                    class Y_None(Entity):
                        """
                        Manually run policy event
                        
                        .. attribute:: default
                        
                        	Default action timer
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maxrun
                        
                        	Maximum runtime of applet
                        	**type**\: int
                        
                        	**range:** 0..31536000
                        
                        .. attribute:: ratelimit
                        
                        	seconds[.milliseconds] value
                        	**type**\: int
                        
                        	**range:** 0..31536000
                        
                        .. attribute:: sync
                        
                        	EEM policy execution sync or async
                        	**type**\:  :py:class:`Sync <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Y_None.Sync>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Event_.Y_None, self).__init__()

                            self.yang_name = "none"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                                ('ratelimit', (YLeaf(YType.uint32, 'ratelimit'), ['int'])),
                                ('sync', (YLeaf(YType.enumeration, 'sync'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Event.Manager.Applet.Event_.Y_None.Sync')])),
                            ])
                            self.default = None
                            self.maxrun = None
                            self.ratelimit = None
                            self.sync = None
                            self._segment_path = lambda: "none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Event_.Y_None, ['default', 'maxrun', 'ratelimit', 'sync'], name, value)

                        class Sync(Enum):
                            """
                            Sync (Enum Class)

                            EEM policy execution sync or async

                            .. data:: yes = 0

                            .. data:: no = 1

                            """

                            yes = Enum.YLeaf(0, "yes")

                            no = Enum.YLeaf(1, "no")



                    class Resource(Entity):
                        """
                        Resource event
                        
                        .. attribute:: policy
                        
                        	Resource policy name string
                        	**type**\: str
                        
                        .. attribute:: maxrun
                        
                        	Maximum runtime of applet
                        	**type**\: int
                        
                        	**range:** 0..31536000
                        
                        .. attribute:: ratelimit
                        
                        	seconds[.milliseconds] value
                        	**type**\: int
                        
                        	**range:** 0..31536000
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Event_.Resource, self).__init__()

                            self.yang_name = "resource"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('policy', (YLeaf(YType.str, 'policy'), ['str'])),
                                ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                                ('ratelimit', (YLeaf(YType.uint32, 'ratelimit'), ['int'])),
                            ])
                            self.policy = None
                            self.maxrun = None
                            self.ratelimit = None
                            self._segment_path = lambda: "resource"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Event_.Resource, ['policy', 'maxrun', 'ratelimit'], name, value)


                    class Rpc(Entity):
                        """
                        Remote Procedure Call event
                        
                        .. attribute:: default
                        
                        	Default action timer
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maxrun
                        
                        	Maximum runtime of applet
                        	**type**\: int
                        
                        	**range:** 0..31536000
                        
                        .. attribute:: ratelimit
                        
                        	seconds[.milliseconds] value
                        	**type**\: int
                        
                        	**range:** 0..31536000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Event_.Rpc, self).__init__()

                            self.yang_name = "rpc"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('default', (YLeaf(YType.uint32, 'default'), ['int'])),
                                ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                                ('ratelimit', (YLeaf(YType.uint32, 'ratelimit'), ['int'])),
                            ])
                            self.default = None
                            self.maxrun = None
                            self.ratelimit = None
                            self._segment_path = lambda: "rpc"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Event_.Rpc, ['default', 'maxrun', 'ratelimit'], name, value)


                    class Config(Entity):
                        """
                        Configuration policy event
                        
                        .. attribute:: maxrun
                        
                        	Maximum runtime of applet
                        	**type**\: int
                        
                        	**range:** 0..31536000
                        
                        .. attribute:: ratelimit
                        
                        	seconds[.milliseconds] value
                        	**type**\: int
                        
                        	**range:** 0..31536000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Event_.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                                ('ratelimit', (YLeaf(YType.uint32, 'ratelimit'), ['int'])),
                            ])
                            self.maxrun = None
                            self.ratelimit = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Event_.Config, ['maxrun', 'ratelimit'], name, value)


                    class Env(Entity):
                        """
                        Environmental event
                        
                        .. attribute:: severity
                        
                        	alarm severity
                        	**type**\:  :py:class:`Severity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Env.Severity>`
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Event_.Env, self).__init__()

                            self.yang_name = "env"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("severity", ("severity", Native.Event.Manager.Applet.Event_.Env.Severity))])
                            self._leafs = OrderedDict()

                            self.severity = Native.Event.Manager.Applet.Event_.Env.Severity()
                            self.severity.parent = self
                            self._children_name_map["severity"] = "severity"
                            self._segment_path = lambda: "env"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Event_.Env, [], name, value)


                        class Severity(Entity):
                            """
                            alarm severity
                            
                            .. attribute:: major
                            
                            	major environmental alarm
                            	**type**\:  :py:class:`Major <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Env.Severity.Major>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: minor
                            
                            	minor environmental alarm
                            	**type**\:  :py:class:`Minor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Env.Severity.Minor>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-eem'
                            _revision = '2017-12-20'

                            def __init__(self):
                                super(Native.Event.Manager.Applet.Event_.Env.Severity, self).__init__()

                                self.yang_name = "severity"
                                self.yang_parent_name = "env"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("major", ("major", Native.Event.Manager.Applet.Event_.Env.Severity.Major)), ("minor", ("minor", Native.Event.Manager.Applet.Event_.Env.Severity.Minor))])
                                self._leafs = OrderedDict()

                                self.major = None
                                self._children_name_map["major"] = "major"

                                self.minor = None
                                self._children_name_map["minor"] = "minor"
                                self._segment_path = lambda: "severity"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Event.Manager.Applet.Event_.Env.Severity, [], name, value)


                            class Major(Entity):
                                """
                                major environmental alarm
                                
                                .. attribute:: maxrun
                                
                                	Maximum runtime of applet
                                	**type**\: int
                                
                                	**range:** 0..31536000
                                
                                .. attribute:: ratelimit
                                
                                	seconds[.milliseconds] value
                                	**type**\: int
                                
                                	**range:** 0..31536000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eem'
                                _revision = '2017-12-20'

                                def __init__(self):
                                    super(Native.Event.Manager.Applet.Event_.Env.Severity.Major, self).__init__()

                                    self.yang_name = "major"
                                    self.yang_parent_name = "severity"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                                        ('ratelimit', (YLeaf(YType.uint32, 'ratelimit'), ['int'])),
                                    ])
                                    self.maxrun = None
                                    self.ratelimit = None
                                    self._segment_path = lambda: "major"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Event.Manager.Applet.Event_.Env.Severity.Major, ['maxrun', 'ratelimit'], name, value)


                            class Minor(Entity):
                                """
                                minor environmental alarm
                                
                                .. attribute:: maxrun
                                
                                	Maximum runtime of applet
                                	**type**\: int
                                
                                	**range:** 0..31536000
                                
                                .. attribute:: ratelimit
                                
                                	seconds[.milliseconds] value
                                	**type**\: int
                                
                                	**range:** 0..31536000
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-eem'
                                _revision = '2017-12-20'

                                def __init__(self):
                                    super(Native.Event.Manager.Applet.Event_.Env.Severity.Minor, self).__init__()

                                    self.yang_name = "minor"
                                    self.yang_parent_name = "severity"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                                        ('ratelimit', (YLeaf(YType.uint32, 'ratelimit'), ['int'])),
                                    ])
                                    self.maxrun = None
                                    self.ratelimit = None
                                    self._segment_path = lambda: "minor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Event.Manager.Applet.Event_.Env.Severity.Minor, ['maxrun', 'ratelimit'], name, value)


                    class Oir(Entity):
                        """
                        OIR event
                        
                        .. attribute:: event
                        
                        	OIR event
                        	**type**\:  :py:class:`Event_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Event_.Oir.Event_>`
                        
                        .. attribute:: maxrun
                        
                        	Maximum runtime of applet
                        	**type**\: int
                        
                        	**range:** 0..31536000
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Event_.Oir, self).__init__()

                            self.yang_name = "oir"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('event', (YLeaf(YType.enumeration, 'event'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Event.Manager.Applet.Event_.Oir.Event_')])),
                                ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                            ])
                            self.event = None
                            self.maxrun = None
                            self._segment_path = lambda: "oir"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Event_.Oir, ['event', 'maxrun'], name, value)

                        class Event_(Enum):
                            """
                            Event\_ (Enum Class)

                            OIR event

                            .. data:: all = 0

                            .. data:: insert = 1

                            .. data:: removal = 2

                            """

                            all = Enum.YLeaf(0, "all")

                            insert = Enum.YLeaf(1, "insert")

                            removal = Enum.YLeaf(2, "removal")



                    class Rf(Entity):
                        """
                        event match string
                        
                        .. attribute:: event
                        
                        	Event match string
                        	**type**\: str
                        
                        .. attribute:: maxrun
                        
                        	Maximum runtime of applet
                        	**type**\: int
                        
                        	**range:** 0..31536000
                        
                        .. attribute:: ratelimit
                        
                        	seconds[.milliseconds] value
                        	**type**\: int
                        
                        	**range:** 0..31536000
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Event_.Rf, self).__init__()

                            self.yang_name = "rf"
                            self.yang_parent_name = "event"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('event', (YLeaf(YType.str, 'event'), ['str'])),
                                ('maxrun', (YLeaf(YType.uint32, 'maxrun'), ['int'])),
                                ('ratelimit', (YLeaf(YType.uint32, 'ratelimit'), ['int'])),
                            ])
                            self.event = None
                            self.maxrun = None
                            self.ratelimit = None
                            self._segment_path = lambda: "rf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Event_.Rf, ['event', 'maxrun', 'ratelimit'], name, value)


                class Action(Entity):
                    """
                    Add or modify an action statement
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: cli
                    
                    	Execute a CLI command
                    	**type**\:  :py:class:`Cli <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.Cli>`
                    
                    .. attribute:: if_
                    
                    	if conditional
                    	**type**\:  :py:class:`If <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.If>`
                    
                    .. attribute:: info
                    
                    	Obtain system specific information
                    	**type**\:  :py:class:`Info <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.Info>`
                    
                    .. attribute:: end
                    
                    	end conditional block
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: regexp
                    
                    	regular expression match
                    	**type**\:  :py:class:`Regexp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.Regexp>`
                    
                    .. attribute:: snmp_trap
                    
                    	Send an SNMP trap
                    	**type**\:  :py:class:`SnmpTrap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.SnmpTrap>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: string
                    
                    	string commands
                    	**type**\:  :py:class:`String <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.String>`
                    
                    .. attribute:: syslog
                    
                    	Log a syslog message
                    	**type**\:  :py:class:`Syslog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.Syslog>`
                    
                    .. attribute:: exit
                    
                    	Exit from applet run
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-eem'
                    _revision = '2017-12-20'

                    def __init__(self):
                        super(Native.Event.Manager.Applet.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "applet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("cli", ("cli", Native.Event.Manager.Applet.Action.Cli)), ("if", ("if_", Native.Event.Manager.Applet.Action.If)), ("info", ("info", Native.Event.Manager.Applet.Action.Info)), ("regexp", ("regexp", Native.Event.Manager.Applet.Action.Regexp)), ("snmp-trap", ("snmp_trap", Native.Event.Manager.Applet.Action.SnmpTrap)), ("string", ("string", Native.Event.Manager.Applet.Action.String)), ("syslog", ("syslog", Native.Event.Manager.Applet.Action.Syslog))])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('end', (YLeaf(YType.empty, 'end'), ['Empty'])),
                            ('exit', (YLeaf(YType.empty, 'exit'), ['Empty'])),
                        ])
                        self.name = None
                        self.end = None
                        self.exit = None

                        self.cli = Native.Event.Manager.Applet.Action.Cli()
                        self.cli.parent = self
                        self._children_name_map["cli"] = "cli"

                        self.if_ = Native.Event.Manager.Applet.Action.If()
                        self.if_.parent = self
                        self._children_name_map["if_"] = "if"

                        self.info = Native.Event.Manager.Applet.Action.Info()
                        self.info.parent = self
                        self._children_name_map["info"] = "info"

                        self.regexp = Native.Event.Manager.Applet.Action.Regexp()
                        self.regexp.parent = self
                        self._children_name_map["regexp"] = "regexp"

                        self.snmp_trap = None
                        self._children_name_map["snmp_trap"] = "snmp-trap"

                        self.string = Native.Event.Manager.Applet.Action.String()
                        self.string.parent = self
                        self._children_name_map["string"] = "string"

                        self.syslog = Native.Event.Manager.Applet.Action.Syslog()
                        self.syslog.parent = self
                        self._children_name_map["syslog"] = "syslog"
                        self._segment_path = lambda: "action" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Event.Manager.Applet.Action, ['name', 'end', 'exit'], name, value)


                    class Cli(Entity):
                        """
                        Execute a CLI command
                        
                        .. attribute:: command
                        
                        	CLI command
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Action.Cli, self).__init__()

                            self.yang_name = "cli"
                            self.yang_parent_name = "action"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('command', (YLeaf(YType.str, 'command'), ['str'])),
                            ])
                            self.command = None
                            self._segment_path = lambda: "cli"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Action.Cli, ['command'], name, value)


                    class If(Entity):
                        """
                        if conditional
                        
                        .. attribute:: string_op_1
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: keyword
                        
                        	
                        	**type**\:  :py:class:`OperatorType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_eem.OperatorType>`
                        
                        .. attribute:: string_op_2
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: goto
                        
                        	goto label
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Action.If, self).__init__()

                            self.yang_name = "if"
                            self.yang_parent_name = "action"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('string_op_1', (YLeaf(YType.str, 'string-op-1'), ['str'])),
                                ('keyword', (YLeaf(YType.enumeration, 'keyword'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_eem', 'OperatorType', '')])),
                                ('string_op_2', (YLeaf(YType.str, 'string-op-2'), ['str'])),
                                ('goto', (YLeaf(YType.str, 'goto'), ['str'])),
                            ])
                            self.string_op_1 = None
                            self.keyword = None
                            self.string_op_2 = None
                            self.goto = None
                            self._segment_path = lambda: "if"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Action.If, ['string_op_1', 'keyword', 'string_op_2', 'goto'], name, value)


                    class Info(Entity):
                        """
                        Obtain system specific information
                        
                        .. attribute:: type
                        
                        	Type of information to obtain
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.Info.Type>`
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Action.Info, self).__init__()

                            self.yang_name = "info"
                            self.yang_parent_name = "action"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Event.Manager.Applet.Action.Info.Type))])
                            self._leafs = OrderedDict()

                            self.type = Native.Event.Manager.Applet.Action.Info.Type()
                            self.type.parent = self
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "info"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Action.Info, [], name, value)


                        class Type(Entity):
                            """
                            Type of information to obtain
                            
                            .. attribute:: snmp
                            
                            	SNMP information
                            	**type**\:  :py:class:`Snmp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.Info.Type.Snmp>`
                            
                            

                            """

                            _prefix = 'ios-eem'
                            _revision = '2017-12-20'

                            def __init__(self):
                                super(Native.Event.Manager.Applet.Action.Info.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("snmp", ("snmp", Native.Event.Manager.Applet.Action.Info.Type.Snmp))])
                                self._leafs = OrderedDict()

                                self.snmp = Native.Event.Manager.Applet.Action.Info.Type.Snmp()
                                self.snmp.parent = self
                                self._children_name_map["snmp"] = "snmp"
                                self._segment_path = lambda: "type"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Event.Manager.Applet.Action.Info.Type, [], name, value)


                            class Snmp(Entity):
                                """
                                SNMP information
                                
                                .. attribute:: var
                                
                                	Trap variable
                                	**type**\:  :py:class:`Var <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.Info.Type.Snmp.Var>`
                                
                                .. attribute:: trap
                                
                                	SNMP trap
                                	**type**\:  :py:class:`Trap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.Info.Type.Snmp.Trap>`
                                
                                

                                """

                                _prefix = 'ios-eem'
                                _revision = '2017-12-20'

                                def __init__(self):
                                    super(Native.Event.Manager.Applet.Action.Info.Type.Snmp, self).__init__()

                                    self.yang_name = "snmp"
                                    self.yang_parent_name = "type"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("var", ("var", Native.Event.Manager.Applet.Action.Info.Type.Snmp.Var)), ("trap", ("trap", Native.Event.Manager.Applet.Action.Info.Type.Snmp.Trap))])
                                    self._leafs = OrderedDict()

                                    self.var = Native.Event.Manager.Applet.Action.Info.Type.Snmp.Var()
                                    self.var.parent = self
                                    self._children_name_map["var"] = "var"

                                    self.trap = Native.Event.Manager.Applet.Action.Info.Type.Snmp.Trap()
                                    self.trap.parent = self
                                    self._children_name_map["trap"] = "trap"
                                    self._segment_path = lambda: "snmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Event.Manager.Applet.Action.Info.Type.Snmp, [], name, value)


                                class Var(Entity):
                                    """
                                    Trap variable
                                    
                                    .. attribute:: variable_name
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: oid
                                    
                                    	SNMP object id
                                    	**type**\: str
                                    
                                    .. attribute:: oid_type
                                    
                                    	
                                    	**type**\:  :py:class:`OidType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Event.Manager.Applet.Action.Info.Type.Snmp.Var.OidType>`
                                    
                                    .. attribute:: oid_type_value
                                    
                                    	
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-eem'
                                    _revision = '2017-12-20'

                                    def __init__(self):
                                        super(Native.Event.Manager.Applet.Action.Info.Type.Snmp.Var, self).__init__()

                                        self.yang_name = "var"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('variable_name', (YLeaf(YType.str, 'variable-name'), ['str'])),
                                            ('oid', (YLeaf(YType.str, 'oid'), ['str'])),
                                            ('oid_type', (YLeaf(YType.enumeration, 'oid-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Event.Manager.Applet.Action.Info.Type.Snmp.Var.OidType')])),
                                            ('oid_type_value', (YLeaf(YType.str, 'oid-type-value'), ['str'])),
                                        ])
                                        self.variable_name = None
                                        self.oid = None
                                        self.oid_type = None
                                        self.oid_type_value = None
                                        self._segment_path = lambda: "var"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Event.Manager.Applet.Action.Info.Type.Snmp.Var, ['variable_name', 'oid', 'oid_type', 'oid_type_value'], name, value)

                                    class OidType(Enum):
                                        """
                                        OidType (Enum Class)

                                        .. data:: counter = 0

                                        .. data:: gauge = 1

                                        .. data:: int = 2

                                        .. data:: ipv4 = 3

                                        .. data:: octet = 4

                                        .. data:: string = 5

                                        .. data:: uint = 6

                                        """

                                        counter = Enum.YLeaf(0, "counter")

                                        gauge = Enum.YLeaf(1, "gauge")

                                        int = Enum.YLeaf(2, "int")

                                        ipv4 = Enum.YLeaf(3, "ipv4")

                                        octet = Enum.YLeaf(4, "octet")

                                        string = Enum.YLeaf(5, "string")

                                        uint = Enum.YLeaf(6, "uint")



                                class Trap(Entity):
                                    """
                                    SNMP trap
                                    
                                    .. attribute:: enterprise_oid
                                    
                                    	Enterprise oid
                                    	**type**\: str
                                    
                                    .. attribute:: generic_trapnum
                                    
                                    	Generic trap number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: specific_trapnum
                                    
                                    	Specific trap number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: trap_oid
                                    
                                    	Trap oid
                                    	**type**\: str
                                    
                                    .. attribute:: trap_var
                                    
                                    	Trap variable
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ios-eem'
                                    _revision = '2017-12-20'

                                    def __init__(self):
                                        super(Native.Event.Manager.Applet.Action.Info.Type.Snmp.Trap, self).__init__()

                                        self.yang_name = "trap"
                                        self.yang_parent_name = "snmp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enterprise_oid', (YLeaf(YType.str, 'enterprise-oid'), ['str'])),
                                            ('generic_trapnum', (YLeaf(YType.uint32, 'generic-trapnum'), ['int'])),
                                            ('specific_trapnum', (YLeaf(YType.uint32, 'specific-trapnum'), ['int'])),
                                            ('trap_oid', (YLeaf(YType.str, 'trap-oid'), ['str'])),
                                            ('trap_var', (YLeaf(YType.str, 'trap-var'), ['str'])),
                                        ])
                                        self.enterprise_oid = None
                                        self.generic_trapnum = None
                                        self.specific_trapnum = None
                                        self.trap_oid = None
                                        self.trap_var = None
                                        self._segment_path = lambda: "trap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Event.Manager.Applet.Action.Info.Type.Snmp.Trap, ['enterprise_oid', 'generic_trapnum', 'specific_trapnum', 'trap_oid', 'trap_var'], name, value)


                    class Regexp(Entity):
                        """
                        regular expression match
                        
                        .. attribute:: string_pattern
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: string_input
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: string_match
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: string_submatch1
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: string_submatch2
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: string_submatch3
                        
                        	
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Action.Regexp, self).__init__()

                            self.yang_name = "regexp"
                            self.yang_parent_name = "action"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('string_pattern', (YLeaf(YType.str, 'string-pattern'), ['str'])),
                                ('string_input', (YLeaf(YType.str, 'string-input'), ['str'])),
                                ('string_match', (YLeaf(YType.str, 'string-match'), ['str'])),
                                ('string_submatch1', (YLeaf(YType.str, 'string-submatch1'), ['str'])),
                                ('string_submatch2', (YLeaf(YType.str, 'string-submatch2'), ['str'])),
                                ('string_submatch3', (YLeaf(YType.str, 'string-submatch3'), ['str'])),
                            ])
                            self.string_pattern = None
                            self.string_input = None
                            self.string_match = None
                            self.string_submatch1 = None
                            self.string_submatch2 = None
                            self.string_submatch3 = None
                            self._segment_path = lambda: "regexp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Action.Regexp, ['string_pattern', 'string_input', 'string_match', 'string_submatch1', 'string_submatch2', 'string_submatch3'], name, value)


                    class SnmpTrap(Entity):
                        """
                        Send an SNMP trap
                        
                        .. attribute:: intdata1
                        
                        	SNMP integer data1
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: intdata2
                        
                        	SNMP integer data2
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: strdata
                        
                        	SNMP trap string
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Action.SnmpTrap, self).__init__()

                            self.yang_name = "snmp-trap"
                            self.yang_parent_name = "action"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('intdata1', (YLeaf(YType.int32, 'intdata1'), ['int'])),
                                ('intdata2', (YLeaf(YType.int32, 'intdata2'), ['int'])),
                                ('strdata', (YLeaf(YType.str, 'strdata'), ['str'])),
                            ])
                            self.intdata1 = None
                            self.intdata2 = None
                            self.strdata = None
                            self._segment_path = lambda: "snmp-trap"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Action.SnmpTrap, ['intdata1', 'intdata2', 'strdata'], name, value)


                    class String(Entity):
                        """
                        string commands
                        
                        .. attribute:: trim
                        
                        	trim characters from both ends of string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Action.String, self).__init__()

                            self.yang_name = "string"
                            self.yang_parent_name = "action"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('trim', (YLeaf(YType.str, 'trim'), ['str'])),
                            ])
                            self.trim = None
                            self._segment_path = lambda: "string"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Action.String, ['trim'], name, value)


                    class Syslog(Entity):
                        """
                        Log a syslog message
                        
                        .. attribute:: facility
                        
                        	Facility string
                        	**type**\: str
                        
                        .. attribute:: msg
                        
                        	Syslog message
                        	**type**\: str
                        
                        .. attribute:: priority
                        
                        	Priority of syslog message
                        	**type**\: union of the below types:
                        
                        		**type**\: int
                        
                        			**range:** 0..7
                        
                        		**type**\:  :py:class:`LoggingLevelType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.LoggingLevelType>`
                        
                        

                        """

                        _prefix = 'ios-eem'
                        _revision = '2017-12-20'

                        def __init__(self):
                            super(Native.Event.Manager.Applet.Action.Syslog, self).__init__()

                            self.yang_name = "syslog"
                            self.yang_parent_name = "action"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('facility', (YLeaf(YType.str, 'facility'), ['str'])),
                                ('msg', (YLeaf(YType.str, 'msg'), ['str'])),
                                ('priority', (YLeaf(YType.str, 'priority'), ['int',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'LoggingLevelType', '')])),
                            ])
                            self.facility = None
                            self.msg = None
                            self.priority = None
                            self._segment_path = lambda: "syslog"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Event.Manager.Applet.Action.Syslog, ['facility', 'msg', 'priority'], name, value)


                class Trigger(Entity):
                    """
                    Enter applet trigger configuration submode
                    
                    

                    """

                    _prefix = 'ios-eem'
                    _revision = '2017-12-20'

                    def __init__(self):
                        super(Native.Event.Manager.Applet.Trigger, self).__init__()

                        self.yang_name = "trigger"
                        self.yang_parent_name = "applet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "trigger"
                        self._is_frozen = True


    class Template(Entity):
        """
        template
        
        .. attribute:: template_details
        
        	
        	**type**\: list of  		 :py:class:`TemplateDetails <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails>`
        
        .. attribute:: ip_camera_interface_template
        
        	built\-in modified
        	**type**\:  :py:class:`IPCAMERAINTERFACETEMPLATE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE>`
        
        .. attribute:: lap_interface_template
        
        	built\-in modified
        	**type**\:  :py:class:`LAPINTERFACETEMPLATE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE>`
        
        .. attribute:: ap_interface_template
        
        	built\-in modified
        	**type**\:  :py:class:`APINTERFACETEMPLATE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE>`
        
        .. attribute:: dmp_interface_template
        
        	built\-in modified
        	**type**\:  :py:class:`DMPINTERFACETEMPLATE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE>`
        
        	**presence node**\: True
        
        .. attribute:: ip_phone_interface_template
        
        	built\-in modified
        	**type**\:  :py:class:`IPPHONEINTERFACETEMPLATE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE>`
        
        	**presence node**\: True
        
        .. attribute:: msp_camera_interface_template
        
        	built\-in modified
        	**type**\:  :py:class:`MSPCAMERAINTERFACETEMPLATE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE>`
        
        .. attribute:: msp_vc_interface_template
        
        	built\-in modified
        	**type**\:  :py:class:`MSPVCINTERFACETEMPLATE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE>`
        
        .. attribute:: printer_interface_template
        
        	built\-in modified
        	**type**\:  :py:class:`PRINTERINTERFACETEMPLATE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE>`
        
        .. attribute:: router_interface_template
        
        	built\-in modified
        	**type**\:  :py:class:`ROUTERINTERFACETEMPLATE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE>`
        
        .. attribute:: switch_interface_template
        
        	built\-in modified
        	**type**\:  :py:class:`SWITCHINTERFACETEMPLATE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE>`
        
        .. attribute:: tp_interface_template
        
        	built\-in modified
        	**type**\:  :py:class:`TPINTERFACETEMPLATE <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Template, self).__init__()

            self.yang_name = "template"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("Cisco-IOS-XE-template:template_details", ("template_details", Native.Template.TemplateDetails)), ("Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE", ("ip_camera_interface_template", Native.Template.IPCAMERAINTERFACETEMPLATE)), ("Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE", ("lap_interface_template", Native.Template.LAPINTERFACETEMPLATE)), ("Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE", ("ap_interface_template", Native.Template.APINTERFACETEMPLATE)), ("Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE", ("dmp_interface_template", Native.Template.DMPINTERFACETEMPLATE)), ("Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE", ("ip_phone_interface_template", Native.Template.IPPHONEINTERFACETEMPLATE)), ("Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE", ("msp_camera_interface_template", Native.Template.MSPCAMERAINTERFACETEMPLATE)), ("Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE", ("msp_vc_interface_template", Native.Template.MSPVCINTERFACETEMPLATE)), ("Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE", ("printer_interface_template", Native.Template.PRINTERINTERFACETEMPLATE)), ("Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE", ("router_interface_template", Native.Template.ROUTERINTERFACETEMPLATE)), ("Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE", ("switch_interface_template", Native.Template.SWITCHINTERFACETEMPLATE)), ("Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE", ("tp_interface_template", Native.Template.TPINTERFACETEMPLATE))])
            self._leafs = OrderedDict()

            self.ip_camera_interface_template = Native.Template.IPCAMERAINTERFACETEMPLATE()
            self.ip_camera_interface_template.parent = self
            self._children_name_map["ip_camera_interface_template"] = "Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE"

            self.lap_interface_template = Native.Template.LAPINTERFACETEMPLATE()
            self.lap_interface_template.parent = self
            self._children_name_map["lap_interface_template"] = "Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE"

            self.ap_interface_template = Native.Template.APINTERFACETEMPLATE()
            self.ap_interface_template.parent = self
            self._children_name_map["ap_interface_template"] = "Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE"

            self.dmp_interface_template = None
            self._children_name_map["dmp_interface_template"] = "Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE"

            self.ip_phone_interface_template = None
            self._children_name_map["ip_phone_interface_template"] = "Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE"

            self.msp_camera_interface_template = Native.Template.MSPCAMERAINTERFACETEMPLATE()
            self.msp_camera_interface_template.parent = self
            self._children_name_map["msp_camera_interface_template"] = "Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE"

            self.msp_vc_interface_template = Native.Template.MSPVCINTERFACETEMPLATE()
            self.msp_vc_interface_template.parent = self
            self._children_name_map["msp_vc_interface_template"] = "Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE"

            self.printer_interface_template = Native.Template.PRINTERINTERFACETEMPLATE()
            self.printer_interface_template.parent = self
            self._children_name_map["printer_interface_template"] = "Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE"

            self.router_interface_template = Native.Template.ROUTERINTERFACETEMPLATE()
            self.router_interface_template.parent = self
            self._children_name_map["router_interface_template"] = "Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE"

            self.switch_interface_template = Native.Template.SWITCHINTERFACETEMPLATE()
            self.switch_interface_template.parent = self
            self._children_name_map["switch_interface_template"] = "Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE"

            self.tp_interface_template = Native.Template.TPINTERFACETEMPLATE()
            self.tp_interface_template.parent = self
            self._children_name_map["tp_interface_template"] = "Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE"

            self.template_details = YList(self)
            self._segment_path = lambda: "template"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Template, [], name, value)


        class TemplateDetails(Entity):
            """
            
            
            .. attribute:: template_name  (key)
            
            	Template name
            	**type**\: str
            
            .. attribute:: ethernet
            
            	Ethernet service
            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet>`
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ip>`
            
            

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.TemplateDetails, self).__init__()

                self.yang_name = "template_details"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['template_name']
                self._child_classes = OrderedDict([("ethernet", ("ethernet", Native.Template.TemplateDetails.Ethernet)), ("service-policy", ("service_policy", Native.Template.TemplateDetails.ServicePolicy)), ("switchport", ("switchport", Native.Template.TemplateDetails.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.TemplateDetails.SpanningTree)), ("storm-control", ("storm_control", Native.Template.TemplateDetails.StormControl)), ("ip", ("ip", Native.Template.TemplateDetails.Ip))])
                self._leafs = OrderedDict([
                    ('template_name', (YLeaf(YType.str, 'template_name'), ['str'])),
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.template_name = None
                self.load_interval = None

                self.ethernet = Native.Template.TemplateDetails.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "ethernet"

                self.service_policy = Native.Template.TemplateDetails.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.TemplateDetails.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.TemplateDetails.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.TemplateDetails.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:template_details" + "[template_name='" + str(self.template_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.TemplateDetails, ['template_name', 'load_interval'], name, value)


            class Ethernet(Entity):
                """
                Ethernet service
                
                .. attribute:: oam
                
                	Operations, Administration and Maintenance
                	**type**\:  :py:class:`Oam <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.TemplateDetails.Ethernet, self).__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "template_details"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oam", ("oam", Native.Template.TemplateDetails.Ethernet.Oam))])
                    self._leafs = OrderedDict()

                    self.oam = Native.Template.TemplateDetails.Ethernet.Oam()
                    self.oam.parent = self
                    self._children_name_map["oam"] = "oam"
                    self._segment_path = lambda: "ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.TemplateDetails.Ethernet, [], name, value)


                class Oam(Entity):
                    """
                    Operations, Administration and Maintenance
                    
                    .. attribute:: link_monitor
                    
                    	Ethernet OAM Link Monitor
                    	**type**\:  :py:class:`LinkMonitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor>`
                    
                    .. attribute:: remote_failure
                    
                    	Ethernet OAM remote failure indication
                    	**type**\:  :py:class:`RemoteFailure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.Ethernet.Oam, self).__init__()

                        self.yang_name = "oam"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("link-monitor", ("link_monitor", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor)), ("remote-failure", ("remote_failure", Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure))])
                        self._leafs = OrderedDict()

                        self.link_monitor = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor()
                        self.link_monitor.parent = self
                        self._children_name_map["link_monitor"] = "link-monitor"

                        self.remote_failure = Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure()
                        self.remote_failure.parent = self
                        self._children_name_map["remote_failure"] = "remote-failure"
                        self._segment_path = lambda: "oam"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam, [], name, value)


                    class LinkMonitor(Entity):
                        """
                        Ethernet OAM Link Monitor
                        
                        .. attribute:: frame
                        
                        	Errored frames in a period measured by time
                        	**type**\:  :py:class:`Frame <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame>`
                        
                        .. attribute:: window
                        
                        	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                        	**type**\: int
                        
                        	**range:** 10..600
                        
                        .. attribute:: frame_period
                        
                        	Errored frames in a period measured by number of frames
                        	**type**\:  :py:class:`FramePeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod>`
                        
                        .. attribute:: frame_seconds
                        
                        	Errored frame seconds in a period
                        	**type**\:  :py:class:`FrameSeconds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds>`
                        
                        .. attribute:: high_threshold
                        
                        	Additional high threshold configuration
                        	**type**\:  :py:class:`HighThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.HighThreshold>`
                        
                        .. attribute:: receive_crc
                        
                        	Received frames with CRC errors in a period
                        	**type**\:  :py:class:`ReceiveCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc>`
                        
                        .. attribute:: symbol_period
                        
                        	Errored symbols in a period
                        	**type**\:  :py:class:`SymbolPeriod <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod>`
                        
                        .. attribute:: transmit_crc
                        
                        	Transmitted frames with CRC errors in a period
                        	**type**\:  :py:class:`TransmitCrc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor, self).__init__()

                            self.yang_name = "link-monitor"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frame", ("frame", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame)), ("frame-period", ("frame_period", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod)), ("frame-seconds", ("frame_seconds", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds)), ("high-threshold", ("high_threshold", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.HighThreshold)), ("receive-crc", ("receive_crc", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc)), ("symbol-period", ("symbol_period", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod)), ("transmit-crc", ("transmit_crc", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc))])
                            self._leafs = OrderedDict([
                                ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                            ])
                            self.window = None

                            self.frame = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame()
                            self.frame.parent = self
                            self._children_name_map["frame"] = "frame"

                            self.frame_period = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod()
                            self.frame_period.parent = self
                            self._children_name_map["frame_period"] = "frame-period"

                            self.frame_seconds = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds()
                            self.frame_seconds.parent = self
                            self._children_name_map["frame_seconds"] = "frame-seconds"

                            self.high_threshold = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.HighThreshold()
                            self.high_threshold.parent = self
                            self._children_name_map["high_threshold"] = "high-threshold"

                            self.receive_crc = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc()
                            self.receive_crc.parent = self
                            self._children_name_map["receive_crc"] = "receive-crc"

                            self.symbol_period = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod()
                            self.symbol_period.parent = self
                            self._children_name_map["symbol_period"] = "symbol-period"

                            self.transmit_crc = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc()
                            self.transmit_crc.parent = self
                            self._children_name_map["transmit_crc"] = "transmit-crc"
                            self._segment_path = lambda: "link-monitor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor, ['window'], name, value)


                        class Frame(Entity):
                            """
                            Errored frames in a period measured by time
                            
                            .. attribute:: threshold
                            
                            	threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame.Threshold>`
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame, self).__init__()

                                self.yang_name = "frame"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame.Threshold))])
                                self._leafs = OrderedDict()

                                self.threshold = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame, [], name, value)


                            class Threshold(Entity):
                                """
                                threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low threshold
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: high_range
                                    
                                    	Set the high threshold
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-template'
                                    _revision = '2017-11-06'

                                    def __init__(self):
                                        super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_range', (YLeaf(YType.uint16, 'high-range'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.high_range = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.Frame.Threshold.High, ['high_range', 'none'], name, value)


                        class FramePeriod(Entity):
                            """
                            Errored frames in a period measured by number of frames
                            
                            .. attribute:: threshold
                            
                            	threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod, self).__init__()

                                self.yang_name = "frame-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low threshold
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: high_range
                                    
                                    	Set the high threshold
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-template'
                                    _revision = '2017-11-06'

                                    def __init__(self):
                                        super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_range', (YLeaf(YType.uint16, 'high-range'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.high_range = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FramePeriod.Threshold.High, ['high_range', 'none'], name, value)


                        class FrameSeconds(Entity):
                            """
                            Errored frame seconds in a period
                            
                            .. attribute:: threshold
                            
                            	Errored frame\-seconds threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in multiple of 100 milliseconds (will be rounded off to second)
                            	**type**\: int
                            
                            	**range:** 100..9000
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds, self).__init__()

                                self.yang_name = "frame-seconds"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "frame-seconds"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                Errored frame\-seconds threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low errored frame\-seconds threshold in number of seconds
                                	**type**\: int
                                
                                	**range:** 1..900
                                
                                

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "frame-seconds"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: high_range
                                    
                                    	Set the high errored frame\-seconds threshold in number of seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..900
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-template'
                                    _revision = '2017-11-06'

                                    def __init__(self):
                                        super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_range', (YLeaf(YType.uint16, 'high-range'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.high_range = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.FrameSeconds.Threshold.High, ['high_range', 'none'], name, value)


                        class HighThreshold(Entity):
                            """
                            Additional high threshold configuration
                            
                            .. attribute:: action
                            
                            	Specifiy an action when the high threshold is crossed
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.HighThreshold.Action>`
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.HighThreshold, self).__init__()

                                self.yang_name = "high-threshold"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.HighThreshold.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.HighThreshold.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "high-threshold"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.HighThreshold, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when the high threshold is crossed
                                
                                .. attribute:: error_disable_interface
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.HighThreshold.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "high-threshold"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.HighThreshold.Action, ['error_disable_interface'], name, value)


                        class ReceiveCrc(Entity):
                            """
                            Received frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc, self).__init__()

                                self.yang_name = "receive-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "receive-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low threshold
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "receive-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: high_range
                                    
                                    	Set the high threshold
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-template'
                                    _revision = '2017-11-06'

                                    def __init__(self):
                                        super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_range', (YLeaf(YType.uint16, 'high-range'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.high_range = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.ReceiveCrc.Threshold.High, ['high_range', 'none'], name, value)


                        class SymbolPeriod(Entity):
                            """
                            Errored symbols in a period
                            
                            .. attribute:: threshold
                            
                            	threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 1..65535
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod, self).__init__()

                                self.yang_name = "symbol-period"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "symbol-period"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low threshold
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "symbol-period"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: high_range
                                    
                                    	Set the high threshold
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-template'
                                    _revision = '2017-11-06'

                                    def __init__(self):
                                        super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_range', (YLeaf(YType.uint16, 'high-range'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.high_range = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.SymbolPeriod.Threshold.High, ['high_range', 'none'], name, value)


                        class TransmitCrc(Entity):
                            """
                            Transmitted frames with CRC errors in a period
                            
                            .. attribute:: threshold
                            
                            	threshold
                            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc.Threshold>`
                            
                            .. attribute:: window
                            
                            	Set window size in number of 10000 frames
                            	**type**\: int
                            
                            	**range:** 10..1800
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc, self).__init__()

                                self.yang_name = "transmit-crc"
                                self.yang_parent_name = "link-monitor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc.Threshold))])
                                self._leafs = OrderedDict([
                                    ('window', (YLeaf(YType.uint16, 'window'), ['int'])),
                                ])
                                self.window = None

                                self.threshold = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc.Threshold()
                                self.threshold.parent = self
                                self._children_name_map["threshold"] = "threshold"
                                self._segment_path = lambda: "transmit-crc"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc, ['window'], name, value)


                            class Threshold(Entity):
                                """
                                threshold
                                
                                .. attribute:: high
                                
                                	High Threshold
                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc.Threshold.High>`
                                
                                .. attribute:: low
                                
                                	Set the low threshold
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc.Threshold, self).__init__()

                                    self.yang_name = "threshold"
                                    self.yang_parent_name = "transmit-crc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("high", ("high", Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc.Threshold.High))])
                                    self._leafs = OrderedDict([
                                        ('low', (YLeaf(YType.uint16, 'low'), ['int'])),
                                    ])
                                    self.low = None

                                    self.high = Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc.Threshold.High()
                                    self.high.parent = self
                                    self._children_name_map["high"] = "high"
                                    self._segment_path = lambda: "threshold"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc.Threshold, ['low'], name, value)


                                class High(Entity):
                                    """
                                    High Threshold
                                    
                                    .. attribute:: high_range
                                    
                                    	Set the high threshold
                                    	**type**\: int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: none
                                    
                                    	Disable high threshold
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-template'
                                    _revision = '2017-11-06'

                                    def __init__(self):
                                        super(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc.Threshold.High, self).__init__()

                                        self.yang_name = "high"
                                        self.yang_parent_name = "threshold"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_range', (YLeaf(YType.uint16, 'high-range'), ['int'])),
                                            ('none', (YLeaf(YType.empty, 'none'), ['Empty'])),
                                        ])
                                        self.high_range = None
                                        self.none = None
                                        self._segment_path = lambda: "high"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.LinkMonitor.TransmitCrc.Threshold.High, ['high_range', 'none'], name, value)


                    class RemoteFailure(Entity):
                        """
                        Ethernet OAM remote failure indication
                        
                        .. attribute:: critical_event
                        
                        	Critical event
                        	**type**\:  :py:class:`CriticalEvent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.CriticalEvent>`
                        
                        .. attribute:: dying_gasp
                        
                        	Dying gasp
                        	**type**\:  :py:class:`DyingGasp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.DyingGasp>`
                        
                        .. attribute:: link_fault
                        
                        	Link fault
                        	**type**\:  :py:class:`LinkFault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.LinkFault>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure, self).__init__()

                            self.yang_name = "remote-failure"
                            self.yang_parent_name = "oam"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("critical-event", ("critical_event", Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.CriticalEvent)), ("dying-gasp", ("dying_gasp", Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.DyingGasp)), ("link-fault", ("link_fault", Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.LinkFault))])
                            self._leafs = OrderedDict()

                            self.critical_event = Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.CriticalEvent()
                            self.critical_event.parent = self
                            self._children_name_map["critical_event"] = "critical-event"

                            self.dying_gasp = Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.DyingGasp()
                            self.dying_gasp.parent = self
                            self._children_name_map["dying_gasp"] = "dying-gasp"

                            self.link_fault = Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.LinkFault()
                            self.link_fault.parent = self
                            self._children_name_map["link_fault"] = "link-fault"
                            self._segment_path = lambda: "remote-failure"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure, [], name, value)


                        class CriticalEvent(Entity):
                            """
                            Critical event
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.CriticalEvent.Action>`
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.CriticalEvent, self).__init__()

                                self.yang_name = "critical-event"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.CriticalEvent.Action))])
                                self._leafs = OrderedDict()

                                self.action = Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.CriticalEvent.Action()
                                self.action.parent = self
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "critical-event"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.CriticalEvent, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "critical-event"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.CriticalEvent.Action, ['error_disable_interface'], name, value)


                        class DyingGasp(Entity):
                            """
                            Dying gasp
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.DyingGasp.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.DyingGasp, self).__init__()

                                self.yang_name = "dying-gasp"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.DyingGasp.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "dying-gasp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.DyingGasp, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.DyingGasp.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "dying-gasp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.DyingGasp.Action, ['error_disable_interface'], name, value)


                        class LinkFault(Entity):
                            """
                            Link fault
                            
                            .. attribute:: action
                            
                            	Specifiy an action when a remote failure is detected
                            	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.LinkFault.Action>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.LinkFault, self).__init__()

                                self.yang_name = "link-fault"
                                self.yang_parent_name = "remote-failure"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("action", ("action", Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.LinkFault.Action))])
                                self._leafs = OrderedDict()

                                self.action = None
                                self._children_name_map["action"] = "action"
                                self._segment_path = lambda: "link-fault"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.LinkFault, [], name, value)


                            class Action(Entity):
                                """
                                Specifiy an action when a remote failure is detected
                                
                                .. attribute:: error_disable_interface
                                
                                	
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.LinkFault.Action, self).__init__()

                                    self.yang_name = "action"
                                    self.yang_parent_name = "link-fault"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('error_disable_interface', (YLeaf(YType.empty, 'error-disable-interface'), ['Empty'])),
                                    ])
                                    self.error_disable_interface = None
                                    self._segment_path = lambda: "action"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TemplateDetails.Ethernet.Oam.RemoteFailure.LinkFault.Action, ['error_disable_interface'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.TemplateDetails.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "template_details"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.TemplateDetails.ServicePolicy.Input)), ("output", ("output", Native.Template.TemplateDetails.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.TemplateDetails.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.TemplateDetails.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.TemplateDetails.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.TemplateDetails.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "template_details"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.TemplateDetails.Switchport.Mode)), ("block", ("block", Native.Template.TemplateDetails.Switchport.Block)), ("port-security", ("port_security", Native.Template.TemplateDetails.Switchport.PortSecurity)), ("access", ("access", Native.Template.TemplateDetails.Switchport.Access)), ("voice", ("voice", Native.Template.TemplateDetails.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.TemplateDetails.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.TemplateDetails.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.TemplateDetails.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.TemplateDetails.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.TemplateDetails.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.TemplateDetails.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.TemplateDetails.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.TemplateDetails.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.TemplateDetails.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TemplateDetails.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.TemplateDetails.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TemplateDetails.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TemplateDetails.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TemplateDetails.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TemplateDetails.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.TemplateDetails.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "template_details"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.TemplateDetails.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.TemplateDetails.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.TemplateDetails.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.TemplateDetails.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.TemplateDetails.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "template_details"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.TemplateDetails.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.TemplateDetails.StormControl.Multicast)), ("action", ("action", Native.Template.TemplateDetails.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.TemplateDetails.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.TemplateDetails.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.TemplateDetails.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.TemplateDetails.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.TemplateDetails.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.TemplateDetails.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TemplateDetails.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.TemplateDetails.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.TemplateDetails.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.TemplateDetails.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.TemplateDetails.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TemplateDetails.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.TemplateDetails.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.TemplateDetails.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TemplateDetails.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.TemplateDetails.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.TemplateDetails.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.TemplateDetails.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.TemplateDetails.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TemplateDetails.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.TemplateDetails.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "template_details"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.TemplateDetails.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.TemplateDetails.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.TemplateDetails.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TemplateDetails.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.TemplateDetails.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.TemplateDetails.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TemplateDetails.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TemplateDetails.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TemplateDetails.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.TemplateDetails.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.TemplateDetails.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TemplateDetails.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TemplateDetails.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TemplateDetails.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


        class IPCAMERAINTERFACETEMPLATE(Entity):
            """
            built\-in modified
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Ip>`
            
            

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.IPCAMERAINTERFACETEMPLATE, self).__init__()

                self.yang_name = "IP_CAMERA_INTERFACE_TEMPLATE"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy)), ("switchport", ("switchport", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree)), ("storm-control", ("storm_control", Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl)), ("ip", ("ip", Native.Template.IPCAMERAINTERFACETEMPLATE.Ip))])
                self._leafs = OrderedDict([
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.load_interval = None

                self.service_policy = Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.IPCAMERAINTERFACETEMPLATE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE, ['load_interval'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "IP_CAMERA_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy.Input)), ("output", ("output", Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "IP_CAMERA_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Mode)), ("block", ("block", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Block)), ("port-security", ("port_security", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity)), ("access", ("access", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Access)), ("voice", ("voice", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/switchport/port-security/aging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/switchport/port-security/maximum/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "IP_CAMERA_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "IP_CAMERA_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast)), ("action", ("action", Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/storm-control/broadcast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/storm-control/multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.IPCAMERAINTERFACETEMPLATE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "IP_CAMERA_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/ip/dhcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_CAMERA_INTERFACE_TEMPLATE/ip/dhcp/snooping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


        class LAPINTERFACETEMPLATE(Entity):
            """
            built\-in modified
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Ip>`
            
            

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.LAPINTERFACETEMPLATE, self).__init__()

                self.yang_name = "LAP_INTERFACE_TEMPLATE"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Template.LAPINTERFACETEMPLATE.ServicePolicy)), ("switchport", ("switchport", Native.Template.LAPINTERFACETEMPLATE.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.LAPINTERFACETEMPLATE.SpanningTree)), ("storm-control", ("storm_control", Native.Template.LAPINTERFACETEMPLATE.StormControl)), ("ip", ("ip", Native.Template.LAPINTERFACETEMPLATE.Ip))])
                self._leafs = OrderedDict([
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.load_interval = None

                self.service_policy = Native.Template.LAPINTERFACETEMPLATE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.LAPINTERFACETEMPLATE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.LAPINTERFACETEMPLATE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.LAPINTERFACETEMPLATE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE, ['load_interval'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.LAPINTERFACETEMPLATE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "LAP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.LAPINTERFACETEMPLATE.ServicePolicy.Input)), ("output", ("output", Native.Template.LAPINTERFACETEMPLATE.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.LAPINTERFACETEMPLATE.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.LAPINTERFACETEMPLATE.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.LAPINTERFACETEMPLATE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "LAP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.LAPINTERFACETEMPLATE.Switchport.Mode)), ("block", ("block", Native.Template.LAPINTERFACETEMPLATE.Switchport.Block)), ("port-security", ("port_security", Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity)), ("access", ("access", Native.Template.LAPINTERFACETEMPLATE.Switchport.Access)), ("voice", ("voice", Native.Template.LAPINTERFACETEMPLATE.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.LAPINTERFACETEMPLATE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.LAPINTERFACETEMPLATE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.LAPINTERFACETEMPLATE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.LAPINTERFACETEMPLATE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/switchport/port-security/aging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/switchport/port-security/maximum/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.LAPINTERFACETEMPLATE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "LAP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.LAPINTERFACETEMPLATE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.LAPINTERFACETEMPLATE.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.LAPINTERFACETEMPLATE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.LAPINTERFACETEMPLATE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "LAP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast)), ("action", ("action", Native.Template.LAPINTERFACETEMPLATE.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.LAPINTERFACETEMPLATE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/storm-control/broadcast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/storm-control/multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.LAPINTERFACETEMPLATE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "LAP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/ip/dhcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:LAP_INTERFACE_TEMPLATE/ip/dhcp/snooping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.LAPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


        class APINTERFACETEMPLATE(Entity):
            """
            built\-in modified
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Ip>`
            
            

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.APINTERFACETEMPLATE, self).__init__()

                self.yang_name = "AP_INTERFACE_TEMPLATE"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Template.APINTERFACETEMPLATE.ServicePolicy)), ("switchport", ("switchport", Native.Template.APINTERFACETEMPLATE.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.APINTERFACETEMPLATE.SpanningTree)), ("storm-control", ("storm_control", Native.Template.APINTERFACETEMPLATE.StormControl)), ("ip", ("ip", Native.Template.APINTERFACETEMPLATE.Ip))])
                self._leafs = OrderedDict([
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.load_interval = None

                self.service_policy = Native.Template.APINTERFACETEMPLATE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.APINTERFACETEMPLATE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.APINTERFACETEMPLATE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.APINTERFACETEMPLATE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.APINTERFACETEMPLATE, ['load_interval'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.APINTERFACETEMPLATE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "AP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.APINTERFACETEMPLATE.ServicePolicy.Input)), ("output", ("output", Native.Template.APINTERFACETEMPLATE.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.APINTERFACETEMPLATE.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.APINTERFACETEMPLATE.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.APINTERFACETEMPLATE.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.APINTERFACETEMPLATE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "AP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.APINTERFACETEMPLATE.Switchport.Mode)), ("block", ("block", Native.Template.APINTERFACETEMPLATE.Switchport.Block)), ("port-security", ("port_security", Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity)), ("access", ("access", Native.Template.APINTERFACETEMPLATE.Switchport.Access)), ("voice", ("voice", Native.Template.APINTERFACETEMPLATE.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.APINTERFACETEMPLATE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.APINTERFACETEMPLATE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.APINTERFACETEMPLATE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.APINTERFACETEMPLATE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/switchport/port-security/aging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/switchport/port-security/maximum/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.APINTERFACETEMPLATE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "AP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.APINTERFACETEMPLATE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.APINTERFACETEMPLATE.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.APINTERFACETEMPLATE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.APINTERFACETEMPLATE.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.APINTERFACETEMPLATE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "AP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.APINTERFACETEMPLATE.StormControl.Multicast)), ("action", ("action", Native.Template.APINTERFACETEMPLATE.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.APINTERFACETEMPLATE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.APINTERFACETEMPLATE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.APINTERFACETEMPLATE.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/storm-control/broadcast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.APINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/storm-control/multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.APINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.APINTERFACETEMPLATE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "AP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.APINTERFACETEMPLATE.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.APINTERFACETEMPLATE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.APINTERFACETEMPLATE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.APINTERFACETEMPLATE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.APINTERFACETEMPLATE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.APINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.APINTERFACETEMPLATE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.APINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.APINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/ip/dhcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.APINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:AP_INTERFACE_TEMPLATE/ip/dhcp/snooping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.APINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


        class DMPINTERFACETEMPLATE(Entity):
            """
            built\-in modified
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Ip>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.DMPINTERFACETEMPLATE, self).__init__()

                self.yang_name = "DMP_INTERFACE_TEMPLATE"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Template.DMPINTERFACETEMPLATE.ServicePolicy)), ("switchport", ("switchport", Native.Template.DMPINTERFACETEMPLATE.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.DMPINTERFACETEMPLATE.SpanningTree)), ("storm-control", ("storm_control", Native.Template.DMPINTERFACETEMPLATE.StormControl)), ("ip", ("ip", Native.Template.DMPINTERFACETEMPLATE.Ip))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.load_interval = None

                self.service_policy = Native.Template.DMPINTERFACETEMPLATE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.DMPINTERFACETEMPLATE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.DMPINTERFACETEMPLATE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.DMPINTERFACETEMPLATE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE, ['load_interval'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.DMPINTERFACETEMPLATE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "DMP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.DMPINTERFACETEMPLATE.ServicePolicy.Input)), ("output", ("output", Native.Template.DMPINTERFACETEMPLATE.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.DMPINTERFACETEMPLATE.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.DMPINTERFACETEMPLATE.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.DMPINTERFACETEMPLATE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "DMP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.DMPINTERFACETEMPLATE.Switchport.Mode)), ("block", ("block", Native.Template.DMPINTERFACETEMPLATE.Switchport.Block)), ("port-security", ("port_security", Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity)), ("access", ("access", Native.Template.DMPINTERFACETEMPLATE.Switchport.Access)), ("voice", ("voice", Native.Template.DMPINTERFACETEMPLATE.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.DMPINTERFACETEMPLATE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.DMPINTERFACETEMPLATE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.DMPINTERFACETEMPLATE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.DMPINTERFACETEMPLATE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/switchport/port-security/aging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/switchport/port-security/maximum/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.DMPINTERFACETEMPLATE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "DMP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.DMPINTERFACETEMPLATE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.DMPINTERFACETEMPLATE.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.DMPINTERFACETEMPLATE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.DMPINTERFACETEMPLATE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "DMP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast)), ("action", ("action", Native.Template.DMPINTERFACETEMPLATE.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.DMPINTERFACETEMPLATE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/storm-control/broadcast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/storm-control/multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.DMPINTERFACETEMPLATE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "DMP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/ip/dhcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:DMP_INTERFACE_TEMPLATE/ip/dhcp/snooping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.DMPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


        class IPPHONEINTERFACETEMPLATE(Entity):
            """
            built\-in modified
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Ip>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.IPPHONEINTERFACETEMPLATE, self).__init__()

                self.yang_name = "IP_PHONE_INTERFACE_TEMPLATE"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy)), ("switchport", ("switchport", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree)), ("storm-control", ("storm_control", Native.Template.IPPHONEINTERFACETEMPLATE.StormControl)), ("ip", ("ip", Native.Template.IPPHONEINTERFACETEMPLATE.Ip))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.load_interval = None

                self.service_policy = Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.IPPHONEINTERFACETEMPLATE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.IPPHONEINTERFACETEMPLATE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.IPPHONEINTERFACETEMPLATE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE, ['load_interval'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "IP_PHONE_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy.Input)), ("output", ("output", Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "IP_PHONE_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Mode)), ("block", ("block", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Block)), ("port-security", ("port_security", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity)), ("access", ("access", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Access)), ("voice", ("voice", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/switchport/port-security/aging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/switchport/port-security/maximum/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "IP_PHONE_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "IP_PHONE_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast)), ("action", ("action", Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/storm-control/broadcast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/storm-control/multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.IPPHONEINTERFACETEMPLATE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "IP_PHONE_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/ip/dhcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:IP_PHONE_INTERFACE_TEMPLATE/ip/dhcp/snooping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.IPPHONEINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


        class MSPCAMERAINTERFACETEMPLATE(Entity):
            """
            built\-in modified
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip>`
            
            

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.MSPCAMERAINTERFACETEMPLATE, self).__init__()

                self.yang_name = "MSP_CAMERA_INTERFACE_TEMPLATE"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy)), ("switchport", ("switchport", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree)), ("storm-control", ("storm_control", Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl)), ("ip", ("ip", Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip))])
                self._leafs = OrderedDict([
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.load_interval = None

                self.service_policy = Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE, ['load_interval'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "MSP_CAMERA_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy.Input)), ("output", ("output", Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "MSP_CAMERA_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Mode)), ("block", ("block", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Block)), ("port-security", ("port_security", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity)), ("access", ("access", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Access)), ("voice", ("voice", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/switchport/port-security/aging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/switchport/port-security/maximum/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "MSP_CAMERA_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "MSP_CAMERA_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast)), ("action", ("action", Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/storm-control/broadcast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/storm-control/multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "MSP_CAMERA_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/ip/dhcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_CAMERA_INTERFACE_TEMPLATE/ip/dhcp/snooping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPCAMERAINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


        class MSPVCINTERFACETEMPLATE(Entity):
            """
            built\-in modified
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Ip>`
            
            

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.MSPVCINTERFACETEMPLATE, self).__init__()

                self.yang_name = "MSP_VC_INTERFACE_TEMPLATE"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy)), ("switchport", ("switchport", Native.Template.MSPVCINTERFACETEMPLATE.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree)), ("storm-control", ("storm_control", Native.Template.MSPVCINTERFACETEMPLATE.StormControl)), ("ip", ("ip", Native.Template.MSPVCINTERFACETEMPLATE.Ip))])
                self._leafs = OrderedDict([
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.load_interval = None

                self.service_policy = Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.MSPVCINTERFACETEMPLATE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.MSPVCINTERFACETEMPLATE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.MSPVCINTERFACETEMPLATE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE, ['load_interval'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "MSP_VC_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy.Input)), ("output", ("output", Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "MSP_VC_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Mode)), ("block", ("block", Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Block)), ("port-security", ("port_security", Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity)), ("access", ("access", Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Access)), ("voice", ("voice", Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/switchport/port-security/aging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/switchport/port-security/maximum/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "MSP_VC_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.MSPVCINTERFACETEMPLATE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "MSP_VC_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast)), ("action", ("action", Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/storm-control/broadcast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/storm-control/multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.MSPVCINTERFACETEMPLATE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "MSP_VC_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/ip/dhcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:MSP_VC_INTERFACE_TEMPLATE/ip/dhcp/snooping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.MSPVCINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


        class PRINTERINTERFACETEMPLATE(Entity):
            """
            built\-in modified
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Ip>`
            
            

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.PRINTERINTERFACETEMPLATE, self).__init__()

                self.yang_name = "PRINTER_INTERFACE_TEMPLATE"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy)), ("switchport", ("switchport", Native.Template.PRINTERINTERFACETEMPLATE.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree)), ("storm-control", ("storm_control", Native.Template.PRINTERINTERFACETEMPLATE.StormControl)), ("ip", ("ip", Native.Template.PRINTERINTERFACETEMPLATE.Ip))])
                self._leafs = OrderedDict([
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.load_interval = None

                self.service_policy = Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.PRINTERINTERFACETEMPLATE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.PRINTERINTERFACETEMPLATE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.PRINTERINTERFACETEMPLATE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE, ['load_interval'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "PRINTER_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy.Input)), ("output", ("output", Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "PRINTER_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Mode)), ("block", ("block", Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Block)), ("port-security", ("port_security", Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity)), ("access", ("access", Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Access)), ("voice", ("voice", Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/switchport/port-security/aging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/switchport/port-security/maximum/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "PRINTER_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.PRINTERINTERFACETEMPLATE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "PRINTER_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast)), ("action", ("action", Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/storm-control/broadcast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/storm-control/multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.PRINTERINTERFACETEMPLATE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "PRINTER_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/ip/dhcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:PRINTER_INTERFACE_TEMPLATE/ip/dhcp/snooping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.PRINTERINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


        class ROUTERINTERFACETEMPLATE(Entity):
            """
            built\-in modified
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Ip>`
            
            

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.ROUTERINTERFACETEMPLATE, self).__init__()

                self.yang_name = "ROUTER_INTERFACE_TEMPLATE"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy)), ("switchport", ("switchport", Native.Template.ROUTERINTERFACETEMPLATE.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree)), ("storm-control", ("storm_control", Native.Template.ROUTERINTERFACETEMPLATE.StormControl)), ("ip", ("ip", Native.Template.ROUTERINTERFACETEMPLATE.Ip))])
                self._leafs = OrderedDict([
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.load_interval = None

                self.service_policy = Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.ROUTERINTERFACETEMPLATE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.ROUTERINTERFACETEMPLATE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.ROUTERINTERFACETEMPLATE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE, ['load_interval'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "ROUTER_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy.Input)), ("output", ("output", Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "ROUTER_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Mode)), ("block", ("block", Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Block)), ("port-security", ("port_security", Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity)), ("access", ("access", Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Access)), ("voice", ("voice", Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/switchport/port-security/aging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/switchport/port-security/maximum/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "ROUTER_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.ROUTERINTERFACETEMPLATE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "ROUTER_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast)), ("action", ("action", Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/storm-control/broadcast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/storm-control/multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.ROUTERINTERFACETEMPLATE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "ROUTER_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/ip/dhcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:ROUTER_INTERFACE_TEMPLATE/ip/dhcp/snooping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.ROUTERINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


        class SWITCHINTERFACETEMPLATE(Entity):
            """
            built\-in modified
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Ip>`
            
            

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.SWITCHINTERFACETEMPLATE, self).__init__()

                self.yang_name = "SWITCH_INTERFACE_TEMPLATE"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy)), ("switchport", ("switchport", Native.Template.SWITCHINTERFACETEMPLATE.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree)), ("storm-control", ("storm_control", Native.Template.SWITCHINTERFACETEMPLATE.StormControl)), ("ip", ("ip", Native.Template.SWITCHINTERFACETEMPLATE.Ip))])
                self._leafs = OrderedDict([
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.load_interval = None

                self.service_policy = Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.SWITCHINTERFACETEMPLATE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.SWITCHINTERFACETEMPLATE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.SWITCHINTERFACETEMPLATE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE, ['load_interval'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "SWITCH_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy.Input)), ("output", ("output", Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "SWITCH_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Mode)), ("block", ("block", Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Block)), ("port-security", ("port_security", Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity)), ("access", ("access", Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Access)), ("voice", ("voice", Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/switchport/port-security/aging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/switchport/port-security/maximum/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "SWITCH_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.SWITCHINTERFACETEMPLATE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "SWITCH_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast)), ("action", ("action", Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/storm-control/broadcast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/storm-control/multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.SWITCHINTERFACETEMPLATE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "SWITCH_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/ip/dhcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:SWITCH_INTERFACE_TEMPLATE/ip/dhcp/snooping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.SWITCHINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


        class TPINTERFACETEMPLATE(Entity):
            """
            built\-in modified
            
            .. attribute:: service_policy
            
            	Configure CPL Service Policy
            	**type**\:  :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.ServicePolicy>`
            
            .. attribute:: switchport
            
            	Set switching mode characteristics
            	**type**\:  :py:class:`Switchport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport>`
            
            .. attribute:: spanning_tree
            
            	Spanning Tree Subsystem
            	**type**\:  :py:class:`SpanningTree <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.SpanningTree>`
            
            	**presence node**\: True
            
            .. attribute:: storm_control
            
            	storm configuration
            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.StormControl>`
            
            .. attribute:: load_interval
            
            	Load interval delay in seconds
            	**type**\: int
            
            	**range:** 30..600
            
            .. attribute:: ip
            
            	IP template config
            	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Ip>`
            
            

            """

            _prefix = 'ios-template'
            _revision = '2017-11-06'

            def __init__(self):
                super(Native.Template.TPINTERFACETEMPLATE, self).__init__()

                self.yang_name = "TP_INTERFACE_TEMPLATE"
                self.yang_parent_name = "template"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.Template.TPINTERFACETEMPLATE.ServicePolicy)), ("switchport", ("switchport", Native.Template.TPINTERFACETEMPLATE.Switchport)), ("spanning-tree", ("spanning_tree", Native.Template.TPINTERFACETEMPLATE.SpanningTree)), ("storm-control", ("storm_control", Native.Template.TPINTERFACETEMPLATE.StormControl)), ("ip", ("ip", Native.Template.TPINTERFACETEMPLATE.Ip))])
                self._leafs = OrderedDict([
                    ('load_interval', (YLeaf(YType.uint16, 'load-interval'), ['int'])),
                ])
                self.load_interval = None

                self.service_policy = Native.Template.TPINTERFACETEMPLATE.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"

                self.switchport = Native.Template.TPINTERFACETEMPLATE.Switchport()
                self.switchport.parent = self
                self._children_name_map["switchport"] = "switchport"

                self.spanning_tree = None
                self._children_name_map["spanning_tree"] = "spanning-tree"

                self.storm_control = Native.Template.TPINTERFACETEMPLATE.StormControl()
                self.storm_control.parent = self
                self._children_name_map["storm_control"] = "storm-control"

                self.ip = Native.Template.TPINTERFACETEMPLATE.Ip()
                self.ip.parent = self
                self._children_name_map["ip"] = "ip"
                self._segment_path = lambda: "Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Template.TPINTERFACETEMPLATE, ['load_interval'], name, value)


            class ServicePolicy(Entity):
                """
                Configure CPL Service Policy
                
                .. attribute:: input
                
                	Assign policy\-map to the input of an interface
                	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.ServicePolicy.Input>`
                
                .. attribute:: output
                
                	Assign policy\-map to the output of an interface
                	**type**\:  :py:class:`Output <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.ServicePolicy.Output>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.TPINTERFACETEMPLATE.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "TP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("input", ("input", Native.Template.TPINTERFACETEMPLATE.ServicePolicy.Input)), ("output", ("output", Native.Template.TPINTERFACETEMPLATE.ServicePolicy.Output))])
                    self._leafs = OrderedDict()

                    self.input = Native.Template.TPINTERFACETEMPLATE.ServicePolicy.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"

                    self.output = Native.Template.TPINTERFACETEMPLATE.ServicePolicy.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._segment_path = lambda: "service-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.ServicePolicy, [], name, value)


                class Input(Entity):
                    """
                    Assign policy\-map to the input of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.ServicePolicy.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "input"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.ServicePolicy.Input, ['policy_map_name'], name, value)


                class Output(Entity):
                    """
                    Assign policy\-map to the output of an interface
                    
                    .. attribute:: policy_map_name
                    
                    	policy\-map name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.ServicePolicy.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "service-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_map_name', (YLeaf(YType.str, 'policy-map-name'), ['str'])),
                        ])
                        self.policy_map_name = None
                        self._segment_path = lambda: "output"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/service-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.ServicePolicy.Output, ['policy_map_name'], name, value)


            class Switchport(Entity):
                """
                Set switching mode characteristics
                
                .. attribute:: mode
                
                	Set trunking mode of the interface
                	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport.Mode>`
                
                .. attribute:: nonegotiate
                
                	Device will not engage in negotiation protocol on this interface
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: block
                
                	Disable forwarding of unknown uni/multi cast addresses
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport.Block>`
                
                .. attribute:: port_security
                
                	Security related command
                	**type**\:  :py:class:`PortSecurity <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity>`
                
                	**presence node**\: True
                
                .. attribute:: access
                
                	Set access mode characteristics of the interface
                	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport.Access>`
                
                .. attribute:: voice
                
                	Voice appliance attributes
                	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport.Voice>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.TPINTERFACETEMPLATE.Switchport, self).__init__()

                    self.yang_name = "switchport"
                    self.yang_parent_name = "TP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mode", ("mode", Native.Template.TPINTERFACETEMPLATE.Switchport.Mode)), ("block", ("block", Native.Template.TPINTERFACETEMPLATE.Switchport.Block)), ("port-security", ("port_security", Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity)), ("access", ("access", Native.Template.TPINTERFACETEMPLATE.Switchport.Access)), ("voice", ("voice", Native.Template.TPINTERFACETEMPLATE.Switchport.Voice))])
                    self._leafs = OrderedDict([
                        ('nonegotiate', (YLeaf(YType.empty, 'nonegotiate'), ['Empty'])),
                    ])
                    self.nonegotiate = None

                    self.mode = Native.Template.TPINTERFACETEMPLATE.Switchport.Mode()
                    self.mode.parent = self
                    self._children_name_map["mode"] = "mode"

                    self.block = Native.Template.TPINTERFACETEMPLATE.Switchport.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.port_security = None
                    self._children_name_map["port_security"] = "port-security"

                    self.access = Native.Template.TPINTERFACETEMPLATE.Switchport.Access()
                    self.access.parent = self
                    self._children_name_map["access"] = "access"

                    self.voice = Native.Template.TPINTERFACETEMPLATE.Switchport.Voice()
                    self.voice.parent = self
                    self._children_name_map["voice"] = "voice"
                    self._segment_path = lambda: "switchport"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport, ['nonegotiate'], name, value)


                class Mode(Entity):
                    """
                    Set trunking mode of the interface
                    
                    .. attribute:: trunk
                    
                    	Set trunking mode to TRUNK unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: access
                    
                    	Set trunking mode to ACCESS unconditionally
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.Switchport.Mode, self).__init__()

                        self.yang_name = "mode"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('trunk', (YLeaf(YType.empty, 'trunk'), ['Empty'])),
                            ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                        ])
                        self.trunk = None
                        self.access = None
                        self._segment_path = lambda: "mode"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport.Mode, ['trunk', 'access'], name, value)


                class Block(Entity):
                    """
                    Disable forwarding of unknown uni/multi cast addresses
                    
                    .. attribute:: unicast
                    
                    	Block unknown unicast addresses
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.Switchport.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('unicast', (YLeaf(YType.empty, 'unicast'), ['Empty'])),
                        ])
                        self.unicast = None
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport.Block, ['unicast'], name, value)


                class PortSecurity(Entity):
                    """
                    Security related command
                    
                    .. attribute:: aging
                    
                    	Port\-security aging commands
                    	**type**\:  :py:class:`Aging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Aging>`
                    
                    .. attribute:: maximum
                    
                    	Max secure addresses
                    	**type**\:  :py:class:`Maximum <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum>`
                    
                    .. attribute:: violation
                    
                    	Security violation mode
                    	**type**\:  :py:class:`Violation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Violation>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity, self).__init__()

                        self.yang_name = "port-security"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aging", ("aging", Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Aging)), ("maximum", ("maximum", Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum)), ("violation", ("violation", Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Violation))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.aging = Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Aging()
                        self.aging.parent = self
                        self._children_name_map["aging"] = "aging"

                        self.maximum = Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum()
                        self.maximum.parent = self
                        self._children_name_map["maximum"] = "maximum"

                        self.violation = Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Violation()
                        self.violation.parent = self
                        self._children_name_map["violation"] = "violation"
                        self._segment_path = lambda: "port-security"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity, [], name, value)


                    class Aging(Entity):
                        """
                        Port\-security aging commands
                        
                        .. attribute:: static
                        
                        	Enable aging for configured secure addresses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: time
                        
                        	Port\-security aging time
                        	**type**\: int
                        
                        	**range:** 1..1440
                        
                        .. attribute:: type
                        
                        	Port\-security aging type
                        	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Aging, self).__init__()

                            self.yang_name = "aging"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("type", ("type", Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type))])
                            self._leafs = OrderedDict([
                                ('static', (YLeaf(YType.empty, 'static'), ['Empty'])),
                                ('time', (YLeaf(YType.uint16, 'time'), ['int'])),
                            ])
                            self.static = None
                            self.time = None

                            self.type = None
                            self._children_name_map["type"] = "type"
                            self._segment_path = lambda: "aging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Aging, ['static', 'time'], name, value)


                        class Type(Entity):
                            """
                            Port\-security aging type
                            
                            .. attribute:: inactivity
                            
                            	Aging based on inactivity time period
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "aging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('inactivity', (YLeaf(YType.empty, 'inactivity'), ['Empty'])),
                                ])
                                self.inactivity = None
                                self._segment_path = lambda: "type"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/switchport/port-security/aging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Aging.Type, ['inactivity'], name, value)


                    class Maximum(Entity):
                        """
                        Max secure addresses
                        
                        .. attribute:: range
                        
                        	
                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, self).__init__()

                            self.yang_name = "maximum"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("range", ("range", Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range))])
                            self._leafs = OrderedDict()

                            self.range = YList(self)
                            self._segment_path = lambda: "maximum"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum, [], name, value)


                        class Range(Entity):
                            """
                            
                            
                            .. attribute:: range  (key)
                            
                            	Maximum addresses
                            	**type**\: int
                            
                            	**range:** 1..3072
                            
                            .. attribute:: vlan
                            
                            	Max secure addresses per vlan
                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, self).__init__()

                                self.yang_name = "range"
                                self.yang_parent_name = "maximum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['range']
                                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan))])
                                self._leafs = OrderedDict([
                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                ])
                                self.range = None

                                self.vlan = None
                                self._children_name_map["vlan"] = "vlan"
                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/switchport/port-security/maximum/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range, ['range'], name, value)


                            class Vlan(Entity):
                                """
                                Max secure addresses per vlan
                                
                                .. attribute:: access
                                
                                	access vlan
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-template'
                                _revision = '2017-11-06'

                                def __init__(self):
                                    super(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('access', (YLeaf(YType.empty, 'access'), ['Empty'])),
                                    ])
                                    self.access = None
                                    self._segment_path = lambda: "vlan"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Maximum.Range.Vlan, ['access'], name, value)


                    class Violation(Entity):
                        """
                        Security violation mode
                        
                        .. attribute:: protect
                        
                        	Security violation protect mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: restrict
                        
                        	Security violation restrict mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: shutdown
                        
                        	Security violation shutdown mode
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Violation, self).__init__()

                            self.yang_name = "violation"
                            self.yang_parent_name = "port-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protect', (YLeaf(YType.empty, 'protect'), ['Empty'])),
                                ('restrict', (YLeaf(YType.empty, 'restrict'), ['Empty'])),
                                ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ])
                            self.protect = None
                            self.restrict = None
                            self.shutdown = None
                            self._segment_path = lambda: "violation"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/switchport/port-security/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport.PortSecurity.Violation, ['protect', 'restrict', 'shutdown'], name, value)


                class Access(Entity):
                    """
                    Set access mode characteristics of the interface
                    
                    .. attribute:: vlan
                    
                    	VLAN ID of the VLAN when this port is in access mode
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.Switchport.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "access"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport.Access, ['vlan'], name, value)


                class Voice(Entity):
                    """
                    Voice appliance attributes
                    
                    .. attribute:: vlan
                    
                    	Vlan for voice traffic
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.Switchport.Voice, self).__init__()

                        self.yang_name = "voice"
                        self.yang_parent_name = "switchport"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                        ])
                        self.vlan = None
                        self._segment_path = lambda: "voice"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/switchport/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Switchport.Voice, ['vlan'], name, value)


            class SpanningTree(Entity):
                """
                Spanning Tree Subsystem
                
                .. attribute:: bpduguard
                
                	Don't accept BPDUs on this interface
                	**type**\:  :py:class:`Bpduguard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.SpanningTree.Bpduguard>`
                
                .. attribute:: service_policy
                
                	help
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: portfast
                
                	Portfast options for the interface
                	**type**\:  :py:class:`Portfast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.SpanningTree.Portfast>`
                
                	**presence node**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.TPINTERFACETEMPLATE.SpanningTree, self).__init__()

                    self.yang_name = "spanning-tree"
                    self.yang_parent_name = "TP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bpduguard", ("bpduguard", Native.Template.TPINTERFACETEMPLATE.SpanningTree.Bpduguard)), ("portfast", ("portfast", Native.Template.TPINTERFACETEMPLATE.SpanningTree.Portfast))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict([
                        ('service_policy', (YLeaf(YType.empty, 'service-policy'), ['Empty'])),
                    ])
                    self.service_policy = None

                    self.bpduguard = Native.Template.TPINTERFACETEMPLATE.SpanningTree.Bpduguard()
                    self.bpduguard.parent = self
                    self._children_name_map["bpduguard"] = "bpduguard"

                    self.portfast = None
                    self._children_name_map["portfast"] = "portfast"
                    self._segment_path = lambda: "spanning-tree"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.SpanningTree, ['service_policy'], name, value)


                class Bpduguard(Entity):
                    """
                    Don't accept BPDUs on this interface
                    
                    .. attribute:: enable
                    
                    	Enable BPDU guard for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.SpanningTree.Bpduguard, self).__init__()

                        self.yang_name = "bpduguard"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                        ])
                        self.enable = None
                        self._segment_path = lambda: "bpduguard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.SpanningTree.Bpduguard, ['enable'], name, value)


                class Portfast(Entity):
                    """
                    Portfast options for the interface
                    
                    .. attribute:: disable
                    
                    	Disable portfast for this interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: edge
                    
                    	Enable portfast edge on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: network
                    
                    	Enable portfast network on the interface
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.SpanningTree.Portfast, self).__init__()

                        self.yang_name = "portfast"
                        self.yang_parent_name = "spanning-tree"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self.is_presence_container = True
                        self._leafs = OrderedDict([
                            ('disable', (YLeaf(YType.empty, 'disable'), ['Empty'])),
                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                            ('network', (YLeaf(YType.empty, 'network'), ['Empty'])),
                        ])
                        self.disable = None
                        self.edge = None
                        self.network = None
                        self._segment_path = lambda: "portfast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/spanning-tree/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.SpanningTree.Portfast, ['disable', 'edge', 'network'], name, value)


            class StormControl(Entity):
                """
                storm configuration
                
                .. attribute:: broadcast
                
                	Broadcast address storm control
                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast>`
                
                .. attribute:: multicast
                
                	Multicast address storm control
                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast>`
                
                .. attribute:: action
                
                	Action to take for storm\-control
                	**type**\:  :py:class:`Action <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.StormControl.Action>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.TPINTERFACETEMPLATE.StormControl, self).__init__()

                    self.yang_name = "storm-control"
                    self.yang_parent_name = "TP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("broadcast", ("broadcast", Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast)), ("multicast", ("multicast", Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast)), ("action", ("action", Native.Template.TPINTERFACETEMPLATE.StormControl.Action))])
                    self._leafs = OrderedDict()

                    self.broadcast = Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast()
                    self.broadcast.parent = self
                    self._children_name_map["broadcast"] = "broadcast"

                    self.multicast = Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast()
                    self.multicast.parent = self
                    self._children_name_map["multicast"] = "multicast"

                    self.action = Native.Template.TPINTERFACETEMPLATE.StormControl.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._segment_path = lambda: "storm-control"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.StormControl, [], name, value)


                class Broadcast(Entity):
                    """
                    Broadcast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast, self).__init__()

                        self.yang_name = "broadcast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "broadcast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "broadcast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps)), ("bps", ("bps", Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/storm-control/broadcast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/storm-control/broadcast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.StormControl.Broadcast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Multicast(Entity):
                    """
                    Multicast address storm control
                    
                    .. attribute:: level
                    
                    	Set storm suppression level on this interface
                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast, self).__init__()

                        self.yang_name = "multicast"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("level", ("level", Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level))])
                        self._leafs = OrderedDict()

                        self.level = Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level()
                        self.level.parent = self
                        self._children_name_map["level"] = "level"
                        self._segment_path = lambda: "multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast, [], name, value)


                    class Level(Entity):
                        """
                        Set storm suppression level on this interface
                        
                        .. attribute:: pps
                        
                        	Enter suppression level in packets per second
                        	**type**\:  :py:class:`Pps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps>`
                        
                        .. attribute:: bps
                        
                        	Enter suppression level in bits per second
                        	**type**\:  :py:class:`Bps <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps>`
                        
                        .. attribute:: threshold
                        
                        	Enter threshold
                        	**type**\: Decimal64
                        
                        	**range:** 0.00..100.00
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level, self).__init__()

                            self.yang_name = "level"
                            self.yang_parent_name = "multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pps", ("pps", Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps)), ("bps", ("bps", Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps))])
                            self._leafs = OrderedDict([
                                ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                            ])
                            self.threshold = None

                            self.pps = Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps()
                            self.pps.parent = self
                            self._children_name_map["pps"] = "pps"

                            self.bps = Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps()
                            self.bps.parent = self
                            self._children_name_map["bps"] = "bps"
                            self._segment_path = lambda: "level"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/storm-control/multicast/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level, ['threshold'], name, value)


                        class Pps(Entity):
                            """
                            Enter suppression level in packets per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, self).__init__()

                                self.yang_name = "pps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                ])
                                self.threshold = None
                                self._segment_path = lambda: "pps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level.Pps, ['threshold'], name, value)


                        class Bps(Entity):
                            """
                            Enter suppression level in bits per second
                            
                            .. attribute:: threshold
                            
                            	Enter threshold
                            	**type**\: Decimal64
                            
                            	**range:** 0.0..10000000000.0
                            
                            .. attribute:: b_unit
                            
                            	
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, self).__init__()

                                self.yang_name = "bps"
                                self.yang_parent_name = "level"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold', (YLeaf(YType.str, 'threshold'), ['Decimal64'])),
                                    ('b_unit', (YLeaf(YType.str, 'b-unit'), ['str'])),
                                ])
                                self.threshold = None
                                self.b_unit = None
                                self._segment_path = lambda: "bps"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/storm-control/multicast/level/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.StormControl.Multicast.Level.Bps, ['threshold', 'b_unit'], name, value)


                class Action(Entity):
                    """
                    Action to take for storm\-control
                    
                    .. attribute:: shutdown
                    
                    	Shutdown this interface if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: trap
                    
                    	Send SNMP trap if a storm occurs
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.StormControl.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "storm-control"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                            ('trap', (YLeaf(YType.empty, 'trap'), ['Empty'])),
                        ])
                        self.shutdown = None
                        self.trap = None
                        self._segment_path = lambda: "action"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/storm-control/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.StormControl.Action, ['shutdown', 'trap'], name, value)


            class Ip(Entity):
                """
                IP template config
                
                .. attribute:: dhcp
                
                	DHCP template config
                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp>`
                
                

                """

                _prefix = 'ios-template'
                _revision = '2017-11-06'

                def __init__(self):
                    super(Native.Template.TPINTERFACETEMPLATE.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "TP_INTERFACE_TEMPLATE"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dhcp", ("dhcp", Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp))])
                    self._leafs = OrderedDict()

                    self.dhcp = Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp()
                    self.dhcp.parent = self
                    self._children_name_map["dhcp"] = "dhcp"
                    self._segment_path = lambda: "ip"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Ip, [], name, value)


                class Dhcp(Entity):
                    """
                    DHCP template config
                    
                    .. attribute:: snooping
                    
                    	DHCP Snooping
                    	**type**\:  :py:class:`Snooping <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp.Snooping>`
                    
                    

                    """

                    _prefix = 'ios-template'
                    _revision = '2017-11-06'

                    def __init__(self):
                        super(Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp, self).__init__()

                        self.yang_name = "dhcp"
                        self.yang_parent_name = "ip"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("snooping", ("snooping", Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp.Snooping))])
                        self._leafs = OrderedDict()

                        self.snooping = Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp.Snooping()
                        self.snooping.parent = self
                        self._children_name_map["snooping"] = "snooping"
                        self._segment_path = lambda: "dhcp"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/ip/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp, [], name, value)


                    class Snooping(Entity):
                        """
                        DHCP Snooping
                        
                        .. attribute:: limit
                        
                        	DHCP Snooping limit
                        	**type**\:  :py:class:`Limit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit>`
                        
                        .. attribute:: trust
                        
                        	DHCP Snooping trust config
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-template'
                        _revision = '2017-11-06'

                        def __init__(self):
                            super(Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp.Snooping, self).__init__()

                            self.yang_name = "snooping"
                            self.yang_parent_name = "dhcp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("limit", ("limit", Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit))])
                            self._leafs = OrderedDict([
                                ('trust', (YLeaf(YType.empty, 'trust'), ['Empty'])),
                            ])
                            self.trust = None

                            self.limit = Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit()
                            self.limit.parent = self
                            self._children_name_map["limit"] = "limit"
                            self._segment_path = lambda: "snooping"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/ip/dhcp/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp.Snooping, ['trust'], name, value)


                        class Limit(Entity):
                            """
                            DHCP Snooping limit
                            
                            .. attribute:: rate
                            
                            	DHCP snooping rate limit
                            	**type**\: int
                            
                            	**range:** 1..2048
                            
                            

                            """

                            _prefix = 'ios-template'
                            _revision = '2017-11-06'

                            def __init__(self):
                                super(Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, self).__init__()

                                self.yang_name = "limit"
                                self.yang_parent_name = "snooping"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('rate', (YLeaf(YType.uint16, 'rate'), ['int'])),
                                ])
                                self.rate = None
                                self._segment_path = lambda: "limit"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/template/Cisco-IOS-XE-template:TP_INTERFACE_TEMPLATE/ip/dhcp/snooping/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Template.TPINTERFACETEMPLATE.Ip.Dhcp.Snooping.Limit, ['rate'], name, value)


    class Process(Entity):
        """
        Configure process
        
        .. attribute:: cpu
        
        	Configure cpu parameters
        	**type**\:  :py:class:`Cpu <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu>`
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Process, self).__init__()

            self.yang_name = "process"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("cpu", ("cpu", Native.Process.Cpu))])
            self._leafs = OrderedDict()

            self.cpu = Native.Process.Cpu()
            self.cpu.parent = self
            self._children_name_map["cpu"] = "cpu"
            self._segment_path = lambda: "process"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Process, [], name, value)


        class Cpu(Entity):
            """
            Configure cpu parameters
            
            .. attribute:: threshold
            
            	cpu threshold parameters
            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold>`
            
            

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Process.Cpu, self).__init__()

                self.yang_name = "cpu"
                self.yang_parent_name = "process"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("threshold", ("threshold", Native.Process.Cpu.Threshold))])
                self._leafs = OrderedDict()

                self.threshold = Native.Process.Cpu.Threshold()
                self.threshold.parent = self
                self._children_name_map["threshold"] = "threshold"
                self._segment_path = lambda: "cpu"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Process.Cpu, [], name, value)


            class Threshold(Entity):
                """
                cpu threshold parameters
                
                .. attribute:: type
                
                	cpu threshold type
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type>`
                
                

                """

                _prefix = 'ios'
                _revision = '2018-05-22'

                def __init__(self):
                    super(Native.Process.Cpu.Threshold, self).__init__()

                    self.yang_name = "threshold"
                    self.yang_parent_name = "cpu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("type", ("type", Native.Process.Cpu.Threshold.Type))])
                    self._leafs = OrderedDict()

                    self.type = Native.Process.Cpu.Threshold.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "threshold"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/cpu/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Process.Cpu.Threshold, [], name, value)


                class Type(Entity):
                    """
                    cpu threshold type
                    
                    .. attribute:: interrupt
                    
                    	interrupt level utilization
                    	**type**\:  :py:class:`Interrupt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Interrupt>`
                    
                    .. attribute:: process
                    
                    	process level utilization
                    	**type**\:  :py:class:`Process_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Process_>`
                    
                    .. attribute:: total
                    
                    	total cpu utilization
                    	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Total>`
                    
                    

                    """

                    _prefix = 'ios'
                    _revision = '2018-05-22'

                    def __init__(self):
                        super(Native.Process.Cpu.Threshold.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "threshold"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interrupt", ("interrupt", Native.Process.Cpu.Threshold.Type.Interrupt)), ("process", ("process", Native.Process.Cpu.Threshold.Type.Process_)), ("total", ("total", Native.Process.Cpu.Threshold.Type.Total))])
                        self._leafs = OrderedDict()

                        self.interrupt = Native.Process.Cpu.Threshold.Type.Interrupt()
                        self.interrupt.parent = self
                        self._children_name_map["interrupt"] = "interrupt"

                        self.process = Native.Process.Cpu.Threshold.Type.Process_()
                        self.process.parent = self
                        self._children_name_map["process"] = "process"

                        self.total = Native.Process.Cpu.Threshold.Type.Total()
                        self.total.parent = self
                        self._children_name_map["total"] = "total"
                        self._segment_path = lambda: "type"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/cpu/threshold/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Process.Cpu.Threshold.Type, [], name, value)


                    class Interrupt(Entity):
                        """
                        interrupt level utilization
                        
                        .. attribute:: rising
                        
                        	rising threshold
                        	**type**\:  :py:class:`Rising <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Interrupt.Rising>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Process.Cpu.Threshold.Type.Interrupt, self).__init__()

                            self.yang_name = "interrupt"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rising", ("rising", Native.Process.Cpu.Threshold.Type.Interrupt.Rising))])
                            self._leafs = OrderedDict()

                            self.rising = Native.Process.Cpu.Threshold.Type.Interrupt.Rising()
                            self.rising.parent = self
                            self._children_name_map["rising"] = "rising"
                            self._segment_path = lambda: "interrupt"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/cpu/threshold/type/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Process.Cpu.Threshold.Type.Interrupt, [], name, value)


                        class Rising(Entity):
                            """
                            rising threshold
                            
                            .. attribute:: cpu_range
                            
                            	
                            	**type**\: list of  		 :py:class:`CpuRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Process.Cpu.Threshold.Type.Interrupt.Rising, self).__init__()

                                self.yang_name = "rising"
                                self.yang_parent_name = "interrupt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cpu-range", ("cpu_range", Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange))])
                                self._leafs = OrderedDict()

                                self.cpu_range = YList(self)
                                self._segment_path = lambda: "rising"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/cpu/threshold/type/interrupt/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Process.Cpu.Threshold.Type.Interrupt.Rising, [], name, value)


                            class CpuRange(Entity):
                                """
                                
                                
                                .. attribute:: cpu_range  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: interval
                                
                                	observation interval
                                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange, self).__init__()

                                    self.yang_name = "cpu-range"
                                    self.yang_parent_name = "rising"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['cpu_range']
                                    self._child_classes = OrderedDict([("interval", ("interval", Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval))])
                                    self._leafs = OrderedDict([
                                        ('cpu_range', (YLeaf(YType.uint8, 'cpu-range'), ['int'])),
                                    ])
                                    self.cpu_range = None

                                    self.interval = Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval()
                                    self.interval.parent = self
                                    self._children_name_map["interval"] = "interval"
                                    self._segment_path = lambda: "cpu-range" + "[cpu-range='" + str(self.cpu_range) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/cpu/threshold/type/interrupt/rising/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange, [u'cpu_range'], name, value)


                                class Interval(Entity):
                                    """
                                    observation interval
                                    
                                    .. attribute:: cpu_range
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`CpuRange_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval, self).__init__()

                                        self.yang_name = "interval"
                                        self.yang_parent_name = "cpu-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("cpu-range", ("cpu_range", Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_))])
                                        self._leafs = OrderedDict()

                                        self.cpu_range = YList(self)
                                        self._segment_path = lambda: "interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval, [], name, value)


                                    class CpuRange_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: cpu_range  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 5..86400
                                        
                                        .. attribute:: falling
                                        
                                        	falling threshold
                                        	**type**\:  :py:class:`Falling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_.Falling>`
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_, self).__init__()

                                            self.yang_name = "cpu-range"
                                            self.yang_parent_name = "interval"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['cpu_range']
                                            self._child_classes = OrderedDict([("falling", ("falling", Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_.Falling))])
                                            self._leafs = OrderedDict([
                                                ('cpu_range', (YLeaf(YType.uint32, 'cpu-range'), ['int'])),
                                            ])
                                            self.cpu_range = None

                                            self.falling = Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_.Falling()
                                            self.falling.parent = self
                                            self._children_name_map["falling"] = "falling"
                                            self._segment_path = lambda: "cpu-range" + "[cpu-range='" + str(self.cpu_range) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_, [u'cpu_range'], name, value)


                                        class Falling(Entity):
                                            """
                                            falling threshold
                                            
                                            .. attribute:: cpu_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`CpuRange_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_>`
                                            
                                            

                                            """

                                            _prefix = 'ios'
                                            _revision = '2018-05-22'

                                            def __init__(self):
                                                super(Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_.Falling, self).__init__()

                                                self.yang_name = "falling"
                                                self.yang_parent_name = "cpu-range"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cpu-range", ("cpu_range", Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_))])
                                                self._leafs = OrderedDict()

                                                self.cpu_range = YList(self)
                                                self._segment_path = lambda: "falling"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_.Falling, [], name, value)


                                            class CpuRange_(Entity):
                                                """
                                                
                                                
                                                .. attribute:: cpu_range  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: interval
                                                
                                                	observation interval
                                                	**type**\: int
                                                
                                                	**range:** 5..86400
                                                
                                                

                                                """

                                                _prefix = 'ios'
                                                _revision = '2018-05-22'

                                                def __init__(self):
                                                    super(Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_, self).__init__()

                                                    self.yang_name = "cpu-range"
                                                    self.yang_parent_name = "falling"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['cpu_range']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('cpu_range', (YLeaf(YType.uint8, 'cpu-range'), ['int'])),
                                                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                                    ])
                                                    self.cpu_range = None
                                                    self.interval = None
                                                    self._segment_path = lambda: "cpu-range" + "[cpu-range='" + str(self.cpu_range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Process.Cpu.Threshold.Type.Interrupt.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_, [u'cpu_range', u'interval'], name, value)


                    class Process_(Entity):
                        """
                        process level utilization
                        
                        .. attribute:: rising
                        
                        	rising threshold
                        	**type**\:  :py:class:`Rising <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Process_.Rising>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Process.Cpu.Threshold.Type.Process_, self).__init__()

                            self.yang_name = "process"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rising", ("rising", Native.Process.Cpu.Threshold.Type.Process_.Rising))])
                            self._leafs = OrderedDict()

                            self.rising = Native.Process.Cpu.Threshold.Type.Process_.Rising()
                            self.rising.parent = self
                            self._children_name_map["rising"] = "rising"
                            self._segment_path = lambda: "process"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/cpu/threshold/type/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Process.Cpu.Threshold.Type.Process_, [], name, value)


                        class Rising(Entity):
                            """
                            rising threshold
                            
                            .. attribute:: cpu_range
                            
                            	
                            	**type**\: list of  		 :py:class:`CpuRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Process.Cpu.Threshold.Type.Process_.Rising, self).__init__()

                                self.yang_name = "rising"
                                self.yang_parent_name = "process"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cpu-range", ("cpu_range", Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange))])
                                self._leafs = OrderedDict()

                                self.cpu_range = YList(self)
                                self._segment_path = lambda: "rising"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/cpu/threshold/type/process/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Process.Cpu.Threshold.Type.Process_.Rising, [], name, value)


                            class CpuRange(Entity):
                                """
                                
                                
                                .. attribute:: cpu_range  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: interval
                                
                                	observation interval
                                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange, self).__init__()

                                    self.yang_name = "cpu-range"
                                    self.yang_parent_name = "rising"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['cpu_range']
                                    self._child_classes = OrderedDict([("interval", ("interval", Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval))])
                                    self._leafs = OrderedDict([
                                        ('cpu_range', (YLeaf(YType.uint8, 'cpu-range'), ['int'])),
                                    ])
                                    self.cpu_range = None

                                    self.interval = Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval()
                                    self.interval.parent = self
                                    self._children_name_map["interval"] = "interval"
                                    self._segment_path = lambda: "cpu-range" + "[cpu-range='" + str(self.cpu_range) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/cpu/threshold/type/process/rising/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange, [u'cpu_range'], name, value)


                                class Interval(Entity):
                                    """
                                    observation interval
                                    
                                    .. attribute:: cpu_range
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`CpuRange_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval, self).__init__()

                                        self.yang_name = "interval"
                                        self.yang_parent_name = "cpu-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("cpu-range", ("cpu_range", Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_))])
                                        self._leafs = OrderedDict()

                                        self.cpu_range = YList(self)
                                        self._segment_path = lambda: "interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval, [], name, value)


                                    class CpuRange_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: cpu_range  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 5..86400
                                        
                                        .. attribute:: falling
                                        
                                        	falling threshold
                                        	**type**\:  :py:class:`Falling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_.Falling>`
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_, self).__init__()

                                            self.yang_name = "cpu-range"
                                            self.yang_parent_name = "interval"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['cpu_range']
                                            self._child_classes = OrderedDict([("falling", ("falling", Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_.Falling))])
                                            self._leafs = OrderedDict([
                                                ('cpu_range', (YLeaf(YType.uint32, 'cpu-range'), ['int'])),
                                            ])
                                            self.cpu_range = None

                                            self.falling = Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_.Falling()
                                            self.falling.parent = self
                                            self._children_name_map["falling"] = "falling"
                                            self._segment_path = lambda: "cpu-range" + "[cpu-range='" + str(self.cpu_range) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_, [u'cpu_range'], name, value)


                                        class Falling(Entity):
                                            """
                                            falling threshold
                                            
                                            .. attribute:: cpu_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`CpuRange_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_>`
                                            
                                            

                                            """

                                            _prefix = 'ios'
                                            _revision = '2018-05-22'

                                            def __init__(self):
                                                super(Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_.Falling, self).__init__()

                                                self.yang_name = "falling"
                                                self.yang_parent_name = "cpu-range"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cpu-range", ("cpu_range", Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_))])
                                                self._leafs = OrderedDict()

                                                self.cpu_range = YList(self)
                                                self._segment_path = lambda: "falling"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_.Falling, [], name, value)


                                            class CpuRange_(Entity):
                                                """
                                                
                                                
                                                .. attribute:: cpu_range  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: interval
                                                
                                                	observation interval
                                                	**type**\: int
                                                
                                                	**range:** 5..86400
                                                
                                                

                                                """

                                                _prefix = 'ios'
                                                _revision = '2018-05-22'

                                                def __init__(self):
                                                    super(Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_, self).__init__()

                                                    self.yang_name = "cpu-range"
                                                    self.yang_parent_name = "falling"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['cpu_range']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('cpu_range', (YLeaf(YType.uint8, 'cpu-range'), ['int'])),
                                                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                                    ])
                                                    self.cpu_range = None
                                                    self.interval = None
                                                    self._segment_path = lambda: "cpu-range" + "[cpu-range='" + str(self.cpu_range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Process.Cpu.Threshold.Type.Process_.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_, [u'cpu_range', u'interval'], name, value)


                    class Total(Entity):
                        """
                        total cpu utilization
                        
                        .. attribute:: rising
                        
                        	rising threshold
                        	**type**\:  :py:class:`Rising <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Total.Rising>`
                        
                        

                        """

                        _prefix = 'ios'
                        _revision = '2018-05-22'

                        def __init__(self):
                            super(Native.Process.Cpu.Threshold.Type.Total, self).__init__()

                            self.yang_name = "total"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rising", ("rising", Native.Process.Cpu.Threshold.Type.Total.Rising))])
                            self._leafs = OrderedDict()

                            self.rising = Native.Process.Cpu.Threshold.Type.Total.Rising()
                            self.rising.parent = self
                            self._children_name_map["rising"] = "rising"
                            self._segment_path = lambda: "total"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/cpu/threshold/type/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Process.Cpu.Threshold.Type.Total, [], name, value)


                        class Rising(Entity):
                            """
                            rising threshold
                            
                            .. attribute:: cpu_range
                            
                            	
                            	**type**\: list of  		 :py:class:`CpuRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange>`
                            
                            

                            """

                            _prefix = 'ios'
                            _revision = '2018-05-22'

                            def __init__(self):
                                super(Native.Process.Cpu.Threshold.Type.Total.Rising, self).__init__()

                                self.yang_name = "rising"
                                self.yang_parent_name = "total"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cpu-range", ("cpu_range", Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange))])
                                self._leafs = OrderedDict()

                                self.cpu_range = YList(self)
                                self._segment_path = lambda: "rising"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/cpu/threshold/type/total/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Process.Cpu.Threshold.Type.Total.Rising, [], name, value)


                            class CpuRange(Entity):
                                """
                                
                                
                                .. attribute:: cpu_range  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..100
                                
                                .. attribute:: interval
                                
                                	observation interval
                                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval>`
                                
                                

                                """

                                _prefix = 'ios'
                                _revision = '2018-05-22'

                                def __init__(self):
                                    super(Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange, self).__init__()

                                    self.yang_name = "cpu-range"
                                    self.yang_parent_name = "rising"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['cpu_range']
                                    self._child_classes = OrderedDict([("interval", ("interval", Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval))])
                                    self._leafs = OrderedDict([
                                        ('cpu_range', (YLeaf(YType.uint8, 'cpu-range'), ['int'])),
                                    ])
                                    self.cpu_range = None

                                    self.interval = Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval()
                                    self.interval.parent = self
                                    self._children_name_map["interval"] = "interval"
                                    self._segment_path = lambda: "cpu-range" + "[cpu-range='" + str(self.cpu_range) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/process/cpu/threshold/type/total/rising/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange, [u'cpu_range'], name, value)


                                class Interval(Entity):
                                    """
                                    observation interval
                                    
                                    .. attribute:: cpu_range
                                    
                                    	
                                    	**type**\: list of  		 :py:class:`CpuRange_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_>`
                                    
                                    

                                    """

                                    _prefix = 'ios'
                                    _revision = '2018-05-22'

                                    def __init__(self):
                                        super(Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval, self).__init__()

                                        self.yang_name = "interval"
                                        self.yang_parent_name = "cpu-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("cpu-range", ("cpu_range", Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_))])
                                        self._leafs = OrderedDict()

                                        self.cpu_range = YList(self)
                                        self._segment_path = lambda: "interval"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval, [], name, value)


                                    class CpuRange_(Entity):
                                        """
                                        
                                        
                                        .. attribute:: cpu_range  (key)
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 5..86400
                                        
                                        .. attribute:: falling
                                        
                                        	falling threshold
                                        	**type**\:  :py:class:`Falling <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_.Falling>`
                                        
                                        

                                        """

                                        _prefix = 'ios'
                                        _revision = '2018-05-22'

                                        def __init__(self):
                                            super(Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_, self).__init__()

                                            self.yang_name = "cpu-range"
                                            self.yang_parent_name = "interval"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['cpu_range']
                                            self._child_classes = OrderedDict([("falling", ("falling", Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_.Falling))])
                                            self._leafs = OrderedDict([
                                                ('cpu_range', (YLeaf(YType.uint32, 'cpu-range'), ['int'])),
                                            ])
                                            self.cpu_range = None

                                            self.falling = Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_.Falling()
                                            self.falling.parent = self
                                            self._children_name_map["falling"] = "falling"
                                            self._segment_path = lambda: "cpu-range" + "[cpu-range='" + str(self.cpu_range) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_, [u'cpu_range'], name, value)


                                        class Falling(Entity):
                                            """
                                            falling threshold
                                            
                                            .. attribute:: cpu_range
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`CpuRange_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_>`
                                            
                                            

                                            """

                                            _prefix = 'ios'
                                            _revision = '2018-05-22'

                                            def __init__(self):
                                                super(Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_.Falling, self).__init__()

                                                self.yang_name = "falling"
                                                self.yang_parent_name = "cpu-range"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("cpu-range", ("cpu_range", Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_))])
                                                self._leafs = OrderedDict()

                                                self.cpu_range = YList(self)
                                                self._segment_path = lambda: "falling"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_.Falling, [], name, value)


                                            class CpuRange_(Entity):
                                                """
                                                
                                                
                                                .. attribute:: cpu_range  (key)
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 1..100
                                                
                                                .. attribute:: interval
                                                
                                                	observation interval
                                                	**type**\: int
                                                
                                                	**range:** 5..86400
                                                
                                                

                                                """

                                                _prefix = 'ios'
                                                _revision = '2018-05-22'

                                                def __init__(self):
                                                    super(Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_, self).__init__()

                                                    self.yang_name = "cpu-range"
                                                    self.yang_parent_name = "falling"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['cpu_range']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('cpu_range', (YLeaf(YType.uint8, 'cpu-range'), ['int'])),
                                                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                                    ])
                                                    self.cpu_range = None
                                                    self.interval = None
                                                    self._segment_path = lambda: "cpu-range" + "[cpu-range='" + str(self.cpu_range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Process.Cpu.Threshold.Type.Total.Rising.CpuRange.Interval.CpuRange_.Falling.CpuRange_, [u'cpu_range', u'interval'], name, value)


    class Exception(Entity):
        """
        help
        
        .. attribute:: crashinfo
        
        	Crashinfo collection
        	**type**\:  :py:class:`Crashinfo <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Exception.Crashinfo>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Exception, self).__init__()

            self.yang_name = "exception"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("crashinfo", ("crashinfo", Native.Exception.Crashinfo))])
            self._leafs = OrderedDict()

            self.crashinfo = None
            self._children_name_map["crashinfo"] = "crashinfo"
            self._segment_path = lambda: "exception"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Exception, [], name, value)


        class Crashinfo(Entity):
            """
            Crashinfo collection
            
            .. attribute:: buffersize
            
            	buffer size in Kbytes 256K or less (default is 32K)
            	**type**\: int
            
            	**range:** 32..256
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios'
            _revision = '2018-05-22'

            def __init__(self):
                super(Native.Exception.Crashinfo, self).__init__()

                self.yang_name = "crashinfo"
                self.yang_parent_name = "exception"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('buffersize', (YLeaf(YType.uint16, 'buffersize'), ['int'])),
                ])
                self.buffersize = None
                self._segment_path = lambda: "crashinfo"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/exception/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Exception.Crashinfo, [u'buffersize'], name, value)


    class Iox(Entity):
        """
        Configure IOx services
        
        

        This class is a :ref:`presence class<presence-class>`

        """

        _prefix = 'ios'
        _revision = '2018-05-22'

        def __init__(self):
            super(Native.Iox, self).__init__()

            self.yang_name = "iox"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self.is_presence_container = True
            self._leafs = OrderedDict()
            self._segment_path = lambda: "iox"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True


    class NamedOrderingRouteMap(Entity):
        """
        named ordering route\-map enable
        
        .. attribute:: enable
        
        	named ordering enable
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios-route-map'
        _revision = '2018-03-08'

        def __init__(self):
            super(Native.NamedOrderingRouteMap, self).__init__()

            self.yang_name = "named-ordering-route-map"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
            ])
            self.enable = None
            self._segment_path = lambda: "Cisco-IOS-XE-route-map:named-ordering-route-map"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.NamedOrderingRouteMap, ['enable'], name, value)


    class Esmc(Entity):
        """
        Ethernet Synchronization Messaging Channel
        
        .. attribute:: process
        
        	process
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios-eth'
        _revision = '2018-04-09'

        def __init__(self):
            super(Native.Esmc, self).__init__()

            self.yang_name = "esmc"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('process', (YLeaf(YType.empty, 'process'), ['Empty'])),
            ])
            self.process = None
            self._segment_path = lambda: "Cisco-IOS-XE-ethernet:esmc"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Esmc, ['process'], name, value)


    class Cef(Entity):
        """
        Cisco Express Forwarding
        
        .. attribute:: table
        
        	Set CEF forwarding table characteristics
        	**type**\:  :py:class:`Table <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table>`
        
        

        """

        _prefix = 'ios-cef'
        _revision = '2017-05-19'

        def __init__(self):
            super(Native.Cef, self).__init__()

            self.yang_name = "cef"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("table", ("table", Native.Cef.Table))])
            self._leafs = OrderedDict()

            self.table = Native.Cef.Table()
            self.table.parent = self
            self._children_name_map["table"] = "table"
            self._segment_path = lambda: "Cisco-IOS-XE-cef:cef"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Cef, [], name, value)


        class Table(Entity):
            """
            Set CEF forwarding table characteristics
            
            .. attribute:: output_chain
            
            	Set table output chain characteristics
            	**type**\:  :py:class:`OutputChain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.OutputChain>`
            
            .. attribute:: consistency_check
            
            	
            	**type**\:  :py:class:`ConsistencyCheck <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck>`
            
            .. attribute:: download
            
            	
            	**type**\:  :py:class:`Download <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download>`
            
            .. attribute:: rate_monitor_period
            
            	Period in minutes
            	**type**\: int
            
            	**range:** 1..60
            
            

            """

            _prefix = 'ios-cef'
            _revision = '2017-05-19'

            def __init__(self):
                super(Native.Cef.Table, self).__init__()

                self.yang_name = "table"
                self.yang_parent_name = "cef"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("output-chain", ("output_chain", Native.Cef.Table.OutputChain)), ("consistency-check", ("consistency_check", Native.Cef.Table.ConsistencyCheck)), ("download", ("download", Native.Cef.Table.Download))])
                self._leafs = OrderedDict([
                    ('rate_monitor_period', (YLeaf(YType.uint8, 'rate-monitor-period'), ['int'])),
                ])
                self.rate_monitor_period = None

                self.output_chain = Native.Cef.Table.OutputChain()
                self.output_chain.parent = self
                self._children_name_map["output_chain"] = "output-chain"

                self.consistency_check = Native.Cef.Table.ConsistencyCheck()
                self.consistency_check.parent = self
                self._children_name_map["consistency_check"] = "consistency-check"

                self.download = Native.Cef.Table.Download()
                self.download.parent = self
                self._children_name_map["download"] = "download"
                self._segment_path = lambda: "table"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Cef.Table, ['rate_monitor_period'], name, value)


            class OutputChain(Entity):
                """
                Set table output chain characteristics
                
                .. attribute:: build
                
                	Set table output chain building characteristics
                	**type**\:  :py:class:`Build <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.OutputChain.Build>`
                
                

                """

                _prefix = 'ios-cef'
                _revision = '2017-05-19'

                def __init__(self):
                    super(Native.Cef.Table.OutputChain, self).__init__()

                    self.yang_name = "output-chain"
                    self.yang_parent_name = "table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("build", ("build", Native.Cef.Table.OutputChain.Build))])
                    self._leafs = OrderedDict()

                    self.build = Native.Cef.Table.OutputChain.Build()
                    self.build.parent = self
                    self._children_name_map["build"] = "build"
                    self._segment_path = lambda: "output-chain"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cef.Table.OutputChain, [], name, value)


                class Build(Entity):
                    """
                    Set table output chain building characteristics
                    
                    .. attribute:: favor
                    
                    	
                    	**type**\:  :py:class:`Favor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.OutputChain.Build.Favor>`
                    
                    .. attribute:: indirection
                    
                    	Customize table output chain building indirection characteristics
                    	**type**\:  :py:class:`Indirection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.OutputChain.Build.Indirection>`
                    
                    .. attribute:: inplace_modify
                    
                    	Customize table output chain building inplace modification characteristics
                    	**type**\:  :py:class:`InplaceModify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.OutputChain.Build.InplaceModify>`
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Cef.Table.OutputChain.Build, self).__init__()

                        self.yang_name = "build"
                        self.yang_parent_name = "output-chain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("favor", ("favor", Native.Cef.Table.OutputChain.Build.Favor)), ("indirection", ("indirection", Native.Cef.Table.OutputChain.Build.Indirection)), ("inplace-modify", ("inplace_modify", Native.Cef.Table.OutputChain.Build.InplaceModify))])
                        self._leafs = OrderedDict()

                        self.favor = Native.Cef.Table.OutputChain.Build.Favor()
                        self.favor.parent = self
                        self._children_name_map["favor"] = "favor"

                        self.indirection = Native.Cef.Table.OutputChain.Build.Indirection()
                        self.indirection.parent = self
                        self._children_name_map["indirection"] = "indirection"

                        self.inplace_modify = Native.Cef.Table.OutputChain.Build.InplaceModify()
                        self.inplace_modify.parent = self
                        self._children_name_map["inplace_modify"] = "inplace-modify"
                        self._segment_path = lambda: "build"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/output-chain/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cef.Table.OutputChain.Build, [], name, value)


                    class Favor(Entity):
                        """
                        
                        
                        .. attribute:: convergence_speed
                        
                        	Favor faster convergence
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: memory_utilization
                        
                        	Favor smaller memory utilization
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.OutputChain.Build.Favor, self).__init__()

                            self.yang_name = "favor"
                            self.yang_parent_name = "build"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('convergence_speed', (YLeaf(YType.empty, 'convergence-speed'), ['Empty'])),
                                ('memory_utilization', (YLeaf(YType.empty, 'memory-utilization'), ['Empty'])),
                            ])
                            self.convergence_speed = None
                            self.memory_utilization = None
                            self._segment_path = lambda: "favor"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/output-chain/build/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.OutputChain.Build.Favor, ['convergence_speed', 'memory_utilization'], name, value)


                    class Indirection(Entity):
                        """
                        Customize table output chain building indirection characteristics
                        
                        .. attribute:: ipv4_to_mpls
                        
                        	shared indirection object for IPv4 labeled prefixes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6_to_mpls
                        
                        	shared indirection object for IPv6 labeled prefixes
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mpls_end_of_stack
                        
                        	shared indirection object for MPLS disposition
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mpls_non_end_of_stack
                        
                        	shared indirection object for MPLS label switch
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: non_recursive_prefix
                        
                        	non\-recursive\-prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: recursive_prefix
                        
                        	recursive\-prefix
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.OutputChain.Build.Indirection, self).__init__()

                            self.yang_name = "indirection"
                            self.yang_parent_name = "build"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_to_mpls', (YLeaf(YType.empty, 'ipv4-to-mpls'), ['Empty'])),
                                ('ipv6_to_mpls', (YLeaf(YType.empty, 'ipv6-to-mpls'), ['Empty'])),
                                ('mpls_end_of_stack', (YLeaf(YType.empty, 'mpls-end-of-stack'), ['Empty'])),
                                ('mpls_non_end_of_stack', (YLeaf(YType.empty, 'mpls-non-end-of-stack'), ['Empty'])),
                                ('non_recursive_prefix', (YLeaf(YType.empty, 'non-recursive-prefix'), ['Empty'])),
                                ('recursive_prefix', (YLeaf(YType.empty, 'recursive-prefix'), ['Empty'])),
                            ])
                            self.ipv4_to_mpls = None
                            self.ipv6_to_mpls = None
                            self.mpls_end_of_stack = None
                            self.mpls_non_end_of_stack = None
                            self.non_recursive_prefix = None
                            self.recursive_prefix = None
                            self._segment_path = lambda: "indirection"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/output-chain/build/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.OutputChain.Build.Indirection, ['ipv4_to_mpls', 'ipv6_to_mpls', 'mpls_end_of_stack', 'mpls_non_end_of_stack', 'non_recursive_prefix', 'recursive_prefix'], name, value)


                    class InplaceModify(Entity):
                        """
                        Customize table output chain building inplace modification characteristics
                        
                        .. attribute:: load_sharing
                        
                        	load sharing structures
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: push_counter
                        
                        	push counter structures
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.OutputChain.Build.InplaceModify, self).__init__()

                            self.yang_name = "inplace-modify"
                            self.yang_parent_name = "build"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('load_sharing', (YLeaf(YType.empty, 'load-sharing'), ['Empty'])),
                                ('push_counter', (YLeaf(YType.empty, 'push-counter'), ['Empty'])),
                            ])
                            self.load_sharing = None
                            self.push_counter = None
                            self._segment_path = lambda: "inplace-modify"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/output-chain/build/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.OutputChain.Build.InplaceModify, ['load_sharing', 'push_counter'], name, value)


            class ConsistencyCheck(Entity):
                """
                
                
                .. attribute:: ipv4
                
                	IPv4 address family
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv4>`
                
                .. attribute:: ipv6
                
                	IPv6 address family
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv6>`
                
                

                """

                _prefix = 'ios-cef'
                _revision = '2017-05-19'

                def __init__(self):
                    super(Native.Cef.Table.ConsistencyCheck, self).__init__()

                    self.yang_name = "consistency-check"
                    self.yang_parent_name = "table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Cef.Table.ConsistencyCheck.Ipv4)), ("ipv6", ("ipv6", Native.Cef.Table.ConsistencyCheck.Ipv6))])
                    self._leafs = OrderedDict()

                    self.ipv4 = Native.Cef.Table.ConsistencyCheck.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = Native.Cef.Table.ConsistencyCheck.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._segment_path = lambda: "consistency-check"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cef.Table.ConsistencyCheck, [], name, value)


                class Ipv4(Entity):
                    """
                    IPv4 address family
                    
                    .. attribute:: auto_repair
                    
                    	Control auto\-repair function
                    	**type**\:  :py:class:`AutoRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv4.AutoRepair>`
                    
                    .. attribute:: type
                    
                    	Type of consistency check to configure
                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv4.Type>`
                    
                    .. attribute:: data_checking
                    
                    	Perform data consistency check
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: error_message
                    
                    	Generate error message on inconsistency detection
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Cef.Table.ConsistencyCheck.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "consistency-check"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto-repair", ("auto_repair", Native.Cef.Table.ConsistencyCheck.Ipv4.AutoRepair)), ("type", ("type", Native.Cef.Table.ConsistencyCheck.Ipv4.Type))])
                        self._leafs = OrderedDict([
                            ('data_checking', (YLeaf(YType.empty, 'data-checking'), ['Empty'])),
                            ('error_message', (YLeaf(YType.empty, 'error-message'), ['Empty'])),
                        ])
                        self.data_checking = None
                        self.error_message = None

                        self.auto_repair = Native.Cef.Table.ConsistencyCheck.Ipv4.AutoRepair()
                        self.auto_repair.parent = self
                        self._children_name_map["auto_repair"] = "auto-repair"

                        self.type = Native.Cef.Table.ConsistencyCheck.Ipv4.Type()
                        self.type.parent = self
                        self._children_name_map["type"] = "type"
                        self._segment_path = lambda: "ipv4"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv4, ['data_checking', 'error_message'], name, value)


                    class AutoRepair(Entity):
                        """
                        Control auto\-repair function
                        
                        .. attribute:: delay
                        
                        	Delay in seconds
                        	**type**\: int
                        
                        	**range:** 10..300
                        
                        .. attribute:: holddown
                        
                        	Delay in seconds
                        	**type**\: int
                        
                        	**range:** 300..3000
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.ConsistencyCheck.Ipv4.AutoRepair, self).__init__()

                            self.yang_name = "auto-repair"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('delay', (YLeaf(YType.uint16, 'delay'), ['int'])),
                                ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                            ])
                            self.delay = None
                            self.holddown = None
                            self._segment_path = lambda: "auto-repair"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv4.AutoRepair, ['delay', 'holddown'], name, value)


                    class Type(Entity):
                        """
                        Type of consistency check to configure
                        
                        .. attribute:: scan_ios_rib
                        
                        	Passive scan that checks RP tables against RIB
                        	**type**\:  :py:class:`ScanIosRib <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanIosRib>`
                        
                        .. attribute:: scan_rib_ios
                        
                        	Passive scan that checks RIB aginst RP tables
                        	**type**\:  :py:class:`ScanRibIos <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRibIos>`
                        
                        .. attribute:: scan_lc_rp
                        
                        	Passive scan that checks LC tables against RP tables
                        	**type**\:  :py:class:`ScanLcRp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanLcRp>`
                        
                        .. attribute:: scan_rp_lc
                        
                        	Passive scan that checks RP tables against LC tables
                        	**type**\:  :py:class:`ScanRpLc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRpLc>`
                        
                        .. attribute:: lc_detect
                        
                        	Linecard detects missing prefix. Confirmed by RP
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.ConsistencyCheck.Ipv4.Type, self).__init__()

                            self.yang_name = "type"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("scan-ios-rib", ("scan_ios_rib", Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanIosRib)), ("scan-rib-ios", ("scan_rib_ios", Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRibIos)), ("scan-lc-rp", ("scan_lc_rp", Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanLcRp)), ("scan-rp-lc", ("scan_rp_lc", Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRpLc))])
                            self._leafs = OrderedDict([
                                ('lc_detect', (YLeaf(YType.empty, 'lc-detect'), ['Empty'])),
                            ])
                            self.lc_detect = None

                            self.scan_ios_rib = Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanIosRib()
                            self.scan_ios_rib.parent = self
                            self._children_name_map["scan_ios_rib"] = "scan-ios-rib"

                            self.scan_rib_ios = Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRibIos()
                            self.scan_rib_ios.parent = self
                            self._children_name_map["scan_rib_ios"] = "scan-rib-ios"

                            self.scan_lc_rp = Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanLcRp()
                            self.scan_lc_rp.parent = self
                            self._children_name_map["scan_lc_rp"] = "scan-lc-rp"

                            self.scan_rp_lc = Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRpLc()
                            self.scan_rp_lc.parent = self
                            self._children_name_map["scan_rp_lc"] = "scan-rp-lc"
                            self._segment_path = lambda: "type"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv4.Type, ['lc_detect'], name, value)


                        class ScanIosRib(Entity):
                            """
                            Passive scan that checks RP tables against RIB
                            
                            .. attribute:: scan_opt
                            
                            	
                            	**type**\:  :py:class:`ScanOpt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanIosRib.ScanOpt>`
                            
                            

                            """

                            _prefix = 'ios-cef'
                            _revision = '2017-05-19'

                            def __init__(self):
                                super(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanIosRib, self).__init__()

                                self.yang_name = "scan-ios-rib"
                                self.yang_parent_name = "type"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("scan-opt", ("scan_opt", Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanIosRib.ScanOpt))])
                                self._leafs = OrderedDict()

                                self.scan_opt = Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanIosRib.ScanOpt()
                                self.scan_opt.parent = self
                                self._children_name_map["scan_opt"] = "scan-opt"
                                self._segment_path = lambda: "scan-ios-rib"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv4/type/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanIosRib, [], name, value)


                            class ScanOpt(Entity):
                                """
                                
                                
                                .. attribute:: count
                                
                                	Maximum number of prefixes to check per scan
                                	**type**\: int
                                
                                	**range:** 2..10000
                                
                                .. attribute:: period
                                
                                	Period between scans
                                	**type**\: int
                                
                                	**range:** 30..3600
                                
                                

                                """

                                _prefix = 'ios-cef'
                                _revision = '2017-05-19'

                                def __init__(self):
                                    super(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanIosRib.ScanOpt, self).__init__()

                                    self.yang_name = "scan-opt"
                                    self.yang_parent_name = "scan-ios-rib"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                        ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                    ])
                                    self.count = None
                                    self.period = None
                                    self._segment_path = lambda: "scan-opt"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv4/type/scan-ios-rib/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanIosRib.ScanOpt, ['count', 'period'], name, value)


                        class ScanRibIos(Entity):
                            """
                            Passive scan that checks RIB aginst RP tables
                            
                            .. attribute:: scan_opt
                            
                            	
                            	**type**\:  :py:class:`ScanOpt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRibIos.ScanOpt>`
                            
                            

                            """

                            _prefix = 'ios-cef'
                            _revision = '2017-05-19'

                            def __init__(self):
                                super(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRibIos, self).__init__()

                                self.yang_name = "scan-rib-ios"
                                self.yang_parent_name = "type"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("scan-opt", ("scan_opt", Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRibIos.ScanOpt))])
                                self._leafs = OrderedDict()

                                self.scan_opt = Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRibIos.ScanOpt()
                                self.scan_opt.parent = self
                                self._children_name_map["scan_opt"] = "scan-opt"
                                self._segment_path = lambda: "scan-rib-ios"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv4/type/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRibIos, [], name, value)


                            class ScanOpt(Entity):
                                """
                                
                                
                                .. attribute:: count
                                
                                	Maximum number of prefixes to check per scan
                                	**type**\: int
                                
                                	**range:** 2..10000
                                
                                .. attribute:: period
                                
                                	Period between scans
                                	**type**\: int
                                
                                	**range:** 30..3600
                                
                                

                                """

                                _prefix = 'ios-cef'
                                _revision = '2017-05-19'

                                def __init__(self):
                                    super(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRibIos.ScanOpt, self).__init__()

                                    self.yang_name = "scan-opt"
                                    self.yang_parent_name = "scan-rib-ios"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                        ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                    ])
                                    self.count = None
                                    self.period = None
                                    self._segment_path = lambda: "scan-opt"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv4/type/scan-rib-ios/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRibIos.ScanOpt, ['count', 'period'], name, value)


                        class ScanLcRp(Entity):
                            """
                            Passive scan that checks LC tables against RP tables
                            
                            .. attribute:: scan_opt
                            
                            	
                            	**type**\:  :py:class:`ScanOpt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanLcRp.ScanOpt>`
                            
                            

                            """

                            _prefix = 'ios-cef'
                            _revision = '2017-05-19'

                            def __init__(self):
                                super(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanLcRp, self).__init__()

                                self.yang_name = "scan-lc-rp"
                                self.yang_parent_name = "type"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("scan-opt", ("scan_opt", Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanLcRp.ScanOpt))])
                                self._leafs = OrderedDict()

                                self.scan_opt = Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanLcRp.ScanOpt()
                                self.scan_opt.parent = self
                                self._children_name_map["scan_opt"] = "scan-opt"
                                self._segment_path = lambda: "scan-lc-rp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv4/type/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanLcRp, [], name, value)


                            class ScanOpt(Entity):
                                """
                                
                                
                                .. attribute:: count
                                
                                	Maximum number of prefixes to check per scan
                                	**type**\: int
                                
                                	**range:** 2..10000
                                
                                .. attribute:: period
                                
                                	Period between scans
                                	**type**\: int
                                
                                	**range:** 30..3600
                                
                                

                                """

                                _prefix = 'ios-cef'
                                _revision = '2017-05-19'

                                def __init__(self):
                                    super(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanLcRp.ScanOpt, self).__init__()

                                    self.yang_name = "scan-opt"
                                    self.yang_parent_name = "scan-lc-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                        ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                    ])
                                    self.count = None
                                    self.period = None
                                    self._segment_path = lambda: "scan-opt"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv4/type/scan-lc-rp/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanLcRp.ScanOpt, ['count', 'period'], name, value)


                        class ScanRpLc(Entity):
                            """
                            Passive scan that checks RP tables against LC tables
                            
                            .. attribute:: scan_opt
                            
                            	
                            	**type**\:  :py:class:`ScanOpt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRpLc.ScanOpt>`
                            
                            

                            """

                            _prefix = 'ios-cef'
                            _revision = '2017-05-19'

                            def __init__(self):
                                super(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRpLc, self).__init__()

                                self.yang_name = "scan-rp-lc"
                                self.yang_parent_name = "type"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("scan-opt", ("scan_opt", Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRpLc.ScanOpt))])
                                self._leafs = OrderedDict()

                                self.scan_opt = Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRpLc.ScanOpt()
                                self.scan_opt.parent = self
                                self._children_name_map["scan_opt"] = "scan-opt"
                                self._segment_path = lambda: "scan-rp-lc"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv4/type/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRpLc, [], name, value)


                            class ScanOpt(Entity):
                                """
                                
                                
                                .. attribute:: count
                                
                                	Maximum number of prefixes to check per scan
                                	**type**\: int
                                
                                	**range:** 2..10000
                                
                                .. attribute:: period
                                
                                	Period between scans
                                	**type**\: int
                                
                                	**range:** 30..3600
                                
                                

                                """

                                _prefix = 'ios-cef'
                                _revision = '2017-05-19'

                                def __init__(self):
                                    super(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRpLc.ScanOpt, self).__init__()

                                    self.yang_name = "scan-opt"
                                    self.yang_parent_name = "scan-rp-lc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                        ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                    ])
                                    self.count = None
                                    self.period = None
                                    self._segment_path = lambda: "scan-opt"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv4/type/scan-rp-lc/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv4.Type.ScanRpLc.ScanOpt, ['count', 'period'], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 address family
                    
                    .. attribute:: auto_repair
                    
                    	Control auto\-repair function
                    	**type**\:  :py:class:`AutoRepair <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv6.AutoRepair>`
                    
                    .. attribute:: type
                    
                    	Type of consistency check to configure
                    	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv6.Type>`
                    
                    .. attribute:: data_checking
                    
                    	Perform data consistency check
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: error_message
                    
                    	Generate error message on inconsistency detection
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Cef.Table.ConsistencyCheck.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "consistency-check"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto-repair", ("auto_repair", Native.Cef.Table.ConsistencyCheck.Ipv6.AutoRepair)), ("type", ("type", Native.Cef.Table.ConsistencyCheck.Ipv6.Type))])
                        self._leafs = OrderedDict([
                            ('data_checking', (YLeaf(YType.empty, 'data-checking'), ['Empty'])),
                            ('error_message', (YLeaf(YType.empty, 'error-message'), ['Empty'])),
                        ])
                        self.data_checking = None
                        self.error_message = None

                        self.auto_repair = Native.Cef.Table.ConsistencyCheck.Ipv6.AutoRepair()
                        self.auto_repair.parent = self
                        self._children_name_map["auto_repair"] = "auto-repair"

                        self.type = Native.Cef.Table.ConsistencyCheck.Ipv6.Type()
                        self.type.parent = self
                        self._children_name_map["type"] = "type"
                        self._segment_path = lambda: "ipv6"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv6, ['data_checking', 'error_message'], name, value)


                    class AutoRepair(Entity):
                        """
                        Control auto\-repair function
                        
                        .. attribute:: delay
                        
                        	Delay in seconds
                        	**type**\: int
                        
                        	**range:** 10..300
                        
                        .. attribute:: holddown
                        
                        	Delay in seconds
                        	**type**\: int
                        
                        	**range:** 300..3000
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.ConsistencyCheck.Ipv6.AutoRepair, self).__init__()

                            self.yang_name = "auto-repair"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('delay', (YLeaf(YType.uint16, 'delay'), ['int'])),
                                ('holddown', (YLeaf(YType.uint16, 'holddown'), ['int'])),
                            ])
                            self.delay = None
                            self.holddown = None
                            self._segment_path = lambda: "auto-repair"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv6.AutoRepair, ['delay', 'holddown'], name, value)


                    class Type(Entity):
                        """
                        Type of consistency check to configure
                        
                        .. attribute:: scan_ios_rib
                        
                        	Passive scan that checks RP tables against RIB
                        	**type**\:  :py:class:`ScanIosRib <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanIosRib>`
                        
                        .. attribute:: scan_lc_rp
                        
                        	Passive scan that checks LC tables against RP tables
                        	**type**\:  :py:class:`ScanLcRp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanLcRp>`
                        
                        .. attribute:: scan_rp_lc
                        
                        	Passive scan that checks RP tables against LC tables
                        	**type**\:  :py:class:`ScanRpLc <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanRpLc>`
                        
                        .. attribute:: lc_detect
                        
                        	Linecard detects missing prefix. Confirmed by RP
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.ConsistencyCheck.Ipv6.Type, self).__init__()

                            self.yang_name = "type"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("scan-ios-rib", ("scan_ios_rib", Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanIosRib)), ("scan-lc-rp", ("scan_lc_rp", Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanLcRp)), ("scan-rp-lc", ("scan_rp_lc", Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanRpLc))])
                            self._leafs = OrderedDict([
                                ('lc_detect', (YLeaf(YType.empty, 'lc-detect'), ['Empty'])),
                            ])
                            self.lc_detect = None

                            self.scan_ios_rib = Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanIosRib()
                            self.scan_ios_rib.parent = self
                            self._children_name_map["scan_ios_rib"] = "scan-ios-rib"

                            self.scan_lc_rp = Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanLcRp()
                            self.scan_lc_rp.parent = self
                            self._children_name_map["scan_lc_rp"] = "scan-lc-rp"

                            self.scan_rp_lc = Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanRpLc()
                            self.scan_rp_lc.parent = self
                            self._children_name_map["scan_rp_lc"] = "scan-rp-lc"
                            self._segment_path = lambda: "type"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv6.Type, ['lc_detect'], name, value)


                        class ScanIosRib(Entity):
                            """
                            Passive scan that checks RP tables against RIB
                            
                            .. attribute:: scan_opt
                            
                            	
                            	**type**\:  :py:class:`ScanOpt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanIosRib.ScanOpt>`
                            
                            

                            """

                            _prefix = 'ios-cef'
                            _revision = '2017-05-19'

                            def __init__(self):
                                super(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanIosRib, self).__init__()

                                self.yang_name = "scan-ios-rib"
                                self.yang_parent_name = "type"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("scan-opt", ("scan_opt", Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanIosRib.ScanOpt))])
                                self._leafs = OrderedDict()

                                self.scan_opt = Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanIosRib.ScanOpt()
                                self.scan_opt.parent = self
                                self._children_name_map["scan_opt"] = "scan-opt"
                                self._segment_path = lambda: "scan-ios-rib"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv6/type/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanIosRib, [], name, value)


                            class ScanOpt(Entity):
                                """
                                
                                
                                .. attribute:: count
                                
                                	Maximum number of prefixes to check per scan
                                	**type**\: int
                                
                                	**range:** 2..10000
                                
                                .. attribute:: period
                                
                                	Period between scans
                                	**type**\: int
                                
                                	**range:** 30..3600
                                
                                

                                """

                                _prefix = 'ios-cef'
                                _revision = '2017-05-19'

                                def __init__(self):
                                    super(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanIosRib.ScanOpt, self).__init__()

                                    self.yang_name = "scan-opt"
                                    self.yang_parent_name = "scan-ios-rib"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                        ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                    ])
                                    self.count = None
                                    self.period = None
                                    self._segment_path = lambda: "scan-opt"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv6/type/scan-ios-rib/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanIosRib.ScanOpt, ['count', 'period'], name, value)


                        class ScanLcRp(Entity):
                            """
                            Passive scan that checks LC tables against RP tables
                            
                            .. attribute:: scan_opt
                            
                            	
                            	**type**\:  :py:class:`ScanOpt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanLcRp.ScanOpt>`
                            
                            

                            """

                            _prefix = 'ios-cef'
                            _revision = '2017-05-19'

                            def __init__(self):
                                super(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanLcRp, self).__init__()

                                self.yang_name = "scan-lc-rp"
                                self.yang_parent_name = "type"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("scan-opt", ("scan_opt", Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanLcRp.ScanOpt))])
                                self._leafs = OrderedDict()

                                self.scan_opt = Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanLcRp.ScanOpt()
                                self.scan_opt.parent = self
                                self._children_name_map["scan_opt"] = "scan-opt"
                                self._segment_path = lambda: "scan-lc-rp"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv6/type/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanLcRp, [], name, value)


                            class ScanOpt(Entity):
                                """
                                
                                
                                .. attribute:: count
                                
                                	Maximum number of prefixes to check per scan
                                	**type**\: int
                                
                                	**range:** 2..10000
                                
                                .. attribute:: period
                                
                                	Period between scans
                                	**type**\: int
                                
                                	**range:** 30..3600
                                
                                

                                """

                                _prefix = 'ios-cef'
                                _revision = '2017-05-19'

                                def __init__(self):
                                    super(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanLcRp.ScanOpt, self).__init__()

                                    self.yang_name = "scan-opt"
                                    self.yang_parent_name = "scan-lc-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                        ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                    ])
                                    self.count = None
                                    self.period = None
                                    self._segment_path = lambda: "scan-opt"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv6/type/scan-lc-rp/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanLcRp.ScanOpt, ['count', 'period'], name, value)


                        class ScanRpLc(Entity):
                            """
                            Passive scan that checks RP tables against LC tables
                            
                            .. attribute:: scan_opt
                            
                            	
                            	**type**\:  :py:class:`ScanOpt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanRpLc.ScanOpt>`
                            
                            

                            """

                            _prefix = 'ios-cef'
                            _revision = '2017-05-19'

                            def __init__(self):
                                super(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanRpLc, self).__init__()

                                self.yang_name = "scan-rp-lc"
                                self.yang_parent_name = "type"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("scan-opt", ("scan_opt", Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanRpLc.ScanOpt))])
                                self._leafs = OrderedDict()

                                self.scan_opt = Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanRpLc.ScanOpt()
                                self.scan_opt.parent = self
                                self._children_name_map["scan_opt"] = "scan-opt"
                                self._segment_path = lambda: "scan-rp-lc"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv6/type/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanRpLc, [], name, value)


                            class ScanOpt(Entity):
                                """
                                
                                
                                .. attribute:: count
                                
                                	Maximum number of prefixes to check per scan
                                	**type**\: int
                                
                                	**range:** 2..10000
                                
                                .. attribute:: period
                                
                                	Period between scans
                                	**type**\: int
                                
                                	**range:** 30..3600
                                
                                

                                """

                                _prefix = 'ios-cef'
                                _revision = '2017-05-19'

                                def __init__(self):
                                    super(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanRpLc.ScanOpt, self).__init__()

                                    self.yang_name = "scan-opt"
                                    self.yang_parent_name = "scan-rp-lc"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                        ('period', (YLeaf(YType.uint16, 'period'), ['int'])),
                                    ])
                                    self.count = None
                                    self.period = None
                                    self._segment_path = lambda: "scan-opt"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/consistency-check/ipv6/type/scan-rp-lc/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Cef.Table.ConsistencyCheck.Ipv6.Type.ScanRpLc.ScanOpt, ['count', 'period'], name, value)


            class Download(Entity):
                """
                
                
                .. attribute:: catch_all
                
                	Any other route not matched (default P4)
                	**type**\:  :py:class:`CatchAll <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.CatchAll>`
                
                .. attribute:: connected_route
                
                	Directly connected route (default P2)
                	**type**\:  :py:class:`ConnectedRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.ConnectedRoute>`
                
                .. attribute:: default_route
                
                	Default route, 0.0.0.0/0 or \:\:/0 (default P1)
                	**type**\:  :py:class:`DefaultRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.DefaultRoute>`
                
                .. attribute:: receive_route
                
                	Receive route, local address on router (default P2)
                	**type**\:  :py:class:`ReceiveRoute <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.ReceiveRoute>`
                
                .. attribute:: recursive_dependents
                
                	Route with recursive dependents, matches next\-hop  of other recursive routes (default P1)
                	**type**\:  :py:class:`RecursiveDependents <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.RecursiveDependents>`
                
                .. attribute:: route_in_vrf
                
                	Route is in a VRF (default P3)
                	**type**\:  :py:class:`RouteInVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.RouteInVrf>`
                
                

                """

                _prefix = 'ios-cef'
                _revision = '2017-05-19'

                def __init__(self):
                    super(Native.Cef.Table.Download, self).__init__()

                    self.yang_name = "download"
                    self.yang_parent_name = "table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("catch-all", ("catch_all", Native.Cef.Table.Download.CatchAll)), ("connected-route", ("connected_route", Native.Cef.Table.Download.ConnectedRoute)), ("default-route", ("default_route", Native.Cef.Table.Download.DefaultRoute)), ("receive-route", ("receive_route", Native.Cef.Table.Download.ReceiveRoute)), ("recursive-dependents", ("recursive_dependents", Native.Cef.Table.Download.RecursiveDependents)), ("route-in-vrf", ("route_in_vrf", Native.Cef.Table.Download.RouteInVrf))])
                    self._leafs = OrderedDict()

                    self.catch_all = Native.Cef.Table.Download.CatchAll()
                    self.catch_all.parent = self
                    self._children_name_map["catch_all"] = "catch-all"

                    self.connected_route = Native.Cef.Table.Download.ConnectedRoute()
                    self.connected_route.parent = self
                    self._children_name_map["connected_route"] = "connected-route"

                    self.default_route = Native.Cef.Table.Download.DefaultRoute()
                    self.default_route.parent = self
                    self._children_name_map["default_route"] = "default-route"

                    self.receive_route = Native.Cef.Table.Download.ReceiveRoute()
                    self.receive_route.parent = self
                    self._children_name_map["receive_route"] = "receive-route"

                    self.recursive_dependents = Native.Cef.Table.Download.RecursiveDependents()
                    self.recursive_dependents.parent = self
                    self._children_name_map["recursive_dependents"] = "recursive-dependents"

                    self.route_in_vrf = Native.Cef.Table.Download.RouteInVrf()
                    self.route_in_vrf.parent = self
                    self._children_name_map["route_in_vrf"] = "route-in-vrf"
                    self._segment_path = lambda: "download"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Cef.Table.Download, [], name, value)


                class CatchAll(Entity):
                    """
                    Any other route not matched (default P4)
                    
                    .. attribute:: priority
                    
                    	
                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.CatchAll.Priority>`
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Cef.Table.Download.CatchAll, self).__init__()

                        self.yang_name = "catch-all"
                        self.yang_parent_name = "download"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority", ("priority", Native.Cef.Table.Download.CatchAll.Priority))])
                        self._leafs = OrderedDict()

                        self.priority = Native.Cef.Table.Download.CatchAll.Priority()
                        self.priority.parent = self
                        self._children_name_map["priority"] = "priority"
                        self._segment_path = lambda: "catch-all"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cef.Table.Download.CatchAll, [], name, value)


                    class Priority(Entity):
                        """
                        
                        
                        .. attribute:: priority1
                        
                        	1st priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority2
                        
                        	2nd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority3
                        
                        	3rd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority4
                        
                        	4th priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.Download.CatchAll.Priority, self).__init__()

                            self.yang_name = "priority"
                            self.yang_parent_name = "catch-all"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('priority1', (YLeaf(YType.empty, 'priority1'), ['Empty'])),
                                ('priority2', (YLeaf(YType.empty, 'priority2'), ['Empty'])),
                                ('priority3', (YLeaf(YType.empty, 'priority3'), ['Empty'])),
                                ('priority4', (YLeaf(YType.empty, 'priority4'), ['Empty'])),
                            ])
                            self.priority1 = None
                            self.priority2 = None
                            self.priority3 = None
                            self.priority4 = None
                            self._segment_path = lambda: "priority"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/catch-all/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.Download.CatchAll.Priority, ['priority1', 'priority2', 'priority3', 'priority4'], name, value)


                class ConnectedRoute(Entity):
                    """
                    Directly connected route (default P2)
                    
                    .. attribute:: priority
                    
                    	
                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.ConnectedRoute.Priority>`
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Cef.Table.Download.ConnectedRoute, self).__init__()

                        self.yang_name = "connected-route"
                        self.yang_parent_name = "download"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority", ("priority", Native.Cef.Table.Download.ConnectedRoute.Priority))])
                        self._leafs = OrderedDict()

                        self.priority = Native.Cef.Table.Download.ConnectedRoute.Priority()
                        self.priority.parent = self
                        self._children_name_map["priority"] = "priority"
                        self._segment_path = lambda: "connected-route"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cef.Table.Download.ConnectedRoute, [], name, value)


                    class Priority(Entity):
                        """
                        
                        
                        .. attribute:: priority1
                        
                        	1st priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority2
                        
                        	2nd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority3
                        
                        	3rd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority4
                        
                        	4th priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.Download.ConnectedRoute.Priority, self).__init__()

                            self.yang_name = "priority"
                            self.yang_parent_name = "connected-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('priority1', (YLeaf(YType.empty, 'priority1'), ['Empty'])),
                                ('priority2', (YLeaf(YType.empty, 'priority2'), ['Empty'])),
                                ('priority3', (YLeaf(YType.empty, 'priority3'), ['Empty'])),
                                ('priority4', (YLeaf(YType.empty, 'priority4'), ['Empty'])),
                            ])
                            self.priority1 = None
                            self.priority2 = None
                            self.priority3 = None
                            self.priority4 = None
                            self._segment_path = lambda: "priority"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/connected-route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.Download.ConnectedRoute.Priority, ['priority1', 'priority2', 'priority3', 'priority4'], name, value)


                class DefaultRoute(Entity):
                    """
                    Default route, 0.0.0.0/0 or \:\:/0 (default P1)
                    
                    .. attribute:: priority
                    
                    	
                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.DefaultRoute.Priority>`
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Cef.Table.Download.DefaultRoute, self).__init__()

                        self.yang_name = "default-route"
                        self.yang_parent_name = "download"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority", ("priority", Native.Cef.Table.Download.DefaultRoute.Priority))])
                        self._leafs = OrderedDict()

                        self.priority = Native.Cef.Table.Download.DefaultRoute.Priority()
                        self.priority.parent = self
                        self._children_name_map["priority"] = "priority"
                        self._segment_path = lambda: "default-route"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cef.Table.Download.DefaultRoute, [], name, value)


                    class Priority(Entity):
                        """
                        
                        
                        .. attribute:: priority1
                        
                        	1st priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority2
                        
                        	2nd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority3
                        
                        	3rd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority4
                        
                        	4th priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.Download.DefaultRoute.Priority, self).__init__()

                            self.yang_name = "priority"
                            self.yang_parent_name = "default-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('priority1', (YLeaf(YType.empty, 'priority1'), ['Empty'])),
                                ('priority2', (YLeaf(YType.empty, 'priority2'), ['Empty'])),
                                ('priority3', (YLeaf(YType.empty, 'priority3'), ['Empty'])),
                                ('priority4', (YLeaf(YType.empty, 'priority4'), ['Empty'])),
                            ])
                            self.priority1 = None
                            self.priority2 = None
                            self.priority3 = None
                            self.priority4 = None
                            self._segment_path = lambda: "priority"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/default-route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.Download.DefaultRoute.Priority, ['priority1', 'priority2', 'priority3', 'priority4'], name, value)


                class ReceiveRoute(Entity):
                    """
                    Receive route, local address on router (default P2)
                    
                    .. attribute:: priority
                    
                    	
                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.ReceiveRoute.Priority>`
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Cef.Table.Download.ReceiveRoute, self).__init__()

                        self.yang_name = "receive-route"
                        self.yang_parent_name = "download"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority", ("priority", Native.Cef.Table.Download.ReceiveRoute.Priority))])
                        self._leafs = OrderedDict()

                        self.priority = Native.Cef.Table.Download.ReceiveRoute.Priority()
                        self.priority.parent = self
                        self._children_name_map["priority"] = "priority"
                        self._segment_path = lambda: "receive-route"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cef.Table.Download.ReceiveRoute, [], name, value)


                    class Priority(Entity):
                        """
                        
                        
                        .. attribute:: priority1
                        
                        	1st priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority2
                        
                        	2nd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority3
                        
                        	3rd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority4
                        
                        	4th priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.Download.ReceiveRoute.Priority, self).__init__()

                            self.yang_name = "priority"
                            self.yang_parent_name = "receive-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('priority1', (YLeaf(YType.empty, 'priority1'), ['Empty'])),
                                ('priority2', (YLeaf(YType.empty, 'priority2'), ['Empty'])),
                                ('priority3', (YLeaf(YType.empty, 'priority3'), ['Empty'])),
                                ('priority4', (YLeaf(YType.empty, 'priority4'), ['Empty'])),
                            ])
                            self.priority1 = None
                            self.priority2 = None
                            self.priority3 = None
                            self.priority4 = None
                            self._segment_path = lambda: "priority"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/receive-route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.Download.ReceiveRoute.Priority, ['priority1', 'priority2', 'priority3', 'priority4'], name, value)


                class RecursiveDependents(Entity):
                    """
                    Route with recursive dependents, matches next\-hop 
                    of other recursive routes (default P1)
                    
                    .. attribute:: priority
                    
                    	
                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.RecursiveDependents.Priority>`
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Cef.Table.Download.RecursiveDependents, self).__init__()

                        self.yang_name = "recursive-dependents"
                        self.yang_parent_name = "download"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority", ("priority", Native.Cef.Table.Download.RecursiveDependents.Priority))])
                        self._leafs = OrderedDict()

                        self.priority = Native.Cef.Table.Download.RecursiveDependents.Priority()
                        self.priority.parent = self
                        self._children_name_map["priority"] = "priority"
                        self._segment_path = lambda: "recursive-dependents"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cef.Table.Download.RecursiveDependents, [], name, value)


                    class Priority(Entity):
                        """
                        
                        
                        .. attribute:: priority1
                        
                        	1st priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority2
                        
                        	2nd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority3
                        
                        	3rd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority4
                        
                        	4th priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.Download.RecursiveDependents.Priority, self).__init__()

                            self.yang_name = "priority"
                            self.yang_parent_name = "recursive-dependents"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('priority1', (YLeaf(YType.empty, 'priority1'), ['Empty'])),
                                ('priority2', (YLeaf(YType.empty, 'priority2'), ['Empty'])),
                                ('priority3', (YLeaf(YType.empty, 'priority3'), ['Empty'])),
                                ('priority4', (YLeaf(YType.empty, 'priority4'), ['Empty'])),
                            ])
                            self.priority1 = None
                            self.priority2 = None
                            self.priority3 = None
                            self.priority4 = None
                            self._segment_path = lambda: "priority"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/recursive-dependents/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.Download.RecursiveDependents.Priority, ['priority1', 'priority2', 'priority3', 'priority4'], name, value)


                class RouteInVrf(Entity):
                    """
                    Route is in a VRF (default P3)
                    
                    .. attribute:: priority
                    
                    	
                    	**type**\:  :py:class:`Priority <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Cef.Table.Download.RouteInVrf.Priority>`
                    
                    

                    """

                    _prefix = 'ios-cef'
                    _revision = '2017-05-19'

                    def __init__(self):
                        super(Native.Cef.Table.Download.RouteInVrf, self).__init__()

                        self.yang_name = "route-in-vrf"
                        self.yang_parent_name = "download"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("priority", ("priority", Native.Cef.Table.Download.RouteInVrf.Priority))])
                        self._leafs = OrderedDict()

                        self.priority = Native.Cef.Table.Download.RouteInVrf.Priority()
                        self.priority.parent = self
                        self._children_name_map["priority"] = "priority"
                        self._segment_path = lambda: "route-in-vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Cef.Table.Download.RouteInVrf, [], name, value)


                    class Priority(Entity):
                        """
                        
                        
                        .. attribute:: priority1
                        
                        	1st priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority2
                        
                        	2nd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority3
                        
                        	3rd priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority4
                        
                        	4th priority
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-cef'
                        _revision = '2017-05-19'

                        def __init__(self):
                            super(Native.Cef.Table.Download.RouteInVrf.Priority, self).__init__()

                            self.yang_name = "priority"
                            self.yang_parent_name = "route-in-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('priority1', (YLeaf(YType.empty, 'priority1'), ['Empty'])),
                                ('priority2', (YLeaf(YType.empty, 'priority2'), ['Empty'])),
                                ('priority3', (YLeaf(YType.empty, 'priority3'), ['Empty'])),
                                ('priority4', (YLeaf(YType.empty, 'priority4'), ['Empty'])),
                            ])
                            self.priority1 = None
                            self.priority2 = None
                            self.priority3 = None
                            self.priority4 = None
                            self._segment_path = lambda: "priority"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cef:cef/table/download/route-in-vrf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Cef.Table.Download.RouteInVrf.Priority, ['priority1', 'priority2', 'priority3', 'priority4'], name, value)


    class Arp(Entity):
        """
        Set a static ARP entry
        
        .. attribute:: arp_entry
        
        	Configure an arp entry
        	**type**\: list of  		 :py:class:`ArpEntry <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.ArpEntry>`
        
        .. attribute:: vrf
        
        	Configure static ARP for a VPN Routing/Forwarding instance
        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.Vrf>`
        
        .. attribute:: access_list
        
        	Named access\-list
        	**type**\: list of  		 :py:class:`AccessList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList>`
        
        

        """

        _prefix = 'ios-arp'
        _revision = '2018-06-28'

        def __init__(self):
            super(Native.Arp, self).__init__()

            self.yang_name = "arp"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("arp-entry", ("arp_entry", Native.Arp.ArpEntry)), ("vrf", ("vrf", Native.Arp.Vrf)), ("Cisco-IOS-XE-switch:access-list", ("access_list", Native.Arp.AccessList))])
            self._leafs = OrderedDict()

            self.arp_entry = YList(self)
            self.vrf = YList(self)
            self.access_list = YList(self)
            self._segment_path = lambda: "Cisco-IOS-XE-arp:arp"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Arp, [], name, value)


        class ArpEntry(Entity):
            """
            Configure an arp entry
            
            .. attribute:: ip  (key)
            
            	IP address of ARP entry
            	**type**\: union of the below types:
            
            		**type**\: str
            
            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            		**type**\: str
            
            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: hardware_address
            
            	48\-bit hardware address of ARP entry
            	**type**\: str
            
            .. attribute:: arp_type
            
            	
            	**type**\:  :py:class:`ArpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.ArpEntry.ArpType>`
            
            

            """

            _prefix = 'ios-arp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Arp.ArpEntry, self).__init__()

                self.yang_name = "arp-entry"
                self.yang_parent_name = "arp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['ip']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                    ('hardware_address', (YLeaf(YType.str, 'hardware-address'), ['str'])),
                    ('arp_type', (YLeaf(YType.enumeration, 'arp-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Arp.ArpEntry.ArpType')])),
                ])
                self.ip = None
                self.hardware_address = None
                self.arp_type = None
                self._segment_path = lambda: "arp-entry" + "[ip='" + str(self.ip) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-arp:arp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Arp.ArpEntry, [u'ip', u'hardware_address', u'arp_type'], name, value)

            class ArpType(Enum):
                """
                ArpType (Enum Class)

                .. data:: ARPA = 0

                .. data:: SAP = 1

                .. data:: SMDS = 2

                .. data:: SNAP = 3

                .. data:: SRP_A = 4

                .. data:: SRP_B = 5

                """

                ARPA = Enum.YLeaf(0, "ARPA")

                SAP = Enum.YLeaf(1, "SAP")

                SMDS = Enum.YLeaf(2, "SMDS")

                SNAP = Enum.YLeaf(3, "SNAP")

                SRP_A = Enum.YLeaf(4, "SRP-A")

                SRP_B = Enum.YLeaf(5, "SRP-B")



        class Vrf(Entity):
            """
            Configure static ARP for a VPN Routing/Forwarding instance
            
            .. attribute:: vrf_name  (key)
            
            	VPN Routing/Forwarding instance name
            	**type**\: str
            
            .. attribute:: arp_entry
            
            	Configure an arp entry
            	**type**\: list of  		 :py:class:`ArpEntry <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.Vrf.ArpEntry>`
            
            

            """

            _prefix = 'ios-arp'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Arp.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "arp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['vrf_name']
                self._child_classes = OrderedDict([("arp-entry", ("arp_entry", Native.Arp.Vrf.ArpEntry))])
                self._leafs = OrderedDict([
                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                ])
                self.vrf_name = None

                self.arp_entry = YList(self)
                self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-arp:arp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Arp.Vrf, [u'vrf_name'], name, value)


            class ArpEntry(Entity):
                """
                Configure an arp entry
                
                .. attribute:: ip  (key)
                
                	IP address of ARP entry
                	**type**\: union of the below types:
                
                		**type**\: str
                
                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                		**type**\: str
                
                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: hardware_address
                
                	48\-bit hardware address of ARP entry
                	**type**\: str
                
                .. attribute:: arp_type
                
                	
                	**type**\:  :py:class:`ArpType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.Vrf.ArpEntry.ArpType>`
                
                

                """

                _prefix = 'ios-arp'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Arp.Vrf.ArpEntry, self).__init__()

                    self.yang_name = "arp-entry"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['ip']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ip', (YLeaf(YType.str, 'ip'), ['str','str'])),
                        ('hardware_address', (YLeaf(YType.str, 'hardware-address'), ['str'])),
                        ('arp_type', (YLeaf(YType.enumeration, 'arp-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Arp.Vrf.ArpEntry.ArpType')])),
                    ])
                    self.ip = None
                    self.hardware_address = None
                    self.arp_type = None
                    self._segment_path = lambda: "arp-entry" + "[ip='" + str(self.ip) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Arp.Vrf.ArpEntry, [u'ip', u'hardware_address', u'arp_type'], name, value)

                class ArpType(Enum):
                    """
                    ArpType (Enum Class)

                    .. data:: ARPA = 0

                    .. data:: SAP = 1

                    .. data:: SMDS = 2

                    .. data:: SNAP = 3

                    .. data:: SRP_A = 4

                    .. data:: SRP_B = 5

                    """

                    ARPA = Enum.YLeaf(0, "ARPA")

                    SAP = Enum.YLeaf(1, "SAP")

                    SMDS = Enum.YLeaf(2, "SMDS")

                    SNAP = Enum.YLeaf(3, "SNAP")

                    SRP_A = Enum.YLeaf(4, "SRP-A")

                    SRP_B = Enum.YLeaf(5, "SRP-B")



        class AccessList(Entity):
            """
            Named access\-list
            
            .. attribute:: name  (key)
            
            	
            	**type**\: str
            
            .. attribute:: permit
            
            	Specify packets to forward
            	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit>`
            
            .. attribute:: deny
            
            	Specify packets to reject
            	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny>`
            
            .. attribute:: default
            
            	Set a command to its defaults
            	**type**\:  :py:class:`Default <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default>`
            
            .. attribute:: no
            
            	Negate a command or set its defaults
            	**type**\:  :py:class:`No <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.Arp.AccessList, self).__init__()

                self.yang_name = "access-list"
                self.yang_parent_name = "arp"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("permit", ("permit", Native.Arp.AccessList.Permit)), ("deny", ("deny", Native.Arp.AccessList.Deny)), ("default", ("default", Native.Arp.AccessList.Default)), ("no", ("no", Native.Arp.AccessList.No))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.permit = Native.Arp.AccessList.Permit()
                self.permit.parent = self
                self._children_name_map["permit"] = "permit"

                self.deny = Native.Arp.AccessList.Deny()
                self.deny.parent = self
                self._children_name_map["deny"] = "deny"

                self.default = Native.Arp.AccessList.Default()
                self.default.parent = self
                self._children_name_map["default"] = "default"

                self.no = Native.Arp.AccessList.No()
                self.no.parent = self
                self._children_name_map["no"] = "no"
                self._segment_path = lambda: "Cisco-IOS-XE-switch:access-list" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-arp:arp/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Arp.AccessList, [u'name'], name, value)


            class Permit(Entity):
                """
                Specify packets to forward
                
                .. attribute:: ip
                
                	Sender IP address
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip>`
                
                .. attribute:: request
                
                	ARP Request
                	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request>`
                
                .. attribute:: response
                
                	ARP Response
                	**type**\:  :py:class:`Response <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Arp.AccessList.Permit, self).__init__()

                    self.yang_name = "permit"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Permit.Ip)), ("request", ("request", Native.Arp.AccessList.Permit.Request)), ("response", ("response", Native.Arp.AccessList.Permit.Response))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Arp.AccessList.Permit.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.request = Native.Arp.AccessList.Permit.Request()
                    self.request.parent = self
                    self._children_name_map["request"] = "request"

                    self.response = Native.Arp.AccessList.Permit.Response()
                    self.response.parent = self
                    self._children_name_map["response"] = "response"
                    self._segment_path = lambda: "permit"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Arp.AccessList.Permit, [], name, value)


                class Ip(Entity):
                    """
                    Sender IP address
                    
                    .. attribute:: sender_ip_address
                    
                    	Sender IP address
                    	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.SenderIpAddress>`
                    
                    .. attribute:: any
                    
                    	Any Sender IP address
                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Any>`
                    
                    .. attribute:: host
                    
                    	Single Sender host
                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Host>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Arp.AccessList.Permit.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "permit"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Permit.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Permit.Ip.Host))])
                        self._leafs = OrderedDict()

                        self.any = Native.Arp.AccessList.Permit.Ip.Any()
                        self.any.parent = self
                        self._children_name_map["any"] = "any"

                        self.host = Native.Arp.AccessList.Permit.Ip.Host()
                        self.host.parent = self
                        self._children_name_map["host"] = "host"

                        self.sender_ip_address = YList(self)
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Arp.AccessList.Permit.Ip, [], name, value)


                    class SenderIpAddress(Entity):
                        """
                        Sender IP address
                        
                        .. attribute:: ip_address  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip_address_mask
                        
                        	Sender IP wildcard mask
                        	**type**\: str
                        
                        .. attribute:: mac
                        
                        	Sender MAC address
                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Permit.Ip.SenderIpAddress, self).__init__()

                            self.yang_name = "sender-ip-address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_address']
                            self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac))])
                            self._leafs = OrderedDict([
                                ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                            ])
                            self.ip_address = None
                            self.ip_address_mask = None

                            self.mac = Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac()
                            self.mac.parent = self
                            self._children_name_map["mac"] = "mac"
                            self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Permit.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                        class Mac(Entity):
                            """
                            Sender MAC address
                            
                            .. attribute:: sender_mac_address
                            
                            	Sender MAC address
                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                            
                            .. attribute:: any
                            
                            	Any MAC address
                            	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Any>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac, self).__init__()

                                self.yang_name = "mac"
                                self.yang_parent_name = "sender-ip-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Host))])
                                self._leafs = OrderedDict()

                                self.any = None
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_mac_address = YList(self)
                                self._segment_path = lambda: "mac"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac, [], name, value)


                            class SenderMacAddress(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: mac_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac_address_mask
                                
                                	Sender MAC address mask
                                	**type**\: str
                                
                                .. attribute:: log
                                
                                	Log on match
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                    self.yang_name = "sender-mac-address"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['mac_address']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                        ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ])
                                    self.mac_address = None
                                    self.mac_address_mask = None
                                    self.log = None
                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                            class Any(Entity):
                                """
                                Any MAC address
                                
                                .. attribute:: log
                                
                                	Log on match
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ])
                                    self.log = None
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                    self._leafs = OrderedDict()

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Any(Entity):
                        """
                        Any Sender IP address
                        
                        .. attribute:: mac
                        
                        	Sender MAC address
                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Any.Mac>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Permit.Ip.Any, self).__init__()

                            self.yang_name = "any"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Permit.Ip.Any.Mac))])
                            self._leafs = OrderedDict()

                            self.mac = Native.Arp.AccessList.Permit.Ip.Any.Mac()
                            self.mac.parent = self
                            self._children_name_map["mac"] = "mac"
                            self._segment_path = lambda: "any"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Any, [], name, value)


                        class Mac(Entity):
                            """
                            Sender MAC address
                            
                            .. attribute:: sender_mac_address
                            
                            	Sender MAC address
                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Any.Mac.SenderMacAddress>`
                            
                            .. attribute:: any
                            
                            	Any MAC address
                            	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Any.Mac.Any_>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Any.Mac.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Permit.Ip.Any.Mac, self).__init__()

                                self.yang_name = "mac"
                                self.yang_parent_name = "any"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Permit.Ip.Any.Mac.Host))])
                                self._leafs = OrderedDict()

                                self.any = None
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.Permit.Ip.Any.Mac.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_mac_address = YList(self)
                                self._segment_path = lambda: "mac"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Any.Mac, [], name, value)


                            class SenderMacAddress(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: mac_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac_address_mask
                                
                                	Sender MAC address mask
                                	**type**\: str
                                
                                .. attribute:: log
                                
                                	Log on match
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                    self.yang_name = "sender-mac-address"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['mac_address']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                        ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ])
                                    self.mac_address = None
                                    self.mac_address_mask = None
                                    self.log = None
                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                            class Any_(Entity):
                                """
                                Any MAC address
                                
                                .. attribute:: log
                                
                                	Log on match
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Ip.Any.Mac.Any_, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ])
                                    self.log = None
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Any.Mac.Any_, [u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Any.Mac.Host.SenderMacAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Ip.Any.Mac.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Ip.Any.Mac.Host.SenderMacAddress))])
                                    self._leafs = OrderedDict()

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Any.Mac.Host, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Host(Entity):
                        """
                        Single Sender host
                        
                        .. attribute:: ip_address
                        
                        	Sender IP address
                        	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Host.IpAddress>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Permit.Ip.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Permit.Ip.Host.IpAddress))])
                            self._leafs = OrderedDict()

                            self.ip_address = YList(self)
                            self._segment_path = lambda: "host"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Host, [], name, value)


                        class IpAddress(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: ip_address  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Permit.Ip.Host.IpAddress, self).__init__()

                                self.yang_name = "ip-address"
                                self.yang_parent_name = "host"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_address']
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac))])
                                self._leafs = OrderedDict([
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                ])
                                self.ip_address = None

                                self.mac = Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Host.IpAddress, [u'ip_address'], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Any>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Host_>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "ip-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Host_))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Host_()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                class Host_(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                class Request(Entity):
                    """
                    ARP Request
                    
                    .. attribute:: ip
                    
                    	Sender IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Arp.AccessList.Permit.Request, self).__init__()

                        self.yang_name = "request"
                        self.yang_parent_name = "permit"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Permit.Request.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Arp.AccessList.Permit.Request.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "request"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Arp.AccessList.Permit.Request, [], name, value)


                    class Ip(Entity):
                        """
                        Sender IP address
                        
                        .. attribute:: sender_ip_address
                        
                        	Sender IP address
                        	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress>`
                        
                        .. attribute:: any
                        
                        	Any Sender IP address
                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Any>`
                        
                        .. attribute:: host
                        
                        	Single Sender host
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Host>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Permit.Request.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "request"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Request.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Permit.Request.Ip.Host))])
                            self._leafs = OrderedDict()

                            self.any = Native.Arp.AccessList.Permit.Request.Ip.Any()
                            self.any.parent = self
                            self._children_name_map["any"] = "any"

                            self.host = Native.Arp.AccessList.Permit.Request.Ip.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.sender_ip_address = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip, [], name, value)


                        class SenderIpAddress(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: ip_address  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip_address_mask
                            
                            	Sender IP wildcard mask
                            	**type**\: str
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress, self).__init__()

                                self.yang_name = "sender-ip-address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_address']
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac))])
                                self._leafs = OrderedDict([
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                ])
                                self.ip_address = None
                                self.ip_address_mask = None

                                self.mac = Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Any>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "sender-ip-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Any(Entity):
                            """
                            Any Sender IP address
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Any.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Permit.Request.Ip.Any, self).__init__()

                                self.yang_name = "any"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Permit.Request.Ip.Any.Mac))])
                                self._leafs = OrderedDict()

                                self.mac = Native.Arp.AccessList.Permit.Request.Ip.Any.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "any"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Any, [], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Any_>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Request.Ip.Any.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "any"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Any.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any_(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Any_, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Any_, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Host(Entity):
                            """
                            Single Sender host
                            
                            .. attribute:: ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Permit.Request.Ip.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress))])
                                self._leafs = OrderedDict()

                                self.ip_address = YList(self)
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Host, [], name, value)


                            class IpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress, self).__init__()

                                    self.yang_name = "ip-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ])
                                    self.ip_address = None

                                    self.mac = Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Host_>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Host_))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Host_()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                    class Host_(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                class Response(Entity):
                    """
                    ARP Response
                    
                    .. attribute:: ip
                    
                    	Sender IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Arp.AccessList.Permit.Response, self).__init__()

                        self.yang_name = "response"
                        self.yang_parent_name = "permit"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Permit.Response.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Arp.AccessList.Permit.Response.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "response"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Arp.AccessList.Permit.Response, [], name, value)


                    class Ip(Entity):
                        """
                        Sender IP address
                        
                        .. attribute:: sender_ip_address
                        
                        	Sender IP address
                        	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress>`
                        
                        .. attribute:: any
                        
                        	Any Sender IP address
                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Any>`
                        
                        .. attribute:: host
                        
                        	Single Sender host
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Host>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Permit.Response.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "response"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Response.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Permit.Response.Ip.Host))])
                            self._leafs = OrderedDict()

                            self.any = Native.Arp.AccessList.Permit.Response.Ip.Any()
                            self.any.parent = self
                            self._children_name_map["any"] = "any"

                            self.host = Native.Arp.AccessList.Permit.Response.Ip.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.sender_ip_address = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip, [], name, value)


                        class SenderIpAddress(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: ip_address  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip_address_mask
                            
                            	Sender IP wildcard mask
                            	**type**\: str
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress, self).__init__()

                                self.yang_name = "sender-ip-address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_address']
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac))])
                                self._leafs = OrderedDict([
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                ])
                                self.ip_address = None
                                self.ip_address_mask = None

                                self.mac = Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Any>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "sender-ip-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Any(Entity):
                            """
                            Any Sender IP address
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Any.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Permit.Response.Ip.Any, self).__init__()

                                self.yang_name = "any"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Permit.Response.Ip.Any.Mac))])
                                self._leafs = OrderedDict()

                                self.mac = Native.Arp.AccessList.Permit.Response.Ip.Any.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "any"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Any, [], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Any_>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Response.Ip.Any.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "any"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Any.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any_(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Any_, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Any_, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Host(Entity):
                            """
                            Single Sender host
                            
                            .. attribute:: ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Permit.Response.Ip.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress))])
                                self._leafs = OrderedDict()

                                self.ip_address = YList(self)
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Host, [], name, value)


                            class IpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress, self).__init__()

                                    self.yang_name = "ip-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ])
                                    self.ip_address = None

                                    self.mac = Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Host_>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Host_))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Host_()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                    class Host_(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


            class Deny(Entity):
                """
                Specify packets to reject
                
                .. attribute:: ip
                
                	Sender IP address
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip>`
                
                .. attribute:: request
                
                	ARP Request
                	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request>`
                
                .. attribute:: response
                
                	ARP Response
                	**type**\:  :py:class:`Response <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Arp.AccessList.Deny, self).__init__()

                    self.yang_name = "deny"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Deny.Ip)), ("request", ("request", Native.Arp.AccessList.Deny.Request)), ("response", ("response", Native.Arp.AccessList.Deny.Response))])
                    self._leafs = OrderedDict()

                    self.ip = Native.Arp.AccessList.Deny.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"

                    self.request = Native.Arp.AccessList.Deny.Request()
                    self.request.parent = self
                    self._children_name_map["request"] = "request"

                    self.response = Native.Arp.AccessList.Deny.Response()
                    self.response.parent = self
                    self._children_name_map["response"] = "response"
                    self._segment_path = lambda: "deny"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Arp.AccessList.Deny, [], name, value)


                class Ip(Entity):
                    """
                    Sender IP address
                    
                    .. attribute:: sender_ip_address
                    
                    	Sender IP address
                    	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.SenderIpAddress>`
                    
                    .. attribute:: any
                    
                    	Any Sender IP address
                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Any>`
                    
                    .. attribute:: host
                    
                    	Single Sender host
                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Host>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Arp.AccessList.Deny.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "deny"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Deny.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Deny.Ip.Host))])
                        self._leafs = OrderedDict()

                        self.any = Native.Arp.AccessList.Deny.Ip.Any()
                        self.any.parent = self
                        self._children_name_map["any"] = "any"

                        self.host = Native.Arp.AccessList.Deny.Ip.Host()
                        self.host.parent = self
                        self._children_name_map["host"] = "host"

                        self.sender_ip_address = YList(self)
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Arp.AccessList.Deny.Ip, [], name, value)


                    class SenderIpAddress(Entity):
                        """
                        Sender IP address
                        
                        .. attribute:: ip_address  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: ip_address_mask
                        
                        	Sender IP wildcard mask
                        	**type**\: str
                        
                        .. attribute:: mac
                        
                        	Sender MAC address
                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Deny.Ip.SenderIpAddress, self).__init__()

                            self.yang_name = "sender-ip-address"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ip_address']
                            self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac))])
                            self._leafs = OrderedDict([
                                ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                            ])
                            self.ip_address = None
                            self.ip_address_mask = None

                            self.mac = Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac()
                            self.mac.parent = self
                            self._children_name_map["mac"] = "mac"
                            self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Deny.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                        class Mac(Entity):
                            """
                            Sender MAC address
                            
                            .. attribute:: sender_mac_address
                            
                            	Sender MAC address
                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                            
                            .. attribute:: any
                            
                            	Any MAC address
                            	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Any>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac, self).__init__()

                                self.yang_name = "mac"
                                self.yang_parent_name = "sender-ip-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Host))])
                                self._leafs = OrderedDict()

                                self.any = None
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_mac_address = YList(self)
                                self._segment_path = lambda: "mac"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac, [], name, value)


                            class SenderMacAddress(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: mac_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac_address_mask
                                
                                	Sender MAC address mask
                                	**type**\: str
                                
                                .. attribute:: log
                                
                                	Log on match
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                    self.yang_name = "sender-mac-address"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['mac_address']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                        ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ])
                                    self.mac_address = None
                                    self.mac_address_mask = None
                                    self.log = None
                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                            class Any(Entity):
                                """
                                Any MAC address
                                
                                .. attribute:: log
                                
                                	Log on match
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ])
                                    self.log = None
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                    self._leafs = OrderedDict()

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Any(Entity):
                        """
                        Any Sender IP address
                        
                        .. attribute:: mac
                        
                        	Sender MAC address
                        	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Any.Mac>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Deny.Ip.Any, self).__init__()

                            self.yang_name = "any"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Deny.Ip.Any.Mac))])
                            self._leafs = OrderedDict()

                            self.mac = Native.Arp.AccessList.Deny.Ip.Any.Mac()
                            self.mac.parent = self
                            self._children_name_map["mac"] = "mac"
                            self._segment_path = lambda: "any"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Any, [], name, value)


                        class Mac(Entity):
                            """
                            Sender MAC address
                            
                            .. attribute:: sender_mac_address
                            
                            	Sender MAC address
                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Any.Mac.SenderMacAddress>`
                            
                            .. attribute:: any
                            
                            	Any MAC address
                            	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Any.Mac.Any_>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Any.Mac.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Deny.Ip.Any.Mac, self).__init__()

                                self.yang_name = "mac"
                                self.yang_parent_name = "any"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Deny.Ip.Any.Mac.Host))])
                                self._leafs = OrderedDict()

                                self.any = None
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.Deny.Ip.Any.Mac.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_mac_address = YList(self)
                                self._segment_path = lambda: "mac"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Any.Mac, [], name, value)


                            class SenderMacAddress(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: mac_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac_address_mask
                                
                                	Sender MAC address mask
                                	**type**\: str
                                
                                .. attribute:: log
                                
                                	Log on match
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                    self.yang_name = "sender-mac-address"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['mac_address']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                        ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ])
                                    self.mac_address = None
                                    self.mac_address_mask = None
                                    self.log = None
                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                            class Any_(Entity):
                                """
                                Any MAC address
                                
                                .. attribute:: log
                                
                                	Log on match
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Ip.Any.Mac.Any_, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict([
                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                    ])
                                    self.log = None
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Any.Mac.Any_, [u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Any.Mac.Host.SenderMacAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Ip.Any.Mac.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "mac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Ip.Any.Mac.Host.SenderMacAddress))])
                                    self._leafs = OrderedDict()

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Any.Mac.Host, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Host(Entity):
                        """
                        Single Sender host
                        
                        .. attribute:: ip_address
                        
                        	Sender IP address
                        	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Host.IpAddress>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Deny.Ip.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "ip"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Deny.Ip.Host.IpAddress))])
                            self._leafs = OrderedDict()

                            self.ip_address = YList(self)
                            self._segment_path = lambda: "host"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Host, [], name, value)


                        class IpAddress(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: ip_address  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Deny.Ip.Host.IpAddress, self).__init__()

                                self.yang_name = "ip-address"
                                self.yang_parent_name = "host"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_address']
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac))])
                                self._leafs = OrderedDict([
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                ])
                                self.ip_address = None

                                self.mac = Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Host.IpAddress, [u'ip_address'], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Any>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Host_>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "ip-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Host_))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Host_()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                class Host_(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                class Request(Entity):
                    """
                    ARP Request
                    
                    .. attribute:: ip
                    
                    	Sender IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Arp.AccessList.Deny.Request, self).__init__()

                        self.yang_name = "request"
                        self.yang_parent_name = "deny"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Deny.Request.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Arp.AccessList.Deny.Request.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "request"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Arp.AccessList.Deny.Request, [], name, value)


                    class Ip(Entity):
                        """
                        Sender IP address
                        
                        .. attribute:: sender_ip_address
                        
                        	Sender IP address
                        	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress>`
                        
                        .. attribute:: any
                        
                        	Any Sender IP address
                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Any>`
                        
                        .. attribute:: host
                        
                        	Single Sender host
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Host>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Deny.Request.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "request"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Request.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Deny.Request.Ip.Host))])
                            self._leafs = OrderedDict()

                            self.any = Native.Arp.AccessList.Deny.Request.Ip.Any()
                            self.any.parent = self
                            self._children_name_map["any"] = "any"

                            self.host = Native.Arp.AccessList.Deny.Request.Ip.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.sender_ip_address = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip, [], name, value)


                        class SenderIpAddress(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: ip_address  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip_address_mask
                            
                            	Sender IP wildcard mask
                            	**type**\: str
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress, self).__init__()

                                self.yang_name = "sender-ip-address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_address']
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac))])
                                self._leafs = OrderedDict([
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                ])
                                self.ip_address = None
                                self.ip_address_mask = None

                                self.mac = Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Any>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "sender-ip-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Any(Entity):
                            """
                            Any Sender IP address
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Any.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Deny.Request.Ip.Any, self).__init__()

                                self.yang_name = "any"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Deny.Request.Ip.Any.Mac))])
                                self._leafs = OrderedDict()

                                self.mac = Native.Arp.AccessList.Deny.Request.Ip.Any.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "any"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Any, [], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Any_>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Request.Ip.Any.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "any"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Any.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any_(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Any_, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Any_, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Host(Entity):
                            """
                            Single Sender host
                            
                            .. attribute:: ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Deny.Request.Ip.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress))])
                                self._leafs = OrderedDict()

                                self.ip_address = YList(self)
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Host, [], name, value)


                            class IpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress, self).__init__()

                                    self.yang_name = "ip-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ])
                                    self.ip_address = None

                                    self.mac = Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Host_>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Host_))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Host_()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                    class Host_(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                class Response(Entity):
                    """
                    ARP Response
                    
                    .. attribute:: ip
                    
                    	Sender IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Arp.AccessList.Deny.Response, self).__init__()

                        self.yang_name = "response"
                        self.yang_parent_name = "deny"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Deny.Response.Ip))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Arp.AccessList.Deny.Response.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"
                        self._segment_path = lambda: "response"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Arp.AccessList.Deny.Response, [], name, value)


                    class Ip(Entity):
                        """
                        Sender IP address
                        
                        .. attribute:: sender_ip_address
                        
                        	Sender IP address
                        	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress>`
                        
                        .. attribute:: any
                        
                        	Any Sender IP address
                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Any>`
                        
                        .. attribute:: host
                        
                        	Single Sender host
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Host>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Deny.Response.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "response"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Response.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Deny.Response.Ip.Host))])
                            self._leafs = OrderedDict()

                            self.any = Native.Arp.AccessList.Deny.Response.Ip.Any()
                            self.any.parent = self
                            self._children_name_map["any"] = "any"

                            self.host = Native.Arp.AccessList.Deny.Response.Ip.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.sender_ip_address = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip, [], name, value)


                        class SenderIpAddress(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: ip_address  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip_address_mask
                            
                            	Sender IP wildcard mask
                            	**type**\: str
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress, self).__init__()

                                self.yang_name = "sender-ip-address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_address']
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac))])
                                self._leafs = OrderedDict([
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                ])
                                self.ip_address = None
                                self.ip_address_mask = None

                                self.mac = Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Any>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "sender-ip-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Any(Entity):
                            """
                            Any Sender IP address
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Any.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Deny.Response.Ip.Any, self).__init__()

                                self.yang_name = "any"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Deny.Response.Ip.Any.Mac))])
                                self._leafs = OrderedDict()

                                self.mac = Native.Arp.AccessList.Deny.Response.Ip.Any.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "any"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Any, [], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Any_>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Response.Ip.Any.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "any"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Any.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any_(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Any_, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Any_, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Host(Entity):
                            """
                            Single Sender host
                            
                            .. attribute:: ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Deny.Response.Ip.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress))])
                                self._leafs = OrderedDict()

                                self.ip_address = YList(self)
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Host, [], name, value)


                            class IpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress, self).__init__()

                                    self.yang_name = "ip-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ])
                                    self.ip_address = None

                                    self.mac = Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Host_>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Host_))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Host_()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                    class Host_(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


            class Default(Entity):
                """
                Set a command to its defaults
                
                .. attribute:: permit
                
                	Specify packets to forward
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit>`
                
                .. attribute:: deny
                
                	Specify packets to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Arp.AccessList.Default, self).__init__()

                    self.yang_name = "default"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("permit", ("permit", Native.Arp.AccessList.Default.Permit)), ("deny", ("deny", Native.Arp.AccessList.Default.Deny))])
                    self._leafs = OrderedDict()

                    self.permit = Native.Arp.AccessList.Default.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"

                    self.deny = Native.Arp.AccessList.Default.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"
                    self._segment_path = lambda: "default"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Arp.AccessList.Default, [], name, value)


                class Permit(Entity):
                    """
                    Specify packets to forward
                    
                    .. attribute:: ip
                    
                    	Sender IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip>`
                    
                    .. attribute:: request
                    
                    	ARP Request
                    	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request>`
                    
                    .. attribute:: response
                    
                    	ARP Response
                    	**type**\:  :py:class:`Response <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Arp.AccessList.Default.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Default.Permit.Ip)), ("request", ("request", Native.Arp.AccessList.Default.Permit.Request)), ("response", ("response", Native.Arp.AccessList.Default.Permit.Response))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Arp.AccessList.Default.Permit.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.request = Native.Arp.AccessList.Default.Permit.Request()
                        self.request.parent = self
                        self._children_name_map["request"] = "request"

                        self.response = Native.Arp.AccessList.Default.Permit.Response()
                        self.response.parent = self
                        self._children_name_map["response"] = "response"
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Arp.AccessList.Default.Permit, [], name, value)


                    class Ip(Entity):
                        """
                        Sender IP address
                        
                        .. attribute:: sender_ip_address
                        
                        	Sender IP address
                        	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress>`
                        
                        .. attribute:: any
                        
                        	Any Sender IP address
                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Any>`
                        
                        .. attribute:: host
                        
                        	Single Sender host
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Host>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Default.Permit.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Ip.Host))])
                            self._leafs = OrderedDict()

                            self.any = Native.Arp.AccessList.Default.Permit.Ip.Any()
                            self.any.parent = self
                            self._children_name_map["any"] = "any"

                            self.host = Native.Arp.AccessList.Default.Permit.Ip.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.sender_ip_address = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip, [], name, value)


                        class SenderIpAddress(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: ip_address  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip_address_mask
                            
                            	Sender IP wildcard mask
                            	**type**\: str
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress, self).__init__()

                                self.yang_name = "sender-ip-address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_address']
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac))])
                                self._leafs = OrderedDict([
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                ])
                                self.ip_address = None
                                self.ip_address_mask = None

                                self.mac = Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Any>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "sender-ip-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Any(Entity):
                            """
                            Any Sender IP address
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Any.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Default.Permit.Ip.Any, self).__init__()

                                self.yang_name = "any"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Permit.Ip.Any.Mac))])
                                self._leafs = OrderedDict()

                                self.mac = Native.Arp.AccessList.Default.Permit.Ip.Any.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "any"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Any, [], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Any_>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Permit.Ip.Any.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "any"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Any.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any_(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Any_, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Any_, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Host(Entity):
                            """
                            Single Sender host
                            
                            .. attribute:: ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Default.Permit.Ip.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress))])
                                self._leafs = OrderedDict()

                                self.ip_address = YList(self)
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Host, [], name, value)


                            class IpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress, self).__init__()

                                    self.yang_name = "ip-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ])
                                    self.ip_address = None

                                    self.mac = Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Host_>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Host_))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Host_()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                    class Host_(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Request(Entity):
                        """
                        ARP Request
                        
                        .. attribute:: ip
                        
                        	Sender IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Default.Permit.Request, self).__init__()

                            self.yang_name = "request"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Default.Permit.Request.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Arp.AccessList.Default.Permit.Request.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request, [], name, value)


                        class Ip(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: sender_ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress>`
                            
                            .. attribute:: any
                            
                            	Any Sender IP address
                            	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Any>`
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Default.Permit.Request.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "request"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Request.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Request.Ip.Host))])
                                self._leafs = OrderedDict()

                                self.any = Native.Arp.AccessList.Default.Permit.Request.Ip.Any()
                                self.any.parent = self
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.Default.Permit.Request.Ip.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_ip_address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip, [], name, value)


                            class SenderIpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: ip_address_mask
                                
                                	Sender IP wildcard mask
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress, self).__init__()

                                    self.yang_name = "sender-ip-address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                    ])
                                    self.ip_address = None
                                    self.ip_address_mask = None

                                    self.mac = Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "sender-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Any(Entity):
                                """
                                Any Sender IP address
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Permit.Request.Ip.Any, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac))])
                                    self._leafs = OrderedDict()

                                    self.mac = Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Any, [], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Any_>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "any"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any_(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Any_, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Any_, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: ip_address
                                
                                	Sender IP address
                                	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Permit.Request.Ip.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress))])
                                    self._leafs = OrderedDict()

                                    self.ip_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Host, [], name, value)


                                class IpAddress(Entity):
                                    """
                                    Sender IP address
                                    
                                    .. attribute:: ip_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac
                                    
                                    	Sender MAC address
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress, self).__init__()

                                        self.yang_name = "ip-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_address']
                                        self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac))])
                                        self._leafs = OrderedDict([
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ])
                                        self.ip_address = None

                                        self.mac = Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac()
                                        self.mac.parent = self
                                        self._children_name_map["mac"] = "mac"
                                        self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                    class Mac(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                        
                                        .. attribute:: any
                                        
                                        	Any MAC address
                                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Any>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: host
                                        
                                        	Single Sender host
                                        	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Host_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Host_))])
                                            self._leafs = OrderedDict()

                                            self.any = None
                                            self._children_name_map["any"] = "any"

                                            self.host = Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Host_()
                                            self.host.parent = self
                                            self._children_name_map["host"] = "host"

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: mac_address_mask
                                            
                                            	Sender MAC address mask
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.mac_address_mask = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                        class Any(Entity):
                                            """
                                            Any MAC address
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                                self.yang_name = "any"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.log = None
                                                self._segment_path = lambda: "any"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                        class Host_(Entity):
                                            """
                                            Single Sender host
                                            
                                            .. attribute:: sender_mac_address
                                            
                                            	Sender MAC address
                                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                                self.yang_name = "host"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                                self._leafs = OrderedDict()

                                                self.sender_mac_address = YList(self)
                                                self._segment_path = lambda: "host"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                            class SenderMacAddress(Entity):
                                                """
                                                Sender MAC address
                                                
                                                .. attribute:: mac_address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: log
                                                
                                                	Log on match
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-sw'
                                                _revision = '2018-01-10'

                                                def __init__(self):
                                                    super(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                    self.yang_name = "sender-mac-address"
                                                    self.yang_parent_name = "host"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['mac_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                    ])
                                                    self.mac_address = None
                                                    self.log = None
                                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Arp.AccessList.Default.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Response(Entity):
                        """
                        ARP Response
                        
                        .. attribute:: ip
                        
                        	Sender IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Default.Permit.Response, self).__init__()

                            self.yang_name = "response"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Default.Permit.Response.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Arp.AccessList.Default.Permit.Response.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response, [], name, value)


                        class Ip(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: sender_ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress>`
                            
                            .. attribute:: any
                            
                            	Any Sender IP address
                            	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Any>`
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Default.Permit.Response.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Response.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Response.Ip.Host))])
                                self._leafs = OrderedDict()

                                self.any = Native.Arp.AccessList.Default.Permit.Response.Ip.Any()
                                self.any.parent = self
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.Default.Permit.Response.Ip.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_ip_address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip, [], name, value)


                            class SenderIpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: ip_address_mask
                                
                                	Sender IP wildcard mask
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress, self).__init__()

                                    self.yang_name = "sender-ip-address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                    ])
                                    self.ip_address = None
                                    self.ip_address_mask = None

                                    self.mac = Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "sender-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Any(Entity):
                                """
                                Any Sender IP address
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Permit.Response.Ip.Any, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac))])
                                    self._leafs = OrderedDict()

                                    self.mac = Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Any, [], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Any_>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "any"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any_(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Any_, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Any_, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: ip_address
                                
                                	Sender IP address
                                	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Permit.Response.Ip.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress))])
                                    self._leafs = OrderedDict()

                                    self.ip_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Host, [], name, value)


                                class IpAddress(Entity):
                                    """
                                    Sender IP address
                                    
                                    .. attribute:: ip_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac
                                    
                                    	Sender MAC address
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress, self).__init__()

                                        self.yang_name = "ip-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_address']
                                        self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac))])
                                        self._leafs = OrderedDict([
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ])
                                        self.ip_address = None

                                        self.mac = Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac()
                                        self.mac.parent = self
                                        self._children_name_map["mac"] = "mac"
                                        self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                    class Mac(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                        
                                        .. attribute:: any
                                        
                                        	Any MAC address
                                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Any>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: host
                                        
                                        	Single Sender host
                                        	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Host_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Host_))])
                                            self._leafs = OrderedDict()

                                            self.any = None
                                            self._children_name_map["any"] = "any"

                                            self.host = Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Host_()
                                            self.host.parent = self
                                            self._children_name_map["host"] = "host"

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: mac_address_mask
                                            
                                            	Sender MAC address mask
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.mac_address_mask = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                        class Any(Entity):
                                            """
                                            Any MAC address
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                                self.yang_name = "any"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.log = None
                                                self._segment_path = lambda: "any"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                        class Host_(Entity):
                                            """
                                            Single Sender host
                                            
                                            .. attribute:: sender_mac_address
                                            
                                            	Sender MAC address
                                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                                self.yang_name = "host"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                                self._leafs = OrderedDict()

                                                self.sender_mac_address = YList(self)
                                                self._segment_path = lambda: "host"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                            class SenderMacAddress(Entity):
                                                """
                                                Sender MAC address
                                                
                                                .. attribute:: mac_address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: log
                                                
                                                	Log on match
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-sw'
                                                _revision = '2018-01-10'

                                                def __init__(self):
                                                    super(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                    self.yang_name = "sender-mac-address"
                                                    self.yang_parent_name = "host"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['mac_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                    ])
                                                    self.mac_address = None
                                                    self.log = None
                                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Arp.AccessList.Default.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                class Deny(Entity):
                    """
                    Specify packets to reject
                    
                    .. attribute:: ip
                    
                    	Sender IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip>`
                    
                    .. attribute:: request
                    
                    	ARP Request
                    	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request>`
                    
                    .. attribute:: response
                    
                    	ARP Response
                    	**type**\:  :py:class:`Response <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Arp.AccessList.Default.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "default"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Default.Deny.Ip)), ("request", ("request", Native.Arp.AccessList.Default.Deny.Request)), ("response", ("response", Native.Arp.AccessList.Default.Deny.Response))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Arp.AccessList.Default.Deny.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.request = Native.Arp.AccessList.Default.Deny.Request()
                        self.request.parent = self
                        self._children_name_map["request"] = "request"

                        self.response = Native.Arp.AccessList.Default.Deny.Response()
                        self.response.parent = self
                        self._children_name_map["response"] = "response"
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Arp.AccessList.Default.Deny, [], name, value)


                    class Ip(Entity):
                        """
                        Sender IP address
                        
                        .. attribute:: sender_ip_address
                        
                        	Sender IP address
                        	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress>`
                        
                        .. attribute:: any
                        
                        	Any Sender IP address
                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Any>`
                        
                        .. attribute:: host
                        
                        	Single Sender host
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Host>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Default.Deny.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Ip.Host))])
                            self._leafs = OrderedDict()

                            self.any = Native.Arp.AccessList.Default.Deny.Ip.Any()
                            self.any.parent = self
                            self._children_name_map["any"] = "any"

                            self.host = Native.Arp.AccessList.Default.Deny.Ip.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.sender_ip_address = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip, [], name, value)


                        class SenderIpAddress(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: ip_address  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip_address_mask
                            
                            	Sender IP wildcard mask
                            	**type**\: str
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress, self).__init__()

                                self.yang_name = "sender-ip-address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_address']
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac))])
                                self._leafs = OrderedDict([
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                ])
                                self.ip_address = None
                                self.ip_address_mask = None

                                self.mac = Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Any>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "sender-ip-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Any(Entity):
                            """
                            Any Sender IP address
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Any.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Default.Deny.Ip.Any, self).__init__()

                                self.yang_name = "any"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Deny.Ip.Any.Mac))])
                                self._leafs = OrderedDict()

                                self.mac = Native.Arp.AccessList.Default.Deny.Ip.Any.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "any"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Any, [], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Any_>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Deny.Ip.Any.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "any"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Any.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any_(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Any_, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Any_, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Host(Entity):
                            """
                            Single Sender host
                            
                            .. attribute:: ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Default.Deny.Ip.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress))])
                                self._leafs = OrderedDict()

                                self.ip_address = YList(self)
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Host, [], name, value)


                            class IpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress, self).__init__()

                                    self.yang_name = "ip-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ])
                                    self.ip_address = None

                                    self.mac = Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Host_>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Host_))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Host_()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                    class Host_(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Request(Entity):
                        """
                        ARP Request
                        
                        .. attribute:: ip
                        
                        	Sender IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Default.Deny.Request, self).__init__()

                            self.yang_name = "request"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Default.Deny.Request.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Arp.AccessList.Default.Deny.Request.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request, [], name, value)


                        class Ip(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: sender_ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress>`
                            
                            .. attribute:: any
                            
                            	Any Sender IP address
                            	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Any>`
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Default.Deny.Request.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "request"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Request.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Request.Ip.Host))])
                                self._leafs = OrderedDict()

                                self.any = Native.Arp.AccessList.Default.Deny.Request.Ip.Any()
                                self.any.parent = self
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.Default.Deny.Request.Ip.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_ip_address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip, [], name, value)


                            class SenderIpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: ip_address_mask
                                
                                	Sender IP wildcard mask
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress, self).__init__()

                                    self.yang_name = "sender-ip-address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                    ])
                                    self.ip_address = None
                                    self.ip_address_mask = None

                                    self.mac = Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "sender-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Any(Entity):
                                """
                                Any Sender IP address
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Deny.Request.Ip.Any, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac))])
                                    self._leafs = OrderedDict()

                                    self.mac = Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Any, [], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Any_>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "any"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any_(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Any_, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Any_, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: ip_address
                                
                                	Sender IP address
                                	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Deny.Request.Ip.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress))])
                                    self._leafs = OrderedDict()

                                    self.ip_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Host, [], name, value)


                                class IpAddress(Entity):
                                    """
                                    Sender IP address
                                    
                                    .. attribute:: ip_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac
                                    
                                    	Sender MAC address
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress, self).__init__()

                                        self.yang_name = "ip-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_address']
                                        self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac))])
                                        self._leafs = OrderedDict([
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ])
                                        self.ip_address = None

                                        self.mac = Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac()
                                        self.mac.parent = self
                                        self._children_name_map["mac"] = "mac"
                                        self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                    class Mac(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                        
                                        .. attribute:: any
                                        
                                        	Any MAC address
                                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Any>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: host
                                        
                                        	Single Sender host
                                        	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Host_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Host_))])
                                            self._leafs = OrderedDict()

                                            self.any = None
                                            self._children_name_map["any"] = "any"

                                            self.host = Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Host_()
                                            self.host.parent = self
                                            self._children_name_map["host"] = "host"

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: mac_address_mask
                                            
                                            	Sender MAC address mask
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.mac_address_mask = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                        class Any(Entity):
                                            """
                                            Any MAC address
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                                self.yang_name = "any"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.log = None
                                                self._segment_path = lambda: "any"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                        class Host_(Entity):
                                            """
                                            Single Sender host
                                            
                                            .. attribute:: sender_mac_address
                                            
                                            	Sender MAC address
                                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                                self.yang_name = "host"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                                self._leafs = OrderedDict()

                                                self.sender_mac_address = YList(self)
                                                self._segment_path = lambda: "host"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                            class SenderMacAddress(Entity):
                                                """
                                                Sender MAC address
                                                
                                                .. attribute:: mac_address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: log
                                                
                                                	Log on match
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-sw'
                                                _revision = '2018-01-10'

                                                def __init__(self):
                                                    super(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                    self.yang_name = "sender-mac-address"
                                                    self.yang_parent_name = "host"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['mac_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                    ])
                                                    self.mac_address = None
                                                    self.log = None
                                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Arp.AccessList.Default.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Response(Entity):
                        """
                        ARP Response
                        
                        .. attribute:: ip
                        
                        	Sender IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.Default.Deny.Response, self).__init__()

                            self.yang_name = "response"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.Default.Deny.Response.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Arp.AccessList.Default.Deny.Response.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response, [], name, value)


                        class Ip(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: sender_ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress>`
                            
                            .. attribute:: any
                            
                            	Any Sender IP address
                            	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Any>`
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.Default.Deny.Response.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Response.Ip.Any)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Response.Ip.Host))])
                                self._leafs = OrderedDict()

                                self.any = Native.Arp.AccessList.Default.Deny.Response.Ip.Any()
                                self.any.parent = self
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.Default.Deny.Response.Ip.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_ip_address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip, [], name, value)


                            class SenderIpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: ip_address_mask
                                
                                	Sender IP wildcard mask
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress, self).__init__()

                                    self.yang_name = "sender-ip-address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                    ])
                                    self.ip_address = None
                                    self.ip_address_mask = None

                                    self.mac = Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "sender-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Any(Entity):
                                """
                                Any Sender IP address
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Deny.Response.Ip.Any, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac))])
                                    self._leafs = OrderedDict()

                                    self.mac = Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Any, [], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Any_>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "any"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any_(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Any_, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Any_, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: ip_address
                                
                                	Sender IP address
                                	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.Default.Deny.Response.Ip.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress))])
                                    self._leafs = OrderedDict()

                                    self.ip_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Host, [], name, value)


                                class IpAddress(Entity):
                                    """
                                    Sender IP address
                                    
                                    .. attribute:: ip_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac
                                    
                                    	Sender MAC address
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress, self).__init__()

                                        self.yang_name = "ip-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_address']
                                        self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac))])
                                        self._leafs = OrderedDict([
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ])
                                        self.ip_address = None

                                        self.mac = Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac()
                                        self.mac.parent = self
                                        self._children_name_map["mac"] = "mac"
                                        self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                    class Mac(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                        
                                        .. attribute:: any
                                        
                                        	Any MAC address
                                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Any>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: host
                                        
                                        	Single Sender host
                                        	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Host_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Host_))])
                                            self._leafs = OrderedDict()

                                            self.any = None
                                            self._children_name_map["any"] = "any"

                                            self.host = Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Host_()
                                            self.host.parent = self
                                            self._children_name_map["host"] = "host"

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: mac_address_mask
                                            
                                            	Sender MAC address mask
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.mac_address_mask = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                        class Any(Entity):
                                            """
                                            Any MAC address
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                                self.yang_name = "any"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.log = None
                                                self._segment_path = lambda: "any"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                        class Host_(Entity):
                                            """
                                            Single Sender host
                                            
                                            .. attribute:: sender_mac_address
                                            
                                            	Sender MAC address
                                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                                self.yang_name = "host"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                                self._leafs = OrderedDict()

                                                self.sender_mac_address = YList(self)
                                                self._segment_path = lambda: "host"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                            class SenderMacAddress(Entity):
                                                """
                                                Sender MAC address
                                                
                                                .. attribute:: mac_address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: log
                                                
                                                	Log on match
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-sw'
                                                _revision = '2018-01-10'

                                                def __init__(self):
                                                    super(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                    self.yang_name = "sender-mac-address"
                                                    self.yang_parent_name = "host"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['mac_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                    ])
                                                    self.mac_address = None
                                                    self.log = None
                                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Arp.AccessList.Default.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


            class No(Entity):
                """
                Negate a command or set its defaults
                
                .. attribute:: permit
                
                	Specify packets to forward
                	**type**\:  :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit>`
                
                .. attribute:: deny
                
                	Specify packets to reject
                	**type**\:  :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Arp.AccessList.No, self).__init__()

                    self.yang_name = "no"
                    self.yang_parent_name = "access-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("permit", ("permit", Native.Arp.AccessList.No.Permit)), ("deny", ("deny", Native.Arp.AccessList.No.Deny))])
                    self._leafs = OrderedDict()

                    self.permit = Native.Arp.AccessList.No.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"

                    self.deny = Native.Arp.AccessList.No.Deny()
                    self.deny.parent = self
                    self._children_name_map["deny"] = "deny"
                    self._segment_path = lambda: "no"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Arp.AccessList.No, [], name, value)


                class Permit(Entity):
                    """
                    Specify packets to forward
                    
                    .. attribute:: ip
                    
                    	Sender IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip>`
                    
                    .. attribute:: request
                    
                    	ARP Request
                    	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request>`
                    
                    .. attribute:: response
                    
                    	ARP Response
                    	**type**\:  :py:class:`Response <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Arp.AccessList.No.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "no"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.No.Permit.Ip)), ("request", ("request", Native.Arp.AccessList.No.Permit.Request)), ("response", ("response", Native.Arp.AccessList.No.Permit.Response))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Arp.AccessList.No.Permit.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.request = Native.Arp.AccessList.No.Permit.Request()
                        self.request.parent = self
                        self._children_name_map["request"] = "request"

                        self.response = Native.Arp.AccessList.No.Permit.Response()
                        self.response.parent = self
                        self._children_name_map["response"] = "response"
                        self._segment_path = lambda: "permit"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Arp.AccessList.No.Permit, [], name, value)


                    class Ip(Entity):
                        """
                        Sender IP address
                        
                        .. attribute:: sender_ip_address
                        
                        	Sender IP address
                        	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress>`
                        
                        .. attribute:: any
                        
                        	Any Sender IP address
                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Any>`
                        
                        .. attribute:: host
                        
                        	Single Sender host
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Host>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.No.Permit.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Ip.Any)), ("host", ("host", Native.Arp.AccessList.No.Permit.Ip.Host))])
                            self._leafs = OrderedDict()

                            self.any = Native.Arp.AccessList.No.Permit.Ip.Any()
                            self.any.parent = self
                            self._children_name_map["any"] = "any"

                            self.host = Native.Arp.AccessList.No.Permit.Ip.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.sender_ip_address = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip, [], name, value)


                        class SenderIpAddress(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: ip_address  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip_address_mask
                            
                            	Sender IP wildcard mask
                            	**type**\: str
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress, self).__init__()

                                self.yang_name = "sender-ip-address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_address']
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac))])
                                self._leafs = OrderedDict([
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                ])
                                self.ip_address = None
                                self.ip_address_mask = None

                                self.mac = Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Any>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "sender-ip-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Any(Entity):
                            """
                            Any Sender IP address
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Any.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.No.Permit.Ip.Any, self).__init__()

                                self.yang_name = "any"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Permit.Ip.Any.Mac))])
                                self._leafs = OrderedDict()

                                self.mac = Native.Arp.AccessList.No.Permit.Ip.Any.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "any"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Any, [], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Any.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Any_>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Permit.Ip.Any.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "any"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Any.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any_(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Any_, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Any_, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Host(Entity):
                            """
                            Single Sender host
                            
                            .. attribute:: ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.No.Permit.Ip.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress))])
                                self._leafs = OrderedDict()

                                self.ip_address = YList(self)
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Host, [], name, value)


                            class IpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress, self).__init__()

                                    self.yang_name = "ip-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ])
                                    self.ip_address = None

                                    self.mac = Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Host_>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Host_))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Host_()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                    class Host_(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Request(Entity):
                        """
                        ARP Request
                        
                        .. attribute:: ip
                        
                        	Sender IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.No.Permit.Request, self).__init__()

                            self.yang_name = "request"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.No.Permit.Request.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Arp.AccessList.No.Permit.Request.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Request, [], name, value)


                        class Ip(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: sender_ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress>`
                            
                            .. attribute:: any
                            
                            	Any Sender IP address
                            	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Any>`
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.No.Permit.Request.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "request"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Request.Ip.Any)), ("host", ("host", Native.Arp.AccessList.No.Permit.Request.Ip.Host))])
                                self._leafs = OrderedDict()

                                self.any = Native.Arp.AccessList.No.Permit.Request.Ip.Any()
                                self.any.parent = self
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.No.Permit.Request.Ip.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_ip_address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip, [], name, value)


                            class SenderIpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: ip_address_mask
                                
                                	Sender IP wildcard mask
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress, self).__init__()

                                    self.yang_name = "sender-ip-address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                    ])
                                    self.ip_address = None
                                    self.ip_address_mask = None

                                    self.mac = Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "sender-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Any(Entity):
                                """
                                Any Sender IP address
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Permit.Request.Ip.Any, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac))])
                                    self._leafs = OrderedDict()

                                    self.mac = Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Any, [], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Any_>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "any"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any_(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Any_, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Any_, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: ip_address
                                
                                	Sender IP address
                                	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Permit.Request.Ip.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress))])
                                    self._leafs = OrderedDict()

                                    self.ip_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Host, [], name, value)


                                class IpAddress(Entity):
                                    """
                                    Sender IP address
                                    
                                    .. attribute:: ip_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac
                                    
                                    	Sender MAC address
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress, self).__init__()

                                        self.yang_name = "ip-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_address']
                                        self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac))])
                                        self._leafs = OrderedDict([
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ])
                                        self.ip_address = None

                                        self.mac = Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac()
                                        self.mac.parent = self
                                        self._children_name_map["mac"] = "mac"
                                        self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                    class Mac(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                        
                                        .. attribute:: any
                                        
                                        	Any MAC address
                                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Any>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: host
                                        
                                        	Single Sender host
                                        	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Host_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Host_))])
                                            self._leafs = OrderedDict()

                                            self.any = None
                                            self._children_name_map["any"] = "any"

                                            self.host = Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Host_()
                                            self.host.parent = self
                                            self._children_name_map["host"] = "host"

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: mac_address_mask
                                            
                                            	Sender MAC address mask
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.mac_address_mask = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                        class Any(Entity):
                                            """
                                            Any MAC address
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                                self.yang_name = "any"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.log = None
                                                self._segment_path = lambda: "any"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                        class Host_(Entity):
                                            """
                                            Single Sender host
                                            
                                            .. attribute:: sender_mac_address
                                            
                                            	Sender MAC address
                                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                                self.yang_name = "host"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                                self._leafs = OrderedDict()

                                                self.sender_mac_address = YList(self)
                                                self._segment_path = lambda: "host"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                            class SenderMacAddress(Entity):
                                                """
                                                Sender MAC address
                                                
                                                .. attribute:: mac_address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: log
                                                
                                                	Log on match
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-sw'
                                                _revision = '2018-01-10'

                                                def __init__(self):
                                                    super(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                    self.yang_name = "sender-mac-address"
                                                    self.yang_parent_name = "host"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['mac_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                    ])
                                                    self.mac_address = None
                                                    self.log = None
                                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Arp.AccessList.No.Permit.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Response(Entity):
                        """
                        ARP Response
                        
                        .. attribute:: ip
                        
                        	Sender IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.No.Permit.Response, self).__init__()

                            self.yang_name = "response"
                            self.yang_parent_name = "permit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.No.Permit.Response.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Arp.AccessList.No.Permit.Response.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Response, [], name, value)


                        class Ip(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: sender_ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress>`
                            
                            .. attribute:: any
                            
                            	Any Sender IP address
                            	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Any>`
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.No.Permit.Response.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Response.Ip.Any)), ("host", ("host", Native.Arp.AccessList.No.Permit.Response.Ip.Host))])
                                self._leafs = OrderedDict()

                                self.any = Native.Arp.AccessList.No.Permit.Response.Ip.Any()
                                self.any.parent = self
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.No.Permit.Response.Ip.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_ip_address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip, [], name, value)


                            class SenderIpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: ip_address_mask
                                
                                	Sender IP wildcard mask
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress, self).__init__()

                                    self.yang_name = "sender-ip-address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                    ])
                                    self.ip_address = None
                                    self.ip_address_mask = None

                                    self.mac = Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "sender-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Any(Entity):
                                """
                                Any Sender IP address
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Permit.Response.Ip.Any, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac))])
                                    self._leafs = OrderedDict()

                                    self.mac = Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Any, [], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Any_>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "any"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any_(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Any_, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Any_, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: ip_address
                                
                                	Sender IP address
                                	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Permit.Response.Ip.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress))])
                                    self._leafs = OrderedDict()

                                    self.ip_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Host, [], name, value)


                                class IpAddress(Entity):
                                    """
                                    Sender IP address
                                    
                                    .. attribute:: ip_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac
                                    
                                    	Sender MAC address
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress, self).__init__()

                                        self.yang_name = "ip-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_address']
                                        self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac))])
                                        self._leafs = OrderedDict([
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ])
                                        self.ip_address = None

                                        self.mac = Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac()
                                        self.mac.parent = self
                                        self._children_name_map["mac"] = "mac"
                                        self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                    class Mac(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                        
                                        .. attribute:: any
                                        
                                        	Any MAC address
                                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Any>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: host
                                        
                                        	Single Sender host
                                        	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Host_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Host_))])
                                            self._leafs = OrderedDict()

                                            self.any = None
                                            self._children_name_map["any"] = "any"

                                            self.host = Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Host_()
                                            self.host.parent = self
                                            self._children_name_map["host"] = "host"

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: mac_address_mask
                                            
                                            	Sender MAC address mask
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.mac_address_mask = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                        class Any(Entity):
                                            """
                                            Any MAC address
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                                self.yang_name = "any"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.log = None
                                                self._segment_path = lambda: "any"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                        class Host_(Entity):
                                            """
                                            Single Sender host
                                            
                                            .. attribute:: sender_mac_address
                                            
                                            	Sender MAC address
                                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                                self.yang_name = "host"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                                self._leafs = OrderedDict()

                                                self.sender_mac_address = YList(self)
                                                self._segment_path = lambda: "host"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                            class SenderMacAddress(Entity):
                                                """
                                                Sender MAC address
                                                
                                                .. attribute:: mac_address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: log
                                                
                                                	Log on match
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-sw'
                                                _revision = '2018-01-10'

                                                def __init__(self):
                                                    super(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                    self.yang_name = "sender-mac-address"
                                                    self.yang_parent_name = "host"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['mac_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                    ])
                                                    self.mac_address = None
                                                    self.log = None
                                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Arp.AccessList.No.Permit.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                class Deny(Entity):
                    """
                    Specify packets to reject
                    
                    .. attribute:: ip
                    
                    	Sender IP address
                    	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip>`
                    
                    .. attribute:: request
                    
                    	ARP Request
                    	**type**\:  :py:class:`Request <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request>`
                    
                    .. attribute:: response
                    
                    	ARP Response
                    	**type**\:  :py:class:`Response <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Arp.AccessList.No.Deny, self).__init__()

                        self.yang_name = "deny"
                        self.yang_parent_name = "no"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.No.Deny.Ip)), ("request", ("request", Native.Arp.AccessList.No.Deny.Request)), ("response", ("response", Native.Arp.AccessList.No.Deny.Response))])
                        self._leafs = OrderedDict()

                        self.ip = Native.Arp.AccessList.No.Deny.Ip()
                        self.ip.parent = self
                        self._children_name_map["ip"] = "ip"

                        self.request = Native.Arp.AccessList.No.Deny.Request()
                        self.request.parent = self
                        self._children_name_map["request"] = "request"

                        self.response = Native.Arp.AccessList.No.Deny.Response()
                        self.response.parent = self
                        self._children_name_map["response"] = "response"
                        self._segment_path = lambda: "deny"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Arp.AccessList.No.Deny, [], name, value)


                    class Ip(Entity):
                        """
                        Sender IP address
                        
                        .. attribute:: sender_ip_address
                        
                        	Sender IP address
                        	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress>`
                        
                        .. attribute:: any
                        
                        	Any Sender IP address
                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Any>`
                        
                        .. attribute:: host
                        
                        	Single Sender host
                        	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Host>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.No.Deny.Ip, self).__init__()

                            self.yang_name = "ip"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Ip.Any)), ("host", ("host", Native.Arp.AccessList.No.Deny.Ip.Host))])
                            self._leafs = OrderedDict()

                            self.any = Native.Arp.AccessList.No.Deny.Ip.Any()
                            self.any.parent = self
                            self._children_name_map["any"] = "any"

                            self.host = Native.Arp.AccessList.No.Deny.Ip.Host()
                            self.host.parent = self
                            self._children_name_map["host"] = "host"

                            self.sender_ip_address = YList(self)
                            self._segment_path = lambda: "ip"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip, [], name, value)


                        class SenderIpAddress(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: ip_address  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: ip_address_mask
                            
                            	Sender IP wildcard mask
                            	**type**\: str
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress, self).__init__()

                                self.yang_name = "sender-ip-address"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['ip_address']
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac))])
                                self._leafs = OrderedDict([
                                    ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                ])
                                self.ip_address = None
                                self.ip_address_mask = None

                                self.mac = Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Any>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "sender-ip-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Any(Entity):
                            """
                            Any Sender IP address
                            
                            .. attribute:: mac
                            
                            	Sender MAC address
                            	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Any.Mac>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.No.Deny.Ip.Any, self).__init__()

                                self.yang_name = "any"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Deny.Ip.Any.Mac))])
                                self._leafs = OrderedDict()

                                self.mac = Native.Arp.AccessList.No.Deny.Ip.Any.Mac()
                                self.mac.parent = self
                                self._children_name_map["mac"] = "mac"
                                self._segment_path = lambda: "any"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Any, [], name, value)


                            class Mac(Entity):
                                """
                                Sender MAC address
                                
                                .. attribute:: sender_mac_address
                                
                                	Sender MAC address
                                	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Any.Mac.SenderMacAddress>`
                                
                                .. attribute:: any
                                
                                	Any MAC address
                                	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Any_>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: host
                                
                                	Single Sender host
                                	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Host>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Deny.Ip.Any.Mac, self).__init__()

                                    self.yang_name = "mac"
                                    self.yang_parent_name = "any"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Host))])
                                    self._leafs = OrderedDict()

                                    self.any = None
                                    self._children_name_map["any"] = "any"

                                    self.host = Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Host()
                                    self.host.parent = self
                                    self._children_name_map["host"] = "host"

                                    self.sender_mac_address = YList(self)
                                    self._segment_path = lambda: "mac"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Any.Mac, [], name, value)


                                class SenderMacAddress(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: mac_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac_address_mask
                                    
                                    	Sender MAC address mask
                                    	**type**\: str
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                        self.yang_name = "sender-mac-address"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mac_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                            ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.mac_address = None
                                        self.mac_address_mask = None
                                        self.log = None
                                        self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                class Any_(Entity):
                                    """
                                    Any MAC address
                                    
                                    .. attribute:: log
                                    
                                    	Log on match
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Any_, self).__init__()

                                        self.yang_name = "any"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                        ])
                                        self.log = None
                                        self._segment_path = lambda: "any"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Any_, [u'log'], name, value)


                                class Host(Entity):
                                    """
                                    Single Sender host
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Host.SenderMacAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Host, self).__init__()

                                        self.yang_name = "host"
                                        self.yang_parent_name = "mac"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Host.SenderMacAddress))])
                                        self._leafs = OrderedDict()

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Host, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "host"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                        class Host(Entity):
                            """
                            Single Sender host
                            
                            .. attribute:: ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.No.Deny.Ip.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "ip"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress))])
                                self._leafs = OrderedDict()

                                self.ip_address = YList(self)
                                self._segment_path = lambda: "host"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Host, [], name, value)


                            class IpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress, self).__init__()

                                    self.yang_name = "ip-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                    ])
                                    self.ip_address = None

                                    self.mac = Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Host_>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Host_))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Host_()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                    class Host_(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Request(Entity):
                        """
                        ARP Request
                        
                        .. attribute:: ip
                        
                        	Sender IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.No.Deny.Request, self).__init__()

                            self.yang_name = "request"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.No.Deny.Request.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Arp.AccessList.No.Deny.Request.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Request, [], name, value)


                        class Ip(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: sender_ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress>`
                            
                            .. attribute:: any
                            
                            	Any Sender IP address
                            	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Any>`
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.No.Deny.Request.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "request"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Request.Ip.Any)), ("host", ("host", Native.Arp.AccessList.No.Deny.Request.Ip.Host))])
                                self._leafs = OrderedDict()

                                self.any = Native.Arp.AccessList.No.Deny.Request.Ip.Any()
                                self.any.parent = self
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.No.Deny.Request.Ip.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_ip_address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip, [], name, value)


                            class SenderIpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: ip_address_mask
                                
                                	Sender IP wildcard mask
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress, self).__init__()

                                    self.yang_name = "sender-ip-address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                    ])
                                    self.ip_address = None
                                    self.ip_address_mask = None

                                    self.mac = Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "sender-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Any(Entity):
                                """
                                Any Sender IP address
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Deny.Request.Ip.Any, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac))])
                                    self._leafs = OrderedDict()

                                    self.mac = Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Any, [], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Any_>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "any"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any_(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Any_, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Any_, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: ip_address
                                
                                	Sender IP address
                                	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Deny.Request.Ip.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress))])
                                    self._leafs = OrderedDict()

                                    self.ip_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Host, [], name, value)


                                class IpAddress(Entity):
                                    """
                                    Sender IP address
                                    
                                    .. attribute:: ip_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac
                                    
                                    	Sender MAC address
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress, self).__init__()

                                        self.yang_name = "ip-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_address']
                                        self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac))])
                                        self._leafs = OrderedDict([
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ])
                                        self.ip_address = None

                                        self.mac = Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac()
                                        self.mac.parent = self
                                        self._children_name_map["mac"] = "mac"
                                        self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                    class Mac(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                        
                                        .. attribute:: any
                                        
                                        	Any MAC address
                                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Any>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: host
                                        
                                        	Single Sender host
                                        	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Host_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Host_))])
                                            self._leafs = OrderedDict()

                                            self.any = None
                                            self._children_name_map["any"] = "any"

                                            self.host = Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Host_()
                                            self.host.parent = self
                                            self._children_name_map["host"] = "host"

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: mac_address_mask
                                            
                                            	Sender MAC address mask
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.mac_address_mask = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                        class Any(Entity):
                                            """
                                            Any MAC address
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                                self.yang_name = "any"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.log = None
                                                self._segment_path = lambda: "any"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                        class Host_(Entity):
                                            """
                                            Single Sender host
                                            
                                            .. attribute:: sender_mac_address
                                            
                                            	Sender MAC address
                                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                                self.yang_name = "host"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                                self._leafs = OrderedDict()

                                                self.sender_mac_address = YList(self)
                                                self._segment_path = lambda: "host"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                            class SenderMacAddress(Entity):
                                                """
                                                Sender MAC address
                                                
                                                .. attribute:: mac_address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: log
                                                
                                                	Log on match
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-sw'
                                                _revision = '2018-01-10'

                                                def __init__(self):
                                                    super(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                    self.yang_name = "sender-mac-address"
                                                    self.yang_parent_name = "host"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['mac_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                    ])
                                                    self.mac_address = None
                                                    self.log = None
                                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Arp.AccessList.No.Deny.Request.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


                    class Response(Entity):
                        """
                        ARP Response
                        
                        .. attribute:: ip
                        
                        	Sender IP address
                        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Arp.AccessList.No.Deny.Response, self).__init__()

                            self.yang_name = "response"
                            self.yang_parent_name = "deny"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ip", ("ip", Native.Arp.AccessList.No.Deny.Response.Ip))])
                            self._leafs = OrderedDict()

                            self.ip = Native.Arp.AccessList.No.Deny.Response.Ip()
                            self.ip.parent = self
                            self._children_name_map["ip"] = "ip"
                            self._segment_path = lambda: "response"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Response, [], name, value)


                        class Ip(Entity):
                            """
                            Sender IP address
                            
                            .. attribute:: sender_ip_address
                            
                            	Sender IP address
                            	**type**\: list of  		 :py:class:`SenderIpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress>`
                            
                            .. attribute:: any
                            
                            	Any Sender IP address
                            	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Any>`
                            
                            .. attribute:: host
                            
                            	Single Sender host
                            	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Host>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Arp.AccessList.No.Deny.Response.Ip, self).__init__()

                                self.yang_name = "ip"
                                self.yang_parent_name = "response"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sender-ip-address", ("sender_ip_address", Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Response.Ip.Any)), ("host", ("host", Native.Arp.AccessList.No.Deny.Response.Ip.Host))])
                                self._leafs = OrderedDict()

                                self.any = Native.Arp.AccessList.No.Deny.Response.Ip.Any()
                                self.any.parent = self
                                self._children_name_map["any"] = "any"

                                self.host = Native.Arp.AccessList.No.Deny.Response.Ip.Host()
                                self.host.parent = self
                                self._children_name_map["host"] = "host"

                                self.sender_ip_address = YList(self)
                                self._segment_path = lambda: "ip"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip, [], name, value)


                            class SenderIpAddress(Entity):
                                """
                                Sender IP address
                                
                                .. attribute:: ip_address  (key)
                                
                                	
                                	**type**\: str
                                
                                .. attribute:: ip_address_mask
                                
                                	Sender IP wildcard mask
                                	**type**\: str
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress, self).__init__()

                                    self.yang_name = "sender-ip-address"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ip_address']
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac))])
                                    self._leafs = OrderedDict([
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ('ip_address_mask', (YLeaf(YType.str, 'ip-address-mask'), ['str'])),
                                    ])
                                    self.ip_address = None
                                    self.ip_address_mask = None

                                    self.mac = Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "sender-ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress, [u'ip_address', u'ip_address_mask'], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Any>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "sender-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Any, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Any, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.SenderIpAddress.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Any(Entity):
                                """
                                Any Sender IP address
                                
                                .. attribute:: mac
                                
                                	Sender MAC address
                                	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Deny.Response.Ip.Any, self).__init__()

                                    self.yang_name = "any"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac))])
                                    self._leafs = OrderedDict()

                                    self.mac = Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac()
                                    self.mac.parent = self
                                    self._children_name_map["mac"] = "mac"
                                    self._segment_path = lambda: "any"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Any, [], name, value)


                                class Mac(Entity):
                                    """
                                    Sender MAC address
                                    
                                    .. attribute:: sender_mac_address
                                    
                                    	Sender MAC address
                                    	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.SenderMacAddress>`
                                    
                                    .. attribute:: any
                                    
                                    	Any MAC address
                                    	**type**\:  :py:class:`Any_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Any_>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: host
                                    
                                    	Single Sender host
                                    	**type**\:  :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Host>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac, self).__init__()

                                        self.yang_name = "mac"
                                        self.yang_parent_name = "any"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Any_)), ("host", ("host", Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Host))])
                                        self._leafs = OrderedDict()

                                        self.any = None
                                        self._children_name_map["any"] = "any"

                                        self.host = Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Host()
                                        self.host.parent = self
                                        self._children_name_map["host"] = "host"

                                        self.sender_mac_address = YList(self)
                                        self._segment_path = lambda: "mac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac, [], name, value)


                                    class SenderMacAddress(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: mac_address  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        .. attribute:: mac_address_mask
                                        
                                        	Sender MAC address mask
                                        	**type**\: str
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.SenderMacAddress, self).__init__()

                                            self.yang_name = "sender-mac-address"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['mac_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.mac_address = None
                                            self.mac_address_mask = None
                                            self.log = None
                                            self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                    class Any_(Entity):
                                        """
                                        Any MAC address
                                        
                                        .. attribute:: log
                                        
                                        	Log on match
                                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Any_, self).__init__()

                                            self.yang_name = "any"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                            ])
                                            self.log = None
                                            self._segment_path = lambda: "any"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Any_, [u'log'], name, value)


                                    class Host(Entity):
                                        """
                                        Single Sender host
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "mac"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress))])
                                            self._leafs = OrderedDict()

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "host"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Host, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "host"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Any.Mac.Host.SenderMacAddress, [u'mac_address', u'log'], name, value)


                            class Host(Entity):
                                """
                                Single Sender host
                                
                                .. attribute:: ip_address
                                
                                	Sender IP address
                                	**type**\: list of  		 :py:class:`IpAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress>`
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Arp.AccessList.No.Deny.Response.Ip.Host, self).__init__()

                                    self.yang_name = "host"
                                    self.yang_parent_name = "ip"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-address", ("ip_address", Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress))])
                                    self._leafs = OrderedDict()

                                    self.ip_address = YList(self)
                                    self._segment_path = lambda: "host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Host, [], name, value)


                                class IpAddress(Entity):
                                    """
                                    Sender IP address
                                    
                                    .. attribute:: ip_address  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    .. attribute:: mac
                                    
                                    	Sender MAC address
                                    	**type**\:  :py:class:`Mac <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac>`
                                    
                                    

                                    """

                                    _prefix = 'ios-sw'
                                    _revision = '2018-01-10'

                                    def __init__(self):
                                        super(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress, self).__init__()

                                        self.yang_name = "ip-address"
                                        self.yang_parent_name = "host"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['ip_address']
                                        self._child_classes = OrderedDict([("mac", ("mac", Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac))])
                                        self._leafs = OrderedDict([
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                        ])
                                        self.ip_address = None

                                        self.mac = Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac()
                                        self.mac.parent = self
                                        self._children_name_map["mac"] = "mac"
                                        self._segment_path = lambda: "ip-address" + "[ip-address='" + str(self.ip_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress, [u'ip_address'], name, value)


                                    class Mac(Entity):
                                        """
                                        Sender MAC address
                                        
                                        .. attribute:: sender_mac_address
                                        
                                        	Sender MAC address
                                        	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress>`
                                        
                                        .. attribute:: any
                                        
                                        	Any MAC address
                                        	**type**\:  :py:class:`Any <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Any>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: host
                                        
                                        	Single Sender host
                                        	**type**\:  :py:class:`Host_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Host_>`
                                        
                                        

                                        """

                                        _prefix = 'ios-sw'
                                        _revision = '2018-01-10'

                                        def __init__(self):
                                            super(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac, self).__init__()

                                            self.yang_name = "mac"
                                            self.yang_parent_name = "ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress)), ("any", ("any", Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Any)), ("host", ("host", Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Host_))])
                                            self._leafs = OrderedDict()

                                            self.any = None
                                            self._children_name_map["any"] = "any"

                                            self.host = Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Host_()
                                            self.host.parent = self
                                            self._children_name_map["host"] = "host"

                                            self.sender_mac_address = YList(self)
                                            self._segment_path = lambda: "mac"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac, [], name, value)


                                        class SenderMacAddress(Entity):
                                            """
                                            Sender MAC address
                                            
                                            .. attribute:: mac_address  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            .. attribute:: mac_address_mask
                                            
                                            	Sender MAC address mask
                                            	**type**\: str
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, self).__init__()

                                                self.yang_name = "sender-mac-address"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['mac_address']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ('mac_address_mask', (YLeaf(YType.str, 'mac-address-mask'), ['str'])),
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.mac_address = None
                                                self.mac_address_mask = None
                                                self.log = None
                                                self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.SenderMacAddress, [u'mac_address', u'mac_address_mask', u'log'], name, value)


                                        class Any(Entity):
                                            """
                                            Any MAC address
                                            
                                            .. attribute:: log
                                            
                                            	Log on match
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Any, self).__init__()

                                                self.yang_name = "any"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict([
                                                    ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                ])
                                                self.log = None
                                                self._segment_path = lambda: "any"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Any, [u'log'], name, value)


                                        class Host_(Entity):
                                            """
                                            Single Sender host
                                            
                                            .. attribute:: sender_mac_address
                                            
                                            	Sender MAC address
                                            	**type**\: list of  		 :py:class:`SenderMacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ios-sw'
                                            _revision = '2018-01-10'

                                            def __init__(self):
                                                super(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Host_, self).__init__()

                                                self.yang_name = "host"
                                                self.yang_parent_name = "mac"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("sender-mac-address", ("sender_mac_address", Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress))])
                                                self._leafs = OrderedDict()

                                                self.sender_mac_address = YList(self)
                                                self._segment_path = lambda: "host"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Host_, [], name, value)


                                            class SenderMacAddress(Entity):
                                                """
                                                Sender MAC address
                                                
                                                .. attribute:: mac_address  (key)
                                                
                                                	
                                                	**type**\: str
                                                
                                                .. attribute:: log
                                                
                                                	Log on match
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                

                                                """

                                                _prefix = 'ios-sw'
                                                _revision = '2018-01-10'

                                                def __init__(self):
                                                    super(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, self).__init__()

                                                    self.yang_name = "sender-mac-address"
                                                    self.yang_parent_name = "host"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['mac_address']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ('log', (YLeaf(YType.empty, 'log'), ['Empty'])),
                                                    ])
                                                    self.mac_address = None
                                                    self.log = None
                                                    self._segment_path = lambda: "sender-mac-address" + "[mac-address='" + str(self.mac_address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.Arp.AccessList.No.Deny.Response.Ip.Host.IpAddress.Mac.Host_.SenderMacAddress, [u'mac_address', u'log'], name, value)


    class NetworkPolicy(Entity):
        """
        Network Policy
        
        .. attribute:: profile
        
        	Network Policy Profile
        	**type**\: int
        
        	**range:** 1..4294967295
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.NetworkPolicy, self).__init__()

            self.yang_name = "network-policy"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('profile', (YLeaf(YType.uint32, 'profile'), ['int'])),
            ])
            self.profile = None
            self._segment_path = lambda: "Cisco-IOS-XE-switch:network-policy"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.NetworkPolicy, [u'profile'], name, value)


    class Energywise(Entity):
        """
        EnergyWise Global Configuration Commands
        
        .. attribute:: domain
        
        	Set the EnergyWise domain this entity should join
        	**type**\: list of  		 :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Energywise.Domain>`
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.Energywise, self).__init__()

            self.yang_name = "energywise"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("domain", ("domain", Native.Energywise.Domain))])
            self._leafs = OrderedDict()

            self.domain = YList(self)
            self._segment_path = lambda: "Cisco-IOS-XE-switch:energywise"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Energywise, [], name, value)


        class Domain(Entity):
            """
            Set the EnergyWise domain this entity should join
            
            .. attribute:: word  (key)
            
            	
            	**type**\: str
            
            .. attribute:: security
            
            	Set security parameters for this EnergyWise domain
            	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Energywise.Domain.Security>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.Energywise.Domain, self).__init__()

                self.yang_name = "domain"
                self.yang_parent_name = "energywise"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['word']
                self._child_classes = OrderedDict([("security", ("security", Native.Energywise.Domain.Security))])
                self._leafs = OrderedDict([
                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                ])
                self.word = None

                self.security = Native.Energywise.Domain.Security()
                self.security.parent = self
                self._children_name_map["security"] = "security"
                self._segment_path = lambda: "domain" + "[word='" + str(self.word) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-switch:energywise/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Energywise.Domain, [u'word'], name, value)


            class Security(Entity):
                """
                Set security parameters for this EnergyWise domain
                
                .. attribute:: shared_secret
                
                	Set the shared secret for this EnergyWise domain
                	**type**\:  :py:class:`SharedSecret <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Energywise.Domain.Security.SharedSecret>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Energywise.Domain.Security, self).__init__()

                    self.yang_name = "security"
                    self.yang_parent_name = "domain"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("shared-secret", ("shared_secret", Native.Energywise.Domain.Security.SharedSecret))])
                    self._leafs = OrderedDict()

                    self.shared_secret = Native.Energywise.Domain.Security.SharedSecret()
                    self.shared_secret.parent = self
                    self._children_name_map["shared_secret"] = "shared-secret"
                    self._segment_path = lambda: "security"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Energywise.Domain.Security, [], name, value)


                class SharedSecret(Entity):
                    """
                    Set the shared secret for this EnergyWise domain
                    
                    .. attribute:: zero
                    
                    	Specifies an UNENCRYPTED shared secret for the domain will follow
                    	**type**\: list of  		 :py:class:`Zero <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Energywise.Domain.Security.SharedSecret.Zero>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Energywise.Domain.Security.SharedSecret, self).__init__()

                        self.yang_name = "shared-secret"
                        self.yang_parent_name = "security"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("zero", ("zero", Native.Energywise.Domain.Security.SharedSecret.Zero))])
                        self._leafs = OrderedDict()

                        self.zero = YList(self)
                        self._segment_path = lambda: "shared-secret"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Energywise.Domain.Security.SharedSecret, [], name, value)


                    class Zero(Entity):
                        """
                        Specifies an UNENCRYPTED shared secret for the domain will follow
                        
                        .. attribute:: word  (key)
                        
                        	
                        	**type**\: str
                        
                        .. attribute:: protocol
                        
                        	Specify a communication protocol to use to communicate with the EnergyWise domain
                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Energywise.Domain.Security.SharedSecret.Zero.Protocol>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Energywise.Domain.Security.SharedSecret.Zero, self).__init__()

                            self.yang_name = "zero"
                            self.yang_parent_name = "shared-secret"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['word']
                            self._child_classes = OrderedDict([("protocol", ("protocol", Native.Energywise.Domain.Security.SharedSecret.Zero.Protocol))])
                            self._leafs = OrderedDict([
                                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                            ])
                            self.word = None

                            self.protocol = Native.Energywise.Domain.Security.SharedSecret.Zero.Protocol()
                            self.protocol.parent = self
                            self._children_name_map["protocol"] = "protocol"
                            self._segment_path = lambda: "zero" + "[word='" + str(self.word) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Energywise.Domain.Security.SharedSecret.Zero, [u'word'], name, value)


                        class Protocol(Entity):
                            """
                            Specify a communication protocol to use to communicate with the EnergyWise domain
                            
                            .. attribute:: udp
                            
                            	UDP protocol
                            	**type**\:  :py:class:`Udp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Energywise.Domain.Security.SharedSecret.Zero.Protocol.Udp>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Energywise.Domain.Security.SharedSecret.Zero.Protocol, self).__init__()

                                self.yang_name = "protocol"
                                self.yang_parent_name = "zero"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("udp", ("udp", Native.Energywise.Domain.Security.SharedSecret.Zero.Protocol.Udp))])
                                self._leafs = OrderedDict()

                                self.udp = Native.Energywise.Domain.Security.SharedSecret.Zero.Protocol.Udp()
                                self.udp.parent = self
                                self._children_name_map["udp"] = "udp"
                                self._segment_path = lambda: "protocol"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Energywise.Domain.Security.SharedSecret.Zero.Protocol, [], name, value)


                            class Udp(Entity):
                                """
                                UDP protocol
                                
                                .. attribute:: port
                                
                                	Specify a port number to use to communicate with the EnergyWise domain
                                	**type**\: int
                                
                                	**range:** 1..65000
                                
                                .. attribute:: ip
                                
                                	Specify an ipaddress to use to communicate with the EnergyWise domain
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ios-sw'
                                _revision = '2018-01-10'

                                def __init__(self):
                                    super(Native.Energywise.Domain.Security.SharedSecret.Zero.Protocol.Udp, self).__init__()

                                    self.yang_name = "udp"
                                    self.yang_parent_name = "protocol"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                    ])
                                    self.port = None
                                    self.ip = None
                                    self._segment_path = lambda: "udp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Energywise.Domain.Security.SharedSecret.Zero.Protocol.Udp, [u'port', u'ip'], name, value)


    class ServiceTemplate(Entity):
        """
        Configure a service\-template/identity policy
        
        .. attribute:: word  (key)
        
        	
        	**type**\: str
        
        .. attribute:: inactivity_timer
        
        	Inactivity timeout value in seconds
        	**type**\:  :py:class:`InactivityTimer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceTemplate.InactivityTimer>`
        
        .. attribute:: vlan
        
        	Vlan to be applied
        	**type**\: int
        
        	**range:** 1..4094
        
        .. attribute:: linksec
        
        	Configure link security parameters
        	**type**\:  :py:class:`Linksec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceTemplate.Linksec>`
        
        .. attribute:: voice
        
        	Voice feature
        	**type**\:  :py:class:`Voice <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceTemplate.Voice>`
        
        .. attribute:: sgt
        
        	SGT tag
        	**type**\: int
        
        	**range:** 2..65519
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.ServiceTemplate, self).__init__()

            self.yang_name = "service-template"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['word']
            self._child_classes = OrderedDict([("inactivity-timer", ("inactivity_timer", Native.ServiceTemplate.InactivityTimer)), ("linksec", ("linksec", Native.ServiceTemplate.Linksec)), ("voice", ("voice", Native.ServiceTemplate.Voice))])
            self._leafs = OrderedDict([
                ('word', (YLeaf(YType.str, 'word'), ['str'])),
                ('vlan', (YLeaf(YType.uint16, 'vlan'), ['int'])),
                ('sgt', (YLeaf(YType.uint16, 'sgt'), ['int'])),
            ])
            self.word = None
            self.vlan = None
            self.sgt = None

            self.inactivity_timer = Native.ServiceTemplate.InactivityTimer()
            self.inactivity_timer.parent = self
            self._children_name_map["inactivity_timer"] = "inactivity-timer"

            self.linksec = Native.ServiceTemplate.Linksec()
            self.linksec.parent = self
            self._children_name_map["linksec"] = "linksec"

            self.voice = Native.ServiceTemplate.Voice()
            self.voice.parent = self
            self._children_name_map["voice"] = "voice"
            self._segment_path = lambda: "Cisco-IOS-XE-switch:service-template" + "[word='" + str(self.word) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.ServiceTemplate, [u'word', u'vlan', u'sgt'], name, value)


        class InactivityTimer(Entity):
            """
            Inactivity timeout value in seconds
            
            .. attribute:: value
            
            	Enter a value between 1 and 65535
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: probe
            
            	ARP probe
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.ServiceTemplate.InactivityTimer, self).__init__()

                self.yang_name = "inactivity-timer"
                self.yang_parent_name = "service-template"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('value', (YLeaf(YType.uint16, 'value'), ['int'])),
                    ('probe', (YLeaf(YType.empty, 'probe'), ['Empty'])),
                ])
                self.value = None
                self.probe = None
                self._segment_path = lambda: "inactivity-timer"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceTemplate.InactivityTimer, [u'value', u'probe'], name, value)


        class Linksec(Entity):
            """
            Configure link security parameters
            
            .. attribute:: policy
            
            	Set the link security policy
            	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceTemplate.Linksec.Policy>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.ServiceTemplate.Linksec, self).__init__()

                self.yang_name = "linksec"
                self.yang_parent_name = "service-template"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('policy', (YLeaf(YType.enumeration, 'policy'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'ServiceTemplate.Linksec.Policy')])),
                ])
                self.policy = None
                self._segment_path = lambda: "linksec"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceTemplate.Linksec, [u'policy'], name, value)

            class Policy(Enum):
                """
                Policy (Enum Class)

                Set the link security policy

                .. data:: must_not_secure = 0

                .. data:: must_secure = 1

                .. data:: should_secure = 2

                """

                must_not_secure = Enum.YLeaf(0, "must-not-secure")

                must_secure = Enum.YLeaf(1, "must-secure")

                should_secure = Enum.YLeaf(2, "should-secure")



        class Voice(Entity):
            """
            Voice feature
            
            .. attribute:: vlan
            
            	Critical voice vlan
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.Se